Case study: Classification of shapes
====================================

This notebook explains how to use ``giotto-tda`` to be able to classify
topologically different high-dimensional spaces.

If you are looking at a static version of this notebook and would like
to run its contents, head over to
`github <https://github.com/giotto-ai/giotto-tda/blob/master/examples/classifying_shapes.ipynb>`__.

**License: AGPLv3**

Import libraries
----------------

The first step consists in importing relevant ``giotto-tda`` components
and other useful libraries or modules.

.. code:: ipython3

    # Importing libraries
    from gtda.homology import VietorisRipsPersistence
    from gtda.diagrams import PersistenceEntropy
    
    import numpy as np
    
    from gtda.pipeline import Pipeline
    from sklearn.linear_model import LogisticRegression
    
    # Plotting functions
    from gtda.plotting import plot_diagram, plot_point_cloud, plot_heatmap

Sampling orientable surfaces
----------------------------

We are going to consider three classical topological spaces: the circle,
the 2-torus and the 2-sphere. The purpose of this tutorial is to go
through the most famous topological spaces and compute their homology
groups.

Each of the topological spaces we are going to encounter will be
sampled. The resulting point cloud will be the input of the *persistent
homology pipeline*. The first step is to apply the Vietoris–Rips
technique to the point cloud. Finally, the persistent homology groups
will be computed.

.. code:: ipython3

    # Representing the circle in 3d with parametric equations.
    circle = np.asarray([[np.sin(t),np.cos(t),0] for t in range(400)])
    plot_point_cloud(circle)



.. raw:: html

            <script type="text/javascript">
            window.PlotlyConfig = {MathJaxConfig: 'local'};
            if (window.MathJax) {MathJax.Hub.Config({SVG: {font: "STIX-Web"}});}
            if (typeof require !== 'undefined') {
            require.undef("plotly");
            define('plotly', function(require, exports, module) {
                /**
    * plotly.js v1.53.0
    * Copyright 2012-2020, Plotly, Inc.
    * All rights reserved.
    * Licensed under the MIT license
    */
    !function(t){if("object"==typeof exports&&"undefined"!=typeof module)module.exports=t();else if("function"==typeof define&&define.amd)define([],t);else{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:this).Plotly=t()}}(function(){return function(){return function t(e,r,n){function a(o,s){if(!r[o]){if(!e[o]){var l="function"==typeof require&&require;if(!s&&l)return l(o,!0);if(i)return i(o,!0);var c=new Error("Cannot find module '"+o+"'");throw c.code="MODULE_NOT_FOUND",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,function(t){return a(e[o][1][t]||t)},u,u.exports,t,e,r,n)}return r[o].exports}for(var i="function"==typeof require&&require,o=0;o<n.length;o++)a(n[o]);return a}}()({1:[function(t,e,r){"use strict";var n=t("../src/lib"),a={"X,X div":"direction:ltr;font-family:'Open Sans', verdana, arial, sans-serif;margin:0;padding:0;","X input,X button":"font-family:'Open Sans', verdana, arial, sans-serif;","X input:focus,X button:focus":"outline:none;","X a":"text-decoration:none;","X a:hover":"text-decoration:none;","X .crisp":"shape-rendering:crispEdges;","X .user-select-none":"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;","X svg":"overflow:hidden;","X svg a":"fill:#447adb;","X svg a:hover":"fill:#3c6dc5;","X .main-svg":"position:absolute;top:0;left:0;pointer-events:none;","X .main-svg .draglayer":"pointer-events:all;","X .cursor-default":"cursor:default;","X .cursor-pointer":"cursor:pointer;","X .cursor-crosshair":"cursor:crosshair;","X .cursor-move":"cursor:move;","X .cursor-col-resize":"cursor:col-resize;","X .cursor-row-resize":"cursor:row-resize;","X .cursor-ns-resize":"cursor:ns-resize;","X .cursor-ew-resize":"cursor:ew-resize;","X .cursor-sw-resize":"cursor:sw-resize;","X .cursor-s-resize":"cursor:s-resize;","X .cursor-se-resize":"cursor:se-resize;","X .cursor-w-resize":"cursor:w-resize;","X .cursor-e-resize":"cursor:e-resize;","X .cursor-nw-resize":"cursor:nw-resize;","X .cursor-n-resize":"cursor:n-resize;","X .cursor-ne-resize":"cursor:ne-resize;","X .cursor-grab":"cursor:-webkit-grab;cursor:grab;","X .modebar":"position:absolute;top:2px;right:2px;","X .ease-bg":"-webkit-transition:background-color 0.3s ease 0s;-moz-transition:background-color 0.3s ease 0s;-ms-transition:background-color 0.3s ease 0s;-o-transition:background-color 0.3s ease 0s;transition:background-color 0.3s ease 0s;","X .modebar--hover>:not(.watermark)":"opacity:0;-webkit-transition:opacity 0.3s ease 0s;-moz-transition:opacity 0.3s ease 0s;-ms-transition:opacity 0.3s ease 0s;-o-transition:opacity 0.3s ease 0s;transition:opacity 0.3s ease 0s;","X:hover .modebar--hover .modebar-group":"opacity:1;","X .modebar-group":"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;","X .modebar-btn":"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;","X .modebar-btn svg":"position:relative;top:2px;","X .modebar.vertical":"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;","X .modebar.vertical svg":"top:-1px;","X .modebar.vertical .modebar-group":"display:block;float:none;padding-left:0px;padding-bottom:8px;","X .modebar.vertical .modebar-group .modebar-btn":"display:block;text-align:center;","X [data-title]:before,X [data-title]:after":"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;","X [data-title]:hover:before,X [data-title]:hover:after":"display:block;opacity:1;","X [data-title]:before":"content:'';position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;","X [data-title]:after":"content:attr(data-title);background:#69738a;color:white;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;","X .vertical [data-title]:before,X .vertical [data-title]:after":"top:0%;right:200%;","X .vertical [data-title]:before":"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;","X .select-outline":"fill:none;stroke-width:1;shape-rendering:crispEdges;","X .select-outline-1":"stroke:white;","X .select-outline-2":"stroke:black;stroke-dasharray:2px 2px;",Y:"font-family:'Open Sans';position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;","Y p":"margin:0;","Y .notifier-note":"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,0.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;","Y .notifier-close":"color:#fff;opacity:0.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;","Y .notifier-close:hover":"color:#444;text-decoration:none;cursor:pointer;"};for(var i in a){var o=i.replace(/^,/," ,").replace(/X/g,".js-plotly-plot .plotly").replace(/Y/g,".plotly-notifier");n.addStyleRule(o,a[i])}},{"../src/lib":717}],2:[function(t,e,r){"use strict";e.exports=t("../src/transforms/aggregate")},{"../src/transforms/aggregate":1297}],3:[function(t,e,r){"use strict";e.exports=t("../src/traces/bar")},{"../src/traces/bar":864}],4:[function(t,e,r){"use strict";e.exports=t("../src/traces/barpolar")},{"../src/traces/barpolar":877}],5:[function(t,e,r){"use strict";e.exports=t("../src/traces/box")},{"../src/traces/box":887}],6:[function(t,e,r){"use strict";e.exports=t("../src/components/calendars")},{"../src/components/calendars":589}],7:[function(t,e,r){"use strict";e.exports=t("../src/traces/candlestick")},{"../src/traces/candlestick":896}],8:[function(t,e,r){"use strict";e.exports=t("../src/traces/carpet")},{"../src/traces/carpet":915}],9:[function(t,e,r){"use strict";e.exports=t("../src/traces/choropleth")},{"../src/traces/choropleth":929}],10:[function(t,e,r){"use strict";e.exports=t("../src/traces/choroplethmapbox")},{"../src/traces/choroplethmapbox":936}],11:[function(t,e,r){"use strict";e.exports=t("../src/traces/cone")},{"../src/traces/cone":942}],12:[function(t,e,r){"use strict";e.exports=t("../src/traces/contour")},{"../src/traces/contour":957}],13:[function(t,e,r){"use strict";e.exports=t("../src/traces/contourcarpet")},{"../src/traces/contourcarpet":968}],14:[function(t,e,r){"use strict";e.exports=t("../src/core")},{"../src/core":695}],15:[function(t,e,r){"use strict";e.exports=t("../src/traces/densitymapbox")},{"../src/traces/densitymapbox":976}],16:[function(t,e,r){"use strict";e.exports=t("../src/transforms/filter")},{"../src/transforms/filter":1298}],17:[function(t,e,r){"use strict";e.exports=t("../src/traces/funnel")},{"../src/traces/funnel":986}],18:[function(t,e,r){"use strict";e.exports=t("../src/traces/funnelarea")},{"../src/traces/funnelarea":995}],19:[function(t,e,r){"use strict";e.exports=t("../src/transforms/groupby")},{"../src/transforms/groupby":1299}],20:[function(t,e,r){"use strict";e.exports=t("../src/traces/heatmap")},{"../src/traces/heatmap":1008}],21:[function(t,e,r){"use strict";e.exports=t("../src/traces/heatmapgl")},{"../src/traces/heatmapgl":1017}],22:[function(t,e,r){"use strict";e.exports=t("../src/traces/histogram")},{"../src/traces/histogram":1029}],23:[function(t,e,r){"use strict";e.exports=t("../src/traces/histogram2d")},{"../src/traces/histogram2d":1035}],24:[function(t,e,r){"use strict";e.exports=t("../src/traces/histogram2dcontour")},{"../src/traces/histogram2dcontour":1039}],25:[function(t,e,r){"use strict";e.exports=t("../src/traces/image")},{"../src/traces/image":1046}],26:[function(t,e,r){"use strict";var n=t("./core");n.register([t("./bar"),t("./box"),t("./heatmap"),t("./histogram"),t("./histogram2d"),t("./histogram2dcontour"),t("./contour"),t("./scatterternary"),t("./violin"),t("./funnel"),t("./waterfall"),t("./image"),t("./pie"),t("./sunburst"),t("./treemap"),t("./funnelarea"),t("./scatter3d"),t("./surface"),t("./isosurface"),t("./volume"),t("./mesh3d"),t("./cone"),t("./streamtube"),t("./scattergeo"),t("./choropleth"),t("./scattergl"),t("./splom"),t("./pointcloud"),t("./heatmapgl"),t("./parcoords"),t("./parcats"),t("./scattermapbox"),t("./choroplethmapbox"),t("./densitymapbox"),t("./sankey"),t("./indicator"),t("./table"),t("./carpet"),t("./scattercarpet"),t("./contourcarpet"),t("./ohlc"),t("./candlestick"),t("./scatterpolar"),t("./scatterpolargl"),t("./barpolar")]),n.register([t("./aggregate"),t("./filter"),t("./groupby"),t("./sort")]),n.register([t("./calendars")]),e.exports=n},{"./aggregate":2,"./bar":3,"./barpolar":4,"./box":5,"./calendars":6,"./candlestick":7,"./carpet":8,"./choropleth":9,"./choroplethmapbox":10,"./cone":11,"./contour":12,"./contourcarpet":13,"./core":14,"./densitymapbox":15,"./filter":16,"./funnel":17,"./funnelarea":18,"./groupby":19,"./heatmap":20,"./heatmapgl":21,"./histogram":22,"./histogram2d":23,"./histogram2dcontour":24,"./image":25,"./indicator":27,"./isosurface":28,"./mesh3d":29,"./ohlc":30,"./parcats":31,"./parcoords":32,"./pie":33,"./pointcloud":34,"./sankey":35,"./scatter3d":36,"./scattercarpet":37,"./scattergeo":38,"./scattergl":39,"./scattermapbox":40,"./scatterpolar":41,"./scatterpolargl":42,"./scatterternary":43,"./sort":44,"./splom":45,"./streamtube":46,"./sunburst":47,"./surface":48,"./table":49,"./treemap":50,"./violin":51,"./volume":52,"./waterfall":53}],27:[function(t,e,r){"use strict";e.exports=t("../src/traces/indicator")},{"../src/traces/indicator":1054}],28:[function(t,e,r){"use strict";e.exports=t("../src/traces/isosurface")},{"../src/traces/isosurface":1060}],29:[function(t,e,r){"use strict";e.exports=t("../src/traces/mesh3d")},{"../src/traces/mesh3d":1065}],30:[function(t,e,r){"use strict";e.exports=t("../src/traces/ohlc")},{"../src/traces/ohlc":1070}],31:[function(t,e,r){"use strict";e.exports=t("../src/traces/parcats")},{"../src/traces/parcats":1079}],32:[function(t,e,r){"use strict";e.exports=t("../src/traces/parcoords")},{"../src/traces/parcoords":1089}],33:[function(t,e,r){"use strict";e.exports=t("../src/traces/pie")},{"../src/traces/pie":1100}],34:[function(t,e,r){"use strict";e.exports=t("../src/traces/pointcloud")},{"../src/traces/pointcloud":1109}],35:[function(t,e,r){"use strict";e.exports=t("../src/traces/sankey")},{"../src/traces/sankey":1115}],36:[function(t,e,r){"use strict";e.exports=t("../src/traces/scatter3d")},{"../src/traces/scatter3d":1152}],37:[function(t,e,r){"use strict";e.exports=t("../src/traces/scattercarpet")},{"../src/traces/scattercarpet":1159}],38:[function(t,e,r){"use strict";e.exports=t("../src/traces/scattergeo")},{"../src/traces/scattergeo":1167}],39:[function(t,e,r){"use strict";e.exports=t("../src/traces/scattergl")},{"../src/traces/scattergl":1180}],40:[function(t,e,r){"use strict";e.exports=t("../src/traces/scattermapbox")},{"../src/traces/scattermapbox":1190}],41:[function(t,e,r){"use strict";e.exports=t("../src/traces/scatterpolar")},{"../src/traces/scatterpolar":1198}],42:[function(t,e,r){"use strict";e.exports=t("../src/traces/scatterpolargl")},{"../src/traces/scatterpolargl":1205}],43:[function(t,e,r){"use strict";e.exports=t("../src/traces/scatterternary")},{"../src/traces/scatterternary":1213}],44:[function(t,e,r){"use strict";e.exports=t("../src/transforms/sort")},{"../src/transforms/sort":1301}],45:[function(t,e,r){"use strict";e.exports=t("../src/traces/splom")},{"../src/traces/splom":1222}],46:[function(t,e,r){"use strict";e.exports=t("../src/traces/streamtube")},{"../src/traces/streamtube":1230}],47:[function(t,e,r){"use strict";e.exports=t("../src/traces/sunburst")},{"../src/traces/sunburst":1238}],48:[function(t,e,r){"use strict";e.exports=t("../src/traces/surface")},{"../src/traces/surface":1247}],49:[function(t,e,r){"use strict";e.exports=t("../src/traces/table")},{"../src/traces/table":1255}],50:[function(t,e,r){"use strict";e.exports=t("../src/traces/treemap")},{"../src/traces/treemap":1264}],51:[function(t,e,r){"use strict";e.exports=t("../src/traces/violin")},{"../src/traces/violin":1276}],52:[function(t,e,r){"use strict";e.exports=t("../src/traces/volume")},{"../src/traces/volume":1284}],53:[function(t,e,r){"use strict";e.exports=t("../src/traces/waterfall")},{"../src/traces/waterfall":1292}],54:[function(t,e,r){"use strict";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||"turntable",u=n(),h=a(),f=i();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),new o({turntable:u,orbit:h,matrix:f},c)};var n=t("turntable-camera-controller"),a=t("orbit-camera-controller"),i=t("matrix-camera-controller");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map(function(e){return t[e]}),this._mode=e,this._active=t[e],this._active||(this._mode="turntable",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[["flush",1],["idle",1],["lookAt",4],["rotate",4],["pan",4],["translate",4],["setMatrix",2],["setDistanceLimits",2],["setDistance",2]].forEach(function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push("a"+n);var a="var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i]."+t[0]+"("+r.join()+")}";s[e]=Function.apply(null,r.concat(a))}),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],a=Math.max(r.lastT(),n.lastT());r.recalcMatrix(a),n.setMatrix(a,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{"matrix-camera-controller":434,"orbit-camera-controller":457,"turntable-camera-controller":540}],55:[function(t,e,r){var n,a;n=this,a=function(t,e,r,n,a){"use strict";function i(t){return t.target.depth}function o(t,e){return t.sourceLinks.length?t.depth:e-1}function s(t){return function(){return t}}a=a&&a.hasOwnProperty("default")?a.default:a;var l="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t};function c(t,e){return h(t.source,e.source)||t.index-e.index}function u(t,e){return h(t.target,e.target)||t.index-e.index}function h(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:"top"===t.circularLinkType||"bottom"===e.circularLinkType?-1:1}function f(t){return t.value}function p(t){return(t.y0+t.y1)/2}function d(t){return p(t.source)}function g(t){return p(t.target)}function v(t){return t.index}function m(t){return t.nodes}function y(t){return t.links}function x(t,e){var r=t.get(e);if(!r)throw new Error("missing: "+e);return r}function b(t,e){return e(t)}var _=25,w=10,k=.3;function T(t,e){var r=0,n=0;t.links.forEach(function(a){a.circular&&(a.source.circularLinkType||a.target.circularLinkType?a.circularLinkType=a.source.circularLinkType?a.source.circularLinkType:a.target.circularLinkType:a.circularLinkType=r<n?"top":"bottom","top"==a.circularLinkType?r+=1:n+=1,t.nodes.forEach(function(t){b(t,e)!=b(a.source,e)&&b(t,e)!=b(a.target,e)||(t.circularLinkType=a.circularLinkType)}))}),t.links.forEach(function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),Y(t,e)&&(t.circularLinkType=t.source.circularLinkType))})}function M(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function A(t,e){var r=0;t.sourceLinks.forEach(function(t){r=t.circular&&!Y(t,e)?r+1:r});var n=0;return t.targetLinks.forEach(function(t){n=t.circular&&!Y(t,e)?n+1:n}),r+n}function S(t){var e=t.source.sourceLinks,r=0;e.forEach(function(t){r=t.circular?r+1:r});var n=t.target.targetLinks,a=0;return n.forEach(function(t){a=t.circular?a+1:a}),!(r>1||a>1)}function E(t,e,r){return t.sort(C),t.forEach(function(n,a){var i,o,s=0;if(Y(n,r)&&S(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<a;l++)if(i=t[a],o=t[l],!(i.source.column<o.target.column||i.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}}),t}function L(t,r,a,i){var o=e.min(t.links,function(t){return t.source.y0});t.links.forEach(function(t){t.circular&&(t.circularPathData={})}),E(t.links.filter(function(t){return"top"==t.circularLinkType}),r,i),E(t.links.filter(function(t){return"bottom"==t.circularLinkType}),r,i),t.links.forEach(function(e){if(e.circular){if(e.circularPathData.arcRadius=e.width+w,e.circularPathData.leftNodeBuffer=5,e.circularPathData.rightNodeBuffer=5,e.circularPathData.sourceWidth=e.source.x1-e.source.x0,e.circularPathData.sourceX=e.source.x0+e.circularPathData.sourceWidth,e.circularPathData.targetX=e.target.x0,e.circularPathData.sourceY=e.y0,e.circularPathData.targetY=e.y1,Y(e,i)&&S(e))e.circularPathData.leftSmallArcRadius=w+e.width/2,e.circularPathData.leftLargeArcRadius=w+e.width/2,e.circularPathData.rightSmallArcRadius=w+e.width/2,e.circularPathData.rightLargeArcRadius=w+e.width/2,"bottom"==e.circularLinkType?(e.circularPathData.verticalFullExtent=e.source.y1+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=e.source.y0-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius);else{var s=e.source.column,l=e.circularLinkType,c=t.links.filter(function(t){return t.source.column==s&&t.circularLinkType==l});"bottom"==e.circularLinkType?c.sort(O):c.sort(P);var u=0;c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.leftSmallArcRadius=w+e.width/2+u,e.circularPathData.leftLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),s=e.target.column,c=t.links.filter(function(t){return t.target.column==s&&t.circularLinkType==l}),"bottom"==e.circularLinkType?c.sort(I):c.sort(z),u=0,c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.rightSmallArcRadius=w+e.width/2+u,e.circularPathData.rightLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),"bottom"==e.circularLinkType?(e.circularPathData.verticalFullExtent=Math.max(a,e.source.y1,e.target.y1)+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=o-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius)}e.circularPathData.leftInnerExtent=e.circularPathData.sourceX+e.circularPathData.leftNodeBuffer,e.circularPathData.rightInnerExtent=e.circularPathData.targetX-e.circularPathData.rightNodeBuffer,e.circularPathData.leftFullExtent=e.circularPathData.sourceX+e.circularPathData.leftLargeArcRadius+e.circularPathData.leftNodeBuffer,e.circularPathData.rightFullExtent=e.circularPathData.targetX-e.circularPathData.rightLargeArcRadius-e.circularPathData.rightNodeBuffer}if(e.circular)e.path=function(t){var e="";e="top"==t.circularLinkType?"M"+t.circularPathData.sourceX+" "+t.circularPathData.sourceY+" L"+t.circularPathData.leftInnerExtent+" "+t.circularPathData.sourceY+" A"+t.circularPathData.leftLargeArcRadius+" "+t.circularPathData.leftSmallArcRadius+" 0 0 0 "+t.circularPathData.leftFullExtent+" "+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+" L"+t.circularPathData.leftFullExtent+" "+t.circularPathData.verticalLeftInnerExtent+" A"+t.circularPathData.leftLargeArcRadius+" "+t.circularPathData.leftLargeArcRadius+" 0 0 0 "+t.circularPathData.leftInnerExtent+" "+t.circularPathData.verticalFullExtent+" L"+t.circularPathData.rightInnerExtent+" "+t.circularPathData.verticalFullExtent+" A"+t.circularPathData.rightLargeArcRadius+" "+t.circularPathData.rightLargeArcRadius+" 0 0 0 "+t.circularPathData.rightFullExtent+" "+t.circularPathData.verticalRightInnerExtent+" L"+t.circularPathData.rightFullExtent+" "+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+" A"+t.circularPathData.rightLargeArcRadius+" "+t.circularPathData.rightSmallArcRadius+" 0 0 0 "+t.circularPathData.rightInnerExtent+" "+t.circularPathData.targetY+" L"+t.circularPathData.targetX+" "+t.circularPathData.targetY:"M"+t.circularPathData.sourceX+" "+t.circularPathData.sourceY+" L"+t.circularPathData.leftInnerExtent+" "+t.circularPathData.sourceY+" A"+t.circularPathData.leftLargeArcRadius+" "+t.circularPathData.leftSmallArcRadius+" 0 0 1 "+t.circularPathData.leftFullExtent+" "+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+" L"+t.circularPathData.leftFullExtent+" "+t.circularPathData.verticalLeftInnerExtent+" A"+t.circularPathData.leftLargeArcRadius+" "+t.circularPathData.leftLargeArcRadius+" 0 0 1 "+t.circularPathData.leftInnerExtent+" "+t.circularPathData.verticalFullExtent+" L"+t.circularPathData.rightInnerExtent+" "+t.circularPathData.verticalFullExtent+" A"+t.circularPathData.rightLargeArcRadius+" "+t.circularPathData.rightLargeArcRadius+" 0 0 1 "+t.circularPathData.rightFullExtent+" "+t.circularPathData.verticalRightInnerExtent+" L"+t.circularPathData.rightFullExtent+" "+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+" A"+t.circularPathData.rightLargeArcRadius+" "+t.circularPathData.rightSmallArcRadius+" 0 0 1 "+t.circularPathData.rightInnerExtent+" "+t.circularPathData.targetY+" L"+t.circularPathData.targetX+" "+t.circularPathData.targetY;return e}(e);else{var h=n.linkHorizontal().source(function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]}).target(function(t){return[t.target.x0,t.y1]});e.path=h(e)}})}function C(t,e){return D(t)==D(e)?"bottom"==t.circularLinkType?O(t,e):P(t,e):D(e)-D(t)}function P(t,e){return t.y0-e.y0}function O(t,e){return e.y0-t.y0}function z(t,e){return t.y1-e.y1}function I(t,e){return e.y1-t.y1}function D(t){return t.target.column-t.source.column}function R(t){return t.target.x0-t.source.x1}function F(t,e){var r=M(t),n=R(e)/Math.tan(r);return"up"==G(t)?t.y1+n:t.y1-n}function B(t,e){var r=M(t),n=R(e)/Math.tan(r);return"up"==G(t)?t.y1-n:t.y1+n}function N(t,e,r,n){t.links.forEach(function(a){if(!a.circular&&a.target.column-a.source.column>1){var i=a.source.column+1,o=a.target.column-1,s=1,l=o-i+1;for(s=1;i<=o;i++,s++)t.nodes.forEach(function(o){if(o.column==i){var c,u=s/(l+1),h=Math.pow(1-u,3),f=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),g=h*a.y0+f*a.y0+p*a.y1+d*a.y1,v=g-a.width/2,m=g+a.width/2;v>o.y0&&v<o.y1?(c=o.y1-v+10,c="bottom"==o.circularLinkType?c:-c,o=V(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&j(o,t)&&V(t,c,e,r)})):m>o.y0&&m<o.y1?(c=m-o.y0+10,o=V(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&V(t,c,e,r)})):v<o.y0&&m>o.y1&&(c=m-o.y0+10,o=V(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&V(t,c,e,r)}))}})}})}function j(t,e){return t.y0>e.y0&&t.y0<e.y1||(t.y1>e.y0&&t.y1<e.y1||t.y0<e.y0&&t.y1>e.y1)}function V(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach(function(t){t.y1=t.y1+e}),t.sourceLinks.forEach(function(t){t.y0=t.y0+e})),t}function U(t,e,r,n){t.nodes.forEach(function(a){n&&a.y+(a.y1-a.y0)>e&&(a.y=a.y-(a.y+(a.y1-a.y0)-e));var i=t.links.filter(function(t){return b(t.source,r)==b(a,r)}),o=i.length;o>1&&i.sort(function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!H(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=B(e,t);return t.y1-r}if(e.target.column>t.target.column)return B(t,e)-e.y1}return t.circular&&!e.circular?"top"==t.circularLinkType?-1:1:e.circular&&!t.circular?"top"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&"top"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&"bottom"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:"top"==t.circularLinkType?-1:1:void 0});var s=a.y0;i.forEach(function(t){t.y0=s+t.width/2,s+=t.width}),i.forEach(function(t,e){if("bottom"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=i[r].width;t.y0=a.y1-n-t.width/2}})})}function q(t,e,r){t.nodes.forEach(function(e){var n=t.links.filter(function(t){return b(t.target,r)==b(e,r)}),a=n.length;a>1&&n.sort(function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!H(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=F(e,t);return t.y0-r}if(t.source.column<e.source.column)return F(t,e)-e.y0}return t.circular&&!e.circular?"top"==t.circularLinkType?-1:1:e.circular&&!t.circular?"top"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&"top"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&"bottom"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:"top"==t.circularLinkType?-1:1:void 0});var i=e.y0;n.forEach(function(t){t.y1=i+t.width/2,i+=t.width}),n.forEach(function(t,r){if("bottom"==t.circularLinkType){for(var i=r+1,o=0;i<a;i++)o+=n[i].width;t.y1=e.y1-o-t.width/2}})})}function H(t,e){return G(t)==G(e)}function G(t){return t.y0-t.y1>0?"up":"down"}function Y(t,e){return b(t.source,e)==b(t.target,e)}t.sankeyCircular=function(){var t,n,i=0,b=0,M=1,S=1,E=24,C=v,P=o,O=m,z=y,I=32,D=2,R=null;function F(){var o={nodes:O.apply(null,arguments),links:z.apply(null,arguments)};!function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,C);t.links.forEach(function(t,r){t.index=r;var n=t.source,a=t.target;"object"!==("undefined"==typeof n?"undefined":l(n))&&(n=t.source=x(e,n)),"object"!==("undefined"==typeof a?"undefined":l(a))&&(a=t.target=x(e,a)),n.sourceLinks.push(t),a.targetLinks.push(t)})}(o),function(t,e,r){var n=0;if(null===r){for(var i=[],o=0;o<t.links.length;o++){var s=t.links[o],l=s.source.index,c=s.target.index;i[l]||(i[l]=[]),i[c]||(i[c]=[]),-1===i[l].indexOf(c)&&i[l].push(c)}var u=a(i);u.sort(function(t,e){return t.length-e.length});var h={};for(o=0;o<u.length;o++){var f=u[o],p=f.slice(-2);h[p[0]]||(h[p[0]]={}),h[p[0]][p[1]]=!0}t.links.forEach(function(t){var e=t.target.index,r=t.source.index;e===r||h[r]&&h[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1})}else t.links.forEach(function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)})}(o,0,R),function(t){t.nodes.forEach(function(t){t.partOfCycle=!1,t.value=Math.max(e.sum(t.sourceLinks,f),e.sum(t.targetLinks,f)),t.sourceLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}),t.targetLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})})}(o),function(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.depth=n,t.sourceLinks.forEach(function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)})});for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.height=n,t.targetLinks.forEach(function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)})});t.nodes.forEach(function(t){t.column=Math.floor(P.call(null,t,n))})}(o),T(o,C),function(a,o,s){var l=r.nest().key(function(t){return t.column}).sortKeys(e.ascending).entries(a.nodes).map(function(t){return t.values});(function(r){if(n){var o=1/0;l.forEach(function(t){var e=S*n/(t.length+1);o=e<o?e:o}),t=o}var s=e.min(l,function(r){return(S-b-(r.length-1)*t)/e.sum(r,f)});s*=k,a.links.forEach(function(t){t.width=t.value*s});var c=function(t){var r=0,n=0,a=0,i=0,o=e.max(t.nodes,function(t){return t.column});return t.links.forEach(function(t){t.circular&&("top"==t.circularLinkType?r+=t.width:n+=t.width,0==t.target.column&&(i+=t.width),t.source.column==o&&(a+=t.width))}),{top:r=r>0?r+_+w:r,bottom:n=n>0?n+_+w:n,left:i=i>0?i+_+w:i,right:a=a>0?a+_+w:a}}(a),u=function(t,r){var n=e.max(t.nodes,function(t){return t.column}),a=M-i,o=S-b,s=a+r.right+r.left,l=o+r.top+r.bottom,c=a/s,u=o/l;return i=i*c+r.left,M=0==r.right?M:M*c,b=b*u+r.top,S*=u,t.nodes.forEach(function(t){t.x0=i+t.column*((M-i-E)/n),t.x1=t.x0+E}),u}(a,c);s*=u,a.links.forEach(function(t){t.width=t.value*s}),l.forEach(function(t){var e=t.length;t.forEach(function(t,n){t.depth==l.length-1&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):0==t.depth&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):t.partOfCycle?0==A(t,r)?(t.y0=S/2+n,t.y1=t.y0+t.value*s):"top"==t.circularLinkType?(t.y0=b+n,t.y1=t.y0+t.value*s):(t.y0=S-t.value*s-n,t.y1=t.y0+t.value*s):0==c.top||0==c.bottom?(t.y0=(S-b)/e*n,t.y1=t.y0+t.value*s):(t.y0=(S-b)/2-e/2+n,t.y1=t.y0+t.value*s)})})})(s),m();for(var c=1,u=o;u>0;--u)v(c*=.99,s),m();function v(t,r){var n=l.length;l.forEach(function(a){var i=a.length,o=a[0].depth;a.forEach(function(a){var s;if(a.sourceLinks.length||a.targetLinks.length)if(a.partOfCycle&&A(a,r)>0);else if(0==o&&1==i)s=a.y1-a.y0,a.y0=S/2-s/2,a.y1=S/2+s/2;else if(o==n-1&&1==i)s=a.y1-a.y0,a.y0=S/2-s/2,a.y1=S/2+s/2;else{var l=e.mean(a.sourceLinks,g),c=e.mean(a.targetLinks,d),u=((l&&c?(l+c)/2:l||c)-p(a))*t;a.y0+=u,a.y1+=u}})})}function m(){l.forEach(function(e){var r,n,a,i=b,o=e.length;for(e.sort(h),a=0;a<o;++a)r=e[a],(n=i-r.y0)>0&&(r.y0+=n,r.y1+=n),i=r.y1+t;if((n=i-t-S)>0)for(i=r.y0-=n,r.y1-=n,a=o-2;a>=0;--a)r=e[a],(n=r.y1+t-i)>0&&(r.y0-=n,r.y1-=n),i=r.y0})}}(o,I,C),B(o);for(var s=0;s<4;s++)U(o,S,C),q(o,0,C),N(o,b,S,C),U(o,S,C),q(o,0,C);return function(t,r,n){var a=t.nodes,i=t.links,o=!1,s=!1;if(i.forEach(function(t){"top"==t.circularLinkType?o=!0:"bottom"==t.circularLinkType&&(s=!0)}),0==o||0==s){var l=e.min(a,function(t){return t.y0}),c=e.max(a,function(t){return t.y1}),u=c-l,h=n-r,f=h/u;a.forEach(function(t){var e=(t.y1-t.y0)*f;t.y0=(t.y0-l)*f,t.y1=t.y0+e}),i.forEach(function(t){t.y0=(t.y0-l)*f,t.y1=(t.y1-l)*f,t.width=t.width*f})}}(o,b,S),L(o,D,S,C),o}function B(t){t.nodes.forEach(function(t){t.sourceLinks.sort(u),t.targetLinks.sort(c)}),t.nodes.forEach(function(t){var e=t.y0,r=e,n=t.y1,a=n;t.sourceLinks.forEach(function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)}),t.targetLinks.forEach(function(t){t.circular?(t.y1=a-t.width/2,a-=t.width):(t.y1=r+t.width/2,r+=t.width)})})}return F.nodeId=function(t){return arguments.length?(C="function"==typeof t?t:s(t),F):C},F.nodeAlign=function(t){return arguments.length?(P="function"==typeof t?t:s(t),F):P},F.nodeWidth=function(t){return arguments.length?(E=+t,F):E},F.nodePadding=function(e){return arguments.length?(t=+e,F):t},F.nodes=function(t){return arguments.length?(O="function"==typeof t?t:s(t),F):O},F.links=function(t){return arguments.length?(z="function"==typeof t?t:s(t),F):z},F.size=function(t){return arguments.length?(i=b=0,M=+t[0],S=+t[1],F):[M-i,S-b]},F.extent=function(t){return arguments.length?(i=+t[0][0],M=+t[1][0],b=+t[0][1],S=+t[1][1],F):[[i,b],[M,S]]},F.iterations=function(t){return arguments.length?(I=+t,F):I},F.circularLinkGap=function(t){return arguments.length?(D=+t,F):D},F.nodePaddingRatio=function(t){return arguments.length?(n=+t,F):n},F.sortNodes=function(t){return arguments.length?(R=t,F):R},F.update=function(t){return T(t,C),B(t),t.links.forEach(function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<S?"top":"bottom",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)}),U(t,S,C,!1),q(t,0,C),L(t,D,S,C),t},F},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,i)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=o,Object.defineProperty(t,"__esModule",{value:!0})},"object"==typeof r&&"undefined"!=typeof e?a(r,t("d3-array"),t("d3-collection"),t("d3-shape"),t("elementary-circuits-directed-graph")):a(n.d3=n.d3||{},n.d3,n.d3,n.d3,null)},{"d3-array":154,"d3-collection":155,"d3-shape":163,"elementary-circuits-directed-graph":175}],56:[function(t,e,r){var n,a;n=this,a=function(t,e,r,n){"use strict";function a(t){return t.target.depth}function i(t,e){return t.sourceLinks.length?t.depth:e-1}function o(t){return function(){return t}}function s(t,e){return c(t.source,e.source)||t.index-e.index}function l(t,e){return c(t.target,e.target)||t.index-e.index}function c(t,e){return t.y0-e.y0}function u(t){return t.value}function h(t){return(t.y0+t.y1)/2}function f(t){return h(t.source)*t.value}function p(t){return h(t.target)*t.value}function d(t){return t.index}function g(t){return t.nodes}function v(t){return t.links}function m(t,e){var r=t.get(e);if(!r)throw new Error("missing: "+e);return r}function y(t){return[t.source.x1,t.y0]}function x(t){return[t.target.x0,t.y1]}t.sankey=function(){var t=0,n=0,a=1,y=1,x=24,b=8,_=d,w=i,k=g,T=v,M=32,A=2/3;function S(){var i={nodes:k.apply(null,arguments),links:T.apply(null,arguments)};return function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,_);t.links.forEach(function(t,r){t.index=r;var n=t.source,a=t.target;"object"!=typeof n&&(n=t.source=m(e,n)),"object"!=typeof a&&(a=t.target=m(e,a)),n.sourceLinks.push(t),a.targetLinks.push(t)})}(i),function(t){t.nodes.forEach(function(t){t.value=Math.max(e.sum(t.sourceLinks,u),e.sum(t.targetLinks,u))})}(i),function(e){var r,n,i;for(r=e.nodes,n=[],i=0;r.length;++i,r=n,n=[])r.forEach(function(t){t.depth=i,t.sourceLinks.forEach(function(t){n.indexOf(t.target)<0&&n.push(t.target)})});for(r=e.nodes,n=[],i=0;r.length;++i,r=n,n=[])r.forEach(function(t){t.height=i,t.targetLinks.forEach(function(t){n.indexOf(t.source)<0&&n.push(t.source)})});var o=(a-t-x)/(i-1);e.nodes.forEach(function(e){e.x1=(e.x0=t+Math.max(0,Math.min(i-1,Math.floor(w.call(null,e,i))))*o)+x})}(i),function(t){var a=r.nest().key(function(t){return t.x0}).sortKeys(e.ascending).entries(t.nodes).map(function(t){return t.values});(function(){var r=e.max(a,function(t){return t.length}),i=A*(y-n)/(r-1);b>i&&(b=i);var o=e.min(a,function(t){return(y-n-(t.length-1)*b)/e.sum(t,u)});a.forEach(function(t){t.forEach(function(t,e){t.y1=(t.y0=e)+t.value*o})}),t.links.forEach(function(t){t.width=t.value*o})})(),d();for(var i=1,o=M;o>0;--o)l(i*=.99),d(),s(i),d();function s(t){a.forEach(function(r){r.forEach(function(r){if(r.targetLinks.length){var n=(e.sum(r.targetLinks,f)/e.sum(r.targetLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function l(t){a.slice().reverse().forEach(function(r){r.forEach(function(r){if(r.sourceLinks.length){var n=(e.sum(r.sourceLinks,p)/e.sum(r.sourceLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function d(){a.forEach(function(t){var e,r,a,i=n,o=t.length;for(t.sort(c),a=0;a<o;++a)e=t[a],(r=i-e.y0)>0&&(e.y0+=r,e.y1+=r),i=e.y1+b;if((r=i-b-y)>0)for(i=e.y0-=r,e.y1-=r,a=o-2;a>=0;--a)e=t[a],(r=e.y1+b-i)>0&&(e.y0-=r,e.y1-=r),i=e.y0})}}(i),E(i),i}function E(t){t.nodes.forEach(function(t){t.sourceLinks.sort(l),t.targetLinks.sort(s)}),t.nodes.forEach(function(t){var e=t.y0,r=e;t.sourceLinks.forEach(function(t){t.y0=e+t.width/2,e+=t.width}),t.targetLinks.forEach(function(t){t.y1=r+t.width/2,r+=t.width})})}return S.update=function(t){return E(t),t},S.nodeId=function(t){return arguments.length?(_="function"==typeof t?t:o(t),S):_},S.nodeAlign=function(t){return arguments.length?(w="function"==typeof t?t:o(t),S):w},S.nodeWidth=function(t){return arguments.length?(x=+t,S):x},S.nodePadding=function(t){return arguments.length?(b=+t,S):b},S.nodes=function(t){return arguments.length?(k="function"==typeof t?t:o(t),S):k},S.links=function(t){return arguments.length?(T="function"==typeof t?t:o(t),S):T},S.size=function(e){return arguments.length?(t=n=0,a=+e[0],y=+e[1],S):[a-t,y-n]},S.extent=function(e){return arguments.length?(t=+e[0][0],a=+e[1][0],n=+e[0][1],y=+e[1][1],S):[[t,n],[a,y]]},S.iterations=function(t){return arguments.length?(M=+t,S):M},S},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,a)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=i,t.sankeyLinkHorizontal=function(){return n.linkHorizontal().source(y).target(x)},Object.defineProperty(t,"__esModule",{value:!0})},"object"==typeof r&&"undefined"!=typeof e?a(r,t("d3-array"),t("d3-collection"),t("d3-shape")):a(n.d3=n.d3||{},n.d3,n.d3,n.d3)},{"d3-array":154,"d3-collection":155,"d3-shape":163}],57:[function(t,e,r){"use strict";Object.defineProperty(r,"__esModule",{value:!0});var n=t("@turf/meta"),a=6378137;function i(t){var e=0;if(t&&t.length>0){e+=Math.abs(o(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(o(t[r]))}return e}function o(t){var e,r,n,i,o,l,c=0,u=t.length;if(u>2){for(l=0;l<u;l++)l===u-2?(n=u-2,i=u-1,o=0):l===u-1?(n=u-1,i=0,o=1):(n=l,i=l+1,o=l+2),e=t[n],r=t[i],c+=(s(t[o][0])-s(e[0]))*Math.sin(s(r[1]));c=c*a*a/2}return c}function s(t){return t*Math.PI/180}r.default=function(t){return n.geomReduce(t,function(t,e){return t+function(t){var e,r=0;switch(t.type){case"Polygon":return i(t.coordinates);case"MultiPolygon":for(e=0;e<t.coordinates.length;e++)r+=i(t.coordinates[e]);return r;case"Point":case"MultiPoint":case"LineString":case"MultiLineString":return 0}return 0}(e)},0)}},{"@turf/meta":61}],58:[function(t,e,r){"use strict";Object.defineProperty(r,"__esModule",{value:!0});var n=t("@turf/meta");r.default=function(t){var e=[1/0,1/0,-1/0,-1/0];return n.coordEach(t,function(t){e[0]>t[0]&&(e[0]=t[0]),e[1]>t[1]&&(e[1]=t[1]),e[2]<t[0]&&(e[2]=t[0]),e[3]<t[1]&&(e[3]=t[1])}),e}},{"@turf/meta":61}],59:[function(t,e,r){"use strict";Object.defineProperty(r,"__esModule",{value:!0});var n=t("@turf/meta"),a=t("@turf/helpers");r.default=function(t,e){void 0===e&&(e={});var r=0,i=0,o=0;return n.coordEach(t,function(t){r+=t[0],i+=t[1],o++}),a.point([r/o,i/o],e.properties)}},{"@turf/helpers":60,"@turf/meta":61}],60:[function(t,e,r){"use strict";function n(t,e,r){void 0===r&&(r={});var n={type:"Feature"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function a(t,e,r){return void 0===r&&(r={}),n({type:"Point",coordinates:t},e,r)}function i(t,e,r){void 0===r&&(r={});for(var a=0,i=t;a<i.length;a++){var o=i[a];if(o.length<4)throw new Error("Each LinearRing of a Polygon must have 4 or more Positions.");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error("First and last Position are not equivalent.")}return n({type:"Polygon",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error("coordinates must be an array of two or more positions");return n({type:"LineString",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:"FeatureCollection"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:"MultiLineString",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:"MultiPoint",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:"MultiPolygon",coordinates:t},e,r)}function h(t,e){void 0===e&&(e="kilometers");var n=r.factors[e];if(!n)throw new Error(e+" units is invalid");return t*n}function f(t,e){void 0===e&&(e="kilometers");var n=r.factors[e];if(!n)throw new Error(e+" units is invalid");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)&&!/^\s*$/.test(t)}Object.defineProperty(r,"__esModule",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:r.earthRadius/1.0936},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1/1.0936},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:3.86e-7,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case"Point":return a(e).geometry;case"LineString":return o(e).geometry;case"Polygon":return i(e).geometry;case"MultiPoint":return c(e).geometry;case"MultiLineString":return l(e).geometry;case"MultiPolygon":return u(e).geometry;default:throw new Error(t+" is invalid")}},r.point=a,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return a(t,e)}),r)},r.polygon=i,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return i(t,e)}),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return o(t,e)}),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:"GeometryCollection",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error("precision must be a positive number");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=h,r.lengthToRadians=f,r.lengthToDegrees=function(t,e){return p(f(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e="kilometers"),void 0===r&&(r="kilometers"),!(t>=0))throw new Error("length must be a positive number");return h(f(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e="meters"),void 0===n&&(n="kilometers"),!(t>=0))throw new Error("area must be a positive number");var a=r.areaFactors[e];if(!a)throw new Error("invalid original units");var i=r.areaFactors[n];if(!i)throw new Error("invalid final units");return t/a*i},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error("bbox is required");if(!Array.isArray(t))throw new Error("bbox must be an Array");if(4!==t.length&&6!==t.length)throw new Error("bbox must be an Array of 4 or 6 numbers");t.forEach(function(t){if(!d(t))throw new Error("bbox must only contain numbers")})},r.validateId=function(t){if(!t)throw new Error("id is required");if(-1===["string","number"].indexOf(typeof t))throw new Error("id must be a number or a string")},r.radians2degrees=function(){throw new Error("method has been renamed to `radiansToDegrees`")},r.degrees2radians=function(){throw new Error("method has been renamed to `degreesToRadians`")},r.distanceToDegrees=function(){throw new Error("method has been renamed to `lengthToDegrees`")},r.distanceToRadians=function(){throw new Error("method has been renamed to `lengthToRadians`")},r.radiansToDistance=function(){throw new Error("method has been renamed to `radiansToLength`")},r.bearingToAngle=function(){throw new Error("method has been renamed to `bearingToAzimuth`")},r.convertDistance=function(){throw new Error("method has been renamed to `convertLength`")}},{}],61:[function(t,e,r){"use strict";Object.defineProperty(r,"__esModule",{value:!0});var n=t("@turf/helpers");function a(t,e,r){if(null!==t)for(var n,i,o,s,l,c,u,h,f=0,p=0,d=t.type,g="FeatureCollection"===d,v="Feature"===d,m=g?t.features.length:1,y=0;y<m;y++){l=(h=!!(u=g?t.features[y].geometry:v?t.geometry:t)&&"GeometryCollection"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=h?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(f=!r||"Polygon"!==w&&"MultiPolygon"!==w?0:1,w){case null:break;case"Point":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case"LineString":case"MultiPoint":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,"MultiPoint"===w&&b++}"LineString"===w&&b++;break;case"Polygon":case"MultiLineString":for(n=0;n<c.length;n++){for(i=0;i<c[n].length-f;i++){if(!1===e(c[n][i],p,y,b,_))return!1;p++}"MultiLineString"===w&&b++,"Polygon"===w&&_++}"Polygon"===w&&b++;break;case"MultiPolygon":for(n=0;n<c.length;n++){for(_=0,i=0;i<c[n].length;i++){for(o=0;o<c[n][i].length-f;o++){if(!1===e(c[n][i][o],p,y,b,_))return!1;p++}_++}b++}break;case"GeometryCollection":for(n=0;n<s.geometries.length;n++)if(!1===a(s.geometries[n],e,r))return!1;break;default:throw new Error("Unknown Geometry Type")}}}}}function i(t,e){var r;switch(t.type){case"FeatureCollection":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case"Feature":e(t.properties,0)}}function o(t,e){if("Feature"===t.type)e(t,0);else if("FeatureCollection"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,a,i,o,s,l,c,u,h,f=0,p="FeatureCollection"===t.type,d="Feature"===t.type,g=p?t.features.length:1;for(r=0;r<g;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,h=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&"GeometryCollection"===s.type)?s.geometries.length:1,a=0;a<o;a++)if(null!==(i=l?s.geometries[a]:s))switch(i.type){case"Point":case"LineString":case"MultiPoint":case"Polygon":case"MultiLineString":case"MultiPolygon":if(!1===e(i,f,c,u,h))return!1;break;case"GeometryCollection":for(n=0;n<i.geometries.length;n++)if(!1===e(i.geometries[n],f,c,u,h))return!1;break;default:throw new Error("Unknown Geometry Type")}else if(!1===e(null,f,c,u,h))return!1;f++}}function l(t,e){s(t,function(t,r,a,i,o){var s,l=null===t?null:t.type;switch(l){case null:case"Point":case"LineString":case"Polygon":return!1!==e(n.feature(t,a,{bbox:i,id:o}),r,0)&&void 0}switch(l){case"MultiPoint":s="Point";break;case"MultiLineString":s="LineString";break;case"MultiPolygon":s="Polygon"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,a),r,c))return!1}})}function c(t,e){l(t,function(t,r,i){var o=0;if(t.geometry){var s=t.geometry.type;if("Point"!==s&&"MultiPoint"!==s){var l,c=0,u=0,h=0;return!1!==a(t,function(a,s,f,p,d){if(void 0===l||r>c||p>u||d>h)return l=a,c=r,u=p,h=d,void(o=0);var g=n.lineString([l,a],t.properties);if(!1===e(g,r,i,d,o))return!1;o++,l=a})&&void 0}}})}function u(t,e){if(!t)throw new Error("geojson is required");l(t,function(t,r,a){if(null!==t.geometry){var i=t.geometry.type,o=t.geometry.coordinates;switch(i){case"LineString":if(!1===e(t,r,a,0,0))return!1;break;case"Polygon":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,a,s))return!1}}})}r.coordEach=a,r.coordReduce=function(t,e,r,n){var i=r;return a(t,function(t,n,a,o,s){i=0===n&&void 0===r?t:e(i,t,n,a,o,s)},n),i},r.propEach=i,r.propReduce=function(t,e,r){var n=r;return i(t,function(t,a){n=0===a&&void 0===r?t:e(n,t,a)}),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,function(t,a){n=0===a&&void 0===r?t:e(n,t,a)}),n},r.coordAll=function(t){var e=[];return a(t,function(t){e.push(t)}),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,function(t,a,i,o,s){n=0===a&&void 0===r?t:e(n,t,a,i,o,s)}),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,function(t,a,i){n=0===a&&0===i&&void 0===r?t:e(n,t,a,i)}),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,a=!1;return c(t,function(t,i,o,s,l){n=!1===a&&void 0===r?t:e(n,t,i,o,s,l),a=!0}),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,function(t,a,i,o){n=0===a&&void 0===r?t:e(n,t,a,i,o)}),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error("options is invalid");var r,a=e.featureIndex||0,i=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case"FeatureCollection":a<0&&(a=t.features.length+a),l=l||t.features[a].properties,r=t.features[a].geometry;break;case"Feature":l=l||t.properties,r=t.geometry;break;case"Point":case"MultiPoint":return null;case"LineString":case"Polygon":case"MultiLineString":case"MultiPolygon":r=t;break;default:throw new Error("geojson is invalid")}if(null===r)return null;var c=r.coordinates;switch(r.type){case"Point":case"MultiPoint":return null;case"LineString":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case"Polygon":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case"MultiLineString":return i<0&&(i=c.length+i),s<0&&(s=c[i].length+s-1),n.lineString([c[i][s],c[i][s+1]],l,e);case"MultiPolygon":return i<0&&(i=c.length+i),o<0&&(o=c[i].length+o),s<0&&(s=c[i][o].length-s-1),n.lineString([c[i][o][s],c[i][o][s+1]],l,e)}throw new Error("geojson is invalid")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error("options is invalid");var r,a=e.featureIndex||0,i=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case"FeatureCollection":a<0&&(a=t.features.length+a),l=l||t.features[a].properties,r=t.features[a].geometry;break;case"Feature":l=l||t.properties,r=t.geometry;break;case"Point":case"MultiPoint":return null;case"LineString":case"Polygon":case"MultiLineString":case"MultiPolygon":r=t;break;default:throw new Error("geojson is invalid")}if(null===r)return null;var c=r.coordinates;switch(r.type){case"Point":return n.point(c,l,e);case"MultiPoint":return i<0&&(i=c.length+i),n.point(c[i],l,e);case"LineString":return s<0&&(s=c.length+s),n.point(c[s],l,e);case"Polygon":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case"MultiLineString":return i<0&&(i=c.length+i),s<0&&(s=c[i].length+s),n.point(c[i][s],l,e);case"MultiPolygon":return i<0&&(i=c.length+i),o<0&&(o=c[i].length+o),s<0&&(s=c[i][o].length-s),n.point(c[i][o][s],l,e)}throw new Error("geojson is invalid")}},{"@turf/helpers":60}],62:[function(t,e,r){"use strict";var n="undefined"==typeof WeakMap?t("weak-map"):WeakMap,a=t("gl-buffer"),i=t("gl-vao"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=a(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=i(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{"gl-buffer":244,"gl-vao":329,"weak-map":550}],63:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,a=0;return t.map(function(t){var i=(t=t.slice())[0],o=i.toUpperCase();if(i!=o)switch(t[0]=o,i){case"a":t[6]+=n,t[7]+=a;break;case"v":t[1]+=a;break;case"h":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=a}switch(o){case"Z":n=e,a=r;break;case"H":n=t[1];break;case"V":a=t[1];break;case"M":n=e=t[1],a=r=t[2];break;default:n=t[t.length-2],a=t[t.length-1]}return t})}},{}],64:[function(t,e,r){var n=t("pad-left");e.exports=function(t,e,r){e="number"==typeof e?e:1,r=r||": ";var a=t.split(/\r?\n/),i=String(a.length+e-1).length;return a.map(function(t,a){var o=a+e,s=String(o).length,l=n(o,i-s);return l+r+t}).join("\n")}},{"pad-left":458}],65:[function(t,e,r){"use strict";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],i=[0],o=1;o<e;++o)if(n.push(t[o]),a(n,r)){if(i.push(o),i.length===r+1)return i}else n.pop();return i};var n=t("robust-orientation");function a(t,e){for(var r=new Array(e+1),a=0;a<t.length;++a)r[a]=t[a];for(a=0;a<=t.length;++a){for(var i=t.length;i<=e;++i){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(i+1-a,s);r[i]=o}if(n.apply(void 0,r))return!0}return!1}},{"robust-orientation":508}],66:[function(t,e,r){"use strict";e.exports=function(t,e){return n(e).filter(function(r){for(var n=new Array(r.length),i=0;i<r.length;++i)n[i]=e[r[i]];return a(n)*t<1})};var n=t("delaunay-triangulate"),a=t("circumradius")},{circumradius:116,"delaunay-triangulate":167}],67:[function(t,e,r){e.exports=function(t,e){return a(n(t,e))};var n=t("alpha-complex"),a=t("simplicial-complex-boundary")},{"alpha-complex":66,"simplicial-complex-boundary":515}],68:[function(t,e,r){"use strict";e.exports=function(t,e){if(!t||null==t.length)throw Error("Argument should be an array");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var a=-1/0,i=1/0,o=n,s=t.length;o<s;o+=e)t[o]>a&&(a=t[o]),t[o]<i&&(i=t[o]);r[n]=i,r[e+n]=a}return r}},{}],69:[function(t,e,r){e.exports=function(t,e){var r="number"==typeof t,n="number"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var a=(e|=0)-(t|=0);if(a<0)throw new Error("array length must be positive");for(var i=new Array(a),o=0,s=t;o<a;o++,s++)i[o]=s;return i}},{}],70:[function(t,e,r){(function(r){"use strict";var n=t("object-assign");function a(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,a=0,i=Math.min(r,n);a<i;++a)if(t[a]!==e[a]){r=t[a],n=e[a];break}return r<n?-1:n<r?1:0}function i(t){return r.Buffer&&"function"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var o=t("util/"),s=Object.prototype.hasOwnProperty,l=Array.prototype.slice,c="foo"===function(){}.name;function u(t){return Object.prototype.toString.call(t)}function h(t){return!i(t)&&("function"==typeof r.ArrayBuffer&&("function"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var f=e.exports=y,p=/\s*function\s+([^\(\s]*)\s*/;function d(t){if(o.isFunction(t)){if(c)return t.name;var e=t.toString().match(p);return e&&e[1]}}function g(t,e){return"string"==typeof t?t.length<e?t:t.slice(0,e):t}function v(t){if(c||!o.isFunction(t))return o.inspect(t);var e=d(t);return"[Function"+(e?": "+e:"")+"]"}function m(t,e,r,n,a){throw new f.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:a})}function y(t,e){t||m(t,!0,e,"==",f.ok)}function x(t,e,r,n){if(t===e)return!0;if(i(t)&&i(e))return 0===a(t,e);if(o.isDate(t)&&o.isDate(e))return t.getTime()===e.getTime();if(o.isRegExp(t)&&o.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&"object"==typeof t||null!==e&&"object"==typeof e){if(h(t)&&h(e)&&u(t)===u(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===a(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(i(t)!==i(e))return!1;var s=(n=n||{actual:[],expected:[]}).actual.indexOf(t);return-1!==s&&s===n.expected.indexOf(e)||(n.actual.push(t),n.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(o.isPrimitive(t)||o.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var a=b(t),i=b(e);if(a&&!i||!a&&i)return!1;if(a)return t=l.call(t),e=l.call(e),x(t,e,r);var s,c,u=k(t),h=k(e);if(u.length!==h.length)return!1;for(u.sort(),h.sort(),c=u.length-1;c>=0;c--)if(u[c]!==h[c])return!1;for(c=u.length-1;c>=0;c--)if(s=u[c],!x(t[s],e[s],r,n))return!1;return!0}(t,e,r,n))}return r?t===e:t==e}function b(t){return"[object Arguments]"==Object.prototype.toString.call(t)}function _(t,e){if(!t||!e)return!1;if("[object RegExp]"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function w(t,e,r,n){var a;if("function"!=typeof e)throw new TypeError('"block" argument must be a function');"string"==typeof r&&(n=r,r=null),a=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?" ("+r.name+").":".")+(n?" "+n:"."),t&&!a&&m(a,r,"Missing expected exception"+n);var i="string"==typeof n,s=!t&&a&&!r;if((!t&&o.isError(a)&&i&&_(a,r)||s)&&m(a,r,"Got unwanted exception"+n),t&&a&&r&&!_(a,r)||!t&&a)throw a}f.AssertionError=function(t){var e;this.name="AssertionError",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=g(v((e=this).actual),128)+" "+e.operator+" "+g(v(e.expected),128),this.generatedMessage=!0);var r=t.stackStartFunction||m;if(Error.captureStackTrace)Error.captureStackTrace(this,r);else{var n=new Error;if(n.stack){var a=n.stack,i=d(r),o=a.indexOf("\n"+i);if(o>=0){var s=a.indexOf("\n",o+1);a=a.substring(s+1)}this.stack=a}}},o.inherits(f.AssertionError,Error),f.fail=m,f.ok=y,f.equal=function(t,e,r){t!=e&&m(t,e,r,"==",f.equal)},f.notEqual=function(t,e,r){t==e&&m(t,e,r,"!=",f.notEqual)},f.deepEqual=function(t,e,r){x(t,e,!1)||m(t,e,r,"deepEqual",f.deepEqual)},f.deepStrictEqual=function(t,e,r){x(t,e,!0)||m(t,e,r,"deepStrictEqual",f.deepStrictEqual)},f.notDeepEqual=function(t,e,r){x(t,e,!1)&&m(t,e,r,"notDeepEqual",f.notDeepEqual)},f.notDeepStrictEqual=function t(e,r,n){x(e,r,!0)&&m(e,r,n,"notDeepStrictEqual",t)},f.strictEqual=function(t,e,r){t!==e&&m(t,e,r,"===",f.strictEqual)},f.notStrictEqual=function(t,e,r){t===e&&m(t,e,r,"!==",f.notStrictEqual)},f.throws=function(t,e,r){w(!0,t,e,r)},f.doesNotThrow=function(t,e,r){w(!1,t,e,r)},f.ifError=function(t){if(t)throw t},f.strict=n(function t(e,r){e||m(e,!0,r,"==",t)},f,{equal:f.strictEqual,deepEqual:f.deepStrictEqual,notEqual:f.notStrictEqual,notDeepEqual:f.notDeepStrictEqual}),f.strict.strict=f.strict;var k=Object.keys||function(t){var e=[];for(var r in t)s.call(t,r)&&e.push(r);return e}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"object-assign":455,"util/":73}],71:[function(t,e,r){"function"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],72:[function(t,e,r){e.exports=function(t){return t&&"object"==typeof t&&"function"==typeof t.copy&&"function"==typeof t.fill&&"function"==typeof t.readUInt8}},{}],73:[function(t,e,r){(function(e,n){var a=/%[sdj%]/g;r.format=function(t){if(!m(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(" ")}r=1;for(var n=arguments,i=n.length,o=String(t).replace(a,function(t){if("%%"===t)return"%";if(r>=i)return t;switch(t){case"%s":return String(n[r++]);case"%d":return Number(n[r++]);case"%j":try{return JSON.stringify(n[r++])}catch(t){return"[Circular]"}default:return t}}),l=n[r];r<i;l=n[++r])g(l)||!b(l)?o+=" "+l:o+=" "+s(l);return o},r.deprecate=function(t,a){if(y(n.process))return function(){return r.deprecate(t,a).apply(this,arguments)};if(!0===e.noDeprecation)return t;var i=!1;return function(){if(!i){if(e.throwDeprecation)throw new Error(a);e.traceDeprecation?console.trace(a):console.error(a),i=!0}return t.apply(this,arguments)}};var i,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?"\x1b["+s.colors[r][0]+"m"+t+"\x1b["+s.colors[r][1]+"m":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&k(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var a=e.inspect(n,t);return m(a)||(a=u(t,a,n)),a}var i=function(t,e){if(y(e))return t.stylize("undefined","undefined");if(m(e)){var r="'"+JSON.stringify(e).replace(/^"|"$/g,"").replace(/'/g,"\\'").replace(/\\"/g,'"')+"'";return t.stylize(r,"string")}if(v(e))return t.stylize(""+e,"number");if(d(e))return t.stylize(""+e,"boolean");if(g(e))return t.stylize("null","null")}(t,e);if(i)return i;var o=Object.keys(e),s=function(t){var e={};return t.forEach(function(t,r){e[t]=!0}),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf("message")>=0||o.indexOf("description")>=0))return h(e);if(0===o.length){if(k(e)){var l=e.name?": "+e.name:"";return t.stylize("[Function"+l+"]","special")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),"regexp");if(_(e))return t.stylize(Date.prototype.toString.call(e),"date");if(w(e))return h(e)}var c,b="",T=!1,M=["{","}"];(p(e)&&(T=!0,M=["[","]"]),k(e))&&(b=" [Function"+(e.name?": "+e.name:"")+"]");return x(e)&&(b=" "+RegExp.prototype.toString.call(e)),_(e)&&(b=" "+Date.prototype.toUTCString.call(e)),w(e)&&(b=" "+h(e)),0!==o.length||T&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),"regexp"):t.stylize("[Object]","special"):(t.seen.push(e),c=T?function(t,e,r,n,a){for(var i=[],o=0,s=e.length;o<s;++o)S(e,String(o))?i.push(f(t,e,r,n,String(o),!0)):i.push("");return a.forEach(function(a){a.match(/^\d+$/)||i.push(f(t,e,r,n,a,!0))}),i}(t,e,n,s,o):o.map(function(r){return f(t,e,n,s,r,T)}),t.seen.pop(),function(t,e,r){if(t.reduce(function(t,e){return 0,e.indexOf("\n")>=0&&0,t+e.replace(/\u001b\[\d\d?m/g,"").length+1},0)>60)return r[0]+(""===e?"":e+"\n ")+" "+t.join(",\n  ")+" "+r[1];return r[0]+e+" "+t.join(", ")+" "+r[1]}(c,b,M)):M[0]+b+M[1]}function h(t){return"["+Error.prototype.toString.call(t)+"]"}function f(t,e,r,n,a,i){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,a)||{value:e[a]}).get?s=l.set?t.stylize("[Getter/Setter]","special"):t.stylize("[Getter]","special"):l.set&&(s=t.stylize("[Setter]","special")),S(n,a)||(o="["+a+"]"),s||(t.seen.indexOf(l.value)<0?(s=g(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf("\n")>-1&&(s=i?s.split("\n").map(function(t){return"  "+t}).join("\n").substr(2):"\n"+s.split("\n").map(function(t){return"   "+t}).join("\n")):s=t.stylize("[Circular]","special")),y(o)){if(i&&a.match(/^\d+$/))return s;(o=JSON.stringify(""+a)).match(/^"([a-zA-Z_][a-zA-Z_0-9]*)"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,"name")):(o=o.replace(/'/g,"\\'").replace(/\\"/g,'"').replace(/(^"|"$)/g,"'"),o=t.stylize(o,"string"))}return o+": "+s}function p(t){return Array.isArray(t)}function d(t){return"boolean"==typeof t}function g(t){return null===t}function v(t){return"number"==typeof t}function m(t){return"string"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&"[object RegExp]"===T(t)}function b(t){return"object"==typeof t&&null!==t}function _(t){return b(t)&&"[object Date]"===T(t)}function w(t){return b(t)&&("[object Error]"===T(t)||t instanceof Error)}function k(t){return"function"==typeof t}function T(t){return Object.prototype.toString.call(t)}function M(t){return t<10?"0"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(i)&&(i=e.env.NODE_DEBUG||""),t=t.toUpperCase(),!o[t])if(new RegExp("\\b"+t+"\\b","i").test(i)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error("%s %d: %s",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:"cyan",number:"yellow",boolean:"yellow",undefined:"grey",null:"bold",string:"green",date:"magenta",regexp:"red"},r.isArray=p,r.isBoolean=d,r.isNull=g,r.isNullOrUndefined=function(t){return null==t},r.isNumber=v,r.isString=m,r.isSymbol=function(t){return"symbol"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=k,r.isPrimitive=function(t){return null===t||"boolean"==typeof t||"number"==typeof t||"string"==typeof t||"symbol"==typeof t||"undefined"==typeof t},r.isBuffer=t("./support/isBuffer");var A=["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"];function S(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){var t,e;console.log("%s - %s",(t=new Date,e=[M(t.getHours()),M(t.getMinutes()),M(t.getSeconds())].join(":"),[t.getDate(),A[t.getMonth()],e].join(" ")),r.format.apply(r,arguments))},r.inherits=t("inherits"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this,t("_process"),"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./support/isBuffer":72,_process:483,inherits:71}],74:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],75:[function(t,e,r){"use strict";e.exports=function(t,e){for(var r=e.length,i=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];i[o]=s}i[r]=new Array(r+1);for(var o=0;o<=r;++o)i[r][o]=1;for(var c=new Array(r+1),o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(i,c),h=a(u[r+1]);0===h&&(h=1);for(var f=new Array(r+1),o=0;o<=r;++o)f[o]=a(u[o])/h;return f};var n=t("robust-linear-solve");function a(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{"robust-linear-solve":507}],76:[function(t,e,r){"use strict";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){var e,r,n=c(t),o=n[0],s=n[1],l=new i(function(t,e,r){return 3*(e+r)/4-r}(0,o,s)),u=0,h=s>0?o-4:o;for(r=0;r<h;r+=4)e=a[t.charCodeAt(r)]<<18|a[t.charCodeAt(r+1)]<<12|a[t.charCodeAt(r+2)]<<6|a[t.charCodeAt(r+3)],l[u++]=e>>16&255,l[u++]=e>>8&255,l[u++]=255&e;2===s&&(e=a[t.charCodeAt(r)]<<2|a[t.charCodeAt(r+1)]>>4,l[u++]=255&e);1===s&&(e=a[t.charCodeAt(r)]<<10|a[t.charCodeAt(r+1)]<<4|a[t.charCodeAt(r+2)]>>2,l[u++]=e>>8&255,l[u++]=255&e);return l},r.fromByteArray=function(t){for(var e,r=t.length,a=r%3,i=[],o=0,s=r-a;o<s;o+=16383)i.push(u(t,o,o+16383>s?s:o+16383));1===a?(e=t[r-1],i.push(n[e>>2]+n[e<<4&63]+"==")):2===a&&(e=(t[r-2]<<8)+t[r-1],i.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+"="));return i.join("")};for(var n=[],a=[],i="undefined"!=typeof Uint8Array?Uint8Array:Array,o="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",s=0,l=o.length;s<l;++s)n[s]=o[s],a[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error("Invalid string. Length must be a multiple of 4");var r=t.indexOf("=");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var a,i,o=[],s=e;s<r;s+=3)a=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(i=a)>>18&63]+n[i>>12&63]+n[i>>6&63]+n[63&i]);return o.join("")}a["-".charCodeAt(0)]=62,a["_".charCodeAt(0)]=63},{}],77:[function(t,e,r){"use strict";var n=t("./lib/rationalize");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{"./lib/rationalize":87}],78:[function(t,e,r){"use strict";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],79:[function(t,e,r){"use strict";var n=t("./lib/rationalize");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{"./lib/rationalize":87}],80:[function(t,e,r){"use strict";var n=t("./is-rat"),a=t("./lib/is-bn"),i=t("./lib/num-to-bn"),o=t("./lib/str-to-bn"),s=t("./lib/rationalize"),l=t("./div");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c=0;var u,h;if(a(e))u=e.clone();else if("string"==typeof e)u=o(e);else{if(0===e)return[i(0),i(1)];if(e===Math.floor(e))u=i(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),c-=256;u=i(e)}}if(n(r))u.mul(r[1]),h=r[0].clone();else if(a(r))h=r.clone();else if("string"==typeof r)h=o(r);else if(r)if(r===Math.floor(r))h=i(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),c+=256;h=i(r)}else h=i(1);c>0?u=u.ushln(c):c<0&&(h=h.ushln(-c));return s(u,h)}},{"./div":79,"./is-rat":81,"./lib/is-bn":85,"./lib/num-to-bn":86,"./lib/rationalize":87,"./lib/str-to-bn":88}],81:[function(t,e,r){"use strict";var n=t("./lib/is-bn");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{"./lib/is-bn":85}],82:[function(t,e,r){"use strict";var n=t("bn.js");e.exports=function(t){return t.cmp(new n(0))}},{"bn.js":96}],83:[function(t,e,r){"use strict";var n=t("./bn-sign");e.exports=function(t){var e=t.length,r=t.words,a=0;if(1===e)a=r[0];else if(2===e)a=r[0]+67108864*r[1];else for(var i=0;i<e;i++){var o=r[i];a+=o*Math.pow(67108864,i)}return n(t)*a}},{"./bn-sign":82}],84:[function(t,e,r){"use strict";var n=t("double-bits"),a=t("bit-twiddle").countTrailingZeros;e.exports=function(t){var e=a(n.lo(t));if(e<32)return e;var r=a(n.hi(t));if(r>20)return 52;return r+32}},{"bit-twiddle":94,"double-bits":169}],85:[function(t,e,r){"use strict";t("bn.js");e.exports=function(t){return t&&"object"==typeof t&&Boolean(t.words)}},{"bn.js":96}],86:[function(t,e,r){"use strict";var n=t("bn.js"),a=t("double-bits");e.exports=function(t){var e=a.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{"bn.js":96,"double-bits":169}],87:[function(t,e,r){"use strict";var n=t("./num-to-bn"),a=t("./bn-sign");e.exports=function(t,e){var r=a(t),i=a(e);if(0===r)return[n(0),n(1)];if(0===i)return[n(0),n(0)];i<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{"./bn-sign":82,"./num-to-bn":86}],88:[function(t,e,r){"use strict";var n=t("bn.js");e.exports=function(t){return new n(t)}},{"bn.js":96}],89:[function(t,e,r){"use strict";var n=t("./lib/rationalize");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{"./lib/rationalize":87}],90:[function(t,e,r){"use strict";var n=t("./lib/bn-sign");e.exports=function(t){return n(t[0])*n(t[1])}},{"./lib/bn-sign":82}],91:[function(t,e,r){"use strict";var n=t("./lib/rationalize");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{"./lib/rationalize":87}],92:[function(t,e,r){"use strict";var n=t("./lib/bn-to-num"),a=t("./lib/ctz");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var i=e.abs().divmod(r.abs()),o=i.div,s=n(o),l=i.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=a(s)+4,h=n(l.ushln(u).divRound(r));return c*(s+h*Math.pow(2,-u))}var f=r.bitLength()-l.bitLength()+53,h=n(l.ushln(f).divRound(r));return f<1023?c*h*Math.pow(2,-f):(h*=Math.pow(2,-1023),c*h*Math.pow(2,1023-f))}},{"./lib/bn-to-num":83,"./lib/ctz":84}],93:[function(t,e,r){"use strict";function n(t,e,r,n,a,i){var o=["function ",t,"(a,l,h,",n.join(","),"){",i?"":"var i=",r?"l-1":"h+1",";while(l<=h){var m=(l+h)>>>1,x=a",a?".get(m)":"[m]"];return i?e.indexOf("c")<0?o.push(";if(x===y){return m}else if(x<=y){"):o.push(";var p=c(x,y);if(p===0){return m}else if(p<=0){"):o.push(";if(",e,"){i=m;"),r?o.push("l=m+1}else{h=m-1}"):o.push("h=m-1}else{l=m+1}"),o.push("}"),i?o.push("return -1};"):o.push("return i};"),o.join("")}function a(t,e,r,a){return new Function([n("A","x"+t+"y",e,["y"],!1,a),n("B","x"+t+"y",e,["y"],!0,a),n("P","c(x,y)"+t+"0",e,["y","c"],!1,a),n("Q","c(x,y)"+t+"0",e,["y","c"],!0,a),"function dispatchBsearch",r,"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch",r].join(""))()}e.exports={ge:a(">=",!1,"GE"),gt:a(">",!1,"GT"),lt:a("<",!0,"LT"),le:a("<=",!0,"LE"),eq:a("-",!0,"EQ",!0)}},{}],94:[function(t,e,r){"use strict";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var a=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,a=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--a;t[e]=n<<a&255}}(a),r.reverse=function(t){return a[255&t]<<24|a[t>>>8&255]<<16|a[t>>>16&255]<<8|a[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],95:[function(t,e,r){"use strict";var n=t("clamp");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,h,f,p,d,g,v=null==e.cutoff?.25:e.cutoff,m=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error("For raw data width and height should be provided by options");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(h=(f=t).getContext("2d"),r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(f=t.canvas,h=t,r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,g=c.length;d<g;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error("Raw data can have only 1 value per pixel");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),k=Array(s+1),T=Array(s);for(d=0,g=r*o;d<g;d++){var M=l[d];x[d]=1===M?0:0===M?a:Math.pow(Math.max(0,.5-M),2),b[d]=1===M?a:0===M?0:Math.pow(Math.max(0,M-.5),2)}i(x,r,o,_,w,T,k),i(b,r,o,_,w,T,k);var A=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,g=r*o;d<g;d++)A[d]=n(1-((x[d]-b[d])/m+v),0,1);return A};var a=1e20;function i(t,e,r,n,a,i,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,a,i,s,r),c=0;c<r;c++)t[c*e+l]=a[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,a,i,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(a[l])}}function o(t,e,r,n,i){r[0]=0,n[0]=-a,n[1]=+a;for(var o=1,s=0;o<i;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+a}for(o=0,s=0;o<i;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:117}],96:[function(t,e,r){!function(e,r){"use strict";function n(t,e){if(!t)throw new Error(e||"Assertion failed")}function a(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function i(t,e,r){if(i.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&("le"!==e&&"be"!==e||(r=e,e=10),this._init(t||0,e||10,r||"be"))}var o;"object"==typeof e?e.exports=i:r.BN=i,i.BN=i,i.wordSize=26;try{o=t("buffer").Buffer}catch(t){}function s(t,e,r){for(var n=0,a=Math.min(t.length,r),i=e;i<a;i++){var o=t.charCodeAt(i)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var a=0,i=Math.min(t.length,r),o=e;o<i;o++){var s=t.charCodeAt(o)-48;a*=n,a+=s>=49?s-49+10:s>=17?s-17+10:s}return a}i.isBN=function(t){return t instanceof i||null!==t&&"object"==typeof t&&t.constructor.wordSize===i.wordSize&&Array.isArray(t.words)},i.max=function(t,e){return t.cmp(e)>0?t:e},i.min=function(t,e){return t.cmp(e)<0?t:e},i.prototype._init=function(t,e,r){if("number"==typeof t)return this._initNumber(t,e,r);if("object"==typeof t)return this._initArray(t,e,r);"hex"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var a=0;"-"===(t=t.toString().replace(/\s+/g,""))[0]&&a++,16===e?this._parseHex(t,a):this._parseBase(t,e,a),"-"===t[0]&&(this.negative=1),this.strip(),"le"===r&&this._initArray(this.toArray(),e,r)},i.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),"le"===r&&this._initArray(this.toArray(),e,r)},i.prototype._initArray=function(t,e,r){if(n("number"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var a=0;a<this.length;a++)this.words[a]=0;var i,o,s=0;if("be"===r)for(a=t.length-1,i=0;a>=0;a-=3)o=t[a]|t[a-1]<<8|t[a-2]<<16,this.words[i]|=o<<s&67108863,this.words[i+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,i++);else if("le"===r)for(a=0,i=0;a<t.length;a+=3)o=t[a]|t[a+1]<<8|t[a+2]<<16,this.words[i]|=o<<s&67108863,this.words[i+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,i++);return this.strip()},i.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,a,i=0;for(r=t.length-6,n=0;r>=e;r-=6)a=s(t,r,r+6),this.words[n]|=a<<i&67108863,this.words[n+1]|=a>>>26-i&4194303,(i+=24)>=26&&(i-=26,n++);r+6!==e&&(a=s(t,e,r+6),this.words[n]|=a<<i&67108863,this.words[n+1]|=a>>>26-i&4194303),this.strip()},i.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,a=1;a<=67108863;a*=e)n++;n--,a=a/e|0;for(var i=t.length-r,o=i%n,s=Math.min(i,i-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(a),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var h=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)h*=e;this.imuln(h),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},i.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},i.prototype.clone=function(){var t=new i(null);return this.copy(t),t},i.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},i.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},i.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},i.prototype.inspect=function(){return(this.red?"<BN-R: ":"<BN: ")+this.toString(16)+">"};var c=["","0","00","000","0000","00000","000000","0000000","00000000","000000000","0000000000","00000000000","000000000000","0000000000000","00000000000000","000000000000000","0000000000000000","00000000000000000","000000000000000000","0000000000000000000","00000000000000000000","000000000000000000000","0000000000000000000000","00000000000000000000000","000000000000000000000000","0000000000000000000000000"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],h=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function f(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var a=0|t.words[0],i=0|e.words[0],o=a*i,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,h=67108863&l,f=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=f;p++){var d=c-p|0;u+=(o=(a=0|t.words[d])*(i=0|e.words[p])+h)/67108864|0,h=67108863&o}r.words[c]=0|h,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}i.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||"hex"===t){r="";for(var a=0,i=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<a|i)).toString(16);r=0!==(i=s>>>24-a&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(a+=2)>=26&&(a-=26,o--)}for(0!==i&&(r=i.toString(16)+r);r.length%e!=0;)r="0"+r;return 0!==this.negative&&(r="-"+r),r}if(t===(0|t)&&t>=2&&t<=36){var f=u[t],p=h[t];r="";var d=this.clone();for(d.negative=0;!d.isZero();){var g=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?g+r:c[f-g.length]+g+r}for(this.isZero()&&(r="0"+r);r.length%e!=0;)r="0"+r;return 0!==this.negative&&(r="-"+r),r}n(!1,"Base should be between 2 and 36")},i.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,"Number can only safely store up to 53 bits"),0!==this.negative?-t:t},i.prototype.toJSON=function(){return this.toString(16)},i.prototype.toBuffer=function(t,e){return n("undefined"!=typeof o),this.toArrayLike(o,t,e)},i.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},i.prototype.toArrayLike=function(t,e,r){var a=this.byteLength(),i=r||Math.max(1,a);n(a<=i,"byte array longer than desired length"),n(i>0,"Requested array length <= 0"),this.strip();var o,s,l="le"===e,c=new t(i),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<i;s++)c[s]=0}else{for(s=0;s<i-a;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[i-s-1]=o}return c},Math.clz32?i.prototype._countBits=function(t){return 32-Math.clz32(t)}:i.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},i.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},i.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},i.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},i.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},i.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},i.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},i.prototype.isNeg=function(){return 0!==this.negative},i.prototype.neg=function(){return this.clone().ineg()},i.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},i.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},i.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},i.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},i.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},i.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},i.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},i.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},i.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},i.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},i.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},i.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},i.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},i.prototype.inotn=function(t){n("number"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var a=0;a<e;a++)this.words[a]=67108863&~this.words[a];return r>0&&(this.words[a]=~this.words[a]&67108863>>26-r),this.strip()},i.prototype.notn=function(t){return this.clone().inotn(t)},i.prototype.setn=function(t,e){n("number"==typeof t&&t>=0);var r=t/26|0,a=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<a:this.words[r]&~(1<<a),this.strip()},i.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var a=0,i=0;i<n.length;i++)e=(0|r.words[i])+(0|n.words[i])+a,this.words[i]=67108863&e,a=e>>>26;for(;0!==a&&i<r.length;i++)e=(0|r.words[i])+a,this.words[i]=67108863&e,a=e>>>26;if(this.length=r.length,0!==a)this.words[this.length]=a,this.length++;else if(r!==this)for(;i<r.length;i++)this.words[i]=r.words[i];return this},i.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},i.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,a=this.cmp(t);if(0===a)return this.negative=0,this.length=1,this.words[0]=0,this;a>0?(r=this,n=t):(r=t,n=this);for(var i=0,o=0;o<n.length;o++)i=(e=(0|r.words[o])-(0|n.words[o])+i)>>26,this.words[o]=67108863&e;for(;0!==i&&o<r.length;o++)i=(e=(0|r.words[o])+i)>>26,this.words[o]=67108863&e;if(0===i&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},i.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,a,i,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],h=8191&u,f=u>>>13,p=0|o[1],d=8191&p,g=p>>>13,v=0|o[2],m=8191&v,y=v>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],k=8191&w,T=w>>>13,M=0|o[5],A=8191&M,S=M>>>13,E=0|o[6],L=8191&E,C=E>>>13,P=0|o[7],O=8191&P,z=P>>>13,I=0|o[8],D=8191&I,R=I>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],V=8191&j,U=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Y=0|s[2],W=8191&Y,X=Y>>>13,Z=0|s[3],J=8191&Z,K=Z>>>13,Q=0|s[4],$=8191&Q,tt=Q>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,at=0|s[6],it=8191&at,ot=at>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ht=8191&ut,ft=ut>>>13,pt=0|s[9],dt=8191&pt,gt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var vt=(c+(n=Math.imul(h,V))|0)+((8191&(a=(a=Math.imul(h,U))+Math.imul(f,V)|0))<<13)|0;c=((i=Math.imul(f,U))+(a>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(d,V),a=(a=Math.imul(d,U))+Math.imul(g,V)|0,i=Math.imul(g,U);var mt=(c+(n=n+Math.imul(h,H)|0)|0)+((8191&(a=(a=a+Math.imul(h,G)|0)+Math.imul(f,H)|0))<<13)|0;c=((i=i+Math.imul(f,G)|0)+(a>>>13)|0)+(mt>>>26)|0,mt&=67108863,n=Math.imul(m,V),a=(a=Math.imul(m,U))+Math.imul(y,V)|0,i=Math.imul(y,U),n=n+Math.imul(d,H)|0,a=(a=a+Math.imul(d,G)|0)+Math.imul(g,H)|0,i=i+Math.imul(g,G)|0;var yt=(c+(n=n+Math.imul(h,W)|0)|0)+((8191&(a=(a=a+Math.imul(h,X)|0)+Math.imul(f,W)|0))<<13)|0;c=((i=i+Math.imul(f,X)|0)+(a>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,V),a=(a=Math.imul(b,U))+Math.imul(_,V)|0,i=Math.imul(_,U),n=n+Math.imul(m,H)|0,a=(a=a+Math.imul(m,G)|0)+Math.imul(y,H)|0,i=i+Math.imul(y,G)|0,n=n+Math.imul(d,W)|0,a=(a=a+Math.imul(d,X)|0)+Math.imul(g,W)|0,i=i+Math.imul(g,X)|0;var xt=(c+(n=n+Math.imul(h,J)|0)|0)+((8191&(a=(a=a+Math.imul(h,K)|0)+Math.imul(f,J)|0))<<13)|0;c=((i=i+Math.imul(f,K)|0)+(a>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(k,V),a=(a=Math.imul(k,U))+Math.imul(T,V)|0,i=Math.imul(T,U),n=n+Math.imul(b,H)|0,a=(a=a+Math.imul(b,G)|0)+Math.imul(_,H)|0,i=i+Math.imul(_,G)|0,n=n+Math.imul(m,W)|0,a=(a=a+Math.imul(m,X)|0)+Math.imul(y,W)|0,i=i+Math.imul(y,X)|0,n=n+Math.imul(d,J)|0,a=(a=a+Math.imul(d,K)|0)+Math.imul(g,J)|0,i=i+Math.imul(g,K)|0;var bt=(c+(n=n+Math.imul(h,$)|0)|0)+((8191&(a=(a=a+Math.imul(h,tt)|0)+Math.imul(f,$)|0))<<13)|0;c=((i=i+Math.imul(f,tt)|0)+(a>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(A,V),a=(a=Math.imul(A,U))+Math.imul(S,V)|0,i=Math.imul(S,U),n=n+Math.imul(k,H)|0,a=(a=a+Math.imul(k,G)|0)+Math.imul(T,H)|0,i=i+Math.imul(T,G)|0,n=n+Math.imul(b,W)|0,a=(a=a+Math.imul(b,X)|0)+Math.imul(_,W)|0,i=i+Math.imul(_,X)|0,n=n+Math.imul(m,J)|0,a=(a=a+Math.imul(m,K)|0)+Math.imul(y,J)|0,i=i+Math.imul(y,K)|0,n=n+Math.imul(d,$)|0,a=(a=a+Math.imul(d,tt)|0)+Math.imul(g,$)|0,i=i+Math.imul(g,tt)|0;var _t=(c+(n=n+Math.imul(h,rt)|0)|0)+((8191&(a=(a=a+Math.imul(h,nt)|0)+Math.imul(f,rt)|0))<<13)|0;c=((i=i+Math.imul(f,nt)|0)+(a>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(L,V),a=(a=Math.imul(L,U))+Math.imul(C,V)|0,i=Math.imul(C,U),n=n+Math.imul(A,H)|0,a=(a=a+Math.imul(A,G)|0)+Math.imul(S,H)|0,i=i+Math.imul(S,G)|0,n=n+Math.imul(k,W)|0,a=(a=a+Math.imul(k,X)|0)+Math.imul(T,W)|0,i=i+Math.imul(T,X)|0,n=n+Math.imul(b,J)|0,a=(a=a+Math.imul(b,K)|0)+Math.imul(_,J)|0,i=i+Math.imul(_,K)|0,n=n+Math.imul(m,$)|0,a=(a=a+Math.imul(m,tt)|0)+Math.imul(y,$)|0,i=i+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,a=(a=a+Math.imul(d,nt)|0)+Math.imul(g,rt)|0,i=i+Math.imul(g,nt)|0;var wt=(c+(n=n+Math.imul(h,it)|0)|0)+((8191&(a=(a=a+Math.imul(h,ot)|0)+Math.imul(f,it)|0))<<13)|0;c=((i=i+Math.imul(f,ot)|0)+(a>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(O,V),a=(a=Math.imul(O,U))+Math.imul(z,V)|0,i=Math.imul(z,U),n=n+Math.imul(L,H)|0,a=(a=a+Math.imul(L,G)|0)+Math.imul(C,H)|0,i=i+Math.imul(C,G)|0,n=n+Math.imul(A,W)|0,a=(a=a+Math.imul(A,X)|0)+Math.imul(S,W)|0,i=i+Math.imul(S,X)|0,n=n+Math.imul(k,J)|0,a=(a=a+Math.imul(k,K)|0)+Math.imul(T,J)|0,i=i+Math.imul(T,K)|0,n=n+Math.imul(b,$)|0,a=(a=a+Math.imul(b,tt)|0)+Math.imul(_,$)|0,i=i+Math.imul(_,tt)|0,n=n+Math.imul(m,rt)|0,a=(a=a+Math.imul(m,nt)|0)+Math.imul(y,rt)|0,i=i+Math.imul(y,nt)|0,n=n+Math.imul(d,it)|0,a=(a=a+Math.imul(d,ot)|0)+Math.imul(g,it)|0,i=i+Math.imul(g,ot)|0;var kt=(c+(n=n+Math.imul(h,lt)|0)|0)+((8191&(a=(a=a+Math.imul(h,ct)|0)+Math.imul(f,lt)|0))<<13)|0;c=((i=i+Math.imul(f,ct)|0)+(a>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(D,V),a=(a=Math.imul(D,U))+Math.imul(R,V)|0,i=Math.imul(R,U),n=n+Math.imul(O,H)|0,a=(a=a+Math.imul(O,G)|0)+Math.imul(z,H)|0,i=i+Math.imul(z,G)|0,n=n+Math.imul(L,W)|0,a=(a=a+Math.imul(L,X)|0)+Math.imul(C,W)|0,i=i+Math.imul(C,X)|0,n=n+Math.imul(A,J)|0,a=(a=a+Math.imul(A,K)|0)+Math.imul(S,J)|0,i=i+Math.imul(S,K)|0,n=n+Math.imul(k,$)|0,a=(a=a+Math.imul(k,tt)|0)+Math.imul(T,$)|0,i=i+Math.imul(T,tt)|0,n=n+Math.imul(b,rt)|0,a=(a=a+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,i=i+Math.imul(_,nt)|0,n=n+Math.imul(m,it)|0,a=(a=a+Math.imul(m,ot)|0)+Math.imul(y,it)|0,i=i+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,a=(a=a+Math.imul(d,ct)|0)+Math.imul(g,lt)|0,i=i+Math.imul(g,ct)|0;var Tt=(c+(n=n+Math.imul(h,ht)|0)|0)+((8191&(a=(a=a+Math.imul(h,ft)|0)+Math.imul(f,ht)|0))<<13)|0;c=((i=i+Math.imul(f,ft)|0)+(a>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(B,V),a=(a=Math.imul(B,U))+Math.imul(N,V)|0,i=Math.imul(N,U),n=n+Math.imul(D,H)|0,a=(a=a+Math.imul(D,G)|0)+Math.imul(R,H)|0,i=i+Math.imul(R,G)|0,n=n+Math.imul(O,W)|0,a=(a=a+Math.imul(O,X)|0)+Math.imul(z,W)|0,i=i+Math.imul(z,X)|0,n=n+Math.imul(L,J)|0,a=(a=a+Math.imul(L,K)|0)+Math.imul(C,J)|0,i=i+Math.imul(C,K)|0,n=n+Math.imul(A,$)|0,a=(a=a+Math.imul(A,tt)|0)+Math.imul(S,$)|0,i=i+Math.imul(S,tt)|0,n=n+Math.imul(k,rt)|0,a=(a=a+Math.imul(k,nt)|0)+Math.imul(T,rt)|0,i=i+Math.imul(T,nt)|0,n=n+Math.imul(b,it)|0,a=(a=a+Math.imul(b,ot)|0)+Math.imul(_,it)|0,i=i+Math.imul(_,ot)|0,n=n+Math.imul(m,lt)|0,a=(a=a+Math.imul(m,ct)|0)+Math.imul(y,lt)|0,i=i+Math.imul(y,ct)|0,n=n+Math.imul(d,ht)|0,a=(a=a+Math.imul(d,ft)|0)+Math.imul(g,ht)|0,i=i+Math.imul(g,ft)|0;var Mt=(c+(n=n+Math.imul(h,dt)|0)|0)+((8191&(a=(a=a+Math.imul(h,gt)|0)+Math.imul(f,dt)|0))<<13)|0;c=((i=i+Math.imul(f,gt)|0)+(a>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,H),a=(a=Math.imul(B,G))+Math.imul(N,H)|0,i=Math.imul(N,G),n=n+Math.imul(D,W)|0,a=(a=a+Math.imul(D,X)|0)+Math.imul(R,W)|0,i=i+Math.imul(R,X)|0,n=n+Math.imul(O,J)|0,a=(a=a+Math.imul(O,K)|0)+Math.imul(z,J)|0,i=i+Math.imul(z,K)|0,n=n+Math.imul(L,$)|0,a=(a=a+Math.imul(L,tt)|0)+Math.imul(C,$)|0,i=i+Math.imul(C,tt)|0,n=n+Math.imul(A,rt)|0,a=(a=a+Math.imul(A,nt)|0)+Math.imul(S,rt)|0,i=i+Math.imul(S,nt)|0,n=n+Math.imul(k,it)|0,a=(a=a+Math.imul(k,ot)|0)+Math.imul(T,it)|0,i=i+Math.imul(T,ot)|0,n=n+Math.imul(b,lt)|0,a=(a=a+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,i=i+Math.imul(_,ct)|0,n=n+Math.imul(m,ht)|0,a=(a=a+Math.imul(m,ft)|0)+Math.imul(y,ht)|0,i=i+Math.imul(y,ft)|0;var At=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(a=(a=a+Math.imul(d,gt)|0)+Math.imul(g,dt)|0))<<13)|0;c=((i=i+Math.imul(g,gt)|0)+(a>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,W),a=(a=Math.imul(B,X))+Math.imul(N,W)|0,i=Math.imul(N,X),n=n+Math.imul(D,J)|0,a=(a=a+Math.imul(D,K)|0)+Math.imul(R,J)|0,i=i+Math.imul(R,K)|0,n=n+Math.imul(O,$)|0,a=(a=a+Math.imul(O,tt)|0)+Math.imul(z,$)|0,i=i+Math.imul(z,tt)|0,n=n+Math.imul(L,rt)|0,a=(a=a+Math.imul(L,nt)|0)+Math.imul(C,rt)|0,i=i+Math.imul(C,nt)|0,n=n+Math.imul(A,it)|0,a=(a=a+Math.imul(A,ot)|0)+Math.imul(S,it)|0,i=i+Math.imul(S,ot)|0,n=n+Math.imul(k,lt)|0,a=(a=a+Math.imul(k,ct)|0)+Math.imul(T,lt)|0,i=i+Math.imul(T,ct)|0,n=n+Math.imul(b,ht)|0,a=(a=a+Math.imul(b,ft)|0)+Math.imul(_,ht)|0,i=i+Math.imul(_,ft)|0;var St=(c+(n=n+Math.imul(m,dt)|0)|0)+((8191&(a=(a=a+Math.imul(m,gt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((i=i+Math.imul(y,gt)|0)+(a>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,J),a=(a=Math.imul(B,K))+Math.imul(N,J)|0,i=Math.imul(N,K),n=n+Math.imul(D,$)|0,a=(a=a+Math.imul(D,tt)|0)+Math.imul(R,$)|0,i=i+Math.imul(R,tt)|0,n=n+Math.imul(O,rt)|0,a=(a=a+Math.imul(O,nt)|0)+Math.imul(z,rt)|0,i=i+Math.imul(z,nt)|0,n=n+Math.imul(L,it)|0,a=(a=a+Math.imul(L,ot)|0)+Math.imul(C,it)|0,i=i+Math.imul(C,ot)|0,n=n+Math.imul(A,lt)|0,a=(a=a+Math.imul(A,ct)|0)+Math.imul(S,lt)|0,i=i+Math.imul(S,ct)|0,n=n+Math.imul(k,ht)|0,a=(a=a+Math.imul(k,ft)|0)+Math.imul(T,ht)|0,i=i+Math.imul(T,ft)|0;var Et=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(a=(a=a+Math.imul(b,gt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((i=i+Math.imul(_,gt)|0)+(a>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,$),a=(a=Math.imul(B,tt))+Math.imul(N,$)|0,i=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,a=(a=a+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,i=i+Math.imul(R,nt)|0,n=n+Math.imul(O,it)|0,a=(a=a+Math.imul(O,ot)|0)+Math.imul(z,it)|0,i=i+Math.imul(z,ot)|0,n=n+Math.imul(L,lt)|0,a=(a=a+Math.imul(L,ct)|0)+Math.imul(C,lt)|0,i=i+Math.imul(C,ct)|0,n=n+Math.imul(A,ht)|0,a=(a=a+Math.imul(A,ft)|0)+Math.imul(S,ht)|0,i=i+Math.imul(S,ft)|0;var Lt=(c+(n=n+Math.imul(k,dt)|0)|0)+((8191&(a=(a=a+Math.imul(k,gt)|0)+Math.imul(T,dt)|0))<<13)|0;c=((i=i+Math.imul(T,gt)|0)+(a>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,rt),a=(a=Math.imul(B,nt))+Math.imul(N,rt)|0,i=Math.imul(N,nt),n=n+Math.imul(D,it)|0,a=(a=a+Math.imul(D,ot)|0)+Math.imul(R,it)|0,i=i+Math.imul(R,ot)|0,n=n+Math.imul(O,lt)|0,a=(a=a+Math.imul(O,ct)|0)+Math.imul(z,lt)|0,i=i+Math.imul(z,ct)|0,n=n+Math.imul(L,ht)|0,a=(a=a+Math.imul(L,ft)|0)+Math.imul(C,ht)|0,i=i+Math.imul(C,ft)|0;var Ct=(c+(n=n+Math.imul(A,dt)|0)|0)+((8191&(a=(a=a+Math.imul(A,gt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((i=i+Math.imul(S,gt)|0)+(a>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,it),a=(a=Math.imul(B,ot))+Math.imul(N,it)|0,i=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,a=(a=a+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,i=i+Math.imul(R,ct)|0,n=n+Math.imul(O,ht)|0,a=(a=a+Math.imul(O,ft)|0)+Math.imul(z,ht)|0,i=i+Math.imul(z,ft)|0;var Pt=(c+(n=n+Math.imul(L,dt)|0)|0)+((8191&(a=(a=a+Math.imul(L,gt)|0)+Math.imul(C,dt)|0))<<13)|0;c=((i=i+Math.imul(C,gt)|0)+(a>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,lt),a=(a=Math.imul(B,ct))+Math.imul(N,lt)|0,i=Math.imul(N,ct),n=n+Math.imul(D,ht)|0,a=(a=a+Math.imul(D,ft)|0)+Math.imul(R,ht)|0,i=i+Math.imul(R,ft)|0;var Ot=(c+(n=n+Math.imul(O,dt)|0)|0)+((8191&(a=(a=a+Math.imul(O,gt)|0)+Math.imul(z,dt)|0))<<13)|0;c=((i=i+Math.imul(z,gt)|0)+(a>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,n=Math.imul(B,ht),a=(a=Math.imul(B,ft))+Math.imul(N,ht)|0,i=Math.imul(N,ft);var zt=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(a=(a=a+Math.imul(D,gt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((i=i+Math.imul(R,gt)|0)+(a>>>13)|0)+(zt>>>26)|0,zt&=67108863;var It=(c+(n=Math.imul(B,dt))|0)+((8191&(a=(a=Math.imul(B,gt))+Math.imul(N,dt)|0))<<13)|0;return c=((i=Math.imul(N,gt))+(a>>>13)|0)+(It>>>26)|0,It&=67108863,l[0]=vt,l[1]=mt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=kt,l[8]=Tt,l[9]=Mt,l[10]=At,l[11]=St,l[12]=Et,l[13]=Lt,l[14]=Ct,l[15]=Pt,l[16]=Ot,l[17]=zt,l[18]=It,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(p=f),i.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?f(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,a=0,i=0;i<r.length-1;i++){var o=a;a=0;for(var s=67108863&n,l=Math.min(i,e.length-1),c=Math.max(0,i-t.length+1);c<=l;c++){var u=i-c,h=(0|t.words[u])*(0|e.words[c]),f=67108863&h;s=67108863&(f=f+s|0),a+=(o=(o=o+(h/67108864|0)|0)+(f>>>26)|0)>>>26,o&=67108863}r.words[i]=s,n=o,o=a}return 0!==n?r.words[i]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=i.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,a=0;a<e;a++)n|=(1&t)<<e-a-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,a,i){for(var o=0;o<i;o++)n[o]=e[t[o]],a[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,a,i){this.permute(i,t,e,r,n,a);for(var o=1;o<a;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<a;u+=s)for(var h=l,f=c,p=0;p<o;p++){var d=r[u+p],g=n[u+p],v=r[u+p+o],m=n[u+p+o],y=h*v-f*m;m=h*m+f*v,v=y,r[u+p]=d+v,n[u+p]=g+m,r[u+p+o]=d-v,n[u+p+o]=g-m,p!==s&&(y=l*h-c*f,f=l*f+c*h,h=y)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,a=0;for(r=r/2|0;r;r>>>=1)a++;return 1<<a+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var a=t[n];t[n]=t[r-n-1],t[r-n-1]=a,a=e[n],e[n]=-e[r-n-1],e[r-n-1]=-a}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var a=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&a,r=a<67108864?0:a/67108864|0}return t},g.prototype.convert13b=function(t,e,r,a){for(var i=0,o=0;o<e;o++)i+=0|t[o],r[2*o]=8191&i,i>>>=13,r[2*o+1]=8191&i,i>>>=13;for(o=2*e;o<a;++o)r[o]=0;n(0===i),n(0==(-8192&i))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),a=this.makeRBT(n),i=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),h=new Array(n),f=r.words;f.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,i,s,l,n,a),this.transform(c,i,u,h,n,a);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*h[p];l[p]=s[p]*h[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,f,i,n,a),this.conjugate(f,i,n),this.normalize13b(f,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},i.prototype.mul=function(t){var e=new i(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},i.prototype.mulf=function(t){var e=new i(null);return e.words=new Array(this.length+t.length),d(this,t,e)},i.prototype.imul=function(t){return this.clone().mulTo(t,this)},i.prototype.imuln=function(t){n("number"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var a=(0|this.words[r])*t,i=(67108863&a)+(67108863&e);e>>=26,e+=a/67108864|0,e+=i>>>26,this.words[r]=67108863&i}return 0!==e&&(this.words[r]=e,this.length++),this},i.prototype.muln=function(t){return this.clone().imuln(t)},i.prototype.sqr=function(){return this.mul(this)},i.prototype.isqr=function(){return this.imul(this.clone())},i.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,a=r%26;e[r]=(t.words[n]&1<<a)>>>a}return e}(t);if(0===e.length)return new i(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var a=r.sqr();n<e.length;n++,a=a.sqr())0!==e[n]&&(r=r.mul(a));return r},i.prototype.iushln=function(t){n("number"==typeof t&&t>=0);var e,r=t%26,a=(t-r)/26,i=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&i,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==a){for(e=this.length-1;e>=0;e--)this.words[e+a]=this.words[e];for(e=0;e<a;e++)this.words[e]=0;this.length+=a}return this.strip()},i.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},i.prototype.iushrn=function(t,e,r){var a;n("number"==typeof t&&t>=0),a=e?(e-e%26)/26:0;var i=t%26,o=Math.min((t-i)/26,this.length),s=67108863^67108863>>>i<<i,l=r;if(a-=o,a=Math.max(0,a),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=a);c--){var h=0|this.words[c];this.words[c]=u<<26-i|h>>>i,u=h&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},i.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},i.prototype.shln=function(t){return this.clone().ishln(t)},i.prototype.ushln=function(t){return this.clone().iushln(t)},i.prototype.shrn=function(t){return this.clone().ishrn(t)},i.prototype.ushrn=function(t){return this.clone().iushrn(t)},i.prototype.testn=function(t){n("number"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,a=1<<e;return!(this.length<=r)&&!!(this.words[r]&a)},i.prototype.imaskn=function(t){n("number"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,"imaskn works only with positive numbers"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var a=67108863^67108863>>>e<<e;this.words[this.length-1]&=a}return this.strip()},i.prototype.maskn=function(t){return this.clone().imaskn(t)},i.prototype.iaddn=function(t){return n("number"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},i.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},i.prototype.isubn=function(t){if(n("number"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},i.prototype.addn=function(t){return this.clone().iaddn(t)},i.prototype.subn=function(t){return this.clone().isubn(t)},i.prototype.iabs=function(){return this.negative=0,this},i.prototype.abs=function(){return this.clone().iabs()},i.prototype._ishlnsubmul=function(t,e,r){var a,i,o=t.length+r;this._expand(o);var s=0;for(a=0;a<t.length;a++){i=(0|this.words[a+r])+s;var l=(0|t.words[a])*e;s=((i-=67108863&l)>>26)-(l/67108864|0),this.words[a+r]=67108863&i}for(;a<this.length-r;a++)s=(i=(0|this.words[a+r])+s)>>26,this.words[a+r]=67108863&i;if(0===s)return this.strip();for(n(-1===s),s=0,a=0;a<this.length;a++)s=(i=-(0|this.words[a])+s)>>26,this.words[a]=67108863&i;return this.negative=1,this.strip()},i.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),a=t,o=0|a.words[a.length-1];0!==(r=26-this._countBits(o))&&(a=a.ushln(r),n.iushln(r),o=0|a.words[a.length-1]);var s,l=n.length-a.length;if("mod"!==e){(s=new i(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(a,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var h=l-1;h>=0;h--){var f=67108864*(0|n.words[a.length+h])+(0|n.words[a.length+h-1]);for(f=Math.min(f/o|0,67108863),n._ishlnsubmul(a,f,h);0!==n.negative;)f--,n.negative=0,n._ishlnsubmul(a,1,h),n.isZero()||(n.negative^=1);s&&(s.words[h]=f)}return s&&s.strip(),n.strip(),"div"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},i.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new i(0),mod:new i(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),"mod"!==e&&(a=s.div.neg()),"div"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:a,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),"mod"!==e&&(a=s.div.neg()),{div:a,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),"div"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new i(0),mod:this}:1===t.length?"div"===e?{div:this.divn(t.words[0]),mod:null}:"mod"===e?{div:null,mod:new i(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new i(this.modn(t.words[0]))}:this._wordDiv(t,e);var a,o,s},i.prototype.div=function(t){return this.divmod(t,"div",!1).div},i.prototype.mod=function(t){return this.divmod(t,"mod",!1).mod},i.prototype.umod=function(t){return this.divmod(t,"mod",!0).mod},i.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),a=t.andln(1),i=r.cmp(n);return i<0||1===a&&0===i?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},i.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,a=this.length-1;a>=0;a--)r=(e*r+(0|this.words[a]))%t;return r},i.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var a=(0|this.words[r])+67108864*e;this.words[r]=a/t|0,e=a%t}return this.strip()},i.prototype.divn=function(t){return this.clone().idivn(t)},i.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var a=new i(1),o=new i(0),s=new i(0),l=new i(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),h=e.clone();!e.isZero();){for(var f=0,p=1;0==(e.words[0]&p)&&f<26;++f,p<<=1);if(f>0)for(e.iushrn(f);f-- >0;)(a.isOdd()||o.isOdd())&&(a.iadd(u),o.isub(h)),a.iushrn(1),o.iushrn(1);for(var d=0,g=1;0==(r.words[0]&g)&&d<26;++d,g<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(h)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),a.isub(s),o.isub(l)):(r.isub(e),s.isub(a),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},i.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var a,o=new i(1),s=new i(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var h=0,f=1;0==(r.words[0]&f)&&h<26;++h,f<<=1);if(h>0)for(r.iushrn(h);h-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(a=0===e.cmpn(1)?o:s).cmpn(0)<0&&a.iadd(t),a},i.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var a=e.cmp(r);if(a<0){var i=e;e=r,r=i}else if(0===a||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},i.prototype.invm=function(t){return this.egcd(t).a.umod(t)},i.prototype.isEven=function(){return 0==(1&this.words[0])},i.prototype.isOdd=function(){return 1==(1&this.words[0])},i.prototype.andln=function(t){return this.words[0]&t},i.prototype.bincn=function(t){n("number"==typeof t);var e=t%26,r=(t-e)/26,a=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=a,this;for(var i=a,o=r;0!==i&&o<this.length;o++){var s=0|this.words[o];i=(s+=i)>>>26,s&=67108863,this.words[o]=s}return 0!==i&&(this.words[o]=i,this.length++),this},i.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},i.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,"Number is too big");var a=0|this.words[0];e=a===t?0:a<t?-1:1}return 0!==this.negative?0|-e:e},i.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},i.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],a=0|t.words[r];if(n!==a){n<a?e=-1:n>a&&(e=1);break}}return e},i.prototype.gtn=function(t){return 1===this.cmpn(t)},i.prototype.gt=function(t){return 1===this.cmp(t)},i.prototype.gten=function(t){return this.cmpn(t)>=0},i.prototype.gte=function(t){return this.cmp(t)>=0},i.prototype.ltn=function(t){return-1===this.cmpn(t)},i.prototype.lt=function(t){return-1===this.cmp(t)},i.prototype.lten=function(t){return this.cmpn(t)<=0},i.prototype.lte=function(t){return this.cmp(t)<=0},i.prototype.eqn=function(t){return 0===this.cmpn(t)},i.prototype.eq=function(t){return 0===this.cmp(t)},i.red=function(t){return new w(t)},i.prototype.toRed=function(t){return n(!this.red,"Already a number in reduction context"),n(0===this.negative,"red works only with positives"),t.convertTo(this)._forceRed(t)},i.prototype.fromRed=function(){return n(this.red,"fromRed works only with numbers in reduction context"),this.red.convertFrom(this)},i.prototype._forceRed=function(t){return this.red=t,this},i.prototype.forceRed=function(t){return n(!this.red,"Already a number in reduction context"),this._forceRed(t)},i.prototype.redAdd=function(t){return n(this.red,"redAdd works only with red numbers"),this.red.add(this,t)},i.prototype.redIAdd=function(t){return n(this.red,"redIAdd works only with red numbers"),this.red.iadd(this,t)},i.prototype.redSub=function(t){return n(this.red,"redSub works only with red numbers"),this.red.sub(this,t)},i.prototype.redISub=function(t){return n(this.red,"redISub works only with red numbers"),this.red.isub(this,t)},i.prototype.redShl=function(t){return n(this.red,"redShl works only with red numbers"),this.red.shl(this,t)},i.prototype.redMul=function(t){return n(this.red,"redMul works only with red numbers"),this.red._verify2(this,t),this.red.mul(this,t)},i.prototype.redIMul=function(t){return n(this.red,"redMul works only with red numbers"),this.red._verify2(this,t),this.red.imul(this,t)},i.prototype.redSqr=function(){return n(this.red,"redSqr works only with red numbers"),this.red._verify1(this),this.red.sqr(this)},i.prototype.redISqr=function(){return n(this.red,"redISqr works only with red numbers"),this.red._verify1(this),this.red.isqr(this)},i.prototype.redSqrt=function(){return n(this.red,"redSqrt works only with red numbers"),this.red._verify1(this),this.red.sqrt(this)},i.prototype.redInvm=function(){return n(this.red,"redInvm works only with red numbers"),this.red._verify1(this),this.red.invm(this)},i.prototype.redNeg=function(){return n(this.red,"redNeg works only with red numbers"),this.red._verify1(this),this.red.neg(this)},i.prototype.redPow=function(t){return n(this.red&&!t.red,"redPow(normalNum)"),this.red._verify1(this),this.red.pow(this,t)};var v={k256:null,p224:null,p192:null,p25519:null};function m(t,e){this.name=t,this.p=new i(e,16),this.n=this.p.bitLength(),this.k=new i(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){m.call(this,"k256","ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f")}function x(){m.call(this,"p224","ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001")}function b(){m.call(this,"p192","ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff")}function _(){m.call(this,"25519","7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed")}function w(t){if("string"==typeof t){var e=i._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),"modulus must be greater than 1"),this.m=t,this.prime=null}function k(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new i(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}m.prototype._tmp=function(){var t=new i(null);return t.words=new Array(Math.ceil(this.n/13)),t},m.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},m.prototype.split=function(t,e){t.iushrn(this.n,0,e)},m.prototype.imulK=function(t){return t.imul(this.k)},a(y,m),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var a=t.words[9];for(e.words[e.length++]=4194303&a,n=10;n<t.length;n++){var i=0|t.words[n];t.words[n-10]=(4194303&i)<<4|a>>>22,a=i}a>>>=22,t.words[n-10]=a,0===a&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},a(x,m),a(b,m),a(_,m),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,a=67108863&n;n>>>=26,t.words[r]=a,e=n}return 0!==e&&(t.words[t.length++]=e),t},i._prime=function(t){if(v[t])return v[t];var e;if("k256"===t)e=new y;else if("p224"===t)e=new x;else if("p192"===t)e=new b;else{if("p25519"!==t)throw new Error("Unknown prime "+t);e=new _}return v[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,"red works only with positives"),n(t.red,"red works only with red numbers")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),"red works only with positives"),n(t.red&&t.red===e.red,"red works only with red numbers")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new i(1)).iushrn(2);return this.pow(t,r)}for(var a=this.m.subn(1),o=0;!a.isZero()&&0===a.andln(1);)o++,a.iushrn(1);n(!a.isZero());var s=new i(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new i(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var h=this.pow(u,a),f=this.pow(t,a.addn(1).iushrn(1)),p=this.pow(t,a),d=o;0!==p.cmp(s);){for(var g=p,v=0;0!==g.cmp(s);v++)g=g.redSqr();n(v<d);var m=this.pow(h,new i(1).iushln(d-v-1));f=f.redMul(m),h=m.redSqr(),p=p.redMul(h),d=v}return f},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new i(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new i(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var a=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var h=c>>u&1;a!==r[0]&&(a=this.sqr(a)),0!==h||0!==o?(o<<=1,o|=h,(4===++s||0===n&&0===u)&&(a=this.mul(a,r[o]),s=0,o=0)):s=0}l=26}return a},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},i.mont=function(t){return new k(t)},a(k,w),k.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},k.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},k.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),a=r.isub(n).iushrn(this.shift),i=a;return a.cmp(this.m)>=0?i=a.isub(this.m):a.cmpn(0)<0&&(i=a.iadd(this.m)),i._forceRed(this)},k.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new i(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),a=r.isub(n).iushrn(this.shift),o=a;return a.cmp(this.m)>=0?o=a.isub(this.m):a.cmpn(0)<0&&(o=a.iadd(this.m)),o._forceRed(this)},k.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}("undefined"==typeof e||e,this)},{buffer:105}],97:[function(t,e,r){"use strict";e.exports=function(t){var e,r,n,a=t.length,i=0;for(e=0;e<a;++e)i+=t[e].length;var o=new Array(i),s=0;for(e=0;e<a;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),h=0;for(n=0;n<c;++n)n!==r&&(u[h++]=l[n]);if(1&r){var f=u[1];u[1]=u[0],u[0]=f}}}return o}},{}],98:[function(t,e,r){"use strict";e.exports=function(t,e,r){switch(arguments.length){case 1:return n=[],c(a=t,a,u,!0),n;case 2:return"function"==typeof e?c(t,t,e,!0):function(t,e){return n=[],c(t,e,u,!1),n}(t,e);case 3:return c(t,e,r,!1);default:throw new Error("box-intersect: Invalid arguments")}var a};var n,a=t("typedarray-pool"),i=t("./lib/sweep"),o=t("./lib/intersect");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var a=0,i=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[a++]=c[u];n[i++]=o}}return i}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var h,f=a.mallocDouble(2*u*s),p=a.mallocInt32(s);if((s=l(t,u,f,p))>0){if(1===u&&n)i.init(s),h=i.sweepComplete(u,r,0,s,f,p,0,s,f,p);else{var d=a.mallocDouble(2*u*c),g=a.mallocInt32(c);(c=l(e,u,d,g))>0&&(i.init(s+c),h=1===u?i.sweepBipartite(u,r,0,s,f,p,0,c,d,g):o(u,r,n,s,f,p,c,d,g),a.free(d),a.free(g))}a.free(f),a.free(p)}return h}}}function u(t,e){n.push([t,e])}},{"./lib/intersect":100,"./lib/sweep":104,"typedarray-pool":543}],99:[function(t,e,r){"use strict";var n="d",a="ax",i="vv",o="fp",s="es",l="rs",c="re",u="rb",h="ri",f="rp",p="bs",d="be",g="bb",v="bi",m="bp",y="rv",x="Q",b=[n,a,i,l,c,u,h,p,d,g,v];function _(t){var e="bruteForce"+(t?"Full":"Partial"),r=[],_=b.slice();t||_.splice(3,0,o);var w=["function "+e+"("+_.join()+"){"];function k(e,o){var _=function(t,e,r){var o="bruteForce"+(t?"Red":"Blue")+(e?"Flip":"")+(r?"Full":""),_=["function ",o,"(",b.join(),"){","var ",s,"=2*",n,";"],w="for(var i="+l+","+f+"="+s+"*"+l+";i<"+c+";++i,"+f+"+="+s+"){var x0="+u+"["+a+"+"+f+"],x1="+u+"["+a+"+"+f+"+"+n+"],xi="+h+"[i];",k="for(var j="+p+","+m+"="+s+"*"+p+";j<"+d+";++j,"+m+"+="+s+"){var y0="+g+"["+a+"+"+m+"],"+(r?"y1="+g+"["+a+"+"+m+"+"+n+"],":"")+"yi="+v+"[j];";return t?_.push(w,x,":",k):_.push(k,x,":",w),r?_.push("if(y1<x0||x1<y0)continue;"):e?_.push("if(y0<=x0||x1<y0)continue;"):_.push("if(y0<x0||x1<y0)continue;"),_.push("for(var k="+a+"+1;k<"+n+";++k){var r0="+u+"[k+"+f+"],r1="+u+"[k+"+n+"+"+f+"],b0="+g+"[k+"+m+"],b1="+g+"[k+"+n+"+"+m+"];if(r1<b0||b1<r0)continue "+x+";}var "+y+"="+i+"("),e?_.push("yi,xi"):_.push("xi,yi"),_.push(");if("+y+"!==void 0)return "+y+";}}}"),{name:o,code:_.join("")}}(e,o,t);r.push(_.code),w.push("return "+_.name+"("+b.join()+");")}w.push("if("+c+"-"+l+">"+d+"-"+p+"){"),t?(k(!0,!1),w.push("}else{"),k(!1,!1)):(w.push("if("+o+"){"),k(!0,!0),w.push("}else{"),k(!0,!1),w.push("}}else{if("+o+"){"),k(!1,!0),w.push("}else{"),k(!1,!1),w.push("}")),w.push("}}return "+e);var T=r.join("")+w.join("");return new Function(T)()}r.partial=_(!1),r.full=_(!0)},{}],100:[function(t,e,r){"use strict";e.exports=function(t,e,r,i,u,S,E,L,C){!function(t,e){var r=8*a.log2(e+1)*(t+1)|0,i=a.nextPow2(b*r);w.length<i&&(n.free(w),w=n.mallocInt32(i));var o=a.nextPow2(_*r);k<o&&(n.free(k),k=n.mallocDouble(o))}(t,i+E);var P,O=0,z=2*t;T(O++,0,0,i,0,E,r?16:0,-1/0,1/0),r||T(O++,0,0,E,0,i,1,-1/0,1/0);for(;O>0;){var I=(O-=1)*b,D=w[I],R=w[I+1],F=w[I+2],B=w[I+3],N=w[I+4],j=w[I+5],V=O*_,U=k[V],q=k[V+1],H=1&j,G=!!(16&j),Y=u,W=S,X=L,Z=C;if(H&&(Y=L,W=C,X=u,Z=S),!(2&j&&(F=v(t,D,R,F,Y,W,q),R>=F)||4&j&&(R=m(t,D,R,F,Y,W,U))>=F)){var J=F-R,K=N-B;if(G){if(t*J*(J+K)<p){if(void 0!==(P=l.scanComplete(t,D,e,R,F,Y,W,B,N,X,Z)))return P;continue}}else{if(t*Math.min(J,K)<h){if(void 0!==(P=o(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}if(t*J*K<f){if(void 0!==(P=l.scanBipartite(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}}var Q=d(t,D,R,F,Y,W,U,q);if(R<Q)if(t*(Q-R)<h){if(void 0!==(P=s(t,D+1,e,R,Q,Y,W,B,N,X,Z)))return P}else if(D===t-2){if(void 0!==(P=H?l.sweepBipartite(t,e,B,N,X,Z,R,Q,Y,W):l.sweepBipartite(t,e,R,Q,Y,W,B,N,X,Z)))return P}else T(O++,D+1,R,Q,B,N,H,-1/0,1/0),T(O++,D+1,B,N,R,Q,1^H,-1/0,1/0);if(Q<F){var $=c(t,D,B,N,X,Z),tt=X[z*$+D],et=g(t,D,$,N,X,Z,tt);if(et<N&&T(O++,D,Q,F,et,N,(4|H)+(G?16:0),tt,q),B<$&&T(O++,D,Q,F,B,$,(2|H)+(G?16:0),U,tt),$+1===et){if(void 0!==(P=G?A(t,D,e,Q,F,Y,W,$,X,Z[$]):M(t,D,e,H,Q,F,Y,W,$,X,Z[$])))return P}else if($<et){var rt;if(G){if(rt=y(t,D,Q,F,Y,W,tt),Q<rt){var nt=g(t,D,Q,rt,Y,W,tt);if(D===t-2){if(Q<nt&&void 0!==(P=l.sweepComplete(t,e,Q,nt,Y,W,$,et,X,Z)))return P;if(nt<rt&&void 0!==(P=l.sweepBipartite(t,e,nt,rt,Y,W,$,et,X,Z)))return P}else Q<nt&&T(O++,D+1,Q,nt,$,et,16,-1/0,1/0),nt<rt&&(T(O++,D+1,nt,rt,$,et,0,-1/0,1/0),T(O++,D+1,$,et,nt,rt,1,-1/0,1/0))}}else rt=H?x(t,D,Q,F,Y,W,tt):y(t,D,Q,F,Y,W,tt),Q<rt&&(D===t-2?P=H?l.sweepBipartite(t,e,$,et,X,Z,Q,rt,Y,W):l.sweepBipartite(t,e,Q,rt,Y,W,$,et,X,Z):(T(O++,D+1,Q,rt,$,et,H,-1/0,1/0),T(O++,D+1,$,et,Q,rt,1^H,-1/0,1/0)))}}}}};var n=t("typedarray-pool"),a=t("bit-twiddle"),i=t("./brute"),o=i.partial,s=i.full,l=t("./sweep"),c=t("./median"),u=t("./partition"),h=128,f=1<<22,p=1<<22,d=u("!(lo>=p0)&&!(p1>=hi)",["p0","p1"]),g=u("lo===p0",["p0"]),v=u("lo<p0",["p0"]),m=u("hi<=p0",["p0"]),y=u("lo<=p0&&p0<=hi",["p0"]),x=u("lo<p0&&p0<=hi",["p0"]),b=6,_=2,w=n.mallocInt32(1024),k=n.mallocDouble(1024);function T(t,e,r,n,a,i,o,s,l){var c=b*t;w[c]=e,w[c+1]=r,w[c+2]=n,w[c+3]=a,w[c+4]=i,w[c+5]=o;var u=_*t;k[u]=s,k[u+1]=l}function M(t,e,r,n,a,i,o,s,l,c,u){var h=2*t,f=l*h,p=c[f+e];t:for(var d=a,g=a*h;d<i;++d,g+=h){var v=o[g+e],m=o[g+e+t];if(!(p<v||m<p)&&(!n||p!==v)){for(var y,x=s[d],b=e+1;b<t;++b){v=o[g+b],m=o[g+b+t];var _=c[f+b],w=c[f+b+t];if(m<_||w<v)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function A(t,e,r,n,a,i,o,s,l,c){var u=2*t,h=s*u,f=l[h+e];t:for(var p=n,d=n*u;p<a;++p,d+=u){var g=o[p];if(g!==c){var v=i[d+e],m=i[d+e+t];if(!(f<v||m<f)){for(var y=e+1;y<t;++y){v=i[d+y],m=i[d+y+t];var x=l[h+y],b=l[h+y+t];if(m<x||b<v)continue t}var _=r(g,c);if(void 0!==_)return _}}}}},{"./brute":99,"./median":101,"./partition":102,"./sweep":104,"bit-twiddle":94,"typedarray-pool":543}],101:[function(t,e,r){"use strict";e.exports=function(t,e,r,o,s,l){if(o<=r+1)return r;var c=r,u=o,h=o+r>>>1,f=2*t,p=h,d=s[f*h+e];for(;c<u;){if(u-c<a){i(t,e,c,u,s,l),d=s[f*h+e];break}var g=u-c,v=Math.random()*g+c|0,m=s[f*v+e],y=Math.random()*g+c|0,x=s[f*y+e],b=Math.random()*g+c|0,_=s[f*b+e];m<=x?_>=x?(p=y,d=x):m>=_?(p=v,d=m):(p=b,d=_):x>=_?(p=y,d=x):_>=m?(p=v,d=m):(p=b,d=_);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var M=s[w];s[w]=s[k],s[k]=M}var A=l[u-1];l[u-1]=l[p],l[p]=A,p=n(t,e,c,u-1,s,l,d);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var M=s[w];s[w]=s[k],s[k]=M}var A=l[u-1];if(l[u-1]=l[p],l[p]=A,h<p){for(u=p-1;c<u&&s[f*(u-1)+e]===d;)u-=1;u+=1}else{if(!(p<h))break;for(c=p+1;c<u&&s[f*c+e]===d;)c+=1}}return n(t,e,r,h,s,l,s[f*h+e])};var n=t("./partition")("lo<p0",["p0"]),a=8;function i(t,e,r,n,a,i){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=a[s],u=l,h=o*(l-1);u>r&&a[h+e]>c;--u,h-=o){for(var f=h,p=h+o,d=0;d<o;++d,++f,++p){var g=a[f];a[f]=a[p],a[p]=g}var v=i[u];i[u]=i[u-1],i[u-1]=v}}},{"./partition":102}],102:[function(t,e,r){"use strict";e.exports=function(t,e){var r="abcdef".split("").concat(e),a=[];t.indexOf("lo")>=0&&a.push("lo=e[k+n]");t.indexOf("hi")>=0&&a.push("hi=e[k+o]");return r.push(n.replace("_",a.join()).replace("$",t)),Function.apply(void 0,r)};var n="for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m"},{}],103:[function(t,e,r){"use strict";e.exports=function(t,e){e<=4*n?a(0,e-1,t):function t(e,r,h){var f=(r-e+1)/6|0,p=e+f,d=r-f,g=e+r>>1,v=g-f,m=g+f,y=p,x=v,b=g,_=m,w=d,k=e+1,T=r-1,M=0;c(y,x,h)&&(M=y,y=x,x=M);c(_,w,h)&&(M=_,_=w,w=M);c(y,b,h)&&(M=y,y=b,b=M);c(x,b,h)&&(M=x,x=b,b=M);c(y,_,h)&&(M=y,y=_,_=M);c(b,_,h)&&(M=b,b=_,_=M);c(x,w,h)&&(M=x,x=w,w=M);c(x,b,h)&&(M=x,x=b,b=M);c(_,w,h)&&(M=_,_=w,w=M);var A=h[2*x];var S=h[2*x+1];var E=h[2*_];var L=h[2*_+1];var C=2*y;var P=2*b;var O=2*w;var z=2*p;var I=2*g;var D=2*d;for(var R=0;R<2;++R){var F=h[C+R],B=h[P+R],N=h[O+R];h[z+R]=F,h[I+R]=B,h[D+R]=N}o(v,e,h);o(m,r,h);for(var j=k;j<=T;++j)if(u(j,A,S,h))j!==k&&i(j,k,h),++k;else if(!u(j,E,L,h))for(;;){if(u(T,E,L,h)){u(T,A,S,h)?(s(j,k,T,h),++k,--T):(i(j,T,h),--T);break}if(--T<j)break}l(e,k-1,A,S,h);l(r,T+1,E,L,h);k-2-e<=n?a(e,k-2,h):t(e,k-2,h);r-(T+2)<=n?a(T+2,r,h):t(T+2,r,h);T-k<=n?a(k,T,h):t(k,T,h)}(0,e-1,t)};var n=32;function a(t,e,r){for(var n=2*(t+1),a=t+1;a<=e;++a){for(var i=r[n++],o=r[n++],s=a,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<i)break;if(c===i&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=i,r[l+1]=o}}function i(t,e,r){e*=2;var n=r[t*=2],a=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=a}function o(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function s(t,e,r,n){e*=2,r*=2;var a=n[t*=2],i=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=a,n[r+1]=i}function l(t,e,r,n,a){e*=2,a[t*=2]=a[e],a[e]=r,a[t+1]=a[e+1],a[e+1]=n}function c(t,e,r){e*=2;var n=r[t*=2],a=r[e];return!(n<a)&&(n!==a||r[t+1]>r[e+1])}function u(t,e,r,n){var a=n[t*=2];return a<e||a===e&&n[t+1]<r}},{}],104:[function(t,e,r){"use strict";e.exports={init:function(t){var e=a.nextPow2(t);s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));h.length<e&&(n.free(h),h=n.mallocInt32(e));f.length<e&&(n.free(f),f=n.mallocInt32(e));var r=8*e;p.length<r&&(n.free(p),p=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,a,h,f,v,m,y){for(var x=0,b=2*t,_=t-1,w=b-1,k=r;k<n;++k){var T=h[k],M=b*k;p[x++]=a[M+_],p[x++]=-(T+1),p[x++]=a[M+w],p[x++]=T}for(var k=f;k<v;++k){var T=y[k]+o,A=b*k;p[x++]=m[A+_],p[x++]=-T,p[x++]=m[A+w],p[x++]=T}var S=x>>>1;i(p,S);for(var E=0,L=0,k=0;k<S;++k){var C=0|p[2*k+1];if(C>=o)d(c,u,L--,C=C-o|0);else if(C>=0)d(s,l,E--,C);else if(C<=-o){C=-C-o|0;for(var P=0;P<E;++P){var O=e(s[P],C);if(void 0!==O)return O}g(c,u,L++,C)}else{C=-C-1|0;for(var P=0;P<L;++P){var O=e(C,c[P]);if(void 0!==O)return O}g(s,l,E++,C)}}},sweepComplete:function(t,e,r,n,a,o,v,m,y,x){for(var b=0,_=2*t,w=t-1,k=_-1,T=r;T<n;++T){var M=o[T]+1<<1,A=_*T;p[b++]=a[A+w],p[b++]=-M,p[b++]=a[A+k],p[b++]=M}for(var T=v;T<m;++T){var M=x[T]+1<<1,S=_*T;p[b++]=y[S+w],p[b++]=1|-M,p[b++]=y[S+k],p[b++]=1|M}var E=b>>>1;i(p,E);for(var L=0,C=0,P=0,T=0;T<E;++T){var O=0|p[2*T+1],z=1&O;if(T<E-1&&O>>1==p[2*T+3]>>1&&(z=2,T+=1),O<0){for(var I=-(O>>1)-1,D=0;D<P;++D){var R=e(h[D],I);if(void 0!==R)return R}if(0!==z)for(var D=0;D<L;++D){var R=e(s[D],I);if(void 0!==R)return R}if(1!==z)for(var D=0;D<C;++D){var R=e(c[D],I);if(void 0!==R)return R}0===z?g(s,l,L++,I):1===z?g(c,u,C++,I):2===z&&g(h,f,P++,I)}else{var I=(O>>1)-1;0===z?d(s,l,L--,I):1===z?d(c,u,C--,I):2===z&&d(h,f,P--,I)}}},scanBipartite:function(t,e,r,n,a,c,u,h,f,v,m,y){var x=0,b=2*t,_=e,w=e+t,k=1,T=1;n?T=o:k=o;for(var M=a;M<c;++M){var A=M+k,S=b*M;p[x++]=u[S+_],p[x++]=-A,p[x++]=u[S+w],p[x++]=A}for(var M=f;M<v;++M){var A=M+T,E=b*M;p[x++]=m[E+_],p[x++]=-A}var L=x>>>1;i(p,L);for(var C=0,M=0;M<L;++M){var P=0|p[2*M+1];if(P<0){var A=-P,O=!1;if(A>=o?(O=!n,A-=o):(O=!!n,A-=1),O)g(s,l,C++,A);else{var z=y[A],I=b*A,D=m[I+e+1],R=m[I+e+1+t];t:for(var F=0;F<C;++F){var B=s[F],N=b*B;if(!(R<u[N+e+1]||u[N+e+1+t]<D)){for(var j=e+2;j<t;++j)if(m[I+j+t]<u[N+j]||u[N+j+t]<m[I+j])continue t;var V,U=h[B];if(void 0!==(V=n?r(z,U):r(U,z)))return V}}}}else d(s,l,C--,P-k)}},scanComplete:function(t,e,r,n,a,l,c,u,h,f,d){for(var g=0,v=2*t,m=e,y=e+t,x=n;x<a;++x){var b=x+o,_=v*x;p[g++]=l[_+m],p[g++]=-b,p[g++]=l[_+y],p[g++]=b}for(var x=u;x<h;++x){var b=x+1,w=v*x;p[g++]=f[w+m],p[g++]=-b}var k=g>>>1;i(p,k);for(var T=0,x=0;x<k;++x){var M=0|p[2*x+1];if(M<0){var b=-M;if(b>=o)s[T++]=b-o;else{var A=d[b-=1],S=v*b,E=f[S+e+1],L=f[S+e+1+t];t:for(var C=0;C<T;++C){var P=s[C],O=c[P];if(O===A)break;var z=v*P;if(!(L<l[z+e+1]||l[z+e+1+t]<E)){for(var I=e+2;I<t;++I)if(f[S+I+t]<l[z+I]||l[z+I+t]<f[S+I])continue t;var D=r(O,A);if(void 0!==D)return D}}}}else{for(var b=M-o,C=T-1;C>=0;--C)if(s[C]===b){for(var I=C+1;I<T;++I)s[I-1]=s[I];break}--T}}}};var n=t("typedarray-pool"),a=t("bit-twiddle"),i=t("./sort"),o=1<<28,s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),h=n.mallocInt32(1024),f=n.mallocInt32(1024),p=n.mallocDouble(8192);function d(t,e,r,n){var a=e[n],i=t[r-1];t[a]=i,e[i]=a}function g(t,e,r,n){t[r]=n,e[n]=r}},{"./sort":103,"bit-twiddle":94,"typedarray-pool":543}],105:[function(t,e,r){},{}],106:[function(t,e,r){var n=Object.create||function(t){var e=function(){};return e.prototype=t,new e},a=Object.keys||function(t){var e=[];for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&e.push(r);return r},i=Function.prototype.bind||function(t){var e=this;return function(){return e.apply(t,arguments)}};function o(){this._events&&Object.prototype.hasOwnProperty.call(this,"_events")||(this._events=n(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0}e.exports=o,o.EventEmitter=o,o.prototype._events=void 0,o.prototype._maxListeners=void 0;var s,l=10;try{var c={};Object.defineProperty&&Object.defineProperty(c,"x",{value:0}),s=0===c.x}catch(t){s=!1}function u(t){return void 0===t._maxListeners?o.defaultMaxListeners:t._maxListeners}function h(t,e,r,a){var i,o,s;if("function"!=typeof r)throw new TypeError('"listener" argument must be a function');if((o=t._events)?(o.newListener&&(t.emit("newListener",e,r.listener?r.listener:r),o=t._events),s=o[e]):(o=t._events=n(null),t._eventsCount=0),s){if("function"==typeof s?s=o[e]=a?[r,s]:[s,r]:a?s.unshift(r):s.push(r),!s.warned&&(i=u(t))&&i>0&&s.length>i){s.warned=!0;var l=new Error("Possible EventEmitter memory leak detected. "+s.length+' "'+String(e)+'" listeners added. Use emitter.setMaxListeners() to increase limit.');l.name="MaxListenersExceededWarning",l.emitter=t,l.type=e,l.count=s.length,"object"==typeof console&&console.warn&&console.warn("%s: %s",l.name,l.message)}}else s=o[e]=r,++t._eventsCount;return t}function f(){if(!this.fired)switch(this.target.removeListener(this.type,this.wrapFn),this.fired=!0,arguments.length){case 0:return this.listener.call(this.target);case 1:return this.listener.call(this.target,arguments[0]);case 2:return this.listener.call(this.target,arguments[0],arguments[1]);case 3:return this.listener.call(this.target,arguments[0],arguments[1],arguments[2]);default:for(var t=new Array(arguments.length),e=0;e<t.length;++e)t[e]=arguments[e];this.listener.apply(this.target,t)}}function p(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},a=i.call(f,n);return a.listener=r,n.wrapFn=a,a}function d(t,e,r){var n=t._events;if(!n)return[];var a=n[e];return a?"function"==typeof a?r?[a.listener||a]:[a]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(a):v(a,a.length):[]}function g(t){var e=this._events;if(e){var r=e[t];if("function"==typeof r)return 1;if(r)return r.length}return 0}function v(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}s?Object.defineProperty(o,"defaultMaxListeners",{enumerable:!0,get:function(){return l},set:function(t){if("number"!=typeof t||t<0||t!=t)throw new TypeError('"defaultMaxListeners" must be a positive number');l=t}}):o.defaultMaxListeners=l,o.prototype.setMaxListeners=function(t){if("number"!=typeof t||t<0||isNaN(t))throw new TypeError('"n" argument must be a positive number');return this._maxListeners=t,this},o.prototype.getMaxListeners=function(){return u(this)},o.prototype.emit=function(t){var e,r,n,a,i,o,s="error"===t;if(o=this._events)s=s&&null==o.error;else if(!s)return!1;if(s){if(arguments.length>1&&(e=arguments[1]),e instanceof Error)throw e;var l=new Error('Unhandled "error" event. ('+e+")");throw l.context=e,l}if(!(r=o[t]))return!1;var c="function"==typeof r;switch(n=arguments.length){case 1:!function(t,e,r){if(e)t.call(r);else for(var n=t.length,a=v(t,n),i=0;i<n;++i)a[i].call(r)}(r,c,this);break;case 2:!function(t,e,r,n){if(e)t.call(r,n);else for(var a=t.length,i=v(t,a),o=0;o<a;++o)i[o].call(r,n)}(r,c,this,arguments[1]);break;case 3:!function(t,e,r,n,a){if(e)t.call(r,n,a);else for(var i=t.length,o=v(t,i),s=0;s<i;++s)o[s].call(r,n,a)}(r,c,this,arguments[1],arguments[2]);break;case 4:!function(t,e,r,n,a,i){if(e)t.call(r,n,a,i);else for(var o=t.length,s=v(t,o),l=0;l<o;++l)s[l].call(r,n,a,i)}(r,c,this,arguments[1],arguments[2],arguments[3]);break;default:for(a=new Array(n-1),i=1;i<n;i++)a[i-1]=arguments[i];!function(t,e,r,n){if(e)t.apply(r,n);else for(var a=t.length,i=v(t,a),o=0;o<a;++o)i[o].apply(r,n)}(r,c,this,a)}return!0},o.prototype.addListener=function(t,e){return h(this,t,e,!1)},o.prototype.on=o.prototype.addListener,o.prototype.prependListener=function(t,e){return h(this,t,e,!0)},o.prototype.once=function(t,e){if("function"!=typeof e)throw new TypeError('"listener" argument must be a function');return this.on(t,p(this,t,e)),this},o.prototype.prependOnceListener=function(t,e){if("function"!=typeof e)throw new TypeError('"listener" argument must be a function');return this.prependListener(t,p(this,t,e)),this},o.prototype.removeListener=function(t,e){var r,a,i,o,s;if("function"!=typeof e)throw new TypeError('"listener" argument must be a function');if(!(a=this._events))return this;if(!(r=a[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=n(null):(delete a[t],a.removeListener&&this.emit("removeListener",t,r.listener||e));else if("function"!=typeof r){for(i=-1,o=r.length-1;o>=0;o--)if(r[o]===e||r[o].listener===e){s=r[o].listener,i=o;break}if(i<0)return this;0===i?r.shift():function(t,e){for(var r=e,n=r+1,a=t.length;n<a;r+=1,n+=1)t[r]=t[n];t.pop()}(r,i),1===r.length&&(a[t]=r[0]),a.removeListener&&this.emit("removeListener",t,s||e)}return this},o.prototype.removeAllListeners=function(t){var e,r,i;if(!(r=this._events))return this;if(!r.removeListener)return 0===arguments.length?(this._events=n(null),this._eventsCount=0):r[t]&&(0==--this._eventsCount?this._events=n(null):delete r[t]),this;if(0===arguments.length){var o,s=a(r);for(i=0;i<s.length;++i)"removeListener"!==(o=s[i])&&this.removeAllListeners(o);return this.removeAllListeners("removeListener"),this._events=n(null),this._eventsCount=0,this}if("function"==typeof(e=r[t]))this.removeListener(t,e);else if(e)for(i=e.length-1;i>=0;i--)this.removeListener(t,e[i]);return this},o.prototype.listeners=function(t){return d(this,t,!0)},o.prototype.rawListeners=function(t){return d(this,t,!1)},o.listenerCount=function(t,e){return"function"==typeof t.listenerCount?t.listenerCount(e):g.call(t,e)},o.prototype.listenerCount=g,o.prototype.eventNames=function(){return this._eventsCount>0?Reflect.ownKeys(this._events):[]}},{}],107:[function(t,e,r){(function(e){"use strict";var n=t("base64-js"),a=t("ieee754"),i="function"==typeof Symbol&&"function"==typeof Symbol.for?Symbol.for("nodejs.util.inspect.custom"):null;r.Buffer=e,r.SlowBuffer=function(t){+t!=t&&(t=0);return e.alloc(+t)},r.INSPECT_MAX_BYTES=50;var o=2147483647;function s(t){if(t>o)throw new RangeError('The value "'+t+'" is invalid for option "size"');var r=new Uint8Array(t);return Object.setPrototypeOf(r,e.prototype),r}function e(t,e,r){if("number"==typeof t){if("string"==typeof e)throw new TypeError('The "string" argument must be of type string. Received type number');return u(t)}return l(t,e,r)}function l(t,r,n){if("string"==typeof t)return function(t,r){"string"==typeof r&&""!==r||(r="utf8");if(!e.isEncoding(r))throw new TypeError("Unknown encoding: "+r);var n=0|p(t,r),a=s(n),i=a.write(t,r);i!==n&&(a=a.slice(0,i));return a}(t,r);if(ArrayBuffer.isView(t))return h(t);if(null==t)throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof t);if(j(t,ArrayBuffer)||t&&j(t.buffer,ArrayBuffer))return function(t,r,n){if(r<0||t.byteLength<r)throw new RangeError('"offset" is outside of buffer bounds');if(t.byteLength<r+(n||0))throw new RangeError('"length" is outside of buffer bounds');var a;a=void 0===r&&void 0===n?new Uint8Array(t):void 0===n?new Uint8Array(t,r):new Uint8Array(t,r,n);return Object.setPrototypeOf(a,e.prototype),a}(t,r,n);if("number"==typeof t)throw new TypeError('The "value" argument must not be of type number. Received type number');var a=t.valueOf&&t.valueOf();if(null!=a&&a!==t)return e.from(a,r,n);var i=function(t){if(e.isBuffer(t)){var r=0|f(t.length),n=s(r);return 0===n.length?n:(t.copy(n,0,0,r),n)}if(void 0!==t.length)return"number"!=typeof t.length||V(t.length)?s(0):h(t);if("Buffer"===t.type&&Array.isArray(t.data))return h(t.data)}(t);if(i)return i;if("undefined"!=typeof Symbol&&null!=Symbol.toPrimitive&&"function"==typeof t[Symbol.toPrimitive])return e.from(t[Symbol.toPrimitive]("string"),r,n);throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof t)}function c(t){if("number"!=typeof t)throw new TypeError('"size" argument must be of type number');if(t<0)throw new RangeError('The value "'+t+'" is invalid for option "size"')}function u(t){return c(t),s(t<0?0:0|f(t))}function h(t){for(var e=t.length<0?0:0|f(t.length),r=s(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function f(t){if(t>=o)throw new RangeError("Attempt to allocate Buffer larger than maximum size: 0x"+o.toString(16)+" bytes");return 0|t}function p(t,r){if(e.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||j(t,ArrayBuffer))return t.byteLength;if("string"!=typeof t)throw new TypeError('The "string" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var n=t.length,a=arguments.length>2&&!0===arguments[2];if(!a&&0===n)return 0;for(var i=!1;;)switch(r){case"ascii":case"latin1":case"binary":return n;case"utf8":case"utf-8":return F(t).length;case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return 2*n;case"hex":return n>>>1;case"base64":return B(t).length;default:if(i)return a?-1:F(t).length;r=(""+r).toLowerCase(),i=!0}}function d(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function g(t,r,n,a,i){if(0===t.length)return-1;if("string"==typeof n?(a=n,n=0):n>2147483647?n=2147483647:n<-2147483648&&(n=-2147483648),V(n=+n)&&(n=i?0:t.length-1),n<0&&(n=t.length+n),n>=t.length){if(i)return-1;n=t.length-1}else if(n<0){if(!i)return-1;n=0}if("string"==typeof r&&(r=e.from(r,a)),e.isBuffer(r))return 0===r.length?-1:v(t,r,n,a,i);if("number"==typeof r)return r&=255,"function"==typeof Uint8Array.prototype.indexOf?i?Uint8Array.prototype.indexOf.call(t,r,n):Uint8Array.prototype.lastIndexOf.call(t,r,n):v(t,[r],n,a,i);throw new TypeError("val must be string, number or Buffer")}function v(t,e,r,n,a){var i,o=1,s=t.length,l=e.length;if(void 0!==n&&("ucs2"===(n=String(n).toLowerCase())||"ucs-2"===n||"utf16le"===n||"utf-16le"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(a){var u=-1;for(i=r;i<s;i++)if(c(t,i)===c(e,-1===u?0:i-u)){if(-1===u&&(u=i),i-u+1===l)return u*o}else-1!==u&&(i-=i-u),u=-1}else for(r+l>s&&(r=s-l),i=r;i>=0;i--){for(var h=!0,f=0;f<l;f++)if(c(t,i+f)!==c(e,f)){h=!1;break}if(h)return i}return-1}function m(t,e,r,n){r=Number(r)||0;var a=t.length-r;n?(n=Number(n))>a&&(n=a):n=a;var i=e.length;n>i/2&&(n=i/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(V(s))return o;t[r+o]=s}return o}function y(t,e,r,n){return N(F(e,t.length-r),t,r,n)}function x(t,e,r,n){return N(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function b(t,e,r,n){return x(t,e,r,n)}function _(t,e,r,n){return N(B(e),t,r,n)}function w(t,e,r,n){return N(function(t,e){for(var r,n,a,i=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,a=r%256,i.push(a),i.push(n);return i}(e,t.length-r),t,r,n)}function k(t,e,r){return 0===e&&r===t.length?n.fromByteArray(t):n.fromByteArray(t.slice(e,r))}function T(t,e,r){r=Math.min(t.length,r);for(var n=[],a=e;a<r;){var i,o,s,l,c=t[a],u=null,h=c>239?4:c>223?3:c>191?2:1;if(a+h<=r)switch(h){case 1:c<128&&(u=c);break;case 2:128==(192&(i=t[a+1]))&&(l=(31&c)<<6|63&i)>127&&(u=l);break;case 3:i=t[a+1],o=t[a+2],128==(192&i)&&128==(192&o)&&(l=(15&c)<<12|(63&i)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:i=t[a+1],o=t[a+2],s=t[a+3],128==(192&i)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&i)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,h=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),a+=h}return function(t){var e=t.length;if(e<=M)return String.fromCharCode.apply(String,t);var r="",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=M));return r}(n)}r.kMaxLength=o,e.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1),e={foo:function(){return 42}};return Object.setPrototypeOf(e,Uint8Array.prototype),Object.setPrototypeOf(t,e),42===t.foo()}catch(t){return!1}}(),e.TYPED_ARRAY_SUPPORT||"undefined"==typeof console||"function"!=typeof console.error||console.error("This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support."),Object.defineProperty(e.prototype,"parent",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.buffer}}),Object.defineProperty(e.prototype,"offset",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.byteOffset}}),"undefined"!=typeof Symbol&&null!=Symbol.species&&e[Symbol.species]===e&&Object.defineProperty(e,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),e.poolSize=8192,e.from=function(t,e,r){return l(t,e,r)},Object.setPrototypeOf(e.prototype,Uint8Array.prototype),Object.setPrototypeOf(e,Uint8Array),e.alloc=function(t,e,r){return function(t,e,r){return c(t),t<=0?s(t):void 0!==e?"string"==typeof r?s(t).fill(e,r):s(t).fill(e):s(t)}(t,e,r)},e.allocUnsafe=function(t){return u(t)},e.allocUnsafeSlow=function(t){return u(t)},e.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==e.prototype},e.compare=function(t,r){if(j(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),j(r,Uint8Array)&&(r=e.from(r,r.offset,r.byteLength)),!e.isBuffer(t)||!e.isBuffer(r))throw new TypeError('The "buf1", "buf2" arguments must be one of type Buffer or Uint8Array');if(t===r)return 0;for(var n=t.length,a=r.length,i=0,o=Math.min(n,a);i<o;++i)if(t[i]!==r[i]){n=t[i],a=r[i];break}return n<a?-1:a<n?1:0},e.isEncoding=function(t){switch(String(t).toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"latin1":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return!0;default:return!1}},e.concat=function(t,r){if(!Array.isArray(t))throw new TypeError('"list" argument must be an Array of Buffers');if(0===t.length)return e.alloc(0);var n;if(void 0===r)for(r=0,n=0;n<t.length;++n)r+=t[n].length;var a=e.allocUnsafe(r),i=0;for(n=0;n<t.length;++n){var o=t[n];if(j(o,Uint8Array)&&(o=e.from(o)),!e.isBuffer(o))throw new TypeError('"list" argument must be an Array of Buffers');o.copy(a,i),i+=o.length}return a},e.byteLength=p,e.prototype._isBuffer=!0,e.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError("Buffer size must be a multiple of 16-bits");for(var e=0;e<t;e+=2)d(this,e,e+1);return this},e.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError("Buffer size must be a multiple of 32-bits");for(var e=0;e<t;e+=4)d(this,e,e+3),d(this,e+1,e+2);return this},e.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError("Buffer size must be a multiple of 64-bits");for(var e=0;e<t;e+=8)d(this,e,e+7),d(this,e+1,e+6),d(this,e+2,e+5),d(this,e+3,e+4);return this},e.prototype.toString=function(){var t=this.length;return 0===t?"":0===arguments.length?T(this,0,t):function(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return"";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return"";if((r>>>=0)<=(e>>>=0))return"";for(t||(t="utf8");;)switch(t){case"hex":return E(this,e,r);case"utf8":case"utf-8":return T(this,e,r);case"ascii":return A(this,e,r);case"latin1":case"binary":return S(this,e,r);case"base64":return k(this,e,r);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return L(this,e,r);default:if(n)throw new TypeError("Unknown encoding: "+t);t=(t+"").toLowerCase(),n=!0}}.apply(this,arguments)},e.prototype.toLocaleString=e.prototype.toString,e.prototype.equals=function(t){if(!e.isBuffer(t))throw new TypeError("Argument must be a Buffer");return this===t||0===e.compare(this,t)},e.prototype.inspect=function(){var t="",e=r.INSPECT_MAX_BYTES;return t=this.toString("hex",0,e).replace(/(.{2})/g,"$1 ").trim(),this.length>e&&(t+=" ... "),"<Buffer "+t+">"},i&&(e.prototype[i]=e.prototype.inspect),e.prototype.compare=function(t,r,n,a,i){if(j(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),!e.isBuffer(t))throw new TypeError('The "target" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===r&&(r=0),void 0===n&&(n=t?t.length:0),void 0===a&&(a=0),void 0===i&&(i=this.length),r<0||n>t.length||a<0||i>this.length)throw new RangeError("out of range index");if(a>=i&&r>=n)return 0;if(a>=i)return-1;if(r>=n)return 1;if(this===t)return 0;for(var o=(i>>>=0)-(a>>>=0),s=(n>>>=0)-(r>>>=0),l=Math.min(o,s),c=this.slice(a,i),u=t.slice(r,n),h=0;h<l;++h)if(c[h]!==u[h]){o=c[h],s=u[h];break}return o<s?-1:s<o?1:0},e.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},e.prototype.indexOf=function(t,e,r){return g(this,t,e,r,!0)},e.prototype.lastIndexOf=function(t,e,r){return g(this,t,e,r,!1)},e.prototype.write=function(t,e,r,n){if(void 0===e)n="utf8",r=this.length,e=0;else if(void 0===r&&"string"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error("Buffer.write(string, encoding, offset[, length]) is no longer supported");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n="utf8")):(n=r,r=void 0)}var a=this.length-e;if((void 0===r||r>a)&&(r=a),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError("Attempt to write outside buffer bounds");n||(n="utf8");for(var i=!1;;)switch(n){case"hex":return m(this,t,e,r);case"utf8":case"utf-8":return y(this,t,e,r);case"ascii":return x(this,t,e,r);case"latin1":case"binary":return b(this,t,e,r);case"base64":return _(this,t,e,r);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return w(this,t,e,r);default:if(i)throw new TypeError("Unknown encoding: "+n);n=(""+n).toLowerCase(),i=!0}},e.prototype.toJSON=function(){return{type:"Buffer",data:Array.prototype.slice.call(this._arr||this,0)}};var M=4096;function A(t,e,r){var n="";r=Math.min(t.length,r);for(var a=e;a<r;++a)n+=String.fromCharCode(127&t[a]);return n}function S(t,e,r){var n="";r=Math.min(t.length,r);for(var a=e;a<r;++a)n+=String.fromCharCode(t[a]);return n}function E(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var a="",i=e;i<r;++i)a+=R(t[i]);return a}function L(t,e,r){for(var n=t.slice(e,r),a="",i=0;i<n.length;i+=2)a+=String.fromCharCode(n[i]+256*n[i+1]);return a}function C(t,e,r){if(t%1!=0||t<0)throw new RangeError("offset is not uint");if(t+e>r)throw new RangeError("Trying to access beyond buffer length")}function P(t,r,n,a,i,o){if(!e.isBuffer(t))throw new TypeError('"buffer" argument must be a Buffer instance');if(r>i||r<o)throw new RangeError('"value" argument is out of bounds');if(n+a>t.length)throw new RangeError("Index out of range")}function O(t,e,r,n,a,i){if(r+n>t.length)throw new RangeError("Index out of range");if(r<0)throw new RangeError("Index out of range")}function z(t,e,r,n,i){return e=+e,r>>>=0,i||O(t,0,r,4),a.write(t,e,r,n,23,4),r+4}function I(t,e,r,n,i){return e=+e,r>>>=0,i||O(t,0,r,8),a.write(t,e,r,n,52,8),r+8}e.prototype.slice=function(t,r){var n=this.length;(t=~~t)<0?(t+=n)<0&&(t=0):t>n&&(t=n),(r=void 0===r?n:~~r)<0?(r+=n)<0&&(r=0):r>n&&(r=n),r<t&&(r=t);var a=this.subarray(t,r);return Object.setPrototypeOf(a,e.prototype),a},e.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],a=1,i=0;++i<e&&(a*=256);)n+=this[t+i]*a;return n},e.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t+--e],a=1;e>0&&(a*=256);)n+=this[t+--e]*a;return n},e.prototype.readUInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),this[t]},e.prototype.readUInt16LE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]|this[t+1]<<8},e.prototype.readUInt16BE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]<<8|this[t+1]},e.prototype.readUInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},e.prototype.readUInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},e.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],a=1,i=0;++i<e&&(a*=256);)n+=this[t+i]*a;return n>=(a*=128)&&(n-=Math.pow(2,8*e)),n},e.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=e,a=1,i=this[t+--n];n>0&&(a*=256);)i+=this[t+--n]*a;return i>=(a*=128)&&(i-=Math.pow(2,8*e)),i},e.prototype.readInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},e.prototype.readInt16LE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt16BE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},e.prototype.readInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},e.prototype.readFloatLE=function(t,e){return t>>>=0,e||C(t,4,this.length),a.read(this,t,!0,23,4)},e.prototype.readFloatBE=function(t,e){return t>>>=0,e||C(t,4,this.length),a.read(this,t,!1,23,4)},e.prototype.readDoubleLE=function(t,e){return t>>>=0,e||C(t,8,this.length),a.read(this,t,!0,52,8)},e.prototype.readDoubleBE=function(t,e){return t>>>=0,e||C(t,8,this.length),a.read(this,t,!1,52,8)},e.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||P(this,t,e,r,Math.pow(2,8*r)-1,0);var a=1,i=0;for(this[e]=255&t;++i<r&&(a*=256);)this[e+i]=t/a&255;return e+r},e.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||P(this,t,e,r,Math.pow(2,8*r)-1,0);var a=r-1,i=1;for(this[e+a]=255&t;--a>=0&&(i*=256);)this[e+a]=t/i&255;return e+r},e.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,1,255,0),this[e]=255&t,e+1},e.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},e.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var a=Math.pow(2,8*r-1);P(this,t,e,r,a-1,-a)}var i=0,o=1,s=0;for(this[e]=255&t;++i<r&&(o*=256);)t<0&&0===s&&0!==this[e+i-1]&&(s=1),this[e+i]=(t/o>>0)-s&255;return e+r},e.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var a=Math.pow(2,8*r-1);P(this,t,e,r,a-1,-a)}var i=r-1,o=1,s=0;for(this[e+i]=255&t;--i>=0&&(o*=256);)t<0&&0===s&&0!==this[e+i+1]&&(s=1),this[e+i]=(t/o>>0)-s&255;return e+r},e.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},e.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},e.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeFloatLE=function(t,e,r){return z(this,t,e,!0,r)},e.prototype.writeFloatBE=function(t,e,r){return z(this,t,e,!1,r)},e.prototype.writeDoubleLE=function(t,e,r){return I(this,t,e,!0,r)},e.prototype.writeDoubleBE=function(t,e,r){return I(this,t,e,!1,r)},e.prototype.copy=function(t,r,n,a){if(!e.isBuffer(t))throw new TypeError("argument should be a Buffer");if(n||(n=0),a||0===a||(a=this.length),r>=t.length&&(r=t.length),r||(r=0),a>0&&a<n&&(a=n),a===n)return 0;if(0===t.length||0===this.length)return 0;if(r<0)throw new RangeError("targetStart out of bounds");if(n<0||n>=this.length)throw new RangeError("Index out of range");if(a<0)throw new RangeError("sourceEnd out of bounds");a>this.length&&(a=this.length),t.length-r<a-n&&(a=t.length-r+n);var i=a-n;if(this===t&&"function"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(r,n,a);else if(this===t&&n<r&&r<a)for(var o=i-1;o>=0;--o)t[o+r]=this[o+n];else Uint8Array.prototype.set.call(t,this.subarray(n,a),r);return i},e.prototype.fill=function(t,r,n,a){if("string"==typeof t){if("string"==typeof r?(a=r,r=0,n=this.length):"string"==typeof n&&(a=n,n=this.length),void 0!==a&&"string"!=typeof a)throw new TypeError("encoding must be a string");if("string"==typeof a&&!e.isEncoding(a))throw new TypeError("Unknown encoding: "+a);if(1===t.length){var i=t.charCodeAt(0);("utf8"===a&&i<128||"latin1"===a)&&(t=i)}}else"number"==typeof t?t&=255:"boolean"==typeof t&&(t=Number(t));if(r<0||this.length<r||this.length<n)throw new RangeError("Out of range index");if(n<=r)return this;var o;if(r>>>=0,n=void 0===n?this.length:n>>>0,t||(t=0),"number"==typeof t)for(o=r;o<n;++o)this[o]=t;else{var s=e.isBuffer(t)?t:e.from(t,a),l=s.length;if(0===l)throw new TypeError('The value "'+t+'" is invalid for argument "value"');for(o=0;o<n-r;++o)this[o+r]=s[o%l]}return this};var D=/[^+/0-9A-Za-z-_]/g;function R(t){return t<16?"0"+t.toString(16):t.toString(16)}function F(t,e){var r;e=e||1/0;for(var n=t.length,a=null,i=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!a){if(r>56319){(e-=3)>-1&&i.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&i.push(239,191,189);continue}a=r;continue}if(r<56320){(e-=3)>-1&&i.push(239,191,189),a=r;continue}r=65536+(a-55296<<10|r-56320)}else a&&(e-=3)>-1&&i.push(239,191,189);if(a=null,r<128){if((e-=1)<0)break;i.push(r)}else if(r<2048){if((e-=2)<0)break;i.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;i.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error("Invalid code point");if((e-=4)<0)break;i.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return i}function B(t){return n.toByteArray(function(t){if((t=(t=t.split("=")[0]).trim().replace(D,"")).length<2)return"";for(;t.length%4!=0;)t+="=";return t}(t))}function N(t,e,r,n){for(var a=0;a<n&&!(a+r>=e.length||a>=t.length);++a)e[a+r]=t[a];return a}function j(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function V(t){return t!=t}}).call(this,t("buffer").Buffer)},{"base64-js":76,buffer:107,ieee754:413}],108:[function(t,e,r){"use strict";var n=t("./lib/monotone"),a=t("./lib/triangulation"),i=t("./lib/delaunay"),o=t("./lib/filter");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,"delaunay",!0),h=!!c(r,"interior",!0),f=!!c(r,"exterior",!0),p=!!c(r,"infinity",!1);if(!h&&!f||0===t.length)return[];var d=n(t,e);if(u||h!==f||p){for(var g=a(t.length,function(t){return t.map(s).sort(l)}(e)),v=0;v<d.length;++v){var m=d[v];g.addTriangle(m[0],m[1],m[2])}return u&&i(t,g),f?h?p?o(g,0,p):g.cells():o(g,1,p):o(g,-1)}return d}},{"./lib/delaunay":109,"./lib/filter":110,"./lib/monotone":111,"./lib/triangulation":112}],109:[function(t,e,r){"use strict";var n=t("robust-in-sphere")[4];t("binary-search-bounds");function a(t,e,r,a,i,o){var s=e.opposite(a,i);if(!(s<0)){if(i<a){var l=a;a=i,i=l,l=o,o=s,s=l}e.isConstraint(a,i)||n(t[a],t[i],t[o],t[s])<0&&r.push(a,i)}}e.exports=function(t,e){for(var r=[],i=t.length,o=e.stars,s=0;s<i;++s)for(var l=o[s],c=1;c<l.length;c+=2){var u=l[c];if(!(u<s)&&!e.isConstraint(s,u)){for(var h=l[c-1],f=-1,p=1;p<l.length;p+=2)if(l[p-1]===u){f=l[p];break}f<0||n(t[s],t[u],t[h],t[f])<0&&r.push(s,u)}}for(;r.length>0;){for(var u=r.pop(),s=r.pop(),h=-1,f=-1,l=o[s],d=1;d<l.length;d+=2){var g=l[d-1],v=l[d];g===u?f=v:v===u&&(h=g)}h<0||f<0||(n(t[s],t[u],t[h],t[f])>=0||(e.flip(s,u),a(t,e,r,h,s,f),a(t,e,r,s,f,h),a(t,e,r,f,u,h),a(t,e,r,u,h,f)))}}},{"binary-search-bounds":113,"robust-in-sphere":506}],110:[function(t,e,r){"use strict";var n,a=t("binary-search-bounds");function i(t,e,r,n,a,i,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=a,this.next=i,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,a=0;a<n;++a){var s=r[a],l=s[0],c=s[1],u=s[2];c<u?c<l&&(s[0]=c,s[1]=u,s[2]=l):u<l&&(s[0]=u,s[1]=l,s[2]=c)}r.sort(o);for(var h=new Array(n),a=0;a<h.length;++a)h[a]=0;var f=[],p=[],d=new Array(3*n),g=new Array(3*n),v=null;e&&(v=[]);for(var m=new i(r,d,g,h,f,p,v),a=0;a<n;++a)for(var s=r[a],y=0;y<3;++y){var l=s[y],c=s[(y+1)%3],x=d[3*a+y]=m.locate(c,l,t.opposite(c,l)),b=g[3*a+y]=t.isConstraint(l,c);x<0&&(b?p.push(a):(f.push(a),h[a]=1),e&&v.push([c,l,-1]))}return m}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var a=1,s=n.active,l=n.next,c=n.flags,u=n.cells,h=n.constraint,f=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-a){c[p]=a;u[p];for(var d=0;d<3;++d){var g=f[3*p+d];g>=0&&0===c[g]&&(h[3*p+d]?l.push(g):(s.push(g),c[g]=a))}}}var v=l;l=s,s=v,l.length=0,a=-a}var m=function(t,e,r){for(var n=0,a=0;a<t.length;++a)e[a]===r&&(t[n++]=t[a]);return t.length=n,t}(u,c,e);if(r)return m.concat(n.boundary);return m},i.prototype.locate=(n=[0,0,0],function(t,e,r){var i=t,s=e,l=r;return e<r?e<t&&(i=e,s=r,l=t):r<t&&(i=r,s=t,l=e),i<0?-1:(n[0]=i,n[1]=s,n[2]=l,a.eq(this.cells,n,o))})},{"binary-search-bounds":113}],111:[function(t,e,r){"use strict";var n=t("binary-search-bounds"),a=t("robust-orientation")[3],i=0,o=1,s=2;function l(t,e,r,n,a){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=a}function c(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function u(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(t.type!==i&&(r=a(t.a,t.b,e.b))?r:t.idx-e.idx)}function h(t,e){return a(t.a,t.b,e)}function f(t,e,r,i,o){for(var s=n.lt(e,i,h),l=n.gt(e,i,h),c=s;c<l;++c){for(var u=e[c],f=u.lowerIds,p=f.length;p>1&&a(r[f[p-2]],r[f[p-1]],i)>0;)t.push([f[p-1],f[p-2],o]),p-=1;f.length=p,f.push(o);var d=u.upperIds;for(p=d.length;p>1&&a(r[d[p-2]],r[d[p-1]],i)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function p(t,e){var r;return(r=t.a[0]<e.a[0]?a(t.a,t.b,e.a):a(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?a(t.a,t.b,e.b):a(e.b,e.a,t.b))||t.idx-e.idx}function d(t,e,r){var a=n.le(t,r,p),i=t[a],o=i.upperIds,s=o[o.length-1];i.upperIds=[s],t.splice(a+1,0,new l(r.a,r.b,r.idx,[s],o))}function g(t,e,r){var a=r.a;r.a=r.b,r.b=a;var i=n.eq(t,r,p),o=t[i];t[i-1].upperIds=o.upperIds,t.splice(i,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,a=[],h=0;h<r;++h)a.push(new c(t[h],null,i,h));for(var h=0;h<n;++h){var p=e[h],v=t[p[0]],m=t[p[1]];v[0]<m[0]?a.push(new c(v,m,s,h),new c(m,v,o,h)):v[0]>m[0]&&a.push(new c(m,v,s,h),new c(v,m,o,h))}a.sort(u);for(var y=a[0].a[0]-(1+Math.abs(a[0].a[0]))*Math.pow(2,-52),x=[new l([y,1],[y,0],-1,[],[],[],[])],b=[],h=0,_=a.length;h<_;++h){var w=a[h],k=w.type;k===i?f(b,x,t,w.a,w.idx):k===s?d(x,t,w):g(x,t,w)}return b}},{"binary-search-bounds":113,"robust-orientation":508}],112:[function(t,e,r){"use strict";var n=t("binary-search-bounds");function a(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new a(r,e)};var i=a.prototype;function o(t,e,r){for(var n=1,a=t.length;n<a;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[a-2],t[n]=t[a-1],void(t.length=a-2)}i.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,a){return t[0]=Math.min(r,a),t[1]=Math.max(r,a),n.eq(this.edges,t,e)>=0}}(),i.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},i.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},i.opposite=function(t,e){for(var r=this.stars[e],n=1,a=r.length;n<a;n+=2)if(r[n]===t)return r[n-1];return-1},i.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},i.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var a=t[r],i=0,o=a.length;i<o;i+=2)e.push([a[i],a[i+1]]);return e},i.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var a=t[r],i=0,o=a.length;i<o;i+=2){var s=a[i],l=a[i+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{"binary-search-bounds":113}],113:[function(t,e,r){"use strict";function n(t,e,r,n,a){var i=["function ",t,"(a,l,h,",n.join(","),"){",a?"":"var i=",r?"l-1":"h+1",";while(l<=h){var m=(l+h)>>>1,x=a[m]"];return a?e.indexOf("c")<0?i.push(";if(x===y){return m}else if(x<=y){"):i.push(";var p=c(x,y);if(p===0){return m}else if(p<=0){"):i.push(";if(",e,"){i=m;"),r?i.push("l=m+1}else{h=m-1}"):i.push("h=m-1}else{l=m+1}"),i.push("}"),a?i.push("return -1};"):i.push("return i};"),i.join("")}function a(t,e,r,a){return new Function([n("A","x"+t+"y",e,["y"],a),n("P","c(x,y)"+t+"0",e,["y","c"],a),"function dispatchBsearch",r,"(a,y,c,l,h){if(typeof(c)==='function'){return P(a,(l===void 0)?0:l|0,(h===void 0)?a.length-1:h|0,y,c)}else{return A(a,(c===void 0)?0:c|0,(l===void 0)?a.length-1:l|0,y)}}return dispatchBsearch",r].join(""))()}e.exports={ge:a(">=",!1,"GE"),gt:a(">",!1,"GT"),lt:a("<",!0,"LT"),le:a("<=",!0,"LE"),eq:a("-",!0,"EQ",!0)}},{}],114:[function(t,e,r){"use strict";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],115:[function(t,e,r){"use strict";var n=t("dup"),a=t("robust-linear-solve");function i(t,e){for(var r=0,n=t.length,a=0;a<n;++a)r+=t[a]*e[a];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*i(t[s],t[l]);o[s]=i(t[s],t[s])}var c=a(r,o),u=0,h=c[e+1];for(s=0;s<h.length;++s)u+=h[s];var f=new Array(e);for(s=0;s<e;++s){h=c[s];var p=0;for(l=0;l<h.length;++l)p+=h[l];f[s]=p/u}return f}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),a=o(t),i=0;i<t.length;++i)for(var s=0;s<e;++s)r[s]+=t[i][s]*a[i];return r}s.barycenetric=o,e.exports=s},{dup:172,"robust-linear-solve":507}],116:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,a=0;a<t.length;++a)for(var i=t[a],o=0;o<e.length;++o)r+=Math.pow(i[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t("circumcenter")},{circumcenter:115}],117:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],118:[function(t,e,r){"use strict";e.exports=function(t,e,r){var n;if(r){n=e;for(var a=new Array(e.length),i=0;i<e.length;++i){var o=e[i];a[i]=[o[0],o[1],r[i]]}e=a}var s=function(t,e,r){var n=d(t,[],p(t));return m(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(var i=0;i<e.length;++i){var o=e[i];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t("union-find"),a=t("box-intersect"),i=t("robust-segment-intersect"),o=t("big-rat"),s=t("big-rat/cmp"),l=t("big-rat/to-float"),c=t("rat-vec"),u=t("nextafter"),h=t("./lib/rat-seg-intersect");function f(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var i=e.length,o=new n(i),s=[],l=0;l<e.length;++l){var c=e[l],h=f(c[0]),p=f(c[1]);s.push([u(h[0],-1/0),u(p[0],-1/0),u(h[1],1/0),u(p[1],1/0)])}a(s,function(t,e){o.link(t,e)});var d=!0,g=new Array(i);for(l=0;l<i;++l){(m=o.find(l))!==l&&(d=!1,t[m]=[Math.min(t[l][0],t[m][0]),Math.min(t[l][1],t[m][1])])}if(d)return null;var v=0;for(l=0;l<i;++l){var m;(m=o.find(l))===l?(g[l]=v,t[v++]=t[l]):g[l]=-1}t.length=v;for(l=0;l<i;++l)g[l]<0&&(g[l]=g[o.find(l)]);return g}function g(t,e){return t[0]-e[0]||t[1]-e[1]}function v(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function m(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var a=e[(o=t[n])[0]],i=e[o[1]];o[0]=Math.min(a,i),o[1]=Math.max(a,i)}else for(n=0;n<t.length;++n){var o;a=(o=t[n])[0],i=o[1];o[0]=Math.min(a,i),o[1]=Math.max(a,i)}r?t.sort(v):t.sort(g);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var a=e[n],i=t[a[0]],o=t[a[1]];r[n]=[u(Math.min(i[0],o[0]),-1/0),u(Math.min(i[1],o[1]),-1/0),u(Math.max(i[0],o[0]),1/0),u(Math.max(i[1],o[1]),1/0)]}return r}(t,e),f=function(t,e,r){var n=[];return a(r,function(r,a){var o=e[r],s=e[a];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],h=t[s[1]];i(l,c,u,h)&&n.push([r,a])}}),n}(t,e,n),g=p(t),v=function(t,e,r,n){var o=[];return a(r,n,function(r,n){var a=e[r];if(a[0]!==n&&a[1]!==n){var s=t[n],l=t[a[0]],c=t[a[1]];i(l,c,s,s)&&o.push([r,n])}}),o}(t,e,n,g),y=d(t,function(t,e,r,n,a){var i,u,f=t.map(function(t){return[o(t[0]),o(t[1])]});for(i=0;i<r.length;++i){var p=r[i];u=p[0];var d=p[1],g=e[u],v=e[d],m=h(c(t[g[0]]),c(t[g[1]]),c(t[v[0]]),c(t[v[1]]));if(m){var y=t.length;t.push([l(m[0]),l(m[1])]),f.push(m),n.push([u,y],[d,y])}}for(n.sort(function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=f[t[1]],n=f[e[1]];return s(r[0],n[0])||s(r[1],n[1])}),i=n.length-1;i>=0;--i){var x=e[u=(S=n[i])[0]],b=x[0],_=x[1],w=t[b],k=t[_];if((w[0]-k[0]||w[1]-k[1])<0){var T=b;b=_,_=T}x[0]=b;var M,A=x[1]=S[1];for(a&&(M=x[2]);i>0&&n[i-1][0]===u;){var S,E=(S=n[--i])[1];a?e.push([A,E,M]):e.push([A,E]),A=E}a?e.push([A,_,M]):e.push([A,_])}return f}(t,e,f,v,r));return m(e,y,r),!!y||(f.length>0||v.length>0)}},{"./lib/rat-seg-intersect":119,"big-rat":80,"big-rat/cmp":78,"big-rat/to-float":92,"box-intersect":98,nextafter:452,"rat-vec":487,"robust-segment-intersect":511,"union-find":544}],119:[function(t,e,r){"use strict";e.exports=function(t,e,r,n){var i=s(e,t),h=s(n,r),f=u(i,h);if(0===o(f))return null;var p=s(t,r),d=u(h,p),g=a(d,f),v=c(i,g);return l(t,v)};var n=t("big-rat/mul"),a=t("big-rat/div"),i=t("big-rat/sub"),o=t("big-rat/sign"),s=t("rat-vec/sub"),l=t("rat-vec/add"),c=t("rat-vec/muls");function u(t,e){return i(n(t[0],e[1]),n(t[1],e[0]))}},{"big-rat/div":79,"big-rat/mul":89,"big-rat/sign":90,"big-rat/sub":91,"rat-vec/add":486,"rat-vec/muls":488,"rat-vec/sub":489}],120:[function(t,e,r){"use strict";var n=t("clamp");function a(t,e){null==e&&(e=!0);var r=t[0],a=t[1],i=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,a*=255,i*=255,o*=255),16777216*(r=255&n(r,0,255))+((a=255&n(a,0,255))<<16)+((i=255&n(i,0,255))<<8)+(o=255&n(o,0,255))}e.exports=a,e.exports.to=a,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,a=(65280&t)>>>8,i=255&t;return!1===e?[r,n,a,i]:[r/255,n/255,a/255,i/255]}},{clamp:117}],121:[function(t,e,r){"use strict";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],122:[function(t,e,r){"use strict";var n=t("color-rgba"),a=t("clamp"),i=t("dtype");e.exports=function(t,e){"float"!==e&&e||(e="array"),"uint"===e&&(e="uint8"),"uint_clamped"===e&&(e="uint8_clamped");var r=new(i(e))(4),o="uint8"!==e&&"uint8_clamped"!==e;return t.length&&"string"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=a(Math.floor(255*t[0]),0,255),r[1]=a(Math.floor(255*t[1]),0,255),r[2]=a(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:a(Math.floor(255*t[3]),0,255)),r)}},{clamp:117,"color-rgba":124,dtype:171}],123:[function(t,e,r){(function(r){"use strict";var n=t("color-name"),a=t("is-plain-obj"),i=t("defined");e.exports=function(t){var e,s,l=[],c=1;if("string"==typeof t)if(n[t])l=n[t].slice(),s="rgb";else if("transparent"===t)c=0,s="rgb",l=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var u=t.slice(1),h=u.length,f=h<=4;c=1,f?(l=[parseInt(u[0]+u[0],16),parseInt(u[1]+u[1],16),parseInt(u[2]+u[2],16)],4===h&&(c=parseInt(u[3]+u[3],16)/255)):(l=[parseInt(u[0]+u[1],16),parseInt(u[2]+u[3],16),parseInt(u[4]+u[5],16)],8===h&&(c=parseInt(u[6]+u[7],16)/255)),l[0]||(l[0]=0),l[1]||(l[1]=0),l[2]||(l[2]=0),s="rgb"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\s*\(([^\)]*)\)/.exec(t)){var p=e[1],d="rgb"===p,u=p.replace(/a$/,"");s=u;var h="cmyk"===u?4:"gray"===u?1:3;l=e[2].trim().split(/\s*,\s*/).map(function(t,e){if(/%$/.test(t))return e===h?parseFloat(t)/100:"rgb"===u?255*parseFloat(t)/100:parseFloat(t);if("h"===u[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==o[t])return o[t]}return parseFloat(t)}),p===u&&l.push(1),c=d?1:void 0===l[h]?1:l[h],l=l.slice(0,h)}else t.length>10&&/[0-9](?:\s|\/)/.test(t)&&(l=t.match(/([0-9]+)/g).map(function(t){return parseFloat(t)}),s=t.match(/([a-z])/gi).join("").toLowerCase());else if(isNaN(t))if(a(t)){var g=i(t.r,t.red,t.R,null);null!==g?(s="rgb",l=[g,i(t.g,t.green,t.G),i(t.b,t.blue,t.B)]):(s="hsl",l=[i(t.h,t.hue,t.H),i(t.s,t.saturation,t.S),i(t.l,t.lightness,t.L,t.b,t.brightness)]),c=i(t.a,t.alpha,t.opacity,1),null!=t.opacity&&(c/=100)}else(Array.isArray(t)||r.ArrayBuffer&&ArrayBuffer.isView&&ArrayBuffer.isView(t))&&(l=[t[0],t[1],t[2]],s="rgb",c=4===t.length?t[3]:1);else s="rgb",l=[t>>>16,(65280&t)>>>8,255&t];return{space:s,values:l,alpha:c}};var o={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"color-name":121,defined:166,"is-plain-obj":423}],124:[function(t,e,r){"use strict";var n=t("color-parse"),a=t("color-space/hsl"),i=t("clamp");e.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=i(r.values[0],0,255),e[1]=i(r.values[1],0,255),e[2]=i(r.values[2],0,255),"h"===r.space[0]&&(e=a.rgb(e)),e.push(i(r.alpha,0,1)),e):[]}},{clamp:117,"color-parse":123,"color-space/hsl":125}],125:[function(t,e,r){"use strict";var n=t("./rgb");e.exports={name:"hsl",min:[0,0,0],max:[360,100,100],channel:["hue","saturation","lightness"],alias:["HSL"],rgb:function(t){var e,r,n,a,i,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[i=255*l,i,i];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),a=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,i=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,a[c]=255*i;return a}},n.hsl=function(t){var e,r,n=t[0]/255,a=t[1]/255,i=t[2]/255,o=Math.min(n,a,i),s=Math.max(n,a,i),l=s-o;return s===o?e=0:n===s?e=(a-i)/l:a===s?e=2+(i-n)/l:i===s&&(e=4+(n-a)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{"./rgb":126}],126:[function(t,e,r){"use strict";e.exports={name:"rgb",min:[0,0,0],max:[255,255,255],channel:["red","green","blue"],alias:["RGB"]}},{}],127:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],cool:[{index:0,rgb:[0,255,255]},{index:1,rgb:[255,0,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],"rainbow-soft":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],"freesurface-blue":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],"freesurface-red":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],"velocity-blue":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],"velocity-green":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],128:[function(t,e,r){"use strict";var n=t("./colorScale"),a=t("lerp");function i(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r="#",n=0;n<3;++n)r+=("00"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return"rgba("+t.join(",")+")"}e.exports=function(t){var e,r,l,c,u,h,f,p,d,g;t||(t={});p=(t.nshades||72)-1,f=t.format||"hex",(h=t.colormap)||(h="jet");if("string"==typeof h){if(h=h.toLowerCase(),!n[h])throw Error(h+" not a supported colorscale");u=n[h]}else{if(!Array.isArray(h))throw Error("unsupported colormap option",h);u=h.slice()}if(u.length>p+1)throw new Error(h+" map requires nshades to be at least size "+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():"number"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map(function(t){return Math.round(t.index*p)}),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var v=u.map(function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1?n:(n[3]=d[0]+(d[1]-d[0])*r,n)}),m=[];for(g=0;g<e.length-1;++g){c=e[g+1]-e[g],r=v[g],l=v[g+1];for(var y=0;y<c;y++){var x=y/c;m.push([Math.round(a(r[0],l[0],x)),Math.round(a(r[1],l[1],x)),Math.round(a(r[2],l[2],x)),a(r[3],l[3],x)])}}m.push(u[u.length-1].rgb.concat(d[1])),"hex"===f?m=m.map(o):"rgbaString"===f?m=m.map(s):"float"===f&&(m=m.map(i));return m}},{"./colorScale":127,lerp:426}],129:[function(t,e,r){"use strict";e.exports=function(t,e,r,i){var o=n(e,r,i);if(0===o){var s=a(n(t,e,r)),c=a(n(t,e,i));if(s===c){if(0===s){var u=l(t,e,r),h=l(t,e,i);return u===h?0:u?1:-1}return 0}return 0===c?s>0?-1:l(t,e,i)?-1:1:0===s?c>0?1:l(t,e,r)?1:-1:a(c-s)}var f=n(t,e,r);if(f>0)return o>0&&n(t,e,i)>0?1:-1;if(f<0)return o>0||n(t,e,i)>0?1:-1;var p=n(t,e,i);return p>0?1:l(t,e,r)?1:-1};var n=t("robust-orientation"),a=t("signum"),i=t("two-sum"),o=t("robust-product"),s=t("robust-sum");function l(t,e,r){var n=i(t[0],-e[0]),a=i(t[1],-e[1]),l=i(r[0],-e[0]),c=i(r[1],-e[1]),u=s(o(n,l),o(a,c));return u[u.length-1]>=0}},{"robust-orientation":508,"robust-product":509,"robust-sum":513,signum:514,"two-sum":542}],130:[function(t,e,r){e.exports=function(t,e){var r=t.length,i=t.length-e.length;if(i)return i;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(i=o+t[2]-(s+e[2]))return i;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],h=t[1],f=t[2],p=t[3],d=e[0],g=e[1],v=e[2],m=e[3];return u+h+f+p-(d+g+v+m)||n(u,h,f,p)-n(d,g,v,m,d)||n(u+h,u+f,u+p,h+f,h+p,f+p)-n(d+g,d+v,d+m,g+v,g+m,v+m)||n(u+h+f,u+h+p,u+f+p,h+f+p)-n(d+g+v,d+g+m,d+v+m,g+v+m);default:for(var y=t.slice().sort(a),x=e.slice().sort(a),b=0;b<r;++b)if(i=y[b]-x[b])return i;return 0}};var n=Math.min;function a(t,e){return t-e}},{}],131:[function(t,e,r){"use strict";var n=t("compare-cell"),a=t("cell-orientation");e.exports=function(t,e){return n(t,e)||a(t)-a(e)}},{"cell-orientation":114,"compare-cell":130}],132:[function(t,e,r){"use strict";var n=t("./lib/ch1d"),a=t("./lib/ch2d"),i=t("./lib/chnd");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return a(t);return i(t,r)}},{"./lib/ch1d":133,"./lib/ch2d":134,"./lib/chnd":135}],133:[function(t,e,r){"use strict";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],134:[function(t,e,r){"use strict";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var a=new Array(r),i=e[r-1],o=0;o<r;++o){var s=e[o];a[o]=[i,s],i=s}return a};var n=t("monotone-convex-hull-2d")},{"monotone-convex-hull-2d":435}],135:[function(t,e,r){"use strict";e.exports=function(t,e){try{return n(t,!0)}catch(s){var r=a(t);if(r.length<=e)return[];var i=function(t,e){for(var r=t.length,n=new Array(r),a=0;a<e.length;++a)n[a]=t[e[a]];for(var i=e.length,a=0;a<r;++a)e.indexOf(a)<0&&(n[i++]=t[a]);return n}(t,r),o=n(i,!0);return function(t,e){for(var r=t.length,n=e.length,a=0;a<r;++a)for(var i=t[a],o=0;o<i.length;++o){var s=i[o];if(s<n)i[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);i[o]=s}}return t}(o,r)}};var n=t("incremental-convex-hull"),a=t("affine-hull")},{"affine-hull":65,"incremental-convex-hull":414}],136:[function(t,e,r){e.exports={AFG:"afghan",ALA:"\\b\\wland",ALB:"albania",DZA:"algeria",ASM:"^(?=.*americ).*samoa",AND:"andorra",AGO:"angola",AIA:"anguill?a",ATA:"antarctica",ATG:"antigua",ARG:"argentin",ARM:"armenia",ABW:"^(?!.*bonaire).*\\baruba",AUS:"australia",AUT:"^(?!.*hungary).*austria|\\baustri.*\\bemp",AZE:"azerbaijan",BHS:"bahamas",BHR:"bahrain",BGD:"bangladesh|^(?=.*east).*paki?stan",BRB:"barbados",BLR:"belarus|byelo",BEL:"^(?!.*luxem).*belgium",BLZ:"belize|^(?=.*british).*honduras",BEN:"benin|dahome",BMU:"bermuda",BTN:"bhutan",BOL:"bolivia",BES:"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\bbes.?islands",BIH:"herzegovina|bosnia",BWA:"botswana|bechuana",BVT:"bouvet",BRA:"brazil",IOT:"british.?indian.?ocean",BRN:"brunei",BGR:"bulgaria",BFA:"burkina|\\bfaso|upper.?volta",BDI:"burundi",CPV:"verde",KHM:"cambodia|kampuchea|khmer",CMR:"cameroon",CAN:"canada",CYM:"cayman",CAF:"\\bcentral.african.republic",TCD:"\\bchad",CHL:"\\bchile",CHN:"^(?!.*\\bmac)(?!.*\\bhong)(?!.*\\btai)(?!.*\\brep).*china|^(?=.*peo)(?=.*rep).*china",CXR:"christmas",CCK:"\\bcocos|keeling",COL:"colombia",COM:"comoro",COG:"^(?!.*\\bdem)(?!.*\\bd[\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\bcongo",COK:"\\bcook",CRI:"costa.?rica",CIV:"ivoire|ivory",HRV:"croatia",CUB:"\\bcuba",CUW:"^(?!.*bonaire).*\\bcura(c|\xe7)ao",CYP:"cyprus",CSK:"czechoslovakia",CZE:"^(?=.*rep).*czech|czechia|bohemia",COD:"\\bdem.*congo|congo.*\\bdem|congo.*\\bd[\\.]?r|\\bd[\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc",DNK:"denmark",DJI:"djibouti",DMA:"dominica(?!n)",DOM:"dominican.rep",ECU:"ecuador",EGY:"egypt",SLV:"el.?salvador",GNQ:"guine.*eq|eq.*guine|^(?=.*span).*guinea",ERI:"eritrea",EST:"estonia",ETH:"ethiopia|abyssinia",FLK:"falkland|malvinas",FRO:"faroe|faeroe",FJI:"fiji",FIN:"finland",FRA:"^(?!.*\\bdep)(?!.*martinique).*france|french.?republic|\\bgaul",GUF:"^(?=.*french).*guiana",PYF:"french.?polynesia|tahiti",ATF:"french.?southern",GAB:"gabon",GMB:"gambia",GEO:"^(?!.*south).*georgia",DDR:"german.?democratic.?republic|democratic.?republic.*germany|east.germany",DEU:"^(?!.*east).*germany|^(?=.*\\bfed.*\\brep).*german",GHA:"ghana|gold.?coast",GIB:"gibraltar",GRC:"greece|hellenic|hellas",GRL:"greenland",GRD:"grenada",GLP:"guadeloupe",GUM:"\\bguam",GTM:"guatemala",GGY:"guernsey",GIN:"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea",GNB:"bissau|^(?=.*portu).*guinea",GUY:"guyana|british.?guiana",HTI:"haiti",HMD:"heard.*mcdonald",VAT:"holy.?see|vatican|papal.?st",HND:"^(?!.*brit).*honduras",HKG:"hong.?kong",HUN:"^(?!.*austr).*hungary",ISL:"iceland",IND:"india(?!.*ocea)",IDN:"indonesia",IRN:"\\biran|persia",IRQ:"\\biraq|mesopotamia",IRL:"(^ireland)|(^republic.*ireland)",IMN:"^(?=.*isle).*\\bman",ISR:"israel",ITA:"italy",JAM:"jamaica",JPN:"japan",JEY:"jersey",JOR:"jordan",KAZ:"kazak",KEN:"kenya|british.?east.?africa|east.?africa.?prot",KIR:"kiribati",PRK:"^(?=.*democrat|people|north|d.*p.*.r).*\\bkorea|dprk|korea.*(d.*p.*r)",KWT:"kuwait",KGZ:"kyrgyz|kirghiz",LAO:"\\blaos?\\b",LVA:"latvia",LBN:"lebanon",LSO:"lesotho|basuto",LBR:"liberia",LBY:"libya",LIE:"liechtenstein",LTU:"lithuania",LUX:"^(?!.*belg).*luxem",MAC:"maca(o|u)",MDG:"madagascar|malagasy",MWI:"malawi|nyasa",MYS:"malaysia",MDV:"maldive",MLI:"\\bmali\\b",MLT:"\\bmalta",MHL:"marshall",MTQ:"martinique",MRT:"mauritania",MUS:"mauritius",MYT:"\\bmayotte",MEX:"\\bmexic",FSM:"fed.*micronesia|micronesia.*fed",MCO:"monaco",MNG:"mongolia",MNE:"^(?!.*serbia).*montenegro",MSR:"montserrat",MAR:"morocco|\\bmaroc",MOZ:"mozambique",MMR:"myanmar|burma",NAM:"namibia",NRU:"nauru",NPL:"nepal",NLD:"^(?!.*\\bant)(?!.*\\bcarib).*netherlands",ANT:"^(?=.*\\bant).*(nether|dutch)",NCL:"new.?caledonia",NZL:"new.?zealand",NIC:"nicaragua",NER:"\\bniger(?!ia)",NGA:"nigeria",NIU:"niue",NFK:"norfolk",MNP:"mariana",NOR:"norway",OMN:"\\boman|trucial",PAK:"^(?!.*east).*paki?stan",PLW:"palau",PSE:"palestin|\\bgaza|west.?bank",PAN:"panama",PNG:"papua|new.?guinea",PRY:"paraguay",PER:"peru",PHL:"philippines",PCN:"pitcairn",POL:"poland",PRT:"portugal",PRI:"puerto.?rico",QAT:"qatar",KOR:"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\bkorea(?!.*d.*p.*r)",MDA:"moldov|b(a|e)ssarabia",REU:"r(e|\xe9)union",ROU:"r(o|u|ou)mania",RUS:"\\brussia|soviet.?union|u\\.?s\\.?s\\.?r|socialist.?republics",RWA:"rwanda",BLM:"barth(e|\xe9)lemy",SHN:"helena",KNA:"kitts|\\bnevis",LCA:"\\blucia",MAF:"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)",SPM:"miquelon",VCT:"vincent",WSM:"^(?!.*amer).*samoa",SMR:"san.?marino",STP:"\\bs(a|\xe3)o.?tom(e|\xe9)",SAU:"\\bsa\\w*.?arabia",SEN:"senegal",SRB:"^(?!.*monte).*serbia",SYC:"seychell",SLE:"sierra",SGP:"singapore",SXM:"^(?!.*martin)(?!.*saba).*maarten",SVK:"^(?!.*cze).*slovak",SVN:"slovenia",SLB:"solomon",SOM:"somali",ZAF:"south.africa|s\\\\..?africa",SGS:"south.?georgia|sandwich",SSD:"\\bs\\w*.?sudan",ESP:"spain",LKA:"sri.?lanka|ceylon",SDN:"^(?!.*\\bs(?!u)).*sudan",SUR:"surinam|dutch.?guiana",SJM:"svalbard",SWZ:"swaziland",SWE:"sweden",CHE:"switz|swiss",SYR:"syria",TWN:"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china",TJK:"tajik",THA:"thailand|\\bsiam",MKD:"macedonia|fyrom",TLS:"^(?=.*leste).*timor|^(?=.*east).*timor",TGO:"togo",TKL:"tokelau",TON:"tonga",TTO:"trinidad|tobago",TUN:"tunisia",TUR:"turkey",TKM:"turkmen",TCA:"turks",TUV:"tuvalu",UGA:"uganda",UKR:"ukrain",ARE:"emirates|^u\\.?a\\.?e\\.?$|united.?arab.?em",GBR:"united.?kingdom|britain|^u\\.?k\\.?$",TZA:"tanzania",USA:"united.?states\\b(?!.*islands)|\\bu\\.?s\\.?a\\.?\\b|^\\s*u\\.?s\\.?\\b(?!.*islands)",UMI:"minor.?outlying.?is",URY:"uruguay",UZB:"uzbek",VUT:"vanuatu|new.?hebrides",VEN:"venezuela",VNM:"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam",VGB:"^(?=.*\\bu\\.?\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin",VIR:"^(?=.*\\bu\\.?\\s?s).*virgin|^(?=.*states).*virgin",WLF:"futuna|wallis",ESH:"western.sahara",YEM:"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\bp\\.?d\\.?r).*yemen",YMD:"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\bp\\.?d\\.?r).*yemen",YUG:"yugoslavia",ZMB:"zambia|northern.?rhodesia",EAZ:"zanzibar",ZWE:"zimbabwe|^(?!.*northern).*rhodesia"}},{}],137:[function(t,e,r){e.exports=["xx-small","x-small","small","medium","large","x-large","xx-large","larger","smaller"]},{}],138:[function(t,e,r){e.exports=["normal","condensed","semi-condensed","extra-condensed","ultra-condensed","expanded","semi-expanded","extra-expanded","ultra-expanded"]},{}],139:[function(t,e,r){e.exports=["normal","italic","oblique"]},{}],140:[function(t,e,r){e.exports=["normal","bold","bolder","lighter","100","200","300","400","500","600","700","800","900"]},{}],141:[function(t,e,r){"use strict";e.exports={parse:t("./parse"),stringify:t("./stringify")}},{"./parse":143,"./stringify":144}],142:[function(t,e,r){"use strict";var n=t("css-font-size-keywords");e.exports={isSize:function(t){return/^[\d\.]/.test(t)||-1!==t.indexOf("/")||-1!==n.indexOf(t)}}},{"css-font-size-keywords":137}],143:[function(t,e,r){"use strict";var n=t("unquote"),a=t("css-global-keywords"),i=t("css-system-font-keywords"),o=t("css-font-weight-keywords"),s=t("css-font-style-keywords"),l=t("css-font-stretch-keywords"),c=t("string-split-by"),u=t("./lib/util").isSize;e.exports=f;var h=f.cache={};function f(t){if("string"!=typeof t)throw new Error("Font argument must be a string.");if(h[t])return h[t];if(""===t)throw new Error("Cannot parse an empty string.");if(-1!==i.indexOf(t))return h[t]={system:t};for(var e,r={style:"normal",variant:"normal",weight:"normal",stretch:"normal",lineHeight:"normal",size:"1rem",family:["serif"]},f=c(t,/\s+/);e=f.shift();){if(-1!==a.indexOf(e))return["style","variant","weight","stretch"].forEach(function(t){r[t]=e}),h[t]=r;if(-1===s.indexOf(e))if("normal"!==e&&"small-caps"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,"/");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):"/"===f[0]&&(f.shift(),r.lineHeight=p(f.shift())),!f.length)throw new Error("Missing required font-family.");return r.family=c(f.join(" "),/\s*,\s*/).map(n),h[t]=r}throw new Error("Unknown or unsupported font token: "+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error("Missing required font-size.")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{"./lib/util":142,"css-font-stretch-keywords":138,"css-font-style-keywords":139,"css-font-weight-keywords":140,"css-global-keywords":145,"css-system-font-keywords":146,"string-split-by":527,unquote:546}],144:[function(t,e,r){"use strict";var n=t("pick-by-alias"),a=t("./lib/util").isSize,i=g(t("css-global-keywords")),o=g(t("css-system-font-keywords")),s=g(t("css-font-weight-keywords")),l=g(t("css-font-style-keywords")),c=g(t("css-font-stretch-keywords")),u={normal:1,"small-caps":1},h={serif:1,"sans-serif":1,monospace:1,cursive:1,fantasy:1,"system-ui":1},f="1rem",p="serif";function d(t,e){if(t&&!e[t]&&!i[t])throw Error("Unknown keyword `"+t+"`");return t}function g(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:"style fontstyle fontStyle font-style slope distinction",variant:"variant font-variant fontVariant fontvariant var capitalization",weight:"weight w font-weight fontWeight fontweight",stretch:"stretch font-stretch fontStretch fontstretch width",size:"size s font-size fontSize fontsize height em emSize",lineHeight:"lh line-height lineHeight lineheight leading",family:"font family fontFamily font-family fontfamily type typeface face",system:"system reserved default global"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=f),"number"==typeof t.size&&(t.size+="px"),!a)throw Error("Bad size value `"+t.size+"`");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map(function(t){return h[t]?t:'"'+t+'"'}).join(", "));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||"normal"===t.lineHeight||t.lineHeight+""=="1"?"":"/"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(" ")}},{"./lib/util":142,"css-font-stretch-keywords":138,"css-font-style-keywords":139,"css-font-weight-keywords":140,"css-global-keywords":145,"css-system-font-keywords":146,"pick-by-alias":466}],145:[function(t,e,r){e.exports=["inherit","initial","unset"]},{}],146:[function(t,e,r){e.exports=["caption","icon","menu","message-box","small-caption","status-bar"]},{}],147:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a,i){var o=a-1,s=a*a,l=o*o,c=(1+2*a)*l,u=a*l,h=s*(3-2*a),f=s*o;if(t.length){i||(i=new Array(t.length));for(var p=t.length-1;p>=0;--p)i[p]=c*t[p]+u*e[p]+h*r[p]+f*n[p];return i}return c*t+u*e+h*r+f*n},e.exports.derivative=function(t,e,r,n,a,i){var o=6*a*a-6*a,s=3*a*a-4*a+1,l=-6*a*a+6*a,c=3*a*a-2*a;if(t.length){i||(i=new Array(t.length));for(var u=t.length-1;u>=0;--u)i[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return i}return o*t+s*e+l*r[u]+c*n}},{}],148:[function(t,e,r){"use strict";var n=t("./lib/thunk.js");function a(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName="",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new a;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var i=0;i<r.length;++i){var o=r[i];if("array"===o||"object"==typeof o&&o.blockIndices){if(e.argTypes[i]="array",e.arrayArgs.push(i),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push("array"+i),i<e.pre.args.length&&e.pre.args[i].count>0)throw new Error("cwise: pre() block may not reference array args");if(i<e.post.args.length&&e.post.args[i].count>0)throw new Error("cwise: post() block may not reference array args")}else if("scalar"===o)e.scalarArgs.push(i),e.shimArgs.push("scalar"+i);else if("index"===o){if(e.indexArgs.push(i),i<e.pre.args.length&&e.pre.args[i].count>0)throw new Error("cwise: pre() block may not reference array index");if(i<e.body.args.length&&e.body.args[i].lvalue)throw new Error("cwise: body() block may not write to array index");if(i<e.post.args.length&&e.post.args[i].count>0)throw new Error("cwise: post() block may not reference array index")}else if("shape"===o){if(e.shapeArgs.push(i),i<e.pre.args.length&&e.pre.args[i].lvalue)throw new Error("cwise: pre() block may not write to array shape");if(i<e.body.args.length&&e.body.args[i].lvalue)throw new Error("cwise: body() block may not write to array shape");if(i<e.post.args.length&&e.post.args[i].lvalue)throw new Error("cwise: post() block may not write to array shape")}else{if("object"!=typeof o||!o.offset)throw new Error("cwise: Unknown argument type "+r[i]);e.argTypes[i]="offset",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(i)}}if(e.arrayArgs.length<=0)throw new Error("cwise: No array arguments specified");if(e.pre.args.length>r.length)throw new Error("cwise: Too many arguments in pre() block");if(e.body.args.length>r.length)throw new Error("cwise: Too many arguments in body() block");if(e.post.args.length>r.length)throw new Error("cwise: Too many arguments in post() block");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||"cwise",e.blockSize=t.blockSize||64,n(e)}},{"./lib/thunk.js":150}],149:[function(t,e,r){"use strict";var n=t("uniq");function a(t,e,r){var n,a,i=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,h=0;for(n=0;n<i;++n)c.push(["i",n,"=0"].join(""));for(a=0;a<o;++a)for(n=0;n<i;++n)h=u,u=t[n],0===n?c.push(["d",a,"s",n,"=t",a,"p",u].join("")):c.push(["d",a,"s",n,"=(t",a,"p",u,"-s",h,"*t",a,"p",h,")"].join(""));for(c.length>0&&l.push("var "+c.join(",")),n=i-1;n>=0;--n)u=t[n],l.push(["for(i",n,"=0;i",n,"<s",u,";++i",n,"){"].join(""));for(l.push(r),n=0;n<i;++n){for(h=u,u=t[n],a=0;a<o;++a)l.push(["p",a,"+=d",a,"s",n].join(""));s&&(n>0&&l.push(["index[",h,"]-=s",h].join("")),l.push(["++index[",u,"]"].join(""))),l.push("}")}return l.join("\n")}function i(t,e,r){for(var n=t.body,a=[],i=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,"g"),c="",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case"offset":var h=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[h].array,c="+q"+h;case"array":c="p"+u+c;var f="l"+o,p="a"+u;if(0===e.arrayBlockIndices[u])1===s.count?"generic"===r[u]?s.lvalue?(a.push(["var ",f,"=",p,".get(",c,")"].join("")),n=n.replace(l,f),i.push([p,".set(",c,",",f,")"].join(""))):n=n.replace(l,[p,".get(",c,")"].join("")):n=n.replace(l,[p,"[",c,"]"].join("")):"generic"===r[u]?(a.push(["var ",f,"=",p,".get(",c,")"].join("")),n=n.replace(l,f),s.lvalue&&i.push([p,".set(",c,",",f,")"].join(""))):(a.push(["var ",f,"=",p,"[",c,"]"].join("")),n=n.replace(l,f),s.lvalue&&i.push([p,"[",c,"]=",f].join("")));else{for(var d=[s.name],g=[c],v=0;v<Math.abs(e.arrayBlockIndices[u]);v++)d.push("\\s*\\[([^\\]]+)\\]"),g.push("$"+(v+1)+"*t"+u+"b"+v);if(l=new RegExp(d.join(""),"g"),c=g.join("+"),"generic"===r[u])throw new Error("cwise: Generic arrays not supported in combination with blocks!");n=n.replace(l,[p,"[",c,"]"].join(""))}break;case"scalar":n=n.replace(l,"Y"+e.scalarArgs.indexOf(o));break;case"index":n=n.replace(l,"index");break;case"shape":n=n.replace(l,"shape")}}}return[a.join("\n"),n,i.join("\n")].join("\n").trim()}function o(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var a=t[n],i=a.match(/\d+/);i=i?i[0]:"",0===a.charAt(0)?e[n]="u"+a.charAt(1)+i:e[n]=a.charAt(0)+i,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join("")}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,s=new Array(t.arrayArgs.length),l=new Array(t.arrayArgs.length),c=0;c<t.arrayArgs.length;++c)l[c]=e[2*c],s[c]=e[2*c+1];var u=[],h=[],f=[],p=[],d=[];for(c=0;c<t.arrayArgs.length;++c){t.arrayBlockIndices[c]<0?(f.push(0),p.push(r),u.push(r),h.push(r+t.arrayBlockIndices[c])):(f.push(t.arrayBlockIndices[c]),p.push(t.arrayBlockIndices[c]+r),u.push(0),h.push(t.arrayBlockIndices[c]));for(var g=[],v=0;v<s[c].length;v++)f[c]<=s[c][v]&&s[c][v]<p[c]&&g.push(s[c][v]-f[c]);d.push(g)}var m=["SS"],y=["'use strict'"],x=[];for(v=0;v<r;++v)x.push(["s",v,"=SS[",v,"]"].join(""));for(c=0;c<t.arrayArgs.length;++c){for(m.push("a"+c),m.push("t"+c),m.push("p"+c),v=0;v<r;++v)x.push(["t",c,"p",v,"=t",c,"[",f[c]+v,"]"].join(""));for(v=0;v<Math.abs(t.arrayBlockIndices[c]);++v)x.push(["t",c,"b",v,"=t",c,"[",u[c]+v,"]"].join(""))}for(c=0;c<t.scalarArgs.length;++c)m.push("Y"+c);if(t.shapeArgs.length>0&&x.push("shape=SS.slice(0)"),t.indexArgs.length>0){var b=new Array(r);for(c=0;c<r;++c)b[c]="0";x.push(["index=[",b.join(","),"]"].join(""))}for(c=0;c<t.offsetArgs.length;++c){var _=t.offsetArgs[c],w=[];for(v=0;v<_.offset.length;++v)0!==_.offset[v]&&(1===_.offset[v]?w.push(["t",_.array,"p",v].join("")):w.push([_.offset[v],"*t",_.array,"p",v].join("")));0===w.length?x.push("q"+c+"=0"):x.push(["q",c,"=",w.join("+")].join(""))}var k=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((x=x.concat(k)).length>0&&y.push("var "+x.join(",")),c=0;c<t.arrayArgs.length;++c)y.push("p"+c+"|=0");t.pre.body.length>3&&y.push(i(t.pre,t,l));var T=i(t.body,t,l),M=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(d);M<r?y.push(function(t,e,r,n){for(var i=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push(["var offset",u,"=p",u].join(""));for(u=t;u<i;++u)c.push(["for(var j"+u+"=SS[",e[u],"]|0;j",u,">0;){"].join("")),c.push(["if(j",u,"<",s,"){"].join("")),c.push(["s",e[u],"=j",u].join("")),c.push(["j",u,"=0"].join("")),c.push(["}else{s",e[u],"=",s].join("")),c.push(["j",u,"-=",s,"}"].join("")),l&&c.push(["index[",e[u],"]=j",u].join(""));for(u=0;u<o;++u){for(var h=["offset"+u],f=t;f<i;++f)h.push(["j",f,"*t",u,"p",e[f]].join(""));c.push(["p",u,"=(",h.join("+"),")"].join(""))}for(c.push(a(e,r,n)),u=t;u<i;++u)c.push("}");return c.join("\n")}(M,d[0],t,T)):y.push(a(d[0],t,T)),t.post.body.length>3&&y.push(i(t.post,t,l)),t.debug&&console.log("-----Generated cwise routine for ",e,":\n"+y.join("\n")+"\n----------");var A=[t.funcName||"unnamed","_cwise_loop_",s[0].join("s"),"m",M,o(l)].join("");return new Function(["function ",A,"(",m.join(","),"){",y.join("\n"),"} return ",A].join(""))()}},{uniq:545}],150:[function(t,e,r){"use strict";var n=t("./compile.js");e.exports=function(t){var e=["'use strict'","var CACHED={}"],r=[],a=t.funcName+"_cwise_thunk";e.push(["return function ",a,"(",t.shimArgs.join(","),"){"].join(""));for(var i=[],o=[],s=[["array",t.arrayArgs[0],".shape.slice(",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?","+t.arrayBlockIndices[0]+")":")"].join("")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var h=t.arrayArgs[u];r.push(["t",h,"=array",h,".dtype,","r",h,"=array",h,".order"].join("")),i.push("t"+h),i.push("r"+h),o.push("t"+h),o.push("r"+h+".join()"),s.push("array"+h+".data"),s.push("array"+h+".stride"),s.push("array"+h+".offset|0"),u>0&&(l.push("array"+t.arrayArgs[0]+".shape.length===array"+h+".shape.length+"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push("array"+t.arrayArgs[0]+".shape[shapeIndex+"+Math.max(0,t.arrayBlockIndices[0])+"]===array"+h+".shape[shapeIndex+"+Math.max(0,t.arrayBlockIndices[u])+"]"))}for(t.arrayArgs.length>1&&(e.push("if (!("+l.join(" && ")+")) throw new Error('cwise: Arrays do not all have the same dimensionality!')"),e.push("for(var shapeIndex=array"+t.arrayArgs[0]+".shape.length-"+Math.abs(t.arrayBlockIndices[0])+"; shapeIndex--\x3e0;) {"),e.push("if (!("+c.join(" && ")+")) throw new Error('cwise: Arrays do not all have the same shape!')"),e.push("}")),u=0;u<t.scalarArgs.length;++u)s.push("scalar"+t.scalarArgs[u]);return r.push(["type=[",o.join(","),"].join()"].join("")),r.push("proc=CACHED[type]"),e.push("var "+r.join(",")),e.push(["if(!proc){","CACHED[type]=proc=compile([",i.join(","),"])}","return proc(",s.join(","),")}"].join("")),t.debug&&console.log("-----Generated thunk:\n"+e.join("\n")+"\n----------"),new Function("compile",e.join("\n"))(n.bind(void 0,t))}},{"./compile.js":149}],151:[function(t,e,r){e.exports=t("cwise-compiler")},{"cwise-compiler":148}],152:[function(t,e,r){"use strict";var n,a=t("es5-ext/object/copy"),i=t("es5-ext/object/normalize-options"),o=t("es5-ext/object/valid-callable"),s=t("es5-ext/object/map"),l=t("es5-ext/object/valid-callable"),c=t("es5-ext/object/valid-value"),u=Function.prototype.bind,h=Object.defineProperty,f=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,i=c(e)&&l(e.value);return delete(n=a(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&f.call(this,t)?i:(e.value=u.call(i,r.resolveContext?r.resolveContext(this):this),h(this,t,e),this[t])},n},e.exports=function(t){var e=i(arguments[1]);return null!=e.resolveContext&&o(e.resolveContext),s(t,function(t,r){return n(r,t,e)})}},{"es5-ext/object/copy":192,"es5-ext/object/map":201,"es5-ext/object/normalize-options":202,"es5-ext/object/valid-callable":206,"es5-ext/object/valid-value":208}],153:[function(t,e,r){"use strict";var n=t("es5-ext/object/assign"),a=t("es5-ext/object/normalize-options"),i=t("es5-ext/object/is-callable"),o=t("es5-ext/string/#/contains");(e.exports=function(t,e){var r,i,s,l,c;return arguments.length<2||"string"!=typeof t?(l=e,e=t,t=null):l=arguments[2],null==t?(r=s=!0,i=!1):(r=o.call(t,"c"),i=o.call(t,"e"),s=o.call(t,"w")),c={value:e,configurable:r,enumerable:i,writable:s},l?n(a(l),c):c}).gs=function(t,e,r){var s,l,c,u;return"string"!=typeof t?(c=r,r=e,e=t,t=null):c=arguments[3],null==e?e=void 0:i(e)?null==r?r=void 0:i(r)||(c=r,r=void 0):(c=e,e=r=void 0),null==t?(s=!0,l=!1):(s=o.call(t,"c"),l=o.call(t,"e")),u={get:e,set:r,configurable:s,enumerable:l},c?n(a(c),u):u}},{"es5-ext/object/assign":189,"es5-ext/object/is-callable":195,"es5-ext/object/normalize-options":202,"es5-ext/string/#/contains":209}],154:[function(t,e,r){var n;n=this,function(t){"use strict";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,a){for(null==n&&(n=0),null==a&&(a=e.length);n<a;){var i=n+a>>>1;t(e[i],r)<0?n=i+1:a=i}return n},right:function(e,r,n,a){for(null==n&&(n=0),null==a&&(a=e.length);n<a;){var i=n+a>>>1;t(e[i],r)>0?a=i:n=i+1}return n}}}var n=r(e),a=n.right,i=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,a=t.length,i=0,o=-1,l=0,c=0;if(null==e)for(;++o<a;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++i)));else for(;++o<a;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++i)));if(i>1)return c/(i-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,a,i=t.length,o=-1;if(null==e){for(;++o<i;)if(null!=(r=t[o])&&r>=r)for(n=a=r;++o<i;)null!=(r=t[o])&&(n>r&&(n=r),a<r&&(a=r))}else for(;++o<i;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=a=r;++o<i;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),a<r&&(a=r));return[n,a]}var h=Array.prototype,f=h.slice,p=h.map;function d(t){return function(){return t}}function g(t){return t}function v(t,e,r){t=+t,e=+e,r=(a=arguments.length)<2?(e=t,t=0,1):a<3?1:+r;for(var n=-1,a=0|Math.max(0,Math.ceil((e-t)/r)),i=new Array(a);++n<a;)i[n]=t+n*r;return i}var m=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),a=Math.floor(Math.log(n)/Math.LN10),i=n/Math.pow(10,a);return a>=0?(i>=m?10:i>=y?5:i>=x?2:1)*Math.pow(10,a):-Math.pow(10,-a)/(i>=m?10:i>=y?5:i>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),a=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),i=n/a;return i>=m?a*=10:i>=y?a*=5:i>=x&&(a*=2),e<t?-a:a}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function k(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,a=(n-1)*e,i=Math.floor(a),o=+r(t[i],i,t);return o+(+r(t[i+1],i+1,t)-o)*(a-i)}}function T(t,e){var r,n,a=t.length,i=-1;if(null==e){for(;++i<a;)if(null!=(r=t[i])&&r>=r)for(n=r;++i<a;)null!=(r=t[i])&&n>r&&(n=r)}else for(;++i<a;)if(null!=(r=e(t[i],i,t))&&r>=r)for(n=r;++i<a;)null!=(r=e(t[i],i,t))&&n>r&&(n=r);return n}function M(t){if(!(a=t.length))return[];for(var e=-1,r=T(t,A),n=new Array(r);++e<r;)for(var a,i=-1,o=n[e]=new Array(a);++i<a;)o[i]=t[i][e];return n}function A(t){return t.length}t.bisect=a,t.bisectRight=a,t.bisectLeft=i,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,a,i,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=i=0;n<l;++n)for(s=t[n],a=0;a<c;++a,++i)u[i]=r(s,e[a]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=g,e=u,r=w;function n(n){var i,o,s=n.length,l=new Array(s);for(i=0;i<s;++i)l[i]=t(n[i],i,n);var c=e(l),u=c[0],h=c[1],f=r(l,u,h);Array.isArray(f)||(f=_(u,h,f),f=v(Math.ceil(u/f)*f,h,f));for(var p=f.length;f[0]<=u;)f.shift(),--p;for(;f[p-1]>h;)f.pop(),--p;var d,g=new Array(p+1);for(i=0;i<=p;++i)(d=g[i]=[]).x0=i>0?f[i-1]:u,d.x1=i<p?f[i]:h;for(i=0;i<s;++i)u<=(o=l[i])&&o<=h&&g[a(f,o,0,p)].push(n[i]);return g}return n.value=function(e){return arguments.length?(t="function"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e="function"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r="function"==typeof t?t:Array.isArray(t)?d(f.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(k(t,.75)-k(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,a=t.length,i=-1;if(null==e){for(;++i<a;)if(null!=(r=t[i])&&r>=r)for(n=r;++i<a;)null!=(r=t[i])&&r>n&&(n=r)}else for(;++i<a;)if(null!=(r=e(t[i],i,t))&&r>=r)for(n=r;++i<a;)null!=(r=e(t[i],i,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,a=n,i=-1,o=0;if(null==e)for(;++i<n;)isNaN(r=s(t[i]))?--a:o+=r;else for(;++i<n;)isNaN(r=s(e(t[i],i,t)))?--a:o+=r;if(a)return o/a},t.median=function(t,r){var n,a=t.length,i=-1,o=[];if(null==r)for(;++i<a;)isNaN(n=s(t[i]))||o.push(n);else for(;++i<a;)isNaN(n=s(r(t[i],i,t)))||o.push(n);return k(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,a=t.length,i=-1,o=0;++i<a;)o+=t[i].length;for(r=new Array(o);--a>=0;)for(e=(n=t[a]).length;--e>=0;)r[--o]=n[e];return r},t.min=T,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,a=t[0],i=new Array(n<0?0:n);r<n;)i[r]=e(a,a=t[++r]);return i},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=k,t.range=v,t.scan=function(t,r){if(n=t.length){var n,a,i=0,o=0,s=t[o];for(null==r&&(r=e);++i<n;)(r(a=t[i],s)<0||0!==r(s,s))&&(s=a,o=i);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,a,i=(null==r?t.length:r)-(e=null==e?0:+e);i;)a=Math.random()*i--|0,n=t[i+e],t[i+e]=t[a+e],t[a+e]=n;return t},t.sum=function(t,e){var r,n=t.length,a=-1,i=0;if(null==e)for(;++a<n;)(r=+t[a])&&(i+=r);else for(;++a<n;)(r=+e(t[a],a,t))&&(i+=r);return i},t.ticks=function(t,e,r){var n,a,i,o,s=-1;if(r=+r,(t=+t)==(e=+e)&&r>0)return[t];if((n=e<t)&&(a=t,t=e,e=a),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),i=new Array(a=Math.ceil(e-t+1));++s<a;)i[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),i=new Array(a=Math.ceil(t-e+1));++s<a;)i[s]=(t-s)/o;return n&&i.reverse(),i},t.tickIncrement=b,t.tickStep=_,t.transpose=M,t.variance=l,t.zip=function(){return M(arguments)},Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:n.d3=n.d3||{})},{}],155:[function(t,e,r){var n;n=this,function(t){"use strict";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each(function(t,e){n.set(e,t)});else if(Array.isArray(t)){var a,i=-1,o=t.length;if(null==r)for(;++i<o;)n.set(i,t[i]);else for(;++i<o;)n.set(r(a=t[i],i,t),a)}else if(t)for(var s in t)n.set(s,t[s]);return n}function n(){return{}}function a(t,e,r){t[e]=r}function i(){return r()}function o(t,e,r){t.set(e,r)}function s(){}e.prototype=r.prototype={constructor:e,has:function(t){return"$"+t in this},get:function(t){return this["$"+t]},set:function(t,e){return this["$"+t]=e,this},remove:function(t){var e="$"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)"$"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)"$"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)"$"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)"$"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)"$"===e[0]&&++t;return t},empty:function(){for(var t in this)if("$"===t[0])return!1;return!0},each:function(t){for(var e in this)"$"===e[0]&&t(this[e],e.slice(1),this)}};var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each(function(t){r.add(t)});else if(t){var n=-1,a=t.length;if(null==e)for(;++n<a;)r.add(t[n]);else for(;++n<a;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this["$"+(t+="")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each},t.nest=function(){var t,e,s,l=[],c=[];function u(n,a,i,o){if(a>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,h,f=-1,p=n.length,d=l[a++],g=r(),v=i();++f<p;)(h=g.get(s=d(c=n[f])+""))?h.push(c):g.set(s,[c]);return g.each(function(t,e){o(v,e,u(t,a,i,o))}),v}return s={object:function(t){return u(t,0,n,a)},map:function(t){return u(t,0,i,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var a,i=c[n-1];return null!=e&&n>=l.length?a=r.entries():(a=[],r.each(function(e,r){a.push({key:r,values:t(e,n)})})),null!=i?a.sort(function(t,e){return i(t.key,e.key)}):a}(u(t,0,i,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:n.d3=n.d3||{})},{}],156:[function(t,e,r){var n;n=this,function(t){"use strict";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var a="\\s*([+-]?\\d+)\\s*",i="\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)\\s*",o="\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)%\\s*",s=/^#([0-9a-f]{3,8})$/,l=new RegExp("^rgb\\("+[a,a,a]+"\\)$"),c=new RegExp("^rgb\\("+[o,o,o]+"\\)$"),u=new RegExp("^rgba\\("+[a,a,a,i]+"\\)$"),h=new RegExp("^rgba\\("+[o,o,o,i]+"\\)$"),f=new RegExp("^hsl\\("+[i,o,o]+"\\)$"),p=new RegExp("^hsla\\("+[i,o,o,i]+"\\)$"),d={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function g(){return this.rgb().formatHex()}function v(){return this.rgb().formatRgb()}function m(t){var e,r;return t=(t+"").trim().toLowerCase(),(e=s.exec(t))?(r=e[1].length,e=parseInt(e[1],16),6===r?y(e):3===r?new w(e>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):8===r?new w(e>>24&255,e>>16&255,e>>8&255,(255&e)/255):4===r?new w(e>>12&15|e>>8&240,e>>8&15|e>>4&240,e>>4&15|240&e,((15&e)<<4|15&e)/255):null):(e=l.exec(t))?new w(e[1],e[2],e[3],1):(e=c.exec(t))?new w(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=u.exec(t))?x(e[1],e[2],e[3],e[4]):(e=h.exec(t))?x(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=f.exec(t))?A(e[1],e[2]/100,e[3]/100,1):(e=p.exec(t))?A(e[1],e[2]/100,e[3]/100,e[4]):d.hasOwnProperty(t)?y(d[t]):"transparent"===t?new w(NaN,NaN,NaN,0):null}function y(t){return new w(t>>16&255,t>>8&255,255&t,1)}function x(t,e,r,n){return n<=0&&(t=e=r=NaN),new w(t,e,r,n)}function b(t){return t instanceof n||(t=m(t)),t?new w((t=t.rgb()).r,t.g,t.b,t.opacity):new w}function _(t,e,r,n){return 1===arguments.length?b(t):new w(t,e,r,null==n?1:n)}function w(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function k(){return"#"+M(this.r)+M(this.g)+M(this.b)}function T(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?"rgb(":"rgba(")+Math.max(0,Math.min(255,Math.round(this.r)||0))+", "+Math.max(0,Math.min(255,Math.round(this.g)||0))+", "+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?")":", "+t+")")}function M(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?"0":"")+t.toString(16)}function A(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new L(t,e,r,n)}function S(t){if(t instanceof L)return new L(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=m(t)),!t)return new L;if(t instanceof L)return t;var e=(t=t.rgb()).r/255,r=t.g/255,a=t.b/255,i=Math.min(e,r,a),o=Math.max(e,r,a),s=NaN,l=o-i,c=(o+i)/2;return l?(s=e===o?(r-a)/l+6*(r<a):r===o?(a-e)/l+2:(e-r)/l+4,l/=c<.5?o+i:2-o-i,s*=60):l=c>0&&c<1?0:s,new L(s,l,c,t.opacity)}function E(t,e,r,n){return 1===arguments.length?S(t):new L(t,e,r,null==n?1:n)}function L(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function C(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,m,{copy:function(t){return Object.assign(new this.constructor,this,t)},displayable:function(){return this.rgb().displayable()},hex:g,formatHex:g,formatHsl:function(){return S(this).formatHsl()},formatRgb:v,toString:v}),e(w,_,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new w(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new w(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return-.5<=this.r&&this.r<255.5&&-.5<=this.g&&this.g<255.5&&-.5<=this.b&&this.b<255.5&&0<=this.opacity&&this.opacity<=1},hex:k,formatHex:k,formatRgb:T,toString:T})),e(L,E,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new L(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new L(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,a=2*r-n;return new w(C(t>=240?t-240:t+120,a,n),C(t,a,n),C(t<120?t+240:t-120,a,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1},formatHsl:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?"hsl(":"hsla(")+(this.h||0)+", "+100*(this.s||0)+"%, "+100*(this.l||0)+"%"+(1===t?")":", "+t+")")}}));var P=Math.PI/180,O=180/Math.PI,z=.96422,I=1,D=.82521,R=4/29,F=6/29,B=3*F*F,N=F*F*F;function j(t){if(t instanceof U)return new U(t.l,t.a,t.b,t.opacity);if(t instanceof Z)return J(t);t instanceof w||(t=b(t));var e,r,n=Y(t.r),a=Y(t.g),i=Y(t.b),o=q((.2225045*n+.7168786*a+.0606169*i)/I);return n===a&&a===i?e=r=o:(e=q((.4360747*n+.3850649*a+.1430804*i)/z),r=q((.0139322*n+.0971045*a+.7141733*i)/D)),new U(116*o-16,500*(e-o),200*(o-r),t.opacity)}function V(t,e,r,n){return 1===arguments.length?j(t):new U(t,e,r,null==n?1:n)}function U(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function q(t){return t>N?Math.pow(t,1/3):t/B+R}function H(t){return t>F?t*t*t:B*(t-R)}function G(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function Y(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function W(t){if(t instanceof Z)return new Z(t.h,t.c,t.l,t.opacity);if(t instanceof U||(t=j(t)),0===t.a&&0===t.b)return new Z(NaN,0<t.l&&t.l<100?0:NaN,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*O;return new Z(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function X(t,e,r,n){return 1===arguments.length?W(t):new Z(t,e,r,null==n?1:n)}function Z(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}function J(t){if(isNaN(t.h))return new U(t.l,0,0,t.opacity);var e=t.h*P;return new U(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}e(U,V,r(n,{brighter:function(t){return new U(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new U(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new w(G(3.1338561*(e=z*H(e))-1.6168667*(t=I*H(t))-.4906146*(r=D*H(r))),G(-.9787684*e+1.9161415*t+.033454*r),G(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(Z,X,r(n,{brighter:function(t){return new Z(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new Z(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return J(this).rgb()}}));var K=-.14861,Q=1.78277,$=-.29227,tt=-.90649,et=1.97294,rt=et*tt,nt=et*Q,at=Q*$-tt*K;function it(t,e,r,n){return 1===arguments.length?function(t){if(t instanceof ot)return new ot(t.h,t.s,t.l,t.opacity);t instanceof w||(t=b(t));var e=t.r/255,r=t.g/255,n=t.b/255,a=(at*n+rt*e-nt*r)/(at+rt-nt),i=n-a,o=(et*(r-a)-$*i)/tt,s=Math.sqrt(o*o+i*i)/(et*a*(1-a)),l=s?Math.atan2(o,i)*O-120:NaN;return new ot(l<0?l+360:l,s,a,t.opacity)}(t):new ot(t,e,r,null==n?1:n)}function ot(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(ot,it,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new ot(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new ot(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*P,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),a=Math.sin(t);return new w(255*(e+r*(K*n+Q*a)),255*(e+r*($*n+tt*a)),255*(e+r*(et*n)),this.opacity)}})),t.color=m,t.cubehelix=it,t.gray=function(t,e){return new U(t,0,0,null==e?1:e)},t.hcl=X,t.hsl=E,t.lab=V,t.lch=function(t,e,r,n){return 1===arguments.length?W(t):new Z(r,e,t,null==n?1:n)},t.rgb=_,Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:(n=n||self).d3=n.d3||{})},{}],157:[function(t,e,r){var n;n=this,function(t){"use strict";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,a={};e<r;++e){if(!(t=arguments[e]+"")||t in a)throw new Error("illegal type: "+t);a[t]=[]}return new n(a)}function n(t){this._=t}function a(t,e){for(var r,n=0,a=t.length;n<a;++n)if((r=t[n]).name===e)return r.value}function i(t,r,n){for(var a=0,i=t.length;a<i;++a)if(t[a].name===r){t[a]=e,t=t.slice(0,a).concat(t.slice(a+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n,o=this._,s=(n=o,(t+"").trim().split(/^|\s+/).map(function(t){var e="",r=t.indexOf(".");if(r>=0&&(e=t.slice(r+1),t=t.slice(0,r)),t&&!n.hasOwnProperty(t))throw new Error("unknown type: "+t);return{type:t,name:e}})),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&"function"!=typeof e)throw new Error("invalid callback: "+e);for(;++l<c;)if(r=(t=s[l]).type)o[r]=i(o[r],t.name,e);else if(null==e)for(r in o)o[r]=i(o[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=a(o[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,a=new Array(r),i=0;i<r;++i)a[i]=arguments[i+2];if(!this._.hasOwnProperty(t))throw new Error("unknown type: "+t);for(i=0,r=(n=this._[t]).length;i<r;++i)n[i].value.apply(e,a)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error("unknown type: "+t);for(var n=this._[t],a=0,i=n.length;a<i;++a)n[a].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:n.d3=n.d3||{})},{}],158:[function(t,e,r){var n,a;n=this,a=function(t,e,r,n,a){"use strict";var i=function(t){return function(){return t}},o=function(){return 1e-6*(Math.random()-.5)};function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error("missing: "+e);return r}function h(t){return t.x}function f(t){return t.y}var p=10,d=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,a,i=r.length,o=0,s=0;for(n=0;n<i;++n)o+=(a=r[n]).x,s+=a.y;for(o=o/i-t,s=s/i-e,n=0;n<i;++n)(a=r[n]).x-=o,a.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,a=1,c=1;function u(){for(var t,i,u,f,p,d,g,v=r.length,m=0;m<c;++m)for(i=e.quadtree(r,s,l).visitAfter(h),t=0;t<v;++t)u=r[t],d=n[u.index],g=d*d,f=u.x+u.vx,p=u.y+u.vy,i.visit(y);function y(t,e,r,n,i){var s=t.data,l=t.r,c=d+l;if(!s)return e>f+c||n<f-c||r>p+c||i<p-c;if(s.index>u.index){var h=f-s.x-s.vx,v=p-s.y-s.vy,m=h*h+v*v;m<c*c&&(0===h&&(m+=(h=o())*h),0===v&&(m+=(v=o())*v),m=(c-(m=Math.sqrt(m)))/m*a,u.vx+=(h*=m)*(c=(l*=l)/(g+l)),u.vy+=(v*=m)*c,s.vx-=h*(c=1-c),s.vy-=v*c)}}}function h(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function f(){if(r){var e,a,i=r.length;for(n=new Array(i),e=0;e<i;++e)a=r[e],n[a.index]=+t(a,e,r)}}return"function"!=typeof t&&(t=i(null==t?1:+t)),u.initialize=function(t){r=t,f()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(a=+t,u):a},u.radius=function(e){return arguments.length?(t="function"==typeof e?e:i(+e),f(),u):t},u},t.forceLink=function(t){var e,n,a,s,l,h=c,f=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=i(30),d=1;function g(r){for(var a=0,i=t.length;a<d;++a)for(var s,c,u,h,f,p,g,v=0;v<i;++v)c=(s=t[v]).source,h=(u=s.target).x+u.vx-c.x-c.vx||o(),f=u.y+u.vy-c.y-c.vy||o(),h*=p=((p=Math.sqrt(h*h+f*f))-n[v])/p*r*e[v],f*=p,u.vx-=h*(g=l[v]),u.vy-=f*g,c.vx+=h*(g=1-g),c.vy+=f*g}function v(){if(a){var i,o,c=a.length,f=t.length,p=r.map(a,h);for(i=0,s=new Array(c);i<f;++i)(o=t[i]).index=i,"object"!=typeof o.source&&(o.source=u(p,o.source)),"object"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(i=0,l=new Array(f);i<f;++i)o=t[i],l[i]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(f),m(),n=new Array(f),y()}}function m(){if(a)for(var r=0,n=t.length;r<n;++r)e[r]=+f(t[r],r,t)}function y(){if(a)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),g.initialize=function(t){a=t,v()},g.links=function(e){return arguments.length?(t=e,v(),g):t},g.id=function(t){return arguments.length?(h=t,g):h},g.iterations=function(t){return arguments.length?(d=+t,g):d},g.strength=function(t){return arguments.length?(f="function"==typeof t?t:i(+t),m(),g):f},g.distance=function(t){return arguments.length?(p="function"==typeof t?t:i(+t),y(),g):p},g},t.forceManyBody=function(){var t,r,n,a,s=i(-30),l=1,c=1/0,u=.81;function p(a){var i,o=t.length,s=e.quadtree(t,h,f).visitAfter(g);for(n=a,i=0;i<o;++i)r=t[i],s.visit(v)}function d(){if(t){var e,r,n=t.length;for(a=new Array(n),e=0;e<n;++e)r=t[e],a[r.index]=+s(r,e,t)}}function g(t){var e,r,n,i,o,s=0,l=0;if(t.length){for(n=i=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,i+=r*e.y);t.x=n/l,t.y=i/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=a[e.data.index]}while(e=e.next)}t.value=s}function v(t,e,i,s){if(!t.value)return!0;var h=t.x-r.x,f=t.y-r.y,p=s-e,d=h*h+f*f;if(p*p/u<d)return d<c&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)),r.vx+=h*t.value*n/d,r.vy+=f*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=a[t.data.index]*n/d,r.vx+=h*p,r.vy+=f*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s="function"==typeof t?t:i(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,a,o,s=i(.1);function l(t){for(var i=0,s=n.length;i<s;++i){var l=n[i],c=l.x-e||1e-6,u=l.y-r||1e-6,h=Math.sqrt(c*c+u*u),f=(o[i]-h)*a[i]*t/h;l.vx+=c*f,l.vy+=u*f}}function c(){if(n){var e,r=n.length;for(a=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),a[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return"function"!=typeof t&&(t=i(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s="function"==typeof t?t:i(+t),c(),l):s},l.radius=function(e){return arguments.length?(t="function"==typeof e?e:i(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,i=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),h=a.timer(g),f=n.dispatch("tick","end");function g(){v(),f.call("tick",e),i<o&&(h.stop(),f.call("end",e))}function v(){var e,r,n=t.length;for(i+=(l-i)*s,u.each(function(t){t(i)}),e=0;e<n;++e)null==(r=t[e]).fx?r.x+=r.vx*=c:(r.x=r.fx,r.vx=0),null==r.fy?r.y+=r.vy*=c:(r.y=r.fy,r.vy=0)}function m(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,isNaN(e.x)||isNaN(e.y)){var a=p*Math.sqrt(r),i=r*d;e.x=a*Math.cos(i),e.y=a*Math.sin(i)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function y(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),m(),e={tick:v,restart:function(){return h.restart(g),e},stop:function(){return h.stop(),e},nodes:function(r){return arguments.length?(t=r,m(),u.each(y),e):t},alpha:function(t){return arguments.length?(i=+t,e):i},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,y(r)),e):u.get(t)},find:function(e,r,n){var a,i,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(a=e-(s=t[c]).x)*a+(i=r-s.y)*i)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(f.on(t,r),e):f.on(t)}}},t.forceX=function(t){var e,r,n,a=i(.1);function o(t){for(var a,i=0,o=e.length;i<o;++i)(a=e[i]).vx+=(n[i]-a.x)*r[i]*t}function s(){if(e){var i,o=e.length;for(r=new Array(o),n=new Array(o),i=0;i<o;++i)r[i]=isNaN(n[i]=+t(e[i],i,e))?0:+a(e[i],i,e)}}return"function"!=typeof t&&(t=i(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(a="function"==typeof t?t:i(+t),s(),o):a},o.x=function(e){return arguments.length?(t="function"==typeof e?e:i(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,a=i(.1);function o(t){for(var a,i=0,o=e.length;i<o;++i)(a=e[i]).vy+=(n[i]-a.y)*r[i]*t}function s(){if(e){var i,o=e.length;for(r=new Array(o),n=new Array(o),i=0;i<o;++i)r[i]=isNaN(n[i]=+t(e[i],i,e))?0:+a(e[i],i,e)}}return"function"!=typeof t&&(t=i(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(a="function"==typeof t?t:i(+t),s(),o):a},o.y=function(e){return arguments.length?(t="function"==typeof e?e:i(+e),s(),o):t},o},Object.defineProperty(t,"__esModule",{value:!0})},"object"==typeof r&&"undefined"!=typeof e?a(r,t("d3-quadtree"),t("d3-collection"),t("d3-dispatch"),t("d3-timer")):a(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)},{"d3-collection":155,"d3-dispatch":157,"d3-quadtree":162,"d3-timer":164}],159:[function(t,e,r){var n;n=this,function(t){"use strict";function e(t,e){return t.parent===e.parent?1:2}function r(t,e){return t+e.x}function n(t,e){return Math.max(t,e.y)}function a(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function i(t,e){var r,n,a,i,s,u=new c(t),h=+t.value&&(u.value=t.value),f=[u];for(null==e&&(e=o);r=f.pop();)if(h&&(r.value=+r.data.value),(a=e(r.data))&&(s=a.length))for(r.children=new Array(s),i=s-1;i>=0;--i)f.push(n=r.children[i]=new c(a[i])),n.parent=r,n.depth=r.depth+1;return u.eachBefore(l)}function o(t){return t.children}function s(t){t.data=t.data.data}function l(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function c(t){this.data=t,this.depth=this.height=0,this.parent=null}c.prototype=i.prototype={constructor:c,count:function(){return this.eachAfter(a)},each:function(t){var e,r,n,a,i=this,o=[i];do{for(e=o.reverse(),o=[];i=e.pop();)if(t(i),r=i.children)for(n=0,a=r.length;n<a;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,a=this,i=[a],o=[];a=i.pop();)if(o.push(a),e=a.children)for(r=0,n=e.length;r<n;++r)i.push(e[r]);for(;a=o.pop();)t(a);return this},eachBefore:function(t){for(var e,r,n=this,a=[n];n=a.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)a.push(e[r]);return this},sum:function(t){return this.eachAfter(function(e){for(var r=+t(e.data)||0,n=e.children,a=n&&n.length;--a>=0;)r+=n[a].value;e.value=r})},sort:function(t){return this.eachBefore(function(e){e.children&&e.children.sort(t)})},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),a=null;for(t=r.pop(),e=n.pop();t===e;)a=t,t=r.pop(),e=n.pop();return a}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var a=n.length;t!==r;)n.splice(a,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each(function(e){t.push(e)}),t},leaves:function(){var t=[];return this.eachBefore(function(e){e.children||t.push(e)}),t},links:function(){var t=this,e=[];return t.each(function(r){r!==t&&e.push({source:r.parent,target:r})}),e},copy:function(){return i(this).eachBefore(s)}};var u=Array.prototype.slice;function h(t){for(var e,r,n=0,a=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(u.call(t))).length,i=[];n<a;)e=t[n],r&&d(r,e)?++n:(r=v(i=f(i,e)),n=0);return r}function f(t,e){var r,n;if(g(e,t))return[e];for(r=0;r<t.length;++r)if(p(e,t[r])&&g(m(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(p(m(t[r],t[n]),e)&&p(m(t[r],e),t[n])&&p(m(t[n],e),t[r])&&g(y(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function p(t,e){var r=t.r-e.r,n=e.x-t.x,a=e.y-t.y;return r<0||r*r<n*n+a*a}function d(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,a=e.y-t.y;return r>0&&r*r>n*n+a*a}function g(t,e){for(var r=0;r<e.length;++r)if(!d(t,e[r]))return!1;return!0}function v(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return m(t[0],t[1]);case 3:return y(t[0],t[1],t[2])}var e}function m(t,e){var r=t.x,n=t.y,a=t.r,i=e.x,o=e.y,s=e.r,l=i-r,c=o-n,u=s-a,h=Math.sqrt(l*l+c*c);return{x:(r+i+l/h*u)/2,y:(n+o+c/h*u)/2,r:(h+a+s)/2}}function y(t,e,r){var n=t.x,a=t.y,i=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,h=r.r,f=n-o,p=n-c,d=a-s,g=a-u,v=l-i,m=h-i,y=n*n+a*a-i*i,x=y-o*o-s*s+l*l,b=y-c*c-u*u+h*h,_=p*d-f*g,w=(d*b-g*x)/(2*_)-n,k=(g*v-d*m)/_,T=(p*x-f*b)/(2*_)-a,M=(f*m-p*v)/_,A=k*k+M*M-1,S=2*(i+w*k+T*M),E=w*w+T*T-i*i,L=-(A?(S+Math.sqrt(S*S-4*A*E))/(2*A):E/S);return{x:n+w+k*L,y:a+T+M*L,r:L}}function x(t,e,r){var n,a,i,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(a=e.r+r.r,a*=a,o=t.r+r.r,a>(o*=o)?(n=(c+o-a)/(2*c),i=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-i*l,r.y=t.y-n*l+i*s):(n=(c+a-o)/(2*c),i=Math.sqrt(Math.max(0,a/c-n*n)),r.x=e.x+n*s-i*l,r.y=e.y+n*l+i*s)):(r.x=e.x+r.r,r.y=e.y)}function b(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,a=e.y-t.y;return r>0&&r*r>n*n+a*a}function _(t){var e=t._,r=t.next._,n=e.r+r.r,a=(e.x*r.r+r.x*e.r)/n,i=(e.y*r.r+r.y*e.r)/n;return a*a+i*i}function w(t){this._=t,this.next=null,this.previous=null}function k(t){if(!(a=t.length))return 0;var e,r,n,a,i,o,s,l,c,u,f;if((e=t[0]).x=0,e.y=0,!(a>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(a>2))return e.r+r.r;x(r,e,n=t[2]),e=new w(e),r=new w(r),n=new w(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<a;++s){x(e._,r._,n=t[s]),n=new w(n),l=r.next,c=e.previous,u=r._.r,f=e._.r;do{if(u<=f){if(b(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(b(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}f+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,i=_(e);(n=n.next)!==r;)(o=_(n))<i&&(e=n,i=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=h(e),s=0;s<a;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function T(t){if("function"!=typeof t)throw new Error;return t}function M(){return 0}function A(t){return function(){return t}}function S(t){return Math.sqrt(t.value)}function E(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function L(t,e){return function(r){if(n=r.children){var n,a,i,o=n.length,s=t(r)*e||0;if(s)for(a=0;a<o;++a)n[a].r+=s;if(i=k(n),s)for(a=0;a<o;++a)n[a].r-=s;r.r=i+s}}}function C(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function P(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function O(t,e,r,n,a){for(var i,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(i=o[s]).y0=r,i.y1=a,i.x0=e,i.x1=e+=i.value*c}var z="$",I={depth:-1},D={};function R(t){return t.id}function F(t){return t.parentId}function B(t,e){return t.parent===e.parent?1:2}function N(t){var e=t.children;return e?e[0]:t.t}function j(t){var e=t.children;return e?e[e.length-1]:t.t}function V(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function U(t,e,r){return t.a.parent===e.parent?t.a:r}function q(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function H(t,e,r,n,a){for(var i,o=t.children,s=-1,l=o.length,c=t.value&&(a-r)/t.value;++s<l;)(i=o[s]).x0=e,i.x1=n,i.y0=r,i.y1=r+=i.value*c}q.prototype=Object.create(c.prototype);var G=(1+Math.sqrt(5))/2;function Y(t,e,r,n,a,i){for(var o,s,l,c,u,h,f,p,d,g,v,m=[],y=e.children,x=0,b=0,_=y.length,w=e.value;x<_;){l=a-r,c=i-n;do{u=y[b++].value}while(!u&&b<_);for(h=f=u,v=u*u*(g=Math.max(c/l,l/c)/(w*t)),d=Math.max(f/v,v/h);b<_;++b){if(u+=s=y[b].value,s<h&&(h=s),s>f&&(f=s),v=u*u*g,(p=Math.max(f/v,v/h))>d){u-=s;break}d=p}m.push(o={value:u,dice:l<c,children:y.slice(x,b)}),o.dice?O(o,r,n,a,w?n+=c*u/w:i):H(o,r,n,w?r+=l*u/w:a,i),w-=u,x=b}return m}var W=function t(e){function r(t,r,n,a,i){Y(e,t,r,n,a,i)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G),X=function t(e){function r(t,r,n,a,i){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,h=-1,f=o.length,p=t.value;++h<f;){for(l=(s=o[h]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?O(s,r,n,a,n+=(i-n)*s.value/p):H(s,r,n,r+=(a-r)*s.value/p,i),p-=s.value}else t._squarify=o=Y(e,t,r,n,a,i),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);t.cluster=function(){var t=e,a=1,i=1,o=!1;function s(e){var s,l=0;e.eachAfter(function(e){var a=e.children;a?(e.x=function(t){return t.reduce(r,0)/t.length}(a),e.y=function(t){return 1+t.reduce(n,0)}(a)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)});var c=function(t){for(var e;e=t.children;)t=e[0];return t}(e),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(e),h=c.x-t(c,u)/2,f=u.x+t(u,c)/2;return e.eachAfter(o?function(t){t.x=(t.x-e.x)*a,t.y=(e.y-t.y)*i}:function(t){t.x=(t.x-h)/(f-h)*a,t.y=(1-(e.y?t.y/e.y:1))*i})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,a=+t[0],i=+t[1],s):o?null:[a,i]},s.nodeSize=function(t){return arguments.length?(o=!0,a=+t[0],i=+t[1],s):o?[a,i]:null},s},t.hierarchy=i,t.pack=function(){var t=null,e=1,r=1,n=M;function a(a){return a.x=e/2,a.y=r/2,t?a.eachBefore(E(t)).eachAfter(L(n,.5)).eachBefore(C(1)):a.eachBefore(E(S)).eachAfter(L(M,1)).eachAfter(L(n,a.r/Math.min(e,r))).eachBefore(C(Math.min(e,r)/(2*a.r))),a}return a.radius=function(e){return arguments.length?(t=null==(r=e)?null:T(r),a):t;var r},a.size=function(t){return arguments.length?(e=+t[0],r=+t[1],a):[e,r]},a.padding=function(t){return arguments.length?(n="function"==typeof t?t:A(+t),a):n},a},t.packEnclose=h,t.packSiblings=function(t){return k(t),t},t.partition=function(){var t=1,e=1,r=0,n=!1;function a(a){var i=a.height+1;return a.x0=a.y0=r,a.x1=t,a.y1=e/i,a.eachBefore(function(t,e){return function(n){n.children&&O(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var a=n.x0,i=n.y0,o=n.x1-r,s=n.y1-r;o<a&&(a=o=(a+o)/2),s<i&&(i=s=(i+s)/2),n.x0=a,n.y0=i,n.x1=o,n.y1=s}}(e,i)),n&&a.eachBefore(P),a}return a.round=function(t){return arguments.length?(n=!!t,a):n},a.size=function(r){return arguments.length?(t=+r[0],e=+r[1],a):[t,e]},a.padding=function(t){return arguments.length?(r=+t,a):r},a},t.stratify=function(){var t=R,e=F;function r(r){var n,a,i,o,s,u,h,f=r.length,p=new Array(f),d={};for(a=0;a<f;++a)n=r[a],s=p[a]=new c(n),null!=(u=t(n,a,r))&&(u+="")&&(d[h=z+(s.id=u)]=h in d?D:s);for(a=0;a<f;++a)if(s=p[a],null!=(u=e(r[a],a,r))&&(u+="")){if(!(o=d[z+u]))throw new Error("missing: "+u);if(o===D)throw new Error("ambiguous: "+u);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(i)throw new Error("multiple roots");i=s}if(!i)throw new Error("no root");if(i.parent=I,i.eachBefore(function(t){t.depth=t.parent.depth+1,--f}).eachBefore(l),i.parent=null,f>0)throw new Error("cycle");return i}return r.id=function(e){return arguments.length?(t=T(e),r):t},r.parentId=function(t){return arguments.length?(e=T(t),r):e},r},t.tree=function(){var t=B,e=1,r=1,n=null;function a(a){var l=function(t){for(var e,r,n,a,i,o=new q(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(i=n.length),a=i-1;a>=0;--a)s.push(r=e.children[a]=new q(n[a],a)),r.parent=e;return(o.parent=new q(null,0)).children=[o],o}(a);if(l.eachAfter(i),l.parent.m=-l.z,l.eachBefore(o),n)a.eachBefore(s);else{var c=a,u=a,h=a;a.eachBefore(function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>h.depth&&(h=t)});var f=c===u?1:t(c,u)/2,p=f-c.x,d=e/(u.x+f+p),g=r/(h.depth||1);a.eachBefore(function(t){t.x=(t.x+p)*d,t.y=t.depth*g})}return a}function i(e){var r=e.children,n=e.parent.children,a=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,a=t.children,i=a.length;--i>=0;)(e=a[i]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var i=(r[0].z+r[r.length-1].z)/2;a?(e.z=a.z+t(e._,a._),e.m=e.z-i):e.z=i}else a&&(e.z=a.z+t(e._,a._));e.parent.A=function(e,r,n){if(r){for(var a,i=e,o=e,s=r,l=i.parent.children[0],c=i.m,u=o.m,h=s.m,f=l.m;s=j(s),i=N(i),s&&i;)l=N(l),(o=j(o)).a=e,(a=s.z+h-i.z-c+t(s._,i._))>0&&(V(U(s,e,n),e,a),c+=a,u+=a),h+=s.m,c+=i.m,f+=l.m,u+=o.m;s&&!j(o)&&(o.t=s,o.m+=h-u),i&&!N(l)&&(l.t=i,l.m+=c-f,n=e)}return n}(e,a,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return a.separation=function(e){return arguments.length?(t=e,a):t},a.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],a):n?null:[e,r]},a.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],a):n?[e,r]:null},a},t.treemap=function(){var t=W,e=!1,r=1,n=1,a=[0],i=M,o=M,s=M,l=M,c=M;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(h),a=[0],e&&t.eachBefore(P),t}function h(e){var r=a[e.depth],n=e.x0+r,u=e.y0+r,h=e.x1-r,f=e.y1-r;h<n&&(n=h=(n+h)/2),f<u&&(u=f=(u+f)/2),e.x0=n,e.y0=u,e.x1=h,e.y1=f,e.children&&(r=a[e.depth+1]=i(e)/2,n+=c(e)-r,u+=o(e)-r,(h-=s(e)-r)<n&&(n=h=(n+h)/2),(f-=l(e)-r)<u&&(u=f=(u+f)/2),t(e,n,u,h,f))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=T(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(i="function"==typeof t?t:A(+t),u):i},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o="function"==typeof t?t:A(+t),u):o},u.paddingRight=function(t){return arguments.length?(s="function"==typeof t?t:A(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l="function"==typeof t?t:A(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c="function"==typeof t?t:A(+t),u):c},u},t.treemapBinary=function(t,e,r,n,a){var i,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=i=0;i<l;++i)c[i+1]=o+=s[i].value;!function t(e,r,n,a,i,o,l){if(e>=r-1){var u=s[e];return u.x0=a,u.y0=i,u.x1=o,void(u.y1=l)}for(var h=c[e],f=n/2+h,p=e+1,d=r-1;p<d;){var g=p+d>>>1;c[g]<f?p=g+1:d=g}f-c[p-1]<c[p]-f&&e+1<p&&--p;var v=c[p]-h,m=n-v;if(o-a>l-i){var y=(a*m+o*v)/n;t(e,p,v,a,i,y,l),t(p,r,m,y,i,o,l)}else{var x=(i*m+l*v)/n;t(e,p,v,a,i,o,x),t(p,r,m,a,x,o,l)}}(0,l,t.value,e,r,n,a)},t.treemapDice=O,t.treemapResquarify=X,t.treemapSlice=H,t.treemapSliceDice=function(t,e,r,n,a){(1&t.depth?H:O)(t,e,r,n,a)},t.treemapSquarify=W,Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:(n=n||self).d3=n.d3||{})},{}],160:[function(t,e,r){var n,a;n=this,a=function(t,e){"use strict";function r(t,e,r,n,a){var i=t*t,o=i*t;return((1-3*t+3*i-o)*e+(4-6*i+3*o)*r+(1+3*t+3*i-3*o)*n+o*a)/6}function n(t){var e=t.length-1;return function(n){var a=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),i=t[a],o=t[a+1],s=a>0?t[a-1]:2*i-o,l=a<e-1?t[a+2]:2*o-i;return r((n-a/e)*e,s,i,o,l)}}function a(t){var e=t.length;return function(n){var a=Math.floor(((n%=1)<0?++n:n)*e),i=t[(a+e-1)%e],o=t[a%e],s=t[(a+1)%e],l=t[(a+2)%e];return r((n-a/e)*e,i,o,s,l)}}function i(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):i(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):i(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):i(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function a(t,r){var a=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),i=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=a(e),t.g=i(e),t.b=o(e),t.opacity=s(e),t+""}}return a.gamma=t,a}(1);function h(t){return function(r){var n,a,i=r.length,o=new Array(i),s=new Array(i),l=new Array(i);for(n=0;n<i;++n)a=e.rgb(r[n]),o[n]=a.r||0,s[n]=a.g||0,l[n]=a.b||0;return o=t(o),s=t(s),l=t(l),a.opacity=1,function(t){return a.r=o(t),a.g=s(t),a.b=l(t),a+""}}}var f=h(n),p=h(a);function d(t,e){e||(e=[]);var r,n=t?Math.min(e.length,t.length):0,a=e.slice();return function(i){for(r=0;r<n;++r)a[r]=t[r]*(1-i)+e[r]*i;return a}}function g(t){return ArrayBuffer.isView(t)&&!(t instanceof DataView)}function v(t,e){var r,n=e?e.length:0,a=t?Math.min(n,t.length):0,i=new Array(a),o=new Array(n);for(r=0;r<a;++r)i[r]=k(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<a;++r)o[r]=i[r](t);return o}}function m(t,e){var r=new Date;return t=+t,e=+e,function(n){return r.setTime(t*(1-n)+e*n),r}}function y(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function x(t,e){var r,n={},a={};for(r in null!==t&&"object"==typeof t||(t={}),null!==e&&"object"==typeof e||(e={}),e)r in t?n[r]=k(t[r],e[r]):a[r]=e[r];return function(t){for(r in n)a[r]=n[r](t);return a}}var b=/[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g,_=new RegExp(b.source,"g");function w(t,e){var r,n,a,i=b.lastIndex=_.lastIndex=0,o=-1,s=[],l=[];for(t+="",e+="";(r=b.exec(t))&&(n=_.exec(e));)(a=n.index)>i&&(a=e.slice(i,a),s[o]?s[o]+=a:s[++o]=a),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:y(r,n)})),i=_.lastIndex;return i<e.length&&(a=e.slice(i),s[o]?s[o]+=a:s[++o]=a),s.length<2?l[0]?function(t){return function(e){return t(e)+""}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join("")})}function k(t,r){var n,a=typeof r;return null==r||"boolean"===a?i(r):("number"===a?y:"string"===a?(n=e.color(r))?(r=n,u):w:r instanceof e.color?u:r instanceof Date?m:g(r)?d:Array.isArray(r)?v:"function"!=typeof r.valueOf&&"function"!=typeof r.toString||isNaN(r)?x:y)(t,r)}var T,M,A,S,E=180/Math.PI,L={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function C(t,e,r,n,a,i){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:a,translateY:i,rotate:Math.atan2(e,t)*E,skewX:Math.atan(l)*E,scaleX:o,scaleY:s}}function P(t,e,r,n){function a(t){return t.length?t.pop()+" ":""}return function(i,o){var s=[],l=[];return i=t(i),o=t(o),function(t,n,a,i,o,s){if(t!==a||n!==i){var l=o.push("translate(",null,e,null,r);s.push({i:l-4,x:y(t,a)},{i:l-2,x:y(n,i)})}else(a||i)&&o.push("translate("+a+e+i+r)}(i.translateX,i.translateY,o.translateX,o.translateY,s,l),function(t,e,r,i){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),i.push({i:r.push(a(r)+"rotate(",null,n)-2,x:y(t,e)})):e&&r.push(a(r)+"rotate("+e+n)}(i.rotate,o.rotate,s,l),function(t,e,r,i){t!==e?i.push({i:r.push(a(r)+"skewX(",null,n)-2,x:y(t,e)}):e&&r.push(a(r)+"skewX("+e+n)}(i.skewX,o.skewX,s,l),function(t,e,r,n,i,o){if(t!==r||e!==n){var s=i.push(a(i)+"scale(",null,",",null,")");o.push({i:s-4,x:y(t,r)},{i:s-2,x:y(e,n)})}else 1===r&&1===n||i.push(a(i)+"scale("+r+","+n+")")}(i.scaleX,i.scaleY,o.scaleX,o.scaleY,s,l),i=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join("")}}}var O=P(function(t){return"none"===t?L:(T||(T=document.createElement("DIV"),M=document.documentElement,A=document.defaultView),T.style.transform=t,t=A.getComputedStyle(M.appendChild(T),null).getPropertyValue("transform"),M.removeChild(T),C(+(t=t.slice(7,-1).split(","))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))},"px, ","px)","deg)"),z=P(function(t){return null==t?L:(S||(S=document.createElementNS("http://www.w3.org/2000/svg","g")),S.setAttribute("transform",t),(t=S.transform.baseVal.consolidate())?C((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):L)},", ",")",")"),I=Math.SQRT2,D=2,R=4,F=1e-12;function B(t){return((t=Math.exp(t))+1/t)/2}function N(t){return function(r,n){var a=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),i=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=a(t),r.s=i(t),r.l=o(t),r.opacity=s(t),r+""}}}var j=N(s),V=N(c);function U(t){return function(r,n){var a=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),i=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=a(t),r.c=i(t),r.l=o(t),r.opacity=s(t),r+""}}}var q=U(s),H=U(c);function G(t){return function r(n){function a(r,a){var i=t((r=e.cubehelix(r)).h,(a=e.cubehelix(a)).h),o=c(r.s,a.s),s=c(r.l,a.l),l=c(r.opacity,a.opacity);return function(t){return r.h=i(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+""}}return n=+n,a.gamma=r,a}(1)}var Y=G(s),W=G(c);t.interpolate=k,t.interpolateArray=function(t,e){return(g(e)?d:v)(t,e)},t.interpolateBasis=n,t.interpolateBasisClosed=a,t.interpolateCubehelix=Y,t.interpolateCubehelixLong=W,t.interpolateDate=m,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHcl=q,t.interpolateHclLong=H,t.interpolateHsl=j,t.interpolateHslLong=V,t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),a=c(t.a,r.a),i=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=a(e),t.b=i(e),t.opacity=o(e),t+""}},t.interpolateNumber=y,t.interpolateNumberArray=d,t.interpolateObject=x,t.interpolateRgb=u,t.interpolateRgbBasis=f,t.interpolateRgbBasisClosed=p,t.interpolateRound=function(t,e){return t=+t,e=+e,function(r){return Math.round(t*(1-r)+e*r)}},t.interpolateString=w,t.interpolateTransformCss=O,t.interpolateTransformSvg=z,t.interpolateZoom=function(t,e){var r,n,a=t[0],i=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-a,h=l-i,f=u*u+h*h;if(f<F)n=Math.log(c/o)/I,r=function(t){return[a+t*u,i+t*h,o*Math.exp(I*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+R*f)/(2*o*D*p),g=(c*c-o*o-R*f)/(2*c*D*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/I,r=function(t){var e,r=t*n,s=B(v),l=o/(D*p)*(s*(e=I*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[a+l*u,i+l*h,o*s/B(I*r+v)]}}return r.duration=1e3*n,r},t.piecewise=function(t,e){for(var r=0,n=e.length-1,a=e[0],i=new Array(n<0?0:n);r<n;)i[r]=t(a,a=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return i[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,"__esModule",{value:!0})},"object"==typeof r&&"undefined"!=typeof e?a(r,t("d3-color")):a((n=n||self).d3=n.d3||{},n.d3)},{"d3-color":156}],161:[function(t,e,r){var n;n=this,function(t){"use strict";var e=Math.PI,r=2*e,n=r-1e-6;function a(){this._x0=this._y0=this._x1=this._y1=null,this._=""}function i(){return new a}a.prototype=i.prototype={constructor:a,moveTo:function(t,e){this._+="M"+(this._x0=this._x1=+t)+","+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+="Z")},lineTo:function(t,e){this._+="L"+(this._x1=+t)+","+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+="Q"+ +t+","+ +e+","+(this._x1=+r)+","+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,a,i){this._+="C"+ +t+","+ +e+","+ +r+","+ +n+","+(this._x1=+a)+","+(this._y1=+i)},arcTo:function(t,r,n,a,i){t=+t,r=+r,n=+n,a=+a,i=+i;var o=this._x1,s=this._y1,l=n-t,c=a-r,u=o-t,h=s-r,f=u*u+h*h;if(i<0)throw new Error("negative radius: "+i);if(null===this._x1)this._+="M"+(this._x1=t)+","+(this._y1=r);else if(f>1e-6)if(Math.abs(h*l-c*u)>1e-6&&i){var p=n-o,d=a-s,g=l*l+c*c,v=p*p+d*d,m=Math.sqrt(g),y=Math.sqrt(f),x=i*Math.tan((e-Math.acos((g+f-v)/(2*m*y)))/2),b=x/y,_=x/m;Math.abs(b-1)>1e-6&&(this._+="L"+(t+b*u)+","+(r+b*h)),this._+="A"+i+","+i+",0,0,"+ +(h*p>u*d)+","+(this._x1=t+_*l)+","+(this._y1=r+_*c)}else this._+="L"+(this._x1=t)+","+(this._y1=r);else;},arc:function(t,a,i,o,s,l){t=+t,a=+a;var c=(i=+i)*Math.cos(o),u=i*Math.sin(o),h=t+c,f=a+u,p=1^l,d=l?o-s:s-o;if(i<0)throw new Error("negative radius: "+i);null===this._x1?this._+="M"+h+","+f:(Math.abs(this._x1-h)>1e-6||Math.abs(this._y1-f)>1e-6)&&(this._+="L"+h+","+f),i&&(d<0&&(d=d%r+r),d>n?this._+="A"+i+","+i+",0,1,"+p+","+(t-c)+","+(a-u)+"A"+i+","+i+",0,1,"+p+","+(this._x1=h)+","+(this._y1=f):d>1e-6&&(this._+="A"+i+","+i+",0,"+ +(d>=e)+","+p+","+(this._x1=t+i*Math.cos(s))+","+(this._y1=a+i*Math.sin(s))))},rect:function(t,e,r,n){this._+="M"+(this._x0=this._x1=+t)+","+(this._y0=this._y1=+e)+"h"+ +r+"v"+ +n+"h"+-r+"Z"},toString:function(){return this._}},t.path=i,Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:n.d3=n.d3||{})},{}],162:[function(t,e,r){var n;n=this,function(t){"use strict";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var a,i,o,s,l,c,u,h,f,p=t._root,d={data:n},g=t._x0,v=t._y0,m=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(i=(g+m)/2))?g=i:m=i,(u=r>=(o=(v+y)/2))?v=o:y=o,a=p,!(p=p[h=u<<1|c]))return a[h]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,a?a[h]=d:t._root=d,t;do{a=a?a[h]=new Array(4):t._root=new Array(4),(c=e>=(i=(g+m)/2))?g=i:m=i,(u=r>=(o=(v+y)/2))?v=o:y=o}while((h=u<<1|c)==(f=(l>=o)<<1|s>=i));return a[f]=p,a[h]=d,t}var r=function(t,e,r,n,a){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=a};function n(t){return t[0]}function a(t){return t[1]}function i(t,e,r){var i=new o(null==e?n:e,null==r?a:r,NaN,NaN,NaN,NaN);return null==t?i:i.addAll(t)}function o(t,e,r,n,a,i){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=a,this._y1=i,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=i.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var a=0;a<4;++a)(e=n.source[a])&&(e.length?t.push({source:e,target:n.target[a]=new Array(4)}):n.target[a]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,a,i,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,h=-1/0,f=-1/0;for(n=0;n<o;++n)isNaN(a=+this._x.call(null,r=t[n]))||isNaN(i=+this._y.call(null,r))||(s[n]=a,l[n]=i,a<c&&(c=a),a>h&&(h=a),i<u&&(u=i),i>f&&(f=i));for(h<c&&(c=this._x0,h=this._x1),f<u&&(u=this._y0,f=this._y1),this.cover(c,u).cover(h,f),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,a=this._x1,i=this._y1;if(isNaN(r))a=(r=Math.floor(t))+1,i=(n=Math.floor(e))+1;else{if(!(r>t||t>a||n>e||e>i))return this;var o,s,l=a-r,c=this._root;switch(s=(e<(n+i)/2)<<1|t<(r+a)/2){case 0:do{(o=new Array(4))[s]=c,c=o}while(i=n+(l*=2),t>(a=r+l)||e>i);break;case 1:do{(o=new Array(4))[s]=c,c=o}while(i=n+(l*=2),(r=a-l)>t||e>i);break;case 2:do{(o=new Array(4))[s]=c,c=o}while(n=i-(l*=2),t>(a=r+l)||n>e);break;case 3:do{(o=new Array(4))[s]=c,c=o}while(n=i-(l*=2),(r=a-l)>t||n>e)}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=a,this._y1=i,this},l.data=function(){var t=[];return this.visit(function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)}),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var a,i,o,s,l,c,u,h=this._x0,f=this._y0,p=this._x1,d=this._y1,g=[],v=this._root;for(v&&g.push(new r(v,h,f,p,d)),null==n?n=1/0:(h=t-n,f=e-n,p=t+n,d=e+n,n*=n);c=g.pop();)if(!(!(v=c.node)||(i=c.x0)>p||(o=c.y0)>d||(s=c.x1)<h||(l=c.y1)<f))if(v.length){var m=(i+s)/2,y=(o+l)/2;g.push(new r(v[3],m,y,s,l),new r(v[2],i,y,m,l),new r(v[1],m,o,s,y),new r(v[0],i,o,m,y)),(u=(e>=y)<<1|t>=m)&&(c=g[g.length-1],g[g.length-1]=g[g.length-1-u],g[g.length-1-u]=c)}else{var x=t-+this._x.call(null,v.data),b=e-+this._y.call(null,v.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);h=t-w,f=e-w,p=t+w,d=e+w,a=v.data}}return a},l.remove=function(t){if(isNaN(i=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,a,i,o,s,l,c,u,h,f,p=this._root,d=this._x0,g=this._y0,v=this._x1,m=this._y1;if(!p)return this;if(p.length)for(;;){if((c=i>=(s=(d+v)/2))?d=s:v=s,(u=o>=(l=(g+m)/2))?g=l:m=l,e=p,!(p=p[h=u<<1|c]))return this;if(!p.length)break;(e[h+1&3]||e[h+2&3]||e[h+3&3])&&(r=e,f=h)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(a=p.next)&&delete p.next,n?(a?n.next=a:delete n.next,this):e?(a?e[h]=a:delete e[h],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[f]=p:this._root=p),this):(this._root=a,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit(function(e){if(!e.length)do{++t}while(e=e.next)}),t},l.visit=function(t){var e,n,a,i,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,a=e.x0,i=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(a+o)/2,h=(i+s)/2;(n=c[3])&&l.push(new r(n,u,h,o,s)),(n=c[2])&&l.push(new r(n,a,h,u,s)),(n=c[1])&&l.push(new r(n,u,i,o,h)),(n=c[0])&&l.push(new r(n,a,i,u,h))}return this},l.visitAfter=function(t){var e,n=[],a=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var i=e.node;if(i.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,h=(s+c)/2,f=(l+u)/2;(o=i[0])&&n.push(new r(o,s,l,h,f)),(o=i[1])&&n.push(new r(o,h,l,c,f)),(o=i[2])&&n.push(new r(o,s,f,h,u)),(o=i[3])&&n.push(new r(o,h,f,c,u))}a.push(e)}for(;e=a.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=i,Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:n.d3=n.d3||{})},{}],163:[function(t,e,r){var n,a;n=this,a=function(t,e){"use strict";function r(t){return function(){return t}}var n=Math.abs,a=Math.atan2,i=Math.cos,o=Math.max,s=Math.min,l=Math.sin,c=Math.sqrt,u=1e-12,h=Math.PI,f=h/2,p=2*h;function d(t){return t>=1?f:t<=-1?-f:Math.asin(t)}function g(t){return t.innerRadius}function v(t){return t.outerRadius}function m(t){return t.startAngle}function y(t){return t.endAngle}function x(t){return t&&t.padAngle}function b(t,e,r,n,a,i,s){var l=t-r,u=e-n,h=(s?i:-i)/c(l*l+u*u),f=h*u,p=-h*l,d=t+f,g=e+p,v=r+f,m=n+p,y=(d+v)/2,x=(g+m)/2,b=v-d,_=m-g,w=b*b+_*_,k=a-i,T=d*m-v*g,M=(_<0?-1:1)*c(o(0,k*k*w-T*T)),A=(T*_-b*M)/w,S=(-T*b-_*M)/w,E=(T*_+b*M)/w,L=(-T*b+_*M)/w,C=A-y,P=S-x,O=E-y,z=L-x;return C*C+P*P>O*O+z*z&&(A=E,S=L),{cx:A,cy:S,x01:-f,y01:-p,x11:A*(a/k-1),y11:S*(a/k-1)}}function _(t){this._context=t}function w(t){return new _(t)}function k(t){return t[0]}function T(t){return t[1]}function M(){var t=k,n=T,a=r(!0),i=null,o=w,s=null;function l(r){var l,c,u,h=r.length,f=!1;for(null==i&&(s=o(u=e.path())),l=0;l<=h;++l)!(l<h&&a(c=r[l],l,r))===f&&((f=!f)?s.lineStart():s.lineEnd()),f&&s.point(+t(c,l,r),+n(c,l,r));if(u)return s=null,u+""||null}return l.x=function(e){return arguments.length?(t="function"==typeof e?e:r(+e),l):t},l.y=function(t){return arguments.length?(n="function"==typeof t?t:r(+t),l):n},l.defined=function(t){return arguments.length?(a="function"==typeof t?t:r(!!t),l):a},l.curve=function(t){return arguments.length?(o=t,null!=i&&(s=o(i)),l):o},l.context=function(t){return arguments.length?(null==t?i=s=null:s=o(i=t),l):i},l}function A(){var t=k,n=null,a=r(0),i=T,o=r(!0),s=null,l=w,c=null;function u(r){var u,h,f,p,d,g=r.length,v=!1,m=new Array(g),y=new Array(g);for(null==s&&(c=l(d=e.path())),u=0;u<=g;++u){if(!(u<g&&o(p=r[u],u,r))===v)if(v=!v)h=u,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),f=u-1;f>=h;--f)c.point(m[f],y[f]);c.lineEnd(),c.areaEnd()}v&&(m[u]=+t(p,u,r),y[u]=+a(p,u,r),c.point(n?+n(p,u,r):m[u],i?+i(p,u,r):y[u]))}if(d)return c=null,d+""||null}function h(){return M().defined(o).curve(l).context(s)}return u.x=function(e){return arguments.length?(t="function"==typeof e?e:r(+e),n=null,u):t},u.x0=function(e){return arguments.length?(t="function"==typeof e?e:r(+e),u):t},u.x1=function(t){return arguments.length?(n=null==t?null:"function"==typeof t?t:r(+t),u):n},u.y=function(t){return arguments.length?(a="function"==typeof t?t:r(+t),i=null,u):a},u.y0=function(t){return arguments.length?(a="function"==typeof t?t:r(+t),u):a},u.y1=function(t){return arguments.length?(i=null==t?null:"function"==typeof t?t:r(+t),u):i},u.lineX0=u.lineY0=function(){return h().x(t).y(a)},u.lineY1=function(){return h().x(t).y(i)},u.lineX1=function(){return h().x(n).y(a)},u.defined=function(t){return arguments.length?(o="function"==typeof t?t:r(!!t),u):o},u.curve=function(t){return arguments.length?(l=t,null!=s&&(c=l(s)),u):l},u.context=function(t){return arguments.length?(null==t?s=c=null:c=l(s=t),u):s},u}function S(t,e){return e<t?-1:e>t?1:e>=t?0:NaN}function E(t){return t}_.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var L=P(w);function C(t){this._curve=t}function P(t){function e(e){return new C(t(e))}return e._curve=t,e}function O(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function z(){return O(M().curve(L))}function I(){var t=A().curve(L),e=t.curve,r=t.lineX0,n=t.lineX1,a=t.lineY0,i=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return O(r())},delete t.lineX0,t.lineEndAngle=function(){return O(n())},delete t.lineX1,t.lineInnerRadius=function(){return O(a())},delete t.lineY0,t.lineOuterRadius=function(){return O(i())},delete t.lineY1,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function D(t,e){return[(e=+e)*Math.cos(t-=Math.PI/2),e*Math.sin(t)]}C.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var R=Array.prototype.slice;function F(t){return t.source}function B(t){return t.target}function N(t){var n=F,a=B,i=k,o=T,s=null;function l(){var r,l=R.call(arguments),c=n.apply(this,l),u=a.apply(this,l);if(s||(s=r=e.path()),t(s,+i.apply(this,(l[0]=c,l)),+o.apply(this,l),+i.apply(this,(l[0]=u,l)),+o.apply(this,l)),r)return s=null,r+""||null}return l.source=function(t){return arguments.length?(n=t,l):n},l.target=function(t){return arguments.length?(a=t,l):a},l.x=function(t){return arguments.length?(i="function"==typeof t?t:r(+t),l):i},l.y=function(t){return arguments.length?(o="function"==typeof t?t:r(+t),l):o},l.context=function(t){return arguments.length?(s=null==t?null:t,l):s},l}function j(t,e,r,n,a){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,a,n,a)}function V(t,e,r,n,a){t.moveTo(e,r),t.bezierCurveTo(e,r=(r+a)/2,n,r,n,a)}function U(t,e,r,n,a){var i=D(e,r),o=D(e,r=(r+a)/2),s=D(n,r),l=D(n,a);t.moveTo(i[0],i[1]),t.bezierCurveTo(o[0],o[1],s[0],s[1],l[0],l[1])}var q={draw:function(t,e){var r=Math.sqrt(e/h);t.moveTo(r,0),t.arc(0,0,r,0,p)}},H={draw:function(t,e){var r=Math.sqrt(e/5)/2;t.moveTo(-3*r,-r),t.lineTo(-r,-r),t.lineTo(-r,-3*r),t.lineTo(r,-3*r),t.lineTo(r,-r),t.lineTo(3*r,-r),t.lineTo(3*r,r),t.lineTo(r,r),t.lineTo(r,3*r),t.lineTo(-r,3*r),t.lineTo(-r,r),t.lineTo(-3*r,r),t.closePath()}},G=Math.sqrt(1/3),Y=2*G,W={draw:function(t,e){var r=Math.sqrt(e/Y),n=r*G;t.moveTo(0,-r),t.lineTo(n,0),t.lineTo(0,r),t.lineTo(-n,0),t.closePath()}},X=Math.sin(h/10)/Math.sin(7*h/10),Z=Math.sin(p/10)*X,J=-Math.cos(p/10)*X,K={draw:function(t,e){var r=Math.sqrt(.8908130915292852*e),n=Z*r,a=J*r;t.moveTo(0,-r),t.lineTo(n,a);for(var i=1;i<5;++i){var o=p*i/5,s=Math.cos(o),l=Math.sin(o);t.lineTo(l*r,-s*r),t.lineTo(s*n-l*a,l*n+s*a)}t.closePath()}},Q={draw:function(t,e){var r=Math.sqrt(e),n=-r/2;t.rect(n,n,r,r)}},$=Math.sqrt(3),tt={draw:function(t,e){var r=-Math.sqrt(e/(3*$));t.moveTo(0,2*r),t.lineTo(-$*r,-r),t.lineTo($*r,-r),t.closePath()}},et=-.5,rt=Math.sqrt(3)/2,nt=1/Math.sqrt(12),at=3*(nt/2+1),it={draw:function(t,e){var r=Math.sqrt(e/at),n=r/2,a=r*nt,i=n,o=r*nt+r,s=-i,l=o;t.moveTo(n,a),t.lineTo(i,o),t.lineTo(s,l),t.lineTo(et*n-rt*a,rt*n+et*a),t.lineTo(et*i-rt*o,rt*i+et*o),t.lineTo(et*s-rt*l,rt*s+et*l),t.lineTo(et*n+rt*a,et*a-rt*n),t.lineTo(et*i+rt*o,et*o-rt*i),t.lineTo(et*s+rt*l,et*l-rt*s),t.closePath()}},ot=[q,H,W,Q,K,tt,it];function st(){}function lt(t,e,r){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+r)/6)}function ct(t){this._context=t}function ut(t){this._context=t}function ht(t){this._context=t}function ft(t,e){this._basis=new ct(t),this._beta=e}ct.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:lt(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ut.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ht.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var r=(this._x0+4*this._x1+t)/6,n=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(r,n):this._context.moveTo(r,n);break;case 3:this._point=4;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ft.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,r=t.length-1;if(r>0)for(var n,a=t[0],i=e[0],o=t[r]-a,s=e[r]-i,l=-1;++l<=r;)n=l/r,this._basis.point(this._beta*t[l]+(1-this._beta)*(a+n*o),this._beta*e[l]+(1-this._beta)*(i+n*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var pt=function t(e){function r(t){return 1===e?new ct(t):new ft(t,e)}return r.beta=function(e){return t(+e)},r}(.85);function dt(t,e,r){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-r),t._x2,t._y2)}function gt(t,e){this._context=t,this._k=(1-e)/6}gt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:dt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var vt=function t(e){function r(t){return new gt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function mt(t,e){this._context=t,this._k=(1-e)/6}mt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var yt=function t(e){function r(t){return new mt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function xt(t,e){this._context=t,this._k=(1-e)/6}xt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var bt=function t(e){function r(t){return new xt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function _t(t,e,r){var n=t._x1,a=t._y1,i=t._x2,o=t._y2;if(t._l01_a>u){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);n=(n*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,a=(a*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>u){var c=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,h=3*t._l23_a*(t._l23_a+t._l12_a);i=(i*c+t._x1*t._l23_2a-e*t._l12_2a)/h,o=(o*c+t._y1*t._l23_2a-r*t._l12_2a)/h}t._context.bezierCurveTo(n,a,i,o,t._x2,t._y2)}function wt(t,e){this._context=t,this._alpha=e}wt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var kt=function t(e){function r(t){return e?new wt(t,e):new gt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Tt(t,e){this._context=t,this._alpha=e}Tt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var Mt=function t(e){function r(t){return e?new Tt(t,e):new mt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function At(t,e){this._context=t,this._alpha=e}At.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var St=function t(e){function r(t){return e?new At(t,e):new xt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Et(t){this._context=t}function Lt(t){return t<0?-1:1}function Ct(t,e,r){var n=t._x1-t._x0,a=e-t._x1,i=(t._y1-t._y0)/(n||a<0&&-0),o=(r-t._y1)/(a||n<0&&-0),s=(i*a+o*n)/(n+a);return(Lt(i)+Lt(o))*Math.min(Math.abs(i),Math.abs(o),.5*Math.abs(s))||0}function Pt(t,e){var r=t._x1-t._x0;return r?(3*(t._y1-t._y0)/r-e)/2:e}function Ot(t,e,r){var n=t._x0,a=t._y0,i=t._x1,o=t._y1,s=(i-n)/3;t._context.bezierCurveTo(n+s,a+s*e,i-s,o-s*r,i,o)}function zt(t){this._context=t}function It(t){this._context=new Dt(t)}function Dt(t){this._context=t}function Rt(t){this._context=t}function Ft(t){var e,r,n=t.length-1,a=new Array(n),i=new Array(n),o=new Array(n);for(a[0]=0,i[0]=2,o[0]=t[0]+2*t[1],e=1;e<n-1;++e)a[e]=1,i[e]=4,o[e]=4*t[e]+2*t[e+1];for(a[n-1]=2,i[n-1]=7,o[n-1]=8*t[n-1]+t[n],e=1;e<n;++e)r=a[e]/i[e-1],i[e]-=r,o[e]-=r*o[e-1];for(a[n-1]=o[n-1]/i[n-1],e=n-2;e>=0;--e)a[e]=(o[e]-a[e+1])/i[e];for(i[n-1]=(t[n]+a[n-1])/2,e=0;e<n-1;++e)i[e]=2*t[e+1]-a[e+1];return[a,i]}function Bt(t,e){this._context=t,this._t=e}function Nt(t,e){if((a=t.length)>1)for(var r,n,a,i=1,o=t[e[0]],s=o.length;i<a;++i)for(n=o,o=t[e[i]],r=0;r<s;++r)o[r][1]+=o[r][0]=isNaN(n[r][1])?n[r][0]:n[r][1]}function jt(t){for(var e=t.length,r=new Array(e);--e>=0;)r[e]=e;return r}function Vt(t,e){return t[e]}function Ut(t){var e=t.map(qt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function qt(t){for(var e,r=-1,n=0,a=t.length,i=-1/0;++r<a;)(e=+t[r][1])>i&&(i=e,n=r);return n}function Ht(t){var e=t.map(Gt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function Gt(t){for(var e,r=0,n=-1,a=t.length;++n<a;)(e=+t[n][1])&&(r+=e);return r}Et.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}},zt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:Ot(this,this._t0,Pt(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var r=NaN;if(e=+e,(t=+t)!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,Ot(this,Pt(this,r=Ct(this,t,e)),r);break;default:Ot(this,this._t0,r=Ct(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=r}}},(It.prototype=Object.create(zt.prototype)).point=function(t,e){zt.prototype.point.call(this,e,t)},Dt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,r,n,a,i){this._context.bezierCurveTo(e,t,n,r,i,a)}},Rt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,r=t.length;if(r)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===r)this._context.lineTo(t[1],e[1]);else for(var n=Ft(t),a=Ft(e),i=0,o=1;o<r;++i,++o)this._context.bezierCurveTo(n[0][i],a[0][i],n[1][i],a[1][i],t[o],e[o]);(this._line||0!==this._line&&1===r)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}},Bt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var r=this._x*(1-this._t)+t*this._t;this._context.lineTo(r,this._y),this._context.lineTo(r,e)}}this._x=t,this._y=e}},t.arc=function(){var t=g,o=v,_=r(0),w=null,k=m,T=y,M=x,A=null;function S(){var r,g,v,m=+t.apply(this,arguments),y=+o.apply(this,arguments),x=k.apply(this,arguments)-f,S=T.apply(this,arguments)-f,E=n(S-x),L=S>x;if(A||(A=r=e.path()),y<m&&(g=y,y=m,m=g),y>u)if(E>p-u)A.moveTo(y*i(x),y*l(x)),A.arc(0,0,y,x,S,!L),m>u&&(A.moveTo(m*i(S),m*l(S)),A.arc(0,0,m,S,x,L));else{var C,P,O=x,z=S,I=x,D=S,R=E,F=E,B=M.apply(this,arguments)/2,N=B>u&&(w?+w.apply(this,arguments):c(m*m+y*y)),j=s(n(y-m)/2,+_.apply(this,arguments)),V=j,U=j;if(N>u){var q=d(N/m*l(B)),H=d(N/y*l(B));(R-=2*q)>u?(I+=q*=L?1:-1,D-=q):(R=0,I=D=(x+S)/2),(F-=2*H)>u?(O+=H*=L?1:-1,z-=H):(F=0,O=z=(x+S)/2)}var G=y*i(O),Y=y*l(O),W=m*i(D),X=m*l(D);if(j>u){var Z,J=y*i(z),K=y*l(z),Q=m*i(I),$=m*l(I);if(E<h&&(Z=function(t,e,r,n,a,i,o,s){var l=r-t,c=n-e,h=o-a,f=s-i,p=f*l-h*c;if(!(p*p<u))return[t+(p=(h*(e-i)-f*(t-a))/p)*l,e+p*c]}(G,Y,Q,$,J,K,W,X))){var tt=G-Z[0],et=Y-Z[1],rt=J-Z[0],nt=K-Z[1],at=1/l(((v=(tt*rt+et*nt)/(c(tt*tt+et*et)*c(rt*rt+nt*nt)))>1?0:v<-1?h:Math.acos(v))/2),it=c(Z[0]*Z[0]+Z[1]*Z[1]);V=s(j,(m-it)/(at-1)),U=s(j,(y-it)/(at+1))}}F>u?U>u?(C=b(Q,$,G,Y,y,U,L),P=b(J,K,W,X,y,U,L),A.moveTo(C.cx+C.x01,C.cy+C.y01),U<j?A.arc(C.cx,C.cy,U,a(C.y01,C.x01),a(P.y01,P.x01),!L):(A.arc(C.cx,C.cy,U,a(C.y01,C.x01),a(C.y11,C.x11),!L),A.arc(0,0,y,a(C.cy+C.y11,C.cx+C.x11),a(P.cy+P.y11,P.cx+P.x11),!L),A.arc(P.cx,P.cy,U,a(P.y11,P.x11),a(P.y01,P.x01),!L))):(A.moveTo(G,Y),A.arc(0,0,y,O,z,!L)):A.moveTo(G,Y),m>u&&R>u?V>u?(C=b(W,X,J,K,m,-V,L),P=b(G,Y,Q,$,m,-V,L),A.lineTo(C.cx+C.x01,C.cy+C.y01),V<j?A.arc(C.cx,C.cy,V,a(C.y01,C.x01),a(P.y01,P.x01),!L):(A.arc(C.cx,C.cy,V,a(C.y01,C.x01),a(C.y11,C.x11),!L),A.arc(0,0,m,a(C.cy+C.y11,C.cx+C.x11),a(P.cy+P.y11,P.cx+P.x11),L),A.arc(P.cx,P.cy,V,a(P.y11,P.x11),a(P.y01,P.x01),!L))):A.arc(0,0,m,D,I,L):A.lineTo(W,X)}else A.moveTo(0,0);if(A.closePath(),r)return A=null,r+""||null}return S.centroid=function(){var e=(+t.apply(this,arguments)+ +o.apply(this,arguments))/2,r=(+k.apply(this,arguments)+ +T.apply(this,arguments))/2-h/2;return[i(r)*e,l(r)*e]},S.innerRadius=function(e){return arguments.length?(t="function"==typeof e?e:r(+e),S):t},S.outerRadius=function(t){return arguments.length?(o="function"==typeof t?t:r(+t),S):o},S.cornerRadius=function(t){return arguments.length?(_="function"==typeof t?t:r(+t),S):_},S.padRadius=function(t){return arguments.length?(w=null==t?null:"function"==typeof t?t:r(+t),S):w},S.startAngle=function(t){return arguments.length?(k="function"==typeof t?t:r(+t),S):k},S.endAngle=function(t){return arguments.length?(T="function"==typeof t?t:r(+t),S):T},S.padAngle=function(t){return arguments.length?(M="function"==typeof t?t:r(+t),S):M},S.context=function(t){return arguments.length?(A=null==t?null:t,S):A},S},t.area=A,t.line=M,t.pie=function(){var t=E,e=S,n=null,a=r(0),i=r(p),o=r(0);function s(r){var s,l,c,u,h,f=r.length,d=0,g=new Array(f),v=new Array(f),m=+a.apply(this,arguments),y=Math.min(p,Math.max(-p,i.apply(this,arguments)-m)),x=Math.min(Math.abs(y)/f,o.apply(this,arguments)),b=x*(y<0?-1:1);for(s=0;s<f;++s)(h=v[g[s]=s]=+t(r[s],s,r))>0&&(d+=h);for(null!=e?g.sort(function(t,r){return e(v[t],v[r])}):null!=n&&g.sort(function(t,e){return n(r[t],r[e])}),s=0,c=d?(y-f*b)/d:0;s<f;++s,m=u)l=g[s],u=m+((h=v[l])>0?h*c:0)+b,v[l]={data:r[l],index:s,value:h,startAngle:m,endAngle:u,padAngle:x};return v}return s.value=function(e){return arguments.length?(t="function"==typeof e?e:r(+e),s):t},s.sortValues=function(t){return arguments.length?(e=t,n=null,s):e},s.sort=function(t){return arguments.length?(n=t,e=null,s):n},s.startAngle=function(t){return arguments.length?(a="function"==typeof t?t:r(+t),s):a},s.endAngle=function(t){return arguments.length?(i="function"==typeof t?t:r(+t),s):i},s.padAngle=function(t){return arguments.length?(o="function"==typeof t?t:r(+t),s):o},s},t.areaRadial=I,t.radialArea=I,t.lineRadial=z,t.radialLine=z,t.pointRadial=D,t.linkHorizontal=function(){return N(j)},t.linkVertical=function(){return N(V)},t.linkRadial=function(){var t=N(U);return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t},t.symbol=function(){var t=r(q),n=r(64),a=null;function i(){var r;if(a||(a=r=e.path()),t.apply(this,arguments).draw(a,+n.apply(this,arguments)),r)return a=null,r+""||null}return i.type=function(e){return arguments.length?(t="function"==typeof e?e:r(e),i):t},i.size=function(t){return arguments.length?(n="function"==typeof t?t:r(+t),i):n},i.context=function(t){return arguments.length?(a=null==t?null:t,i):a},i},t.symbols=ot,t.symbolCircle=q,t.symbolCross=H,t.symbolDiamond=W,t.symbolSquare=Q,t.symbolStar=K,t.symbolTriangle=tt,t.symbolWye=it,t.curveBasisClosed=function(t){return new ut(t)},t.curveBasisOpen=function(t){return new ht(t)},t.curveBasis=function(t){return new ct(t)},t.curveBundle=pt,t.curveCardinalClosed=yt,t.curveCardinalOpen=bt,t.curveCardinal=vt,t.curveCatmullRomClosed=Mt,t.curveCatmullRomOpen=St,t.curveCatmullRom=kt,t.curveLinearClosed=function(t){return new Et(t)},t.curveLinear=w,t.curveMonotoneX=function(t){return new zt(t)},t.curveMonotoneY=function(t){return new It(t)},t.curveNatural=function(t){return new Rt(t)},t.curveStep=function(t){return new Bt(t,.5)},t.curveStepAfter=function(t){return new Bt(t,1)},t.curveStepBefore=function(t){return new Bt(t,0)},t.stack=function(){var t=r([]),e=jt,n=Nt,a=Vt;function i(r){var i,o,s=t.apply(this,arguments),l=r.length,c=s.length,u=new Array(c);for(i=0;i<c;++i){for(var h,f=s[i],p=u[i]=new Array(l),d=0;d<l;++d)p[d]=h=[0,+a(r[d],f,d,r)],h.data=r[d];p.key=f}for(i=0,o=e(u);i<c;++i)u[o[i]].index=i;return n(u,o),u}return i.keys=function(e){return arguments.length?(t="function"==typeof e?e:r(R.call(e)),i):t},i.value=function(t){return arguments.length?(a="function"==typeof t?t:r(+t),i):a},i.order=function(t){return arguments.length?(e=null==t?jt:"function"==typeof t?t:r(R.call(t)),i):e},i.offset=function(t){return arguments.length?(n=null==t?Nt:t,i):n},i},t.stackOffsetExpand=function(t,e){if((n=t.length)>0){for(var r,n,a,i=0,o=t[0].length;i<o;++i){for(a=r=0;r<n;++r)a+=t[r][i][1]||0;if(a)for(r=0;r<n;++r)t[r][i][1]/=a}Nt(t,e)}},t.stackOffsetDiverging=function(t,e){if((s=t.length)>1)for(var r,n,a,i,o,s,l=0,c=t[e[0]].length;l<c;++l)for(i=o=0,r=0;r<s;++r)(a=(n=t[e[r]][l])[1]-n[0])>=0?(n[0]=i,n[1]=i+=a):a<0?(n[1]=o,n[0]=o+=a):n[0]=i},t.stackOffsetNone=Nt,t.stackOffsetSilhouette=function(t,e){if((r=t.length)>0){for(var r,n=0,a=t[e[0]],i=a.length;n<i;++n){for(var o=0,s=0;o<r;++o)s+=t[o][n][1]||0;a[n][1]+=a[n][0]=-s/2}Nt(t,e)}},t.stackOffsetWiggle=function(t,e){if((a=t.length)>0&&(n=(r=t[e[0]]).length)>0){for(var r,n,a,i=0,o=1;o<n;++o){for(var s=0,l=0,c=0;s<a;++s){for(var u=t[e[s]],h=u[o][1]||0,f=(h-(u[o-1][1]||0))/2,p=0;p<s;++p){var d=t[e[p]];f+=(d[o][1]||0)-(d[o-1][1]||0)}l+=h,c+=f*h}r[o-1][1]+=r[o-1][0]=i,l&&(i-=c/l)}r[o-1][1]+=r[o-1][0]=i,Nt(t,e)}},t.stackOrderAppearance=Ut,t.stackOrderAscending=Ht,t.stackOrderDescending=function(t){return Ht(t).reverse()},t.stackOrderInsideOut=function(t){var e,r,n=t.length,a=t.map(Gt),i=Ut(t),o=0,s=0,l=[],c=[];for(e=0;e<n;++e)r=i[e],o<s?(o+=a[r],l.push(r)):(s+=a[r],c.push(r));return c.reverse().concat(l)},t.stackOrderNone=jt,t.stackOrderReverse=function(t){return jt(t).reverse()},Object.defineProperty(t,"__esModule",{value:!0})},"object"==typeof r&&"undefined"!=typeof e?a(r,t("d3-path")):a(n.d3=n.d3||{},n.d3)},{"d3-path":161}],164:[function(t,e,r){var n;n=this,function(t){"use strict";var e,r,n=0,a=0,i=0,o=1e3,s=0,l=0,c=0,u="object"==typeof performance&&performance.now?performance:Date,h="object"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function f(){return l||(h(p),l=u.now()+c)}function p(){l=0}function d(){this._call=this._time=this._next=null}function g(t,e,r){var n=new d;return n.restart(t,e,r),n}function v(){f(),++n;for(var t,r=e;r;)(t=l-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function m(){l=(s=u.now())+c,n=a=0;try{v()}finally{n=0,function(){var t,n,a=e,i=1/0;for(;a;)a._call?(i>a._time&&(i=a._time),t=a,a=a._next):(n=a._next,a._next=null,a=t?t._next=n:e=n);r=t,x(i)}(),l=0}}function y(){var t=u.now(),e=t-s;e>o&&(c-=e,s=t)}function x(t){n||(a&&(a=clearTimeout(a)),t-l>24?(t<1/0&&(a=setTimeout(m,t-u.now()-c)),i&&(i=clearInterval(i))):(i||(s=u.now(),i=setInterval(y,o)),n=1,h(m)))}d.prototype=g.prototype={constructor:d,restart:function(t,n,a){if("function"!=typeof t)throw new TypeError("callback is not a function");a=(null==a?f():+a)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=a,x()},stop:function(){this._call&&(this._call=null,this._time=1/0,x())}},t.now=f,t.timer=g,t.timerFlush=v,t.timeout=function(t,e,r){var n=new d;return e=null==e?0:+e,n.restart(function(r){n.stop(),t(r+e)},e,r),n},t.interval=function(t,e,r){var n=new d,a=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?f():+r,n.restart(function i(o){o+=a,n.restart(i,a+=e,r),t(o)},e,r),n)},Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:n.d3=n.d3||{})},{}],165:[function(t,e,r){!function(){var t={version:"3.5.17"},r=[].slice,n=function(t){return r.call(t)},a=this.document;function i(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(a)try{n(a.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),a)try{a.createElement("DIV").style.setProperty("opacity",0,"")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,h=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+"")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+"")},u.setProperty=function(t,e,r){h.call(this,t,e+"",r)}}function f(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function g(t){return{left:function(e,r,n,a){for(arguments.length<3&&(n=0),arguments.length<4&&(a=e.length);n<a;){var i=n+a>>>1;t(e[i],r)<0?n=i+1:a=i}return n},right:function(e,r,n,a){for(arguments.length<3&&(n=0),arguments.length<4&&(a=e.length);n<a;){var i=n+a>>>1;t(e[i],r)>0?a=i:n=i+1}return n}}}t.ascending=f,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,a=-1,i=t.length;if(1===arguments.length){for(;++a<i;)if(null!=(n=t[a])&&n>=n){r=n;break}for(;++a<i;)null!=(n=t[a])&&r>n&&(r=n)}else{for(;++a<i;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=n;break}for(;++a<i;)null!=(n=e.call(t,t[a],a))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,a=-1,i=t.length;if(1===arguments.length){for(;++a<i;)if(null!=(n=t[a])&&n>=n){r=n;break}for(;++a<i;)null!=(n=t[a])&&n>r&&(r=n)}else{for(;++a<i;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=n;break}for(;++a<i;)null!=(n=e.call(t,t[a],a))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,a,i=-1,o=t.length;if(1===arguments.length){for(;++i<o;)if(null!=(n=t[i])&&n>=n){r=a=n;break}for(;++i<o;)null!=(n=t[i])&&(r>n&&(r=n),a<n&&(a=n))}else{for(;++i<o;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=a=n;break}for(;++i<o;)null!=(n=e.call(t,t[i],i))&&(r>n&&(r=n),a<n&&(a=n))}return[r,a]},t.sum=function(t,e){var r,n=0,a=t.length,i=-1;if(1===arguments.length)for(;++i<a;)d(r=+t[i])&&(n+=r);else for(;++i<a;)d(r=+e.call(t,t[i],i))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,a=t.length,i=-1,o=a;if(1===arguments.length)for(;++i<a;)d(r=p(t[i]))?n+=r:--o;else for(;++i<a;)d(r=p(e.call(t,t[i],i)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),a=+t[n-1],i=r-n;return i?a+i*(t[n]-a):a},t.median=function(e,r){var n,a=[],i=e.length,o=-1;if(1===arguments.length)for(;++o<i;)d(n=p(e[o]))&&a.push(n);else for(;++o<i;)d(n=p(r.call(e,e[o],o)))&&a.push(n);if(a.length)return t.quantile(a.sort(f),.5)},t.variance=function(t,e){var r,n,a=t.length,i=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<a;)d(r=p(t[s]))&&(o+=(n=r-i)*(r-(i+=n/++l)));else for(;++s<a;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-i)*(r-(i+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var v=g(f);function m(t){return t.length}t.bisectLeft=v.left,t.bisect=t.bisectRight=v.right,t.bisector=function(t){return g(1===t.length?function(e,r){return f(t(e),r)}:t)},t.shuffle=function(t,e,r){(i=arguments.length)<3&&(r=t.length,i<2&&(e=0));for(var n,a,i=r-e;i;)a=Math.random()*i--|0,n=t[i+e],t[i+e]=t[a+e],t[a+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],a=new Array(r<0?0:r);e<r;)a[e]=[n,n=t[++e]];return a},t.transpose=function(e){if(!(i=e.length))return[];for(var r=-1,n=t.min(e,m),a=new Array(n);++r<n;)for(var i,o=-1,s=a[r]=new Array(i);++o<i;)s[o]=e[o][r];return a},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,a=t.length,i=-1,o=0;++i<a;)o+=t[i].length;for(r=new Array(o);--a>=0;)for(e=(n=t[a]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function b(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error("infinite range");var n,a=[],i=function(t){var e=1;for(;t*e%1;)e*=10;return e}(y(r)),o=-1;if(t*=i,e*=i,(r*=i)<0)for(;(n=t+r*++o)>e;)a.push(n/i);else for(;(n=t+r*++o)<e;)a.push(n/i);return a},t.map=function(t,e){var r=new b;if(t instanceof b)t.forEach(function(t,e){r.set(t,e)});else if(Array.isArray(t)){var n,a=-1,i=t.length;if(1===arguments.length)for(;++a<i;)r.set(a,t[a]);else for(;++a<i;)r.set(e.call(t,n=t[a],a),n)}else for(var o in t)r.set(o,t[o]);return r};var _="__proto__",w="\0";function k(t){return(t+="")===_||t[0]===w?w+t:t}function T(t){return(t+="")[0]===w?t.slice(1):t}function M(t){return k(t)in this._}function A(t){return(t=k(t))in this._&&delete this._[t]}function S(){var t=[];for(var e in this._)t.push(T(e));return t}function E(){var t=0;for(var e in this._)++t;return t}function L(){for(var t in this._)return!1;return!0}function C(){this._=Object.create(null)}function P(t){return t}function O(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function z(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=I.length;r<n;++r){var a=I[r]+e;if(a in t)return a}}x(b,{has:M,get:function(t){return this._[k(t)]},set:function(t,e){return this._[k(t)]=e},remove:A,keys:S,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:T(e),value:this._[e]});return t},size:E,empty:L,forEach:function(t){for(var e in this._)t.call(this,T(e),this._[e])}}),t.nest=function(){var e,r,n={},a=[],i=[];function o(t,i,s){if(s>=a.length)return r?r.call(n,i):e?i.sort(e):i;for(var l,c,u,h,f=-1,p=i.length,d=a[s++],g=new b;++f<p;)(h=g.get(l=d(c=i[f])))?h.push(c):g.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),g.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=a.length)return e;var n=[],o=i[r++];return e.forEach(function(e,a){n.push({key:e,values:t(a,r)})}),o?n.sort(function(t,e){return o(t.key,e.key)}):n}(o(t.map,e,0),0)},n.key=function(t){return a.push(t),n},n.sortKeys=function(t){return i[a.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new C;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},x(C,{has:M,add:function(t){return this._[k(t+="")]=!0,t},remove:A,values:S,size:E,empty:L,forEach:function(t){for(var e in this._)t.call(this,T(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,a=arguments.length;++n<a;)t[r=arguments[n]]=O(t,e,e[r]);return t};var I=["webkit","ms","moz","Moz","o","O"];function D(){}function R(){}function F(t){var e=[],r=new b;function n(){for(var r,n=e,a=-1,i=n.length;++a<i;)(r=n[a].on)&&r.apply(this,arguments);return t}return n.on=function(n,a){var i,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,i=e.indexOf(o)).concat(e.slice(i+1)),r.remove(n)),a&&e.push(r.set(n,{on:a})),t)},n}function B(){t.event.preventDefault()}function N(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function j(e){for(var r=new R,n=0,a=arguments.length;++n<a;)r[arguments[n]]=F(r);return r.of=function(n,a){return function(i){try{var o=i.sourceEvent=t.event;i.target=e,t.event=i,r[i.type].apply(n,a)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new R,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=F(t);return t},R.prototype.on=function(t,e){var r=t.indexOf("."),n="";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(V,"\\$&")};var V=/[\\\^\$\*\+\?\|\[\]\(\)\.\{\}]/g,U={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function q(t){return U(t,W),t}var H=function(t,e){return e.querySelector(t)},G=function(t,e){return e.querySelectorAll(t)},Y=function(t,e){var r=t.matches||t[z(t,"matchesSelector")];return(Y=function(t,e){return r.call(t,e)})(t,e)};"function"==typeof Sizzle&&(H=function(t,e){return Sizzle(t,e)[0]||null},G=Sizzle,Y=Sizzle.matchesSelector),t.selection=function(){return t.select(a.documentElement)};var W=t.selection.prototype=[];function X(t){return"function"==typeof t?t:function(){return H(t,this)}}function Z(t){return"function"==typeof t?t:function(){return G(t,this)}}W.select=function(t){var e,r,n,a,i=[];t=X(t);for(var o=-1,s=this.length;++o<s;){i.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(a=n[l])?(e.push(r=t.call(a,a.__data__,l,o)),r&&"__data__"in a&&(r.__data__=a.__data__)):e.push(null)}return q(i)},W.selectAll=function(t){var e,r,a=[];t=Z(t);for(var i=-1,o=this.length;++i<o;)for(var s=this[i],l=-1,c=s.length;++l<c;)(r=s[l])&&(a.push(e=n(t.call(r,r.__data__,l,i))),e.parentNode=r);return q(a)};var J="http://www.w3.org/1999/xhtml",K={svg:"http://www.w3.org/2000/svg",xhtml:J,xlink:"http://www.w3.org/1999/xlink",xml:"http://www.w3.org/XML/1998/namespace",xmlns:"http://www.w3.org/2000/xmlns/"};function Q(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:"function"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function $(t){return t.trim().replace(/\s+/g," ")}function tt(e){return new RegExp("(?:^|\\s+)"+t.requote(e)+"(?:\\s+|$)","g")}function et(t){return(t+"").trim().split(/^|\s+/)}function rt(t,e){var r=(t=et(t).map(nt)).length;return"function"==typeof e?function(){for(var n=-1,a=e.apply(this,arguments);++n<r;)t[n](this,a)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function nt(t){var e=tt(t);return function(r,n){if(a=r.classList)return n?a.add(t):a.remove(t);var a=r.getAttribute("class")||"";n?(e.lastIndex=0,e.test(a)||r.setAttribute("class",$(a+" "+t))):r.setAttribute("class",$(a.replace(e," ")))}}function at(t,e,r){return null==e?function(){this.style.removeProperty(t)}:"function"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function it(t,e){return null==e?function(){delete this[t]}:"function"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function ot(e){return"function"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===J&&t.documentElement.namespaceURI===J?t.createElement(e):t.createElementNS(r,e)}}function st(){var t=this.parentNode;t&&t.removeChild(this)}function lt(t){return{__data__:t}}function ct(t){return function(){return Y(this,t)}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var a,i=t[r],o=0,s=i.length;o<s;o++)(a=i[o])&&e(a,o,r);return t}function ht(t){return U(t,ft),t}t.ns={prefix:K,qualify:function(t){var e=t.indexOf(":"),r=t;return e>=0&&"xmlns"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),K.hasOwnProperty(r)?{space:K[r],local:t}:t}},W.attr=function(e,r){if(arguments.length<2){if("string"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each(Q(r,e[r]));return this}return this.each(Q(e,r))},W.classed=function(t,e){if(arguments.length<2){if("string"==typeof t){var r=this.node(),n=(t=et(t)).length,a=-1;if(e=r.classList){for(;++a<n;)if(!e.contains(t[a]))return!1}else for(e=r.getAttribute("class");++a<n;)if(!tt(t[a]).test(e))return!1;return!0}for(e in t)this.each(rt(e,t[e]));return this}return this.each(rt(t,e))},W.style=function(t,e,r){var n=arguments.length;if(n<3){if("string"!=typeof t){for(r in n<2&&(e=""),t)this.each(at(r,t[r],e));return this}if(n<2){var a=this.node();return o(a).getComputedStyle(a,null).getPropertyValue(t)}r=""}return this.each(at(t,e,r))},W.property=function(t,e){if(arguments.length<2){if("string"==typeof t)return this.node()[t];for(e in t)this.each(it(e,t[e]));return this}return this.each(it(t,e))},W.text=function(t){return arguments.length?this.each("function"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?"":e}:null==t?function(){this.textContent=""}:function(){this.textContent=t}):this.node().textContent},W.html=function(t){return arguments.length?this.each("function"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?"":e}:null==t?function(){this.innerHTML=""}:function(){this.innerHTML=t}):this.node().innerHTML},W.append=function(t){return t=ot(t),this.select(function(){return this.appendChild(t.apply(this,arguments))})},W.insert=function(t,e){return t=ot(t),e=X(e),this.select(function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)})},W.remove=function(){return this.each(st)},W.data=function(t,e){var r,n,a=-1,i=this.length;if(!arguments.length){for(t=new Array(i=(r=this[0]).length);++a<i;)(n=r[a])&&(t[a]=n.__data__);return t}function o(t,r){var n,a,i,o=t.length,u=r.length,h=Math.min(o,u),f=new Array(u),p=new Array(u),d=new Array(o);if(e){var g,v=new b,m=new Array(o);for(n=-1;++n<o;)(a=t[n])&&(v.has(g=e.call(a,a.__data__,n))?d[n]=a:v.set(g,a),m[n]=g);for(n=-1;++n<u;)(a=v.get(g=e.call(r,i=r[n],n)))?!0!==a&&(f[n]=a,a.__data__=i):p[n]=lt(i),v.set(g,!0);for(n=-1;++n<o;)n in m&&!0!==v.get(m[n])&&(d[n]=t[n])}else{for(n=-1;++n<h;)a=t[n],i=r[n],a?(a.__data__=i,f[n]=a):p[n]=lt(i);for(;n<u;++n)p[n]=lt(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=f,p.parentNode=f.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(f),c.push(d)}var s=ht([]),l=q([]),c=q([]);if("function"==typeof t)for(;++a<i;)o(r=this[a],t.call(r,r.parentNode.__data__,a));else for(;++a<i;)o(r=this[a],t);return l.enter=function(){return s},l.exit=function(){return c},l},W.datum=function(t){return arguments.length?this.property("__data__",t):this.property("__data__")},W.filter=function(t){var e,r,n,a=[];"function"!=typeof t&&(t=ct(t));for(var i=0,o=this.length;i<o;i++){a.push(e=[]),e.parentNode=(r=this[i]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,i)&&e.push(n)}return q(a)},W.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],a=n.length-1,i=n[a];--a>=0;)(r=n[a])&&(i&&i!==r.nextSibling&&i.parentNode.insertBefore(r,i),i=r);return this},W.sort=function(t){t=function(t){arguments.length||(t=f);return function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},W.each=function(t){return ut(this,function(e,r,n){t.call(e,e.__data__,r,n)})},W.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},W.empty=function(){return!this.node()},W.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,a=r.length;n<a;n++){var i=r[n];if(i)return i}return null},W.size=function(){var t=0;return ut(this,function(){++t}),t};var ft=[];function pt(e,r,a){var i="__on"+e,o=e.indexOf("."),s=gt;o>0&&(e=e.slice(0,o));var l=dt.get(e);function c(){var t=this[i];t&&(this.removeEventListener(e,t,t.$),delete this[i])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[i]=t,t.$=a),t._=r}:c:r?D:function(){var r,n=new RegExp("^__on([^.]+)"+t.requote(e)+"$");for(var a in this)if(r=a.match(n)){var i=this[a];this.removeEventListener(r[1],i,i.$),delete this[a]}}}t.selection.enter=ht,t.selection.enter.prototype=ft,ft.append=W.append,ft.empty=W.empty,ft.node=W.node,ft.call=W.call,ft.size=W.size,ft.select=function(t){for(var e,r,n,a,i,o=[],s=-1,l=this.length;++s<l;){n=(a=this[s]).update,o.push(e=[]),e.parentNode=a.parentNode;for(var c=-1,u=a.length;++c<u;)(i=a[c])?(e.push(n[c]=r=t.call(a.parentNode,i.__data__,c,s)),r.__data__=i.__data__):e.push(null)}return q(o)},ft.insert=function(t,e){var r,n,a;return arguments.length<2&&(r=this,e=function(t,e,i){var o,s=r[i].update,l=s.length;for(i!=a&&(a=i,n=0),e>=n&&(n=e+1);!(o=s[n])&&++n<l;);return o}),W.insert.call(this,t,e)},t.select=function(t){var e;return"string"==typeof t?(e=[H(t,a)]).parentNode=a.documentElement:(e=[t]).parentNode=i(t),q([e])},t.selectAll=function(t){var e;return"string"==typeof t?(e=n(G(t,a))).parentNode=a.documentElement:(e=n(t)).parentNode=null,q([e])},W.on=function(t,e,r){var n=arguments.length;if(n<3){if("string"!=typeof t){for(r in n<2&&(e=!1),t)this.each(pt(r,t[r],e));return this}if(n<2)return(n=this.node()["__on"+t])&&n._;r=!1}return this.each(pt(t,e,r))};var dt=t.map({mouseenter:"mouseover",mouseleave:"mouseout"});function gt(e,r){return function(n){var a=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=a}}}function vt(t,e){var r=gt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}a&&dt.forEach(function(t){"on"+t in a&&dt.remove(t)});var mt,yt=0;function xt(e){var r=".dragsuppress-"+ ++yt,n="click"+r,a=t.select(o(e)).on("touchmove"+r,B).on("dragstart"+r,B).on("selectstart"+r,B);if(null==mt&&(mt=!("onselectstart"in e)&&z(e.style,"userSelect")),mt){var s=i(e).style,l=s[mt];s[mt]="none"}return function(t){if(a.on(r,null),mt&&(s[mt]=l),t){var e=function(){a.on(n,null)};a.on(n,function(){B(),e()},!0),setTimeout(e,0)}}}t.mouse=function(t){return _t(t,N())};var bt=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function _t(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var a=n.createSVGPoint();if(bt<0){var i=o(e);if(i.scrollX||i.scrollY){var s=(n=t.select("body").append("svg").style({position:"absolute",top:0,left:0,margin:0,padding:0,border:"none"},"important"))[0][0].getScreenCTM();bt=!(s.f||s.e),n.remove()}}return bt?(a.x=r.pageX,a.y=r.pageY):(a.x=r.clientX,a.y=r.clientY),[(a=a.matrixTransform(e.getScreenCTM().inverse())).x,a.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function wt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=N().changedTouches),e)for(var n,a=0,i=e.length;a<i;++a)if((n=e[a]).identifier===r)return _t(t,n)},t.behavior.drag=function(){var e=j(i,"drag","dragstart","dragend"),r=null,n=s(D,t.mouse,o,"mousemove","mouseup"),a=s(wt,t.touch,P,"touchmove","touchend");function i(){this.on("mousedown.drag",n).on("touchstart.drag",a)}function s(n,a,i,o,s){return function(){var l,c=t.event.target.correspondingElement||t.event.target,u=this.parentNode,h=e.of(this,arguments),f=0,p=n(),d=".drag"+(null==p?"":"-"+p),g=t.select(i(c)).on(o+d,function(){var t,e,r=a(u,p);if(!r)return;t=r[0]-m[0],e=r[1]-m[1],f|=t|e,m=r,h({type:"drag",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e})}).on(s+d,function(){if(!a(u,p))return;g.on(o+d,null).on(s+d,null),v(f),h({type:"dragend"})}),v=xt(c),m=a(u,p);l=r?[(l=r.apply(this,arguments)).x-m[0],l.y-m[1]]:[0,0],h({type:"dragstart"})}}return i.origin=function(t){return arguments.length?(r=t,i):r},t.rebind(i,e,"on")},t.touches=function(t,e){return arguments.length<2&&(e=N().touches),e?n(e).map(function(e){var r=_t(t,e);return r.identifier=e.identifier,r}):[]};var kt=1e-6,Tt=kt*kt,Mt=Math.PI,At=2*Mt,St=At-kt,Et=Mt/2,Lt=Mt/180,Ct=180/Mt;function Pt(t){return t>0?1:t<0?-1:0}function Ot(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function zt(t){return t>1?0:t<-1?Mt:Math.acos(t)}function It(t){return t>1?Et:t<-1?-Et:Math.asin(t)}function Dt(t){return((t=Math.exp(t))+1/t)/2}function Rt(t){return(t=Math.sin(t/2))*t}var Ft=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,a=t[0],i=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-a,h=l-i,f=u*u+h*h;if(f<Tt)n=Math.log(c/o)/Ft,r=function(t){return[a+t*u,i+t*h,o*Math.exp(Ft*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+4*f)/(2*o*2*p),g=(c*c-o*o-4*f)/(2*c*2*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/Ft,r=function(t){var e,r=t*n,s=Dt(v),l=o/(2*p)*(s*(e=Ft*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[a+l*u,i+l*h,o*s/Dt(Ft*r+v)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,i,s,l,c,u,h,f={x:0,y:0,k:1},p=[960,500],d=jt,g=250,v=0,m="mousedown.zoom",y="mousemove.zoom",x="mouseup.zoom",b="touchstart.zoom",_=j(w,"zoomstart","zoom","zoomend");function w(t){t.on(m,P).on(Nt+".zoom",z).on("dblclick.zoom",I).on(b,O)}function k(t){return[(t[0]-f.x)/f.k,(t[1]-f.y)/f.k]}function T(t){f.k=Math.max(d[0],Math.min(d[1],t))}function M(t,e){e=function(t){return[t[0]*f.k+f.x,t[1]*f.k+f.y]}(e),f.x+=t[0]-e[0],f.y+=t[1]-e[1]}function A(e,n,a,i){e.__chart__={x:f.x,y:f.y,k:f.k},T(Math.pow(2,i)),M(r=n,a),e=t.select(e),g>0&&(e=e.transition().duration(g)),e.call(w.event)}function S(){c&&c.domain(l.range().map(function(t){return(t-f.x)/f.k}).map(l.invert)),h&&h.domain(u.range().map(function(t){return(t-f.y)/f.k}).map(u.invert))}function E(t){v++||t({type:"zoomstart"})}function L(t){S(),t({type:"zoom",scale:f.k,translate:[f.x,f.y]})}function C(t){--v||(t({type:"zoomend"}),r=null)}function P(){var e=this,r=_.of(e,arguments),n=0,a=t.select(o(e)).on(y,function(){n=1,M(t.mouse(e),i),L(r)}).on(x,function(){a.on(y,null).on(x,null),s(n),C(r)}),i=k(t.mouse(e)),s=xt(e);ps.call(e),E(r)}function O(){var e,r=this,n=_.of(r,arguments),a={},i=0,o=".zoom-"+t.event.changedTouches[0].identifier,l="touchmove"+o,c="touchend"+o,u=[],h=t.select(r),p=xt(r);function d(){var n=t.touches(r);return e=f.k,n.forEach(function(t){t.identifier in a&&(a[t.identifier]=k(t))}),n}function g(){var e=t.event.target;t.select(e).on(l,v).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,h=n.length;o<h;++o)a[n[o].identifier]=null;var p=d(),g=Date.now();if(1===p.length){if(g-s<500){var m=p[0];A(r,m,a[m.identifier],Math.floor(Math.log(f.k)/Math.LN2)+1),B()}s=g}else if(p.length>1){m=p[0];var x=p[1],b=m[0]-x[0],_=m[1]-x[1];i=b*b+_*_}}function v(){var o,l,c,u,h=t.touches(r);ps.call(r);for(var f=0,p=h.length;f<p;++f,u=null)if(c=h[f],u=a[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,g=i&&Math.sqrt(d/i);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],T(g*e)}s=null,M(o,l),L(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,i=e.length;r<i;++r)delete a[e[r].identifier];for(var s in a)return void d()}t.selectAll(u).on(o,null),h.on(m,P).on(b,O),p(),C(n)}g(),E(n),h.on(m,null).on(b,g)}function z(){var a=_.of(this,arguments);i?clearTimeout(i):(ps.call(this),e=k(r=n||t.mouse(this)),E(a)),i=setTimeout(function(){i=null,C(a)},50),B(),T(Math.pow(2,.002*Bt())*f.k),M(r,e),L(a)}function I(){var e=t.mouse(this),r=Math.log(f.k)/Math.LN2;A(this,e,k(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return Nt||(Nt="onwheel"in a?(Bt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},"wheel"):"onmousewheel"in a?(Bt=function(){return t.event.wheelDelta},"mousewheel"):(Bt=function(){return-t.event.detail},"MozMousePixelScroll")),w.event=function(e){e.each(function(){var e=_.of(this,arguments),n=f;vs?t.select(this).transition().each("start.zoom",function(){f=this.__chart__||{x:0,y:0,k:1},E(e)}).tween("zoom:zoom",function(){var a=p[0],i=p[1],o=r?r[0]:a/2,s=r?r[1]:i/2,l=t.interpolateZoom([(o-f.x)/f.k,(s-f.y)/f.k,a/f.k],[(o-n.x)/n.k,(s-n.y)/n.k,a/n.k]);return function(t){var r=l(t),n=a/r[2];this.__chart__=f={x:o-r[0]*n,y:s-r[1]*n,k:n},L(e)}}).each("interrupt.zoom",function(){C(e)}).each("end.zoom",function(){C(e)}):(this.__chart__=f,E(e),L(e),C(e))})},w.translate=function(t){return arguments.length?(f={x:+t[0],y:+t[1],k:f.k},S(),w):[f.x,f.y]},w.scale=function(t){return arguments.length?(f={x:f.x,y:f.y,k:null},T(+t),S(),w):f.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?jt:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(g=+t,w):g},w.x=function(t){return arguments.length?(c=t,l=t.copy(),f={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(h=t,u=t.copy(),f={x:0,y:0,k:1},w):h},t.rebind(w,_,"on")};var Bt,Nt,jt=[0,1/0];function Vt(){}function Ut(t,e,r){return this instanceof Ut?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof Ut?new Ut(t.h,t.s,t.l):ue(""+t,he,Ut):new Ut(t,e,r)}t.color=Vt,Vt.prototype.toString=function(){return this.rgb()+""},t.hsl=Ut;var qt=Ut.prototype=new Vt;function Ht(t,e,r){var n,a;function i(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(a-n)*t/60:t<180?a:t<240?n+(a-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)?0:e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(a=r<=.5?r*(1+e):r+e-r*e),new ie(i(t+120),i(t),i(t-120))}function Gt(e,r,n){return this instanceof Gt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Gt?new Gt(e.h,e.c,e.l):ee(e instanceof Xt?e.l:(e=fe((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Gt(e,r,n)}qt.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new Ut(this.h,this.s,this.l/t)},qt.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new Ut(this.h,this.s,t*this.l)},qt.rgb=function(){return Ht(this.h,this.s,this.l)},t.hcl=Gt;var Yt=Gt.prototype=new Vt;function Wt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Xt(r,Math.cos(t*=Lt)*e,Math.sin(t)*e)}function Xt(t,e,r){return this instanceof Xt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Xt?new Xt(t.l,t.a,t.b):t instanceof Gt?Wt(t.h,t.c,t.l):fe((t=ie(t)).r,t.g,t.b):new Xt(t,e,r)}Yt.brighter=function(t){return new Gt(this.h,this.c,Math.min(100,this.l+Zt*(arguments.length?t:1)))},Yt.darker=function(t){return new Gt(this.h,this.c,Math.max(0,this.l-Zt*(arguments.length?t:1)))},Yt.rgb=function(){return Wt(this.h,this.c,this.l).rgb()},t.lab=Xt;var Zt=18,Jt=.95047,Kt=1,Qt=1.08883,$t=Xt.prototype=new Vt;function te(t,e,r){var n=(t+16)/116,a=n+e/500,i=n-r/200;return new ie(ae(3.2404542*(a=re(a)*Jt)-1.5371385*(n=re(n)*Kt)-.4985314*(i=re(i)*Qt)),ae(-.969266*a+1.8760108*n+.041556*i),ae(.0556434*a-.2040259*n+1.0572252*i))}function ee(t,e,r){return t>0?new Gt(Math.atan2(r,e)*Ct,Math.sqrt(e*e+r*r),t):new Gt(NaN,NaN,t)}function re(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ne(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function ae(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ie(t,e,r){return this instanceof ie?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ie?new ie(t.r,t.g,t.b):ue(""+t,ie,Ht):new ie(t,e,r)}function oe(t){return new ie(t>>16,t>>8&255,255&t)}function se(t){return oe(t)+""}$t.brighter=function(t){return new Xt(Math.min(100,this.l+Zt*(arguments.length?t:1)),this.a,this.b)},$t.darker=function(t){return new Xt(Math.max(0,this.l-Zt*(arguments.length?t:1)),this.a,this.b)},$t.rgb=function(){return te(this.l,this.a,this.b)},t.rgb=ie;var le=ie.prototype=new Vt;function ce(t){return t<16?"0"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function ue(t,e,r){var n,a,i,o=0,s=0,l=0;if(n=/([a-z]+)\((.*)\)/.exec(t=t.toLowerCase()))switch(a=n[2].split(","),n[1]){case"hsl":return r(parseFloat(a[0]),parseFloat(a[1])/100,parseFloat(a[2])/100);case"rgb":return e(de(a[0]),de(a[1]),de(a[2]))}return(i=ge.get(t))?e(i.r,i.g,i.b):(null==t||"#"!==t.charAt(0)||isNaN(i=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&i)>>4,o|=o>>4,s=240&i,s|=s>>4,l=15&i,l|=l<<4):7===t.length&&(o=(16711680&i)>>16,s=(65280&i)>>8,l=255&i)),e(o,s,l))}function he(t,e,r){var n,a,i=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-i,l=(o+i)/2;return s?(a=l<.5?s/(o+i):s/(2-o-i),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,a=l>0&&l<1?0:n),new Ut(n,a,l)}function fe(t,e,r){var n=ne((.4124564*(t=pe(t))+.3575761*(e=pe(e))+.1804375*(r=pe(r)))/Jt),a=ne((.2126729*t+.7151522*e+.072175*r)/Kt);return Xt(116*a-16,500*(n-a),200*(a-ne((.0193339*t+.119192*e+.9503041*r)/Qt)))}function pe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function de(t){var e=parseFloat(t);return"%"===t.charAt(t.length-1)?Math.round(2.55*e):e}le.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,a=30;return e||r||n?(e&&e<a&&(e=a),r&&r<a&&(r=a),n&&n<a&&(n=a),new ie(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ie(a,a,a)},le.darker=function(t){return new ie((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},le.hsl=function(){return he(this.r,this.g,this.b)},le.toString=function(){return"#"+ce(this.r)+ce(this.g)+ce(this.b)};var ge=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function ve(t){return"function"==typeof t?t:function(){return t}}function me(t){return function(e,r,n){return 2===arguments.length&&"function"==typeof r&&(n=r,r=null),ye(e,r,t,n)}}function ye(e,r,a,i){var o={},s=t.dispatch("beforesend","progress","load","error"),l={},c=new XMLHttpRequest,u=null;function h(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&"text"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=a.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return!this.XDomainRequest||"withCredentials"in c||!/^(http(s)?:)?\/\//.test(e)||(c=new XDomainRequest),"onload"in c?c.onload=c.onerror=h:c.onreadystatechange=function(){c.readyState>3&&h()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+"").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+"",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+"",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return a=t,o},["get","post"].forEach(function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}}),o.send=function(t,n,a){if(2===arguments.length&&"function"==typeof n&&(a=n,n=null),c.open(t,e,!0),null==r||"accept"in l||(l.accept=r+",*/*"),c.setRequestHeader)for(var i in l)c.setRequestHeader(i,l[i]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=a&&o.on("error",a).on("load",function(t){a(null,t)}),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,"on"),null==i?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(i))}ge.forEach(function(t,e){ge.set(t,oe(e))}),t.functor=ve,t.xhr=me(P),t.dsv=function(t,e){var r=new RegExp('["'+t+"\n]"),n=t.charCodeAt(0);function a(t,r,n){arguments.length<3&&(n=r,r=null);var a=ye(t,e,null==r?i:o(r),n);return a.row=function(t){return arguments.length?a.response(null==(r=t)?i:o(t)):r},a}function i(t){return a.parse(t.responseText)}function o(t){return function(e){return a.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'"'+t.replace(/\"/g,'""')+'"':t}return a.parse=function(t,e){var r;return a.parseRows(t,function(t,n){if(r)return r(t,n-1);var a=new Function("d","return {"+t.map(function(t,e){return JSON.stringify(t)+": d["+e+"]"}).join(",")+"}");r=e?function(t,r){return e(a(t),r)}:a})},a.parseRows=function(t,e){var r,a,i={},o={},s=[],l=t.length,c=0,u=0;function h(){if(c>=l)return o;if(a)return a=!1,i;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(a=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(a=!0),t.slice(e+1,r).replace(/""/g,'"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))a=!0;else if(13===s)a=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=h())!==o;){for(var f=[];r!==i&&r!==o;)f.push(r),r=h();e&&null==(f=e(f,u++))||s.push(f)}return s},a.format=function(e){if(Array.isArray(e[0]))return a.formatRows(e);var r=new C,n=[];return e.forEach(function(t){for(var e in t)r.has(e)||n.push(r.add(e))}),[n.map(l).join(t)].concat(e.map(function(e){return n.map(function(t){return l(e[t])}).join(t)})).join("\n")},a.formatRows=function(t){return t.map(s).join("\n")},a},t.csv=t.dsv(",","text/csv"),t.tsv=t.dsv("\t","text/tab-separated-values");var xe,be,_e,we,ke=this[z(this,"requestAnimationFrame")]||function(t){setTimeout(t,17)};function Te(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var a={c:t,t:r+e,n:null};return be?be.n=a:xe=a,be=a,_e||(we=clearTimeout(we),_e=1,ke(Me)),a}function Me(){var t=Ae(),e=Se()-t;e>24?(isFinite(e)&&(clearTimeout(we),we=setTimeout(Me,e)),_e=0):(_e=1,ke(Me))}function Ae(){for(var t=Date.now(),e=xe;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Se(){for(var t,e=xe,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:xe=e.n;return be=t,r}function Ee(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){Te.apply(this,arguments)},t.timer.flush=function(){Ae(),Se()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Le=["y","z","a","f","p","n","\xb5","m","","k","M","G","T","P","E","Z","Y"].map(function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}});function Ce(e){var r=e.decimal,n=e.thousands,a=e.grouping,i=e.currency,o=a&&n?function(t,e){for(var r=t.length,i=[],o=0,s=a[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),i.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=a[o=(o+1)%a.length];return i.reverse().join(n)}:P;return function(e){var n=Pe.exec(e),a=n[1]||" ",s=n[2]||">",l=n[3]||"-",c=n[4]||"",u=n[5],h=+n[6],f=n[7],p=n[8],d=n[9],g=1,v="",m="",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||"0"===a&&"="===s)&&(u=a="0",s="="),d){case"n":f=!0,d="g";break;case"%":g=100,m="%",d="f";break;case"p":g=100,m="%",d="r";break;case"b":case"o":case"x":case"X":"#"===c&&(v="0"+d.toLowerCase());case"c":x=!1;case"d":y=!0,p=0;break;case"s":g=-1,d="r"}"$"===c&&(v=i[0],m=i[1]),"r"!=d||p||(d="g"),null!=p&&("g"==d?p=Math.max(1,Math.min(21,p)):"e"!=d&&"f"!=d||(p=Math.max(0,Math.min(20,p)))),d=Oe.get(d)||ze;var b=u&&f;return function(e){var n=m;if(y&&e%1)return"";var i=e<0||0===e&&1/e<0?(e=-e,"-"):"-"===l?"":l;if(g<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+m}else e*=g;var _,w,k=(e=d(e,p)).lastIndexOf(".");if(k<0){var T=x?e.lastIndexOf("e"):-1;T<0?(_=e,w=""):(_=e.substring(0,T),w=e.substring(T))}else _=e.substring(0,k),w=r+e.substring(k+1);!u&&f&&(_=o(_,1/0));var M=v.length+_.length+w.length+(b?0:i.length),A=M<h?new Array(M=h-M+1).join(a):"";return b&&(_=o(A+_,A.length?h-w.length:1/0)),i+=v,e=_+w,("<"===s?i+e+A:">"===s?A+i+e:"^"===s?A.substring(0,M>>=1)+i+e+A.substring(M):i+(b?e:A+e))+n}}}t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ee(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Le[8+n/3]};var Pe=/(?:([^{])?([<>=^]))?([+\- ])?([$#])?(0)?(\d+)?(,)?(\.-?\d+)?([a-z%])?/i,Oe=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ee(e,r))).toFixed(Math.max(0,Math.min(20,Ee(e*(1+1e-15),r))))}});function ze(t){return t+""}var Ie=t.time={},De=Date;function Re(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}Re.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){Fe.setUTCDate.apply(this._,arguments)},setDay:function(){Fe.setUTCDay.apply(this._,arguments)},setFullYear:function(){Fe.setUTCFullYear.apply(this._,arguments)},setHours:function(){Fe.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){Fe.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){Fe.setUTCMinutes.apply(this._,arguments)},setMonth:function(){Fe.setUTCMonth.apply(this._,arguments)},setSeconds:function(){Fe.setUTCSeconds.apply(this._,arguments)},setTime:function(){Fe.setTime.apply(this._,arguments)}};var Fe=Date.prototype;function Be(t,e,r){function n(e){var r=t(e),n=i(r,1);return e-r<n-e?r:n}function a(r){return e(r=t(new De(r-1)),1),r}function i(t,r){return e(t=new De(+t),r),t}function o(t,n,i){var o=a(t),s=[];if(i>1)for(;o<n;)r(o)%i||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=a,t.offset=i,t.range=o;var s=t.utc=Ne(t);return s.floor=s,s.round=Ne(n),s.ceil=Ne(a),s.offset=Ne(i),s.range=function(t,e,r){try{De=Re;var n=new Re;return n._=t,o(n,e,r)}finally{De=Date}},t}function Ne(t){return function(e,r){try{De=Re;var n=new Re;return n._=e,t(n,r)._}finally{De=Date}}}function je(e){var r=e.dateTime,n=e.date,a=e.time,i=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,a,i,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(a=Ve[n=t.charAt(++s)])&&(n=t.charAt(++s)),(i=_[n])&&(n=i(r,null==a?"e"===n?" ":"0":a)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join("")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(h(r,t,e,0)!=e.length)return null;"p"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&De!==Re,a=new(n?Re:De);return"j"in r?a.setFullYear(r.y,0,r.j):"W"in r||"U"in r?("w"in r||(r.w="W"in r?1:0),a.setFullYear(r.y,0,1),a.setFullYear(r.y,0,"W"in r?(r.w+6)%7+7*r.W-(a.getDay()+5)%7:r.w+7*r.U-(a.getDay()+6)%7)):a.setFullYear(r.y,r.m,r.d),a.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?a._:a},r.toString=function(){return t},r}function h(t,e,r,n){for(var a,i,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(a=e.charCodeAt(s++))){if(o=e.charAt(s++),!(i=w[o in Ve?e.charAt(s++):o])||(n=i(t,r,n))<0)return-1}else if(a!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(De=Re);return r._=t,e(r)}finally{De=Date}}return r.parse=function(t){try{De=Re;var r=e.parse(t);return r&&r._}finally{De=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=lr;var f=t.map(),p=Ge(o),d=Ye(o),g=Ge(s),v=Ye(s),m=Ge(l),y=Ye(l),x=Ge(c),b=Ye(c);i.forEach(function(t,e){f.set(t.toLowerCase(),e)});var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return He(t.getDate(),e,2)},e:function(t,e){return He(t.getDate(),e,2)},H:function(t,e){return He(t.getHours(),e,2)},I:function(t,e){return He(t.getHours()%12||12,e,2)},j:function(t,e){return He(1+Ie.dayOfYear(t),e,3)},L:function(t,e){return He(t.getMilliseconds(),e,3)},m:function(t,e){return He(t.getMonth()+1,e,2)},M:function(t,e){return He(t.getMinutes(),e,2)},p:function(t){return i[+(t.getHours()>=12)]},S:function(t,e){return He(t.getSeconds(),e,2)},U:function(t,e){return He(Ie.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return He(Ie.mondayOfYear(t),e,2)},x:u(n),X:u(a),y:function(t,e){return He(t.getFullYear()%100,e,2)},Y:function(t,e){return He(t.getFullYear()%1e4,e,4)},Z:or,"%":function(){return"%"}},w={a:function(t,e,r){g.lastIndex=0;var n=g.exec(e.slice(r));return n?(t.w=v.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){m.lastIndex=0;var n=m.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return h(t,_.c.toString(),e,r)},d:tr,e:tr,H:rr,I:rr,j:er,L:ir,m:$e,M:nr,p:function(t,e,r){var n=f.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:ar,U:Xe,w:We,W:Ze,x:function(t,e,r){return h(t,_.x.toString(),e,r)},X:function(t,e,r){return h(t,_.X.toString(),e,r)},y:Ke,Y:Je,Z:Qe,"%":sr};return u}Ie.year=Be(function(t){return(t=Ie.day(t)).setMonth(0,1),t},function(t,e){t.setFullYear(t.getFullYear()+e)},function(t){return t.getFullYear()}),Ie.years=Ie.year.range,Ie.years.utc=Ie.year.utc.range,Ie.day=Be(function(t){var e=new De(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e},function(t,e){t.setDate(t.getDate()+e)},function(t){return t.getDate()-1}),Ie.days=Ie.day.range,Ie.days.utc=Ie.day.utc.range,Ie.dayOfYear=function(t){var e=Ie.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},["sunday","monday","tuesday","wednesday","thursday","friday","saturday"].forEach(function(t,e){e=7-e;var r=Ie[t]=Be(function(t){return(t=Ie.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t},function(t,e){t.setDate(t.getDate()+7*Math.floor(e))},function(t){var r=Ie.year(t).getDay();return Math.floor((Ie.dayOfYear(t)+(r+e)%7)/7)-(r!==e)});Ie[t+"s"]=r.range,Ie[t+"s"].utc=r.utc.range,Ie[t+"OfYear"]=function(t){var r=Ie.year(t).getDay();return Math.floor((Ie.dayOfYear(t)+(r+e)%7)/7)}}),Ie.week=Ie.sunday,Ie.weeks=Ie.sunday.range,Ie.weeks.utc=Ie.sunday.utc.range,Ie.weekOfYear=Ie.sundayOfYear;var Ve={"-":"",_:" ",0:"0"},Ue=/^\s*\d+/,qe=/^%/;function He(t,e,r){var n=t<0?"-":"",a=(n?-t:t)+"",i=a.length;return n+(i<r?new Array(r-i+1).join(e)+a:a)}function Ge(e){return new RegExp("^(?:"+e.map(t.requote).join("|")+")","i")}function Ye(t){for(var e=new b,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function We(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function Xe(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function Ze(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Je(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Ke(t,e,r){Ue.lastIndex=0;var n,a=Ue.exec(e.slice(r,r+2));return a?(t.y=(n=+a[0])+(n>68?1900:2e3),r+a[0].length):-1}function Qe(t,e,r){return/^[+-]\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function $e(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function tr(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function er(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function rr(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function nr(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function ar(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function ir(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function or(t){var e=t.getTimezoneOffset(),r=e>0?"-":"+",n=y(e)/60|0,a=y(e)%60;return r+He(n,"0",2)+He(a,"0",2)}function sr(t,e,r){qe.lastIndex=0;var n=qe.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function lr(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(t){return{numberFormat:Ce(t),timeFormat:je(t)}};var cr=t.locale({decimal:".",thousands:",",grouping:[3],currency:["$",""],dateTime:"%a %b %e %X %Y",date:"%m/%d/%Y",time:"%H:%M:%S",periods:["AM","PM"],days:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],shortDays:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],months:["January","February","March","April","May","June","July","August","September","October","November","December"],shortMonths:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"]});function ur(){}t.format=cr.numberFormat,t.geo={},ur.prototype={s:0,t:0,add:function(t){fr(t,this.t,hr),fr(hr.s,this.s,this),this.s?this.t+=hr.t:this.s=hr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var hr=new ur;function fr(t,e,r){var n=r.s=t+e,a=n-t,i=n-a;r.t=t-i+(e-a)}function pr(t,e){t&&gr.hasOwnProperty(t.type)&&gr[t.type](t,e)}t.geo.stream=function(t,e){t&&dr.hasOwnProperty(t.type)?dr[t.type](t,e):pr(t,e)};var dr={Feature:function(t,e){pr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,a=r.length;++n<a;)pr(r[n].geometry,e)}},gr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,a=r.length;++n<a;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){vr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,a=r.length;++n<a;)vr(r[n],e,0)},Polygon:function(t,e){mr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,a=r.length;++n<a;)mr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,a=r.length;++n<a;)pr(r[n],e)}};function vr(t,e,r){var n,a=-1,i=t.length-r;for(e.lineStart();++a<i;)n=t[a],e.point(n[0],n[1],n[2]);e.lineEnd()}function mr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)vr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return yr=0,t.geo.stream(e,Pr),yr};var yr,xr,br,_r,wr,kr,Tr,Mr,Ar,Sr,Er,Lr,Cr=new ur,Pr={sphere:function(){yr+=4*Mt},point:D,lineStart:D,lineEnd:D,polygonStart:function(){Cr.reset(),Pr.lineStart=Or},polygonEnd:function(){var t=2*Cr;yr+=t<0?4*Mt+t:t,Pr.lineStart=Pr.lineEnd=Pr.point=D}};function Or(){var t,e,r,n,a;function i(t,e){e=e*Lt/2+Mt/4;var i=(t*=Lt)-r,o=i>=0?1:-1,s=o*i,l=Math.cos(e),c=Math.sin(e),u=a*c,h=n*l+u*Math.cos(s),f=u*o*Math.sin(s);Cr.add(Math.atan2(f,h)),r=t,n=l,a=c}Pr.point=function(o,s){Pr.point=i,r=(t=o)*Lt,n=Math.cos(s=(e=s)*Lt/2+Mt/4),a=Math.sin(s)},Pr.lineEnd=function(){i(t,e)}}function zr(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Ir(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function Dr(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Rr(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Fr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Br(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Nr(t){return[Math.atan2(t[1],t[0]),It(t[2])]}function jr(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,a,i,o,s,l,c,u,h,f={point:p,lineStart:g,lineEnd:v,polygonStart:function(){f.point=m,f.lineStart=x,f.lineEnd=b,c=0,Pr.polygonStart()},polygonEnd:function(){Pr.polygonEnd(),f.point=p,f.lineStart=g,f.lineEnd=v,Cr<0?(e=-(n=180),r=-(a=90)):c>kt?a=90:c<-kt&&(r=-90),h[0]=e,h[1]=n}};function p(t,i){u.push(h=[e=t,n=t]),i<r&&(r=i),i>a&&(a=i)}function d(t,o){var s=zr([t*Lt,o*Lt]);if(l){var c=Dr(l,s),u=Dr([c[1],-c[0],0],c);Br(u),u=Nr(u);var h=t-i,f=h>0?1:-1,d=u[0]*Ct*f,g=y(h)>180;if(g^(f*i<d&&d<f*t))(v=u[1]*Ct)>a&&(a=v);else if(g^(f*i<(d=(d+360)%360-180)&&d<f*t)){var v;(v=-u[1]*Ct)<r&&(r=v)}else o<r&&(r=o),o>a&&(a=o);g?t<i?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>i?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,i=t}function g(){f.point=d}function v(){h[0]=e,h[1]=n,f.point=p,l=null}function m(t,e){if(l){var r=t-i;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Pr.point(t,e),d(t,e)}function x(){Pr.lineStart()}function b(){m(o,s),Pr.lineEnd(),y(c)>kt&&(e=-(n=180)),h[0]=e,h[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function k(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(i){if(a=n=-(e=r=1/0),u=[],t.geo.stream(i,f),c=u.length){u.sort(w);for(var o=1,s=[g=u[0]];o<c;++o)k((p=u[o])[0],g)||k(p[1],g)?(_(g[0],p[1])>_(g[0],g[1])&&(g[1]=p[1]),_(p[0],g[1])>_(g[0],g[1])&&(g[0]=p[0])):s.push(g=p);for(var l,c,p,d=-1/0,g=(o=0,s[c=s.length-1]);o<=c;g=p,++o)p=s[o],(l=_(g[1],p[0]))>d&&(d=l,e=p[0],n=g[1])}return u=h=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,a]]}}(),t.geo.centroid=function(e){xr=br=_r=wr=kr=Tr=Mr=Ar=Sr=Er=Lr=0,t.geo.stream(e,Vr);var r=Sr,n=Er,a=Lr,i=r*r+n*n+a*a;return i<Tt&&(r=Tr,n=Mr,a=Ar,br<kt&&(r=_r,n=wr,a=kr),(i=r*r+n*n+a*a)<Tt)?[NaN,NaN]:[Math.atan2(n,r)*Ct,It(a/Math.sqrt(i))*Ct]};var Vr={sphere:D,point:Ur,lineStart:Hr,lineEnd:Gr,polygonStart:function(){Vr.lineStart=Yr},polygonEnd:function(){Vr.lineStart=Hr}};function Ur(t,e){t*=Lt;var r=Math.cos(e*=Lt);qr(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function qr(t,e,r){_r+=(t-_r)/++xr,wr+=(e-wr)/xr,kr+=(r-kr)/xr}function Hr(){var t,e,r;function n(n,a){n*=Lt;var i=Math.cos(a*=Lt),o=i*Math.cos(n),s=i*Math.sin(n),l=Math.sin(a),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);br+=c,Tr+=c*(t+(t=o)),Mr+=c*(e+(e=s)),Ar+=c*(r+(r=l)),qr(t,e,r)}Vr.point=function(a,i){a*=Lt;var o=Math.cos(i*=Lt);t=o*Math.cos(a),e=o*Math.sin(a),r=Math.sin(i),Vr.point=n,qr(t,e,r)}}function Gr(){Vr.point=Ur}function Yr(){var t,e,r,n,a;function i(t,e){t*=Lt;var i=Math.cos(e*=Lt),o=i*Math.cos(t),s=i*Math.sin(t),l=Math.sin(e),c=n*l-a*s,u=a*o-r*l,h=r*s-n*o,f=Math.sqrt(c*c+u*u+h*h),p=r*o+n*s+a*l,d=f&&-zt(p)/f,g=Math.atan2(f,p);Sr+=d*c,Er+=d*u,Lr+=d*h,br+=g,Tr+=g*(r+(r=o)),Mr+=g*(n+(n=s)),Ar+=g*(a+(a=l)),qr(r,n,a)}Vr.point=function(o,s){t=o,e=s,Vr.point=i,o*=Lt;var l=Math.cos(s*=Lt);r=l*Math.cos(o),n=l*Math.sin(o),a=Math.sin(s),qr(r,n,a)},Vr.lineEnd=function(){i(t,e),Vr.lineEnd=Gr,Vr.point=Ur}}function Wr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Xr(){return!0}function Zr(t,e,r,n,a){var i=[],o=[];if(t.forEach(function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(jr(r,n)){a.lineStart();for(var s=0;s<e;++s)a.point((r=t[s])[0],r[1]);a.lineEnd()}else{var l=new Kr(r,t,null,!0),c=new Kr(r,null,l,!1);l.o=c,i.push(l),o.push(c),l=new Kr(n,t,null,!1),c=new Kr(n,null,l,!0),l.o=c,i.push(l),o.push(c)}}}),o.sort(e),Jr(i),Jr(o),i.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,h,f=i[0];;){for(var p=f,d=!0;p.v;)if((p=p.n)===f)return;u=p.z,a.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)a.point((h=u[s])[0],h[1]);else n(p.x,p.n.x,1,a);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)a.point((h=u[s])[0],h[1]);else n(p.x,p.p.x,-1,a);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);a.lineEnd()}}}function Jr(t){if(e=t.length){for(var e,r,n=0,a=t[0];++n<e;)a.n=r=t[n],r.p=a,a=r;a.n=r=t[0],r.p=a}}function Kr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function Qr(e,r,n,a){return function(i,o){var s,l=r(o),c=i.invert(a[0],a[1]),u={point:h,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],g=[]},polygonEnd:function(){u.point=h,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],a=[Math.sin(r),-Math.cos(r),0],i=0,o=0;Cr.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var h=c[0],f=h[0],p=h[1]/2+Mt/4,d=Math.sin(p),g=Math.cos(p),v=1;;){v===u&&(v=0);var m=(t=c[v])[0],y=t[1]/2+Mt/4,x=Math.sin(y),b=Math.cos(y),_=m-f,w=_>=0?1:-1,k=w*_,T=k>Mt,M=d*x;if(Cr.add(Math.atan2(M*w*Math.sin(k),g*b+M*Math.cos(k))),i+=T?_+w*At:_,T^f>=r^m>=r){var A=Dr(zr(h),zr(t));Br(A);var S=Dr(a,A);Br(S);var E=(T^_>=0?-1:1)*It(S[2]);(n>E||n===E&&(A[0]||A[1]))&&(o+=T^_>=0?1:-1)}if(!v++)break;f=m,d=x,g=b,h=t}}return(i<-kt||i<kt&&Cr<-kt)^1&o}(c,g);s.length?(x||(o.polygonStart(),x=!0),Zr(s,en,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=g=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function h(t,r){var n=i(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function f(t,e){var r=i(t,e);l.point(r[0],r[1])}function p(){u.point=f,l.lineStart()}function d(){u.point=h,l.lineEnd()}var g,v,m=tn(),y=r(m),x=!1;function b(t,e){v.push([t,e]);var r=i(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),v=[]}function w(){b(v[0][0],v[0][1]),y.lineEnd();var t,e=y.clean(),r=m.buffer(),n=r.length;if(v.pop(),g.push(v),v=null,n)if(1&e){var a,i=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++i<n;)o.point((a=t[i])[0],a[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter($r))}return u}}function $r(t){return t.length>1}function tn(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:D,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function en(t,e){return((t=t.x)[0]<0?t[1]-Et-kt:Et-t[1])-((e=e.x)[0]<0?e[1]-Et-kt:Et-e[1])}var rn=Qr(Xr,function(t){var e,r=NaN,n=NaN,a=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(i,o){var s=i>0?Mt:-Mt,l=y(i-r);y(l-Mt)<kt?(t.point(r,n=(n+o)/2>0?Et:-Et),t.point(a,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(i,n),e=0):a!==s&&l>=Mt&&(y(r-a)<kt&&(r-=a*kt),y(i-s)<kt&&(i-=s*kt),n=function(t,e,r,n){var a,i,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(i=Math.cos(n))*Math.sin(r)-Math.sin(n)*(a=Math.cos(e))*Math.sin(t))/(a*i*o)):(e+n)/2}(r,n,i,o),t.point(a,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=i,n=o),a=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}},function(t,e,r,n){var a;if(null==t)a=r*Et,n.point(-Mt,a),n.point(0,a),n.point(Mt,a),n.point(Mt,0),n.point(Mt,-a),n.point(0,-a),n.point(-Mt,-a),n.point(-Mt,0),n.point(-Mt,a);else if(y(t[0]-e[0])>kt){var i=t[0]<e[0]?Mt:-Mt;a=r*i/2,n.point(-i,a),n.point(0,a),n.point(i,a)}else n.point(e[0],e[1])},[-Mt,-Mt/2]);function nn(t,e,r,n){return function(a){var i,o=a.a,s=a.b,l=o.x,c=o.y,u=0,h=1,f=s.x-l,p=s.y-c;if(i=t-l,f||!(i>0)){if(i/=f,f<0){if(i<u)return;i<h&&(h=i)}else if(f>0){if(i>h)return;i>u&&(u=i)}if(i=r-l,f||!(i<0)){if(i/=f,f<0){if(i>h)return;i>u&&(u=i)}else if(f>0){if(i<u)return;i<h&&(h=i)}if(i=e-c,p||!(i>0)){if(i/=p,p<0){if(i<u)return;i<h&&(h=i)}else if(p>0){if(i>h)return;i>u&&(u=i)}if(i=n-c,p||!(i<0)){if(i/=p,p<0){if(i>h)return;i>u&&(u=i)}else if(p>0){if(i<u)return;i<h&&(h=i)}return u>0&&(a.a={x:l+u*f,y:c+u*p}),h<1&&(a.b={x:l+h*f,y:c+h*p}),a}}}}}}var an=1e9;function on(e,r,n,a){return function(l){var c,u,h,f,p,d,g,v,m,y,x,b=l,_=tn(),w=nn(e,r,n,a),k={point:A,lineStart:function(){k.point=S,u&&u.push(h=[]);y=!0,m=!1,g=v=NaN},lineEnd:function(){c&&(S(f,p),d&&m&&_.rejoin(),c.push(_.buffer()));k.point=A,m&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],a=0;a<r;++a)for(var i,o=1,s=u[a],l=s.length,c=s[0];o<l;++o)i=s[o],c[1]<=n?i[1]>n&&Ot(c,i,t)>0&&++e:i[1]<=n&&Ot(c,i,t)<0&&--e,c=i;return 0!==e}([e,a]),n=x&&r,i=c.length;(n||i)&&(l.polygonStart(),n&&(l.lineStart(),T(null,null,1,l),l.lineEnd()),i&&Zr(c,o,r,T,l),l.polygonEnd()),c=u=h=null}};function T(t,o,l,c){var u=0,h=0;if(null==t||(u=i(t,l))!==(h=i(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?a:r)}while((u=(u+l+4)%4)!==h);else c.point(o[0],o[1])}function M(t,i){return e<=t&&t<=n&&r<=i&&i<=a}function A(t,e){M(t,e)&&l.point(t,e)}function S(t,e){var r=M(t=Math.max(-an,Math.min(an,t)),e=Math.max(-an,Math.min(an,e)));if(u&&h.push([t,e]),y)f=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&m)l.point(t,e);else{var n={a:{x:g,y:v},b:{x:t,y:e}};w(n)?(m||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}g=t,v=e,m=r}return k};function i(t,a){return y(t[0]-e)<kt?a>0?0:3:y(t[0]-n)<kt?a>0?2:1:y(t[1]-r)<kt?a>0?1:0:a>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=i(t,1),n=i(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function sn(t){var e=0,r=Mt/3,n=Pn(t),a=n(e,r);return a.parallels=function(t){return arguments.length?n(e=t[0]*Mt/180,r=t[1]*Mt/180):[e/Mt*180,r/Mt*180]},a}function ln(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,a=1+r*(2*n-r),i=Math.sqrt(a)/n;function o(t,e){var r=Math.sqrt(a-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),i-r*Math.cos(t)]}return o.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,It((a-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,a,i,o={stream:function(t){return a&&(a.valid=!1),(a=i(t)).valid=!0,a},extent:function(s){return arguments.length?(i=on(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),a&&(a.valid=!1,a=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return sn(ln)}).raw=ln,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,a,i=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var i=t[0],o=t[1];return e=null,r(i,o),e||(n(i,o),e)||a(i,o),e}return c.invert=function(t){var e=i.scale(),r=i.translate(),n=(t[0]-r[0])/e,a=(t[1]-r[1])/e;return(a>=.12&&a<.234&&n>=-.425&&n<-.214?o:a>=.166&&a<.234&&n>=-.214&&n<-.115?s:i).invert(t)},c.stream=function(t){var e=i.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,a){e.point(t,a),r.point(t,a),n.point(t,a)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(i.precision(t),o.precision(t),s.precision(t),c):i.precision()},c.scale=function(t){return arguments.length?(i.scale(t),o.scale(.35*t),s.scale(t),c.translate(i.translate())):i.scale()},c.translate=function(t){if(!arguments.length)return i.translate();var e=i.scale(),u=+t[0],h=+t[1];return r=i.translate(t).clipExtent([[u-.455*e,h-.238*e],[u+.455*e,h+.238*e]]).stream(l).point,n=o.translate([u-.307*e,h+.201*e]).clipExtent([[u-.425*e+kt,h+.12*e+kt],[u-.214*e-kt,h+.234*e-kt]]).stream(l).point,a=s.translate([u-.205*e,h+.212*e]).clipExtent([[u-.214*e+kt,h+.166*e+kt],[u-.115*e-kt,h+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var cn,un,hn,fn,pn,dn,gn={point:D,lineStart:D,lineEnd:D,polygonStart:function(){un=0,gn.lineStart=vn},polygonEnd:function(){gn.lineStart=gn.lineEnd=gn.point=D,cn+=y(un/2)}};function vn(){var t,e,r,n;function a(t,e){un+=n*t-r*e,r=t,n=e}gn.point=function(i,o){gn.point=a,t=r=i,e=n=o},gn.lineEnd=function(){a(t,e)}}var mn={point:function(t,e){t<hn&&(hn=t);t>pn&&(pn=t);e<fn&&(fn=e);e>dn&&(dn=e)},lineStart:D,lineEnd:D,polygonStart:D,polygonEnd:D};function yn(){var t=xn(4.5),e=[],r={point:n,lineStart:function(){r.point=a},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=xn(e),r},result:function(){if(e.length){var t=e.join("");return e=[],t}}};function n(r,n){e.push("M",r,",",n,t)}function a(t,n){e.push("M",t,",",n),r.point=i}function i(t,r){e.push("L",t,",",r)}function o(){r.point=n}function s(){e.push("Z")}return r}function xn(t){return"m0,"+t+"a"+t+","+t+" 0 1,1 0,"+-2*t+"a"+t+","+t+" 0 1,1 0,"+2*t+"z"}var bn,_n={point:wn,lineStart:kn,lineEnd:Tn,polygonStart:function(){_n.lineStart=Mn},polygonEnd:function(){_n.point=wn,_n.lineStart=kn,_n.lineEnd=Tn}};function wn(t,e){_r+=t,wr+=e,++kr}function kn(){var t,e;function r(r,n){var a=r-t,i=n-e,o=Math.sqrt(a*a+i*i);Tr+=o*(t+r)/2,Mr+=o*(e+n)/2,Ar+=o,wn(t=r,e=n)}_n.point=function(n,a){_n.point=r,wn(t=n,e=a)}}function Tn(){_n.point=wn}function Mn(){var t,e,r,n;function a(t,e){var a=t-r,i=e-n,o=Math.sqrt(a*a+i*i);Tr+=o*(r+t)/2,Mr+=o*(n+e)/2,Ar+=o,Sr+=(o=n*t-r*e)*(r+t),Er+=o*(n+e),Lr+=3*o,wn(r=t,n=e)}_n.point=function(i,o){_n.point=a,wn(t=r=i,e=n=o)},_n.lineEnd=function(){a(t,e)}}function An(t){var e=4.5,r={point:n,lineStart:function(){r.point=a},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:D};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,At)}function a(e,n){t.moveTo(e,n),r.point=i}function i(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function Sn(t){var e=.5,r=Math.cos(30*Lt),n=16;function a(e){return(n?function(e){var r,a,o,s,l,c,u,h,f,p,d,g,v={point:m,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),v.lineStart=_},polygonEnd:function(){e.polygonEnd(),v.lineStart=y}};function m(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){h=NaN,v.point=x,e.lineStart()}function x(r,a){var o=zr([r,a]),s=t(r,a);i(h,f,u,p,d,g,h=s[0],f=s[1],u=r,p=o[0],d=o[1],g=o[2],n,e),e.point(h,f)}function b(){v.point=m,e.lineEnd()}function _(){y(),v.point=w,v.lineEnd=k}function w(t,e){x(r=t,e),a=h,o=f,s=p,l=d,c=g,v.point=x}function k(){i(h,f,u,p,d,g,a,o,r,s,l,c,n,e),v.lineEnd=b,b()}return v}:function(e){return Ln(e,function(r,n){r=t(r,n),e.point(r[0],r[1])})})(e)}function i(n,a,o,s,l,c,u,h,f,p,d,g,v,m){var x=u-n,b=h-a,_=x*x+b*b;if(_>4*e&&v--){var w=s+p,k=l+d,T=c+g,M=Math.sqrt(w*w+k*k+T*T),A=Math.asin(T/=M),S=y(y(T)-1)<kt||y(o-f)<kt?(o+f)/2:Math.atan2(k,w),E=t(S,A),L=E[0],C=E[1],P=L-n,O=C-a,z=b*P-x*O;(z*z/_>e||y((x*P+b*O)/_-.5)>.3||s*p+l*d+c*g<r)&&(i(n,a,o,s,l,c,L,C,S,w/=M,k/=M,T,v,m),m.point(L,C),i(L,C,S,w,k,T,u,h,f,p,d,g,v,m))}}return a.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,a):Math.sqrt(e)},a}function En(t){this.stream=t}function Ln(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function Cn(t){return Pn(function(){return t})()}function Pn(e){var r,n,a,i,o,s,l=Sn(function(t,e){return[(t=r(t,e))[0]*c+i,o-t[1]*c]}),c=150,u=480,h=250,f=0,p=0,d=0,g=0,v=0,m=rn,x=P,b=null,_=null;function w(t){return[(t=a(t[0]*Lt,t[1]*Lt))[0]*c+i,o-t[1]*c]}function k(t){return(t=a.invert((t[0]-i)/c,(o-t[1])/c))&&[t[0]*Ct,t[1]*Ct]}function T(){a=Wr(n=Dn(d,g,v),r);var t=r(f,p);return i=u-t[0]*c,o=h+t[1]*c,M()}function M(){return s&&(s.valid=!1,s=null),w}return w.stream=function(t){return s&&(s.valid=!1),(s=On(m(n,l(x(t))))).valid=!0,s},w.clipAngle=function(t){return arguments.length?(m=null==t?(b=t,rn):function(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return Qr(a,function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(h,f){var p,d=[h,f],g=a(h,f),v=r?g?0:o(h,f):g?o(h+(h<0?Mt:-Mt),f):0;if(!e&&(c=l=g)&&t.lineStart(),g!==l&&(p=i(e,d),(jr(e,p)||jr(d,p))&&(d[0]+=kt,d[1]+=kt,g=a(d[0],d[1]))),g!==l)u=0,g?(t.lineStart(),p=i(d,e),t.point(p[0],p[1])):(p=i(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^g){var m;v&s||!(m=i(d,e,!0))||(u=0,r?(t.lineStart(),t.point(m[0][0],m[0][1]),t.point(m[1][0],m[1][1]),t.lineEnd()):(t.point(m[1][0],m[1][1]),t.lineEnd(),t.lineStart(),t.point(m[0][0],m[0][1])))}!g||e&&jr(e,d)||t.point(d[0],d[1]),e=d,l=g,s=v},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}},Nn(t,6*Lt),r?[0,-t]:[-Mt,t-Mt]);function a(t,r){return Math.cos(t)*Math.cos(r)>e}function i(t,r,n){var a=[1,0,0],i=Dr(zr(t),zr(r)),o=Ir(i,i),s=i[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,h=Dr(a,i),f=Fr(a,c);Rr(f,Fr(i,u));var p=h,d=Ir(f,p),g=Ir(p,p),v=d*d-g*(Ir(f,f)-1);if(!(v<0)){var m=Math.sqrt(v),x=Fr(p,(-d-m)/g);if(Rr(x,f),x=Nr(x),!n)return x;var b,_=t[0],w=r[0],k=t[1],T=r[1];w<_&&(b=_,_=w,w=b);var M=w-_,A=y(M-Mt)<kt;if(!A&&T<k&&(b=k,k=T,T=b),A||M<kt?A?k+T>0^x[1]<(y(x[0]-_)<kt?k:T):k<=x[1]&&x[1]<=T:M>Mt^(_<=x[0]&&x[0]<=w)){var S=Fr(p,(-d+m)/g);return Rr(S,f),[x,Nr(S)]}}}function o(e,n){var a=r?t:Mt-t,i=0;return e<-a?i|=1:e>a&&(i|=2),n<-a?i|=4:n>a&&(i|=8),i}}((b=+t)*Lt),M()):b},w.clipExtent=function(t){return arguments.length?(_=t,x=t?on(t[0][0],t[0][1],t[1][0],t[1][1]):P,M()):_},w.scale=function(t){return arguments.length?(c=+t,T()):c},w.translate=function(t){return arguments.length?(u=+t[0],h=+t[1],T()):[u,h]},w.center=function(t){return arguments.length?(f=t[0]%360*Lt,p=t[1]%360*Lt,T()):[f*Ct,p*Ct]},w.rotate=function(t){return arguments.length?(d=t[0]%360*Lt,g=t[1]%360*Lt,v=t.length>2?t[2]%360*Lt:0,T()):[d*Ct,g*Ct,v*Ct]},t.rebind(w,l,"precision"),function(){return r=e.apply(this,arguments),w.invert=r.invert&&k,T()}}function On(t){return Ln(t,function(e,r){t.point(e*Lt,r*Lt)})}function zn(t,e){return[t,e]}function In(t,e){return[t>Mt?t-At:t<-Mt?t+At:t,e]}function Dn(t,e,r){return t?e||r?Wr(Fn(t),Bn(e,r)):Fn(t):e||r?Bn(e,r):In}function Rn(t){return function(e,r){return[(e+=t)>Mt?e-At:e<-Mt?e+At:e,r]}}function Fn(t){var e=Rn(t);return e.invert=Rn(-t),e}function Bn(t,e){var r=Math.cos(t),n=Math.sin(t),a=Math.cos(e),i=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*a-u*i,s*r-c*n),It(u*a+l*i)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*a-l*i;return[Math.atan2(l*a+c*i,s*r+u*n),It(u*r-s*n)]},o}function Nn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(a,i,o,s){var l=o*e;null!=a?(a=jn(r,a),i=jn(r,i),(o>0?a<i:a>i)&&(a+=o*At)):(a=t+o*At,i=t-.5*l);for(var c,u=a;o>0?u>i:u<i;u-=l)s.point((c=Nr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function jn(t,e){var r=zr(e);r[0]-=t,Br(r);var n=zt(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function Vn(e,r,n){var a=t.range(e,r-kt,n).concat(r);return function(t){return a.map(function(e){return[t,e]})}}function Un(e,r,n){var a=t.range(e,r-kt,n).concat(r);return function(t){return a.map(function(e){return[e,t]})}}function qn(t){return t.source}function Hn(t){return t.target}t.geo.path=function(){var e,r,n,a,i,o=4.5;function s(e){return e&&("function"==typeof o&&a.pointRadius(+o.apply(this,arguments)),i&&i.valid||(i=n(a)),t.geo.stream(e,i)),a.result()}function l(){return i=null,s}return s.area=function(e){return cn=0,t.geo.stream(e,n(gn)),cn},s.centroid=function(e){return _r=wr=kr=Tr=Mr=Ar=Sr=Er=Lr=0,t.geo.stream(e,n(_n)),Lr?[Sr/Lr,Er/Lr]:Ar?[Tr/Ar,Mr/Ar]:kr?[_r/kr,wr/kr]:[NaN,NaN]},s.bounds=function(e){return pn=dn=-(hn=fn=1/0),t.geo.stream(e,n(mn)),[[hn,fn],[pn,dn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||(r=t,a=Sn(function(t,e){return r([t*Ct,e*Ct])}),function(t){return On(a(t))}):P,l()):e;var r,a},s.context=function(t){return arguments.length?(a=null==(r=t)?new yn:new An(t),"function"!=typeof o&&a.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o="function"==typeof t?t:(a.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new En(e);for(var n in t)r[n]=t[n];return r}}},En.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=Cn,t.geo.projectionMutator=Pn,(t.geo.equirectangular=function(){return Cn(zn)}).raw=zn.invert=zn,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Lt,e[1]*Lt))[0]*=Ct,e[1]*=Ct,e}return t=Dn(t[0]%360*Lt,t[1]*Lt,t.length>2?t[2]*Lt:0),e.invert=function(e){return(e=t.invert(e[0]*Lt,e[1]*Lt))[0]*=Ct,e[1]*=Ct,e},e},In.invert=zn,t.geo.circle=function(){var t,e,r=[0,0],n=6;function a(){var t="function"==typeof r?r.apply(this,arguments):r,n=Dn(-t[0]*Lt,-t[1]*Lt,0).invert,a=[];return e(null,null,1,{point:function(t,e){a.push(t=n(t,e)),t[0]*=Ct,t[1]*=Ct}}),{type:"Polygon",coordinates:[a]}}return a.origin=function(t){return arguments.length?(r=t,a):r},a.angle=function(r){return arguments.length?(e=Nn((t=+r)*Lt,n*Lt),a):t},a.precision=function(r){return arguments.length?(e=Nn(t*Lt,(n=+r)*Lt),a):n},a.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Lt,a=t[1]*Lt,i=e[1]*Lt,o=Math.sin(n),s=Math.cos(n),l=Math.sin(a),c=Math.cos(a),u=Math.sin(i),h=Math.cos(i);return Math.atan2(Math.sqrt((r=h*o)*r+(r=c*u-l*h*s)*r),l*u+c*h*s)},t.geo.graticule=function(){var e,r,n,a,i,o,s,l,c,u,h,f,p=10,d=p,g=90,v=360,m=2.5;function x(){return{type:"MultiLineString",coordinates:b()}}function b(){return t.range(Math.ceil(a/g)*g,n,g).map(h).concat(t.range(Math.ceil(l/v)*v,s,v).map(f)).concat(t.range(Math.ceil(r/p)*p,e,p).filter(function(t){return y(t%g)>kt}).map(c)).concat(t.range(Math.ceil(o/d)*d,i,d).filter(function(t){return y(t%v)>kt}).map(u))}return x.lines=function(){return b().map(function(t){return{type:"LineString",coordinates:t}})},x.outline=function(){return{type:"Polygon",coordinates:[h(a).concat(f(s).slice(1),h(n).reverse().slice(1),f(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(a=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],a>n&&(t=a,a=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(m)):[[a,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],i=+t[1][1],r>e&&(t=r,r=e,e=t),o>i&&(t=o,o=i,i=t),x.precision(m)):[[r,o],[e,i]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(g=+t[0],v=+t[1],x):[g,v]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(m=+t,c=Vn(o,i,90),u=Un(r,e,m),h=Vn(l,s,90),f=Un(a,n,m),x):m},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=qn,a=Hn;function i(){return{type:"LineString",coordinates:[e||n.apply(this,arguments),r||a.apply(this,arguments)]}}return i.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||a.apply(this,arguments))},i.source=function(t){return arguments.length?(n=t,e="function"==typeof t?null:t,i):n},i.target=function(t){return arguments.length?(a=t,r="function"==typeof t?null:t,i):a},i.precision=function(){return arguments.length?i:0},i},t.geo.interpolate=function(t,e){return r=t[0]*Lt,n=t[1]*Lt,a=e[0]*Lt,i=e[1]*Lt,o=Math.cos(n),s=Math.sin(n),l=Math.cos(i),c=Math.sin(i),u=o*Math.cos(r),h=o*Math.sin(r),f=l*Math.cos(a),p=l*Math.sin(a),d=2*Math.asin(Math.sqrt(Rt(i-n)+o*l*Rt(a-r))),g=1/Math.sin(d),(v=d?function(t){var e=Math.sin(t*=d)*g,r=Math.sin(d-t)*g,n=r*u+e*f,a=r*h+e*p,i=r*s+e*c;return[Math.atan2(a,n)*Ct,Math.atan2(i,Math.sqrt(n*n+a*a))*Ct]}:function(){return[r*Ct,n*Ct]}).distance=d,v;var r,n,a,i,o,s,l,c,u,h,f,p,d,g,v},t.geo.length=function(e){return bn=0,t.geo.stream(e,Gn),bn};var Gn={sphere:D,point:D,lineStart:function(){var t,e,r;function n(n,a){var i=Math.sin(a*=Lt),o=Math.cos(a),s=y((n*=Lt)-t),l=Math.cos(s);bn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*i-e*o*l)*s),e*i+r*o*l),t=n,e=i,r=o}Gn.point=function(a,i){t=a*Lt,e=Math.sin(i*=Lt),r=Math.cos(i),Gn.point=n},Gn.lineEnd=function(){Gn.point=Gn.lineEnd=D}},lineEnd:D,polygonStart:D,polygonEnd:D};function Yn(t,e){function r(e,r){var n=Math.cos(e),a=Math.cos(r),i=t(n*a);return[i*a*Math.sin(e),i*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),a=e(n),i=Math.sin(a),o=Math.cos(a);return[Math.atan2(t*i,n*o),Math.asin(n&&r*i/n)]},r}var Wn=Yn(function(t){return Math.sqrt(2/(1+t))},function(t){return 2*Math.asin(t/2)});(t.geo.azimuthalEqualArea=function(){return Cn(Wn)}).raw=Wn;var Xn=Yn(function(t){var e=Math.acos(t);return e&&e/Math.sin(e)},P);function Zn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(Mt/4+t/2)},a=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),i=r*Math.pow(n(t),a)/a;if(!a)return Qn;function o(t,e){i>0?e<-Et+kt&&(e=-Et+kt):e>Et-kt&&(e=Et-kt);var r=i/Math.pow(n(e),a);return[r*Math.sin(a*t),i-r*Math.cos(a*t)]}return o.invert=function(t,e){var r=i-e,n=Pt(a)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/a,2*Math.atan(Math.pow(i/n,1/a))-Et]},o}function Jn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),a=r/n+t;if(y(n)<kt)return zn;function i(t,e){var r=a-e;return[r*Math.sin(n*t),a-r*Math.cos(n*t)]}return i.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,a-Pt(n)*Math.sqrt(t*t+r*r)]},i}(t.geo.azimuthalEquidistant=function(){return Cn(Xn)}).raw=Xn,(t.geo.conicConformal=function(){return sn(Zn)}).raw=Zn,(t.geo.conicEquidistant=function(){return sn(Jn)}).raw=Jn;var Kn=Yn(function(t){return 1/t},Math.atan);function Qn(t,e){return[t,Math.log(Math.tan(Mt/4+e/2))]}function $n(t){var e,r=Cn(t),n=r.scale,a=r.translate,i=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=a.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=i.apply(r,arguments);if(o===r){if(e=null==t){var s=Mt*n(),l=a();i([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return Cn(Kn)}).raw=Kn,Qn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Et]},(t.geo.mercator=function(){return $n(Qn)}).raw=Qn;var ta=Yn(function(){return 1},Math.asin);(t.geo.orthographic=function(){return Cn(ta)}).raw=ta;var ea=Yn(function(t){return 1/(1+t)},function(t){return 2*Math.atan(t)});function ra(t,e){return[Math.log(Math.tan(Mt/4+e/2)),-t]}function na(t){return t[0]}function aa(t){return t[1]}function ia(t){for(var e=t.length,r=[0,1],n=2,a=2;a<e;a++){for(;n>1&&Ot(t[r[n-2]],t[r[n-1]],t[a])<=0;)--n;r[n++]=a}return r.slice(0,n)}function oa(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return Cn(ea)}).raw=ea,ra.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Et]},(t.geo.transverseMercator=function(){var t=$n(ra),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ra,t.geom={},t.geom.hull=function(t){var e=na,r=aa;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,a=ve(e),i=ve(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+a.call(this,t[n],n),+i.call(this,t[n],n),n]);for(s.sort(oa),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=ia(s),u=ia(l),h=u[0]===c[0],f=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+h;n<u.length-f;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return U(t,sa),t};var sa=t.geom.polygon.prototype=[];function la(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function ca(t,e,r,n){var a=t[0],i=r[0],o=e[0]-a,s=n[0]-i,l=t[1],c=r[1],u=e[1]-l,h=n[1]-c,f=(s*(l-c)-h*(a-i))/(h*o-s*u);return[a+f*o,l+f*u]}function ua(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}sa.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],a=0;++e<r;)t=n,n=this[e],a+=t[1]*n[0]-t[0]*n[1];return.5*a},sa.centroid=function(t){var e,r,n=-1,a=this.length,i=0,o=0,s=this[a-1];for(arguments.length||(t=-1/(6*this.area()));++n<a;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],i+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[i*t,o*t]},sa.clip=function(t){for(var e,r,n,a,i,o,s=ua(t),l=-1,c=this.length-ua(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,a=this[l],i=e[(n=e.length-s)-1],r=-1;++r<n;)la(o=e[r],u,a)?(la(i,u,a)||t.push(ca(i,o,u,a)),t.push(o)):la(i,u,a)&&t.push(ca(i,o,u,a)),i=o;s&&t.push(t[0]),u=a}return t};var ha,fa,pa,da,ga,va=[],ma=[];function ya(){Ra(this),this.edge=this.site=this.circle=null}function xa(t){var e=va.pop()||new ya;return e.site=t,e}function ba(t){La(t),pa.remove(t),va.push(t),Ra(t)}function _a(t){var e=t.circle,r=e.x,n=e.cy,a={x:r,y:n},i=t.P,o=t.N,s=[t];ba(t);for(var l=i;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)i=l.P,s.unshift(l),ba(l),l=i;s.unshift(l),La(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),ba(c),c=o;s.push(c),La(c);var u,h=s.length;for(u=1;u<h;++u)c=s[u],l=s[u-1],za(c.edge,l.site,c.site,a);l=s[0],(c=s[h-1]).edge=Oa(l.site,c.site,null,a),Ea(l),Ea(c)}function wa(t){for(var e,r,n,a,i=t.x,o=t.y,s=pa._;s;)if((n=ka(s,o)-i)>kt)s=s.L;else{if(!((a=i-Ta(s,o))>kt)){n>-kt?(e=s.P,r=s):a>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=xa(t);if(pa.insert(e,l),e||r){if(e===r)return La(e),r=xa(e.site),pa.insert(l,r),l.edge=r.edge=Oa(e.site,l.site),Ea(e),void Ea(r);if(r){La(e),La(r);var c=e.site,u=c.x,h=c.y,f=t.x-u,p=t.y-h,d=r.site,g=d.x-u,v=d.y-h,m=2*(f*v-p*g),y=f*f+p*p,x=g*g+v*v,b={x:(v*y-p*x)/m+u,y:(f*x-g*y)/m+h};za(r.edge,c,d,b),l.edge=Oa(c,t,null,b),r.edge=Oa(t,d,null,b),Ea(e),Ea(r)}else l.edge=Oa(e.site,l.site)}}function ka(t,e){var r=t.site,n=r.x,a=r.y,i=a-e;if(!i)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,h=1/i-1/c,f=u/c;return h?(-f+Math.sqrt(f*f-2*h*(u*u/(-2*c)-l+c/2+a-i/2)))/h+n:(n+s)/2}function Ta(t,e){var r=t.N;if(r)return ka(r,e);var n=t.site;return n.y===e?n.x:1/0}function Ma(t){this.site=t,this.edges=[]}function Aa(t,e){return e.angle-t.angle}function Sa(){Ra(this),this.x=this.y=this.arc=this.site=this.cy=null}function Ea(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,a=t.site,i=r.site;if(n!==i){var o=a.x,s=a.y,l=n.x-o,c=n.y-s,u=i.x-o,h=2*(l*(v=i.y-s)-c*u);if(!(h>=-Tt)){var f=l*l+c*c,p=u*u+v*v,d=(v*f-c*p)/h,g=(l*p-u*f)/h,v=g+s,m=ma.pop()||new Sa;m.arc=t,m.site=a,m.x=d+o,m.y=v+Math.sqrt(d*d+g*g),m.cy=v,t.circle=m;for(var y=null,x=ga._;x;)if(m.y<x.y||m.y===x.y&&m.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}ga.insert(y,m),y||(da=m)}}}}function La(t){var e=t.circle;e&&(e.P||(da=e.N),ga.remove(e),ma.push(e),Ra(e),t.circle=null)}function Ca(t,e){var r=t.b;if(r)return!0;var n,a,i=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,h=t.r,f=u.x,p=u.y,d=h.x,g=h.y,v=(f+d)/2,m=(p+g)/2;if(g===p){if(v<o||v>=s)return;if(f>d){if(i){if(i.y>=c)return}else i={x:v,y:l};r={x:v,y:c}}else{if(i){if(i.y<l)return}else i={x:v,y:c};r={x:v,y:l}}}else if(a=m-(n=(f-d)/(g-p))*v,n<-1||n>1)if(f>d){if(i){if(i.y>=c)return}else i={x:(l-a)/n,y:l};r={x:(c-a)/n,y:c}}else{if(i){if(i.y<l)return}else i={x:(c-a)/n,y:c};r={x:(l-a)/n,y:l}}else if(p<g){if(i){if(i.x>=s)return}else i={x:o,y:n*o+a};r={x:s,y:n*s+a}}else{if(i){if(i.x<o)return}else i={x:s,y:n*s+a};r={x:o,y:n*o+a}}return t.a=i,t.b=r,!0}function Pa(t,e){this.l=t,this.r=e,this.a=this.b=null}function Oa(t,e,r,n){var a=new Pa(t,e);return ha.push(a),r&&za(a,t,e,r),n&&za(a,e,t,n),fa[t.i].edges.push(new Ia(a,t,e)),fa[e.i].edges.push(new Ia(a,e,t)),a}function za(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function Ia(t,e,r){var n=t.a,a=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(a.x-n.x,n.y-a.y):Math.atan2(n.x-a.x,a.y-n.y)}function Da(){this._=null}function Ra(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Fa(t,e){var r=e,n=e.R,a=r.U;a?a.L===r?a.L=n:a.R=n:t._=n,n.U=a,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Ba(t,e){var r=e,n=e.L,a=r.U;a?a.L===r?a.L=n:a.R=n:t._=n,n.U=a,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Na(t){for(;t.L;)t=t.L;return t}function ja(t,e){var r,n,a,i=t.sort(Va).pop();for(ha=[],fa=new Array(t.length),pa=new Da,ga=new Da;;)if(a=da,i&&(!a||i.y<a.y||i.y===a.y&&i.x<a.x))i.x===r&&i.y===n||(fa[i.i]=new Ma(i),wa(i),r=i.x,n=i.y),i=t.pop();else{if(!a)break;_a(a.arc)}e&&(function(t){for(var e,r=ha,n=nn(t[0][0],t[0][1],t[1][0],t[1][1]),a=r.length;a--;)(!Ca(e=r[a],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(a,1))}(e),function(t){for(var e,r,n,a,i,o,s,l,c,u,h=t[0][0],f=t[1][0],p=t[0][1],d=t[1][1],g=fa,v=g.length;v--;)if((i=g[v])&&i.prepare())for(l=(s=i.edges).length,o=0;o<l;)n=(u=s[o].end()).x,a=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(a-r)>kt)&&(s.splice(o,0,new Ia((m=i.site,x=u,b=y(n-h)<kt&&d-a>kt?{x:h,y:y(e-h)<kt?r:d}:y(a-d)<kt&&f-n>kt?{x:y(r-d)<kt?e:f,y:d}:y(n-f)<kt&&a-p>kt?{x:f,y:y(e-f)<kt?r:p}:y(a-p)<kt&&n-h>kt?{x:y(r-p)<kt?e:h,y:p}:null,_=void 0,_=new Pa(m,null),_.a=x,_.b=b,ha.push(_),_),i.site,null)),++l);var m,x,b,_}(e));var o={cells:fa,edges:ha};return pa=ga=ha=fa=null,o}function Va(t,e){return e.y-t.y||e.x-t.x}Ma.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Aa),e.length},Ia.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},Da.prototype={insert:function(t,e){var r,n,a;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Na(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(a=n.R)&&a.C?(r.C=a.C=!1,n.C=!0,t=n):(t===r.R&&(Fa(this,r),r=(t=r).U),r.C=!1,n.C=!0,Ba(this,n)):(a=n.L)&&a.C?(r.C=a.C=!1,n.C=!0,t=n):(t===r.L&&(Ba(this,r),r=(t=r).U),r.C=!1,n.C=!0,Fa(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,a=t.U,i=t.L,o=t.R;if(r=i?o?Na(o):i:o,a?a.L===t?a.L=r:a.R=r:this._=r,i&&o?(n=r.C,r.C=t.C,r.L=i,i.U=r,r!==o?(a=r.U,r.U=t.U,t=r.R,a.L=t,r.R=o,o.U=r):(r.U=a,a=r,t=r.R)):(n=t.C,t=r),t&&(t.U=a),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===a.L){if((e=a.R).C&&(e.C=!1,a.C=!0,Fa(this,a),e=a.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Ba(this,e),e=a.R),e.C=a.C,a.C=e.R.C=!1,Fa(this,a),t=this._;break}}else if((e=a.L).C&&(e.C=!1,a.C=!0,Ba(this,a),e=a.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Fa(this,e),e=a.L),e.C=a.C,a.C=e.L.C=!1,Ba(this,a),t=this._;break}e.C=!0,t=a,a=a.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=na,r=aa,n=e,a=r,i=Ua;if(t)return o(t);function o(t){var e=new Array(t.length),r=i[0][0],n=i[0][1],a=i[1][0],o=i[1][1];return ja(s(t),i).cells.forEach(function(i,s){var l=i.edges,c=i.site;(e[s]=l.length?l.map(function(t){var e=t.start();return[e.x,e.y]}):c.x>=r&&c.x<=a&&c.y>=n&&c.y<=o?[[r,o],[a,o],[a,n],[r,n]]:[]).point=t[s]}),e}function s(t){return t.map(function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(a(t,e)/kt)*kt,i:e}})}return o.links=function(t){return ja(s(t)).edges.filter(function(t){return t.l&&t.r}).map(function(e){return{source:t[e.l.i],target:t[e.r.i]}})},o.triangles=function(t){var e=[];return ja(s(t)).cells.forEach(function(r,n){for(var a,i,o,s,l=r.site,c=r.edges.sort(Aa),u=-1,h=c.length,f=c[h-1].edge,p=f.l===l?f.r:f.l;++u<h;)f,a=p,p=(f=c[u].edge).l===l?f.r:f.l,n<a.i&&n<p.i&&(o=a,s=p,((i=l).x-s.x)*(o.y-i.y)-(i.x-o.x)*(s.y-i.y)<0)&&e.push([t[n],t[a.i],t[p.i]])}),e},o.x=function(t){return arguments.length?(n=ve(e=t),o):e},o.y=function(t){return arguments.length?(a=ve(r=t),o):r},o.clipExtent=function(t){return arguments.length?(i=null==t?Ua:t,o):i===Ua?null:i},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):i===Ua?null:i&&i[1]},o};var Ua=[[-1e6,-1e6],[1e6,1e6]];function qa(t){return t.x}function Ha(t){return t.y}function Ga(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,a=e.g,i=e.b,o=r.r-n,s=r.g-a,l=r.b-i;return function(t){return"#"+ce(Math.round(n+o*t))+ce(Math.round(a+s*t))+ce(Math.round(i+l*t))}}function Ya(t,e){var r,n={},a={};for(r in t)r in e?n[r]=Ka(t[r],e[r]):a[r]=t[r];for(r in e)r in t||(a[r]=e[r]);return function(t){for(r in n)a[r]=n[r](t);return a}}function Wa(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Xa(t,e){var r,n,a,i=Za.lastIndex=Ja.lastIndex=0,o=-1,s=[],l=[];for(t+="",e+="";(r=Za.exec(t))&&(n=Ja.exec(e));)(a=n.index)>i&&(a=e.slice(i,a),s[o]?s[o]+=a:s[++o]=a),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Wa(r,n)})),i=Ja.lastIndex;return i<e.length&&(a=e.slice(i),s[o]?s[o]+=a:s[++o]=a),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+""}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join("")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,a){var i,o=na,s=aa;if(i=arguments.length)return o=qa,s=Ha,3===i&&(a=r,n=e,r=e=0),l(t);function l(t){var l,c,u,h,f,p,d,g,v,m=ve(o),x=ve(s);if(null!=e)p=e,d=r,g=n,v=a;else if(g=v=-(p=d=1/0),c=[],u=[],f=t.length,i)for(h=0;h<f;++h)(l=t[h]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>g&&(g=l.x),l.y>v&&(v=l.y),c.push(l.x),u.push(l.y);else for(h=0;h<f;++h){var b=+m(l=t[h],h),_=+x(l,h);b<p&&(p=b),_<d&&(d=_),b>g&&(g=b),_>v&&(v=_),c.push(b),u.push(_)}var w=g-p,k=v-d;function T(t,e,r,n,a,i,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)M(t,e,r,n,a,i,o,s);else{var u=t.point;t.x=t.y=t.point=null,M(t,u,l,c,a,i,o,s),M(t,e,r,n,a,i,o,s)}else t.x=r,t.y=n,t.point=e}else M(t,e,r,n,a,i,o,s)}function M(t,e,r,n,a,i,o,s){var l=.5*(a+o),c=.5*(i+s),u=r>=l,h=n>=c,f=h<<1|u;t.leaf=!1,u?a=l:o=l,h?i=c:s=c,T(t=t.nodes[f]||(t.nodes[f]={leaf:!0,nodes:[],point:null,x:null,y:null}),e,r,n,a,i,o,s)}w>k?v=d+w:g=p+k;var A={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(A,t,+m(t,++h),+x(t,h),p,d,g,v)}};if(A.visit=function(t){!function t(e,r,n,a,i,o){if(!e(r,n,a,i,o)){var s=.5*(n+i),l=.5*(a+o),c=r.nodes;c[0]&&t(e,c[0],n,a,s,l),c[1]&&t(e,c[1],s,a,i,l),c[2]&&t(e,c[2],n,l,s,o),c[3]&&t(e,c[3],s,l,i,o)}}(t,A,p,d,g,v)},A.find=function(t){return function(t,e,r,n,a,i,o){var s,l=1/0;return function t(c,u,h,f,p){if(!(u>i||h>o||f<n||p<a)){if(d=c.point){var d,g=e-c.x,v=r-c.y,m=g*g+v*v;if(m<l){var y=Math.sqrt(l=m);n=e-y,a=r-y,i=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+f),_=.5*(h+p),w=(r>=_)<<1|e>=b,k=w+4;w<k;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,h,b,_);break;case 1:t(c,b,h,f,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,f,p)}}}(t,n,a,i,o),s}(A,t[0],t[1],p,d,g,v)},h=-1,null==e){for(;++h<f;)T(A,t[h],c[h],u[h],p,d,g,v);--h}else t.forEach(A.add);return c=u=t=l=null,A}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=a=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],a=+t[1][1]),l):null==e?null:[[e,r],[n,a]]},l.size=function(t){return arguments.length?(null==t?e=r=n=a=null:(e=r=0,n=+t[0],a=+t[1]),l):null==e?null:[n-e,a-r]},l},t.interpolateRgb=Ga,t.interpolateObject=Ya,t.interpolateNumber=Wa,t.interpolateString=Xa;var Za=/[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g,Ja=new RegExp(Za.source,"g");function Ka(e,r){for(var n,a=t.interpolators.length;--a>=0&&!(n=t.interpolators[a](e,r)););return n}function Qa(t,e){var r,n=[],a=[],i=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push(Ka(t[r],e[r]));for(;r<i;++r)a[r]=t[r];for(;r<o;++r)a[r]=e[r];return function(t){for(r=0;r<s;++r)a[r]=n[r](t);return a}}t.interpolate=Ka,t.interpolators=[function(t,e){var r=typeof e;return("string"===r?ge.has(e.toLowerCase())||/^(#|rgb\(|hsl\()/i.test(e)?Ga:Xa:e instanceof Vt?Ga:Array.isArray(e)?Qa:"object"===r&&isNaN(e)?Ya:Wa)(t,e)}],t.interpolateArray=Qa;var $a=function(){return P},ti=t.map({linear:$a,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return ai},cubic:function(){return ii},sin:function(){return si},exp:function(){return li},circle:function(){return ci},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/At*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*At/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return ui}}),ei=t.map({in:P,out:ri,"in-out":ni,"out-in":function(t){return ni(ri(t))}});function ri(t){return function(e){return 1-t(1-e)}}function ni(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function ai(t){return t*t}function ii(t){return t*t*t}function oi(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function si(t){return 1-Math.cos(t*Et)}function li(t){return Math.pow(2,10*(t-1))}function ci(t){return 1-Math.sqrt(1-t*t)}function ui(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function hi(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function fi(t){var e,r,n,a=[t.a,t.b],i=[t.c,t.d],o=di(a),s=pi(a,i),l=di(((e=i)[0]+=(n=-s)*(r=a)[0],e[1]+=n*r[1],e))||0;a[0]*i[1]<i[0]*a[1]&&(a[0]*=-1,a[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(a[1],a[0]):Math.atan2(-i[0],i[1]))*Ct,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*Ct:0}function pi(t,e){return t[0]*e[0]+t[1]*e[1]}function di(t){var e=Math.sqrt(pi(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e,n=t.indexOf("-"),a=n>=0?t.slice(0,n):t,i=n>=0?t.slice(n+1):"in";return a=ti.get(a)||$a,i=ei.get(i)||P,e=i(a.apply(null,r.call(arguments,1))),function(t){return t<=0?0:t>=1?1:e(t)}},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,a=e.c,i=e.l,o=r.h-n,s=r.c-a,l=r.l-i;isNaN(s)&&(s=0,a=isNaN(a)?r.c:a);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Wt(n+o*t,a+s*t,i+l*t)+""}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,a=e.s,i=e.l,o=r.h-n,s=r.s-a,l=r.l-i;isNaN(s)&&(s=0,a=isNaN(a)?r.s:a);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Ht(n+o*t,a+s*t,i+l*t)+""}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,a=e.a,i=e.b,o=r.l-n,s=r.a-a,l=r.b-i;return function(t){return te(n+o*t,a+s*t,i+l*t)+""}},t.interpolateRound=hi,t.transform=function(e){var r=a.createElementNS(t.ns.prefix.svg,"g");return(t.transform=function(t){if(null!=t){r.setAttribute("transform",t);var e=r.transform.baseVal.consolidate()}return new fi(e?e.matrix:gi)})(e)},fi.prototype.toString=function(){return"translate("+this.translate+")rotate("+this.rotate+")skewX("+this.skew+")scale("+this.scale+")"};var gi={a:1,b:0,c:0,d:1,e:0,f:0};function vi(t){return t.length?t.pop()+",":""}function mi(e,r){var n=[],a=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var a=r.push("translate(",null,",",null,")");n.push({i:a-4,x:Wa(t[0],e[0])},{i:a-2,x:Wa(t[1],e[1])})}else(e[0]||e[1])&&r.push("translate("+e+")")}(e.translate,r.translate,n,a),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(vi(r)+"rotate(",null,")")-2,x:Wa(t,e)})):e&&r.push(vi(r)+"rotate("+e+")")}(e.rotate,r.rotate,n,a),function(t,e,r,n){t!==e?n.push({i:r.push(vi(r)+"skewX(",null,")")-2,x:Wa(t,e)}):e&&r.push(vi(r)+"skewX("+e+")")}(e.skew,r.skew,n,a),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var a=r.push(vi(r)+"scale(",null,",",null,")");n.push({i:a-4,x:Wa(t[0],e[0])},{i:a-2,x:Wa(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(vi(r)+"scale("+e+")")}(e.scale,r.scale,n,a),e=r=null,function(t){for(var e,r=-1,i=a.length;++r<i;)n[(e=a[r]).i]=e.x(t);return n.join("")}}function yi(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function xi(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function bi(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=_i(t),n=_i(e),a=r.pop(),i=n.pop(),o=null;for(;a===i;)o=a,a=r.pop(),i=n.pop();return o}(e,r),a=[e];e!==n;)e=e.parent,a.push(e);for(var i=a.length;r!==n;)a.splice(i,0,r),r=r.parent;return a}function _i(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function wi(t){t.fixed|=2}function ki(t){t.fixed&=-7}function Ti(t){t.fixed|=4,t.px=t.x,t.py=t.y}function Mi(t){t.fixed&=-5}t.interpolateTransform=mi,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(bi(t[r]));return e}},t.layout.chord=function(){var e,r,n,a,i,o,s,l={},c=0;function u(){var l,u,f,p,d,g={},v=[],m=t.range(a),y=[];for(e=[],r=[],l=0,p=-1;++p<a;){for(u=0,d=-1;++d<a;)u+=n[p][d];v.push(u),y.push(t.range(a)),l+=u}for(i&&m.sort(function(t,e){return i(v[t],v[e])}),o&&y.forEach(function(t,e){t.sort(function(t,r){return o(n[e][t],n[e][r])})}),l=(At-c*a)/l,u=0,p=-1;++p<a;){for(f=u,d=-1;++d<a;){var x=m[p],b=y[x][d],_=n[x][b],w=u,k=u+=_*l;g[x+"-"+b]={index:x,subindex:b,startAngle:w,endAngle:k,value:_}}r[x]={index:x,startAngle:f,endAngle:u,value:v[x]},u+=c}for(p=-1;++p<a;)for(d=p-1;++d<a;){var T=g[p+"-"+d],M=g[d+"-"+p];(T.value||M.value)&&e.push(T.value<M.value?{source:M,target:T}:{source:T,target:M})}s&&h()}function h(){e.sort(function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)})}return l.matrix=function(t){return arguments.length?(a=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(i=t,e=r=null,l):i},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&h(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,a,i,o,s={},l=t.dispatch("start","tick","end"),c=[1,1],u=.9,h=Ai,f=Si,p=-30,d=Ei,g=.1,v=.64,m=[],y=[];function x(t){return function(e,r,n,a){if(e.point!==t){var i=e.cx-t.x,o=e.cy-t.y,s=a-r,l=i*i+o*o;if(s*s/v<l){if(l<d){var c=e.charge/l;t.px-=i*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=i*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:"end",alpha:n=0}),!0;var r,s,h,f,d,v,b,_,w,k=m.length,T=y.length;for(s=0;s<T;++s)f=(h=y[s]).source,(v=(_=(d=h.target).x-f.x)*_+(w=d.y-f.y)*w)&&(_*=v=n*i[s]*((v=Math.sqrt(v))-a[s])/v,w*=v,d.x-=_*(b=f.weight+d.weight?f.weight/(f.weight+d.weight):.5),d.y-=w*b,f.x+=_*(b=1-b),f.y+=w*b);if((b=n*g)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<k;)(h=m[s]).x+=(_-h.x)*b,h.y+=(w-h.y)*b;if(p)for(!function t(e,r,n){var a=0,i=0;e.charge=0;if(!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,a+=o.charge*o.cx,i+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,a+=u*e.point.x,i+=u*e.point.y}e.cx=a/e.charge;e.cy=i/e.charge}(r=t.geom.quadtree(m),n,o),s=-1;++s<k;)(h=m[s]).fixed||r.visit(x(h));for(s=-1;++s<k;)(h=m[s]).fixed?(h.x=h.px,h.y=h.py):(h.x-=(h.px-(h.px=h.x))*u,h.y-=(h.py-(h.py=h.y))*u);l.tick({type:"tick",alpha:n})},s.nodes=function(t){return arguments.length?(m=t,s):m},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(h="function"==typeof t?t:+t,s):h},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(f="function"==typeof t?t:+t,s):f},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p="function"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(g=+t,s):g},s.theta=function(t){return arguments.length?(v=t*t,s):Math.sqrt(v)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:"end",alpha:n=0})):t>0&&(l.start({type:"start",alpha:n=t}),e=Te(s.tick)),s):n},s.start=function(){var t,e,r,n=m.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=m[t]).index=t,r.weight=0;for(t=0;t<l;++t)"number"==typeof(r=y[t]).source&&(r.source=m[r.source]),"number"==typeof r.target&&(r.target=m[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=m[t],isNaN(r.x)&&(r.x=g("x",u)),isNaN(r.y)&&(r.y=g("y",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(a=[],"function"==typeof h)for(t=0;t<l;++t)a[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=h;if(i=[],"function"==typeof f)for(t=0;t<l;++t)i[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=f;if(o=[],"function"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,m[t],t);else for(t=0;t<n;++t)o[t]=p;function g(r,a){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var i=y[c];e[i.source.index].push(i.target),e[i.target.index].push(i.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*a}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(P).on("dragstart.force",wi).on("drag.force",b).on("dragend.force",ki)),!arguments.length)return r;this.on("mouseover.force",Ti).on("mouseout.force",Mi).call(r)},t.rebind(s,l,"on")};var Ai=20,Si=1,Ei=1/0;function Li(e,r){return t.rebind(e,r,"sort","children","value"),e.nodes=e,e.links=Di,e}function Ci(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(a=t.children)&&(n=a.length))for(var n,a;--n>=0;)r.push(a[n])}function Pi(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(i=t.children)&&(a=i.length))for(var a,i,o=-1;++o<a;)r.push(i[o]);for(;null!=(t=n.pop());)e(t)}function Oi(t){return t.children}function zi(t){return t.value}function Ii(t,e){return e.value-t.value}function Di(e){return t.merge(e.map(function(t){return(t.children||[]).map(function(e){return{source:t,target:e}})}))}t.layout.hierarchy=function(){var t=Ii,e=Oi,r=zi;function n(a){var i,o=[a],s=[];for(a.depth=0;null!=(i=o.pop());)if(s.push(i),(c=e.call(n,i,i.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=i,u.depth=i.depth+1;r&&(i.value=0),i.children=c}else r&&(i.value=+r.call(n,i,i.depth)||0),delete i.children;return Pi(a,function(e){var n,a;t&&(n=e.children)&&n.sort(t),r&&(a=e.parent)&&(a.value+=e.value)}),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(Ci(t,function(t){t.children&&(t.value=0)}),Pi(t,function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)})),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var a=e.call(this,t,n);return function t(e,r,n,a){var i=e.children;if(e.x=r,e.y=e.depth*a,e.dx=n,e.dy=a,i&&(o=i.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=i[c],r,l=s.value*n,a),r+=l}}(a[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(a=r.length))for(var a,i=-1;++i<a;)n=Math.max(n,t(r[i]));return 1+n}(a[0])),a}return n.size=function(t){return arguments.length?(r=t,n):r},Li(n,e)},t.layout.pie=function(){var e=Number,r=Ri,n=0,a=At,i=0;function o(s){var l,c=s.length,u=s.map(function(t,r){return+e.call(o,t,r)}),h=+("function"==typeof n?n.apply(this,arguments):n),f=("function"==typeof a?a.apply(this,arguments):a)-h,p=Math.min(Math.abs(f)/c,+("function"==typeof i?i.apply(this,arguments):i)),d=p*(f<0?-1:1),g=t.sum(u),v=g?(f-c*d)/g:0,m=t.range(c),y=[];return null!=r&&m.sort(r===Ri?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),m.forEach(function(t){y[t]={data:s[t],value:l=u[t],startAngle:h,endAngle:h+=l*v+d,padAngle:p}}),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(a=t,o):a},o.padAngle=function(t){return arguments.length?(i=t,o):i},o};var Ri={};function Fi(t){return t.x}function Bi(t){return t.y}function Ni(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=P,r=Ui,n=qi,a=Ni,i=Fi,o=Bi;function s(l,c){if(!(p=l.length))return l;var u=l.map(function(t,r){return e.call(s,t,r)}),h=u.map(function(t){return t.map(function(t,e){return[i.call(s,t,e),o.call(s,t,e)]})}),f=r.call(s,h,c);u=t.permute(u,f),h=t.permute(h,f);var p,d,g,v,m=n.call(s,h,c),y=u[0].length;for(g=0;g<y;++g)for(a.call(s,u[0][g],v=m[g],h[0][g][1]),d=1;d<p;++d)a.call(s,u[d][g],v+=h[d-1][g][1],h[d][g][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r="function"==typeof t?t:ji.get(t)||Ui,s):r},s.offset=function(t){return arguments.length?(n="function"==typeof t?t:Vi.get(t)||qi,s):n},s.x=function(t){return arguments.length?(i=t,s):i},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(a=t,s):a},s};var ji=t.map({"inside-out":function(e){var r,n,a=e.length,i=e.map(Hi),o=e.map(Gi),s=t.range(a).sort(function(t,e){return i[t]-i[e]}),l=0,c=0,u=[],h=[];for(r=0;r<a;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],h.push(n));return h.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:Ui}),Vi=t.map({silhouette:function(t){var e,r,n,a=t.length,i=t[0].length,o=[],s=0,l=[];for(r=0;r<i;++r){for(e=0,n=0;e<a;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<i;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,a,i,o,s,l,c,u=t.length,h=t[0],f=h.length,p=[];for(p[0]=l=c=0,r=1;r<f;++r){for(e=0,a=0;e<u;++e)a+=t[e][r][1];for(e=0,i=0,s=h[r][0]-h[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;i+=o*t[e][r][1]}p[r]=l-=a?i/a*s:0,l<c&&(c=l)}for(r=0;r<f;++r)p[r]-=c;return p},expand:function(t){var e,r,n,a=t.length,i=t[0].length,o=1/a,s=[];for(r=0;r<i;++r){for(e=0,n=0;e<a;e++)n+=t[e][r][1];if(n)for(e=0;e<a;e++)t[e][r][1]/=n;else for(e=0;e<a;e++)t[e][r][1]=o}for(r=0;r<i;++r)s[r]=0;return s},zero:qi});function Ui(e){return t.range(e.length)}function qi(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Hi(t){for(var e,r=1,n=0,a=t[0][1],i=t.length;r<i;++r)(e=t[r][1])>a&&(n=r,a=e);return n}function Gi(t){return t.reduce(Yi,0)}function Yi(t,e){return t+e[1]}function Wi(t,e){return Xi(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Xi(t,e){for(var r=-1,n=+t[0],a=(t[1]-n)/e,i=[];++r<=e;)i[r]=a*r+n;return i}function Zi(e){return[t.min(e),t.max(e)]}function Ji(t,e){return t.value-e.value}function Ki(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function Qi(t,e){t._pack_next=e,e._pack_prev=t}function $i(t,e){var r=e.x-t.x,n=e.y-t.y,a=t.r+e.r;return.999*a*a>r*r+n*n}function to(t){if((e=t.children)&&(l=e.length)){var e,r,n,a,i,o,s,l,c=1/0,u=-1/0,h=1/0,f=-1/0;if(e.forEach(eo),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(no(r,n,a=e[2]),x(a),Ki(r,a),r._pack_prev=a,Ki(a,n),n=r._pack_next,i=3;i<l;i++){no(r,n,a=e[i]);var p=0,d=1,g=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if($i(o,a)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!$i(s,a);s=s._pack_prev,g++);p?(d<g||d==g&&n.r<r.r?Qi(r,n=o):Qi(r=s,n),i--):(Ki(r,a),n=a,x(a))}var v=(c+u)/2,m=(h+f)/2,y=0;for(i=0;i<l;i++)(a=e[i]).x-=v,a.y-=m,y=Math.max(y,a.r+Math.sqrt(a.x*a.x+a.y*a.y));t.r=y,e.forEach(ro)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),h=Math.min(t.y-t.r,h),f=Math.max(t.y+t.r,f)}}function eo(t){t._pack_next=t._pack_prev=t}function ro(t){delete t._pack_next,delete t._pack_prev}function no(t,e,r){var n=t.r+r.r,a=e.x-t.x,i=e.y-t.y;if(n&&(a||i)){var o=e.r+r.r,s=a*a+i*i,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*a+c*i,r.y=t.y+l*i-c*a}else r.x=t.x+n,r.y=t.y}function ao(t,e){return t.parent==e.parent?1:2}function io(t){var e=t.children;return e.length?e[0]:t.t}function oo(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function so(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function lo(t,e,r){return t.a.parent===e.parent?t.a:r}function co(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function uo(t,e){var r=t.x+e[3],n=t.y+e[0],a=t.dx-e[1]-e[3],i=t.dy-e[0]-e[2];return a<0&&(r+=a/2,a=0),i<0&&(n+=i/2,i=0),{x:r,y:n,dx:a,dy:i}}function ho(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function fo(t){return t.rangeExtent?t.rangeExtent():ho(t.range())}function po(t,e,r,n){var a=r(t[0],t[1]),i=n(e[0],e[1]);return function(t){return i(a(t))}}function go(t,e){var r,n=0,a=t.length-1,i=t[n],o=t[a];return o<i&&(r=n,n=a,a=r,r=i,i=o,o=r),t[n]=e.floor(i),t[a]=e.ceil(o),t}function vo(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:mo}t.layout.histogram=function(){var e=!0,r=Number,n=Zi,a=Wi;function i(i,o){for(var s,l,c=[],u=i.map(r,this),h=n.call(this,u,o),f=a.call(this,h,u,o),p=(o=-1,u.length),d=f.length-1,g=e?1:1/p;++o<d;)(s=c[o]=[]).dx=f[o+1]-(s.x=f[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=h[0]&&l<=h[1]&&((s=c[t.bisect(f,l,1,d)-1]).y+=g,s.push(i[o]));return c}return i.value=function(t){return arguments.length?(r=t,i):r},i.range=function(t){return arguments.length?(n=ve(t),i):n},i.bins=function(t){return arguments.length?(a="number"==typeof t?function(e){return Xi(e,t)}:ve(t),i):a},i.frequency=function(t){return arguments.length?(e=!!t,i):e},i},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort(Ji),n=0,a=[1,1];function i(t,i){var o=r.call(this,t,i),s=o[0],l=a[0],c=a[1],u=null==e?Math.sqrt:"function"==typeof e?e:function(){return e};if(s.x=s.y=0,Pi(s,function(t){t.r=+u(t.value)}),Pi(s,to),n){var h=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;Pi(s,function(t){t.r+=h}),Pi(s,to),Pi(s,function(t){t.r-=h})}return function t(e,r,n,a){var i=e.children;e.x=r+=a*e.x;e.y=n+=a*e.y;e.r*=a;if(i)for(var o=-1,s=i.length;++o<s;)t(i[o],r,n,a)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return i.size=function(t){return arguments.length?(a=t,i):a},i.radius=function(t){return arguments.length?(e=null==t||"function"==typeof t?t:+t,i):e},i.padding=function(t){return arguments.length?(n=+t,i):n},Li(i,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ao,n=[1,1],a=null;function i(t,i){var c=e.call(this,t,i),u=c[0],h=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var a,i=e.children,o=0,s=i.length;o<s;++o)n.push((i[o]=a={_:i[o],parent:e,children:(a=i[o].children)&&a.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=a);return r.children[0]}(u);if(Pi(h,o),h.parent.m=-h.z,Ci(h,s),a)Ci(u,l);else{var f=u,p=u,d=u;Ci(u,function(t){t.x<f.x&&(f=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)});var g=r(f,p)/2-f.x,v=n[0]/(p.x+r(p,f)/2+g),m=n[1]/(d.depth||1);Ci(u,function(t){t.x=(t.x+g)*v,t.y=t.depth*m})}return c}function o(t){var e=t.children,n=t.parent.children,a=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,a=t.children,i=a.length;for(;--i>=0;)(e=a[i]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var i=(e[0].z+e[e.length-1].z)/2;a?(t.z=a.z+r(t._,a._),t.m=t.z-i):t.z=i}else a&&(t.z=a.z+r(t._,a._));t.parent.A=function(t,e,n){if(e){for(var a,i=t,o=t,s=e,l=i.parent.children[0],c=i.m,u=o.m,h=s.m,f=l.m;s=oo(s),i=io(i),s&&i;)l=io(l),(o=oo(o)).a=t,(a=s.z+h-i.z-c+r(s._,i._))>0&&(so(lo(s,t,n),t,a),c+=a,u+=a),h+=s.m,c+=i.m,f+=l.m,u+=o.m;s&&!oo(o)&&(o.t=s,o.m+=h-u),i&&!io(l)&&(l.t=i,l.m+=c-f,n=t)}return n}(t,a,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return i.separation=function(t){return arguments.length?(r=t,i):r},i.size=function(t){return arguments.length?(a=null==(n=t)?l:null,i):a?null:n},i.nodeSize=function(t){return arguments.length?(a=null==(n=t)?null:l,i):a?n:null},Li(i,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ao,n=[1,1],a=!1;function i(i,o){var s,l=e.call(this,i,o),c=l[0],u=0;Pi(c,function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce(function(t,e){return t+e.x},0)/t.length}(n),e.y=function(e){return 1+t.max(e,function(t){return t.y})}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)});var h=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),f=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=h.x-r(h,f)/2,d=f.x+r(f,h)/2;return Pi(c,a?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return i.separation=function(t){return arguments.length?(r=t,i):r},i.size=function(t){return arguments.length?(a=null==(n=t),i):a?null:n},i.nodeSize=function(t){return arguments.length?(a=null!=(n=t),i):a?n:null},Li(i,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,a=[1,1],i=null,o=co,s=!1,l="squarify",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,a=-1,i=t.length;++a<i;)n=(r=t[a]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function h(t){var e=t.children;if(e&&e.length){var r,n,a,i=o(t),s=[],c=e.slice(),f=1/0,g="slice"===l?i.dx:"dice"===l?i.dy:"slice-dice"===l?1&t.depth?i.dy:i.dx:Math.min(i.dx,i.dy);for(u(c,i.dx*i.dy/t.value),s.area=0;(a=c.length)>0;)s.push(r=c[a-1]),s.area+=r.area,"squarify"!==l||(n=p(s,g))<=f?(c.pop(),f=n):(s.area-=s.pop().area,d(s,g,i,!1),g=Math.min(i.dx,i.dy),s.length=s.area=0,f=1/0);s.length&&(d(s,g,i,!0),s.length=s.area=0),e.forEach(h)}}function f(t){var e=t.children;if(e&&e.length){var r,n=o(t),a=e.slice(),i=[];for(u(a,n.dx*n.dy/t.value),i.area=0;r=a.pop();)i.push(r),i.area+=r.area,null!=r.z&&(d(i,r.z?n.dx:n.dy,n,!a.length),i.length=i.area=0);e.forEach(f)}}function p(t,e){for(var r,n=t.area,a=0,i=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<i&&(i=r),r>a&&(a=r));return e*=e,(n*=n)?Math.max(e*a*c/n,n/(e*i*c)):1/0}function d(t,e,r,a){var i,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((a||u>r.dy)&&(u=r.dy);++o<s;)(i=t[o]).x=l,i.y=c,i.dy=u,l+=i.dx=Math.min(r.x+r.dx-l,u?n(i.area/u):0);i.z=!0,i.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((a||u>r.dx)&&(u=r.dx);++o<s;)(i=t[o]).x=l,i.y=c,i.dx=u,c+=i.dy=Math.min(r.y+r.dy-c,u?n(i.area/u):0);i.z=!1,i.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function g(t){var n=e||r(t),i=n[0];return i.x=i.y=0,i.value?(i.dx=a[0],i.dy=a[1]):i.dx=i.dy=0,e&&r.revalue(i),u([i],i.dx*i.dy/i.value),(e?f:h)(i),s&&(e=n),n}return g.size=function(t){return arguments.length?(a=t,g):a},g.padding=function(t){if(!arguments.length)return i;function e(e){return uo(e,t)}var r;return o=null==(i=t)?co:"function"==(r=typeof t)?function(e){var r=t.call(g,e,e.depth);return null==r?co(e):uo(e,"number"==typeof r?[r,r,r,r]:r)}:"number"===r?(t=[t,t,t,t],e):e,g},g.round=function(t){return arguments.length?(n=t?Math.round:Number,g):n!=Number},g.sticky=function(t){return arguments.length?(s=t,e=null,g):s},g.ratio=function(t){return arguments.length?(c=t,g):c},g.mode=function(t){return arguments.length?(l=t+"",g):l},Li(g,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,a;do{a=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!a||a>1);return t+e*r*Math.sqrt(-2*Math.log(a)/a)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var mo={floor:P,ceil:P};function yo(e,r,n,a){var i=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)i.push(n(e[s-1],e[s])),o.push(a(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](i[n](r))}}function xo(e,r){return t.rebind(e,r,"range","rangeRound","interpolate","clamp")}function bo(t,e){return go(t,vo(_o(t,e)[2])),go(t,vo(_o(t,e)[2])),t}function _o(t,e){null==e&&(e=10);var r=ho(t),n=r[1]-r[0],a=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),i=e/n*a;return i<=.15?a*=10:i<=.35?a*=5:i<=.75&&(a*=2),r[0]=Math.ceil(r[0]/a)*a,r[1]=Math.floor(r[1]/a)*a+.5*a,r[2]=a,r}function wo(e,r){return t.range.apply(t,_o(e,r))}function ko(e,r,n){var a=_o(e,r);if(n){var i=Pe.exec(n);if(i.shift(),"s"===i[8]){var o=t.formatPrefix(Math.max(y(a[0]),y(a[1])));return i[7]||(i[7]="."+Mo(o.scale(a[2]))),i[8]="f",n=t.format(i.join("")),function(t){return n(o.scale(t))+o.symbol}}i[7]||(i[7]="."+function(t,e){var r=Mo(e[2]);return t in To?Math.abs(r-Mo(Math.max(y(e[0]),y(e[1]))))+ +("e"!==t):r-2*("%"===t)}(i[8],a)),n=i.join("")}else n=",."+Mo(a[2])+"f";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,a){var i,o;function s(){var t=Math.min(e.length,r.length)>2?yo:po,s=a?xi:yi;return i=t(e,r,s,n),o=t(r,e,s,Ka),l}function l(t){return i(t)}l.invert=function(t){return o(t)};l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e};l.range=function(t){return arguments.length?(r=t,s()):r};l.rangeRound=function(t){return l.range(t).interpolate(hi)};l.clamp=function(t){return arguments.length?(a=t,s()):a};l.interpolate=function(t){return arguments.length?(n=t,s()):n};l.ticks=function(t){return wo(e,t)};l.tickFormat=function(t,r){return ko(e,t,r)};l.nice=function(t){return bo(e,t),s()};l.copy=function(){return t(e,r,n,a)};return s()}([0,1],[0,1],Ka,!1)};var To={s:1,g:1,p:1,r:1,e:1};function Mo(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,a,i){function o(t){return(a?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return a?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}l.invert=function(t){return s(r.invert(t))};l.domain=function(t){return arguments.length?(a=t[0]>=0,r.domain((i=t.map(Number)).map(o)),l):i};l.base=function(t){return arguments.length?(n=+t,r.domain(i.map(o)),l):n};l.nice=function(){var t=go(i.map(o),a?Math:So);return r.domain(t),i=t.map(s),l};l.ticks=function(){var t=ho(i),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),h=n%1?2:n;if(isFinite(u-c)){if(a){for(;c<u;c++)for(var f=1;f<h;f++)e.push(s(c)*f);e.push(s(c))}else for(e.push(s(c));c++<u;)for(var f=h-1;f>0;f--)e.push(s(c)*f);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e};l.tickFormat=function(e,r){if(!arguments.length)return Ao;arguments.length<2?r=Ao:"function"!=typeof r&&(r=t.format(r));var a=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=a?r(t):""}};l.copy=function(){return e(r.copy(),n,a,i)};return xo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var Ao=t.format(".0e"),So={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function Eo(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var a=Eo(r),i=Eo(1/r);function o(t){return e(a(t))}o.invert=function(t){return i(e.invert(t))};o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(a)),o):n};o.ticks=function(t){return wo(n,t)};o.tickFormat=function(t,e){return ko(n,t,e)};o.nice=function(t){return o.domain(bo(n,t))};o.exponent=function(t){return arguments.length?(a=Eo(r=t),i=Eo(1/r),e.domain(n.map(a)),o):r};o.copy=function(){return t(e.copy(),r,n)};return xo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var a,i,o;function s(t){return i[((a.get(t)||("range"===n.t?a.set(t,r.push(t)):NaN))-1)%i.length]}function l(e,n){return t.range(r.length).map(function(t){return e+n*t})}s.domain=function(t){if(!arguments.length)return r;r=[],a=new b;for(var e,i=-1,o=t.length;++i<o;)a.has(e=t[i])||a.set(e,r.push(e));return s[n.t].apply(s,n.a)};s.range=function(t){return arguments.length?(i=t,o=0,n={t:"range",a:arguments},s):i};s.rangePoints=function(t,e){arguments.length<2&&(e=0);var a=t[0],c=t[1],u=r.length<2?(a=(a+c)/2,0):(c-a)/(r.length-1+e);return i=l(a+u*e/2,u),o=0,n={t:"rangePoints",a:arguments},s};s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var a=t[0],c=t[1],u=r.length<2?(a=c=Math.round((a+c)/2),0):(c-a)/(r.length-1+e)|0;return i=l(a+Math.round(u*e/2+(c-a-(r.length-1+e)*u)/2),u),o=0,n={t:"rangeRoundPoints",a:arguments},s};s.rangeBands=function(t,e,a){arguments.length<2&&(e=0),arguments.length<3&&(a=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=(h-u)/(r.length-e+2*a);return i=l(u+f*a,f),c&&i.reverse(),o=f*(1-e),n={t:"rangeBands",a:arguments},s};s.rangeRoundBands=function(t,e,a){arguments.length<2&&(e=0),arguments.length<3&&(a=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=Math.floor((h-u)/(r.length-e+2*a));return i=l(u+Math.round((h-u-(r.length-e)*f)/2),f),c&&i.reverse(),o=Math.round(f*(1-e)),n={t:"rangeRoundBands",a:arguments},s};s.rangeBand=function(){return o};s.rangeExtent=function(){return ho(n.a[0])};s.copy=function(){return e(r,n)};return s.domain(r)}([],{t:"range",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(Lo)},t.scale.category20=function(){return t.scale.ordinal().range(Co)},t.scale.category20b=function(){return t.scale.ordinal().range(Po)},t.scale.category20c=function(){return t.scale.ordinal().range(Oo)};var Lo=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(se),Co=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(se),Po=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(se),Oo=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(se);function zo(){return 0}t.scale.quantile=function(){return function e(r,n){var a;function i(){var e=0,i=n.length;for(a=[];++e<i;)a[e-1]=t.quantile(r,e/i);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(a,e)]}o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(f),i()):r};o.range=function(t){return arguments.length?(n=t,i()):n};o.quantiles=function(){return a};o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?a[t-1]:r[0],t<a.length?a[t]:r[r.length-1]]};o.copy=function(){return e(r,n)};return i()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var a,i;function o(t){return n[Math.max(0,Math.min(i,Math.floor(a*(t-e))))]}function s(){return a=n.length/(r-e),i=n.length-1,o}o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]};o.range=function(t){return arguments.length?(n=t,s()):n};o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/a+e,t+1/a]};o.copy=function(){return t(e,r,n)};return s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function a(e){if(e<=e)return n[t.bisect(r,e)]}a.domain=function(t){return arguments.length?(r=t,a):r};a.range=function(t){return arguments.length?(n=t,a):n};a.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]};a.copy=function(){return e(r,n)};return a}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}r.invert=r;r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e};r.ticks=function(t){return wo(e,t)};r.tickFormat=function(t,r){return ko(e,t,r)};r.copy=function(){return t(e)};return r}([0,1])},t.svg={},t.svg.arc=function(){var t=Do,e=Ro,r=zo,n=Io,a=Fo,i=Bo,o=No;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=a.apply(this,arguments)-Et,h=i.apply(this,arguments)-Et,f=Math.abs(h-u),p=u>h?0:1;if(c<s&&(d=c,c=s,s=d),f>=St)return l(c,p)+(s?l(s,1-p):"")+"Z";var d,g,v,m,y,x,b,_,w,k,T,M,A=0,S=0,E=[];if((m=(+o.apply(this,arguments)||0)/2)&&(v=n===Io?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=It(v/c*Math.sin(m))),s&&(A=It(v/s*Math.sin(m)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(h-S),_=c*Math.sin(h-S);var L=Math.abs(h-u-2*S)<=Mt?0:1;if(S&&jo(y,x,b,_)===p^L){var C=(u+h)/2;y=c*Math.cos(C),x=c*Math.sin(C),b=_=null}}else y=x=0;if(s){w=s*Math.cos(h-A),k=s*Math.sin(h-A),T=s*Math.cos(u+A),M=s*Math.sin(u+A);var P=Math.abs(u-h+2*A)<=Mt?0:1;if(A&&jo(w,k,T,M)===1-p^P){var O=(u+h)/2;w=s*Math.cos(O),k=s*Math.sin(O),T=M=null}}else w=k=0;if(f>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){g=s<c^p?0:1;var z=d,I=d;if(f<Mt){var D=null==T?[w,k]:null==b?[y,x]:ca([y,x],[T,M],[b,_],[w,k]),R=y-D[0],F=x-D[1],B=b-D[0],N=_-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),V=Math.sqrt(D[0]*D[0]+D[1]*D[1]);I=Math.min(d,(s-V)/(j-1)),z=Math.min(d,(c-V)/(j+1))}if(null!=b){var U=Vo(null==T?[w,k]:[T,M],[y,x],c,z,p),q=Vo([b,_],[w,k],c,z,p);d===z?E.push("M",U[0],"A",z,",",z," 0 0,",g," ",U[1],"A",c,",",c," 0 ",1-p^jo(U[1][0],U[1][1],q[1][0],q[1][1]),",",p," ",q[1],"A",z,",",z," 0 0,",g," ",q[0]):E.push("M",U[0],"A",z,",",z," 0 1,",g," ",q[0])}else E.push("M",y,",",x);if(null!=T){var H=Vo([y,x],[T,M],s,-I,p),G=Vo([w,k],null==b?[y,x]:[b,_],s,-I,p);d===I?E.push("L",G[0],"A",I,",",I," 0 0,",g," ",G[1],"A",s,",",s," 0 ",p^jo(G[1][0],G[1][1],H[1][0],H[1][1]),",",1-p," ",H[1],"A",I,",",I," 0 0,",g," ",H[0]):E.push("L",G[0],"A",I,",",I," 0 0,",g," ",H[0])}else E.push("L",w,",",k)}else E.push("M",y,",",x),null!=b&&E.push("A",c,",",c," 0 ",L,",",p," ",b,",",_),E.push("L",w,",",k),null!=T&&E.push("A",s,",",s," 0 ",P,",",1-p," ",T,",",M);return E.push("Z"),E.join("")}function l(t,e){return"M0,"+t+"A"+t+","+t+" 0 1,"+e+" 0,"+-t+"A"+t+","+t+" 0 1,"+e+" 0,"+t}return s.innerRadius=function(e){return arguments.length?(t=ve(e),s):t},s.outerRadius=function(t){return arguments.length?(e=ve(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=ve(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Io?Io:ve(t),s):n},s.startAngle=function(t){return arguments.length?(a=ve(t),s):a},s.endAngle=function(t){return arguments.length?(i=ve(t),s):i},s.padAngle=function(t){return arguments.length?(o=ve(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+a.apply(this,arguments)+ +i.apply(this,arguments))/2-Et;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Io="auto";function Do(t){return t.innerRadius}function Ro(t){return t.outerRadius}function Fo(t){return t.startAngle}function Bo(t){return t.endAngle}function No(t){return t&&t.padAngle}function jo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function Vo(t,e,r,n,a){var i=t[0]-e[0],o=t[1]-e[1],s=(a?n:-n)/Math.sqrt(i*i+o*o),l=s*o,c=-s*i,u=t[0]+l,h=t[1]+c,f=e[0]+l,p=e[1]+c,d=(u+f)/2,g=(h+p)/2,v=f-u,m=p-h,y=v*v+m*m,x=r-n,b=u*p-f*h,_=(m<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*m-v*_)/y,k=(-b*v-m*_)/y,T=(b*m+v*_)/y,M=(-b*v+m*_)/y,A=w-d,S=k-g,E=T-d,L=M-g;return A*A+S*S>E*E+L*L&&(w=T,k=M),[[w-l,k-c],[w*r/x,k*r/x]]}function Uo(t){var e=na,r=aa,n=Xr,a=Ho,i=a.key,o=.7;function s(i){var s,l=[],c=[],u=-1,h=i.length,f=ve(e),p=ve(r);function d(){l.push("M",a(t(c),o))}for(;++u<h;)n.call(this,s=i[u],u)?c.push([+f.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(""):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(i="function"==typeof t?a=t:(a=qo.get(t)||Ho).key,s):i},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return Uo(P)};var qo=t.map({linear:Ho,"linear-closed":Go,step:function(t){var e=0,r=t.length,n=t[0],a=[n[0],",",n[1]];for(;++e<r;)a.push("H",(n[0]+(n=t[e])[0])/2,"V",n[1]);r>1&&a.push("H",n[0]);return a.join("")},"step-before":Yo,"step-after":Wo,basis:Jo,"basis-open":function(t){if(t.length<4)return Ho(t);var e,r=[],n=-1,a=t.length,i=[0],o=[0];for(;++n<3;)e=t[n],i.push(e[0]),o.push(e[1]);r.push(Ko(ts,i)+","+Ko(ts,o)),--n;for(;++n<a;)e=t[n],i.shift(),i.push(e[0]),o.shift(),o.push(e[1]),es(r,i,o);return r.join("")},"basis-closed":function(t){var e,r,n=-1,a=t.length,i=a+4,o=[],s=[];for(;++n<4;)r=t[n%a],o.push(r[0]),s.push(r[1]);e=[Ko(ts,o),",",Ko(ts,s)],--n;for(;++n<i;)r=t[n%a],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),es(e,o,s);return e.join("")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,a,i=t[0][0],o=t[0][1],s=t[r][0]-i,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],a=c/r,n[0]=e*n[0]+(1-e)*(i+a*s),n[1]=e*n[1]+(1-e)*(o+a*l);return Jo(t)},cardinal:function(t,e){return t.length<3?Ho(t):t[0]+Xo(t,Zo(t,e))},"cardinal-open":function(t,e){return t.length<4?Ho(t):t[1]+Xo(t.slice(1,-1),Zo(t,e))},"cardinal-closed":function(t,e){return t.length<3?Go(t):t[0]+Xo((t.push(t[0]),t),Zo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Ho(t):t[0]+Xo(t,function(t){var e,r,n,a,i=[],o=function(t){var e=0,r=t.length-1,n=[],a=t[0],i=t[1],o=n[0]=rs(a,i);for(;++e<r;)n[e]=(o+(o=rs(a=i,i=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=rs(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(a=r*r+n*n)>9&&(a=3*e/Math.sqrt(a),o[s]=a*r,o[s+1]=a*n));s=-1;for(;++s<=l;)a=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),i.push([a||0,o[s]*a||0]);return i}(t))}});function Ho(t){return t.length>1?t.join("L"):t+"Z"}function Go(t){return t.join("L")+"Z"}function Yo(t){for(var e=0,r=t.length,n=t[0],a=[n[0],",",n[1]];++e<r;)a.push("V",(n=t[e])[1],"H",n[0]);return a.join("")}function Wo(t){for(var e=0,r=t.length,n=t[0],a=[n[0],",",n[1]];++e<r;)a.push("H",(n=t[e])[0],"V",n[1]);return a.join("")}function Xo(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Ho(t);var r=t.length!=e.length,n="",a=t[0],i=t[1],o=e[0],s=o,l=1;if(r&&(n+="Q"+(i[0]-2*o[0]/3)+","+(i[1]-2*o[1]/3)+","+i[0]+","+i[1],a=t[1],l=2),e.length>1){s=e[1],i=t[l],l++,n+="C"+(a[0]+o[0])+","+(a[1]+o[1])+","+(i[0]-s[0])+","+(i[1]-s[1])+","+i[0]+","+i[1];for(var c=2;c<e.length;c++,l++)i=t[l],s=e[c],n+="S"+(i[0]-s[0])+","+(i[1]-s[1])+","+i[0]+","+i[1]}if(r){var u=t[l];n+="Q"+(i[0]+2*s[0]/3)+","+(i[1]+2*s[1]/3)+","+u[0]+","+u[1]}return n}function Zo(t,e){for(var r,n=[],a=(1-e)/2,i=t[0],o=t[1],s=1,l=t.length;++s<l;)r=i,i=o,o=t[s],n.push([a*(o[0]-r[0]),a*(o[1]-r[1])]);return n}function Jo(t){if(t.length<3)return Ho(t);var e=1,r=t.length,n=t[0],a=n[0],i=n[1],o=[a,a,a,(n=t[1])[0]],s=[i,i,i,n[1]],l=[a,",",i,"L",Ko(ts,o),",",Ko(ts,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),es(l,o,s);return t.pop(),l.push("L",n),l.join("")}function Ko(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}qo.forEach(function(t,e){e.key=t,e.closed=/-closed$/.test(t)});var Qo=[0,2/3,1/3,0],$o=[0,1/3,2/3,0],ts=[0,1/6,2/3,1/6];function es(t,e,r){t.push("C",Ko(Qo,e),",",Ko(Qo,r),",",Ko($o,e),",",Ko($o,r),",",Ko(ts,e),",",Ko(ts,r))}function rs(t,e){return(e[1]-t[1])/(e[0]-t[0])}function ns(t){for(var e,r,n,a=-1,i=t.length;++a<i;)r=(e=t[a])[0],n=e[1]-Et,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function as(t){var e=na,r=na,n=0,a=aa,i=Xr,o=Ho,s=o.key,l=o,c="L",u=.7;function h(s){var h,f,p,d=[],g=[],v=[],m=-1,y=s.length,x=ve(e),b=ve(n),_=e===r?function(){return f}:ve(r),w=n===a?function(){return p}:ve(a);function k(){d.push("M",o(t(v),u),c,l(t(g.reverse()),u),"Z")}for(;++m<y;)i.call(this,h=s[m],m)?(g.push([f=+x.call(this,h,m),p=+b.call(this,h,m)]),v.push([+_.call(this,h,m),+w.call(this,h,m)])):g.length&&(k(),g=[],v=[]);return g.length&&k(),d.length?d.join(""):null}return h.x=function(t){return arguments.length?(e=r=t,h):r},h.x0=function(t){return arguments.length?(e=t,h):e},h.x1=function(t){return arguments.length?(r=t,h):r},h.y=function(t){return arguments.length?(n=a=t,h):a},h.y0=function(t){return arguments.length?(n=t,h):n},h.y1=function(t){return arguments.length?(a=t,h):a},h.defined=function(t){return arguments.length?(i=t,h):i},h.interpolate=function(t){return arguments.length?(s="function"==typeof t?o=t:(o=qo.get(t)||Ho).key,l=o.reverse||o,c=o.closed?"M":"L",h):s},h.tension=function(t){return arguments.length?(u=t,h):u},h}function is(t){return t.radius}function os(t){return[t.x,t.y]}function ss(){return 64}function ls(){return"circle"}function cs(t){var e=Math.sqrt(t/Mt);return"M0,"+e+"A"+e+","+e+" 0 1,1 0,"+-e+"A"+e+","+e+" 0 1,1 0,"+e+"Z"}t.svg.line.radial=function(){var t=Uo(ns);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Yo.reverse=Wo,Wo.reverse=Yo,t.svg.area=function(){return as(P)},t.svg.area.radial=function(){var t=as(ns);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=qn,e=Hn,r=is,n=Fo,a=Bo;function i(r,n){var a,i,c=o(this,t,r,n),u=o(this,e,r,n);return"M"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(i=u,(a=c).a0==i.a0&&a.a1==i.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+"Z"}function o(t,e,i,o){var s=e.call(t,i,o),l=r.call(t,s,o),c=n.call(t,s,o)-Et,u=a.call(t,s,o)-Et;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return"A"+t+","+t+" 0 "+ +(r>Mt)+",1 "+e}function l(t,e,r,n){return"Q 0,0 "+n}return i.radius=function(t){return arguments.length?(r=ve(t),i):r},i.source=function(e){return arguments.length?(t=ve(e),i):t},i.target=function(t){return arguments.length?(e=ve(t),i):e},i.startAngle=function(t){return arguments.length?(n=ve(t),i):n},i.endAngle=function(t){return arguments.length?(a=ve(t),i):a},i},t.svg.diagonal=function(){var t=qn,e=Hn,r=os;function n(n,a){var i=t.call(this,n,a),o=e.call(this,n,a),s=(i.y+o.y)/2,l=[i,{x:i.x,y:s},{x:o.x,y:s},o];return"M"+(l=l.map(r))[0]+"C"+l[1]+" "+l[2]+" "+l[3]}return n.source=function(e){return arguments.length?(t=ve(e),n):t},n.target=function(t){return arguments.length?(e=ve(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=os,n=e.projection;return e.projection=function(t){return arguments.length?n(function(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Et;return[r*Math.cos(n),r*Math.sin(n)]}}(r=t)):r},e},t.svg.symbol=function(){var t=ls,e=ss;function r(r,n){return(us.get(t.call(this,r,n))||cs)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=ve(e),r):t},r.size=function(t){return arguments.length?(e=ve(t),r):e},r};var us=t.map({circle:cs,cross:function(t){var e=Math.sqrt(t/5)/2;return"M"+-3*e+","+-e+"H"+-e+"V"+-3*e+"H"+e+"V"+-e+"H"+3*e+"V"+e+"H"+e+"V"+3*e+"H"+-e+"V"+e+"H"+-3*e+"Z"},diamond:function(t){var e=Math.sqrt(t/(2*fs)),r=e*fs;return"M0,"+-e+"L"+r+",0 0,"+e+" "+-r+",0Z"},square:function(t){var e=Math.sqrt(t)/2;return"M"+-e+","+-e+"L"+e+","+-e+" "+e+","+e+" "+-e+","+e+"Z"},"triangle-down":function(t){var e=Math.sqrt(t/hs),r=e*hs/2;return"M0,"+r+"L"+e+","+-r+" "+-e+","+-r+"Z"},"triangle-up":function(t){var e=Math.sqrt(t/hs),r=e*hs/2;return"M0,"+-r+"L"+e+","+r+" "+-e+","+r+"Z"}});t.svg.symbolTypes=us.keys();var hs=Math.sqrt(3),fs=Math.tan(30*Lt);W.transition=function(t){for(var e,r,n=vs||++xs,a=ws(t),i=[],o=ms||{time:Date.now(),ease:oi,delay:0,duration:250},s=-1,l=this.length;++s<l;){i.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(r=c[u])&&ks(r,u,a,n,o),e.push(r)}return gs(i,a,n)},W.interrupt=function(t){return this.each(null==t?ps:ds(ws(t)))};var ps=ds(ws());function ds(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function gs(t,e,r){return U(t,ys),t.namespace=e,t.id=r,t}var vs,ms,ys=[],xs=0;function bs(t,e,r,n){var a=t.id,i=t.namespace;return ut(t,"function"==typeof r?function(t,o,s){t[i][a].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[i][a].tween.set(e,r)}))}function _s(t){return null==t&&(t=""),function(){this.textContent=t}}function ws(t){return null==t?"__transition__":"__transition_"+t+"__"}function ks(t,e,r,n,a){var i,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),h=u[n];function f(r){var a=u.active,f=u[a];for(var d in f&&(f.timer.c=null,f.timer.t=NaN,--u.count,delete u[a],f.event&&f.event.interrupt.call(t,t.__data__,f.index)),u)if(+d<n){var g=u[d];g.timer.c=null,g.timer.t=NaN,--u.count,delete u[d]}o.c=p,Te(function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1},0,i),u.active=n,h.event&&h.event.start.call(t,t.__data__,e),c=[],h.tween.forEach(function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)}),l=h.ease,s=h.duration}function p(a){for(var i=a/s,o=l(i),f=c.length;f>0;)c[--f].call(t,o);if(i>=1)return h.event&&h.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}h||(i=a.time,o=Te(function(t){var e=h.delay;if(o.t=e+i,e<=t)return f(t-e);o.c=f},0,i),h=u[n]={tween:new b,time:i,timer:o,delay:a.delay,duration:a.duration,ease:a.ease,index:e},a=null,++u.count)}ys.call=W.call,ys.empty=W.empty,ys.node=W.node,ys.size=W.size,t.transition=function(e,r){return e&&e.transition?vs?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=ys,ys.select=function(t){var e,r,n,a=this.id,i=this.namespace,o=[];t=X(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?("__data__"in n&&(r.__data__=n.__data__),ks(r,u,i,a,n[i][a]),e.push(r)):e.push(null)}return gs(o,i,a)},ys.selectAll=function(t){var e,r,n,a,i,o=this.id,s=this.namespace,l=[];t=Z(t);for(var c=-1,u=this.length;++c<u;)for(var h=this[c],f=-1,p=h.length;++f<p;)if(n=h[f]){i=n[s][o],r=t.call(n,n.__data__,f,c),l.push(e=[]);for(var d=-1,g=r.length;++d<g;)(a=r[d])&&ks(a,d,s,o,i),e.push(a)}return gs(l,s,o)},ys.filter=function(t){var e,r,n=[];"function"!=typeof t&&(t=ct(t));for(var a=0,i=this.length;a<i;a++){n.push(e=[]);for(var o,s=0,l=(o=this[a]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,a)&&e.push(r)}return gs(n,this.namespace,this.id)},ys.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(a){a[n][r].tween.set(t,e)})},ys.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n="transform"==e?mi:Ka,a=t.ns.qualify(e);function i(){this.removeAttribute(a)}function o(){this.removeAttributeNS(a.space,a.local)}return bs(this,"attr."+e,r,a.local?function(t){return null==t?o:(t+="",function(){var e,r=this.getAttributeNS(a.space,a.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(a.space,a.local,e(t))})})}:function(t){return null==t?i:(t+="",function(){var e,r=this.getAttribute(a);return r!==t&&(e=n(r,t),function(t){this.setAttribute(a,e(t))})})})},ys.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween("attr."+e,n.local?function(t,e){var a=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return a&&function(t){this.setAttributeNS(n.space,n.local,a(t))}}:function(t,e){var a=r.call(this,t,e,this.getAttribute(n));return a&&function(t){this.setAttribute(n,a(t))}})},ys.style=function(t,e,r){var n=arguments.length;if(n<3){if("string"!=typeof t){for(r in n<2&&(e=""),t)this.style(r,t[r],e);return this}r=""}function a(){this.style.removeProperty(t)}return bs(this,"style."+t,e,function(e){return null==e?a:(e+="",function(){var n,a=o(this).getComputedStyle(this,null).getPropertyValue(t);return a!==e&&(n=Ka(a,e),function(e){this.style.setProperty(t,n(e),r)})})})},ys.styleTween=function(t,e,r){return arguments.length<3&&(r=""),this.tween("style."+t,function(n,a){var i=e.call(this,n,a,o(this).getComputedStyle(this,null).getPropertyValue(t));return i&&function(e){this.style.setProperty(t,i(e),r)}})},ys.text=function(t){return bs(this,"text",t,_s)},ys.remove=function(){var t=this.namespace;return this.each("end.transition",function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)})},ys.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:("function"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,function(t){t[n][r].ease=e}))},ys.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,"function"==typeof t?function(n,a,i){n[r][e].delay=+t.call(n,n.__data__,a,i)}:(t=+t,function(n){n[r][e].delay=t}))},ys.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,"function"==typeof t?function(n,a,i){n[r][e].duration=Math.max(1,t.call(n,n.__data__,a,i))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},ys.each=function(e,r){var n=this.id,a=this.namespace;if(arguments.length<2){var i=ms,o=vs;try{vs=n,ut(this,function(t,r,i){ms=t[a][n],e.call(t,t.__data__,r,i)})}finally{ms=i,vs=o}}else ut(this,function(i){var o=i[a][n];(o.event||(o.event=t.dispatch("start","end","interrupt"))).on(e,r)});return this},ys.transition=function(){for(var t,e,r,n=this.id,a=++xs,i=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,h=(c=this[s]).length;u<h;u++)(e=c[u])&&ks(e,u,i,a,{time:(r=e[i][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return gs(o,i,a)},t.svg.axis=function(){var e,r=t.scale.linear(),a=Ts,i=6,o=6,s=3,l=[10],c=null;function u(n){n.each(function(){var n,u=t.select(this),h=this.__chart__||r,f=this.__chart__=r.copy(),p=null==c?f.ticks?f.ticks.apply(f,l):f.domain():c,d=null==e?f.tickFormat?f.tickFormat.apply(f,l):P:e,g=u.selectAll(".tick").data(p,f),v=g.enter().insert("g",".domain").attr("class","tick").style("opacity",kt),m=t.transition(g.exit()).style("opacity",kt).remove(),y=t.transition(g.order()).style("opacity",1),x=Math.max(i,0)+s,b=fo(f),_=u.selectAll(".domain").data([0]),w=(_.enter().append("path").attr("class","domain"),t.transition(_));v.append("line"),v.append("text");var k,T,M,A,S=v.select("line"),E=y.select("line"),L=g.select("text").text(d),C=v.select("text"),O=y.select("text"),z="top"===a||"left"===a?-1:1;if("bottom"===a||"top"===a?(n=As,k="x",M="y",T="x2",A="y2",L.attr("dy",z<0?"0em":".71em").style("text-anchor","middle"),w.attr("d","M"+b[0]+","+z*o+"V0H"+b[1]+"V"+z*o)):(n=Ss,k="y",M="x",T="y2",A="x2",L.attr("dy",".32em").style("text-anchor",z<0?"end":"start"),w.attr("d","M"+z*o+","+b[0]+"H0V"+b[1]+"H"+z*o)),S.attr(A,z*i),C.attr(M,z*x),E.attr(T,0).attr(A,z*i),O.attr(k,0).attr(M,z*x),f.rangeBand){var I=f,D=I.rangeBand()/2;h=f=function(t){return I(t)+D}}else h.rangeBand?h=f:m.call(n,f,h);v.call(n,h,f),y.call(n,f,f)})}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(a=t in Ms?t+"":Ts,u):a},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(i=+t,o=+arguments[e-1],u):i},u.innerTickSize=function(t){return arguments.length?(i=+t,u):i},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var Ts="bottom",Ms={top:1,right:1,bottom:1,left:1};function As(t,e,r){t.attr("transform",function(t){var n=e(t);return"translate("+(isFinite(n)?n:r(t))+",0)"})}function Ss(t,e,r){t.attr("transform",function(t){var n=e(t);return"translate(0,"+(isFinite(n)?n:r(t))+")"})}t.svg.brush=function(){var e,r,n=j(f,"brushstart","brush","brushend"),a=null,i=null,s=[0,0],l=[0,0],c=!0,u=!0,h=Ls[0];function f(e){e.each(function(){var e=t.select(this).style("pointer-events","all").style("-webkit-tap-highlight-color","rgba(0,0,0,0)").on("mousedown.brush",v).on("touchstart.brush",v),r=e.selectAll(".background").data([0]);r.enter().append("rect").attr("class","background").style("visibility","hidden").style("cursor","crosshair"),e.selectAll(".extent").data([0]).enter().append("rect").attr("class","extent").style("cursor","move");var n=e.selectAll(".resize").data(h,P);n.exit().remove(),n.enter().append("g").attr("class",function(t){return"resize "+t}).style("cursor",function(t){return Es[t]}).append("rect").attr("x",function(t){return/[ew]$/.test(t)?-3:null}).attr("y",function(t){return/^[ns]/.test(t)?-3:null}).attr("width",6).attr("height",6).style("visibility","hidden"),n.style("display",f.empty()?"none":null);var o,s=t.transition(e),l=t.transition(r);a&&(o=fo(a),l.attr("x",o[0]).attr("width",o[1]-o[0]),d(s)),i&&(o=fo(i),l.attr("y",o[0]).attr("height",o[1]-o[0]),g(s)),p(s)})}function p(t){t.selectAll(".resize").attr("transform",function(t){return"translate("+s[+/e$/.test(t)]+","+l[+/^s/.test(t)]+")"})}function d(t){t.select(".extent").attr("x",s[0]),t.selectAll(".extent,.n>rect,.s>rect").attr("width",s[1]-s[0])}function g(t){t.select(".extent").attr("y",l[0]),t.selectAll(".extent,.e>rect,.w>rect").attr("height",l[1]-l[0])}function v(){var h,v,m=this,y=t.select(t.event.target),x=n.of(m,arguments),b=t.select(m),_=y.datum(),w=!/^(n|s)$/.test(_)&&a,k=!/^(e|w)$/.test(_)&&i,T=y.classed("extent"),M=xt(m),A=t.mouse(m),S=t.select(o(m)).on("keydown.brush",function(){32==t.event.keyCode&&(T||(h=null,A[0]-=s[1],A[1]-=l[1],T=2),B())}).on("keyup.brush",function(){32==t.event.keyCode&&2==T&&(A[0]+=s[1],A[1]+=l[1],T=0,B())});if(t.event.changedTouches?S.on("touchmove.brush",C).on("touchend.brush",O):S.on("mousemove.brush",C).on("mouseup.brush",O),b.interrupt().selectAll("*").interrupt(),T)A[0]=s[0]-A[0],A[1]=l[0]-A[1];else if(_){var E=+/w$/.test(_),L=+/^n/.test(_);v=[s[1-E]-A[0],l[1-L]-A[1]],A[0]=s[E],A[1]=l[L]}else t.event.altKey&&(h=A.slice());function C(){var e=t.mouse(m),r=!1;v&&(e[0]+=v[0],e[1]+=v[1]),T||(t.event.altKey?(h||(h=[(s[0]+s[1])/2,(l[0]+l[1])/2]),A[0]=s[+(e[0]<h[0])],A[1]=l[+(e[1]<h[1])]):h=null),w&&P(e,a,0)&&(d(b),r=!0),k&&P(e,i,1)&&(g(b),r=!0),r&&(p(b),x({type:"brush",mode:T?"move":"resize"}))}function P(t,n,a){var i,o,f=fo(n),p=f[0],d=f[1],g=A[a],v=a?l:s,m=v[1]-v[0];if(T&&(p-=g,d-=m+g),i=(a?u:c)?Math.max(p,Math.min(d,t[a])):t[a],T?o=(i+=g)+m:(h&&(g=Math.max(p,Math.min(d,2*h[a]-i))),g<i?(o=i,i=g):o=g),v[0]!=i||v[1]!=o)return a?r=null:e=null,v[0]=i,v[1]=o,!0}function O(){C(),b.style("pointer-events","all").selectAll(".resize").style("display",f.empty()?"none":null),t.select("body").style("cursor",null),S.on("mousemove.brush",null).on("mouseup.brush",null).on("touchmove.brush",null).on("touchend.brush",null).on("keydown.brush",null).on("keyup.brush",null),M(),x({type:"brushend"})}b.style("pointer-events","none").selectAll(".resize").style("display",null),t.select("body").style("cursor",y.style("cursor")),x({type:"brushstart"}),C()}return f.event=function(a){a.each(function(){var a=n.of(this,arguments),i={x:s,y:l,i:e,j:r},o=this.__chart__||i;this.__chart__=i,vs?t.select(this).transition().each("start.brush",function(){e=o.i,r=o.j,s=o.x,l=o.y,a({type:"brushstart"})}).tween("brush:brush",function(){var t=Qa(s,i.x),n=Qa(l,i.y);return e=r=null,function(e){s=i.x=t(e),l=i.y=n(e),a({type:"brush",mode:"resize"})}}).each("end.brush",function(){e=i.i,r=i.j,a({type:"brush",mode:"resize"}),a({type:"brushend"})}):(a({type:"brushstart"}),a({type:"brush",mode:"resize"}),a({type:"brushend"}))})},f.x=function(t){return arguments.length?(h=Ls[!(a=t)<<1|!i],f):a},f.y=function(t){return arguments.length?(h=Ls[!a<<1|!(i=t)],f):i},f.clamp=function(t){return arguments.length?(a&&i?(c=!!t[0],u=!!t[1]):a?c=!!t:i&&(u=!!t),f):a&&i?[c,u]:a?c:i?u:null},f.extent=function(t){var n,o,c,u,h;return arguments.length?(a&&(n=t[0],o=t[1],i&&(n=n[0],o=o[0]),e=[n,o],a.invert&&(n=a(n),o=a(o)),o<n&&(h=n,n=o,o=h),n==s[0]&&o==s[1]||(s=[n,o])),i&&(c=t[0],u=t[1],a&&(c=c[1],u=u[1]),r=[c,u],i.invert&&(c=i(c),u=i(u)),u<c&&(h=c,c=u,u=h),c==l[0]&&u==l[1]||(l=[c,u])),f):(a&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],a.invert&&(n=a.invert(n),o=a.invert(o)),o<n&&(h=n,n=o,o=h))),i&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],i.invert&&(c=i.invert(c),u=i.invert(u)),u<c&&(h=c,c=u,u=h))),a&&i?[[n,c],[o,u]]:a?[n,o]:i&&[c,u])},f.clear=function(){return f.empty()||(s=[0,0],l=[0,0],e=r=null),f},f.empty=function(){return!!a&&s[0]==s[1]||!!i&&l[0]==l[1]},t.rebind(f,n,"on")};var Es={n:"ns-resize",e:"ew-resize",s:"ns-resize",w:"ew-resize",nw:"nwse-resize",ne:"nesw-resize",se:"nwse-resize",sw:"nesw-resize"},Ls=[["n","e","s","w","nw","ne","se","sw"],["e","w"],["n","s"],[]],Cs=Ie.format=cr.timeFormat,Ps=Cs.utc,Os=Ps("%Y-%m-%dT%H:%M:%S.%LZ");function zs(t){return t.toISOString()}function Is(e,r,n){function a(t){return e(t)}function i(e,n){var a=(e[1]-e[0])/n,i=t.bisect(Rs,a);return i==Rs.length?[r.year,_o(e.map(function(t){return t/31536e6}),n)[2]]:i?r[a/Rs[i-1]<Rs[i]/a?i-1:i]:[Ns,_o(e,n)[2]]}return a.invert=function(t){return Ds(e.invert(t))},a.domain=function(t){return arguments.length?(e.domain(t),a):e.domain().map(Ds)},a.nice=function(t,e){var r=a.domain(),n=ho(r),o=null==t?i(n,10):"number"==typeof t&&i(n,t);function s(r){return!isNaN(r)&&!t.range(r,Ds(+r+1),e).length}return o&&(t=o[0],e=o[1]),a.domain(go(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=Ds(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=Ds(+e+1);return e}}:t))},a.ticks=function(t,e){var r=ho(a.domain()),n=null==t?i(r,10):"number"==typeof t?i(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],Ds(+r[1]+1),e<1?1:e)},a.tickFormat=function(){return n},a.copy=function(){return Is(e.copy(),r,n)},xo(a,e)}function Ds(t){return new Date(t)}Cs.iso=Date.prototype.toISOString&&+new Date("2000-01-01T00:00:00.000Z")?zs:Os,zs.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},zs.toString=Os.toString,Ie.second=Be(function(t){return new De(1e3*Math.floor(t/1e3))},function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))},function(t){return t.getSeconds()}),Ie.seconds=Ie.second.range,Ie.seconds.utc=Ie.second.utc.range,Ie.minute=Be(function(t){return new De(6e4*Math.floor(t/6e4))},function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))},function(t){return t.getMinutes()}),Ie.minutes=Ie.minute.range,Ie.minutes.utc=Ie.minute.utc.range,Ie.hour=Be(function(t){var e=t.getTimezoneOffset()/60;return new De(36e5*(Math.floor(t/36e5-e)+e))},function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))},function(t){return t.getHours()}),Ie.hours=Ie.hour.range,Ie.hours.utc=Ie.hour.utc.range,Ie.month=Be(function(t){return(t=Ie.day(t)).setDate(1),t},function(t,e){t.setMonth(t.getMonth()+e)},function(t){return t.getMonth()}),Ie.months=Ie.month.range,Ie.months.utc=Ie.month.utc.range;var Rs=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Fs=[[Ie.second,1],[Ie.second,5],[Ie.second,15],[Ie.second,30],[Ie.minute,1],[Ie.minute,5],[Ie.minute,15],[Ie.minute,30],[Ie.hour,1],[Ie.hour,3],[Ie.hour,6],[Ie.hour,12],[Ie.day,1],[Ie.day,2],[Ie.week,1],[Ie.month,1],[Ie.month,3],[Ie.year,1]],Bs=Cs.multi([[".%L",function(t){return t.getMilliseconds()}],[":%S",function(t){return t.getSeconds()}],["%I:%M",function(t){return t.getMinutes()}],["%I %p",function(t){return t.getHours()}],["%a %d",function(t){return t.getDay()&&1!=t.getDate()}],["%b %d",function(t){return 1!=t.getDate()}],["%B",function(t){return t.getMonth()}],["%Y",Xr]]),Ns={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(Ds)},floor:P,ceil:P};Fs.year=Ie.year,Ie.scale=function(){return Is(t.scale.linear(),Fs,Bs)};var js=Fs.map(function(t){return[t[0].utc,t[1]]}),Vs=Ps.multi([[".%L",function(t){return t.getUTCMilliseconds()}],[":%S",function(t){return t.getUTCSeconds()}],["%I:%M",function(t){return t.getUTCMinutes()}],["%I %p",function(t){return t.getUTCHours()}],["%a %d",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],["%b %d",function(t){return 1!=t.getUTCDate()}],["%B",function(t){return t.getUTCMonth()}],["%Y",Xr]]);function Us(t){return JSON.parse(t.responseText)}function qs(t){var e=a.createRange();return e.selectNode(a.body),e.createContextualFragment(t.responseText)}js.year=Ie.year.utc,Ie.scale.utc=function(){return Is(t.scale.linear(),js,Vs)},t.text=me(function(t){return t.responseText}),t.json=function(t,e){return ye(t,"application/json",Us,e)},t.html=function(t,e){return ye(t,"text/html",qs,e)},t.xml=me(function(t){return t.responseXML}),"object"==typeof e&&e.exports?e.exports=t:this.d3=t}()},{}],166:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],167:[function(t,e,r){"use strict";var n=t("incremental-convex-hull"),a=t("uniq");function i(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,a=r.length,i=0;i<a;++i){var o=n[i]-r[i];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map(function(t,e){return[t[0],e]});n.sort(function(t,e){return t[0]-e[0]});for(var a=new Array(t-1),i=1;i<t;++i){var o=n[i-1],s=n[i];a[i-1]=[o[1],s[1]]}r&&a.push([-1,a[0][1]],[a[t-1][1],-1]);return a}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var h=t[u],f=new Array(s+1),p=0,d=0;d<s;++d){var g=h[d];f[d]=g,p+=g*g}f[s]=p,l[u]=new i(f,u),c=Math.max(p,c)}a(l,o),r=l.length;for(var v=new Array(r+s+1),m=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1),u=0;u<=s;++u)x[u]=0;x[s]=y,v[0]=x.slice(),m[0]=-1;for(var u=0;u<=s;++u){var f=x.slice();f[u]=1,v[u+1]=f,m[u+1]=-1}for(var u=0;u<r;++u){var b=l[u];v[u+s+1]=b.point,m[u+s+1]=b.index}var _=n(v,!1);_=e?_.filter(function(t){for(var e=0,r=0;r<=s;++r){var n=m[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0}):_.filter(function(t){for(var e=0;e<=s;++e){var r=m[t[e]];if(r<0)return!1;t[e]=r}return!0});if(1&s)for(var u=0;u<_.length;++u){var b=_[u],f=b[0];b[0]=b[1],b[1]=f}return _}},{"incremental-convex-hull":414,uniq:545}],168:[function(t,e,r){"use strict";e.exports=i;var n=(i.canvas=document.createElement("canvas")).getContext("2d"),a=o([32,126]);function i(t,e){Array.isArray(t)&&(t=t.join(", "));var r,i={},s=16,l=.05;e&&(2===e.length&&"number"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=a),n.font=s+"px "+t;for(var c=0;c<r.length;c++){var u=r[c],h=n.measureText(u[0]).width+n.measureText(u[1]).width,f=n.measureText(u).width;if(Math.abs(h-f)>s*l){var p=(f-h)/s;i[u]=1e3*p}}return i}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),a=t[0];a<t[1];a++){var i=n+String.fromCharCode(a);e.push(i)}return e}i.createPairs=o,i.ascii=a},{}],169:[function(t,e,r){(function(t){var r=!1;if("undefined"!=typeof Float64Array){var n=new Float64Array(1),a=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===a[1]){e.exports=function(t){return n[0]=t,[a[0],a[1]]},e.exports.pack=function(t,e){return a[0]=t,a[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,a[0]},e.exports.hi=function(t){return n[0]=t,a[1]}}else if(1072693248===a[0]){e.exports=function(t){return n[0]=t,[a[1],a[0]]},e.exports.pack=function(t,e){return a[1]=t,a[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,a[1]},e.exports.hi=function(t){return n[0]=t,a[0]}}else r=!1}if(!r){var i=new t(8);e.exports=function(t){return i.writeDoubleLE(t,0,!0),[i.readUInt32LE(0,!0),i.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return i.writeUInt32LE(t,0,!0),i.writeUInt32LE(e,4,!0),i.readDoubleLE(0,!0)},e.exports.lo=function(t){return i.writeDoubleLE(t,0,!0),i.readUInt32LE(0,!0)},e.exports.hi=function(t){return i.writeDoubleLE(t,0,!0),i.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),a=1048575&n;return 2146435072&n&&(a+=1<<20),[r,a]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this,t("buffer").Buffer)},{buffer:107}],170:[function(t,e,r){var n=t("abs-svg-path"),a=t("normalize-svg-path"),i={M:"moveTo",C:"bezierCurveTo"};e.exports=function(t,e){t.beginPath(),a(n(e)).forEach(function(e){var r=e[0],n=e.slice(1);t[i[r]].apply(t,n)}),t.closePath()}},{"abs-svg-path":63,"normalize-svg-path":453}],171:[function(t,e,r){e.exports=function(t){switch(t){case"int8":return Int8Array;case"int16":return Int16Array;case"int32":return Int32Array;case"uint8":return Uint8Array;case"uint16":return Uint16Array;case"uint32":return Uint32Array;case"float32":return Float32Array;case"float64":return Float64Array;case"array":return Array;case"uint8_clamped":return Uint8ClampedArray}}},{}],172:[function(t,e,r){"use strict";e.exports=function(t,e){switch("undefined"==typeof e&&(e=0),typeof t){case"number":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case"object":if("number"==typeof t.length)return function t(e,r,n){var a=0|e[n];if(a<=0)return[];var i,o=new Array(a);if(n===e.length-1)for(i=0;i<a;++i)o[i]=r;else for(i=0;i<a;++i)o[i]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],173:[function(t,e,r){"use strict";function n(t,e,r){r=r||2;var n,s,l,c,u,p,d,v=e&&e.length,m=v?e[0]*r:t.length,y=a(t,0,m,r,!0),x=[];if(!y||y.next===y.prev)return x;if(v&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=a(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(g(u));for(p.sort(h),o=0;o<p.length;o++)f(p[o],r),r=i(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<m;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);d=0!==(d=Math.max(l-n,c-s))?1/d:0}return o(y,x,r,n,s,d),x}function a(t,e,r,n,a){var i,o;if(a===E(t,e,r,n)>0)for(i=e;i<r;i+=n)o=M(i,t[i],t[i+1],o);else for(i=r-n;i>=e;i-=n)o=M(i,t[i],t[i+1],o);return o&&x(o,o.next)&&(A(o),o=o.next),o}function i(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!x(n,n.next)&&0!==y(n.prev,n,n.next))n=n.next;else{if(A(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,a,h,f){if(t){!f&&h&&function(t,e,r,n){var a=t;do{null===a.z&&(a.z=d(a.x,a.y,e,r,n)),a.prevZ=a.prev,a.nextZ=a.next,a=a.next}while(a!==t);a.prevZ.nextZ=null,a.prevZ=null,function(t){var e,r,n,a,i,o,s,l,c=1;do{for(r=t,t=null,i=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(a=r,r=r.nextZ,s--):(a=n,n=n.nextZ,l--),i?i.nextZ=a:t=a,a.prevZ=i,i=a;r=n}i.nextZ=null,c*=2}while(o>1)}(a)}(t,n,a,h);for(var p,g,v=t;t.prev!==t.next;)if(p=t.prev,g=t.next,h?l(t,n,a,h):s(t))e.push(p.i/r),e.push(t.i/r),e.push(g.i/r),A(t),t=g.next,v=g.next;else if((t=g)===v){f?1===f?o(t=c(i(t),e,r),e,r,n,a,h,2):2===f&&u(t,e,r,n,a,h):o(i(t),e,r,n,a,h,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(y(e,r,n)>=0)return!1;for(var a=t.next.next;a!==t.prev;){if(v(e.x,e.y,r.x,r.y,n.x,n.y,a.x,a.y)&&y(a.prev,a,a.next)>=0)return!1;a=a.next}return!0}function l(t,e,r,n){var a=t.prev,i=t,o=t.next;if(y(a,i,o)>=0)return!1;for(var s=a.x<i.x?a.x<o.x?a.x:o.x:i.x<o.x?i.x:o.x,l=a.y<i.y?a.y<o.y?a.y:o.y:i.y<o.y?i.y:o.y,c=a.x>i.x?a.x>o.x?a.x:o.x:i.x>o.x?i.x:o.x,u=a.y>i.y?a.y>o.y?a.y:o.y:i.y>o.y?i.y:o.y,h=d(s,l,e,r,n),f=d(c,u,e,r,n),p=t.prevZ,g=t.nextZ;p&&p.z>=h&&g&&g.z<=f;){if(p!==t.prev&&p!==t.next&&v(a.x,a.y,i.x,i.y,o.x,o.y,p.x,p.y)&&y(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,g!==t.prev&&g!==t.next&&v(a.x,a.y,i.x,i.y,o.x,o.y,g.x,g.y)&&y(g.prev,g,g.next)>=0)return!1;g=g.nextZ}for(;p&&p.z>=h;){if(p!==t.prev&&p!==t.next&&v(a.x,a.y,i.x,i.y,o.x,o.y,p.x,p.y)&&y(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;g&&g.z<=f;){if(g!==t.prev&&g!==t.next&&v(a.x,a.y,i.x,i.y,o.x,o.y,g.x,g.y)&&y(g.prev,g,g.next)>=0)return!1;g=g.nextZ}return!0}function c(t,e,r){var n=t;do{var a=n.prev,o=n.next.next;!x(a,o)&&b(a,n,n.next,o)&&k(a,o)&&k(o,a)&&(e.push(a.i/r),e.push(n.i/r),e.push(o.i/r),A(n),A(n.next),n=t=o),n=n.next}while(n!==t);return i(n)}function u(t,e,r,n,a,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&m(l,c)){var u=T(l,c);return l=i(l,l.next),u=i(u,u.next),o(l,e,r,n,a,s),void o(u,e,r,n,a,s)}c=c.next}l=l.next}while(l!==t)}function h(t,e){return t.x-e.x}function f(t,e){if(e=function(t,e){var r,n=e,a=t.x,i=t.y,o=-1/0;do{if(i<=n.y&&i>=n.next.y&&n.next.y!==n.y){var s=n.x+(i-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=a&&s>o){if(o=s,s===a){if(i===n.y)return n;if(i===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(a===o)return r;var l,c=r,u=r.x,h=r.y,f=1/0;n=r;do{a>=n.x&&n.x>=u&&a!==n.x&&v(i<h?a:o,i,u,h,i<h?o:a,i,n.x,n.y)&&(l=Math.abs(i-n.y)/(a-n.x),k(n,t)&&(l<f||l===f&&(n.x>r.x||n.x===r.x&&p(r,n)))&&(r=n,f=l)),n=n.next}while(n!==c);return r}(t,e)){var r=T(e,t);i(r,r.next)}}function p(t,e){return y(t.prev,t,e.prev)<0&&y(e.next,t,t.next)<0}function d(t,e,r,n,a){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*a)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*a)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function g(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function v(t,e,r,n,a,i,o,s){return(a-o)*(e-s)-(t-o)*(i-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(i-s)-(a-o)*(n-s)>=0}function m(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&b(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(k(t,e)&&k(e,t)&&function(t,e){var r=t,n=!1,a=(t.x+e.x)/2,i=(t.y+e.y)/2;do{r.y>i!=r.next.y>i&&r.next.y!==r.y&&a<(r.next.x-r.x)*(i-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(y(t.prev,t,e.prev)||y(t,e.prev,e))||x(t,e)&&y(t.prev,t,t.next)>0&&y(e.prev,e,e.next)>0)}function y(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function x(t,e){return t.x===e.x&&t.y===e.y}function b(t,e,r,n){var a=w(y(t,e,r)),i=w(y(t,e,n)),o=w(y(r,n,t)),s=w(y(r,n,e));return a!==i&&o!==s||(!(0!==a||!_(t,r,e))||(!(0!==i||!_(t,n,e))||(!(0!==o||!_(r,t,n))||!(0!==s||!_(r,e,n)))))}function _(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function w(t){return t>0?1:t<0?-1:0}function k(t,e){return y(t.prev,t,t.next)<0?y(t,e,t.next)>=0&&y(t,t.prev,e)>=0:y(t,e,t.prev)<0||y(t,t.next,e)<0}function T(t,e){var r=new S(t.i,t.x,t.y),n=new S(e.i,e.x,e.y),a=t.next,i=e.prev;return t.next=e,e.prev=t,r.next=a,a.prev=r,n.next=r,r.prev=n,i.next=n,n.prev=i,n}function M(t,e,r,n){var a=new S(t,e,r);return n?(a.next=n.next,a.prev=n,n.next.prev=a,n.next=a):(a.prev=a,a.next=a),a}function A(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function S(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function E(t,e,r,n){for(var a=0,i=e,o=r-n;i<r;i+=n)a+=(t[o]-t[i])*(t[i+1]+t[o+1]),o=i;return a}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var a=e&&e.length,i=a?e[0]*r:t.length,o=Math.abs(E(t,0,i,r));if(a)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(E(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,a=0;a<t.length;a++){for(var i=0;i<t[a].length;i++)for(var o=0;o<e;o++)r.vertices.push(t[a][i][o]);a>0&&(n+=t[a-1].length,r.holes.push(n))}return r}},{}],174:[function(t,e,r){"use strict";e.exports=function(t,e){var r=t.length;if("number"!=typeof e){e=0;for(var a=0;a<r;++a){var i=t[a];e=Math.max(e,i[0],i[1])}e=1+(0|e)}e|=0;for(var o=new Array(e),a=0;a<e;++a)o[a]=[];for(var a=0;a<r;++a){var i=t[a];o[i[0]].push(i[1]),o[i[1]].push(i[0])}for(var s=0;s<e;++s)n(o[s],function(t,e){return t-e});return o};var n=t("uniq")},{uniq:545}],175:[function(t,e,r){var n=t("strongly-connected-components");e.exports=function(t){var e,r=[],a=[],i=[],o={},s=[];function l(t){var r,n,u=!1;for(a.push(t),i[t]=!0,r=0;r<s[t].length;r++)(n=s[t][r])===e?(c(e,a),u=!0):i[n]||(u=l(n));if(u)!function t(e){i[e]=!1,o.hasOwnProperty(e)&&Object.keys(o[e]).forEach(function(r){delete o[e][r],i[r]&&t(r)})}(t);else for(r=0;r<s[t].length;r++){n=s[t][r];var h=o[n];h||(h={},o[n]=h),h[n]=!0}return a.pop(),u}function c(t,e){var n=[].concat(e).concat(t);r.push(n)}function u(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter(function(t){return t>=e})}(e);for(var r,a=n(t).components.filter(function(t){return t.length>1}),i=1/0,o=0;o<a.length;o++)for(var s=0;s<a[o].length;s++)a[o][s]<i&&(i=a[o][s],r=o);var l=a[r];return!!l&&{leastVertex:i,adjList:t.map(function(t,e){return-1===l.indexOf(e)?[]:t.filter(function(t){return-1!==l.indexOf(t)})})}}e=0;for(var h=t.length;e<h;){var f=u(e);if(e=f.leastVertex,s=f.adjList){for(var p=0;p<s.length;p++)for(var d=0;d<s[p].length;d++){var g=s[p][d];i[+g]=!1,o[g]={}}l(e),e+=1}else e=h}return r}},{"strongly-connected-components":528}],176:[function(t,e,r){"use strict";var n=t("../../object/valid-value");e.exports=function(){return n(this).length=0,this}},{"../../object/valid-value":208}],177:[function(t,e,r){"use strict";e.exports=t("./is-implemented")()?Array.from:t("./shim")},{"./is-implemented":178,"./shim":179}],178:[function(t,e,r){"use strict";e.exports=function(){var t,e,r=Array.from;return"function"==typeof r&&(e=r(t=["raz","dwa"]),Boolean(e&&e!==t&&"dwa"===e[1]))}},{}],179:[function(t,e,r){"use strict";var n=t("es6-symbol").iterator,a=t("../../function/is-arguments"),i=t("../../function/is-function"),o=t("../../number/to-pos-integer"),s=t("../../object/valid-callable"),l=t("../../object/valid-value"),c=t("../../object/is-value"),u=t("../../string/is-string"),h=Array.isArray,f=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,g,v,m,y,x,b,_,w,k=arguments[1],T=arguments[2];if(t=Object(l(t)),c(k)&&s(k),this&&this!==Array&&i(this))e=this;else{if(!k){if(a(t))return 1!==(m=t.length)?Array.apply(null,t):((v=new Array(1))[0]=t[0],v);if(h(t)){for(v=new Array(m=t.length),r=0;r<m;++r)v[r]=t[r];return v}}v=[]}if(!h(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(v=new e),b=x.next(),r=0;!b.done;)w=k?f.call(k,T,b.value,r):b.value,e?(p.value=w,d(v,r,p)):v[r]=w,b=x.next(),++r;m=r}else if(u(t)){for(m=t.length,e&&(v=new e),r=0,g=0;r<m;++r)w=t[r],r+1<m&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=k?f.call(k,T,w,g):w,e?(p.value=w,d(v,g,p)):v[g]=w,++g;m=g}if(void 0===m)for(m=o(t.length),e&&(v=new e(m)),r=0;r<m;++r)w=k?f.call(k,T,t[r],r):t[r],e?(p.value=w,d(v,r,p)):v[r]=w;return e&&(p.value=null,v.length=m),v}},{"../../function/is-arguments":180,"../../function/is-function":181,"../../number/to-pos-integer":187,"../../object/is-value":197,"../../object/valid-callable":206,"../../object/valid-value":208,"../../string/is-string":212,"es6-symbol":222}],180:[function(t,e,r){"use strict";var n=Object.prototype.toString,a=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===a}},{}],181:[function(t,e,r){"use strict";var n=Object.prototype.toString,a=n.call(t("./noop"));e.exports=function(t){return"function"==typeof t&&n.call(t)===a}},{"./noop":182}],182:[function(t,e,r){"use strict";e.exports=function(){}},{}],183:[function(t,e,r){"use strict";e.exports=t("./is-implemented")()?Math.sign:t("./shim")},{"./is-implemented":184,"./shim":185}],184:[function(t,e,r){"use strict";e.exports=function(){var t=Math.sign;return"function"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],185:[function(t,e,r){"use strict";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],186:[function(t,e,r){"use strict";var n=t("../math/sign"),a=Math.abs,i=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*i(a(t)):t}},{"../math/sign":183}],187:[function(t,e,r){"use strict";var n=t("./to-integer"),a=Math.max;e.exports=function(t){return a(0,n(t))}},{"./to-integer":186}],188:[function(t,e,r){"use strict";var n=t("./valid-callable"),a=t("./valid-value"),i=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,h=arguments[2],f=arguments[3];return r=Object(a(r)),n(c),u=s(r),f&&u.sort("function"==typeof f?i.call(f,r):void 0),"function"!=typeof t&&(t=u[t]),o.call(t,u,function(t,n){return l.call(r,t)?o.call(c,h,r[t],t,r,n):e})}}},{"./valid-callable":206,"./valid-value":208}],189:[function(t,e,r){"use strict";e.exports=t("./is-implemented")()?Object.assign:t("./shim")},{"./is-implemented":190,"./shim":191}],190:[function(t,e,r){"use strict";e.exports=function(){var t,e=Object.assign;return"function"==typeof e&&(e(t={foo:"raz"},{bar:"dwa"},{trzy:"trzy"}),t.foo+t.bar+t.trzy==="razdwatrzy")}},{}],191:[function(t,e,r){"use strict";var n=t("../keys"),a=t("../valid-value"),i=Math.max;e.exports=function(t,e){var r,o,s,l=i(arguments.length,2);for(t=Object(a(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)e=arguments[o],n(e).forEach(s);if(void 0!==r)throw r;return t}},{"../keys":198,"../valid-value":208}],192:[function(t,e,r){"use strict";var n=t("../array/from"),a=t("./assign"),i=t("./valid-value");e.exports=function(t){var e=Object(i(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,function(e){(o.ensure||e in t)&&(s[e]=t[e])}):a(s,t),s}},{"../array/from":177,"./assign":189,"./valid-value":208}],193:[function(t,e,r){"use strict";var n,a,i,o,s=Object.create;t("./set-prototype-of/is-implemented")()||(n=t("./set-prototype-of/shim")),e.exports=n?1!==n.level?s:(a={},i={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach(function(t){i[t]="__proto__"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}}),Object.defineProperties(a,i),Object.defineProperty(n,"nullPolyfill",{configurable:!1,enumerable:!1,writable:!1,value:a}),function(t,e){return s(null===t?a:t,e)}):s},{"./set-prototype-of/is-implemented":204,"./set-prototype-of/shim":205}],194:[function(t,e,r){"use strict";e.exports=t("./_iterate")("forEach")},{"./_iterate":188}],195:[function(t,e,r){"use strict";e.exports=function(t){return"function"==typeof t}},{}],196:[function(t,e,r){"use strict";var n=t("./is-value"),a={function:!0,object:!0};e.exports=function(t){return n(t)&&a[typeof t]||!1}},{"./is-value":197}],197:[function(t,e,r){"use strict";var n=t("../function/noop")();e.exports=function(t){return t!==n&&null!==t}},{"../function/noop":182}],198:[function(t,e,r){"use strict";e.exports=t("./is-implemented")()?Object.keys:t("./shim")},{"./is-implemented":199,"./shim":200}],199:[function(t,e,r){"use strict";e.exports=function(){try{return Object.keys("primitive"),!0}catch(t){return!1}}},{}],200:[function(t,e,r){"use strict";var n=t("../is-value"),a=Object.keys;e.exports=function(t){return a(n(t)?Object(t):t)}},{"../is-value":197}],201:[function(t,e,r){"use strict";var n=t("./valid-callable"),a=t("./for-each"),i=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),a(t,function(t,n,a,s){r[n]=i.call(e,o,t,n,a,s)}),r}},{"./for-each":194,"./valid-callable":206}],202:[function(t,e,r){"use strict";var n=t("./is-value"),a=Array.prototype.forEach,i=Object.create;e.exports=function(t){var e=i(null);return a.call(arguments,function(t){n(t)&&function(t,e){var r;for(r in t)e[r]=t[r]}(Object(t),e)}),e}},{"./is-value":197}],203:[function(t,e,r){"use strict";e.exports=t("./is-implemented")()?Object.setPrototypeOf:t("./shim")},{"./is-implemented":204,"./shim":205}],204:[function(t,e,r){"use strict";var n=Object.create,a=Object.getPrototypeOf,i={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return"function"==typeof t&&a(t(e(null),i))===i}},{}],205:[function(t,e,r){"use strict";var n,a,i,o,s=t("../is-object"),l=t("../valid-value"),c=Object.prototype.isPrototypeOf,u=Object.defineProperty,h={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(l(t),null===e||s(e))return t;throw new TypeError("Prototype must be null or an object")},e.exports=(a=function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,"__proto__");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}())?(2===a.level?a.set?(o=a.set,i=function(t,e){return o.call(n(t,e),e),t}):i=function(t,e){return n(t,e).__proto__=e,t}:i=function t(e,r){var a;return n(e,r),(a=c.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,a&&u(t.nullPolyfill,"__proto__",h),e},Object.defineProperty(i,"level",{configurable:!1,enumerable:!1,writable:!1,value:a.level})):null,t("../create")},{"../create":193,"../is-object":196,"../valid-value":208}],206:[function(t,e,r){"use strict";e.exports=function(t){if("function"!=typeof t)throw new TypeError(t+" is not a function");return t}},{}],207:[function(t,e,r){"use strict";var n=t("./is-object");e.exports=function(t){if(!n(t))throw new TypeError(t+" is not an Object");return t}},{"./is-object":196}],208:[function(t,e,r){"use strict";var n=t("./is-value");e.exports=function(t){if(!n(t))throw new TypeError("Cannot use null or undefined");return t}},{"./is-value":197}],209:[function(t,e,r){"use strict";e.exports=t("./is-implemented")()?String.prototype.contains:t("./shim")},{"./is-implemented":210,"./shim":211}],210:[function(t,e,r){"use strict";var n="razdwatrzy";e.exports=function(){return"function"==typeof n.contains&&(!0===n.contains("dwa")&&!1===n.contains("foo"))}},{}],211:[function(t,e,r){"use strict";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],212:[function(t,e,r){"use strict";var n=Object.prototype.toString,a=n.call("");e.exports=function(t){return"string"==typeof t||t&&"object"==typeof t&&(t instanceof String||n.call(t)===a)||!1}},{}],213:[function(t,e,r){"use strict";var n=Object.create(null),a=Math.random;e.exports=function(){var t;do{t=a().toString(36).slice(2)}while(n[t]);return t}},{}],214:[function(t,e,r){"use strict";var n,a=t("es5-ext/object/set-prototype-of"),i=t("es5-ext/string/#/contains"),o=t("d"),s=t("es6-symbol"),l=t("./"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError("Constructor requires 'new'");l.call(this,t),e=e?i.call(e,"key+value")?"key+value":i.call(e,"key")?"key":"value":"value",c(this,"__kind__",o("",e))},a&&a(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o(function(t){return"value"===this.__kind__?this.__list__[t]:"key+value"===this.__kind__?[t,this.__list__[t]]:t})}),c(n.prototype,s.toStringTag,o("c","Array Iterator"))},{"./":217,d:153,"es5-ext/object/set-prototype-of":203,"es5-ext/string/#/contains":209,"es6-symbol":222}],215:[function(t,e,r){"use strict";var n=t("es5-ext/function/is-arguments"),a=t("es5-ext/object/valid-callable"),i=t("es5-ext/string/is-string"),o=t("./get"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,h,f,p,d,g,v,m=arguments[2];if(s(t)||n(t)?r="array":i(t)?r="string":t=o(t),a(e),h=function(){f=!0},"array"!==r)if("string"!==r)for(u=t.next();!u.done;){if(l.call(e,m,u.value,h),f)return;u=t.next()}else for(d=t.length,p=0;p<d&&(g=t[p],p+1<d&&(v=g.charCodeAt(0))>=55296&&v<=56319&&(g+=t[++p]),l.call(e,m,g,h),!f);++p);else c.call(t,function(t){return l.call(e,m,t,h),f})}},{"./get":216,"es5-ext/function/is-arguments":180,"es5-ext/object/valid-callable":206,"es5-ext/string/is-string":212}],216:[function(t,e,r){"use strict";var n=t("es5-ext/function/is-arguments"),a=t("es5-ext/string/is-string"),i=t("./array"),o=t("./string"),s=t("./valid-iterable"),l=t("es6-symbol").iterator;e.exports=function(t){return"function"==typeof s(t)[l]?t[l]():n(t)?new i(t):a(t)?new o(t):new i(t)}},{"./array":214,"./string":219,"./valid-iterable":220,"es5-ext/function/is-arguments":180,"es5-ext/string/is-string":212,"es6-symbol":222}],217:[function(t,e,r){"use strict";var n,a=t("es5-ext/array/#/clear"),i=t("es5-ext/object/assign"),o=t("es5-ext/object/valid-callable"),s=t("es5-ext/object/valid-value"),l=t("d"),c=t("d/auto-bind"),u=t("es6-symbol"),h=Object.defineProperty,f=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError("Constructor requires 'new'");f(this,{__list__:l("w",s(t)),__context__:l("w",e),__nextIndex__:l("w",0)}),e&&(o(e.on),e.on("_add",this._onAdd),e.on("_delete",this._onDelete),e.on("_clear",this._onClear))},delete n.prototype.constructor,f(n.prototype,i({_next:l(function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()}),next:l(function(){return this._createResult(this._next())}),_createResult:l(function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}}),_resolve:l(function(t){return this.__list__[t]}),_unBind:l(function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off("_add",this._onAdd),this.__context__.off("_delete",this._onDelete),this.__context__.off("_clear",this._onClear),this.__context__=null)}),toString:l(function(){return"[object "+(this[u.toStringTag]||"Object")+"]"})},c({_onAdd:l(function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach(function(e,r){e>=t&&(this.__redo__[r]=++e)},this),this.__redo__.push(t)):h(this,"__redo__",l("c",[t])))}),_onDelete:l(function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach(function(e,r){e>t&&(this.__redo__[r]=--e)},this)))}),_onClear:l(function(){this.__redo__&&a.call(this.__redo__),this.__nextIndex__=0})}))),h(n.prototype,u.iterator,l(function(){return this}))},{d:153,"d/auto-bind":152,"es5-ext/array/#/clear":176,"es5-ext/object/assign":189,"es5-ext/object/valid-callable":206,"es5-ext/object/valid-value":208,"es6-symbol":222}],218:[function(t,e,r){"use strict";var n=t("es5-ext/function/is-arguments"),a=t("es5-ext/object/is-value"),i=t("es5-ext/string/is-string"),o=t("es6-symbol").iterator,s=Array.isArray;e.exports=function(t){return!!a(t)&&(!!s(t)||(!!i(t)||(!!n(t)||"function"==typeof t[o])))}},{"es5-ext/function/is-arguments":180,"es5-ext/object/is-value":197,"es5-ext/string/is-string":212,"es6-symbol":222}],219:[function(t,e,r){"use strict";var n,a=t("es5-ext/object/set-prototype-of"),i=t("d"),o=t("es6-symbol"),s=t("./"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError("Constructor requires 'new'");t=String(t),s.call(this,t),l(this,"__length__",i("",t.length))},a&&a(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:i(function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()}),_resolve:i(function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r})}),l(n.prototype,o.toStringTag,i("c","String Iterator"))},{"./":217,d:153,"es5-ext/object/set-prototype-of":203,"es6-symbol":222}],220:[function(t,e,r){"use strict";var n=t("./is-iterable");e.exports=function(t){if(!n(t))throw new TypeError(t+" is not iterable");return t}},{"./is-iterable":218}],221:[function(t,e,r){(function(n,a){!function(t,n){"object"==typeof r&&"undefined"!=typeof e?e.exports=n():t.ES6Promise=n()}(this,function(){"use strict";function e(t){return"function"==typeof t}var r=Array.isArray?Array.isArray:function(t){return"[object Array]"===Object.prototype.toString.call(t)},i=0,o=void 0,s=void 0,l=function(t,e){g[i]=t,g[i+1]=e,2===(i+=2)&&(s?s(v):_())};var c="undefined"!=typeof window?window:void 0,u=c||{},h=u.MutationObserver||u.WebKitMutationObserver,f="undefined"==typeof self&&"undefined"!=typeof n&&"[object process]"==={}.toString.call(n),p="undefined"!=typeof Uint8ClampedArray&&"undefined"!=typeof importScripts&&"undefined"!=typeof MessageChannel;function d(){var t=setTimeout;return function(){return t(v,1)}}var g=new Array(1e3);function v(){for(var t=0;t<i;t+=2){(0,g[t])(g[t+1]),g[t]=void 0,g[t+1]=void 0}i=0}var m,y,x,b,_=void 0;function w(t,e){var r=arguments,n=this,a=new this.constructor(M);void 0===a[T]&&U(a);var i,o=n._state;return o?(i=r[o-1],l(function(){return j(o,a,i,n._result)})):R(n,a,t,e),a}function k(t){if(t&&"object"==typeof t&&t.constructor===this)return t;var e=new this(M);return O(e,t),e}f?_=function(){return n.nextTick(v)}:h?(y=0,x=new h(v),b=document.createTextNode(""),x.observe(b,{characterData:!0}),_=function(){b.data=y=++y%2}):p?((m=new MessageChannel).port1.onmessage=v,_=function(){return m.port2.postMessage(0)}):_=void 0===c&&"function"==typeof t?function(){try{var e=t("vertx");return o=e.runOnLoop||e.runOnContext,function(){o(v)}}catch(t){return d()}}():d();var T=Math.random().toString(36).substring(16);function M(){}var A=void 0,S=1,E=2,L=new B;function C(t){try{return t.then}catch(t){return L.error=t,L}}function P(t,r,n){r.constructor===t.constructor&&n===w&&r.constructor.resolve===k?function(t,e){e._state===S?I(t,e._result):e._state===E?D(t,e._result):R(e,void 0,function(e){return O(t,e)},function(e){return D(t,e)})}(t,r):n===L?D(t,L.error):void 0===n?I(t,r):e(n)?function(t,e,r){l(function(t){var n=!1,a=function(t,e,r,n){try{t.call(e,r,n)}catch(t){return t}}(r,e,function(r){n||(n=!0,e!==r?O(t,r):I(t,r))},function(e){n||(n=!0,D(t,e))},t._label);!n&&a&&(n=!0,D(t,a))},t)}(t,r,n):I(t,r)}function O(t,e){var r;t===e?D(t,new TypeError("You cannot resolve a promise with itself")):"function"==typeof(r=e)||"object"==typeof r&&null!==r?P(t,e,C(e)):I(t,e)}function z(t){t._onerror&&t._onerror(t._result),F(t)}function I(t,e){t._state===A&&(t._result=e,t._state=S,0!==t._subscribers.length&&l(F,t))}function D(t,e){t._state===A&&(t._state=E,t._result=e,l(z,t))}function R(t,e,r,n){var a=t._subscribers,i=a.length;t._onerror=null,a[i]=e,a[i+S]=r,a[i+E]=n,0===i&&t._state&&l(F,t)}function F(t){var e=t._subscribers,r=t._state;if(0!==e.length){for(var n=void 0,a=void 0,i=t._result,o=0;o<e.length;o+=3)n=e[o],a=e[o+r],n?j(r,n,a,i):a(i);t._subscribers.length=0}}function B(){this.error=null}var N=new B;function j(t,r,n,a){var i=e(n),o=void 0,s=void 0,l=void 0,c=void 0;if(i){if((o=function(t,e){try{return t(e)}catch(t){return N.error=t,N}}(n,a))===N?(c=!0,s=o.error,o=null):l=!0,r===o)return void D(r,new TypeError("A promises callback cannot return that same promise."))}else o=a,l=!0;r._state!==A||(i&&l?O(r,o):c?D(r,s):t===S?I(r,o):t===E&&D(r,o))}var V=0;function U(t){t[T]=V++,t._state=void 0,t._result=void 0,t._subscribers=[]}function q(t,e){this._instanceConstructor=t,this.promise=new t(M),this.promise[T]||U(this.promise),r(e)?(this._input=e,this.length=e.length,this._remaining=e.length,this._result=new Array(this.length),0===this.length?I(this.promise,this._result):(this.length=this.length||0,this._enumerate(),0===this._remaining&&I(this.promise,this._result))):D(this.promise,new Error("Array Methods must be provided an Array"))}function H(t){this[T]=V++,this._result=this._state=void 0,this._subscribers=[],M!==t&&("function"!=typeof t&&function(){throw new TypeError("You must pass a resolver function as the first argument to the promise constructor")}(),this instanceof H?function(t,e){try{e(function(e){O(t,e)},function(e){D(t,e)})}catch(e){D(t,e)}}(this,t):function(){throw new TypeError("Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.")}())}function G(){var t=void 0;if("undefined"!=typeof a)t=a;else if("undefined"!=typeof self)t=self;else try{t=Function("return this")()}catch(t){throw new Error("polyfill failed because global object is unavailable in this environment")}var e=t.Promise;if(e){var r=null;try{r=Object.prototype.toString.call(e.resolve())}catch(t){}if("[object Promise]"===r&&!e.cast)return}t.Promise=H}return q.prototype._enumerate=function(){for(var t=this.length,e=this._input,r=0;this._state===A&&r<t;r++)this._eachEntry(e[r],r)},q.prototype._eachEntry=function(t,e){var r=this._instanceConstructor,n=r.resolve;if(n===k){var a=C(t);if(a===w&&t._state!==A)this._settledAt(t._state,e,t._result);else if("function"!=typeof a)this._remaining--,this._result[e]=t;else if(r===H){var i=new r(M);P(i,t,a),this._willSettleAt(i,e)}else this._willSettleAt(new r(function(e){return e(t)}),e)}else this._willSettleAt(n(t),e)},q.prototype._settledAt=function(t,e,r){var n=this.promise;n._state===A&&(this._remaining--,t===E?D(n,r):this._result[e]=r),0===this._remaining&&I(n,this._result)},q.prototype._willSettleAt=function(t,e){var r=this;R(t,void 0,function(t){return r._settledAt(S,e,t)},function(t){return r._settledAt(E,e,t)})},H.all=function(t){return new q(this,t).promise},H.race=function(t){var e=this;return r(t)?new e(function(r,n){for(var a=t.length,i=0;i<a;i++)e.resolve(t[i]).then(r,n)}):new e(function(t,e){return e(new TypeError("You must pass an array to race."))})},H.resolve=k,H.reject=function(t){var e=new this(M);return D(e,t),e},H._setScheduler=function(t){s=t},H._setAsap=function(t){l=t},H._asap=l,H.prototype={constructor:H,then:w,catch:function(t){return this.then(null,t)}},G(),H.polyfill=G,H.Promise=H,H})}).call(this,t("_process"),"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{_process:483}],222:[function(t,e,r){"use strict";e.exports=t("./is-implemented")()?Symbol:t("./polyfill")},{"./is-implemented":223,"./polyfill":225}],223:[function(t,e,r){"use strict";var n={object:!0,symbol:!0};e.exports=function(){var t;if("function"!=typeof Symbol)return!1;t=Symbol("test symbol");try{String(t)}catch(t){return!1}return!!n[typeof Symbol.iterator]&&(!!n[typeof Symbol.toPrimitive]&&!!n[typeof Symbol.toStringTag])}},{}],224:[function(t,e,r){"use strict";e.exports=function(t){return!!t&&("symbol"==typeof t||!!t.constructor&&("Symbol"===t.constructor.name&&"Symbol"===t[t.constructor.toStringTag]))}},{}],225:[function(t,e,r){"use strict";var n,a,i,o,s=t("d"),l=t("./validate-symbol"),c=Object.create,u=Object.defineProperties,h=Object.defineProperty,f=Object.prototype,p=c(null);if("function"==typeof Symbol){n=Symbol;try{String(n()),o=!0}catch(t){}}var d,g=(d=c(null),function(t){for(var e,r,n=0;d[t+(n||"")];)++n;return d[t+=n||""]=!0,h(f,e="@@"+t,s.gs(null,function(t){r||(r=!0,h(this,e,s(t)),r=!1)})),e});i=function(t){if(this instanceof i)throw new TypeError("Symbol is not a constructor");return a(t)},e.exports=a=function t(e){var r;if(this instanceof t)throw new TypeError("Symbol is not a constructor");return o?n(e):(r=c(i.prototype),e=void 0===e?"":String(e),u(r,{__description__:s("",e),__name__:s("",g(e))}))},u(a,{for:s(function(t){return p[t]?p[t]:p[t]=a(String(t))}),keyFor:s(function(t){var e;for(e in l(t),p)if(p[e]===t)return e}),hasInstance:s("",n&&n.hasInstance||a("hasInstance")),isConcatSpreadable:s("",n&&n.isConcatSpreadable||a("isConcatSpreadable")),iterator:s("",n&&n.iterator||a("iterator")),match:s("",n&&n.match||a("match")),replace:s("",n&&n.replace||a("replace")),search:s("",n&&n.search||a("search")),species:s("",n&&n.species||a("species")),split:s("",n&&n.split||a("split")),toPrimitive:s("",n&&n.toPrimitive||a("toPrimitive")),toStringTag:s("",n&&n.toStringTag||a("toStringTag")),unscopables:s("",n&&n.unscopables||a("unscopables"))}),u(i.prototype,{constructor:s(a),toString:s("",function(){return this.__name__})}),u(a.prototype,{toString:s(function(){return"Symbol ("+l(this).__description__+")"}),valueOf:s(function(){return l(this)})}),h(a.prototype,a.toPrimitive,s("",function(){var t=l(this);return"symbol"==typeof t?t:t.toString()})),h(a.prototype,a.toStringTag,s("c","Symbol")),h(i.prototype,a.toStringTag,s("c",a.prototype[a.toStringTag])),h(i.prototype,a.toPrimitive,s("c",a.prototype[a.toPrimitive]))},{"./validate-symbol":226,d:153}],226:[function(t,e,r){"use strict";var n=t("./is-symbol");e.exports=function(t){if(!n(t))throw new TypeError(t+" is not a symbol");return t}},{"./is-symbol":224}],227:[function(t,e,r){"use strict";e.exports=function(t,e,r){var n=e||0,a=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[a*t[12]-t[8],a*t[13]-t[9],a*t[14]-t[10],a*t[15]-t[11]]]}},{}],228:[function(t,e,r){"use strict";var n=t("is-string-blank");e.exports=function(t){var e=typeof t;if("string"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if("number"!==e)return!1;return t-t<1}},{"is-string-blank":424}],229:[function(t,e,r){"use strict";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:if("number"==typeof t){var n=l(t);return new o(n,n,0)}return new o(t,l(t.length),0);case 2:if("number"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error("state and velocity lengths must match");return new o(t,e,r)}};var n=t("cubic-hermite"),a=t("binary-search-bounds");function i(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=a.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=a.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,h=this.bounds;if(o<0)for(var f=u-1,p=0;p<u;++p,--f)s[p]=l[f];else if(o>=r-1){f=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--f)s[p]=l[f]+d*c[f]}else{f=u*(o+1)-1;var g=e[o],v=e[o+1]-g||1,m=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--f)m[p]=l[f],x[p]=c[f]*v,y[p]=l[f+u],b[p]=c[f+u]*v,_=_&&m[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=m[p];else n(m,x,y,b,(t-g)/v,s)}var w=h[0],k=h[1];for(p=0;p<u;++p)s[p]=i(w[p],k[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,i=a.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(i>=r-1)for(var u=s.length-1,h=(e[r-1],0);h<c;++h,--u)o[h]=l[u];else{u=c*(i+1)-1;var f=e[i],p=e[i+1]-f||1,d=this._scratch[1],g=this._scratch[2],v=this._scratch[3],m=this._scratch[4],y=!0;for(h=0;h<c;++h,--u)d[h]=s[u],v[h]=l[u]*p,g[h]=s[u+c],m[h]=l[u+c]*p,y=y&&d[h]===g[h]&&v[h]===m[h]&&0===v[h];if(y)for(h=0;h<c;++h)o[h]=0;else{n.derivative(d,v,g,m,(t-f)/p,o);for(h=0;h<c;++h)o[h]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,a=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var h=0;h<r;++h)n.push(n[o++]),a.push(0);this._time.push(t);for(h=r;h>0;--h)n.push(i(l[h-1],c[h-1],arguments[h])),a.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,a=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],h=s>1e-6?1/s:0;this._time.push(t);for(var f=r;f>0;--f){var p=i(c[f-1],u[f-1],arguments[f]);n.push(p),a.push((p-n[o++])*h)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,a=this.bounds,o=a[0],s=a[1];this._time.push(t);for(var l=e;l>0;--l)r.push(i(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,a=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,h=u>1e-6?1/u:0;this._time.push(t);for(var f=r;f>0;--f){var p=arguments[f];n.push(i(l[f-1],c[f-1],n[o++]+p)),a.push(p*h)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,a=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var h=r-1;h>=0;--h)n.push(i(l[h],c[h],n[o]+u*a[o])),a.push(0),o+=1}}},{"binary-search-bounds":93,"cubic-hermite":147}],230:[function(t,e,r){var n=t("dtype");e.exports=function(t,e,r){if(!t)throw new TypeError("must specify data as first parameter");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&"number"==typeof t[0][0]){var a,i,o,s,l=t[0].length,c=t.length*l;e&&"string"!=typeof e||(e=new(n(e||"float32"))(c+r));var u=e.length-r;if(c!==u)throw new Error("source length "+c+" ("+l+"x"+t.length+") does not match destination length "+u);for(a=0,o=r;a<t.length;a++)for(i=0;i<l;i++)e[o++]=null===t[a][i]?NaN:t[a][i]}else if(e&&"string"!=typeof e)e.set(t,r);else{var h=n(e||"float32");if(Array.isArray(t)||"array"===e)for(e=new h(t.length+r),a=0,o=r,s=e.length;o<s;o++,a++)e[o]=null===t[a]?NaN:t[a];else 0===r?e=new h(t):(e=new h(t.length+r)).set(t,r)}return e}},{dtype:171}],231:[function(t,e,r){"use strict";var n=t("css-font/stringify"),a=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement("canvas"),i=t.font,o="number"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||a;i&&"string"!=typeof i&&(i=n(i));if(Array.isArray(s)){if(2===s.length&&"number"==typeof s[0]&&"number"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split("");e=e.slice(),r.width=e[0],r.height=e[1];var h=r.getContext("2d");h.fillStyle="#000",h.fillRect(0,0,r.width,r.height),h.font=i,h.textAlign="center",h.textBaseline="middle",h.fillStyle="#fff";for(var f=o[0]/2,p=o[1]/2,c=0;c<s.length;c++)h.fillText(s[c],f,p),(f+=o[0])>e[0]-o[0]/2&&(f=o[0]/2,p+=o[1]);return r}},{"css-font/stringify":144}],232:[function(t,e,r){"use strict";function n(t,e){e||(e={}),("string"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(", "):e.family;if(!r)throw Error("`family` must be defined");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||"",c=(t=[e.style||e.fontStyle||"",l,s].join(" ")+"px "+r,e.origin||"top");if(n.cache[r]&&s<=n.cache[r].em)return a(n.cache[r],c);var u=e.canvas||n.canvas,h=u.getContext("2d"),f={upper:void 0!==e.upper?e.upper:"H",lower:void 0!==e.lower?e.lower:"x",descent:void 0!==e.descent?e.descent:"p",ascent:void 0!==e.ascent?e.ascent:"h",tittle:void 0!==e.tittle?e.tittle:"i",overshoot:void 0!==e.overshoot?e.overshoot:"O"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,h.font=t;var d={top:0};h.clearRect(0,0,p,p),h.textBaseline="top",h.fillStyle="black",h.fillText("H",0,0);var g=i(h.getImageData(0,0,p,p));h.clearRect(0,0,p,p),h.textBaseline="bottom",h.fillText("H",0,p);var v=i(h.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-v+g,h.clearRect(0,0,p,p),h.textBaseline="alphabetic",h.fillText("H",0,p);var m=p-i(h.getImageData(0,0,p,p))-1+g;d.baseline=d.alphabetic=m,h.clearRect(0,0,p,p),h.textBaseline="middle",h.fillText("H",0,.5*p);var y=i(h.getImageData(0,0,p,p));d.median=d.middle=p-y-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline="hanging",h.fillText("H",0,.5*p);var x=i(h.getImageData(0,0,p,p));d.hanging=p-x-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline="ideographic",h.fillText("H",0,p);var b=i(h.getImageData(0,0,p,p));if(d.ideographic=p-b-1+g,f.upper&&(h.clearRect(0,0,p,p),h.textBaseline="top",h.fillText(f.upper,0,0),d.upper=i(h.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),f.lower&&(h.clearRect(0,0,p,p),h.textBaseline="top",h.fillText(f.lower,0,0),d.lower=i(h.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),f.tittle&&(h.clearRect(0,0,p,p),h.textBaseline="top",h.fillText(f.tittle,0,0),d.tittle=i(h.getImageData(0,0,p,p))),f.ascent&&(h.clearRect(0,0,p,p),h.textBaseline="top",h.fillText(f.ascent,0,0),d.ascent=i(h.getImageData(0,0,p,p))),f.descent&&(h.clearRect(0,0,p,p),h.textBaseline="top",h.fillText(f.descent,0,0),d.descent=o(h.getImageData(0,0,p,p))),f.overshoot){h.clearRect(0,0,p,p),h.textBaseline="top",h.fillText(f.overshoot,0,0);var _=o(h.getImageData(0,0,p,p));d.overshoot=_-m}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,a(d,c)}function a(t,e){var r={};for(var n in"string"==typeof e&&(e=t[e]),t)"em"!==n&&(r[n]=t[n]-e);return r}function i(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement("canvas"),n.cache={}},{}],233:[function(t,e,r){"use strict";e.exports=function(t){return new c(t||d,null)};var n=0,a=1;function i(t,e,r,n,a,i){this._color=t,this.key=e,this.value=r,this.left=n,this.right=a,this._count=i}function o(t){return new i(t._color,t.key,t.value,t.left,t.right,t._count)}function s(t,e){return new i(t,e.key,e.value,e.left,e.right,e._count)}function l(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function c(t,e){this._compare=t,this.root=e}var u=c.prototype;function h(t,e){this.tree=t,this._stack=e}Object.defineProperty(u,"keys",{get:function(){var t=[];return this.forEach(function(e,r){t.push(e)}),t}}),Object.defineProperty(u,"values",{get:function(){var t=[];return this.forEach(function(e,r){t.push(r)}),t}}),Object.defineProperty(u,"length",{get:function(){return this.root?this.root._count:0}}),u.insert=function(t,e){for(var r=this._compare,o=this.root,u=[],h=[];o;){var f=r(t,o.key);u.push(o),h.push(f),o=f<=0?o.left:o.right}u.push(new i(n,t,e,null,null,1));for(var p=u.length-2;p>=0;--p){o=u[p];h[p]<=0?u[p]=new i(o._color,o.key,o.value,u[p+1],o.right,o._count+1):u[p]=new i(o._color,o.key,o.value,o.left,u[p+1],o._count+1)}for(p=u.length-1;p>1;--p){var d=u[p-1];o=u[p];if(d._color===a||o._color===a)break;var g=u[p-2];if(g.left===d)if(d.left===o){if(!(v=g.right)||v._color!==n){if(g._color=n,g.left=d.right,d._color=a,d.right=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).left===g?m.left=d:m.right=d;break}d._color=a,g.right=s(a,v),g._color=n,p-=1}else{if(!(v=g.right)||v._color!==n){if(d.right=o.left,g._color=n,g.left=o.right,o._color=a,o.left=d,o.right=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).left===g?m.left=o:m.right=o;break}d._color=a,g.right=s(a,v),g._color=n,p-=1}else if(d.right===o){if(!(v=g.left)||v._color!==n){if(g._color=n,g.right=d.left,d._color=a,d.left=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).right===g?m.right=d:m.left=d;break}d._color=a,g.left=s(a,v),g._color=n,p-=1}else{var v;if(!(v=g.left)||v._color!==n){var m;if(d.left=o.right,g._color=n,g.right=o.left,o._color=a,o.right=d,o.left=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).right===g?m.right=o:m.left=o;break}d._color=a,g.left=s(a,v),g._color=n,p-=1}}return u[0]._color=a,new c(r,u[0])},u.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return function t(e,r){var n;if(r.left&&(n=t(e,r.left)))return n;return(n=e(r.key,r.value))||(r.right?t(e,r.right):void 0)}(t,this.root);case 2:return function t(e,r,n,a){if(r(e,a.key)<=0){var i;if(a.left&&(i=t(e,r,n,a.left)))return i;if(i=n(a.key,a.value))return i}if(a.right)return t(e,r,n,a.right)}(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return function t(e,r,n,a,i){var o,s=n(e,i.key),l=n(r,i.key);if(s<=0){if(i.left&&(o=t(e,r,n,a,i.left)))return o;if(l>0&&(o=a(i.key,i.value)))return o}if(l>0&&i.right)return t(e,r,n,a,i.right)}(e,r,this._compare,t,this.root)}},Object.defineProperty(u,"begin",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new h(this,t)}}),Object.defineProperty(u,"end",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new h(this,t)}}),u.at=function(t){if(t<0)return new h(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new h(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new h(this,[])},u.ge=function(t){for(var e=this._compare,r=this.root,n=[],a=0;r;){var i=e(t,r.key);n.push(r),i<=0&&(a=n.length),r=i<=0?r.left:r.right}return n.length=a,new h(this,n)},u.gt=function(t){for(var e=this._compare,r=this.root,n=[],a=0;r;){var i=e(t,r.key);n.push(r),i<0&&(a=n.length),r=i<0?r.left:r.right}return n.length=a,new h(this,n)},u.lt=function(t){for(var e=this._compare,r=this.root,n=[],a=0;r;){var i=e(t,r.key);n.push(r),i>0&&(a=n.length),r=i<=0?r.left:r.right}return n.length=a,new h(this,n)},u.le=function(t){for(var e=this._compare,r=this.root,n=[],a=0;r;){var i=e(t,r.key);n.push(r),i>=0&&(a=n.length),r=i<0?r.left:r.right}return n.length=a,new h(this,n)},u.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var a=e(t,r.key);if(n.push(r),0===a)return new h(this,n);r=a<=0?r.left:r.right}return new h(this,[])},u.remove=function(t){var e=this.find(t);return e?e.remove():this},u.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var f=h.prototype;function p(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function d(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(f,"valid",{get:function(){return this._stack.length>0}}),Object.defineProperty(f,"node",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),f.clone=function(){return new h(this.tree,this._stack.slice())},f.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new i(r._color,r.key,r.value,r.left,r.right,r._count);for(var u=t.length-2;u>=0;--u){(r=t[u]).left===t[u+1]?e[u]=new i(r._color,r.key,r.value,e[u+1],r.right,r._count):e[u]=new i(r._color,r.key,r.value,r.left,e[u+1],r._count)}if((r=e[e.length-1]).left&&r.right){var h=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var f=e[h-1];e.push(new i(r._color,f.key,f.value,r.left,r.right,r._count)),e[h-1].key=r.key,e[h-1].value=r.value;for(u=e.length-2;u>=h;--u)r=e[u],e[u]=new i(r._color,r.key,r.value,r.left,e[u+1],r._count);e[h-1].left=e[h]}if((r=e[e.length-1])._color===n){var d=e[e.length-2];d.left===r?d.left=null:d.right===r&&(d.right=null),e.pop();for(u=0;u<e.length;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(r.left||r.right){r.left?p(r,r.left):r.right&&p(r,r.right),r._color=a;for(u=0;u<e.length-1;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(1===e.length)return new c(this.tree._compare,null);for(u=0;u<e.length;++u)e[u]._count--;var g=e[e.length-2];return function(t){for(var e,r,i,c,u=t.length-1;u>=0;--u){if(e=t[u],0===u)return void(e._color=a);if((r=t[u-1]).left===e){if((i=r.right).right&&i.right._color===n)return c=(i=r.right=o(i)).right=o(i.right),r.right=i.left,i.left=r,i.right=c,i._color=r._color,e._color=a,r._color=a,c._color=a,l(r),l(i),u>1&&((h=t[u-2]).left===r?h.left=i:h.right=i),void(t[u-1]=i);if(i.left&&i.left._color===n)return c=(i=r.right=o(i)).left=o(i.left),r.right=c.left,i.left=c.right,c.left=r,c.right=i,c._color=r._color,r._color=a,i._color=a,e._color=a,l(r),l(i),l(c),u>1&&((h=t[u-2]).left===r?h.left=c:h.right=c),void(t[u-1]=c);if(i._color===a){if(r._color===n)return r._color=a,void(r.right=s(n,i));r.right=s(n,i);continue}i=o(i),r.right=i.left,i.left=r,i._color=r._color,r._color=n,l(r),l(i),u>1&&((h=t[u-2]).left===r?h.left=i:h.right=i),t[u-1]=i,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}else{if((i=r.left).left&&i.left._color===n)return c=(i=r.left=o(i)).left=o(i.left),r.left=i.right,i.right=r,i.left=c,i._color=r._color,e._color=a,r._color=a,c._color=a,l(r),l(i),u>1&&((h=t[u-2]).right===r?h.right=i:h.left=i),void(t[u-1]=i);if(i.right&&i.right._color===n)return c=(i=r.left=o(i)).right=o(i.right),r.left=c.right,i.right=c.left,c.right=r,c.left=i,c._color=r._color,r._color=a,i._color=a,e._color=a,l(r),l(i),l(c),u>1&&((h=t[u-2]).right===r?h.right=c:h.left=c),void(t[u-1]=c);if(i._color===a){if(r._color===n)return r._color=a,void(r.left=s(n,i));r.left=s(n,i);continue}var h;i=o(i),r.left=i.right,i.right=r,i._color=r._color,r._color=n,l(r),l(i),u>1&&((h=t[u-2]).right===r?h.right=i:h.left=i),t[u-1]=i,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}}}(e),g.left===r?g.left=null:g.right=null,new c(this.tree._compare,e[0])},Object.defineProperty(f,"key",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(f,"value",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(f,"index",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),f.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,"hasNext",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),f.update=function(t){var e=this._stack;if(0===e.length)throw new Error("Can't update empty node!");var r=new Array(e.length),n=e[e.length-1];r[r.length-1]=new i(n._color,n.key,t,n.left,n.right,n._count);for(var a=e.length-2;a>=0;--a)(n=e[a]).left===e[a+1]?r[a]=new i(n._color,n.key,n.value,r[a+1],n.right,n._count):r[a]=new i(n._color,n.key,n.value,n.left,r[a+1],n._count);return new c(this.tree._compare,r[0])},f.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,"hasPrev",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],234:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],a=607/128,i=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function o(t){if(t<0)return Number("0/0");for(var e=i[0],r=i.length-1;r>0;--r)e+=i[r]/(t+r);var n=t+a+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(o(e));e-=1;for(var r=n[0],a=1;a<9;a++)r+=n[a]/(e+a);var i=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(i,e+.5)*Math.exp(-i)*r},e.exports.log=o},{}],235:[function(t,e,r){e.exports=function(t,e){if("string"!=typeof t)throw new TypeError("must specify type string");if(e=e||{},"undefined"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement("canvas");"number"==typeof e.width&&(r.width=e.width);"number"==typeof e.height&&(r.height=e.height);var n,a=e;try{var i=[t];0===t.indexOf("webgl")&&i.push("experimental-"+t);for(var o=0;o<i.length;o++)if(n=r.getContext(i[o],a))return n}catch(t){n=null}return n||null}},{}],236:[function(t,e,r){"use strict";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t("./lib/text.js"),a=t("./lib/lines.js"),i=t("./lib/background.js"),o=t("./lib/cube.js"),s=t("./lib/ticks.js"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=["sans-serif","sans-serif","sans-serif"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=["auto","auto","auto"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=["x","y","z"],this.labelEnable=[!0,!0,!0],this.labelFont="sans-serif",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=["auto","auto","auto"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=i(t)}var h=u.prototype;function f(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}h.update=function(t){function e(e,r,n){if(n in t){var a,i=t[n],o=this[n];(e?Array.isArray(i)&&Array.isArray(i[0]):Array.isArray(i))?this[n]=a=[r(i[0]),r(i[1]),r(i[2])]:this[n]=a=[r(i),r(i),r(i)];for(var s=0;s<3;++s)if(a[s]!==o[s])return!0}return!1}t=t||{};var r,i=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]}),u=!1,h=!1;if("bounds"in t)for(var f=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)f[p][d]!==this.bounds[p][d]&&(h=!0),this.bounds[p][d]=f[p][d];if("ticks"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else i("tickSpacing")&&(this.autoTicks=!0,h=!0);if(this._firstInit&&("ticks"in t||"tickSpacing"in t||(this.autoTicks=!0),h=!0,u=!0,this._firstInit=!1),h&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort(function(t,e){return t.x-e.x});s.equal(r,this.ticks)?u=!1:this.ticks=r}o("tickEnable"),l("tickFont")&&(u=!0),i("tickSize"),i("tickAngle"),i("tickPad"),c("tickColor");var g=l("labels");l("labelFont")&&(g=!0),o("labelEnable"),i("labelSize"),i("labelPad"),c("labelColor"),o("lineEnable"),o("lineMirror"),i("lineWidth"),c("lineColor"),o("lineTickEnable"),o("lineTickMirror"),i("lineTickLength"),i("lineTickWidth"),c("lineTickColor"),o("gridEnable"),i("gridWidth"),c("gridColor"),o("zeroEnable"),c("zeroLineColor"),i("zeroLineWidth"),o("backgroundEnable"),c("backgroundColor"),this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=a(this.gl,this.bounds,this.ticks))};var p=[new f,new f,new f];function d(t,e,r,n,a){for(var i=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var h=i,f=s,p=o,d=l;c&1<<u&&(h=s,f=i,p=l,d=o),h[u]=r[0][u],f[u]=r[1][u],a[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var g=[0,0,0],v={model:l,view:l,projection:l,_ortho:!1};h.isOpaque=function(){return!0},h.isTransparent=function(){return!1},h.drawTransparent=function(t){};var m=[0,0,0],y=[0,0,0],x=[0,0,0];h.draw=function(t){t=t||v;for(var e=this.gl,r=t.model||l,n=t.view||l,a=t.projection||l,i=this.bounds,s=t._ortho||!1,u=o(r,n,a,i,s),h=u.cubeEdges,f=u.axis,b=n[12],_=n[13],w=n[14],k=n[15],T=(s?2:1)*this.pixelRatio*(a[3]*b+a[7]*_+a[11]*w+a[15]*k)/e.drawingBufferHeight,M=0;M<3;++M)this.lastCubeProps.cubeEdges[M]=h[M],this.lastCubeProps.axis[M]=f[M];var A=p;for(M=0;M<3;++M)d(p[M],M,this.bounds,h,f);e=this.gl;var S,E=g;for(M=0;M<3;++M)this.backgroundEnable[M]?E[M]=f[M]:E[M]=0;this._background.draw(r,n,a,i,E,this.backgroundColor),this._lines.bind(r,n,a,this);for(M=0;M<3;++M){var L=[0,0,0];f[M]>0?L[M]=i[1][M]:L[M]=i[0][M];for(var C=0;C<2;++C){var P=(M+1+C)%3,O=(M+1+(1^C))%3;this.gridEnable[P]&&this._lines.drawGrid(P,O,this.bounds,L,this.gridColor[P],this.gridWidth[P]*this.pixelRatio)}for(C=0;C<2;++C){P=(M+1+C)%3,O=(M+1+(1^C))%3;this.zeroEnable[O]&&Math.min(i[0][O],i[1][O])<=0&&Math.max(i[0][O],i[1][O])>=0&&this._lines.drawZero(P,O,this.bounds,L,this.zeroLineColor[O],this.zeroLineWidth[O]*this.pixelRatio)}}for(M=0;M<3;++M){this.lineEnable[M]&&this._lines.drawAxisLine(M,this.bounds,A[M].primalOffset,this.lineColor[M],this.lineWidth[M]*this.pixelRatio),this.lineMirror[M]&&this._lines.drawAxisLine(M,this.bounds,A[M].mirrorOffset,this.lineColor[M],this.lineWidth[M]*this.pixelRatio);var z=c(m,A[M].primalMinor),I=c(y,A[M].mirrorMinor),D=this.lineTickLength;for(C=0;C<3;++C){var R=T/r[5*C];z[C]*=D[C]*R,I[C]*=D[C]*R}this.lineTickEnable[M]&&this._lines.drawAxisTicks(M,A[M].primalOffset,z,this.lineTickColor[M],this.lineTickWidth[M]*this.pixelRatio),this.lineTickMirror[M]&&this._lines.drawAxisTicks(M,A[M].mirrorOffset,I,this.lineTickColor[M],this.lineTickWidth[M]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,a,this.pixelRatio);var F,B;function N(t){(B=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,a=(t+2)%3,i=e[n],o=e[a],s=r[n],l=r[a];i>0&&l>0?N(n):i>0&&l<0?N(n):i<0&&l>0?N(n):i<0&&l<0?N(n):o>0&&s>0?N(a):o>0&&s<0?N(a):o<0&&s>0?N(a):o<0&&s<0&&N(a)}for(M=0;M<3;++M){var V=A[M].primalMinor,U=A[M].mirrorMinor,q=c(x,A[M].primalOffset);for(C=0;C<3;++C)this.lineTickEnable[M]&&(q[C]+=T*V[C]*Math.max(this.lineTickLength[C],0)/r[5*C]);var H=[0,0,0];if(H[M]=1,this.tickEnable[M]){-3600===this.tickAngle[M]?(this.tickAngle[M]=0,this.tickAlign[M]="auto"):this.tickAlign[M]=-1,F=1,"auto"===(S=[this.tickAlign[M],.5,F])[0]?S[0]=0:S[0]=parseInt(""+S[0]),B=[0,0,0],j(M,V,U);for(C=0;C<3;++C)q[C]+=T*V[C]*this.tickPad[C]/r[5*C];this._text.drawTicks(M,this.tickSize[M],this.tickAngle[M],q,this.tickColor[M],H,B,S)}if(this.labelEnable[M]){F=0,B=[0,0,0],this.labels[M].length>4&&(N(M),F=1),"auto"===(S=[this.labelAlign[M],.5,F])[0]?S[0]=0:S[0]=parseInt(""+S[0]);for(C=0;C<3;++C)q[C]+=T*V[C]*this.labelPad[C]/r[5*C];q[M]+=.5*(i[0][M]+i[1][M]),this._text.drawLabel(M,this.labelSize[M],this.labelAngle[M],q,this.labelColor[M],[0,0,0],B,S)}}this._text.unbind()},h.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{"./lib/background.js":237,"./lib/cube.js":238,"./lib/lines.js":239,"./lib/text.js":241,"./lib/ticks.js":242}],237:[function(t,e,r){"use strict";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,h=[0,0,0],f=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),h[l]=p,f[l]=p;for(var d=-1;d<=1;d+=2){h[c]=d;for(var g=-1;g<=1;g+=2)h[u]=g,e.push(h[0],h[1],h[2],f[0],f[1],f[2]),s+=1}var v=c;c=u,u=v}var m=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=a(t,[{buffer:m,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:m,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=i(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,m,x,b)};var n=t("gl-buffer"),a=t("gl-vao"),i=t("./shaders").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,a,i){for(var o=!1,s=0;s<3;++s)o=o||a[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:a,colors:i},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{"./shaders":240,"gl-buffer":244,"gl-vao":329}],238:[function(t,e,r){"use strict";e.exports=function(t,e,r,i,p){a(s,e,t),a(s,r,s);for(var y=0,x=0;x<2;++x){u[2]=i[x][2];for(var b=0;b<2;++b){u[1]=i[b][1];for(var _=0;_<2;++_)u[0]=i[_][0],f(l[y],u,s),y+=1}}for(var w=-1,x=0;x<8;++x){for(var k=l[x][3],T=0;T<3;++T)c[x][T]=l[x][T]/k;p&&(c[x][2]*=-1),k<0&&(w<0?w=x:c[x][2]<c[w][2]&&(w=x))}if(w<0){w=0;for(var M=0;M<3;++M){for(var A=(M+2)%3,S=(M+1)%3,E=-1,L=-1,C=0;C<2;++C){var P=C<<M,O=P+(C<<A)+(1-C<<S),z=P+(1-C<<A)+(C<<S);o(c[P],c[O],c[z],h)<0||(C?E=1:L=1)}if(E<0||L<0)L>E&&(w|=1<<M);else{for(var C=0;C<2;++C){var P=C<<M,O=P+(C<<A)+(1-C<<S),z=P+(1-C<<A)+(C<<S),I=d([l[P],l[O],l[z],l[P+(1<<A)+(1<<S)]]);C?E=I:L=I}L>E&&(w|=1<<M)}}}for(var D=7^w,R=-1,x=0;x<8;++x)x!==w&&x!==D&&(R<0?R=x:c[R][1]>c[x][1]&&(R=x));for(var F=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D){F<0&&(F=B);var S=c[B];S[0]<c[F][0]&&(F=B)}}for(var N=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D&&B!==F){N<0&&(N=B);var S=c[B];S[0]>c[N][0]&&(N=B)}}var j=g;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^N)]=R&N;var V=7^N;V===w||V===D?(V=7^F,j[n.log2(N^V)]=V&N):j[n.log2(F^V)]=V&F;for(var U=v,q=w,M=0;M<3;++M)U[M]=q&1<<M?-1:1;return m};var n=t("bit-twiddle"),a=t("gl-mat4/multiply"),i=t("split-polygon"),o=t("robust-orientation"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),h=[0,0,0];function f(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var a=0;a<3;++a)t[n]+=e[a]*r[4*a+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=i.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],a=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-a,h=l[0]/l[3]-n,f=l[1]/l[3]-a;o+=Math.abs(c*f-u*h)}return o}var g=[1,1,1],v=[0,0,0],m={cubeEdges:g,axis:v}},{"bit-twiddle":94,"gl-mat4/multiply":270,"robust-orientation":508,"split-polygon":525}],239:[function(t,e,r){"use strict";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var h=0;h<3;++h){for(var f=o.length/3|0,d=0;d<r[h].length;++d){var g=+r[h][d].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;s[h]=f,l[h]=v-f;for(var f=o.length/3|0,m=0;m<r[h].length;++m){var g=+r[h][m].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;c[h]=f,u[h]=v-f}var y=n(t,new Float32Array(o)),x=a(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=i(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t("gl-buffer"),a=t("gl-vao"),i=t("./shaders").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function h(t){return t[0]=t[1]=t[2]=0,t}function f(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,a,i,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=a,this.tickOffset=i,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,a){var i=h(s);this.shader.uniforms.majorAxis=s,i[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=i;var o,u=f(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=n,(o=h(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=h(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,a){if(this.tickCount[t]){var i=h(o);i[t]=1,this.shader.uniforms.majorAxis=i,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=a;var s=h(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,a,i){if(this.gridCount[t]){var u=h(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=f(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=h(o);d[t]=1,this.shader.uniforms.majorAxis=d;var g=h(l);g[t]=1,this.shader.uniforms.screenAxis=g,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=a,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,a,i){var o=h(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=f(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=h(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=a,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{"./shaders":240,"gl-buffer":244,"gl-vao":329}],240:[function(t,e,r){"use strict";var n=t("glslify"),a=t("gl-shader"),i=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position;\n\nuniform mat4 model, view, projection;\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\nuniform float lineWidth;\nuniform vec2 screenShape;\n\nvec3 project(vec3 p) {\n  vec4 pp = projection * view * model * vec4(p, 1.0);\n  return pp.xyz / max(pp.w, 0.0001);\n}\n\nvoid main() {\n  vec3 major = position.x * majorAxis;\n  vec3 minor = position.y * minorAxis;\n\n  vec3 vPosition = major + minor + offset;\n  vec3 pPosition = project(vPosition);\n  vec3 offset = project(vPosition + screenAxis * position.z);\n\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\n\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\n}\n"]),o=n(["precision highp float;\n#define GLSLIFY 1\n\nuniform vec4 color;\nvoid main() {\n  gl_FragColor = color;\n}"]);r.line=function(t){return a(t,i,o,null,[{name:"position",type:"vec3"}])};var s=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position;\n\nuniform mat4 model, view, projection;\nuniform vec3 offset, axis, alignDir, alignOpt;\nuniform float scale, angle, pixelScale;\nuniform vec2 resolution;\n\nvec3 project(vec3 p) {\n  vec4 pp = projection * view * model * vec4(p, 1.0);\n  return pp.xyz / max(pp.w, 0.0001);\n}\n\nfloat computeViewAngle(vec3 a, vec3 b) {\n  vec3 A = project(a);\n  vec3 B = project(b);\n\n  return atan(\n    (B.y - A.y) * resolution.y,\n    (B.x - A.x) * resolution.x\n  );\n}\n\nconst float PI = 3.141592;\nconst float TWO_PI = 2.0 * PI;\nconst float HALF_PI = 0.5 * PI;\nconst float ONE_AND_HALF_PI = 1.5 * PI;\n\nint option = int(floor(alignOpt.x + 0.001));\nfloat hv_ratio =       alignOpt.y;\nbool enableAlign =    (alignOpt.z != 0.0);\n\nfloat mod_angle(float a) {\n  return mod(a, PI);\n}\n\nfloat positive_angle(float a) {\n  return mod_angle((a < 0.0) ?\n    a + TWO_PI :\n    a\n  );\n}\n\nfloat look_upwards(float a) {\n  float b = positive_angle(a);\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\n    b - PI :\n    b;\n}\n\nfloat look_horizontal_or_vertical(float a, float ratio) {\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\n  // if ratio is set to 0.5 then it is 50%, 50%.\n  // when using a higher ratio e.g. 0.75 the result would\n  // likely be more horizontal than vertical.\n\n  float b = positive_angle(a);\n\n  return\n    (b < (      ratio) * HALF_PI) ? 0.0 :\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\n                                    0.0;\n}\n\nfloat roundTo(float a, float b) {\n  return float(b * floor((a + 0.5 * b) / b));\n}\n\nfloat look_round_n_directions(float a, int n) {\n  float b = positive_angle(a);\n  float div = TWO_PI / float(n);\n  float c = roundTo(b, div);\n  return look_upwards(c);\n}\n\nfloat applyAlignOption(float rawAngle, float delta) {\n  return\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\n                    rawAngle;                // otherwise return back raw input angle\n}\n\nbool isAxisTitle = (axis.x == 0.0) &&\n                   (axis.y == 0.0) &&\n                   (axis.z == 0.0);\n\nvoid main() {\n  //Compute world offset\n  float axisDistance = position.z;\n  vec3 dataPosition = axisDistance * axis + offset;\n\n  float beta = angle; // i.e. user defined attributes for each tick\n\n  float axisAngle;\n  float clipAngle;\n  float flip;\n\n  if (enableAlign) {\n    axisAngle = (isAxisTitle) ? HALF_PI :\n                      computeViewAngle(dataPosition, dataPosition + axis);\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\n\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\n\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\n\n    beta += applyAlignOption(clipAngle, flip * PI);\n  }\n\n  //Compute plane offset\n  vec2 planeCoord = position.xy * pixelScale;\n\n  mat2 planeXform = scale * mat2(\n     cos(beta), sin(beta),\n    -sin(beta), cos(beta)\n  );\n\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\n\n  //Compute clip position\n  vec3 clipPosition = project(dataPosition);\n\n  //Apply text offset in clip coordinates\n  clipPosition += vec3(viewOffset, 0.0);\n\n  //Done\n  gl_Position = vec4(clipPosition, 1.0);\n}"]),l=n(["precision highp float;\n#define GLSLIFY 1\n\nuniform vec4 color;\nvoid main() {\n  gl_FragColor = color;\n}"]);r.text=function(t){return a(t,s,l,null,[{name:"position",type:"vec3"}])};var c=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position;\nattribute vec3 normal;\n\nuniform mat4 model, view, projection;\nuniform vec3 enable;\nuniform vec3 bounds[2];\n\nvarying vec3 colorChannel;\n\nvoid main() {\n\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\n\n  vec3 realNormal = signAxis * normal;\n\n  if(dot(realNormal, enable) > 0.0) {\n    vec3 minRange = min(bounds[0], bounds[1]);\n    vec3 maxRange = max(bounds[0], bounds[1]);\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\n  } else {\n    gl_Position = vec4(0,0,0,0);\n  }\n\n  colorChannel = abs(realNormal);\n}"]),u=n(["precision highp float;\n#define GLSLIFY 1\n\nuniform vec4 colors[3];\n\nvarying vec3 colorChannel;\n\nvoid main() {\n  gl_FragColor = colorChannel.x * colors[0] +\n                 colorChannel.y * colors[1] +\n                 colorChannel.z * colors[2];\n}"]);r.bg=function(t){return a(t,c,u,null,[{name:"position",type:"vec3"},{name:"normal",type:"vec3"}])}},{"gl-shader":304,glslify:410}],241:[function(t,e,r){(function(r){"use strict";e.exports=function(t,e,r,i,s,l){var u=n(t),h=a(t,[{buffer:u,size:3}]),f=o(t);f.attributes.position.location=0;var p=new c(t,f,u,h);return p.update(e,r,i,s,l),p};var n=t("gl-buffer"),a=t("gl-vao"),i=t("vectorize-text"),o=t("./shaders").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,h=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var a=this.shader.uniforms;a.model=t,a.view=e,a.projection=r,a.pixelScale=n,h[0]=this.gl.drawingBufferWidth,h[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=h},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,a){var o=[];function s(t,e,r,n,a,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return i(t,e)}catch(e){return console.warn('error vectorizing text:"'+t+'" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:"center",textBaseline:"middle",lineSpacing:a,styletags:s}));for(var h=(n||12)/12,f=u.positions,p=u.cells,d=0,g=p.length;d<g;++d)for(var v=p[d],m=2;m>=0;--m){var y=f[v[m]];o.push(h*y[0],-h*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],h=[0,0,0],f=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){h[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),f[d]=(o.length/3|0)-h[d],c[d]=o.length/3|0;for(var g=0;g<n[d].length;++g)n[d][g].text&&s(n[d][g].x,n[d][g].text,n[d][g].font||a,n[d][g].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=h,this.labelCount=f},u.drawTicks=function(t,e,r,n,a,i,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=i,this.shader.uniforms.color=a,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,a,i,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=i,this.shader.uniforms.color=a,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this,t("_process"))},{"./shaders":240,_process:483,"gl-buffer":244,"gl-vao":329,"vectorize-text":548}],242:[function(t,e,r){"use strict";function n(t,e){var r=t+"",n=r.indexOf("."),a=0;n>=0&&(a=r.length-n-1);var i=Math.pow(10,a),o=Math.round(t*e*i),s=o+"";if(s.indexOf("e")>=0)return s;var l=o/i,c=o%i;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=""+l;if(o<0&&(u="-"+u),a){for(var h=""+c;h.length<a;)h="0"+h;return u+"."+h}return u}r.create=function(t,e){for(var r=[],a=0;a<3;++a){for(var i=[],o=(t[0][a],t[1][a],0);o*e[a]<=t[1][a];++o)i.push({x:o*e[a],text:n(e[a],o)});for(var o=-1;o*e[a]>=t[0][a];--o)i.push({x:o*e[a],text:n(e[a],o)});r.push(i)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var a=t[r][n],i=e[r][n];if(a.x!==i.x||a.text!==i.text||a.font!==i.font||a.fontColor!==i.fontColor||a.fontSize!==i.fontSize||a.dx!==i.dx||a.dy!==i.dy)return!1}}return!0}},{}],243:[function(t,e,r){"use strict";e.exports=function(t,e,r,l,h){var f=e.model||c,p=e.view||c,m=e.projection||c,y=e._ortho||!1,x=t.bounds,b=(h=h||i(f,p,m,x,y)).axis;o(u,p,f),o(u,m,u);for(var _=g,w=0;w<3;++w)_[w].lo=1/0,_[w].hi=-1/0,_[w].pixelsPerDataUnit=1/0;var k=n(s(u,u));s(u,u);for(var T=0;T<3;++T){var M=(T+1)%3,A=(T+2)%3,S=v;t:for(var w=0;w<2;++w){var E=[];if(b[T]<0!=!!w){S[T]=x[w][T];for(var L=0;L<2;++L){S[M]=x[L^w][M];for(var C=0;C<2;++C)S[A]=x[C^L^w][A],E.push(S.slice())}for(var P=y?5:4,L=P;L===P;++L){if(0===E.length)continue t;E=a.positive(E,k[L])}for(var L=0;L<E.length;++L)for(var A=E[L],O=d(v,u,A,r,l),C=0;C<3;++C)_[C].lo=Math.min(_[C].lo,A[C]),_[C].hi=Math.max(_[C].hi,A[C]),C!==T&&(_[C].pixelsPerDataUnit=Math.min(_[C].pixelsPerDataUnit,Math.abs(O[C])))}}}return _};var n=t("extract-frustum-planes"),a=t("split-polygon"),i=t("./lib/cube.js"),o=t("gl-mat4/multiply"),s=t("gl-mat4/transpose"),l=t("gl-vec4/transformMat4"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function h(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var f=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,a){for(var i=0;i<3;++i){for(var o=f,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[i]+=1,l(s,s,e),s[3]<0&&(t[i]=1/0),o[i]-=1,l(o,o,e),o[3]<0&&(t[i]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,h=(o[1]/o[3]-s[1]/s[3])*a;t[i]=.25*Math.sqrt(u*u+h*h)}return t}var g=[new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0)],v=[0,0,0]},{"./lib/cube.js":238,"extract-frustum-planes":227,"gl-mat4/multiply":270,"gl-mat4/transpose":279,"gl-vec4/transformMat4":400,"split-polygon":525}],244:[function(t,e,r){"use strict";var n=t("typedarray-pool"),a=t("ndarray-ops"),i=t("ndarray"),o=["uint8","uint8_clamped","uint16","uint32","int8","int16","int32","float32"];function s(t,e,r,n,a){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=a}var l=s.prototype;function c(t,e,r,n,a,i){var o=a.length*a.BYTES_PER_ELEMENT;if(i<0)return t.bufferData(e,a,n),o;if(o+i>r)throw new Error("gl-buffer: If resizing buffer, must not specify offset");return t.bufferSubData(e,i,a),r}function u(t,e){for(var r=n.malloc(t.length,e),a=t.length,i=0;i<a;++i)r[i]=t[i];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if("number"!=typeof e&&(e=-1),this.bind(),"object"==typeof t&&"undefined"!=typeof t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r="float32"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension("OES_element_index_uint")&&"uint16"!==r?"uint32":"uint16";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=i(s,t.shape);a.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var h;h=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,"uint16"):u(t,"float32"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?h:h.subarray(0,t.length),e),n.free(h)}else if("object"==typeof t&&"number"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if("number"!=typeof t&&void 0!==t)throw new Error("gl-buffer: Invalid data type");if(e>=0)throw new Error("gl-buffer: Cannot specify offset when resizing buffer");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error("gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error("gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW");var a=t.createBuffer(),i=new s(t,r,a,0,n);return i.update(e),i}},{ndarray:451,"ndarray-ops":445,"typedarray-pool":543}],245:[function(t,e,r){"use strict";var n=t("gl-vec3");e.exports=function(t,e){var r=t.positions,a=t.vectors,i={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),i;for(var o=0,s=1/0,l=-1/0,c=1/0,u=-1/0,h=1/0,f=-1/0,p=null,d=null,g=[],v=1/0,m=!1,y=0;y<r.length;y++){var x=r[y];s=Math.min(x[0],s),l=Math.max(x[0],l),c=Math.min(x[1],c),u=Math.max(x[1],u),h=Math.min(x[2],h),f=Math.max(x[2],f);var b=a[y];if(n.length(b)>o&&(o=n.length(b)),y){var _=2*n.distance(p,x)/(n.length(d)+n.length(b));_?(v=Math.min(v,_),m=!1):m=!0}m||(p=x,d=b),g.push(b)}var w=[s,c,h],k=[l,u,f];e&&(e[0]=w,e[1]=k),0===o&&(o=1);var T=1/o;isFinite(v)||(v=1),i.vectorScale=v;var M=t.coneSize||.5;t.absoluteConeSize&&(M=t.absoluteConeSize*T),i.coneScale=M;y=0;for(var A=0;y<r.length;y++)for(var S=(x=r[y])[0],E=x[1],L=x[2],C=g[y],P=n.length(C)*T,O=0;O<8;O++){i.positions.push([S,E,L,A++]),i.positions.push([S,E,L,A++]),i.positions.push([S,E,L,A++]),i.positions.push([S,E,L,A++]),i.positions.push([S,E,L,A++]),i.positions.push([S,E,L,A++]),i.vectors.push(C),i.vectors.push(C),i.vectors.push(C),i.vectors.push(C),i.vectors.push(C),i.vectors.push(C),i.vertexIntensity.push(P,P,P),i.vertexIntensity.push(P,P,P);var z=i.positions.length;i.cells.push([z-6,z-5,z-4],[z-3,z-2,z-1])}return i};var a=t("./lib/shaders");e.exports.createMesh=t("./create_mesh"),e.exports.createConeMesh=function(t,r){return e.exports.createMesh(t,r,{shaders:a,traceType:"cone"})}},{"./create_mesh":246,"./lib/shaders":247,"gl-vec3":348}],246:[function(t,e,r){"use strict";var n=t("gl-shader"),a=t("gl-buffer"),i=t("gl-vao"),o=t("gl-texture2d"),s=t("gl-mat4/multiply"),l=t("gl-mat4/invert"),c=t("ndarray"),u=t("colormap"),h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function f(t,e,r,n,a,i,o,s,l,c,u){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=a,this.triangleVectors=i,this.triangleColors=s,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=c,this.triangleCount=0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.traceType=u,this.tubeScale=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=h,this._view=h,this._projection=h,this._resolution=[1,1]}var p=f.prototype;p.isOpaque=function(){return this.opacity>=1},p.isTransparent=function(){return this.opacity<1},p.pickSlots=1,p.setPickBase=function(t){this.pickId=t},p.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,"lightPosition"in t&&(this.lightPosition=t.lightPosition),"opacity"in t&&(this.opacity=t.opacity),"ambient"in t&&(this.ambientLight=t.ambient),"diffuse"in t&&(this.diffuseLight=t.diffuse),"specular"in t&&(this.specularLight=t.specular),"roughness"in t&&(this.roughness=t.roughness),"fresnel"in t&&(this.fresnel=t.fresnel),void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=u({colormap:t,nshades:256,format:"rgba"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var a=e[n],i=0;i<3;++i)r[4*n+i]=a[i];r[4*n+3]=255*a[3]}return c(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,a=t.vectors;if(n&&r&&a){var i=[],o=[],s=[],l=[],h=[];this.cells=r,this.positions=n,this.vectors=a;var f=t.meshColor||[1,1,1,1],p=t.vertexIntensity,d=1/0,g=-1/0;if(p)if(t.vertexIntensityBounds)d=+t.vertexIntensityBounds[0],g=+t.vertexIntensityBounds[1];else for(var v=0;v<p.length;++v){var m=p[v];d=Math.min(d,m),g=Math.max(g,m)}else for(v=0;v<n.length;++v){m=n[v][2];d=Math.min(d,m),g=Math.max(g,m)}this.intensity=p||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n),this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(v=0;v<n.length;++v)for(var y=n[v],x=0;x<3;++x)!isNaN(y[x])&&isFinite(y[x])&&(this.bounds[0][x]=Math.min(this.bounds[0][x],y[x]),this.bounds[1][x]=Math.max(this.bounds[1][x],y[x]));var b=0;t:for(v=0;v<r.length;++v){var _=r[v];switch(_.length){case 3:for(x=0;x<3;++x){y=n[k=_[x]];for(var w=0;w<3;++w)if(isNaN(y[w])||!isFinite(y[w]))continue t}for(x=0;x<3;++x){var k;y=n[k=_[2-x]];i.push(y[0],y[1],y[2],y[3]);var T=a[k];o.push(T[0],T[1],T[2],T[3]||0);var M,A=f;3===A.length?s.push(A[0],A[1],A[2],1):s.push(A[0],A[1],A[2],A[3]),M=p?[(p[k]-d)/(g-d),0]:[(y[2]-d)/(g-d),0],l.push(M[0],M[1]),h.push(v)}b+=1}}this.triangleCount=b,this.trianglePositions.update(i),this.triangleVectors.update(o),this.triangleColors.update(s),this.triangleUVs.update(l),this.triangleIds.update(new Uint32Array(h))}},p.drawTransparent=p.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||h,n=t.view||h,a=t.projection||h,i=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)i[0][o]=Math.max(i[0][o],this.clipBounds[0][o]),i[1][o]=Math.min(i[1][o],this.clipBounds[1][o]);var c={model:r,view:n,projection:a,inverseModel:h.slice(),clipBounds:i,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,texture:0};c.inverseModel=l(c.inverseModel,c.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);s(u,c.view,c.model),s(u,c.projection,u),l(u,u);for(o=0;o<3;++o)c.eyePosition[o]=u[12+o]/u[15];var f=u[15];for(o=0;o<3;++o)f+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];c.lightPosition[o]=p/f}if(this.triangleCount>0){var g=this.triShader;g.bind(),g.uniforms=c,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},p.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||h,n=t.view||h,a=t.projection||h,i=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)i[0][o]=Math.max(i[0][o],this.clipBounds[0][o]),i[1][o]=Math.min(i[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(a),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:a,clipBounds:i,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind())},p.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3),a={position:n,dataCoordinate:n,index:Math.floor(r[1]/48)};return"cone"===this.traceType?a.index=Math.floor(r[1]/48):"streamtube"===this.traceType&&(a.intensity=this.intensity[r[1]],a.velocity=this.vectors[r[1]].slice(0,3),a.divergence=this.vectors[r[1]][3],a.index=e),a},p.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleIds.dispose()},e.exports=function(t,e,r){var s=r.shaders;1===arguments.length&&(t=(e=t).gl);var l=function(t,e){var r=n(t,e.meshShader.vertex,e.meshShader.fragment,null,e.meshShader.attributes);return r.attributes.position.location=0,r.attributes.color.location=2,r.attributes.uv.location=3,r.attributes.vector.location=4,r}(t,s),u=function(t,e){var r=n(t,e.pickShader.vertex,e.pickShader.fragment,null,e.pickShader.attributes);return r.attributes.position.location=0,r.attributes.id.location=1,r.attributes.vector.location=4,r}(t,s),h=o(t,c(new Uint8Array([255,255,255,255]),[1,1,4]));h.generateMipmap(),h.minFilter=t.LINEAR_MIPMAP_LINEAR,h.magFilter=t.LINEAR;var p=a(t),d=a(t),g=a(t),v=a(t),m=a(t),y=new f(t,h,l,u,p,d,m,g,v,i(t,[{buffer:p,type:t.FLOAT,size:4},{buffer:m,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:v,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:4}]),r.traceType||"cone");return y.update(e),y}},{colormap:128,"gl-buffer":244,"gl-mat4/invert":268,"gl-mat4/multiply":270,"gl-shader":304,"gl-texture2d":324,"gl-vao":329,ndarray:451}],247:[function(t,e,r){var n=t("glslify"),a=n(["precision highp float;\n\nprecision highp float;\n#define GLSLIFY 1\n\nvec3 getOrthogonalVector(vec3 v) {\n  // Return up-vector for only-z vector.\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\n  // Assign z = 0, x = -b, y = a:\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\n    return normalize(vec3(-v.y, v.x, 0.0));\n  } else {\n    return normalize(vec3(0.0, v.z, -v.y));\n  }\n}\n\n// Calculate the cone vertex and normal at the given index.\n//\n// The returned vertex is for a cone with its top at origin and height of 1.0,\n// pointing in the direction of the vector attribute.\n//\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\n// These vertices are used to make up the triangles of the cone by the following:\n//   segment + 0 top vertex\n//   segment + 1 perimeter vertex a+1\n//   segment + 2 perimeter vertex a\n//   segment + 3 center base vertex\n//   segment + 4 perimeter vertex a\n//   segment + 5 perimeter vertex a+1\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\n// To go from index to segment, floor(index / 6)\n// To go from segment to angle, 2*pi * (segment/segmentCount)\n// To go from index to segment index, index - (segment*6)\n//\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\n\n  const float segmentCount = 8.0;\n\n  float index = rawIndex - floor(rawIndex /\n    (segmentCount * 6.0)) *\n    (segmentCount * 6.0);\n\n  float segment = floor(0.001 + index/6.0);\n  float segmentIndex = index - (segment*6.0);\n\n  normal = -normalize(d);\n\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\n    return mix(vec3(0.0), -d, coneOffset);\n  }\n\n  float nextAngle = (\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\n  ) ? 1.0 : 0.0;\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\n\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\n  vec3 v2 = v1 - d;\n\n  vec3 u = getOrthogonalVector(d);\n  vec3 v = normalize(cross(u, d));\n\n  vec3 x = u * cos(angle) * length(d)*0.25;\n  vec3 y = v * sin(angle) * length(d)*0.25;\n  vec3 v3 = v2 + x + y;\n  if (segmentIndex < 3.0) {\n    vec3 tx = u * sin(angle);\n    vec3 ty = v * -cos(angle);\n    vec3 tangent = tx + ty;\n    normal = normalize(cross(v3 - v1, tangent));\n  }\n\n  if (segmentIndex == 0.0) {\n    return mix(d, vec3(0.0), coneOffset);\n  }\n  return v3;\n}\n\nattribute vec3 vector;\nattribute vec4 color, position;\nattribute vec2 uv;\n\nuniform float vectorScale, coneScale, coneOffset;\nuniform mat4 model, view, projection, inverseModel;\nuniform vec3 eyePosition, lightPosition;\n\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\nvarying vec4 f_color;\nvarying vec2 f_uv;\n\nvoid main() {\n  // Scale the vector magnitude to stay constant with\n  // model & view changes.\n  vec3 normal;\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\n\n  //Lighting geometry parameters\n  vec4 cameraCoordinate = view * conePosition;\n  cameraCoordinate.xyz /= cameraCoordinate.w;\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\n\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\n  vec4 t_position  = view * conePosition;\n  gl_Position      = projection * t_position;\n\n  f_color          = color;\n  f_data           = conePosition.xyz;\n  f_position       = position.xyz;\n  f_uv             = uv;\n}\n"]),i=n(["#extension GL_OES_standard_derivatives : enable\n\nprecision highp float;\n#define GLSLIFY 1\n\nfloat beckmannDistribution(float x, float roughness) {\n  float NdotH = max(x, 0.0001);\n  float cos2Alpha = NdotH * NdotH;\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\n  float roughness2 = roughness * roughness;\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\n  return exp(tan2Alpha / roughness2) / denom;\n}\n\nfloat cookTorranceSpecular(\n  vec3 lightDirection,\n  vec3 viewDirection,\n  vec3 surfaceNormal,\n  float roughness,\n  float fresnel) {\n\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\n\n  //Half angle vector\n  vec3 H = normalize(lightDirection + viewDirection);\n\n  //Geometric term\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\n  float VdotH = max(dot(viewDirection, H), 0.000001);\n  float LdotH = max(dot(lightDirection, H), 0.000001);\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\n  float G = min(1.0, min(G1, G2));\n  \n  //Distribution term\n  float D = beckmannDistribution(NdotH, roughness);\n\n  //Fresnel term\n  float F = pow(1.0 - VdotN, fresnel);\n\n  //Multiply terms and done\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\n}\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3 clipBounds[2];\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\nuniform sampler2D texture;\n\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\nvarying vec4 f_color;\nvarying vec2 f_uv;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\n  vec3 N = normalize(f_normal);\n  vec3 L = normalize(f_lightDirection);\n  vec3 V = normalize(f_eyeDirection);\n\n  if(gl_FrontFacing) {\n    N = -N;\n  }\n\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\n\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\n\n  gl_FragColor = litColor * opacity;\n}\n"]),o=n(["precision highp float;\n\nprecision highp float;\n#define GLSLIFY 1\n\nvec3 getOrthogonalVector(vec3 v) {\n  // Return up-vector for only-z vector.\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\n  // Assign z = 0, x = -b, y = a:\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\n    return normalize(vec3(-v.y, v.x, 0.0));\n  } else {\n    return normalize(vec3(0.0, v.z, -v.y));\n  }\n}\n\n// Calculate the cone vertex and normal at the given index.\n//\n// The returned vertex is for a cone with its top at origin and height of 1.0,\n// pointing in the direction of the vector attribute.\n//\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\n// These vertices are used to make up the triangles of the cone by the following:\n//   segment + 0 top vertex\n//   segment + 1 perimeter vertex a+1\n//   segment + 2 perimeter vertex a\n//   segment + 3 center base vertex\n//   segment + 4 perimeter vertex a\n//   segment + 5 perimeter vertex a+1\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\n// To go from index to segment, floor(index / 6)\n// To go from segment to angle, 2*pi * (segment/segmentCount)\n// To go from index to segment index, index - (segment*6)\n//\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\n\n  const float segmentCount = 8.0;\n\n  float index = rawIndex - floor(rawIndex /\n    (segmentCount * 6.0)) *\n    (segmentCount * 6.0);\n\n  float segment = floor(0.001 + index/6.0);\n  float segmentIndex = index - (segment*6.0);\n\n  normal = -normalize(d);\n\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\n    return mix(vec3(0.0), -d, coneOffset);\n  }\n\n  float nextAngle = (\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\n  ) ? 1.0 : 0.0;\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\n\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\n  vec3 v2 = v1 - d;\n\n  vec3 u = getOrthogonalVector(d);\n  vec3 v = normalize(cross(u, d));\n\n  vec3 x = u * cos(angle) * length(d)*0.25;\n  vec3 y = v * sin(angle) * length(d)*0.25;\n  vec3 v3 = v2 + x + y;\n  if (segmentIndex < 3.0) {\n    vec3 tx = u * sin(angle);\n    vec3 ty = v * -cos(angle);\n    vec3 tangent = tx + ty;\n    normal = normalize(cross(v3 - v1, tangent));\n  }\n\n  if (segmentIndex == 0.0) {\n    return mix(d, vec3(0.0), coneOffset);\n  }\n  return v3;\n}\n\nattribute vec4 vector;\nattribute vec4 position;\nattribute vec4 id;\n\nuniform mat4 model, view, projection;\nuniform float vectorScale, coneScale, coneOffset;\n\nvarying vec3 f_position;\nvarying vec4 f_id;\n\nvoid main() {\n  vec3 normal;\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector.xyz), position.w, coneOffset, normal);\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\n  gl_Position = projection * view * conePosition;\n  f_id        = id;\n  f_position  = position.xyz;\n}\n"]),s=n(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3  clipBounds[2];\nuniform float pickId;\n\nvarying vec3 f_position;\nvarying vec4 f_id;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\n\n  gl_FragColor = vec4(pickId, f_id.xyz);\n}"]);r.meshShader={vertex:a,fragment:i,attributes:[{name:"position",type:"vec4"},{name:"color",type:"vec4"},{name:"uv",type:"vec2"},{name:"vector",type:"vec3"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:"position",type:"vec4"},{name:"id",type:"vec4"},{name:"vector",type:"vec3"}]}},{glslify:410}],248:[function(t,e,r){e.exports={0:"NONE",1:"ONE",2:"LINE_LOOP",3:"LINE_STRIP",4:"TRIANGLES",5:"TRIANGLE_STRIP",6:"TRIANGLE_FAN",256:"DEPTH_BUFFER_BIT",512:"NEVER",513:"LESS",514:"EQUAL",515:"LEQUAL",516:"GREATER",517:"NOTEQUAL",518:"GEQUAL",519:"ALWAYS",768:"SRC_COLOR",769:"ONE_MINUS_SRC_COLOR",770:"SRC_ALPHA",771:"ONE_MINUS_SRC_ALPHA",772:"DST_ALPHA",773:"ONE_MINUS_DST_ALPHA",774:"DST_COLOR",775:"ONE_MINUS_DST_COLOR",776:"SRC_ALPHA_SATURATE",1024:"STENCIL_BUFFER_BIT",1028:"FRONT",1029:"BACK",1032:"FRONT_AND_BACK",1280:"INVALID_ENUM",1281:"INVALID_VALUE",1282:"INVALID_OPERATION",1285:"OUT_OF_MEMORY",1286:"INVALID_FRAMEBUFFER_OPERATION",2304:"CW",2305:"CCW",2849:"LINE_WIDTH",2884:"CULL_FACE",2885:"CULL_FACE_MODE",2886:"FRONT_FACE",2928:"DEPTH_RANGE",2929:"DEPTH_TEST",2930:"DEPTH_WRITEMASK",2931:"DEPTH_CLEAR_VALUE",2932:"DEPTH_FUNC",2960:"STENCIL_TEST",2961:"STENCIL_CLEAR_VALUE",2962:"STENCIL_FUNC",2963:"STENCIL_VALUE_MASK",2964:"STENCIL_FAIL",2965:"STENCIL_PASS_DEPTH_FAIL",2966:"STENCIL_PASS_DEPTH_PASS",2967:"STENCIL_REF",2968:"STENCIL_WRITEMASK",2978:"VIEWPORT",3024:"DITHER",3042:"BLEND",3088:"SCISSOR_BOX",3089:"SCISSOR_TEST",3106:"COLOR_CLEAR_VALUE",3107:"COLOR_WRITEMASK",3317:"UNPACK_ALIGNMENT",3333:"PACK_ALIGNMENT",3379:"MAX_TEXTURE_SIZE",3386:"MAX_VIEWPORT_DIMS",3408:"SUBPIXEL_BITS",3410:"RED_BITS",3411:"GREEN_BITS",3412:"BLUE_BITS",3413:"ALPHA_BITS",3414:"DEPTH_BITS",3415:"STENCIL_BITS",3553:"TEXTURE_2D",4352:"DONT_CARE",4353:"FASTEST",4354:"NICEST",5120:"BYTE",5121:"UNSIGNED_BYTE",5122:"SHORT",5123:"UNSIGNED_SHORT",5124:"INT",5125:"UNSIGNED_INT",5126:"FLOAT",5386:"INVERT",5890:"TEXTURE",6401:"STENCIL_INDEX",6402:"DEPTH_COMPONENT",6406:"ALPHA",6407:"RGB",6408:"RGBA",6409:"LUMINANCE",6410:"LUMINANCE_ALPHA",7680:"KEEP",7681:"REPLACE",7682:"INCR",7683:"DECR",7936:"VENDOR",7937:"RENDERER",7938:"VERSION",9728:"NEAREST",9729:"LINEAR",9984:"NEAREST_MIPMAP_NEAREST",9985:"LINEAR_MIPMAP_NEAREST",9986:"NEAREST_MIPMAP_LINEAR",9987:"LINEAR_MIPMAP_LINEAR",10240:"TEXTURE_MAG_FILTER",10241:"TEXTURE_MIN_FILTER",10242:"TEXTURE_WRAP_S",10243:"TEXTURE_WRAP_T",10497:"REPEAT",10752:"POLYGON_OFFSET_UNITS",16384:"COLOR_BUFFER_BIT",32769:"CONSTANT_COLOR",32770:"ONE_MINUS_CONSTANT_COLOR",32771:"CONSTANT_ALPHA",32772:"ONE_MINUS_CONSTANT_ALPHA",32773:"BLEND_COLOR",32774:"FUNC_ADD",32777:"BLEND_EQUATION_RGB",32778:"FUNC_SUBTRACT",32779:"FUNC_REVERSE_SUBTRACT",32819:"UNSIGNED_SHORT_4_4_4_4",32820:"UNSIGNED_SHORT_5_5_5_1",32823:"POLYGON_OFFSET_FILL",32824:"POLYGON_OFFSET_FACTOR",32854:"RGBA4",32855:"RGB5_A1",32873:"TEXTURE_BINDING_2D",32926:"SAMPLE_ALPHA_TO_COVERAGE",32928:"SAMPLE_COVERAGE",32936:"SAMPLE_BUFFERS",32937:"SAMPLES",32938:"SAMPLE_COVERAGE_VALUE",32939:"SAMPLE_COVERAGE_INVERT",32968:"BLEND_DST_RGB",32969:"BLEND_SRC_RGB",32970:"BLEND_DST_ALPHA",32971:"BLEND_SRC_ALPHA",33071:"CLAMP_TO_EDGE",33170:"GENERATE_MIPMAP_HINT",33189:"DEPTH_COMPONENT16",33306:"DEPTH_STENCIL_ATTACHMENT",33635:"UNSIGNED_SHORT_5_6_5",33648:"MIRRORED_REPEAT",33901:"ALIASED_POINT_SIZE_RANGE",33902:"ALIASED_LINE_WIDTH_RANGE",33984:"TEXTURE0",33985:"TEXTURE1",33986:"TEXTURE2",33987:"TEXTURE3",33988:"TEXTURE4",33989:"TEXTURE5",33990:"TEXTURE6",33991:"TEXTURE7",33992:"TEXTURE8",33993:"TEXTURE9",33994:"TEXTURE10",33995:"TEXTURE11",33996:"TEXTURE12",33997:"TEXTURE13",33998:"TEXTURE14",33999:"TEXTURE15",34000:"TEXTURE16",34001:"TEXTURE17",34002:"TEXTURE18",34003:"TEXTURE19",34004:"TEXTURE20",34005:"TEXTURE21",34006:"TEXTURE22",34007:"TEXTURE23",34008:"TEXTURE24",34009:"TEXTURE25",34010:"TEXTURE26",34011:"TEXTURE27",34012:"TEXTURE28",34013:"TEXTURE29",34014:"TEXTURE30",34015:"TEXTURE31",34016:"ACTIVE_TEXTURE",34024:"MAX_RENDERBUFFER_SIZE",34041:"DEPTH_STENCIL",34055:"INCR_WRAP",34056:"DECR_WRAP",34067:"TEXTURE_CUBE_MAP",34068:"TEXTURE_BINDING_CUBE_MAP",34069:"TEXTURE_CUBE_MAP_POSITIVE_X",34070:"TEXTURE_CUBE_MAP_NEGATIVE_X",34071:"TEXTURE_CUBE_MAP_POSITIVE_Y",34072:"TEXTURE_CUBE_MAP_NEGATIVE_Y",34073:"TEXTURE_CUBE_MAP_POSITIVE_Z",34074:"TEXTURE_CUBE_MAP_NEGATIVE_Z",34076:"MAX_CUBE_MAP_TEXTURE_SIZE",34338:"VERTEX_ATTRIB_ARRAY_ENABLED",34339:"VERTEX_ATTRIB_ARRAY_SIZE",34340:"VERTEX_ATTRIB_ARRAY_STRIDE",34341:"VERTEX_ATTRIB_ARRAY_TYPE",34342:"CURRENT_VERTEX_ATTRIB",34373:"VERTEX_ATTRIB_ARRAY_POINTER",34466:"NUM_COMPRESSED_TEXTURE_FORMATS",34467:"COMPRESSED_TEXTURE_FORMATS",34660:"BUFFER_SIZE",34661:"BUFFER_USAGE",34816:"STENCIL_BACK_FUNC",34817:"STENCIL_BACK_FAIL",34818:"STENCIL_BACK_PASS_DEPTH_FAIL",34819:"STENCIL_BACK_PASS_DEPTH_PASS",34877:"BLEND_EQUATION_ALPHA",34921:"MAX_VERTEX_ATTRIBS",34922:"VERTEX_ATTRIB_ARRAY_NORMALIZED",34930:"MAX_TEXTURE_IMAGE_UNITS",34962:"ARRAY_BUFFER",34963:"ELEMENT_ARRAY_BUFFER",34964:"ARRAY_BUFFER_BINDING",34965:"ELEMENT_ARRAY_BUFFER_BINDING",34975:"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING",35040:"STREAM_DRAW",35044:"STATIC_DRAW",35048:"DYNAMIC_DRAW",35632:"FRAGMENT_SHADER",35633:"VERTEX_SHADER",35660:"MAX_VERTEX_TEXTURE_IMAGE_UNITS",35661:"MAX_COMBINED_TEXTURE_IMAGE_UNITS",35663:"SHADER_TYPE",35664:"FLOAT_VEC2",35665:"FLOAT_VEC3",35666:"FLOAT_VEC4",35667:"INT_VEC2",35668:"INT_VEC3",35669:"INT_VEC4",35670:"BOOL",35671:"BOOL_VEC2",35672:"BOOL_VEC3",35673:"BOOL_VEC4",35674:"FLOAT_MAT2",35675:"FLOAT_MAT3",35676:"FLOAT_MAT4",35678:"SAMPLER_2D",35680:"SAMPLER_CUBE",35712:"DELETE_STATUS",35713:"COMPILE_STATUS",35714:"LINK_STATUS",35715:"VALIDATE_STATUS",35716:"INFO_LOG_LENGTH",35717:"ATTACHED_SHADERS",35718:"ACTIVE_UNIFORMS",35719:"ACTIVE_UNIFORM_MAX_LENGTH",35720:"SHADER_SOURCE_LENGTH",35721:"ACTIVE_ATTRIBUTES",35722:"ACTIVE_ATTRIBUTE_MAX_LENGTH",35724:"SHADING_LANGUAGE_VERSION",35725:"CURRENT_PROGRAM",36003:"STENCIL_BACK_REF",36004:"STENCIL_BACK_VALUE_MASK",36005:"STENCIL_BACK_WRITEMASK",36006:"FRAMEBUFFER_BINDING",36007:"RENDERBUFFER_BINDING",36048:"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE",36049:"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME",36050:"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL",36051:"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE",36053:"FRAMEBUFFER_COMPLETE",36054:"FRAMEBUFFER_INCOMPLETE_ATTACHMENT",36055:"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT",36057:"FRAMEBUFFER_INCOMPLETE_DIMENSIONS",36061:"FRAMEBUFFER_UNSUPPORTED",36064:"COLOR_ATTACHMENT0",36096:"DEPTH_ATTACHMENT",36128:"STENCIL_ATTACHMENT",36160:"FRAMEBUFFER",36161:"RENDERBUFFER",36162:"RENDERBUFFER_WIDTH",36163:"RENDERBUFFER_HEIGHT",36164:"RENDERBUFFER_INTERNAL_FORMAT",36168:"STENCIL_INDEX8",36176:"RENDERBUFFER_RED_SIZE",36177:"RENDERBUFFER_GREEN_SIZE",36178:"RENDERBUFFER_BLUE_SIZE",36179:"RENDERBUFFER_ALPHA_SIZE",36180:"RENDERBUFFER_DEPTH_SIZE",36181:"RENDERBUFFER_STENCIL_SIZE",36194:"RGB565",36336:"LOW_FLOAT",36337:"MEDIUM_FLOAT",36338:"HIGH_FLOAT",36339:"LOW_INT",36340:"MEDIUM_INT",36341:"HIGH_INT",36346:"SHADER_COMPILER",36347:"MAX_VERTEX_UNIFORM_VECTORS",36348:"MAX_VARYING_VECTORS",36349:"MAX_FRAGMENT_UNIFORM_VECTORS",37440:"UNPACK_FLIP_Y_WEBGL",37441:"UNPACK_PREMULTIPLY_ALPHA_WEBGL",37442:"CONTEXT_LOST_WEBGL",37443:"UNPACK_COLORSPACE_CONVERSION_WEBGL",37444:"BROWSER_DEFAULT_WEBGL"}},{}],249:[function(t,e,r){var n=t("./1.0/numbers");e.exports=function(t){return n[t]}},{"./1.0/numbers":248}],250:[function(t,e,r){"use strict";e.exports=function(t){var e=t.gl,r=n(e),o=a(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=i(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t("gl-buffer"),a=t("gl-vao"),i=t("./shaders/index"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,a=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var i=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho||!1?2:1)*this.pixelRatio*(a[3]*i+a[7]*s+a[11]*l+a[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var h=0;h<3;++h)e.lineWidth(this.lineWidth[h]*this.pixelRatio),r.capSize=this.capSize[h]*u,this.lineCount[h]&&e.drawArrays(e.LINES,this.lineOffset[h],this.lineCount[h]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var a=-1;a<=1;a+=2){var i=[0,0,0];i[(n+e)%3]=a,r.push(i)}t[e]=r}return t}();function h(t,e,r,n){for(var a=u[n],i=0;i<a.length;++i){var o=a[i];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return a.length}l.update=function(t){"lineWidth"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),"capSize"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,"opacity"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var a=[],i=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<i;++l){for(var u=r[l],f=0;f<3;++f)if(isNaN(u[f])||!isFinite(u[f]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length?d=[d[0],d[1],d[2],1]:4===d.length&&(d=[d[0],d[1],d[2],d[3]],!this.hasAlpha&&d[3]<1&&(this.hasAlpha=!0)),!isNaN(p[0][s])&&!isNaN(p[1][s])){var g;if(p[0][s]<0)(g=u.slice())[s]+=p[0][s],a.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(a,g,d,s);if(p[1][s]>0)(g=u.slice())[s]+=p[1][s],a.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(a,g,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(a)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{"./shaders/index":251,"gl-buffer":244,"gl-vao":329}],251:[function(t,e,r){"use strict";var n=t("glslify"),a=t("gl-shader"),i=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position, offset;\nattribute vec4 color;\nuniform mat4 model, view, projection;\nuniform float capSize;\nvarying vec4 fragColor;\nvarying vec3 fragPosition;\n\nvoid main() {\n  vec4 worldPosition  = model * vec4(position, 1.0);\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\n  gl_Position         = projection * view * worldPosition;\n  fragColor           = color;\n  fragPosition        = position;\n}"]),o=n(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3 clipBounds[2];\nuniform float opacity;\nvarying vec3 fragPosition;\nvarying vec4 fragColor;\n\nvoid main() {\n  if (\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\n    fragColor.a * opacity == 0.\n  ) discard;\n\n  gl_FragColor = opacity * fragColor;\n}"]);e.exports=function(t){return a(t,i,o,null,[{name:"position",type:"vec3"},{name:"color",type:"vec4"},{name:"offset",type:"vec3"}])}},{"gl-shader":304,glslify:410}],252:[function(t,e,r){"use strict";var n=t("gl-texture2d");e.exports=function(t,e,r,n){a||(a=t.FRAMEBUFFER_UNSUPPORTED,i=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension("WEBGL_draw_buffers");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var a=new Array(r),i=0;i<n;++i)a[i]=t.COLOR_ATTACHMENT0+i;for(var i=n;i<r;++i)a[i]=t.NONE;l[n]=a}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if("number"!=typeof e)throw new Error("gl-fbo: Missing shape parameter");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error("gl-fbo: Parameters are too large for FBO");var h=1;if("color"in(n=n||{})){if((h=Math.max(0|n.color,0))<0)throw new Error("gl-fbo: Must specify a nonnegative number of colors");if(h>1){if(!c)throw new Error("gl-fbo: Multiple draw buffer extension not supported");if(h>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error("gl-fbo: Context does not support "+h+" draw buffers")}}var f=t.UNSIGNED_BYTE,p=t.getExtension("OES_texture_float");if(n.float&&h>0){if(!p)throw new Error("gl-fbo: Context does not support floating point textures");f=t.FLOAT}else n.preferFloat&&h>0&&p&&(f=t.FLOAT);var g=!0;"depth"in n&&(g=!!n.depth);var v=!1;"stencil"in n&&(v=!!n.stencil);return new d(t,e,r,f,h,g,v,c)};var a,i,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function h(t){switch(t){case a:throw new Error("gl-fbo: Framebuffer unsupported");case i:throw new Error("gl-fbo: Framebuffer incomplete attachment");case o:throw new Error("gl-fbo: Framebuffer incomplete dimensions");case s:throw new Error("gl-fbo: Framebuffer incomplete missing attachment");default:throw new Error("gl-fbo: Framebuffer failed for unspecified reason")}}function f(t,e,r,a,i,o){if(!a)return null;var s=n(t,e,r,i,a);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,a){var i=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,i),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,a,t.RENDERBUFFER,i),i}function d(t,e,r,n,a,i,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(a);for(var d=0;d<a;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=i,this._useStencil=o;var g=this,v=[0|e,0|r];Object.defineProperties(v,{0:{get:function(){return g._shape[0]},set:function(t){return g.width=t}},1:{get:function(){return g._shape[1]},set:function(t){return g.height=t}}}),this._shapeVector=v,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),a=t._shape[0],i=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,g=t._useDepth,v=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var m=0;m<o;++m)t.color[m]=f(r,a,i,v,r.RGBA,r.COLOR_ATTACHMENT0+m);0===o?(t._color_rb=p(r,a,i,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension("WEBGL_depth_texture");y?d?t.depth=f(r,a,i,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g&&(t.depth=f(r,a,i,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):g&&d?t._depth_rb=p(r,a,i,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g?t._depth_rb=p(r,a,i,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,a,i,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){for(t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null),m=0;m<t.color.length;++m)t.color[m].dispose(),t.color[m]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),h(x)}u(r,e)}(this)}var g=d.prototype;function v(t,e,r){if(t._destroyed)throw new Error("gl-fbo: Can't resize destroyed FBO");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,a=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>a||r<0||r>a)throw new Error("gl-fbo: Can't resize FBO, invalid dimensions");t._shape[0]=e,t._shape[1]=r;for(var i=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,i),h(s)),u(n,i)}}Object.defineProperties(g,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error("gl-fbo: Shape vector must be length 2");var e=0|t[0],r=0|t[1];return v(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return v(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,v(this,this._shape[0],t),t},enumerable:!1}}),g.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},g.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{"gl-texture2d":324}],253:[function(t,e,r){var n=t("sprintf-js").sprintf,a=t("gl-constants/lookup"),i=t("glsl-shader-name"),o=t("add-line-numbers");e.exports=function(t,e,r){"use strict";var s=i(e)||"of unknown name (see npm glsl-shader-name)",l="unknown type";void 0!==r&&(l=r===a.FRAGMENT_SHADER?"fragment":"vertex");for(var c=n("Error compiling %s shader %s:\n",l,s),u=n("%s%s",c,t),h=t.split("\n"),f={},p=0;p<h.length;p++){var d=h[p];if(""!==d&&"\0"!==d){var g=parseInt(d.split(":")[2]);if(isNaN(g))throw new Error(n("Could not parse error: %s",d));f[g]=d}}for(var v=o(e).split("\n"),p=0;p<v.length;p++)if(f[p+3]||f[p+2]||f[p+1]){var m=v[p];if(c+=m+"\n",f[p+1]){var y=f[p+1];y=y.substr(y.split(":",3).join(":").length+1).trim(),c+=n("^^^ %s\n\n",y)}}return{long:c.trim(),short:u.trim()}}},{"add-line-numbers":64,"gl-constants/lookup":249,"glsl-shader-name":402,"sprintf-js":526}],254:[function(t,e,r){"use strict";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),a=o(r,l.pickVertex,l.pickFragment),i=s(r),u=s(r),h=s(r),f=s(r),p=new c(t,n,a,i,u,h,f);return p.update(e),t.addObject(p),p};var n=t("binary-search-bounds"),a=t("iota-array"),i=t("typedarray-pool"),o=t("gl-shader"),s=t("gl-buffer"),l=t("./lib/shaders");function c(t,e,r,n,a,i,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=a,this.colorBuffer=i,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,h=c.prototype,f=[0,0,1,0,0,1,1,0,1,1,0,1];h.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var a=t.gl,i=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=i[2]-i[0],c=i[3]-i[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-i[0])/l-1,u[7]=2*(r[1]-i[1])/c-1,e.bind();var h=e.uniforms;h.viewTransform=u,h.shape=this.shape;var f=e.attributes;this.positionBuffer.bind(),f.position.pointer(),this.weightBuffer.bind(),f.weight.pointer(a.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),f.color.pointer(a.UNSIGNED_BYTE,!0),a.drawArrays(a.TRIANGLES,0,n)}}),h.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,a=this.pickShader,i=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=i[2]-i[0],u=i[3]-i[1],h=l[2]-l[0],f=l[3]-l[1];t[0]=2*c/h,t[4]=2*u/f,t[6]=2*(i[0]-l[0])/h-1,t[7]=2*(i[1]-l[1])/f-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,a.bind();var d=a.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var g=a.attributes;return this.positionBuffer.bind(),g.position.pointer(),this.weightBuffer.bind(),g.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),g.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),h.pick=function(t,e,r){var n=this.pickOffset,a=this.shape[0]*this.shape[1];if(r<n||r>=n+a)return null;var i=r-n,o=this.xData,s=this.yData;return{object:this,pointId:i,dataCoord:[o[i%this.shape[0]],s[i/this.shape[0]|0]]}},h.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||a(e[0]),o=t.y||a(e[1]),s=t.z||new Float32Array(e[0]*e[1]);this.xData=r,this.yData=o;var l=t.colorLevels||[0],c=t.colorValues||[0,0,0,1],u=l.length,h=this.bounds,p=h[0]=r[0],d=h[1]=o[0],g=1/((h[2]=r[r.length-1])-p),v=1/((h[3]=o[o.length-1])-d),m=e[0],y=e[1];this.shape=[m,y];var x=(m-1)*(y-1)*(f.length>>>1);this.numVertices=x;for(var b=i.mallocUint8(4*x),_=i.mallocFloat32(2*x),w=i.mallocUint8(2*x),k=i.mallocUint32(x),T=0,M=0;M<y-1;++M)for(var A=v*(o[M]-d),S=v*(o[M+1]-d),E=0;E<m-1;++E)for(var L=g*(r[E]-p),C=g*(r[E+1]-p),P=0;P<f.length;P+=2){var O,z,I,D,R=f[P],F=f[P+1],B=s[(M+F)*m+(E+R)],N=n.le(l,B);if(N<0)O=c[0],z=c[1],I=c[2],D=c[3];else if(N===u-1)O=c[4*u-4],z=c[4*u-3],I=c[4*u-2],D=c[4*u-1];else{var j=(B-l[N])/(l[N+1]-l[N]),V=1-j,U=4*N,q=4*(N+1);O=V*c[U]+j*c[q],z=V*c[U+1]+j*c[q+1],I=V*c[U+2]+j*c[q+2],D=V*c[U+3]+j*c[q+3]}b[4*T]=255*O,b[4*T+1]=255*z,b[4*T+2]=255*I,b[4*T+3]=255*D,_[2*T]=.5*L+.5*C,_[2*T+1]=.5*A+.5*S,w[2*T]=R,w[2*T+1]=F,k[T]=M*m+E,T+=1}this.positionBuffer.update(_),this.weightBuffer.update(w),this.colorBuffer.update(b),this.idBuffer.update(k),i.free(_),i.free(b),i.free(w),i.free(k)},h.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{"./lib/shaders":255,"binary-search-bounds":256,"gl-buffer":244,"gl-shader":304,"iota-array":417,"typedarray-pool":543}],255:[function(t,e,r){"use strict";var n=t("glslify");e.exports={fragment:n(["precision lowp float;\n#define GLSLIFY 1\nvarying vec4 fragColor;\nvoid main() {\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\n}\n"]),vertex:n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec2 position;\nattribute vec4 color;\nattribute vec2 weight;\n\nuniform vec2 shape;\nuniform mat3 viewTransform;\n\nvarying vec4 fragColor;\n\nvoid main() {\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\n  fragColor = color;\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\n}\n"]),pickFragment:n(["precision mediump float;\n#define GLSLIFY 1\n\nvarying vec4 fragId;\nvarying vec2 vWeight;\n\nuniform vec2 shape;\nuniform vec4 pickOffset;\n\nvoid main() {\n  vec2 d = step(.5, vWeight);\n  vec4 id = fragId + pickOffset;\n  id.x += d.x + d.y*shape.x;\n\n  id.y += floor(id.x / 256.0);\n  id.x -= floor(id.x / 256.0) * 256.0;\n\n  id.z += floor(id.y / 256.0);\n  id.y -= floor(id.y / 256.0) * 256.0;\n\n  id.w += floor(id.z / 256.0);\n  id.z -= floor(id.z / 256.0) * 256.0;\n\n  gl_FragColor = id/255.;\n}\n"]),pickVertex:n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec2 position;\nattribute vec4 pickId;\nattribute vec2 weight;\n\nuniform vec2 shape;\nuniform mat3 viewTransform;\n\nvarying vec4 fragId;\nvarying vec2 vWeight;\n\nvoid main() {\n  vWeight = weight;\n\n  fragId = pickId;\n\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\n}\n"])}},{glslify:410}],256:[function(t,e,r){arguments[4][113][0].apply(r,arguments)},{dup:113}],257:[function(t,e,r){var n=t("glslify"),a=t("gl-shader"),i=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position, nextPosition;\nattribute float arcLength, lineWidth;\nattribute vec4 color;\n\nuniform vec2 screenShape;\nuniform float pixelRatio;\nuniform mat4 model, view, projection;\n\nvarying vec4 fragColor;\nvarying vec3 worldPosition;\nvarying float pixelArcLength;\n\nvec4 project(vec3 p) {\n  return projection * view * model * vec4(p, 1.0);\n}\n\nvoid main() {\n  vec4 startPoint = project(position);\n  vec4 endPoint   = project(nextPosition);\n\n  vec2 A = startPoint.xy / startPoint.w;\n  vec2 B =   endPoint.xy /   endPoint.w;\n\n  float clipAngle = atan(\n    (B.y - A.y) * screenShape.y,\n    (B.x - A.x) * screenShape.x\n  );\n\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\n    sin(clipAngle),\n    -cos(clipAngle)\n  ) / screenShape;\n\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\n\n  worldPosition = position;\n  pixelArcLength = arcLength;\n  fragColor = color;\n}\n"]),o=n(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3      clipBounds[2];\nuniform sampler2D dashTexture;\nuniform float     dashScale;\nuniform float     opacity;\n\nvarying vec3    worldPosition;\nvarying float   pixelArcLength;\nvarying vec4    fragColor;\n\nvoid main() {\n  if (\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\n    fragColor.a * opacity == 0.\n  ) discard;\n\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\n  if(dashWeight < 0.5) {\n    discard;\n  }\n  gl_FragColor = fragColor * opacity;\n}\n"]),s=n(["precision highp float;\n#define GLSLIFY 1\n\n#define FLOAT_MAX  1.70141184e38\n#define FLOAT_MIN  1.17549435e-38\n\n// https://github.com/mikolalysenko/glsl-read-float/blob/master/index.glsl\nvec4 packFloat(float v) {\n  float av = abs(v);\n\n  //Handle special cases\n  if(av < FLOAT_MIN) {\n    return vec4(0.0, 0.0, 0.0, 0.0);\n  } else if(v > FLOAT_MAX) {\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\n  } else if(v < -FLOAT_MAX) {\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\n  }\n\n  vec4 c = vec4(0,0,0,0);\n\n  //Compute exponent and mantissa\n  float e = floor(log2(av));\n  float m = av * pow(2.0, -e) - 1.0;\n\n  //Unpack mantissa\n  c[1] = floor(128.0 * m);\n  m -= c[1] / 128.0;\n  c[2] = floor(32768.0 * m);\n  m -= c[2] / 32768.0;\n  c[3] = floor(8388608.0 * m);\n\n  //Unpack exponent\n  float ebias = e + 127.0;\n  c[0] = floor(ebias / 2.0);\n  ebias -= c[0] * 2.0;\n  c[1] += floor(ebias) * 128.0;\n\n  //Unpack sign bit\n  c[0] += 128.0 * step(0.0, -v);\n\n  //Scale back to range\n  return c / 255.0;\n}\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform float pickId;\nuniform vec3 clipBounds[2];\n\nvarying vec3 worldPosition;\nvarying float pixelArcLength;\nvarying vec4 fragColor;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\n\n  gl_FragColor = vec4(pickId/255.0, packFloat(pixelArcLength).xyz);\n}"]),l=[{name:"position",type:"vec3"},{name:"nextPosition",type:"vec3"},{name:"arcLength",type:"float"},{name:"lineWidth",type:"float"},{name:"color",type:"vec4"}];r.createShader=function(t){return a(t,i,o,null,l)},r.createPickShader=function(t){return a(t,i,s,null,l)}},{"gl-shader":304,glslify:410}],258:[function(t,e,r){"use strict";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=h(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=f(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),l=a(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),u=c(new Array(1024),[256,1,4]),p=0;p<1024;++p)u.data[p]=255;var d=i(e,u);d.wrap=e.REPEAT;var g=new m(e,r,o,s,l,d);return g.update(t),g};var n=t("gl-buffer"),a=t("gl-vao"),i=t("gl-texture2d"),o=new Uint8Array(4),s=new Float32Array(o.buffer);var l=t("binary-search-bounds"),c=t("ndarray"),u=t("./lib/shaders"),h=u.createShader,f=u.createPickShader,p=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function d(t,e){for(var r=0,n=0;n<3;++n){var a=t[n]-e[n];r+=a*a}return Math.sqrt(r)}function g(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function v(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function m(t,e,r,n,a,i){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=a,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=i,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var y=m.prototype;y.isTransparent=function(){return this.hasAlpha},y.isOpaque=function(){return!this.hasAlpha},y.pickSlots=1,y.setPickBase=function(t){this.pickId=t},y.drawTransparent=y.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||p,view:t.view||p,projection:t.projection||p,clipBounds:g(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},y.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||p,view:t.view||p,projection:t.projection||p,pickId:this.pickId,clipBounds:g(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},y.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;"dashScale"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,"opacity"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var a=[],i=[],o=[],s=0,u=0,h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],f=t.position||t.positions;if(f){var p=t.color||t.colors||[0,0,0,1],g=t.lineWidth||1,v=!1;t:for(e=1;e<f.length;++e){var m,y,x,b=f[e-1],_=f[e];for(i.push(s),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&a.length>0){for(var w=0;w<24;++w)a.push(a[a.length-12]);u+=2,v=!0}continue t}h[0][r]=Math.min(h[0][r],b[r],_[r]),h[1][r]=Math.max(h[1][r],b[r],_[r])}Array.isArray(p[0])?(m=p.length>e-1?p[e-1]:p.length>0?p[p.length-1]:[0,0,0,1],y=p.length>e?p[e]:p.length>0?p[p.length-1]:[0,0,0,1]):m=y=p,3===m.length&&(m=[m[0],m[1],m[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),!this.hasAlpha&&m[3]<1&&(this.hasAlpha=!0),x=Array.isArray(g)?g.length>e-1?g[e-1]:g.length>0?g[g.length-1]:[0,0,0,1]:g;var k=s;if(s+=d(b,_),v){for(r=0;r<2;++r)a.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3]);u+=2,v=!1}a.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3],b[0],b[1],b[2],_[0],_[1],_[2],k,-x,m[0],m[1],m[2],m[3],_[0],_[1],_[2],b[0],b[1],b[2],s,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],s,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(a),i.push(s),o.push(f[f.length-1].slice()),this.bounds=h,this.vertexCount=u,this.points=o,this.arcLength=i,"dashes"in t){var T=t.dashes.slice();for(T.unshift(0),e=1;e<T.length;++e)T[e]=T[e-1]+T[e];var M=c(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)M.set(e,0,r,0);1&l.le(T,T[T.length-1]*e/255)?M.set(e,0,0,0):M.set(e,0,0,255)}this.texture.setPixels(M)}},y.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},y.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=function(t,e,r,n){return o[0]=n,o[1]=r,o[2]=e,o[3]=t,s[0]}(t.value[0],t.value[1],t.value[2],0),r=l.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new v(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],a=this.points[Math.min(r+1,this.points.length-1)],i=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),c=1-i,u=[0,0,0],h=0;h<3;++h)u[h]=c*n[h]+i*a[h];var f=Math.min(i<.5?r:r+1,this.points.length-1);return new v(e,u,f,this.points[f])}},{"./lib/shaders":257,"binary-search-bounds":259,"gl-buffer":244,"gl-texture2d":324,"gl-vao":329,ndarray:451}],259:[function(t,e,r){arguments[4][113][0].apply(r,arguments)},{dup:113}],260:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=r*i-a*n;return o?(o=1/o,t[0]=i*o,t[1]=-n*o,t[2]=-a*o,t[3]=r*o,t):null}},{}],261:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=u*o-s*c,f=-u*i+s*l,p=c*i-o*l,d=r*h+n*f+a*p;return d?(d=1/d,t[0]=h*d,t[1]=(-u*n+a*c)*d,t[2]=(s*n-a*o)*d,t[3]=f*d,t[4]=(u*r-a*l)*d,t[5]=(-s*r+a*i)*d,t[6]=p*d,t[7]=(-c*r+n*l)*d,t[8]=(o*r-n*i)*d,t):null}},{}],262:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],263:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],264:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],a=t[3],i=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],h=t[10],f=t[11],p=t[12],d=t[13],g=t[14],v=t[15];return(e*o-r*i)*(h*v-f*g)-(e*s-n*i)*(u*v-f*d)+(e*l-a*i)*(u*g-h*d)+(r*s-n*o)*(c*v-f*p)-(r*l-a*o)*(c*g-h*p)+(n*l-a*s)*(c*d-u*p)}},{}],265:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=r+r,s=n+n,l=a+a,c=r*o,u=n*o,h=n*s,f=a*o,p=a*s,d=a*l,g=i*o,v=i*s,m=i*l;return t[0]=1-h-d,t[1]=u+m,t[2]=f-v,t[3]=0,t[4]=u-m,t[5]=1-c-d,t[6]=p+g,t[7]=0,t[8]=f+v,t[9]=p-g,t[10]=1-c-h,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],266:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3],s=n+n,l=a+a,c=i+i,u=n*s,h=n*l,f=n*c,p=a*l,d=a*c,g=i*c,v=o*s,m=o*l,y=o*c;return t[0]=1-(p+g),t[1]=h+y,t[2]=f-m,t[3]=0,t[4]=h-y,t[5]=1-(u+g),t[6]=d+v,t[7]=0,t[8]=f+m,t[9]=d-v,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],267:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],268:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-a*o,b=r*c-i*o,_=n*l-a*s,w=n*c-i*s,k=a*c-i*l,T=u*g-h*d,M=u*v-f*d,A=u*m-p*d,S=h*v-f*g,E=h*m-p*g,L=f*m-p*v,C=y*L-x*E+b*S+_*A-w*M+k*T;if(!C)return null;return C=1/C,t[0]=(s*L-l*E+c*S)*C,t[1]=(a*E-n*L-i*S)*C,t[2]=(g*k-v*w+m*_)*C,t[3]=(f*w-h*k-p*_)*C,t[4]=(l*A-o*L-c*M)*C,t[5]=(r*L-a*A+i*M)*C,t[6]=(v*b-d*k-m*x)*C,t[7]=(u*k-f*b+p*x)*C,t[8]=(o*E-s*A+c*T)*C,t[9]=(n*A-r*E-i*T)*C,t[10]=(d*w-g*b+m*y)*C,t[11]=(h*b-u*w-p*y)*C,t[12]=(s*M-o*S-l*T)*C,t[13]=(r*S-n*M+a*T)*C,t[14]=(g*x-d*_-v*y)*C,t[15]=(u*_-h*x+f*y)*C,t}},{}],269:[function(t,e,r){var n=t("./identity");e.exports=function(t,e,r,a){var i,o,s,l,c,u,h,f,p,d,g=e[0],v=e[1],m=e[2],y=a[0],x=a[1],b=a[2],_=r[0],w=r[1],k=r[2];if(Math.abs(g-_)<1e-6&&Math.abs(v-w)<1e-6&&Math.abs(m-k)<1e-6)return n(t);h=g-_,f=v-w,p=m-k,d=1/Math.sqrt(h*h+f*f+p*p),i=x*(p*=d)-b*(f*=d),o=b*(h*=d)-y*p,s=y*f-x*h,(d=Math.sqrt(i*i+o*o+s*s))?(i*=d=1/d,o*=d,s*=d):(i=0,o=0,s=0);l=f*s-p*o,c=p*i-h*s,u=h*o-f*i,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=i,t[1]=l,t[2]=h,t[3]=0,t[4]=o,t[5]=c,t[6]=f,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(i*g+o*v+s*m),t[13]=-(l*g+c*v+u*m),t[14]=-(h*g+f*v+p*m),t[15]=1,t}},{"./identity":267}],270:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*a+b*l+_*f+w*v,t[2]=x*i+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*a+b*l+_*f+w*v,t[6]=x*i+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*a+b*l+_*f+w*v,t[10]=x*i+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*a+b*l+_*f+w*v,t[14]=x*i+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t}},{}],271:[function(t,e,r){e.exports=function(t,e,r,n,a,i,o){var s=1/(e-r),l=1/(n-a),c=1/(i-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(a+n)*l,t[14]=(o+i)*c,t[15]=1,t}},{}],272:[function(t,e,r){e.exports=function(t,e,r,n,a){var i=1/Math.tan(e/2),o=1/(n-a);return t[0]=i/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=i,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(a+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*a*n*o,t[15]=0,t}},{}],273:[function(t,e,r){e.exports=function(t,e,r,n){var a,i,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k,T,M,A,S,E=n[0],L=n[1],C=n[2],P=Math.sqrt(E*E+L*L+C*C);if(Math.abs(P)<1e-6)return null;E*=P=1/P,L*=P,C*=P,a=Math.sin(r),i=Math.cos(r),o=1-i,s=e[0],l=e[1],c=e[2],u=e[3],h=e[4],f=e[5],p=e[6],d=e[7],g=e[8],v=e[9],m=e[10],y=e[11],x=E*E*o+i,b=L*E*o+C*a,_=C*E*o-L*a,w=E*L*o-C*a,k=L*L*o+i,T=C*L*o+E*a,M=E*C*o+L*a,A=L*C*o-E*a,S=C*C*o+i,t[0]=s*x+h*b+g*_,t[1]=l*x+f*b+v*_,t[2]=c*x+p*b+m*_,t[3]=u*x+d*b+y*_,t[4]=s*w+h*k+g*T,t[5]=l*w+f*k+v*T,t[6]=c*w+p*k+m*T,t[7]=u*w+d*k+y*T,t[8]=s*M+h*A+g*S,t[9]=l*M+f*A+v*S,t[10]=c*M+p*A+m*S,t[11]=u*M+d*A+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],274:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),a=Math.cos(r),i=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=i*a+c*n,t[5]=o*a+u*n,t[6]=s*a+h*n,t[7]=l*a+f*n,t[8]=c*a-i*n,t[9]=u*a-o*n,t[10]=h*a-s*n,t[11]=f*a-l*n,t}},{}],275:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),a=Math.cos(r),i=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=i*a-c*n,t[1]=o*a-u*n,t[2]=s*a-h*n,t[3]=l*a-f*n,t[8]=i*n+c*a,t[9]=o*n+u*a,t[10]=s*n+h*a,t[11]=l*n+f*a,t}},{}],276:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),a=Math.cos(r),i=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=i*a+c*n,t[1]=o*a+u*n,t[2]=s*a+h*n,t[3]=l*a+f*n,t[4]=c*a-i*n,t[5]=u*a-o*n,t[6]=h*a-s*n,t[7]=f*a-l*n,t}},{}],277:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],a=r[1],i=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*a,t[5]=e[5]*a,t[6]=e[6]*a,t[7]=e[7]*a,t[8]=e[8]*i,t[9]=e[9]*i,t[10]=e[10]*i,t[11]=e[11]*i,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],278:[function(t,e,r){e.exports=function(t,e,r){var n,a,i,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],a=e[1],i=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=a,t[2]=i,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=a*g+l*v+f*m+e[13],t[14]=i*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]);return t}},{}],279:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],a=e[3],i=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=i,t[11]=e[14],t[12]=a,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],280:[function(t,e,r){"use strict";e.exports=function(t,e){switch(e.length){case 0:break;case 1:t[0]=1/e[0];break;case 4:n(t,e);break;case 9:a(t,e);break;case 16:i(t,e);break;default:throw new Error("currently supports matrices up to 4x4")}return t};var n=t("gl-mat2/invert"),a=t("gl-mat3/invert"),i=t("gl-mat4/invert")},{"gl-mat2/invert":260,"gl-mat3/invert":261,"gl-mat4/invert":268}],281:[function(t,e,r){"use strict";var n=t("barycentric"),a=t("polytope-closest-point/lib/closest_point_2d.js");function i(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var a=0;a<4;++a)r[a]+=t[4*n+a]*e[n];return r}function o(t,e,r,n,a){for(var o=i(n,i(r,i(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*a[0]*(1+o[0]),.5*a[1]*(1-o[1])]}function s(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var a=t[n],i=e[n],o=0;o<3;++o)r[o]+=i*a[o];return r}e.exports=function(t,e,r,i,l,c){if(1===t.length)return[0,t[0].slice()];for(var u=new Array(t.length),h=0;h<t.length;++h)u[h]=o(t[h],r,i,l,c);for(var f=0,p=1/0,h=0;h<u.length;++h){for(var d=0,g=0;g<2;++g)d+=Math.pow(u[h][g]-e[g],2);d<p&&(p=d,f=h)}for(var v=function(t,e){if(2===t.length){for(var r=0,i=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),i+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),i=Math.sqrt(i),r+i<1e-6?[1,0]:[i/(r+i),r/(i+r)]}if(3===t.length){var s=[0,0];return a(t[0],t[1],t[2],e,s),n(t,s)}return[]}(u,e),m=0,h=0;h<3;++h){if(v[h]<-.001||v[h]>1.0001)return null;m+=v[h]}if(Math.abs(m-1)>.001)return null;return[f,s(t,v),v]}},{barycentric:75,"polytope-closest-point/lib/closest_point_2d.js":482}],282:[function(t,e,r){var n=t("glslify"),a=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position, normal;\nattribute vec4 color;\nattribute vec2 uv;\n\nuniform mat4 model\n           , view\n           , projection\n           , inverseModel;\nuniform vec3 eyePosition\n           , lightPosition;\n\nvarying vec3 f_normal\n           , f_lightDirection\n           , f_eyeDirection\n           , f_data;\nvarying vec4 f_color;\nvarying vec2 f_uv;\n\nvec4 project(vec3 p) {\n  return projection * view * model * vec4(p, 1.0);\n}\n\nvoid main() {\n  gl_Position      = project(position);\n\n  //Lighting geometry parameters\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\n  cameraCoordinate.xyz /= cameraCoordinate.w;\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\n\n  f_color          = color;\n  f_data           = position;\n  f_uv             = uv;\n}\n"]),i=n(["#extension GL_OES_standard_derivatives : enable\n\nprecision highp float;\n#define GLSLIFY 1\n\nfloat beckmannDistribution(float x, float roughness) {\n  float NdotH = max(x, 0.0001);\n  float cos2Alpha = NdotH * NdotH;\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\n  float roughness2 = roughness * roughness;\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\n  return exp(tan2Alpha / roughness2) / denom;\n}\n\nfloat cookTorranceSpecular(\n  vec3 lightDirection,\n  vec3 viewDirection,\n  vec3 surfaceNormal,\n  float roughness,\n  float fresnel) {\n\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\n\n  //Half angle vector\n  vec3 H = normalize(lightDirection + viewDirection);\n\n  //Geometric term\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\n  float VdotH = max(dot(viewDirection, H), 0.000001);\n  float LdotH = max(dot(lightDirection, H), 0.000001);\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\n  float G = min(1.0, min(G1, G2));\n  \n  //Distribution term\n  float D = beckmannDistribution(NdotH, roughness);\n\n  //Fresnel term\n  float F = pow(1.0 - VdotN, fresnel);\n\n  //Multiply terms and done\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\n}\n\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3 clipBounds[2];\nuniform float roughness\n            , fresnel\n            , kambient\n            , kdiffuse\n            , kspecular;\nuniform sampler2D texture;\n\nvarying vec3 f_normal\n           , f_lightDirection\n           , f_eyeDirection\n           , f_data;\nvarying vec4 f_color;\nvarying vec2 f_uv;\n\nvoid main() {\n  if (f_color.a == 0.0 ||\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\n  ) discard;\n\n  vec3 N = normalize(f_normal);\n  vec3 L = normalize(f_lightDirection);\n  vec3 V = normalize(f_eyeDirection);\n\n  if(gl_FrontFacing) {\n    N = -N;\n  }\n\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\n\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\n\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\n\n  gl_FragColor = litColor * f_color.a;\n}\n"]),o=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position;\nattribute vec4 color;\nattribute vec2 uv;\n\nuniform mat4 model, view, projection;\n\nvarying vec4 f_color;\nvarying vec3 f_data;\nvarying vec2 f_uv;\n\nvoid main() {\n  gl_Position = projection * view * model * vec4(position, 1.0);\n  f_color = color;\n  f_data  = position;\n  f_uv    = uv;\n}"]),s=n(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3 clipBounds[2];\nuniform sampler2D texture;\nuniform float opacity;\n\nvarying vec4 f_color;\nvarying vec3 f_data;\nvarying vec2 f_uv;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\n\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\n}"]),l=n(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nattribute vec3 position;\nattribute vec4 color;\nattribute vec2 uv;\nattribute float pointSize;\n\nuniform mat4 model, view, projection;\nuniform vec3 clipBounds[2];\n\nvarying vec4 f_color;\nvarying vec2 f_uv;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\n\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\n  } else {\n    gl_Position = projection * view * model * vec4(position, 1.0);\n  }\n  gl_PointSize = pointSize;\n  f_color = color;\n  f_uv = uv;\n}"]),c=n(["precision highp float;\n#define GLSLIFY 1\n\nuniform sampler2D texture;\nuniform float opacity;\n\nvarying vec4 f_color;\nvarying vec2 f_uv;\n\nvoid main() {\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\n  if(dot(pointR, pointR) > 0.25) {\n    discard;\n  }\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\n}"]),u=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position;\nattribute vec4 id;\n\nuniform mat4 model, view, projection;\n\nvarying vec3 f_position;\nvarying vec4 f_id;\n\nvoid main() {\n  gl_Position = projection * view * model * vec4(position, 1.0);\n  f_id        = id;\n  f_position  = position;\n}"]),h=n(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3  clipBounds[2];\nuniform float pickId;\n\nvarying vec3 f_position;\nvarying vec4 f_id;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\n\n  gl_FragColor = vec4(pickId, f_id.xyz);\n}"]),f=n(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nattribute vec3  position;\nattribute float pointSize;\nattribute vec4  id;\n\nuniform mat4 model, view, projection;\nuniform vec3 clipBounds[2];\n\nvarying vec3 f_position;\nvarying vec4 f_id;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\n\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\n  } else {\n    gl_Position  = projection * view * model * vec4(position, 1.0);\n    gl_PointSize = pointSize;\n  }\n  f_id         = id;\n  f_position   = position;\n}"]),p=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position;\n\nuniform mat4 model, view, projection;\n\nvoid main() {\n  gl_Position = projection * view * model * vec4(position, 1.0);\n}"]),d=n(["precision highp float;\n#define GLSLIFY 1\n\nuniform vec3 contourColor;\n\nvoid main() {\n  gl_FragColor = vec4(contourColor, 1.0);\n}\n"]);r.meshShader={vertex:a,fragment:i,attributes:[{name:"position",type:"vec3"},{name:"normal",type:"vec3"},{name:"color",type:"vec4"},{name:"uv",type:"vec2"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:"position",type:"vec3"},{name:"color",type:"vec4"},{name:"uv",type:"vec2"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:"position",type:"vec3"},{name:"color",type:"vec4"},{name:"uv",type:"vec2"},{name:"pointSize",type:"float"}]},r.pickShader={vertex:u,fragment:h,attributes:[{name:"position",type:"vec3"},{name:"id",type:"vec4"}]},r.pointPickShader={vertex:f,fragment:h,attributes:[{name:"position",type:"vec3"},{name:"pointSize",type:"float"},{name:"id",type:"vec4"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:"position",type:"vec3"}]}},{glslify:410}],283:[function(t,e,r){"use strict";var n=t("gl-shader"),a=t("gl-buffer"),i=t("gl-vao"),o=t("gl-texture2d"),s=t("normals"),l=t("gl-mat4/multiply"),c=t("gl-mat4/invert"),u=t("ndarray"),h=t("colormap"),f=t("simplicial-complex-contour"),p=t("typedarray-pool"),d=t("./lib/shaders"),g=t("./lib/closest-point"),v=d.meshShader,m=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function k(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,k,T,M,A,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=a,this.pickShader=i,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=f,this.triangleUVs=h,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=v,this.edgeUVs=m,this.edgeIds=g,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=k,this.pointSizes=T,this.pointIds=b,this.pointVAO=M,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=A,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickVertex=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var T=k.prototype;function M(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function A(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function S(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function E(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function L(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}T.isOpaque=function(){return!this.hasAlpha},T.isTransparent=function(){return this.hasAlpha},T.pickSlots=1,T.setPickBase=function(t){this.pickId=t},T.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,a=e.vertexWeights,i=r.length,o=p.mallocFloat32(6*i),s=0,l=0;l<i;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=a[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},T.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,"contourEnable"in t&&(this.contourEnable=t.contourEnable),"contourColor"in t&&(this.contourColor=t.contourColor),"lineWidth"in t&&(this.lineWidth=t.lineWidth),"lightPosition"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,"opacity"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),"opacityscale"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),"ambient"in t&&(this.ambientLight=t.ambient),"diffuse"in t&&(this.diffuseLight=t.diffuse),"specular"in t&&(this.specularLight=t.specular),"roughness"in t&&(this.roughness=t.roughness),"fresnel"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=h({colormap:t,nshades:256,format:"rgba"}),n=new Uint8Array(1024),a=0;a<256;++a){for(var i=r[a],o=0;o<3;++o)n[4*a+o]=i[o];n[4*a+3]=e?255*M(a/255,e):255*i[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var a=[],i=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,k=t.cellNormals,T=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,A=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!k&&(k=s.faceNormals(r,n,A)),k||w||(w=s.vertexNormals(r,n,T));var S=t.vertexColors,E=t.cellColors,L=t.meshColor||[1,1,1,1],C=t.vertexUVs,P=t.vertexIntensity,O=t.cellUVs,z=t.cellIntensity,I=1/0,D=-1/0;if(!C&&!O)if(P)if(t.vertexIntensityBounds)I=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<P.length;++R){var F=P[R];I=Math.min(I,F),D=Math.max(D,F)}else if(z)if(t.cellIntensityBounds)I=+t.cellIntensityBounds[0],D=+t.cellIntensityBounds[1];else for(R=0;R<z.length;++R){F=z[R];I=Math.min(I,F),D=Math.max(D,F)}else for(R=0;R<n.length;++R){F=n[R][2];I=Math.min(I,F),D=Math.max(D,F)}this.intensity=P||(z||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n)),this.pickVertex=!(z||E);var B=t.pointSizes,N=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(R=0;R<n.length;++R)for(var j=n[R],V=0;V<3;++V)!isNaN(j[V])&&isFinite(j[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],j[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],j[V]));var U=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],V=0;V<3;++V)if(isNaN(j[V])||!isFinite(j[V]))continue t;m.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:L,this.opacityscale&&P?i.push(X[0],X[1],X[2],this.opacity*M((P[W]-I)/(D-I),this.opacityscale)):3===X.length?y.push(X[0],X[1],X[2],this.opacity):(y.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)),Z=C?C[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],x.push(Z[0],Z[1]),B?b.push(B[W]):b.push(N),_.push(R),H+=1;break;case 2:for(V=0;V<2;++V){j=n[W=G[V]];for(var Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t}for(V=0;V<2;++V){j=n[W=G[V]];p.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:L,this.opacityscale&&P?i.push(X[0],X[1],X[2],this.opacity*M((P[W]-I)/(D-I),this.opacityscale)):3===X.length?d.push(X[0],X[1],X[2],this.opacity):(d.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)),Z=C?C[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],g.push(Z[0],Z[1]),v.push(R)}q+=1;break;case 3:for(V=0;V<3;++V)for(j=n[W=G[V]],Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t;for(V=0;V<3;++V){var W,X,Z,J;j=n[W=G[2-V]];a.push(j[0],j[1],j[2]),(X=S?S[W]:E?E[R]:L)?this.opacityscale&&P?i.push(X[0],X[1],X[2],this.opacity*M((P[W]-I)/(D-I),this.opacityscale)):3===X.length?i.push(X[0],X[1],X[2],this.opacity):(i.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)):i.push(.5,.5,.5,1),Z=C?C[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],c.push(Z[0],Z[1]),J=w?w[W]:k[R],l.push(J[0],J[1],J[2]),f.push(R)}U+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=U,this.pointPositions.update(m),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(g),this.edgeIds.update(new Uint32Array(v)),this.trianglePositions.update(a),this.triangleColors.update(i),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(f))}},T.drawTransparent=T.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,a=t.projection||w,i=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)i[0][o]=Math.max(i[0][o],this.clipBounds[0][o]),i[1][o]=Math.min(i[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:a,inverseModel:w.slice(),clipBounds:i,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h,f=u[15];for(o=0;o<3;++o)f+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/f}this.triangleCount>0&&((h=this.triShader).bind(),h.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((h=this.lineShader).bind(),h.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((h=this.pointShader).bind(),h.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((h=this.contourShader).bind(),h.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},T.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,a=t.projection||w,i=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)i[0][o]=Math.max(i[0][o],this.clipBounds[0][o]),i[1][o]=Math.min(i[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(a),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:a,clipBounds:i,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},T.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,a=new Array(r.length),i=0;i<r.length;++i)a[i]=n[r[i]];var o=t.coord[0],s=t.coord[1];if(!this.pickVertex){var l=this.positions[r[0]],c=this.positions[r[1]],u=this.positions[r[2]],h=[(l[0]+c[0]+u[0])/3,(l[1]+c[1]+u[1])/3,(l[2]+c[2]+u[2])/3];return{_cellCenter:!0,position:[o,s],index:e,cell:r,cellId:e,intensity:this.intensity[e],dataCoordinate:h}}var f=g(a,[o*this.pixelRatio,this._resolution[1]-s*this.pixelRatio],this._model,this._view,this._projection,this._resolution);if(!f)return null;var p=f[2],d=0;for(i=0;i<r.length;++i)d+=p[i]*this.intensity[r[i]];return{position:f[1],index:r[f[0]],cell:r,cellId:e,intensity:d,dataCoordinate:this.positions[r[f[0]]]}},T.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){if(1===arguments.length&&(t=(e=t).gl),!(t.getExtension("OES_standard_derivatives")||t.getExtension("MOZ_OES_standard_derivatives")||t.getExtension("WEBKIT_OES_standard_derivatives")))throw new Error("derivatives not supported");var r=function(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}(t),s=function(t){var e=n(t,m.vertex,m.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}(t),l=A(t),c=S(t),h=E(t),f=L(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=a(t),g=a(t),y=a(t),x=a(t),b=a(t),_=i(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:b,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:y,type:t.FLOAT,size:2},{buffer:x,type:t.FLOAT,size:3}]),w=a(t),T=a(t),M=a(t),C=a(t),P=i(t,[{buffer:w,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:T,type:t.FLOAT,size:4},{buffer:M,type:t.FLOAT,size:2}]),O=a(t),z=a(t),I=a(t),D=a(t),R=a(t),F=i(t,[{buffer:O,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:z,type:t.FLOAT,size:4},{buffer:I,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=a(t),N=new k(t,p,r,s,l,c,h,f,d,b,g,y,x,_,w,C,T,M,P,O,R,z,I,D,F,B,i(t,[{buffer:B,type:t.FLOAT,size:3}]));return N.update(e),N}},{"./lib/closest-point":281,"./lib/shaders":282,colormap:128,"gl-buffer":244,"gl-mat4/invert":268,"gl-mat4/multiply":270,"gl-shader":304,"gl-texture2d":324,"gl-vao":329,ndarray:451,normals:454,"simplicial-complex-contour":516,"typedarray-pool":543}],284:[function(t,e,r){"use strict";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=a(e,i.boxVert,i.lineFrag);return new o(t,r,s)};var n=t("gl-buffer"),a=t("gl-shader"),i=t("./shaders");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,a){var i=this.plot,o=this.shader,c=i.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=a,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{"./shaders":287,"gl-buffer":244,"gl-shader":304}],285:[function(t,e,r){"use strict";e.exports=function(t){var e=t.gl,r=n(e),i=a(e,o.gridVert,o.gridFrag),l=a(e,o.tickVert,o.gridFrag);return new s(t,r,i,l)};var n=t("gl-buffer"),a=t("gl-shader"),i=t("binary-search-bounds"),o=t("./shaders");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,h,f,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],h=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,a=t.gl,i=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,f=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,g=0;g<2;++g){var v=i[g],m=i[g+2]-v,y=.5*(o[g+2]+o[g]),x=o[g+2]-o[g];u[g]=2*m/x,c[g]=2*(v-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(g=0;g<2;++g){h[0]=h[1]=0,h[g]=1,r.uniforms.dataAxis=h,r.uniforms.lineWidth=l[g]/(s[g+2]-s[g])*d,r.uniforms.color=f[g];var _=6*n[g].length;p[g]&&_&&a.drawArrays(a.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],a=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,h=this.ticks,f=s.gl,p=s._tickBounds,d=s.dataBox,g=s.viewBox,v=s.pixelRatio,m=s.screenBox,y=m[2]-m[0],x=m[3]-m[1],b=g[2]-g[0],_=g[3]-g[1],w=0;w<2;++w){var k=p[w],T=p[w+2]-k,M=.5*(d[w+2]+d[w]),A=d[w+2]-d[w];e[w]=2*T/A,t[w]=2*(k-M)/A}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,L=s.tickMarkWidth,C=s.tickMarkColor,P=6*h[0].length,O=Math.min(i.ge(h[0],(d[0]-p[0])/(p[2]-p[0]),l),h[0].length),z=Math.min(i.gt(h[0],(d[2]-p[0])/(p[2]-p[0]),l),h[0].length),I=0+6*O,D=6*Math.max(0,z-O),R=Math.min(i.ge(h[1],(d[1]-p[1])/(p[3]-p[1]),l),h[1].length),F=Math.min(i.gt(h[1],(d[3]-p[1])/(p[3]-p[1]),l),h[1].length),B=P+6*R,N=6*Math.max(0,F-R);a[0]=2*(g[0]-E[1])/y-1,a[1]=(g[3]+g[1])/x-1,o[0]=E[1]*v/y,o[1]=L[1]*v/x,N&&(S.color=C[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=a,f.drawArrays(f.TRIANGLES,B,N)),a[0]=(g[2]+g[0])/y-1,a[1]=2*(g[1]-E[0])/x-1,o[0]=L[0]*v/y,o[1]=E[0]*v/x,D&&(S.color=C[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=a,f.drawArrays(f.TRIANGLES,I,D)),a[0]=2*(g[2]+E[3])/y-1,a[1]=(g[3]+g[1])/x-1,o[0]=E[3]*v/y,o[1]=L[3]*v/x,N&&(S.color=C[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=a,f.drawArrays(f.TRIANGLES,B,N)),a[0]=(g[2]+g[0])/y-1,a[1]=2*(g[3]+E[2])/x-1,o[0]=L[2]*v/y,o[1]=E[2]*v/x,D&&(S.color=C[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=a,f.drawArrays(f.TRIANGLES,I,D))}}(),d.update=(f=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),a=(this.plot.zeroLineEnable,0),i=[[],[]],o=0;o<2;++o)for(var s=i[o],l=e[o],c=r[o],u=r[o+2],h=0;h<l.length;++h){var d=(l[h].x-c)/(u-c);s.push(d);for(var g=0;g<6;++g)n[a++]=d,n[a++]=f[g],n[a++]=p[g]}this.ticks=i,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{"./shaders":287,"binary-search-bounds":289,"gl-buffer":244,"gl-shader":304}],286:[function(t,e,r){"use strict";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=a(e,i.lineVert,i.lineFrag);return new o(t,r,s)};var n=t("gl-buffer"),a=t("gl-shader"),i=t("./shaders");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,a,i){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=a*o.pixelRatio,c.uniforms.color=i,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{"./shaders":287,"gl-buffer":244,"gl-shader":304}],287:[function(t,e,r){"use strict";var n=t("glslify"),a=n(["precision lowp float;\n#define GLSLIFY 1\nuniform vec4 color;\nvoid main() {\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\n}\n"]);e.exports={lineVert:n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec2 coord;\n\nuniform vec4 screenBox;\nuniform vec2 start, end;\nuniform float width;\n\nvec2 perp(vec2 v) {\n  return vec2(v.y, -v.x);\n}\n\nvec2 screen(vec2 v) {\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\n}\n\nvoid main() {\n  vec2 delta = normalize(perp(start - end));\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\n}\n"]),lineFrag:a,textVert:n(["#define GLSLIFY 1\nattribute vec3 textCoordinate;\n\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\nuniform float angle;\n\nvoid main() {\n  float dataOffset  = textCoordinate.z;\n  vec2 glyphOffset  = textCoordinate.xy;\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\n    glyphMatrix * glyphOffset * textScale + screenOffset;\n  gl_Position = vec4(screenCoordinate, 0, 1);\n}\n"]),textFrag:a,gridVert:n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec3 dataCoord;\n\nuniform vec2 dataAxis, dataShift, dataScale;\nuniform float lineWidth;\n\nvoid main() {\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\n  gl_Position = vec4(pos, 0, 1);\n}\n"]),gridFrag:a,boxVert:n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec2 coord;\n\nuniform vec4 screenBox;\nuniform vec2 lo, hi;\n\nvec2 screen(vec2 v) {\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\n}\n\nvoid main() {\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\n}\n"]),tickVert:n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec3 dataCoord;\n\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\n\nvoid main() {\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\n}\n"])}},{glslify:410}],288:[function(t,e,r){"use strict";e.exports=function(t){var e=t.gl,r=n(e),i=a(e,s.textVert,s.textFrag);return new l(t,r,i)};var n=t("gl-buffer"),a=t("gl-shader"),i=t("text-cache"),o=t("binary-search-bounds"),s=t("./shaders");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,h,f,p,d,g=l.prototype;g.drawTicks=(c=[0,0],u=[0,0],h=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],a=this.tickOffset[t],i=e.gl,s=e.viewBox,l=e.dataBox,f=e.screenBox,p=e.pixelRatio,d=e.tickEnable,g=e.tickPad,v=e.tickColor,m=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],k=this.labelCount[t],T=o.lt(n,l[t]),M=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(f[2+t]-f[t])-1;var A=2/f[2+(1^t)]-f[1^t];u[1^t]=A*s[1^t]-1,d[t]&&(u[1^t]-=A*p*g[t],T<M&&a[M]>a[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t],r.uniforms.angle=m[t],i.drawArrays(i.TRIANGLES,a[T],a[M]-a[T]))),y[t]&&k&&(u[1^t]-=A*p*x[t],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],i.drawArrays(i.TRIANGLES,w,k)),u[1^t]=A*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=A*p*g[t+2],T<M&&a[M]>a[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t+2],r.uniforms.angle=m[t+2],i.drawArrays(i.TRIANGLES,a[T],a[M]-a[T]))),y[t+2]&&k&&(u[1^t]+=A*p*x[t+2],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],i.drawArrays(i.TRIANGLES,w,k))}),g.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,a=r.gl,i=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-i[u])/(i[2+u]-i[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,a.drawArrays(a.TRIANGLES,this.titleOffset,this.titleCount)}}}(),g.bind=(f=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,a=t.screenBox,i=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],h=i[o],g=i[o+2]-h,v=a[o],m=a[o+2]-v;p[o]=2*l/u*g/m,f[o]=2*(s-c)/u*g/m}d[1]=2*t.pixelRatio/(a[3]-a[1]),d[0]=d[1]*(a[3]-a[1])/(a[2]-a[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=f,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),g.update=function(t){var e,r,n,a,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],h=[-1/0],f=l[o];for(e=0;e<f.length;++e){var p=f[e],d=p.x,g=p.text,v=p.font||"sans-serif";a=p.fontSize||12;for(var m=1/(c[o+2]-c[o]),y=c[o],x=g.split("\n"),b=0;b<x.length;b++)for(n=i(v,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*a,-n[r+1]*a-b*a*1.2,(d-y)*m);u.push(Math.floor(s.length/3)),h.push(d)}this.tickOffset[o]=u,this.tickX[o]=h}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=i(t.labelFont[o],t.labels[o],{textAlign:"center"}).data,a=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*a,-n[e+1]*a,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=i(t.titleFont,t.title).data,a=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*a,-n[e+1]*a,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},g.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{"./shaders":287,"binary-search-bounds":289,"gl-buffer":244,"gl-shader":304,"text-cache":534}],289:[function(t,e,r){arguments[4][113][0].apply(r,arguments)},{dup:113}],290:[function(t,e,r){"use strict";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=a(c),c.text=i(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t("gl-select-static"),a=t("./lib/grid"),i=t("./lib/text"),o=t("./lib/line"),s=t("./lib/box");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function h(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,a=this.pixelRatio,i=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),i.draw();var h=this.zeroLineEnable,f=this.zeroLineColor,p=this.zeroLineWidth;if(h[0]||h[1]){o.bind();for(var d=0;d<2;++d)if(h[d]&&n[d]<=0&&n[d+2]>=0){var g=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(g,e[1],g,e[3],p[d],f[d]):o.drawLine(e[0],g,e[2],g,p[d],f[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var v=this.borderLineEnable,m=this.borderLineWidth,y=this.borderLineColor;for(v[1]&&o.drawLine(r[0],r[1]-.5*m[1]*a,r[0],r[3]+.5*m[3]*a,m[1],y[1]),v[0]&&o.drawLine(r[0]-.5*m[0]*a,r[1],r[2]+.5*m[2]*a,r[1],m[0],y[0]),v[3]&&o.drawLine(r[2],r[1]-.5*m[1]*a,r[2],r[3]+.5*m[3]*a,m[3],y[3]),v[2]&&o.drawLine(r[0]-.5*m[0]*a,r[3],r[2]+.5*m[2]*a,r[3],m[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl,this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,a=this.viewBox,i=0|Math.round((t-a[0]/r)*n),o=0|Math.round((e-a[1]/r)*n),s=this.pickBuffer.query(i,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var h=c[u].pick(i,o,l);if(h)return h}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,a=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/a,10,10/a]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!("titleEnable"in t&&!t.titleEnable),this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var i=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=i[s].slice(0);0!==l.length&&(l.sort(h),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:i}),this.text.update({bounds:o,ticks:i,labels:t.labels||["x","y"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||["sans-serif","sans-serif"],title:t.title||"",titleSize:t.titleSize||18,titleFont:t.titleFont||"sans-serif"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{"./lib/box":284,"./lib/grid":285,"./lib/line":286,"./lib/text":288,"gl-select-static":303}],291:[function(t,e,r){"use strict";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];"distanceLimits"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);"zoomMin"in e&&(r[0]=e.zoomMin);"zoomMax"in e&&(r[1]=e.zoomMax);var c=a({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||"orbit",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],h=0,f=t.clientWidth,p=t.clientHeight,d={keyBindingMode:"rotate",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&"orthographic"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,a=e-2*r;c.idle(e-r),c.recalcMatrix(a),c.flush(e-(100+2*r));for(var i=!0,o=c.computedMatrix,s=0;s<16;++s)i=i&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===f&&t.clientHeight===p;return f=t.clientWidth,p=t.clientHeight,i?!l:(h=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),a=c.computedCenter.slice();if(c.setMode(t),"turntable"===t){var i=n();c._active.lookAt(i,r,a,e),c._active.lookAt(i+500,r,a,[0,0,1]),c._active.flush(i)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return h},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener("contextmenu",function(t){return t.preventDefault(),!1}),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,a,i){var o=d.keyBindingMode;if(!1!==o){var s="rotate"===o,l="pan"===o,u="zoom"===o,f=!!i.control,p=!!i.alt,g=!!i.shift,v=!!(1&e),m=!!(2&e),y=!!(4&e),x=1/t.clientHeight,b=x*(r-d._lastX),_=x*(a-d._lastY),w=d.flipX?1:-1,k=d.flipY?1:-1,T=Math.PI*d.rotateSpeed,M=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&v&&!f&&!p&&!g||v&&!f&&!p&&g)&&c.rotate(M,w*T*b,-k*T*_,0),(l&&v&&!f&&!p&&!g||m||v&&f&&!p&&!g)&&c.pan(M,-d.translateSpeed*b*h,d.translateSpeed*_*h,0),u&&v&&!f&&!p&&!g||y||v&&!f&&p&&!g)){var A=-d.zoomSpeed*_/window.innerHeight*(M-c.lastT())*100;c.pan(M,0,0,h*(Math.exp(A)-1))}return d._lastX=r,d._lastY=a,d._lastMods=i,!0}}d.mouseListener=i(t,e),t.addEventListener("touchstart",function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener("touchmove",function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener("touchend",function(t){e(0,d._lastX,d._lastY,d._lastMods),t.preventDefault()},!!l&&{passive:!1}),d.wheelListener=o(t,function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,a=d.flipY?1:-1,i=n();if(Math.abs(t)>Math.abs(e))c.rotate(i,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*a*e/window.innerHeight*(i-c.lastT())/20;c.pan(i,0,0,h*(Math.exp(o)-1))}}},!0)},d.enableMouseListeners(),d};var n=t("right-now"),a=t("3d-view"),i=t("mouse-change"),o=t("mouse-wheel"),s=t("mouse-event-offset"),l=t("has-passive-events")},{"3d-view":54,"has-passive-events":412,"mouse-change":436,"mouse-event-offset":437,"mouse-wheel":439,"right-now":502}],292:[function(t,e,r){var n=t("glslify"),a=t("gl-shader"),i=n(["precision mediump float;\n#define GLSLIFY 1\nattribute vec2 position;\nvarying vec2 uv;\nvoid main() {\n  uv = position;\n  gl_Position = vec4(position, 0, 1);\n}"]),o=n(["precision mediump float;\n#define GLSLIFY 1\n\nuniform sampler2D accumBuffer;\nvarying vec2 uv;\n\nvoid main() {\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\n  gl_FragColor = min(vec4(1,1,1,1), accum);\n}"]);e.exports=function(t){return a(t,i,o,null,[{name:"position",type:"vec2"}])}},{"gl-shader":304,glslify:410}],293:[function(t,e,r){"use strict";var n=t("./camera.js"),a=t("gl-axes3d"),i=t("gl-axes3d/properties"),o=t("gl-spikes3d"),s=t("gl-select-static"),l=t("gl-fbo"),c=t("a-big-triangle"),u=t("mouse-change"),h=t("gl-mat4/perspective"),f=t("gl-mat4/ortho"),p=t("./lib/shader"),d=t("is-mobile")({tablet:!0,featureDetect:!0});function g(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function v(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function m(t){return"boolean"!=typeof t||t}e.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;if(!e)if(e=document.createElement("canvas"),t.container){var r=t.container;r.appendChild(e)}else document.body.appendChild(e);var y=t.gl;y||(t.glOptions&&(d=!!t.glOptions.preserveDrawingBuffer),y=function(t,e){var r=null;try{(r=t.getContext("webgl",e))||(r=t.getContext("experimental-webgl",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:d}));if(!y)throw new Error("webgl not supported");var x=t.bounds||[[-10,-10,-10],[10,10,10]],b=new g,_=l(y,y.drawingBufferWidth,y.drawingBufferHeight,{preferFloat:!d}),w=p(y),k=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&"orthographic"===t.camera.projection.type||!1,T={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||"turntable",_ortho:k},M=t.axes||{},A=a(y,M);A.enable=!M.disable;var S=t.spikes||{},E=o(y,S),L=[],C=[],P=[],O=[],z=!0,I=!0,D=new Array(16),R=new Array(16),F={view:null,projection:D,model:R,_ortho:!1},I=!0,B=[y.drawingBufferWidth,y.drawingBufferHeight],N=t.cameraObject||n(e,T),j={gl:y,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:b,camera:N,axes:A,axesPixels:null,spikes:E,bounds:x,objects:L,shape:B,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:m(t.autoResize),autoBounds:m(t.autoBounds),autoScale:!!t.autoScale,autoCenter:m(t.autoCenter),clipToBounds:m(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:F,oncontextloss:null,mouseListener:null,_stopped:!1,getAspectratio:function(){return{x:this.aspect[0],y:this.aspect[1],z:this.aspect[2]}},setAspectratio:function(t){this.aspect[0]=t.x,this.aspect[1]=t.y,this.aspect[2]=t.z,I=!0},setBounds:function(t,e){this.bounds[0][t]=e.min,this.bounds[1][t]=e.max},setClearColor:function(t){this.clearColor=t},clearRGBA:function(){this.gl.clearColor(this.clearColor[0],this.clearColor[1],this.clearColor[2],this.clearColor[3]),this.gl.clear(this.gl.COLOR_BUFFER_BIT|this.gl.DEPTH_BUFFER_BIT)}},V=[y.drawingBufferWidth/j.pixelRatio|0,y.drawingBufferHeight/j.pixelRatio|0];function U(){if(!j._stopped&&j.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var a=0|Math.ceil(r*j.pixelRatio),i=0|Math.ceil(n*j.pixelRatio);if(a!==e.width||i!==e.height){e.width=a,e.height=i;var o=e.style;o.position=o.position||"absolute",o.left="0px",o.top="0px",o.width=r+"px",o.height=n+"px",z=!0}}}j.autoResize&&U();function q(){for(var t=L.length,e=O.length,r=0;r<e;++r)P[r]=0;t:for(var r=0;r<t;++r){var n=L[r],a=n.pickSlots;if(a){for(var i=0;i<e;++i)if(P[i]+a<255){C[r]=i,n.setPickBase(P[i]+1),P[i]+=a;continue t}var o=s(y,B);C[r]=e,O.push(o),P.push(a),n.setPickBase(1),e+=1}else C[r]=-1}for(;e>0&&0===P[e-1];)P.pop(),O.pop().dispose()}function H(){if(j.contextLost)return!0;y.isContextLost()&&(j.contextLost=!0,j.mouseListener.enabled=!1,j.selection.object=null,j.oncontextloss&&j.oncontextloss())}window.addEventListener("resize",U),j.update=function(t){j._stopped||(t=t||{},z=!0,I=!0)},j.add=function(t){j._stopped||(t.axes=A,L.push(t),C.push(-1),z=!0,I=!0,q())},j.remove=function(t){if(!j._stopped){var e=L.indexOf(t);e<0||(L.splice(e,1),C.pop(),z=!0,I=!0,q())}},j.dispose=function(){if(!j._stopped&&(j._stopped=!0,window.removeEventListener("resize",U),e.removeEventListener("webglcontextlost",H),j.mouseListener.enabled=!1,!j.contextLost)){A.dispose(),E.dispose();for(var t=0;t<L.length;++t)L[t].dispose();_.dispose();for(var t=0;t<O.length;++t)O[t].dispose();w.dispose(),y=null,A=null,E=null,L=[]}},j._mouseRotating=!1,j._prevButtons=0,j.enableMouseListeners=function(){j.mouseListener=u(e,function(t,e,r){if(!j._stopped){var n=O.length,a=L.length,i=b.object;b.distance=1/0,b.mouse[0]=e,b.mouse[1]=r,b.object=null,b.screen=null,b.dataCoordinate=b.dataPosition=null;var o=!1;if(t&&j._prevButtons)j._mouseRotating=!0;else{j._mouseRotating&&(I=!0),j._mouseRotating=!1;for(var s=0;s<n;++s){var l=O[s].query(e,V[1]-r-1,j.pickRadius);if(l){if(l.distance>b.distance)continue;for(var c=0;c<a;++c){var u=L[c];if(C[c]===s){var h=u.pick(l);h&&(b.buttons=t,b.screen=l.coord,b.distance=l.distance,b.object=u,b.index=h.distance,b.dataPosition=h.position,b.dataCoordinate=h.dataCoordinate,b.data=h,o=!0)}}}}}i&&i!==b.object&&(i.highlight&&i.highlight(null),z=!0),b.object&&(b.object.highlight&&b.object.highlight(b.data),z=!0),(o=o||b.object!==i)&&j.onselect&&j.onselect(b),1&t&&!(1&j._prevButtons)&&j.onclick&&j.onclick(b),j._prevButtons=t}})},e.addEventListener("webglcontextlost",H);var G=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],Y=[G[0].slice(),G[1].slice()];function W(){if(!H()){U();var t=j.camera.tick();F.view=j.camera.matrix,z=z||t,I=I||t,A.pixelRatio=j.pixelRatio,E.pixelRatio=j.pixelRatio;var e=L.length,r=G[0],n=G[1];r[0]=r[1]=r[2]=1/0,n[0]=n[1]=n[2]=-1/0;for(var a=0;a<e;++a){var o=L[a];o.pixelRatio=j.pixelRatio,o.axes=j.axes,z=z||!!o.dirty,I=I||!!o.dirty;var s=o.bounds;if(s)for(var l=s[0],u=s[1],p=0;p<3;++p)r[p]=Math.min(r[p],l[p]),n[p]=Math.max(n[p],u[p])}var d=j.bounds;if(j.autoBounds)for(var p=0;p<3;++p){if(n[p]<r[p])r[p]=-1,n[p]=1;else{r[p]===n[p]&&(r[p]-=1,n[p]+=1);var g=.05*(n[p]-r[p]);r[p]=r[p]-g,n[p]=n[p]+g}d[0][p]=r[p],d[1][p]=n[p]}for(var m=!1,p=0;p<3;++p)m=m||Y[0][p]!==d[0][p]||Y[1][p]!==d[1][p],Y[0][p]=d[0][p],Y[1][p]=d[1][p];if(I=I||m,z=z||m){if(m){for(var x=[0,0,0],a=0;a<3;++a)x[a]=v((d[1][a]-d[0][a])/10);A.autoTicks?A.update({bounds:d,tickSpacing:x}):A.update({bounds:d})}var T=y.drawingBufferWidth,M=y.drawingBufferHeight;B[0]=T,B[1]=M,V[0]=0|Math.max(T/j.pixelRatio,1),V[1]=0|Math.max(M/j.pixelRatio,1),function(t,e){var r=t.bounds,n=t.cameraParams,a=n.projection,i=n.model,o=t.gl.drawingBufferWidth,s=t.gl.drawingBufferHeight,l=t.zNear,c=t.zFar,u=t.fovy,p=o/s;e?(f(a,-p,p,-1,1,l,c),n._ortho=!0):(h(a,u,p,l,c),n._ortho=!1);for(var d=0;d<16;++d)i[d]=0;i[15]=1;for(var g=0,d=0;d<3;++d)g=Math.max(g,r[1][d]-r[0][d]);for(var d=0;d<3;++d)t.autoScale?i[5*d]=t.aspect[d]/(r[1][d]-r[0][d]):i[5*d]=1/g,t.autoCenter&&(i[12+d]=.5*-i[5*d]*(r[0][d]+r[1][d]))}(j,k);for(var a=0;a<e;++a){var o=L[a];o.axesBounds=d,j.clipToBounds&&(o.clipBounds=d)}b.object&&(j.snapToData?E.position=b.dataCoordinate:E.position=b.dataPosition,E.bounds=d),I&&(I=!1,function(){if(H())return;y.colorMask(!0,!0,!0,!0),y.depthMask(!0),y.disable(y.BLEND),y.enable(y.DEPTH_TEST),y.depthFunc(y.LEQUAL);for(var t=L.length,e=O.length,r=0;r<e;++r){var n=O[r];n.shape=V,n.begin();for(var a=0;a<t;++a)if(C[a]===r){var i=L[a];i.drawPick&&(i.pixelRatio=1,i.drawPick(F))}n.end()}}()),j.axesPixels=i(j.axes,F,T,M),j.onrender&&j.onrender(),y.bindFramebuffer(y.FRAMEBUFFER,null),y.viewport(0,0,T,M),j.clearRGBA(),y.depthMask(!0),y.colorMask(!0,!0,!0,!0),y.enable(y.DEPTH_TEST),y.depthFunc(y.LEQUAL),y.disable(y.BLEND),y.disable(y.CULL_FACE);var S=!1;A.enable&&(S=S||A.isTransparent(),A.draw(F)),E.axes=A,b.object&&E.draw(F),y.disable(y.CULL_FACE);for(var a=0;a<e;++a){var o=L[a];o.axes=A,o.pixelRatio=j.pixelRatio,o.isOpaque&&o.isOpaque()&&o.draw(F),o.isTransparent&&o.isTransparent()&&(S=!0)}if(S){_.shape=B,_.bind(),y.clear(y.DEPTH_BUFFER_BIT),y.colorMask(!1,!1,!1,!1),y.depthMask(!0),y.depthFunc(y.LESS),A.enable&&A.isTransparent()&&A.drawTransparent(F);for(var a=0;a<e;++a){var o=L[a];o.isOpaque&&o.isOpaque()&&o.draw(F)}y.enable(y.BLEND),y.blendEquation(y.FUNC_ADD),y.blendFunc(y.ONE,y.ONE_MINUS_SRC_ALPHA),y.colorMask(!0,!0,!0,!0),y.depthMask(!1),y.clearColor(0,0,0,0),y.clear(y.COLOR_BUFFER_BIT),A.isTransparent()&&A.drawTransparent(F);for(var a=0;a<e;++a){var o=L[a];o.isTransparent&&o.isTransparent()&&o.drawTransparent(F)}y.bindFramebuffer(y.FRAMEBUFFER,null),y.blendFunc(y.ONE,y.ONE_MINUS_SRC_ALPHA),y.disable(y.DEPTH_TEST),w.bind(),_.color[0].bind(0),w.uniforms.accumBuffer=0,c(y),y.disable(y.BLEND)}z=!1;for(var a=0;a<e;++a)L[a].dirty=!1}}}return j.enableMouseListeners(),function t(){j._stopped||j.contextLost||(W(),requestAnimationFrame(t))}(),j.redraw=function(){j._stopped||(z=!0,W())},j},createCamera:n}},{"./camera.js":291,"./lib/shader":292,"a-big-triangle":62,"gl-axes3d":236,"gl-axes3d/properties":243,"gl-fbo":252,"gl-mat4/ortho":271,"gl-mat4/perspective":272,"gl-select-static":303,"gl-spikes3d":313,"is-mobile":421,"mouse-change":436}],294:[function(t,e,r){var n=t("glslify");r.pointVertex=n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec2 position;\n\nuniform mat3 matrix;\nuniform float pointSize;\nuniform float pointCloud;\n\nhighp float rand(vec2 co) {\n  highp float a = 12.9898;\n  highp float b = 78.233;\n  highp float c = 43758.5453;\n  highp float d = dot(co.xy, vec2(a, b));\n  highp float e = mod(d, 3.14);\n  return fract(sin(e) * c);\n}\n\nvoid main() {\n  vec3 hgPosition = matrix * vec3(position, 1);\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\n    // if we don't jitter the point size a bit, overall point cloud\n    // saturation 'jumps' on zooming, which is disturbing and confusing\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\n  if(pointCloud != 0.0) { // pointCloud is truthy\n    // get the same square surface as circle would be\n    gl_PointSize *= 0.886;\n  }\n}"]),r.pointFragment=n(["precision mediump float;\n#define GLSLIFY 1\n\nuniform vec4 color, borderColor;\nuniform float centerFraction;\nuniform float pointCloud;\n\nvoid main() {\n  float radius;\n  vec4 baseColor;\n  if(pointCloud != 0.0) { // pointCloud is truthy\n    if(centerFraction == 1.0) {\n      gl_FragColor = color;\n    } else {\n      gl_FragColor = mix(borderColor, color, centerFraction);\n    }\n  } else {\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\n    if(radius > 1.0) {\n      discard;\n    }\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\n  }\n}\n"]),r.pickVertex=n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec2 position;\nattribute vec4 pickId;\n\nuniform mat3 matrix;\nuniform float pointSize;\nuniform vec4 pickOffset;\n\nvarying vec4 fragId;\n\nvoid main() {\n  vec3 hgPosition = matrix * vec3(position, 1);\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\n  gl_PointSize = pointSize;\n\n  vec4 id = pickId + pickOffset;\n  id.y += floor(id.x / 256.0);\n  id.x -= floor(id.x / 256.0) * 256.0;\n\n  id.z += floor(id.y / 256.0);\n  id.y -= floor(id.y / 256.0) * 256.0;\n\n  id.w += floor(id.z / 256.0);\n  id.z -= floor(id.z / 256.0) * 256.0;\n\n  fragId = id;\n}\n"]),r.pickFragment=n(["precision mediump float;\n#define GLSLIFY 1\n\nvarying vec4 fragId;\n\nvoid main() {\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\n  if(radius > 1.0) {\n    discard;\n  }\n  gl_FragColor = fragId / 255.0;\n}\n"])},{glslify:410}],295:[function(t,e,r){"use strict";var n=t("gl-shader"),a=t("gl-buffer"),i=t("typedarray-pool"),o=t("./lib/shader");function s(t,e,r,n,a){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=a,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,i=a(r),l=a(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),h=new s(t,i,l,c,u);return h.update(e),t.addObject(h),h};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r("sizeMin",.5),this.sizeMax=r("sizeMax",20),this.color=r("color",[1,0,0,1]).slice(),this.areaRatio=r("areaRatio",1),this.borderColor=r("borderColor",[0,0,0,1]).slice(),this.blend=r("blend",!1);var n=t.positions.length>>>1,a=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=a?s:i.mallocFloat32(s.length),c=o?t.idToIndex:i.mallocInt32(n);if(a||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),a||i.free(l),o||i.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,a=this.plot.dataBox;if(0===this.pointCount)return t;var i=a[2]-a[0],o=a[3]-a[1],s=function(t,e){var r,n=0,a=t.length>>>1;for(r=0;r<a;r++){var i=t[2*r],o=t[2*r+1];i>=e[0]&&i<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,a),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/i,l[4]=2/o,l[6]=-2*a[0]/i-1,l[7]=-2*a[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var h=n.getParameter(n.BLEND),f=n.getParameter(n.DITHER);return h&&!this.blend&&n.disable(n.BLEND),f&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),h&&!this.blend&&n.enable(n.BLEND),f&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,a=this.pointCount;if(r<n||r>=n+a)return null;var i=r-n,o=this.points;return{object:this,pointId:i,dataCoord:[o[2*i],o[2*i+1]]}}},{"./lib/shader":294,"gl-buffer":244,"gl-shader":304,"typedarray-pool":543}],296:[function(t,e,r){e.exports=function(t,e,r,n){var a,i,o,s,l,c=e[0],u=e[1],h=e[2],f=e[3],p=r[0],d=r[1],g=r[2],v=r[3];(i=c*p+u*d+h*g+f*v)<0&&(i=-i,p=-p,d=-d,g=-g,v=-v);1-i>1e-6?(a=Math.acos(i),o=Math.sin(a),s=Math.sin((1-n)*a)/o,l=Math.sin(n*a)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*h+l*g,t[3]=s*f+l*v,t}},{}],297:[function(t,e,r){"use strict";e.exports=function(t){return t||0===t?t.toString():""}},{}],298:[function(t,e,r){"use strict";var n=t("vectorize-text");e.exports=function(t,e,r){var i=a[e];i||(i=a[e]={});if(t in i)return i[t];var o={textAlign:"center",textBaseline:"middle",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},s=n(t,o);o.triangles=!1;var l,c,u=n(t,o);if(r&&1!==r){for(l=0;l<s.positions.length;++l)for(c=0;c<s.positions[l].length;++c)s.positions[l][c]/=r;for(l=0;l<u.positions.length;++l)for(c=0;c<u.positions[l].length;++c)u.positions[l][c]/=r}var h=[[1/0,1/0],[-1/0,-1/0]],f=u.positions.length;for(l=0;l<f;++l){var p=u.positions[l];for(c=0;c<2;++c)h[0][c]=Math.min(h[0][c],p[c]),h[1][c]=Math.max(h[1][c],p[c])}return i[t]=[s,u,h]};var a={}},{"vectorize-text":548}],299:[function(t,e,r){var n=t("gl-shader"),a=t("glslify"),i=a(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nattribute vec3 position;\nattribute vec4 color;\nattribute vec2 glyph;\nattribute vec4 id;\n\nuniform vec4 highlightId;\nuniform float highlightScale;\nuniform mat4 model, view, projection;\nuniform vec3 clipBounds[2];\n\nvarying vec4 interpColor;\nvarying vec4 pickId;\nvarying vec3 dataCoordinate;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\n\n    gl_Position = vec4(0,0,0,0);\n  } else {\n    float scale = 1.0;\n    if(distance(highlightId, id) < 0.0001) {\n      scale = highlightScale;\n    }\n\n    vec4 worldPosition = model * vec4(position, 1);\n    vec4 viewPosition = view * worldPosition;\n    viewPosition = viewPosition / viewPosition.w;\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\n\n    gl_Position = clipPosition;\n    interpColor = color;\n    pickId = id;\n    dataCoordinate = position;\n  }\n}"]),o=a(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nattribute vec3 position;\nattribute vec4 color;\nattribute vec2 glyph;\nattribute vec4 id;\n\nuniform mat4 model, view, projection;\nuniform vec2 screenSize;\nuniform vec3 clipBounds[2];\nuniform float highlightScale, pixelRatio;\nuniform vec4 highlightId;\n\nvarying vec4 interpColor;\nvarying vec4 pickId;\nvarying vec3 dataCoordinate;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\n\n    gl_Position = vec4(0,0,0,0);\n  } else {\n    float scale = pixelRatio;\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\n      scale *= highlightScale;\n    }\n\n    vec4 worldPosition = model * vec4(position, 1.0);\n    vec4 viewPosition = view * worldPosition;\n    vec4 clipPosition = projection * viewPosition;\n    clipPosition /= clipPosition.w;\n\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\n    interpColor = color;\n    pickId = id;\n    dataCoordinate = position;\n  }\n}"]),s=a(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nattribute vec3 position;\nattribute vec4 color;\nattribute vec2 glyph;\nattribute vec4 id;\n\nuniform float highlightScale;\nuniform vec4 highlightId;\nuniform vec3 axes[2];\nuniform mat4 model, view, projection;\nuniform vec2 screenSize;\nuniform vec3 clipBounds[2];\nuniform float scale, pixelRatio;\n\nvarying vec4 interpColor;\nvarying vec4 pickId;\nvarying vec3 dataCoordinate;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\n\n    gl_Position = vec4(0,0,0,0);\n  } else {\n    float lscale = pixelRatio * scale;\n    if(distance(highlightId, id) < 0.0001) {\n      lscale *= highlightScale;\n    }\n\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\n\n    gl_Position = clipPosition;\n    interpColor = color;\n    pickId = id;\n    dataCoordinate = dataPosition;\n  }\n}\n"]),l=a(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3 fragClipBounds[2];\nuniform float opacity;\n\nvarying vec4 interpColor;\nvarying vec3 dataCoordinate;\n\nvoid main() {\n  if (\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\n    interpColor.a * opacity == 0.\n  ) discard;\n  gl_FragColor = interpColor * opacity;\n}\n"]),c=a(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3 fragClipBounds[2];\nuniform float pickGroup;\n\nvarying vec4 pickId;\nvarying vec3 dataCoordinate;\n\nvoid main() {\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\n\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\n}"]),u=[{name:"position",type:"vec3"},{name:"color",type:"vec4"},{name:"glyph",type:"vec2"},{name:"id",type:"vec4"}],h={vertex:i,fragment:l,attributes:u},f={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:i,fragment:c,attributes:u},g={vertex:o,fragment:c,attributes:u},v={vertex:s,fragment:c,attributes:u};function m(t,e){var r=n(t,e),a=r.attributes;return a.position.location=0,a.color.location=1,a.glyph.location=2,a.id.location=3,r}r.createPerspective=function(t){return m(t,h)},r.createOrtho=function(t){return m(t,f)},r.createProject=function(t){return m(t,p)},r.createPickPerspective=function(t){return m(t,d)},r.createPickOrtho=function(t){return m(t,g)},r.createPickProject=function(t){return m(t,v)}},{"gl-shader":304,glslify:410}],300:[function(t,e,r){"use strict";var n=t("is-string-blank"),a=t("gl-buffer"),i=t("gl-vao"),o=t("typedarray-pool"),s=t("gl-mat4/multiply"),l=t("./lib/shaders"),c=t("./lib/glyphs"),u=t("./lib/get-simple-string"),h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function f(t,e){var r=t[0],n=t[1],a=t[2],i=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*a+e[12]*i,t[1]=e[1]*r+e[5]*n+e[9]*a+e[13]*i,t[2]=e[2]*r+e[6]*n+e[10]*a+e[14]*i,t[3]=e[3]*r+e[7]*n+e[11]*a+e[15]*i,t}function p(t,e,r,n){return f(n,n),f(n,n),f(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}function g(t){return!0===t?1:t>1?1:t}function v(t,e,r,n,a,i,o,s,l,c,u,h){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=a,this.colorBuffer=i,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=h,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),h=a(e),f=a(e),p=a(e),d=a(e),g=i(e,[{buffer:h,size:3,type:e.FLOAT},{buffer:f,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),m=new v(e,r,n,o,h,f,p,d,g,s,c,u);return m.update(t),m};var m=v.prototype;m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},m.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var y=[0,0],x=[0,0,0],b=[0,0,0],_=[0,0,0,1],w=[0,0,0,1],k=h.slice(),T=[0,0,0],M=[[0,0,0],[0,0,0]];function A(t){return t[0]=t[1]=t[2]=0,t}function S(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function L(t,e,r,n){var a,i=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||h,u=r.view||h,f=r.projection||h,d=e.axesBounds,g=function(t){for(var e=M,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);a=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],y[0]=2/o.drawingBufferWidth,y[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=f,l.screenSize=y,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=g,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var v=0;v<3;++v)if(i[v]){l.scale=e.projectScale[v],l.opacity=e.projectOpacity[v];for(var m=k,L=0;L<16;++L)m[L]=0;for(L=0;L<4;++L)m[5*L]=1;m[5*v]=0,a[v]<0?m[12+v]=d[0][v]:m[12+v]=d[1][v],s(m,c,m),l.model=m;var C=(v+1)%3,P=(v+2)%3,O=A(x),z=A(b);O[C]=1,z[P]=1;var I=p(0,0,0,S(_,O)),D=p(0,0,0,S(w,z));if(Math.abs(I[1])>Math.abs(D[1])){var R=I;I=D,D=R,R=O,O=z,z=R;var F=C;C=P,P=F}I[0]<0&&(O[C]=-1),D[1]>0&&(z[P]=-1);var B=0,N=0;for(L=0;L<4;++L)B+=Math.pow(c[4*C+L],2),N+=Math.pow(c[4*P+L],2);O[C]/=Math.sqrt(B),z[P]/=Math.sqrt(N),l.axes[0]=O,l.axes[1]=z,l.fragClipBounds[0]=E(T,g[0],v,-1e8),l.fragClipBounds[1]=E(T,g[1],v,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var C=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function P(t,e,r,n,a,i,o){var s=r.gl;if((i===r.projectHasAlpha||o)&&L(e,r,n,a),i===r.hasAlpha||o){t.bind();var l=t.uniforms;l.model=n.model||h,l.view=n.view||h,l.projection=n.projection||h,y[0]=2/s.drawingBufferWidth,y[1]=2/s.drawingBufferHeight,l.screenSize=y,l.highlightId=r.highlightId,l.highlightScale=r.highlightScale,l.fragClipBounds=C,l.clipBounds=r.axes.bounds,l.opacity=r.opacity,l.pickGroup=r.pickId/255,l.pixelRatio=a,r.vao.bind(),r.vao.draw(s.TRIANGLES,r.vertexCount),r.lineWidth>0&&(s.lineWidth(r.lineWidth*a),r.vao.draw(s.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function O(t,e,r,a){var i;i=Array.isArray(t)?e<t.length?t[e]:void 0:t,i=u(i);var o=!0;n(i)&&(i="\u25bc",o=!1);var s=c(i,r,a);return{mesh:s[0],lines:s[1],bounds:s[2],visible:o}}m.draw=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},m.drawTransparent=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},m.drawPick=function(t){P(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var a=0;a<3;++a)n.position[a]=n.dataCoordinate[a]=r[a];return n},m.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,a=e>>16&255;this.highlightId=[r/255,n/255,a/255,0]}else this.highlightId=[1,1,1,1]},m.update=function(t){if("perspective"in(t=t||{})&&(this.useOrtho=!t.perspective),"orthographic"in t&&(this.useOrtho=!!t.orthographic),"lineWidth"in t&&(this.lineWidth=t.lineWidth),"project"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if("projectScale"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,"projectOpacity"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=g(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,"opacity"in t&&(this.opacity=g(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var a,i,s=t.position,l=t.font||"normal",c=t.alignment||[0,0];if(2===c.length)a=c[0],i=c[1];else{a=[],i=[];for(n=0;n<c.length;++n)a[n]=c[n][0],i[n]=c[n][1]}var u=[1/0,1/0,1/0],h=[-1/0,-1/0,-1/0],f=t.glyph,p=t.color,d=t.size,v=t.angle,m=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],k=0;k<3;++k)if(isNaN(w[k])||!isFinite(w[k]))continue t;var T=(N=O(f,n,l,this.pixelRatio)).mesh,M=N.lines,A=N.bounds;x+=3*T.cells.length,b+=2*M.edges.length}}var S=x+b,E=o.mallocFloat(3*S),L=o.mallocFloat(4*S),C=o.mallocFloat(2*S),P=o.mallocUint32(S);if(S>0){var z=0,I=x,D=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(m)&&Array.isArray(m[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],k=0;k<3;++k){if(isNaN(w[k])||!isFinite(w[k]))continue t;h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k])}T=(N=O(f,n,l,this.pixelRatio)).mesh,M=N.lines,A=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(V=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(k=0;k<3;++k)D[k]=V[k];D[3]=1}else if(4===V.length){for(k=0;k<4;++k)D[k]=V[k];!this.hasAlpha&&V[3]<1&&(this.hasAlpha=!0)}}else D[0]=D[1]=D[2]=0,D[3]=1;else D=[1,1,1,0];if(j)if(Array.isArray(m)){var V;if(3===(V=B?n<m.length?m[n]:[0,0,0,0]:m).length){for(k=0;k<3;++k)R[k]=V[k];R[k]=1}else if(4===V.length){for(k=0;k<4;++k)R[k]=V[k];!this.hasAlpha&&V[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var U=.5;j?Array.isArray(d)?U=n<d.length?+d[n]:12:d?U=+d:this.useOrtho&&(U=12):U=0;var q=0;Array.isArray(v)?q=n<v.length?+v[n]:0:v&&(q=+v);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],k=0;k<3;++k)h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k]);var Y=a,W=i;Y=0;Array.isArray(a)?Y=n<a.length?a[n]:0:a&&(Y=a);W=0;Array.isArray(i)?W=n<i.length?i[n]:0:i&&(W=i);var X=[Y*=Y>0?1-A[0][0]:Y<0?1+A[1][0]:1,W*=W>0?1-A[0][1]:W<0?1+A[1][1]:1],Z=T.cells||[],J=T.positions||[];for(k=0;k<Z.length;++k)for(var K=Z[k],Q=0;Q<3;++Q){for(var $=0;$<3;++$)E[3*z+$]=w[$];for($=0;$<4;++$)L[4*z+$]=D[$];P[z]=y;var tt=J[K[Q]];C[2*z]=U*(H*tt[0]-G*tt[1]+X[0]),C[2*z+1]=U*(G*tt[0]+H*tt[1]+X[1]),z+=1}for(Z=M.edges,J=M.positions,k=0;k<Z.length;++k)for(K=Z[k],Q=0;Q<2;++Q){for($=0;$<3;++$)E[3*I+$]=w[$];for($=0;$<4;++$)L[4*I+$]=R[$];P[I]=y;tt=J[K[Q]];C[2*I]=U*(H*tt[0]-G*tt[1]+X[0]),C[2*I+1]=U*(G*tt[0]+H*tt[1]+X[1]),I+=1}}}this.bounds=[u,h],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(E),this.colorBuffer.update(L),this.glyphBuffer.update(C),this.idBuffer.update(P),o.free(E),o.free(L),o.free(C),o.free(P)},m.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{"./lib/get-simple-string":297,"./lib/glyphs":298,"./lib/shaders":299,"gl-buffer":244,"gl-mat4/multiply":270,"gl-vao":329,"is-string-blank":424,"typedarray-pool":543}],301:[function(t,e,r){"use strict";var n=t("glslify");r.boxVertex=n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec2 vertex;\n\nuniform vec2 cornerA, cornerB;\n\nvoid main() {\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\n}\n"]),r.boxFragment=n(["precision mediump float;\n#define GLSLIFY 1\n\nuniform vec4 color;\n\nvoid main() {\n  gl_FragColor = color;\n}\n"])},{glslify:410}],302:[function(t,e,r){"use strict";var n=t("gl-shader"),a=t("gl-buffer"),i=t("./lib/shaders");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=a(r,[0,0,0,1,1,0,1,1]),l=n(r,i.boxVertex,i.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),a=(this.outerFill,this.outerColor),i=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,h=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],f=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(h=Math.max(h,c[0]),f=Math.max(f,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<h||d<f)){o.bind();var g=s[2]-s[0],v=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,g,f,a),o.drawBox(0,f,h,d,a),o.drawBox(0,d,g,v,a),o.drawBox(p,f,g,d,a)),this.innerFill&&o.drawBox(h,f,p,d,n),r>0){var m=r*u;o.drawBox(h-m,f-m,p+m,f+m,i),o.drawBox(h-m,d-m,p+m,d+m,i),o.drawBox(h-m,f-m,h+m,d+m,i),o.drawBox(p-m,f-m,p+m,d+m,i)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{"./lib/shaders":301,"gl-buffer":244,"gl-shader":304}],303:[function(t,e,r){"use strict";e.exports=function(t,e){var r=e[0],i=e[1],o=n(t,r,i,{}),s=a.mallocUint8(r*i*4);return new c(t,o,s)};var n=t("gl-fbo"),a=t("typedarray-pool"),i=t("ndarray"),o=t("bit-twiddle").nextPow2,s=t("cwise/lib/wrapper")({args:["array",{offset:[0,0,1],array:0},{offset:[0,0,2],array:0},{offset:[0,0,3],array:0},"scalar","scalar","index"],pre:{body:"{this_closestD2=1e8,this_closestX=-1,this_closestY=-1}",args:[],thisVars:["this_closestD2","this_closestX","this_closestY"],localVars:[]},body:{body:"{if(_inline_16_arg0_<255||_inline_16_arg1_<255||_inline_16_arg2_<255||_inline_16_arg3_<255){var _inline_16_l=_inline_16_arg4_-_inline_16_arg6_[0],_inline_16_a=_inline_16_arg5_-_inline_16_arg6_[1],_inline_16_f=_inline_16_l*_inline_16_l+_inline_16_a*_inline_16_a;_inline_16_f<this_closestD2&&(this_closestD2=_inline_16_f,this_closestX=_inline_16_arg6_[0],this_closestY=_inline_16_arg6_[1])}}",args:[{name:"_inline_16_arg0_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_16_arg1_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_16_arg2_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_16_arg3_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_16_arg4_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_16_arg5_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_16_arg6_",lvalue:!1,rvalue:!0,count:4}],thisVars:["this_closestD2","this_closestX","this_closestY"],localVars:["_inline_16_a","_inline_16_f","_inline_16_l"]},post:{body:"{return[this_closestX,this_closestY,this_closestD2]}",args:[],thisVars:["this_closestD2","this_closestX","this_closestY"],localVars:[]},debug:!1,funcName:"cwise",blockSize:64});function l(t,e,r,n,a){this.coord=[t,e],this.id=r,this.value=n,this.distance=a}function c(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var u=c.prototype;Object.defineProperty(u,"shape",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){a.free(this.buffer);for(var n=this.buffer=a.mallocUint8(o(r*e*4)),i=0;i<r*e*4;++i)n[i]=255}return t}}}),u.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},u.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},u.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,"number"!=typeof r&&(r=1);var a=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),c=0|Math.min(Math.max(e-r,0),n[1]),u=0|Math.min(Math.max(e+r,0),n[1]);if(o<=a||u<=c)return null;var h=[o-a,u-c],f=i(this.buffer,[h[0],h[1],4],[4,4*n[0],1],4*(a+n[0]*c)),p=s(f.hi(h[0],h[1],1),r,r),d=p[0],g=p[1];return d<0||Math.pow(this.radius,2)<p[2]?null:new l(d+a|0,g+c|0,f.get(d,g,0),[f.get(d,g,1),f.get(d,g,2),f.get(d,g,3)],Math.sqrt(p[2]))},u.dispose=function(){this.gl&&(this.fbo.dispose(),a.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{"bit-twiddle":94,"cwise/lib/wrapper":151,"gl-fbo":252,ndarray:451,"typedarray-pool":543}],304:[function(t,e,r){"use strict";var n=t("./lib/create-uniforms"),a=t("./lib/create-attributes"),i=t("./lib/reflect"),o=t("./lib/shader-cache"),s=t("./lib/runtime-reflect"),l=t("./lib/GLError");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function h(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var f=this,p=f.gl,d=f._vref;f._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),f.vertShader=f._vref.shader;var g=this._fref;if(f._fref=o.shader(p,p.FRAGMENT_SHADER,e),g&&g.dispose(),f.fragShader=f._fref.shader,!r||!c){var v=p.createProgram();if(p.attachShader(v,f.fragShader),p.attachShader(v,f.vertShader),p.linkProgram(v),!p.getProgramParameter(v,p.LINK_STATUS)){var m=p.getProgramInfoLog(v);throw new l(m,"Error linking program:"+m)}r=r||s.uniforms(p,v),c=c||s.attributes(p,v),p.deleteProgram(v)}(c=c.slice()).sort(h);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf("mat")>=0){for(var k=0|w.type.charAt(w.type.length-1),T=new Array(k),M=0;M<k;++M)T[M]=_.length,b.push(w.name+"["+M+"]"),"number"==typeof w.location?_.push(w.location+M):Array.isArray(w.location)&&w.location.length===k&&"number"==typeof w.location[M]?_.push(0|w.location[M]):_.push(-1);x.push({name:w.name,type:w.type,locations:T})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),"number"==typeof w.location?_.push(0|w.location):_.push(-1)}var A=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(A)>=0;)A+=1;_[y]=A}var S=new Array(r.length);function E(){f.program=o.program(p,f._vref,f._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(f.program,r[t].name)}E(),f._relink=E,f.types={uniforms:i(r),attributes:i(c)},f.attributes=a(p,f,x,_),Object.defineProperty(f,"uniforms",n(p,f,r,S))},e.exports=function(t,e,r,n,a){var i=new c(t);return i.update(e,r,n,a),i}},{"./lib/GLError":305,"./lib/create-attributes":306,"./lib/create-uniforms":307,"./lib/reflect":308,"./lib/runtime-reflect":309,"./lib/shader-cache":310}],305:[function(t,e,r){function n(t,e,r){this.shortMessage=e||"",this.longMessage=r||"",this.rawError=t||"",this.message="gl-shader: "+(e||t||"")+(r?"\n"+r:""),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name="GLError",n.prototype.constructor=n,e.exports=n},{}],306:[function(t,e,r){"use strict";e.exports=function(t,e,r,a){for(var i={},l=0,c=r.length;l<c;++l){var u=r[l],h=u.name,f=u.type,p=u.locations;switch(f){case"bool":case"int":case"float":o(t,e,p[0],a,1,i,h);break;default:if(f.indexOf("vec")>=0){var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n("","Invalid data type for attribute "+h+": "+f);o(t,e,p[0],a,d,i,h)}else{if(!(f.indexOf("mat")>=0))throw new n("","Unknown data type for attribute "+h+": "+f);var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n("","Invalid data type for attribute "+h+": "+f);s(t,e,p,a,d,i,h)}}}return i};var n=t("./GLError");function a(t,e,r,n,a,i){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=a,this._constFunc=i}var i=a.prototype;function o(t,e,r,n,i,o,s){for(var l=["gl","v"],c=[],u=0;u<i;++u)l.push("x"+u),c.push("x"+u);l.push("if(x0.length===void 0){return gl.vertexAttrib"+i+"f(v,"+c.join()+")}else{return gl.vertexAttrib"+i+"fv(v,x0)}");var h=Function.apply(null,l),f=new a(t,e,r,n,i,h);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),h(t,n[r],e),e},get:function(){return f},enumerable:!0})}function s(t,e,r,n,a,i,s){for(var l=new Array(a),c=new Array(a),u=0;u<a;++u)o(t,e,r[u],n,a,l,u),c[u]=l[u];Object.defineProperty(l,"location",{set:function(t){if(Array.isArray(t))for(var e=0;e<a;++e)c[e].location=t[e];else for(e=0;e<a;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(a),e=0;e<a;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,i,o,s){e=e||t.FLOAT,i=!!i,o=o||a*a,s=s||0;for(var l=0;l<a;++l){var c=n[r[l]];t.vertexAttribPointer(c,a,e,i,o,s+l*a),t.enableVertexAttribArray(c)}};var h=new Array(a),f=t["vertexAttrib"+a+"fv"];Object.defineProperty(i,s,{set:function(e){for(var i=0;i<a;++i){var o=n[r[i]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))f.call(t,o,e[i]);else{for(var s=0;s<a;++s)h[s]=e[a*i+s];f.call(t,o,h)}}return e},get:function(){return l},enumerable:!0})}i.pointer=function(t,e,r,n){var a=this._gl,i=this._locations[this._index];a.vertexAttribPointer(i,this._dimension,t||a.FLOAT,!!e,r||0,n||0),a.enableVertexAttribArray(i)},i.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(i,"location",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{"./GLError":305}],307:[function(t,e,r){"use strict";var n=t("./reflect"),a=t("./GLError");function i(t){return new Function("y","return function(){return y}")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case"bool":case"int":case"sampler2D":case"samplerCube":return"gl.uniform1i(locations["+e+"],obj"+t+")";case"float":return"gl.uniform1f(locations["+e+"],obj"+t+")";default:var n=r.indexOf("vec");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf("mat")&&4===r.length){var i=r.charCodeAt(r.length-1)-48;if(i<2||i>4)throw new a("","Invalid uniform dimension type for matrix "+name+": "+r);return"gl.uniformMatrix"+i+"fv(locations["+e+"],false,obj"+t+")"}throw new a("","Unknown uniform data type for "+name+": "+r)}var i=r.charCodeAt(r.length-1)-48;if(i<2||i>4)throw new a("","Invalid data type");switch(r.charAt(0)){case"b":case"i":return"gl.uniform"+i+"iv(locations["+e+"],obj"+t+")";case"v":return"gl.uniform"+i+"fv(locations["+e+"],obj"+t+")";default:throw new a("","Unrecognized data type for vector "+name+": "+r)}}}function c(e){for(var n=["return function updateProperty(obj){"],a=function t(e,r){if("object"!=typeof r)return[[e,r]];var n=[];for(var a in r){var i=r[a],o=e;parseInt(a)+""===a?o+="["+a+"]":o+="."+a,"object"==typeof i?n.push.apply(n,t(o,i)):n.push([o,i])}return n}("",e),i=0;i<a.length;++i){var o=a[i],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}n.push("return obj}");var h=new Function("gl","locations",n.join("\n"));return h(t,s)}function u(n,l,u){if("object"==typeof u){var f=h(u);Object.defineProperty(n,l,{get:i(f),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,d=new Function("gl","wrapper","locations","return function(){return gl.getUniform(wrapper.program,locations["+p+"])}"),d(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case"bool":return!1;case"int":case"sampler2D":case"samplerCube":case"float":return 0;default:var e=t.indexOf("vec");if(0<=e&&e<=1&&t.length===4+e){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new a("","Invalid data type");return"b"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf("mat")&&4===t.length){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new a("","Invalid uniform dimension type for matrix "+name+": "+t);return o(r*r,0)}throw new a("","Unknown uniform data type for "+name+": "+t)}}(r[u].type);var p,d}function h(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var f=n(r,!0);return{get:i(h(f)),set:c(f),enumerable:!0,configurable:!0}}},{"./GLError":305,"./reflect":308}],308:[function(t,e,r){"use strict";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var a=t[n].name,i=a.split("."),o=r,s=0;s<i.length;++s){var l=i[s].split("[");if(l.length>1){l[0]in o||(o[l[0]]=[]),o=o[l[0]];for(var c=1;c<l.length;++c){var u=parseInt(l[c]);c<l.length-1||s<i.length-1?(u in o||(c<l.length-1?o[u]=[]:o[u]={}),o=o[u]):o[u]=e?n:t[n].type}}else s<i.length-1?(l[0]in o||(o[l[0]]={}),o=o[l[0]]):o[l[0]]=e?n:t[n].type}return r}},{}],309:[function(t,e,r){"use strict";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],a=0;a<r;++a){var o=t.getActiveUniform(e,a);if(o){var s=i(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace("[0]","["+l+"]"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],a=0;a<r;++a){var o=t.getActiveAttrib(e,a);o&&n.push({name:o.name,type:i(t,o.type)})}return n};var n={FLOAT:"float",FLOAT_VEC2:"vec2",FLOAT_VEC3:"vec3",FLOAT_VEC4:"vec4",INT:"int",INT_VEC2:"ivec2",INT_VEC3:"ivec3",INT_VEC4:"ivec4",BOOL:"bool",BOOL_VEC2:"bvec2",BOOL_VEC3:"bvec3",BOOL_VEC4:"bvec4",FLOAT_MAT2:"mat2",FLOAT_MAT3:"mat3",FLOAT_MAT4:"mat4",SAMPLER_2D:"sampler2D",SAMPLER_CUBE:"samplerCube"},a=null;function i(t,e){if(!a){var r=Object.keys(n);a={};for(var i=0;i<r.length;++i){var o=r[i];a[t[o]]=n[o]}}return a[e]}},{}],310:[function(t,e,r){"use strict";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,a){return u(t).getProgram(e,r,n,a)};var n=t("./GLError"),a=t("gl-format-compiler-error"),i=new("undefined"==typeof WeakMap?t("weakmap-shim"):WeakMap),o=0;function s(t,e,r,n,a,i,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=i,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,a=r.length;n<a;++n){var i=t.programs[r[n]];i&&(delete t.programs[n],e.deleteProgram(i))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=i.get(t);return e||(e=new l(t),i.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,i=this.shaders[t===r.FRAGMENT_SHADER|0],l=i[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var i=t.createShader(e);if(t.shaderSource(i,r),t.compileShader(i),!t.getShaderParameter(i,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(i);try{var s=a(o,r,e)}catch(t){throw console.warn("Failed to format compiler error: "+t),new n(o,"Error compiling shader:\n"+o)}throw new n(o,s.short,s.long)}return i}(r,t,e);l=i[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,a){var i=[t.id,e.id,r.join(":"),a.join(":")].join("@"),o=this.programs[i];return o&&this.gl.isProgram(o)||(this.programs[i]=o=function(t,e,r,a,i){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<a.length;++s)t.bindAttribLocation(o,i[s],a[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,"Error linking program: "+l)}return o}(this.gl,t.shader,e.shader,r,a),t.programs.push(i),e.programs.push(i)),o}},{"./GLError":305,"gl-format-compiler-error":253,"weakmap-shim":553}],311:[function(t,e,r){"use strict";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var a=n.prototype;a.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map(function(t){return t.slice()}),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},a.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,a=this.plot,i=a.line,o=a.dataBox,s=a.viewBox;if(i.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&i.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&i.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&i.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&i.drawLine(l,c,l,s[3],e[3],r[3])}},a.dispose=function(){this.plot.removeOverlay(this)}},{}],312:[function(t,e,r){"use strict";var n=t("glslify"),a=t("gl-shader"),i=n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec3 position, color;\nattribute float weight;\n\nuniform mat4 model, view, projection;\nuniform vec3 coordinates[3];\nuniform vec4 colors[3];\nuniform vec2 screenShape;\nuniform float lineWidth;\n\nvarying vec4 fragColor;\n\nvoid main() {\n  vec3 vertexPosition = mix(coordinates[0],\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\n\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\n  vec2 delta = weight * clipOffset * screenShape;\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\n\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\n}\n"]),o=n(["precision mediump float;\n#define GLSLIFY 1\n\nvarying vec4 fragColor;\n\nvoid main() {\n  gl_FragColor = fragColor;\n}"]);e.exports=function(t){return a(t,i,o,null,[{name:"position",type:"vec3"},{name:"color",type:"vec3"},{name:"weight",type:"float"}])}},{"gl-shader":304,glslify:410}],313:[function(t,e,r){"use strict";var n=t("gl-buffer"),a=t("gl-vao"),i=t("./shaders/index");e.exports=function(t,e){var r=[];function o(t,e,n,a,i,o){var s=[t,e,n,0,0,0,1];s[a+3]=1,s[a]=i,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[a]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[a]=i,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=a(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=i(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var h=new s(t,l,c,u);return h.update(e),h};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],h=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var a,i=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(a=this.axes.lastCubeProps.axis);for(var f=c,p=u,d=0;d<3;++d)a&&a[d]<0?(f[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(f[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);h[0]=e.drawingBufferWidth,h[1]=e.drawingBufferHeight,n.uniforms.model=i,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,f,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=h;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&("bounds"in t&&(this.bounds=t.bounds),"position"in t&&(this.position=t.position),"lineWidth"in t&&(this.lineWidth=t.lineWidth),"colors"in t&&(this.colors=t.colors),"enabled"in t&&(this.enabled=t.enabled),"drawSides"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{"./shaders/index":312,"gl-buffer":244,"gl-vao":329}],314:[function(t,e,r){var n=t("glslify"),a=n(["precision highp float;\n\nprecision highp float;\n#define GLSLIFY 1\n\nvec3 getOrthogonalVector(vec3 v) {\n  // Return up-vector for only-z vector.\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\n  // Assign z = 0, x = -b, y = a:\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\n    return normalize(vec3(-v.y, v.x, 0.0));\n  } else {\n    return normalize(vec3(0.0, v.z, -v.y));\n  }\n}\n\n// Calculate the tube vertex and normal at the given index.\n//\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\n//\n// Each tube segment is made up of a ring of vertices.\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\n// The indexes of tube segments run from 0 to 8.\n//\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\n  float segmentCount = 8.0;\n\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\n\n  vec3 u = getOrthogonalVector(d);\n  vec3 v = normalize(cross(u, d));\n\n  vec3 x = u * cos(angle) * length(d);\n  vec3 y = v * sin(angle) * length(d);\n  vec3 v3 = x + y;\n\n  normal = normalize(v3);\n\n  return v3;\n}\n\nattribute vec4 vector;\nattribute vec4 color, position;\nattribute vec2 uv;\n\nuniform float vectorScale, tubeScale;\nuniform mat4 model, view, projection, inverseModel;\nuniform vec3 eyePosition, lightPosition;\n\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\nvarying vec4 f_color;\nvarying vec2 f_uv;\n\nvoid main() {\n  // Scale the vector magnitude to stay constant with\n  // model & view changes.\n  vec3 normal;\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\n\n  //Lighting geometry parameters\n  vec4 cameraCoordinate = view * tubePosition;\n  cameraCoordinate.xyz /= cameraCoordinate.w;\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\n\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\n  vec4 t_position  = view * tubePosition;\n  gl_Position      = projection * t_position;\n\n  f_color          = color;\n  f_data           = tubePosition.xyz;\n  f_position       = position.xyz;\n  f_uv             = uv;\n}\n"]),i=n(["#extension GL_OES_standard_derivatives : enable\n\nprecision highp float;\n#define GLSLIFY 1\n\nfloat beckmannDistribution(float x, float roughness) {\n  float NdotH = max(x, 0.0001);\n  float cos2Alpha = NdotH * NdotH;\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\n  float roughness2 = roughness * roughness;\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\n  return exp(tan2Alpha / roughness2) / denom;\n}\n\nfloat cookTorranceSpecular(\n  vec3 lightDirection,\n  vec3 viewDirection,\n  vec3 surfaceNormal,\n  float roughness,\n  float fresnel) {\n\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\n\n  //Half angle vector\n  vec3 H = normalize(lightDirection + viewDirection);\n\n  //Geometric term\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\n  float VdotH = max(dot(viewDirection, H), 0.000001);\n  float LdotH = max(dot(lightDirection, H), 0.000001);\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\n  float G = min(1.0, min(G1, G2));\n  \n  //Distribution term\n  float D = beckmannDistribution(NdotH, roughness);\n\n  //Fresnel term\n  float F = pow(1.0 - VdotN, fresnel);\n\n  //Multiply terms and done\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\n}\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3 clipBounds[2];\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\nuniform sampler2D texture;\n\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\nvarying vec4 f_color;\nvarying vec2 f_uv;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\n  vec3 N = normalize(f_normal);\n  vec3 L = normalize(f_lightDirection);\n  vec3 V = normalize(f_eyeDirection);\n\n  if(gl_FrontFacing) {\n    N = -N;\n  }\n\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\n\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\n\n  gl_FragColor = litColor * opacity;\n}\n"]),o=n(["precision highp float;\n\nprecision highp float;\n#define GLSLIFY 1\n\nvec3 getOrthogonalVector(vec3 v) {\n  // Return up-vector for only-z vector.\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\n  // Assign z = 0, x = -b, y = a:\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\n    return normalize(vec3(-v.y, v.x, 0.0));\n  } else {\n    return normalize(vec3(0.0, v.z, -v.y));\n  }\n}\n\n// Calculate the tube vertex and normal at the given index.\n//\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\n//\n// Each tube segment is made up of a ring of vertices.\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\n// The indexes of tube segments run from 0 to 8.\n//\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\n  float segmentCount = 8.0;\n\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\n\n  vec3 u = getOrthogonalVector(d);\n  vec3 v = normalize(cross(u, d));\n\n  vec3 x = u * cos(angle) * length(d);\n  vec3 y = v * sin(angle) * length(d);\n  vec3 v3 = x + y;\n\n  normal = normalize(v3);\n\n  return v3;\n}\n\nattribute vec4 vector;\nattribute vec4 position;\nattribute vec4 id;\n\nuniform mat4 model, view, projection;\nuniform float tubeScale;\n\nvarying vec3 f_position;\nvarying vec4 f_id;\n\nvoid main() {\n  vec3 normal;\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\n\n  gl_Position = projection * view * tubePosition;\n  f_id        = id;\n  f_position  = position.xyz;\n}\n"]),s=n(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3  clipBounds[2];\nuniform float pickId;\n\nvarying vec3 f_position;\nvarying vec4 f_id;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\n\n  gl_FragColor = vec4(pickId, f_id.xyz);\n}"]);r.meshShader={vertex:a,fragment:i,attributes:[{name:"position",type:"vec4"},{name:"color",type:"vec4"},{name:"uv",type:"vec2"},{name:"vector",type:"vec4"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:"position",type:"vec4"},{name:"id",type:"vec4"},{name:"vector",type:"vec4"}]}},{glslify:410}],315:[function(t,e,r){"use strict";var n=t("gl-vec3"),a=t("gl-vec4"),i=["xyz","xzy","yxz","yzx","zxy","zyx"],o=function(t,e,r,i){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++)o=Math.max(o,n.length(l[c]));var u=t.map(function(t){return function(t,e,r,i){for(var o=t.points,s=t.velocities,l=t.divergences,c=[],u=[],h=[],f=[],p=[],d=[],g=0,v=0,m=a.create(),y=a.create(),x=0;x<o.length;x++){var b=o[x],_=s[x],w=l[x];0===e&&(w=.05*r),v=n.length(_)/i,m=a.create(),n.copy(m,_),m[3]=w;for(var k=0;k<8;k++)p[k]=[b[0],b[1],b[2],k];if(f.length>0)for(k=0;k<8;k++){var T=(k+1)%8;c.push(f[k],p[k],p[T],p[T],f[T],f[k]),h.push(y,m,m,m,y,y),d.push(g,v,v,v,g,g);var M=c.length;u.push([M-6,M-5,M-4],[M-3,M-2,M-1])}var A=f;f=p,p=A;var S=y;y=m,m=S;var E=g;g=v,v=E}return{positions:c,cells:u,vectors:h,vertexIntensity:d}}(t,r,i,o)}),h=[],f=[],p=[],d=[];for(s=0;s<u.length;s++){var g=u[s],v=h.length;h=h.concat(g.positions),p=p.concat(g.vectors),d=d.concat(g.vertexIntensity);for(c=0;c<g.cells.length;c++){var m=g.cells[c],y=[];f.push(y);for(var x=0;x<m.length;x++)y.push(m[x]+v)}}return{positions:h,cells:f,vectors:p,vertexIntensity:d,colormap:e}},s=function(t,e){var r,n=t.length;for(r=0;r<n;r++){var a=t[r];if(a===e)return r;if(a>e)return r-1}return r},l=function(t,e,r){return t<e?e:t>r?r:t},c=function(t){var e=1/0;t.sort(function(t,e){return t-e});for(var r=t.length,n=1;n<r;n++){var a=Math.abs(t[n]-t[n-1]);a<e&&(e=a)}return e};e.exports=function(t,e){var r=t.startingPositions,a=t.maxLength||1e3,u=t.tubeSize||1,h=t.absoluteTubeSize,f=t.gridFill||"+x+y+z",p={};-1!==f.indexOf("-x")&&(p.reversedX=!0),-1!==f.indexOf("-y")&&(p.reversedY=!0),-1!==f.indexOf("-z")&&(p.reversedZ=!0),p.filled=i.indexOf(f.replace(/-/g,"").replace(/\+/g,""));var d=t.getVelocity||function(e){return function(t,e,r){var a=e.vectors,i=e.meshgrid,o=t[0],c=t[1],u=t[2],h=i[0].length,f=i[1].length,p=i[2].length,d=s(i[0],o),g=s(i[1],c),v=s(i[2],u),m=d+1,y=g+1,x=v+1;if(d=l(d,0,h-1),m=l(m,0,h-1),g=l(g,0,f-1),y=l(y,0,f-1),v=l(v,0,p-1),x=l(x,0,p-1),d<0||g<0||v<0||m>h-1||y>f-1||x>p-1)return n.create();var b,_,w,k,T,M,A=i[0][d],S=i[0][m],E=i[1][g],L=i[1][y],C=i[2][v],P=(o-A)/(S-A),O=(c-E)/(L-E),z=(u-C)/(i[2][x]-C);switch(isFinite(P)||(P=.5),isFinite(O)||(O=.5),isFinite(z)||(z=.5),r.reversedX&&(d=h-1-d,m=h-1-m),r.reversedY&&(g=f-1-g,y=f-1-y),r.reversedZ&&(v=p-1-v,x=p-1-x),r.filled){case 5:T=v,M=x,w=g*p,k=y*p,b=d*p*f,_=m*p*f;break;case 4:T=v,M=x,b=d*p,_=m*p,w=g*p*h,k=y*p*h;break;case 3:w=g,k=y,T=v*f,M=x*f,b=d*f*p,_=m*f*p;break;case 2:w=g,k=y,b=d*f,_=m*f,T=v*f*h,M=x*f*h;break;case 1:b=d,_=m,T=v*h,M=x*h,w=g*h*p,k=y*h*p;break;default:b=d,_=m,w=g*h,k=y*h,T=v*h*f,M=x*h*f}var I=a[b+w+T],D=a[b+w+M],R=a[b+k+T],F=a[b+k+M],B=a[_+w+T],N=a[_+w+M],j=a[_+k+T],V=a[_+k+M],U=n.create(),q=n.create(),H=n.create(),G=n.create();n.lerp(U,I,B,P),n.lerp(q,D,N,P),n.lerp(H,R,j,P),n.lerp(G,F,V,P);var Y=n.create(),W=n.create();n.lerp(Y,U,H,O),n.lerp(W,q,G,O);var X=n.create();return n.lerp(X,Y,W,z),X}(e,t,p)},g=t.getDivergence||function(t,e){var r=n.create(),a=1e-4;n.add(r,t,[a,0,0]);var i=d(r);n.subtract(i,i,e),n.scale(i,i,1e4),n.add(r,t,[0,a,0]);var o=d(r);n.subtract(o,o,e),n.scale(o,o,1e4),n.add(r,t,[0,0,a]);var s=d(r);return n.subtract(s,s,e),n.scale(s,s,1e4),n.add(r,i,o),n.add(r,r,s),r},v=[],m=e[0][0],y=e[0][1],x=e[0][2],b=e[1][0],_=e[1][1],w=e[1][2],k=function(t){var e=t[0],r=t[1],n=t[2];return!(e<m||e>b||r<y||r>_||n<x||n>w)},T=10*n.distance(e[0],e[1])/a,M=T*T,A=1,S=0,E=r.length;E>1&&(A=function(t){for(var e=[],r=[],n=[],a={},i={},o={},s=t.length,l=0;l<s;l++){var u=t[l],h=u[0],f=u[1],p=u[2];a[h]||(e.push(h),a[h]=!0),i[f]||(r.push(f),i[f]=!0),o[p]||(n.push(p),o[p]=!0)}var d=c(e),g=c(r),v=c(n),m=Math.min(d,g,v);return isFinite(m)?m:1}(r));for(var L=0;L<E;L++){var C=n.create();n.copy(C,r[L]);var P=[C],O=[],z=d(C),I=C;O.push(z);var D=[],R=g(C,z),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F),v.push({points:P,velocities:O,divergences:D});for(var B=0;B<100*a&&P.length<a&&k(C);){B++;var N=n.clone(z),j=n.squaredLength(N);if(0===j)break;if(j>M&&n.scale(N,N,T/Math.sqrt(j)),n.add(N,N,C),z=d(N),n.squaredDistance(I,N)-M>-1e-4*M){P.push(N),I=N,O.push(z);R=g(N,z),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F)}C=N}}var V=o(v,t.colormap,S,A);return h?V.tubeScale=h:(0===S&&(S=1),V.tubeScale=.5*u*A/S),V};var u=t("./lib/shaders"),h=t("gl-cone3d").createMesh;e.exports.createTubeMesh=function(t,e){return h(t,e,{shaders:u,traceType:"streamtube"})}},{"./lib/shaders":314,"gl-cone3d":245,"gl-vec3":348,"gl-vec4":384}],316:[function(t,e,r){var n=t("gl-shader"),a=t("glslify"),i=a(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec4 uv;\nattribute vec3 f;\nattribute vec3 normal;\n\nuniform vec3 objectOffset;\nuniform mat4 model, view, projection, inverseModel;\nuniform vec3 lightPosition, eyePosition;\nuniform sampler2D colormap;\n\nvarying float value, kill;\nvarying vec3 worldCoordinate;\nvarying vec2 planeCoordinate;\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\nvarying vec4 vColor;\n\nvoid main() {\n  vec3 localCoordinate = vec3(uv.zw, f.x);\n  worldCoordinate = objectOffset + localCoordinate;\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\n  vec4 clipPosition = projection * view * worldPosition;\n  gl_Position = clipPosition;\n  kill = f.y;\n  value = f.z;\n  planeCoordinate = uv.xy;\n\n  vColor = texture2D(colormap, vec2(value, value));\n\n  //Lighting geometry parameters\n  vec4 cameraCoordinate = view * worldPosition;\n  cameraCoordinate.xyz /= cameraCoordinate.w;\n  lightDirection = lightPosition - cameraCoordinate.xyz;\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\n}\n"]),o=a(["precision highp float;\n#define GLSLIFY 1\n\nfloat beckmannDistribution(float x, float roughness) {\n  float NdotH = max(x, 0.0001);\n  float cos2Alpha = NdotH * NdotH;\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\n  float roughness2 = roughness * roughness;\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\n  return exp(tan2Alpha / roughness2) / denom;\n}\n\nfloat beckmannSpecular(\n  vec3 lightDirection,\n  vec3 viewDirection,\n  vec3 surfaceNormal,\n  float roughness) {\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\n}\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3 lowerBound, upperBound;\nuniform float contourTint;\nuniform vec4 contourColor;\nuniform sampler2D colormap;\nuniform vec3 clipBounds[2];\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\nuniform float vertexColor;\n\nvarying float value, kill;\nvarying vec3 worldCoordinate;\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\nvarying vec4 vColor;\n\nvoid main() {\n  if (\n    kill > 0.0 ||\n    vColor.a == 0.0 ||\n    outOfRange(clipBounds[0], clipBounds[1], worldCoordinate)\n  ) discard;\n\n  vec3 N = normalize(surfaceNormal);\n  vec3 V = normalize(eyeDirection);\n  vec3 L = normalize(lightDirection);\n\n  if(gl_FrontFacing) {\n    N = -N;\n  }\n\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\n\n  //decide how to interpolate color \u2014 in vertex or in fragment\n  vec4 surfaceColor =\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\n    step(.5, vertexColor) * vColor;\n\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\n\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\n}\n"]),s=a(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec4 uv;\nattribute float f;\n\nuniform vec3 objectOffset;\nuniform mat3 permutation;\nuniform mat4 model, view, projection;\nuniform float height, zOffset;\nuniform sampler2D colormap;\n\nvarying float value, kill;\nvarying vec3 worldCoordinate;\nvarying vec2 planeCoordinate;\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\nvarying vec4 vColor;\n\nvoid main() {\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\n  worldCoordinate = objectOffset + dataCoordinate;\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\n\n  vec4 clipPosition = projection * view * worldPosition;\n  clipPosition.z += zOffset;\n\n  gl_Position = clipPosition;\n  value = f + objectOffset.z;\n  kill = -1.0;\n  planeCoordinate = uv.zw;\n\n  vColor = texture2D(colormap, vec2(value, value));\n\n  //Don't do lighting for contours\n  surfaceNormal   = vec3(1,0,0);\n  eyeDirection    = vec3(0,1,0);\n  lightDirection  = vec3(0,0,1);\n}\n"]),l=a(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec2 shape;\nuniform vec3 clipBounds[2];\nuniform float pickId;\n\nvarying float value, kill;\nvarying vec3 worldCoordinate;\nvarying vec2 planeCoordinate;\nvarying vec3 surfaceNormal;\n\nvec2 splitFloat(float v) {\n  float vh = 255.0 * v;\n  float upper = floor(vh);\n  float lower = fract(vh);\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\n}\n\nvoid main() {\n  if ((kill > 0.0) ||\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\n\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\n}\n"]);r.createShader=function(t){var e=n(t,i,o,null,[{name:"uv",type:"vec4"},{name:"f",type:"vec3"},{name:"normal",type:"vec3"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,i,l,null,[{name:"uv",type:"vec4"},{name:"f",type:"vec3"},{name:"normal",type:"vec3"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:"uv",type:"vec4"},{name:"f",type:"float"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:"uv",type:"vec4"},{name:"f",type:"float"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{"gl-shader":304,glslify:410}],317:[function(t,e,r){arguments[4][113][0].apply(r,arguments)},{dup:113}],318:[function(t,e,r){"use strict";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=a(e),u=i(e,[{buffer:c,size:4,stride:w,offset:0},{buffer:c,size:3,stride:w,offset:16},{buffer:c,size:3,stride:w,offset:28}]),h=a(e),f=i(e,[{buffer:h,size:4,stride:20,offset:0},{buffer:h,size:1,stride:20,offset:16}]),p=a(e),d=i(e,[{buffer:p,size:2,type:e.FLOAT}]),g=o(e,1,S,e.RGBA,e.UNSIGNED_BYTE);g.minFilter=e.LINEAR,g.magFilter=e.LINEAR;var v=new E(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,g,s,l,h,f,p,d,[0,0,0]),m={levels:[[],[],[]]};for(var k in t)m[k]=t[k];return m.colormap=m.colormap||"jet",v.update(m),v};var n=t("bit-twiddle"),a=t("gl-buffer"),i=t("gl-vao"),o=t("gl-texture2d"),s=t("typedarray-pool"),l=t("colormap"),c=t("ndarray-ops"),u=t("ndarray-pack"),h=t("ndarray"),f=t("surface-nets"),p=t("gl-mat4/multiply"),d=t("gl-mat4/invert"),g=t("binary-search-bounds"),v=t("ndarray-gradient"),m=t("./lib/shaders"),y=m.createShader,x=m.createContourShader,b=m.createPickShader,_=m.createPickContourShader,w=40,k=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],T=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],M=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function A(t,e,r,n,a){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=a}!function(){for(var t=0;t<3;++t){var e=M[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();var S=256;function E(t,e,r,n,a,i,o,l,c,u,f,p,d,g,v){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=v,this.intensityBounds=[],this._shader=n,this._pickShader=a,this._coordinateBuffer=i,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=f,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new A([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=g,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.opacityscale=!1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var L=E.prototype;L.isTransparent=function(){return this.opacity<1||this.opacityscale},L.isOpaque=function(){if(this.opacityscale)return!1;if(this.opacity<1)return!1;if(this.opacity>=1)return!0;for(var t=0;t<3;++t)if(this._contourCounts[t].length>0)return!0;return!1},L.pickSlots=1,L.setPickBase=function(t){this.pickId=t};var C=[0,0,0],P={showSurface:!1,showContour:!1,projections:[k.slice(),k.slice(),k.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function O(t,e){var r,n,a,i=e.axes&&e.axes.lastCubeProps.axis||C,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=P.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(i[r]>0)][r],p(l,t.model,l);var c=P.clipBounds[r];for(a=0;a<2;++a)for(n=0;n<3;++n)c[a][n]=t.clipBounds[a][n];c[0][r]=-1e8,c[1][r]=1e8}return P.showSurface=o,P.showContour=s,P}var z={model:k,view:k,projection:k,inverseModel:k.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},I=k.slice(),D=[1,0,0,0,1,0,0,0,1];function R(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=z;n.model=t.model||k,n.view=t.view||k,n.projection=t.projection||k,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var a=0;a<2;++a)for(var i=n.clipBounds[a],o=0;o<3;++o)i[o]=Math.min(Math.max(this.clipBounds[a][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=D,n.vertexColor=this.vertexColor;var s=I;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),a=0;a<3;++a)n.eyePosition[a]=s[12+a]/s[15];var l=s[15];for(a=0;a<3;++a)l+=this.lightPosition[a]*s[4*a+3];for(a=0;a<3;++a){var c=s[12+a];for(o=0;o<3;++o)c+=s[4*o+a]*this.lightPosition[o];n.lightPosition[a]=c/l}var u=O(n,this);if(u.showSurface){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),a=0;a<3;++a)this.surfaceProject[a]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[a],this._shader.uniforms.clipBounds=u.clipBounds[a],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour){var h=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,h.bind(),h.uniforms=n;var f=this._contourVAO;for(f.bind(),a=0;a<3;++a)for(h.uniforms.permutation=M[a],r.lineWidth(this.contourWidth[a]*this.pixelRatio),o=0;o<this.contourLevels[a].length;++o)o===this.highlightLevel[a]?(h.uniforms.contourColor=this.highlightColor[a],h.uniforms.contourTint=this.highlightTint[a]):0!==o&&o-1!==this.highlightLevel[a]||(h.uniforms.contourColor=this.contourColor[a],h.uniforms.contourTint=this.contourTint[a]),this._contourCounts[a][o]&&(h.uniforms.height=this.contourLevels[a][o],f.draw(r.LINES,this._contourCounts[a][o],this._contourOffsets[a][o]));for(a=0;a<3;++a)for(h.uniforms.model=u.projections[a],h.uniforms.clipBounds=u.clipBounds[a],o=0;o<3;++o)if(this.contourProject[a][o]){h.uniforms.permutation=M[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var g=0;g<this.contourLevels[o].length;++g)g===this.highlightLevel[o]?(h.uniforms.contourColor=this.highlightColor[o],h.uniforms.contourTint=this.highlightTint[o]):0!==g&&g-1!==this.highlightLevel[o]||(h.uniforms.contourColor=this.contourColor[o],h.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][g]&&(h.uniforms.height=this.contourLevels[o][g],f.draw(r.LINES,this._contourCounts[o][g],this._contourOffsets[o][g]))}for(f.unbind(),(f=this._dynamicVAO).bind(),a=0;a<3;++a)if(0!==this._dynamicCounts[a])for(h.uniforms.model=n.model,h.uniforms.clipBounds=n.clipBounds,h.uniforms.permutation=M[a],r.lineWidth(this.dynamicWidth[a]*this.pixelRatio),h.uniforms.contourColor=this.dynamicColor[a],h.uniforms.contourTint=this.dynamicTint[a],h.uniforms.height=this.dynamicLevel[a],f.draw(r.LINES,this._dynamicCounts[a],this._dynamicOffsets[a]),o=0;o<3;++o)this.contourProject[o][a]&&(h.uniforms.model=u.projections[o],h.uniforms.clipBounds=u.clipBounds[o],f.draw(r.LINES,this._dynamicCounts[a],this._dynamicOffsets[a]));f.unbind()}}L.draw=function(t){return R.call(this,t,!1)},L.drawTransparent=function(t){return R.call(this,t,!0)};var F={model:k,view:k,projection:k,inverseModel:k,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function B(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function N(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function j(t){if(Array.isArray(t)){if(Array.isArray(t))return[N(t[0]),N(t[1]),N(t[2])];var e=N(t);return[e.slice(),e.slice(),e.slice()]}}L.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=F;r.model=t.model||k,r.view=t.view||k,r.projection=t.projection||k,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=D;for(var n=0;n<2;++n)for(var a=r.clipBounds[n],i=0;i<3;++i)a[i]=Math.min(Math.max(this.clipBounds[n][i],-1e8),1e8);var o=O(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),i=0;i<3;++i)for(e.lineWidth(this.contourWidth[i]*this.pixelRatio),s.uniforms.permutation=M[i],n=0;n<this.contourLevels[i].length;++n)this._contourCounts[i][n]&&(s.uniforms.height=this.contourLevels[i][n],l.draw(e.LINES,this._contourCounts[i][n],this._contourOffsets[i][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],i=0;i<3;++i)if(this.contourProject[n][i]){s.uniforms.permutation=M[i],e.lineWidth(this.contourWidth[i]*this.pixelRatio);for(var c=0;c<this.contourLevels[i].length;++c)this._contourCounts[i][c]&&(s.uniforms.height=this.contourLevels[i][c],l.draw(e.LINES,this._contourCounts[i][c],this._contourOffsets[i][c]))}l.unbind()}},L.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,a=Math.floor(n),i=n-a,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;a+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var h=u?i:1-i,f=0;f<2;++f)for(var p=a+u,d=s+f,v=h*(f?l:1-l),m=0;m<3;++m)c[m]+=this._field[m].get(p,d)*v;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=g.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=i<.5?a:a+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],m=0;m<3;++m)r.dataCoordinate[m]=this._field[m].get(r.index[0],r.index[1]);return r},L.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},L.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,"contourWidth"in t&&(this.contourWidth=B(t.contourWidth,Number)),"showContour"in t&&(this.showContour=B(t.showContour,Boolean)),"showSurface"in t&&(this.showSurface=!!t.showSurface),"contourTint"in t&&(this.contourTint=B(t.contourTint,Boolean)),"contourColor"in t&&(this.contourColor=j(t.contourColor)),"contourProject"in t&&(this.contourProject=B(t.contourProject,function(t){return B(t,Boolean)})),"surfaceProject"in t&&(this.surfaceProject=t.surfaceProject),"dynamicColor"in t&&(this.dynamicColor=j(t.dynamicColor)),"dynamicTint"in t&&(this.dynamicTint=B(t.dynamicTint,Number)),"dynamicWidth"in t&&(this.dynamicWidth=B(t.dynamicWidth,Number)),"opacity"in t&&(this.opacity=t.opacity),"opacityscale"in t&&(this.opacityscale=t.opacityscale),"colorBounds"in t&&(this.colorBounds=t.colorBounds),"vertexColor"in t&&(this.vertexColor=t.vertexColor?1:0);var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),"field"in t||"coords"in t){var a=(e.shape[0]+2)*(e.shape[1]+2);a>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(a))),this._field[2]=h(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var i=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=h(this._field[o].data,[i[0]+2,i[1]+2]);if(t.coords){var p=t.coords;if(!Array.isArray(p)||3!==p.length)throw new Error("gl-surface: invalid coordinates for x/y");for(o=0;o<2;++o){var d=p[o];for(b=0;b<2;++b)if(d.shape[b]!==i[b])throw new Error("gl-surface: coords have incorrect shape");this.padField(this._field[o],d)}}else if(t.ticks){var g=t.ticks;if(!Array.isArray(g)||2!==g.length)throw new Error("gl-surface: invalid ticks");for(o=0;o<2;++o){var m=g[o];if((Array.isArray(m)||m.length)&&(m=h(m)),m.shape[0]!==i[o])throw new Error("gl-surface: invalid tick length");var y=h(m.data,i);y.stride[o]=m.stride[0],y.stride[1^o]=0,this.padField(this._field[o],y)}}else{for(o=0;o<2;++o){var x=[0,0];x[o]=1,this._field[o]=h(this._field[o].data,[i[0]+2,i[1]+2],x,0)}this._field[0].set(0,0,0);for(var b=0;b<i[0];++b)this._field[0].set(b+1,0,b);for(this._field[0].set(i[0]+1,0,i[0]-1),this._field[1].set(0,0,0),b=0;b<i[1];++b)this._field[1].set(0,b+1,b);this._field[1].set(0,i[1]+1,i[1]-1)}var _=this._field,w=h(s.mallocFloat(3*_[2].size*2),[3,i[0]+2,i[1]+2,2]);for(o=0;o<3;++o)v(w.pick(o),_[o],"mirror");var k=h(s.mallocFloat(3*_[2].size),[i[0]+2,i[1]+2,3]);for(o=0;o<i[0]+2;++o)for(b=0;b<i[1]+2;++b){var M=w.get(0,o,b,0),A=w.get(0,o,b,1),E=w.get(1,o,b,0),L=w.get(1,o,b,1),C=w.get(2,o,b,0),P=w.get(2,o,b,1),O=E*P-L*C,z=C*A-P*M,I=M*L-A*E,D=Math.sqrt(O*O+z*z+I*I);D<1e-8?(D=Math.max(Math.abs(O),Math.abs(z),Math.abs(I)))<1e-8?(I=1,z=O=0,D=1):D=1/D:D=1/Math.sqrt(D),k.set(o,b,0,O*D),k.set(o,b,1,z*D),k.set(o,b,2,I*D)}s.free(w.data);var R=[1/0,1/0,1/0],F=[-1/0,-1/0,-1/0],N=1/0,V=-1/0,U=(i[0]-1)*(i[1]-1)*6,q=s.mallocFloat(n.nextPow2(10*U)),H=0,G=0;for(o=0;o<i[0]-1;++o)t:for(b=0;b<i[1]-1;++b){for(var Y=0;Y<2;++Y)for(var W=0;W<2;++W)for(var X=0;X<3;++X){var Z=this._field[X].get(1+o+Y,1+b+W);if(isNaN(Z)||!isFinite(Z))continue t}for(X=0;X<6;++X){var J=o+T[X][0],K=b+T[X][1],Q=this._field[0].get(J+1,K+1),$=this._field[1].get(J+1,K+1);Z=this._field[2].get(J+1,K+1),O=k.get(J+1,K+1,0),z=k.get(J+1,K+1,1),I=k.get(J+1,K+1,2),t.intensity&&(tt=t.intensity.get(J,K));var tt=t.intensity?t.intensity.get(J,K):Z+this.objectOffset[2];q[H++]=J,q[H++]=K,q[H++]=Q,q[H++]=$,q[H++]=Z,q[H++]=0,q[H++]=tt,q[H++]=O,q[H++]=z,q[H++]=I,R[0]=Math.min(R[0],Q+this.objectOffset[0]),R[1]=Math.min(R[1],$+this.objectOffset[1]),R[2]=Math.min(R[2],Z+this.objectOffset[2]),N=Math.min(N,tt),F[0]=Math.max(F[0],Q+this.objectOffset[0]),F[1]=Math.max(F[1],$+this.objectOffset[1]),F[2]=Math.max(F[2],Z+this.objectOffset[2]),V=Math.max(V,tt),G+=1}}for(t.intensityBounds&&(N=+t.intensityBounds[0],V=+t.intensityBounds[1]),o=6;o<H;o+=10)q[o]=(q[o]-N)/(V-N);this._vertexCount=G,this._coordinateBuffer.update(q.subarray(0,H)),s.freeFloat(q),s.free(k.data),this.bounds=[R,F],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===N&&this.intensityBounds[1]===V||(r=!0),this.intensityBounds=[N,V]}if("levels"in t){var et=t.levels;for(et=Array.isArray(et[0])?et.slice():[[],[],et],o=0;o<3;++o)et[o]=et[o].slice(),et[o].sort(function(t,e){return t-e});for(o=0;o<3;++o)for(b=0;b<et[o].length;++b)et[o][b]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(et[o].length!==this.contourLevels[o].length){r=!0;break}for(b=0;b<et[o].length;++b)if(et[o][b]!==this.contourLevels[o][b]){r=!0;break t}}this.contourLevels=et}if(r){_=this._field,i=this.shape;for(var rt=[],nt=0;nt<3;++nt){var at=this.contourLevels[nt],it=[],ot=[],st=[0,0,0];for(o=0;o<at.length;++o){var lt=f(this._field[nt],at[o]);it.push(rt.length/5|0),G=0;t:for(b=0;b<lt.cells.length;++b){var ct=lt.cells[b];for(X=0;X<2;++X){var ut=lt.positions[ct[X]],ht=ut[0],ft=0|Math.floor(ht),pt=ht-ft,dt=ut[1],gt=0|Math.floor(dt),vt=dt-gt,mt=!1;e:for(var yt=0;yt<3;++yt){st[yt]=0;var xt=(nt+yt+1)%3;for(Y=0;Y<2;++Y){var bt=Y?pt:1-pt;for(J=0|Math.min(Math.max(ft+Y,0),i[0]),W=0;W<2;++W){var _t=W?vt:1-vt;if(K=0|Math.min(Math.max(gt+W,0),i[1]),Z=yt<2?this._field[xt].get(J,K):(this.intensity.get(J,K)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(Z)||isNaN(Z)){mt=!0;break e}var wt=bt*_t;st[yt]+=wt*Z}}}if(mt){if(X>0){for(var kt=0;kt<5;++kt)rt.pop();G-=1}continue t}rt.push(st[0],st[1],ut[0],ut[1],st[2]),G+=1}}ot.push(G)}this._contourOffsets[nt]=it,this._contourCounts[nt]=ot}var Tt=s.mallocFloat(rt.length);for(o=0;o<rt.length;++o)Tt[o]=rt[o];this._contourBuffer.update(Tt),s.freeFloat(Tt)}t.colormap&&this._colorMap.setPixels(function(t,e){var r=u([l({colormap:t,nshades:S,format:"rgba"}).map(function(t,r){var n=e?function(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}(r/255,e):1;return[t[0],t[1],t[2],255*n]})]);return c.divseq(r,255),r}(t.colormap,this.opacityscale))},L.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},L.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,a=this.shape,i=s.mallocFloat(12*a[0]*a[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],h=this._field[l],p=this._field[c],d=f(u,r[o]),g=d.cells,v=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<g.length;++e)for(var m=g[e],y=0;y<2;++y){var x=v[m[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,a[0]),k=b-_,T=1-k,M=+x[1],A=0|M,S=0|Math.min(A+1,a[1]),E=M-A,L=1-E,C=T*L,P=T*E,O=k*L,z=k*E,I=C*h.get(_,A)+P*h.get(_,S)+O*h.get(w,A)+z*h.get(w,S),D=C*p.get(_,A)+P*p.get(_,S)+O*p.get(w,A)+z*p.get(w,S);if(isNaN(I)||isNaN(D)){y&&(n-=1);break}i[2*n+0]=I,i[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(i.subarray(0,2*n)),s.freeFloat(i)}}},{"./lib/shaders":316,"binary-search-bounds":317,"bit-twiddle":94,colormap:128,"gl-buffer":244,"gl-mat4/invert":268,"gl-mat4/multiply":270,"gl-texture2d":324,"gl-vao":329,ndarray:451,"ndarray-gradient":442,"ndarray-ops":445,"ndarray-pack":446,"surface-nets":529,"typedarray-pool":543}],319:[function(t,e,r){"use strict";var n=t("css-font"),a=t("pick-by-alias"),i=t("regl"),o=t("gl-util/context"),s=t("es6-weak-map"),l=t("color-normalize"),c=t("font-atlas"),u=t("typedarray-pool"),h=t("parse-rect"),f=t("is-plain-obj"),p=t("parse-unit"),d=t("to-px"),g=t("detect-kerning"),v=t("object-assign"),m=t("font-measure"),y=t("flatten-vertex-data"),x=t("bit-twiddle").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement("div"));w.style.font="italic small-caps bold condensed 16px/2 cursive",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var k=function(t){!function(t){return"function"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||i({gl:this.gl}),this.charBuffer=this.regl.buffer({type:"uint8",usage:"stream"}),this.sizeBuffer=this.regl.buffer({type:"float",usage:"stream"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(f(t)?t:{})};k.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:"src alpha",dstRGB:"one minus src alpha",srcAlpha:"one minus dst alpha",dstAlpha:"one"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop("count"),offset:t.prop("offset"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this("sizeBuffer")},width:{offset:0,stride:8,buffer:t.this("sizeBuffer")},char:t.this("charBuffer"),position:t.this("position")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop("color"),opacity:t.prop("opacity"),viewport:t.this("viewportArray"),scale:t.this("scale"),align:t.prop("align"),baseline:t.prop("baseline"),translate:t.this("translate"),positionOffset:t.prop("positionOffset")},primitive:"points",viewport:t.this("viewport"),vert:"\n\t\t\tprecision highp float;\n\t\t\tattribute float width, charOffset, char;\n\t\t\tattribute vec2 position;\n\t\t\tuniform float fontSize, charStep, em, align, baseline;\n\t\t\tuniform vec4 viewport;\n\t\t\tuniform vec4 color;\n\t\t\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\n\t\t\tvarying vec2 charCoord, charId;\n\t\t\tvarying float charWidth;\n\t\t\tvarying vec4 fontColor;\n\t\t\tvoid main () {\n\t\t\t\t"+(k.normalViewport?"":"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);")+"\n\n\t\t\t\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\n\t\t\t\t\t+ positionOffset))\n\t\t\t\t\t/ (viewport.zw * scale.xy);\n\n\t\t\t\tvec2 position = (position + translate) * scale;\n\t\t\t\tposition += offset * scale;\n\n\t\t\t\t"+(k.normalViewport?"position.y = 1. - position.y;":"")+"\n\n\t\t\t\tcharCoord = position * viewport.zw + viewport.xy;\n\n\t\t\t\tgl_Position = vec4(position * 2. - 1., 0, 1);\n\n\t\t\t\tgl_PointSize = charStep;\n\n\t\t\t\tcharId.x = mod(char, atlasDim.x);\n\t\t\t\tcharId.y = floor(char / atlasDim.x);\n\n\t\t\t\tcharWidth = width * em;\n\n\t\t\t\tfontColor = color / 255.;\n\t\t\t}",frag:"\n\t\t\tprecision highp float;\n\t\t\tuniform sampler2D atlas;\n\t\t\tuniform float fontSize, charStep, opacity;\n\t\t\tuniform vec2 atlasSize;\n\t\t\tuniform vec4 viewport;\n\t\t\tvarying vec4 fontColor;\n\t\t\tvarying vec2 charCoord, charId;\n\t\t\tvarying float charWidth;\n\n\t\t\tfloat lightness(vec4 color) {\n\t\t\t\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\n\t\t\t}\n\n\t\t\tvoid main () {\n\t\t\t\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\n\t\t\t\tfloat halfCharStep = floor(charStep * .5 + .5);\n\n\t\t\t\t// invert y and shift by 1px (FF expecially needs that)\n\t\t\t\tuv.y = charStep - uv.y;\n\n\t\t\t\t// ignore points outside of character bounding box\n\t\t\t\tfloat halfCharWidth = ceil(charWidth * .5);\n\t\t\t\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\n\t\t\t\t\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\n\n\t\t\t\tuv += charId * charStep;\n\t\t\t\tuv = uv / atlasSize;\n\n\t\t\t\tvec4 color = fontColor;\n\t\t\t\tvec4 mask = texture2D(atlas, uv);\n\n\t\t\t\tfloat maskY = lightness(mask);\n\t\t\t\t// float colorY = lightness(color);\n\t\t\t\tcolor.a *= maskY;\n\t\t\t\tcolor.a *= opacity;\n\n\t\t\t\t// color.a += .1;\n\n\t\t\t\t// antialiasing, see yiq color space y-channel formula\n\t\t\t\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\n\n\t\t\t\tgl_FragColor = color;\n\t\t\t}"});return{regl:t,draw:e,atlas:{}}},k.prototype.update=function(t){var e=this;if("string"==typeof t)t={text:t};else if(!t)return;null!=(t=a(t,{position:"position positions coord coords coordinates",font:"font fontFace fontface typeface cssFont css-font family fontFamily",fontSize:"fontSize fontsize size font-size",text:"text texts chars characters value values symbols",align:"align alignment textAlign textbaseline",baseline:"baseline textBaseline textbaseline",direction:"dir direction textDirection",color:"color colour fill fill-color fillColor textColor textcolor",kerning:"kerning kern",range:"range dataBox",viewport:"vp viewport viewBox viewbox viewPort",opacity:"opacity alpha transparency visible visibility opaque",offset:"offset positionOffset padding shift indent indentation"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map(function(t){return parseFloat(t)}):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=h(t.viewport),k.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&("number"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=k.baseFontSize+"px sans-serif");var r,i=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach(function(t,r){if("string"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(k.baseFontSize+"px "+t)}else t=n.parse(n.stringify(t));var a=n.stringify({size:k.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&a==e.font[r].baseString||(i=!0,e.font[r]=k.fonts[a],e.font[r]))){var c=t.family.join(", "),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:a,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:m(c,{origin:"top",fontSize:k.baseFontSize,fontStyle:u.join(" ")})},k.fonts[a]=e.font[r]}}),(i||o)&&this.font.forEach(function(r,a){var i=n.stringify({size:e.fontSize[a],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[a]=e.shader.atlas[i],!e.fontAtlas[a]){var o=r.metrics;e.shader.atlas[i]=e.fontAtlas[a]={fontString:i,step:2*Math.ceil(e.fontSize[a]*o.bottom*.5),em:e.fontSize[a],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)}),"string"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),f=0;f<s.length;f++)s[f]=t.text;t.text=s}if(null!=t.text||i){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)this.textOffsets[b]=this.textOffsets[b-1]+t.text[b-1].length,this.count+=t.text[b].length,this.counts.push(t.text[b].length);this.text=t.text.join("")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach(function(t,n){k.atlasContext.font=t.baseString;for(var a=e.fontAtlas[n],i=0;i<e.text.length;i++){var o=e.text.charAt(i);if(null==a.ids[o]&&(a.ids[o]=a.chars.length,a.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=k.atlasContext.measureText(o).width/k.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);v(t.kerning,g(t.family,{pairs:s}))}}})}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,T=u.mallocFloat(2*this.count),M=0,A=0;M<this.counts.length;M++){var S=this.counts[M];if(w)for(var E=0;E<S;E++)T[A++]=t.position[2*M],T[A++]=t.position[2*M+1];else for(var L=0;L<S;L++)T[A++]=t.position[M][0],T[A++]=t.position[M][1]}this.position.call?this.position({type:"float",data:T}):this.position=this.regl.buffer({type:"float",data:T}),u.freeFloat(T)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||i){var C=u.mallocUint8(this.count),P=u.mallocFloat(2*this.count);this.textWidth=[];for(var O=0,z=0;O<this.counts.length;O++){for(var I=this.counts[O],D=this.font[O]||this.font[0],R=this.fontAtlas[O]||this.fontAtlas[0],F=0;F<I;F++){var B=this.text.charAt(z),N=this.text.charAt(z-1);if(C[z]=R.ids[B],P[2*z]=D.width[B],F){var j=P[2*z-2],V=P[2*z],U=P[2*z-1]+.5*j+.5*V;if(this.kerning){var q=D.kerning[N+B];q&&(U+=.001*q)}P[2*z+1]=U}else P[2*z+1]=.5*P[2*z];z++}this.textWidth.push(P.length?.5*P[2*z-2]+P[2*z-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:C,type:"uint8",usage:"stream"}),this.sizeBuffer({data:P,type:"float",usage:"stream"}),u.freeUint8(C),u.freeFloat(P),r.length&&this.font.forEach(function(t,r){var n=e.fontAtlas[r],a=n.step,i=Math.floor(k.maxAtlasSize/a),o=Math.min(i,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*a),u=x(s*a);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:k.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[a,a]})})})}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map(function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if("number"==typeof n)return n;switch(n){case"right":case"end":return-t;case"center":case"centre":case"middle":return.5*-t}return 0})),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map(function(t,r){var n=(e.font[r]||e.font[0]).metrics,a=0;return a+=.5*n.bottom,a+="number"==typeof t?t-n.baseline:-n[t],k.normalViewport||(a*=-1),a})),null!=t.color)if(t.color||(t.color="transparent"),"string"!=typeof t.color&&isNaN(t.color)){var H;if("number"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Y=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Y(W,W+4),"uint8"),W)}else{var X=t.color.length;H=u.mallocUint8(4*X);for(var Z=0;Z<X;Z++)H.set(l(t.color[Z]||0,"uint8"),4*Z)}this.color=H}else this.color=l(t.color,"uint8");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var J=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array(J);for(var K=0;K<this.batch.length;K++)this.batch[K]={count:this.counts.length>1?this.counts[K]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[K]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*K,4*K+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[K]:this.opacity,baseline:null!=this.baselineOffset[K]?this.baselineOffset[K]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[K]?this.alignOffset[K]:this.alignOffset[0]:0,atlas:this.fontAtlas[K]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*K,2*K+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},k.prototype.destroy=function(){},k.prototype.kerning=!0,k.prototype.position={constant:new Float32Array(2)},k.prototype.translate=null,k.prototype.scale=null,k.prototype.font=null,k.prototype.text="",k.prototype.positionOffset=[0,0],k.prototype.opacity=1,k.prototype.color=new Uint8Array([0,0,0,255]),k.prototype.alignOffset=[0,0],k.normalViewport=!1,k.maxAtlasSize=1024,k.atlasCanvas=document.createElement("canvas"),k.atlasContext=k.atlasCanvas.getContext("2d",{alpha:!1}),k.baseFontSize=64,k.fonts={},e.exports=k},{"bit-twiddle":94,"color-normalize":122,"css-font":141,"detect-kerning":168,"es6-weak-map":320,"flatten-vertex-data":230,"font-atlas":231,"font-measure":232,"gl-util/context":325,"is-plain-obj":423,"object-assign":455,"parse-rect":460,"parse-unit":462,"pick-by-alias":466,regl:500,"to-px":537,"typedarray-pool":543}],320:[function(t,e,r){"use strict";e.exports=t("./is-implemented")()?WeakMap:t("./polyfill")},{"./is-implemented":321,"./polyfill":323}],321:[function(t,e,r){"use strict";e.exports=function(){var t,e;if("function"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},"one"],[{},"two"],[{},"three"]])}catch(t){return!1}return"[object WeakMap]"===String(t)&&("function"==typeof t.set&&(t.set({},1)===t&&("function"==typeof t.delete&&("function"==typeof t.has&&"one"===t.get(e)))))}},{}],322:[function(t,e,r){"use strict";e.exports="function"==typeof WeakMap&&"[object WeakMap]"===Object.prototype.toString.call(new WeakMap)},{}],323:[function(t,e,r){"use strict";var n,a=t("es5-ext/object/is-value"),i=t("es5-ext/object/set-prototype-of"),o=t("es5-ext/object/valid-object"),s=t("es5-ext/object/valid-value"),l=t("es5-ext/string/random-uniq"),c=t("d"),u=t("es6-iterator/get"),h=t("es6-iterator/for-of"),f=t("es6-symbol").toStringTag,p=t("./is-native-implemented"),d=Array.isArray,g=Object.defineProperty,v=Object.prototype.hasOwnProperty,m=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError("Constructor requires 'new'");return t=p&&i&&WeakMap!==n?i(new WeakMap,m(this)):this,a(e)&&(d(e)||(e=u(e))),g(t,"__weakMapData__",c("c","$weakMap$"+l())),e?(h(e,function(e){s(e),t.set(e[0],e[1])}),t):t},p&&(i&&i(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c(function(t){return!!v.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)}),get:c(function(t){if(v.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]}),has:c(function(t){return v.call(o(t),this.__weakMapData__)}),set:c(function(t,e){return g(o(t),this.__weakMapData__,c("c",e)),this}),toString:c(function(){return"[object WeakMap]"})}),g(n.prototype,f,c("c","WeakMap"))},{"./is-native-implemented":322,d:153,"es5-ext/object/is-value":197,"es5-ext/object/set-prototype-of":203,"es5-ext/object/valid-object":207,"es5-ext/object/valid-value":208,"es5-ext/string/random-uniq":213,"es6-iterator/for-of":215,"es6-iterator/get":216,"es6-symbol":222}],324:[function(t,e,r){"use strict";var n=t("ndarray"),a=t("ndarray-ops"),i=t("typedarray-pool");e.exports=function(t){if(arguments.length<=1)throw new Error("gl-texture2d: Missing arguments for texture2d constructor");o||function(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}(t);if("number"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if("object"==typeof arguments[1]){var e=arguments[1],r=c(e)?e:e.raw;if(r)return function(t,e,r,n,a,i){var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,a,a,i,e),new f(t,o,r,n,a,i)}(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return function(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error("gl-texture2d: Invalid texture size");var l=d(o,e.stride.slice()),c=0;"float32"===r?c=t.FLOAT:"float64"===r?(c=t.FLOAT,l=!1,r="float32"):"uint8"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r="uint8");var h,p,v=0;if(2===o.length)v=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error("gl-texture2d: Invalid shape for texture");if(1===o[2])v=t.ALPHA;else if(2===o[2])v=t.LUMINANCE_ALPHA;else if(3===o[2])v=t.RGB;else{if(4!==o[2])throw new Error("gl-texture2d: Invalid shape for pixel coords");v=t.RGBA}}c!==t.FLOAT||t.getExtension("OES_texture_float")||(c=t.UNSIGNED_BYTE,l=!1);var m=e.size;if(l)h=0===e.offset&&e.data.length===m?e.data:e.data.subarray(e.offset,e.offset+m);else{var y=[o[2],o[2]*o[0],1];p=i.malloc(m,r);var x=n(p,o,y,0);"float32"!==r&&"float64"!==r||c!==t.UNSIGNED_BYTE?a.assign(x,e):u(x,e),h=p.subarray(0,m)}var b=g(t);t.texImage2D(t.TEXTURE_2D,0,v,o[0],o[1],0,v,c,h),l||i.free(p);return new f(t,b,o[0],o[1],v,c)}(t,e)}throw new Error("gl-texture2d: Invalid arguments for texture2d constructor")};var o=null,s=null,l=null;function c(t){return"undefined"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||"undefined"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||"undefined"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||"undefined"!=typeof ImageData&&t instanceof ImageData}var u=function(t,e){a.muls(t,e,255)};function h(t,e,r){var n=t.gl,a=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error("gl-texture2d: Invalid texture size");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function f(t,e,r,n,a,i){this.gl=t,this.handle=e,this.format=a,this.type=i,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var p=f.prototype;function d(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function g(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,a){var i=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error("gl-texture2d: Invalid texture shape");if(a===t.FLOAT&&!t.getExtension("OES_texture_float"))throw new Error("gl-texture2d: Floating point textures not supported on this platform");var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,a,null),new f(t,o,e,r,n,a)}Object.defineProperties(p,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension("OES_texture_float_linear")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error("gl-texture2d: Unknown filter mode "+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension("OES_texture_float_linear")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error("gl-texture2d: Unknown filter mode "+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension("EXT_texture_filter_anisotropic");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error("gl-texture2d: Unknown wrap mode "+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error("gl-texture2d: Unknown wrap mode "+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error("gl-texture2d: Must specify wrap mode for rows and columns");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error("gl-texture2d: Unknown wrap mode "+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error("gl-texture2d: Invalid texture shape")}else t=[0|t,0|t];return h(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return h(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,h(this,this._shape[0],t),t}}}),p.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},p.dispose=function(){this.gl.deleteTexture(this.handle)},p.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},p.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=c(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error("gl-texture2d: Unsupported data type");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error("gl-texture2d: Texture dimensions are out of bounds");!function(t,e,r,o,s,l,c,h){var f=h.dtype,p=h.shape.slice();if(p.length<2||p.length>3)throw new Error("gl-texture2d: Invalid ndarray, must be 2d or 3d");var g=0,v=0,m=d(p,h.stride.slice());"float32"===f?g=t.FLOAT:"float64"===f?(g=t.FLOAT,m=!1,f="float32"):"uint8"===f?g=t.UNSIGNED_BYTE:(g=t.UNSIGNED_BYTE,m=!1,f="uint8");if(2===p.length)v=t.LUMINANCE,p=[p[0],p[1],1],h=n(h.data,p,[h.stride[0],h.stride[1],1],h.offset);else{if(3!==p.length)throw new Error("gl-texture2d: Invalid shape for texture");if(1===p[2])v=t.ALPHA;else if(2===p[2])v=t.LUMINANCE_ALPHA;else if(3===p[2])v=t.RGB;else{if(4!==p[2])throw new Error("gl-texture2d: Invalid shape for pixel coords");v=t.RGBA}p[2]}v!==t.LUMINANCE&&v!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(v=s);if(v!==s)throw new Error("gl-texture2d: Incompatible texture format for setPixels");var y=h.size,x=c.indexOf(o)<0;x&&c.push(o);if(g===l&&m)0===h.offset&&h.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data.subarray(h.offset,h.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data.subarray(h.offset,h.offset+y));else{var b;b=l===t.FLOAT?i.mallocFloat32(y):i.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);g===t.FLOAT&&l===t.UNSIGNED_BYTE?u(_,h):a.assign(_,h),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?i.freeFloat32(b):i.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:451,"ndarray-ops":445,"typedarray-pool":543}],325:[function(t,e,r){(function(r){"use strict";var n=t("pick-by-alias");function a(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function i(t){return"function"==typeof t.getContext&&"width"in t&&"height"in t}function o(){var t=document.createElement("canvas");return t.style.position="absolute",t.style.top=0,t.style.left=0,t}e.exports=function(t){var e;if(t?"string"==typeof t&&(t={container:t}):t={},i(t)?t={container:t}:t="string"==typeof(e=t).nodeName&&"function"==typeof e.appendChild&&"function"==typeof e.getBoundingClientRect?{container:t}:function(t){return"function"==typeof t.drawArrays||"function"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:"container target element el canvas holder parent parentNode wrapper use ref root node",gl:"gl context webgl glContext",attrs:"attributes attrs contextAttributes",pixelRatio:"pixelRatio pxRatio px ratio pxratio pixelratio",width:"w width",height:"h height"},!0),t.pixelRatio||(t.pixelRatio=r.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if("string"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error("Element "+t.container+" is not found");t.container=s}i(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),a(t))}else if(!t.canvas){if("undefined"==typeof document)throw Error("Not DOM environment. Use headless-gl.");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),a(t)}if(!t.gl)try{t.gl=t.canvas.getContext("webgl",t.attrs)}catch(e){try{t.gl=t.canvas.getContext("experimental-webgl",t.attrs)}catch(e){t.gl=t.canvas.getContext("webgl-experimental",t.attrs)}}return t.gl}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"pick-by-alias":466}],326:[function(t,e,r){"use strict";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error("gl-vao: Too many vertex attributes");for(var a=0;a<r.length;++a){var i=r[a];if(i.buffer){var o=i.buffer,s=i.size||4,l=i.type||t.FLOAT,c=!!i.normalized,u=i.stride||0,h=i.offset||0;o.bind(),t.enableVertexAttribArray(a),t.vertexAttribPointer(a,s,l,c,u,h)}else{if("number"==typeof i)t.vertexAttrib1f(a,i);else if(1===i.length)t.vertexAttrib1f(a,i[0]);else if(2===i.length)t.vertexAttrib2f(a,i[0],i[1]);else if(3===i.length)t.vertexAttrib3f(a,i[0],i[1],i[2]);else{if(4!==i.length)throw new Error("gl-vao: Invalid vertex attribute");t.vertexAttrib4f(a,i[0],i[1],i[2],i[3])}t.disableVertexAttribArray(a)}}for(;a<n;++a)t.disableVertexAttribArray(a)}else for(t.bindBuffer(t.ARRAY_BUFFER,null),a=0;a<n;++a)t.disableVertexAttribArray(a)}},{}],327:[function(t,e,r){"use strict";var n=t("./do-bind.js");function a(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}a.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},a.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.dispose=function(){},a.prototype.unbind=function(){},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new a(t)}},{"./do-bind.js":326}],328:[function(t,e,r){"use strict";var n=t("./do-bind.js");function a(t,e,r,n,a,i){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=a,this.d=i}function i(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}a.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},i.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},i.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},i.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},i.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var i=0;i<t.length;++i){var o=t[i];"number"==typeof o?this._attribs.push(new a(i,1,o)):Array.isArray(o)&&this._attribs.push(new a(i,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new i(t,e,e.createVertexArrayOES())}},{"./do-bind.js":326}],329:[function(t,e,r){"use strict";var n=t("./lib/vao-native.js"),a=t("./lib/vao-emulated.js");function i(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new i(t):t.getExtension("OES_vertex_array_object");return(s=l?n(t,l):a(t)).update(e,r,o),s}},{"./lib/vao-emulated.js":327,"./lib/vao-native.js":328}],330:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],331:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);a(r,r),a(o,o);var s=i(r,o);return s>1?0:Math.acos(s)};var n=t("./fromValues"),a=t("./normalize"),i=t("./dot")},{"./dot":341,"./fromValues":347,"./normalize":358}],332:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],333:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],334:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],335:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],336:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=r[0],s=r[1],l=r[2];return t[0]=a*l-i*s,t[1]=i*o-n*l,t[2]=n*s-a*o,t}},{}],337:[function(t,e,r){e.exports=t("./distance")},{"./distance":338}],338:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],a=e[2]-t[2];return Math.sqrt(r*r+n*n+a*a)}},{}],339:[function(t,e,r){e.exports=t("./divide")},{"./divide":340}],340:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],341:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],342:[function(t,e,r){e.exports=1e-6},{}],343:[function(t,e,r){e.exports=function(t,e){var r=t[0],a=t[1],i=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(a-s)<=n*Math.max(1,Math.abs(a),Math.abs(s))&&Math.abs(i-l)<=n*Math.max(1,Math.abs(i),Math.abs(l))};var n=t("./epsilon")},{"./epsilon":342}],344:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],345:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],346:[function(t,e,r){e.exports=function(t,e,r,a,i,o){var s,l;e||(e=3);r||(r=0);l=a?Math.min(a*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],i(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t("./create")()},{"./create":335}],347:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],348:[function(t,e,r){e.exports={EPSILON:t("./epsilon"),create:t("./create"),clone:t("./clone"),angle:t("./angle"),fromValues:t("./fromValues"),copy:t("./copy"),set:t("./set"),equals:t("./equals"),exactEquals:t("./exactEquals"),add:t("./add"),subtract:t("./subtract"),sub:t("./sub"),multiply:t("./multiply"),mul:t("./mul"),divide:t("./divide"),div:t("./div"),min:t("./min"),max:t("./max"),floor:t("./floor"),ceil:t("./ceil"),round:t("./round"),scale:t("./scale"),scaleAndAdd:t("./scaleAndAdd"),distance:t("./distance"),dist:t("./dist"),squaredDistance:t("./squaredDistance"),sqrDist:t("./sqrDist"),length:t("./length"),len:t("./len"),squaredLength:t("./squaredLength"),sqrLen:t("./sqrLen"),negate:t("./negate"),inverse:t("./inverse"),normalize:t("./normalize"),dot:t("./dot"),cross:t("./cross"),lerp:t("./lerp"),random:t("./random"),transformMat4:t("./transformMat4"),transformMat3:t("./transformMat3"),transformQuat:t("./transformQuat"),rotateX:t("./rotateX"),rotateY:t("./rotateY"),rotateZ:t("./rotateZ"),forEach:t("./forEach")}},{"./add":330,"./angle":331,"./ceil":332,"./clone":333,"./copy":334,"./create":335,"./cross":336,"./dist":337,"./distance":338,"./div":339,"./divide":340,"./dot":341,"./epsilon":342,"./equals":343,"./exactEquals":344,"./floor":345,"./forEach":346,"./fromValues":347,"./inverse":349,"./len":350,"./length":351,"./lerp":352,"./max":353,"./min":354,"./mul":355,"./multiply":356,"./negate":357,"./normalize":358,"./random":359,"./rotateX":360,"./rotateY":361,"./rotateZ":362,"./round":363,"./scale":364,"./scaleAndAdd":365,"./set":366,"./sqrDist":367,"./sqrLen":368,"./squaredDistance":369,"./squaredLength":370,"./sub":371,"./subtract":372,"./transformMat3":373,"./transformMat4":374,"./transformQuat":375}],349:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],350:[function(t,e,r){e.exports=t("./length")},{"./length":351}],351:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],352:[function(t,e,r){e.exports=function(t,e,r,n){var a=e[0],i=e[1],o=e[2];return t[0]=a+n*(r[0]-a),t[1]=i+n*(r[1]-i),t[2]=o+n*(r[2]-o),t}},{}],353:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],354:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],355:[function(t,e,r){e.exports=t("./multiply")},{"./multiply":356}],356:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],357:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],358:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],a=e[2],i=r*r+n*n+a*a;i>0&&(i=1/Math.sqrt(i),t[0]=e[0]*i,t[1]=e[1]*i,t[2]=e[2]*i);return t}},{}],359:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,a=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*a,t[1]=Math.sin(r)*a,t[2]=n*e,t}},{}],360:[function(t,e,r){e.exports=function(t,e,r,n){var a=r[1],i=r[2],o=e[1]-a,s=e[2]-i,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=a+o*c-s*l,t[2]=i+o*l+s*c,t}},{}],361:[function(t,e,r){e.exports=function(t,e,r,n){var a=r[0],i=r[2],o=e[0]-a,s=e[2]-i,l=Math.sin(n),c=Math.cos(n);return t[0]=a+s*l+o*c,t[1]=e[1],t[2]=i+s*c-o*l,t}},{}],362:[function(t,e,r){e.exports=function(t,e,r,n){var a=r[0],i=r[1],o=e[0]-a,s=e[1]-i,l=Math.sin(n),c=Math.cos(n);return t[0]=a+o*c-s*l,t[1]=i+o*l+s*c,t[2]=e[2],t}},{}],363:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],364:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],365:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],366:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],367:[function(t,e,r){e.exports=t("./squaredDistance")},{"./squaredDistance":369}],368:[function(t,e,r){e.exports=t("./squaredLength")},{"./squaredLength":370}],369:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],a=e[2]-t[2];return r*r+n*n+a*a}},{}],370:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],371:[function(t,e,r){e.exports=t("./subtract")},{"./subtract":372}],372:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],373:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2];return t[0]=n*r[0]+a*r[3]+i*r[6],t[1]=n*r[1]+a*r[4]+i*r[7],t[2]=n*r[2]+a*r[5]+i*r[8],t}},{}],374:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=r[3]*n+r[7]*a+r[11]*i+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*a+r[8]*i+r[12])/o,t[1]=(r[1]*n+r[5]*a+r[9]*i+r[13])/o,t[2]=(r[2]*n+r[6]*a+r[10]*i+r[14])/o,t}},{}],375:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*i-l*a,h=c*a+l*n-o*i,f=c*i+o*a-s*n,p=-o*n-s*a-l*i;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t}},{}],376:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],377:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],378:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],379:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],380:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],a=e[2]-t[2],i=e[3]-t[3];return Math.sqrt(r*r+n*n+a*a+i*i)}},{}],381:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],382:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],383:[function(t,e,r){e.exports=function(t,e,r,n){var a=new Float32Array(4);return a[0]=t,a[1]=e,a[2]=r,a[3]=n,a}},{}],384:[function(t,e,r){e.exports={create:t("./create"),clone:t("./clone"),fromValues:t("./fromValues"),copy:t("./copy"),set:t("./set"),add:t("./add"),subtract:t("./subtract"),multiply:t("./multiply"),divide:t("./divide"),min:t("./min"),max:t("./max"),scale:t("./scale"),scaleAndAdd:t("./scaleAndAdd"),distance:t("./distance"),squaredDistance:t("./squaredDistance"),length:t("./length"),squaredLength:t("./squaredLength"),negate:t("./negate"),inverse:t("./inverse"),normalize:t("./normalize"),dot:t("./dot"),lerp:t("./lerp"),random:t("./random"),transformMat4:t("./transformMat4"),transformQuat:t("./transformQuat")}},{"./add":376,"./clone":377,"./copy":378,"./create":379,"./distance":380,"./divide":381,"./dot":382,"./fromValues":383,"./inverse":385,"./length":386,"./lerp":387,"./max":388,"./min":389,"./multiply":390,"./negate":391,"./normalize":392,"./random":393,"./scale":394,"./scaleAndAdd":395,"./set":396,"./squaredDistance":397,"./squaredLength":398,"./subtract":399,"./transformMat4":400,"./transformQuat":401}],385:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],386:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],a=t[3];return Math.sqrt(e*e+r*r+n*n+a*a)}},{}],387:[function(t,e,r){e.exports=function(t,e,r,n){var a=e[0],i=e[1],o=e[2],s=e[3];return t[0]=a+n*(r[0]-a),t[1]=i+n*(r[1]-i),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],388:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],389:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],390:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],391:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],392:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=r*r+n*n+a*a+i*i;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=a*o,t[3]=i*o);return t}},{}],393:[function(t,e,r){var n=t("./normalize"),a=t("./scale");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),a(t,t,e),t}},{"./normalize":392,"./scale":394}],394:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],395:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],396:[function(t,e,r){e.exports=function(t,e,r,n,a){return t[0]=e,t[1]=r,t[2]=n,t[3]=a,t}},{}],397:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],a=e[2]-t[2],i=e[3]-t[3];return r*r+n*n+a*a+i*i}},{}],398:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],a=t[3];return e*e+r*r+n*n+a*a}},{}],399:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],400:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3];return t[0]=r[0]*n+r[4]*a+r[8]*i+r[12]*o,t[1]=r[1]*n+r[5]*a+r[9]*i+r[13]*o,t[2]=r[2]*n+r[6]*a+r[10]*i+r[14]*o,t[3]=r[3]*n+r[7]*a+r[11]*i+r[15]*o,t}},{}],401:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*i-l*a,h=c*a+l*n-o*i,f=c*i+o*a-s*n,p=-o*n-s*a-l*i;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t[3]=e[3],t}},{}],402:[function(t,e,r){var n=t("glsl-tokenizer"),a=t("atob-lite");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var i=e[r];if("preprocessor"===i.type){var o=i.data.match(/\#define\s+SHADER_NAME(_B64)?\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?a(l):l).trim()}}}}},{"atob-lite":74,"glsl-tokenizer":409}],403:[function(t,e,r){e.exports=function(t){var e,r,k,T=0,M=0,A=l,S=[],E=[],L=1,C=0,P=0,O=!1,z=!1,I="",D=i,R=n;"300 es"===(t=t||{}).version&&(D=s,R=o);return function(t){return E=[],null!==t?function(t){var r;T=0,k=(I+=t).length;for(;e=I[T],T<k;){switch(r=T,A){case u:T=V();break;case h:case f:T=j();break;case p:T=U();break;case d:T=G();break;case _:T=H();break;case g:T=Y();break;case c:T=W();break;case x:T=N();break;case l:T=B()}if(r!==T)switch(I[r]){case"\n":C=0,++L;break;default:++C}}return M+=T,I=I.slice(T),E}(t.replace?t.replace(/\r\n/g,"\n"):t):function(t){S.length&&F(S.join(""));return A=b,F("(eof)"),E}()};function F(t){t.length&&E.push({type:w[A],data:t,position:P,line:L,column:C})}function B(){return S=S.length?[]:S,"/"===r&&"*"===e?(P=M+T-1,A=u,r=e,T+1):"/"===r&&"/"===e?(P=M+T-1,A=h,r=e,T+1):"#"===e?(A=f,P=M+T,T):/\s/.test(e)?(A=x,P=M+T,T):(O=/\d/.test(e),z=/[^\w_]/.test(e),P=M+T,A=O?d:z?p:c,T)}function N(){return/[^\s]/g.test(e)?(F(S.join("")),A=l,T):(S.push(e),r=e,T+1)}function j(){return"\r"!==e&&"\n"!==e||"\\"===r?(S.push(e),r=e,T+1):(F(S.join("")),A=l,T)}function V(){return"/"===e&&"*"===r?(S.push(e),F(S.join("")),A=l,T+1):(S.push(e),r=e,T+1)}function U(){if("."===r&&/\d/.test(e))return A=g,T;if("/"===r&&"*"===e)return A=u,T;if("/"===r&&"/"===e)return A=h,T;if("."===e&&S.length){for(;q(S););return A=g,T}if(";"===e||")"===e||"("===e){if(S.length)for(;q(S););return F(e),A=l,T+1}var t=2===S.length&&"="!==e;if(/[\w_\d\s]/.test(e)||t){for(;q(S););return A=l,T}return S.push(e),r=e,T+1}function q(t){for(var e,r,n=0;;){if(e=a.indexOf(t.slice(0,t.length+n).join("")),r=a[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join("")}return F(r),P+=r.length,(S=S.slice(r.length)).length}}function H(){return/[^a-fA-F0-9]/.test(e)?(F(S.join("")),A=l,T):(S.push(e),r=e,T+1)}function G(){return"."===e?(S.push(e),A=g,r=e,T+1):/[eE]/.test(e)?(S.push(e),A=g,r=e,T+1):"x"===e&&1===S.length&&"0"===S[0]?(A=_,S.push(e),r=e,T+1):/[^\d]/.test(e)?(F(S.join("")),A=l,T):(S.push(e),r=e,T+1)}function Y(){return"f"===e&&(S.push(e),r=e,T+=1),/[eE]/.test(e)?(S.push(e),r=e,T+1):"-"===e&&/[eE]/.test(r)?(S.push(e),r=e,T+1):/[^\d]/.test(e)?(F(S.join("")),A=l,T):(S.push(e),r=e,T+1)}function W(){if(/[^\d\w_]/.test(e)){var t=S.join("");return A=R.indexOf(t)>-1?y:D.indexOf(t)>-1?m:v,F(S.join("")),A=l,T}return S.push(e),r=e,T+1}};var n=t("./lib/literals"),a=t("./lib/operators"),i=t("./lib/builtins"),o=t("./lib/literals-300es"),s=t("./lib/builtins-300es"),l=999,c=9999,u=0,h=1,f=2,p=3,d=4,g=5,v=6,m=7,y=8,x=9,b=10,_=11,w=["block-comment","line-comment","preprocessor","operator","integer","float","ident","builtin","keyword","whitespace","eof","integer"]},{"./lib/builtins":405,"./lib/builtins-300es":404,"./lib/literals":407,"./lib/literals-300es":406,"./lib/operators":408}],404:[function(t,e,r){var n=t("./builtins");n=n.slice().filter(function(t){return!/^(gl\_|texture)/.test(t)}),e.exports=n.concat(["gl_VertexID","gl_InstanceID","gl_Position","gl_PointSize","gl_FragCoord","gl_FrontFacing","gl_FragDepth","gl_PointCoord","gl_MaxVertexAttribs","gl_MaxVertexUniformVectors","gl_MaxVertexOutputVectors","gl_MaxFragmentInputVectors","gl_MaxVertexTextureImageUnits","gl_MaxCombinedTextureImageUnits","gl_MaxTextureImageUnits","gl_MaxFragmentUniformVectors","gl_MaxDrawBuffers","gl_MinProgramTexelOffset","gl_MaxProgramTexelOffset","gl_DepthRangeParameters","gl_DepthRange","trunc","round","roundEven","isnan","isinf","floatBitsToInt","floatBitsToUint","intBitsToFloat","uintBitsToFloat","packSnorm2x16","unpackSnorm2x16","packUnorm2x16","unpackUnorm2x16","packHalf2x16","unpackHalf2x16","outerProduct","transpose","determinant","inverse","texture","textureSize","textureProj","textureLod","textureOffset","texelFetch","texelFetchOffset","textureProjOffset","textureLodOffset","textureProjLod","textureProjLodOffset","textureGrad","textureGradOffset","textureProjGrad","textureProjGradOffset"])},{"./builtins":405}],405:[function(t,e,r){e.exports=["abs","acos","all","any","asin","atan","ceil","clamp","cos","cross","dFdx","dFdy","degrees","distance","dot","equal","exp","exp2","faceforward","floor","fract","gl_BackColor","gl_BackLightModelProduct","gl_BackLightProduct","gl_BackMaterial","gl_BackSecondaryColor","gl_ClipPlane","gl_ClipVertex","gl_Color","gl_DepthRange","gl_DepthRangeParameters","gl_EyePlaneQ","gl_EyePlaneR","gl_EyePlaneS","gl_EyePlaneT","gl_Fog","gl_FogCoord","gl_FogFragCoord","gl_FogParameters","gl_FragColor","gl_FragCoord","gl_FragData","gl_FragDepth","gl_FragDepthEXT","gl_FrontColor","gl_FrontFacing","gl_FrontLightModelProduct","gl_FrontLightProduct","gl_FrontMaterial","gl_FrontSecondaryColor","gl_LightModel","gl_LightModelParameters","gl_LightModelProducts","gl_LightProducts","gl_LightSource","gl_LightSourceParameters","gl_MaterialParameters","gl_MaxClipPlanes","gl_MaxCombinedTextureImageUnits","gl_MaxDrawBuffers","gl_MaxFragmentUniformComponents","gl_MaxLights","gl_MaxTextureCoords","gl_MaxTextureImageUnits","gl_MaxTextureUnits","gl_MaxVaryingFloats","gl_MaxVertexAttribs","gl_MaxVertexTextureImageUnits","gl_MaxVertexUniformComponents","gl_ModelViewMatrix","gl_ModelViewMatrixInverse","gl_ModelViewMatrixInverseTranspose","gl_ModelViewMatrixTranspose","gl_ModelViewProjectionMatrix","gl_ModelViewProjectionMatrixInverse","gl_ModelViewProjectionMatrixInverseTranspose","gl_ModelViewProjectionMatrixTranspose","gl_MultiTexCoord0","gl_MultiTexCoord1","gl_MultiTexCoord2","gl_MultiTexCoord3","gl_MultiTexCoord4","gl_MultiTexCoord5","gl_MultiTexCoord6","gl_MultiTexCoord7","gl_Normal","gl_NormalMatrix","gl_NormalScale","gl_ObjectPlaneQ","gl_ObjectPlaneR","gl_ObjectPlaneS","gl_ObjectPlaneT","gl_Point","gl_PointCoord","gl_PointParameters","gl_PointSize","gl_Position","gl_ProjectionMatrix","gl_ProjectionMatrixInverse","gl_ProjectionMatrixInverseTranspose","gl_ProjectionMatrixTranspose","gl_SecondaryColor","gl_TexCoord","gl_TextureEnvColor","gl_TextureMatrix","gl_TextureMatrixInverse","gl_TextureMatrixInverseTranspose","gl_TextureMatrixTranspose","gl_Vertex","greaterThan","greaterThanEqual","inversesqrt","length","lessThan","lessThanEqual","log","log2","matrixCompMult","max","min","mix","mod","normalize","not","notEqual","pow","radians","reflect","refract","sign","sin","smoothstep","sqrt","step","tan","texture2D","texture2DLod","texture2DProj","texture2DProjLod","textureCube","textureCubeLod","texture2DLodEXT","texture2DProjLodEXT","textureCubeLodEXT","texture2DGradEXT","texture2DProjGradEXT","textureCubeGradEXT"]},{}],406:[function(t,e,r){var n=t("./literals");e.exports=n.slice().concat(["layout","centroid","smooth","case","mat2x2","mat2x3","mat2x4","mat3x2","mat3x3","mat3x4","mat4x2","mat4x3","mat4x4","uint","uvec2","uvec3","uvec4","samplerCubeShadow","sampler2DArray","sampler2DArrayShadow","isampler2D","isampler3D","isamplerCube","isampler2DArray","usampler2D","usampler3D","usamplerCube","usampler2DArray","coherent","restrict","readonly","writeonly","resource","atomic_uint","noperspective","patch","sample","subroutine","common","partition","active","filter","image1D","image2D","image3D","imageCube","iimage1D","iimage2D","iimage3D","iimageCube","uimage1D","uimage2D","uimage3D","uimageCube","image1DArray","image2DArray","iimage1DArray","iimage2DArray","uimage1DArray","uimage2DArray","image1DShadow","image2DShadow","image1DArrayShadow","image2DArrayShadow","imageBuffer","iimageBuffer","uimageBuffer","sampler1DArray","sampler1DArrayShadow","isampler1D","isampler1DArray","usampler1D","usampler1DArray","isampler2DRect","usampler2DRect","samplerBuffer","isamplerBuffer","usamplerBuffer","sampler2DMS","isampler2DMS","usampler2DMS","sampler2DMSArray","isampler2DMSArray","usampler2DMSArray"])},{"./literals":407}],407:[function(t,e,r){e.exports=["precision","highp","mediump","lowp","attribute","const","uniform","varying","break","continue","do","for","while","if","else","in","out","inout","float","int","void","bool","true","false","discard","return","mat2","mat3","mat4","vec2","vec3","vec4","ivec2","ivec3","ivec4","bvec2","bvec3","bvec4","sampler1D","sampler2D","sampler3D","samplerCube","sampler1DShadow","sampler2DShadow","struct","asm","class","union","enum","typedef","template","this","packed","goto","switch","default","inline","noinline","volatile","public","static","extern","external","interface","long","short","double","half","fixed","unsigned","input","output","hvec2","hvec3","hvec4","dvec2","dvec3","dvec4","fvec2","fvec3","fvec4","sampler2DRect","sampler3DRect","sampler2DRectShadow","sizeof","cast","namespace","using"]},{}],408:[function(t,e,r){e.exports=["<<=",">>=","++","--","<<",">>","<=",">=","==","!=","&&","||","+=","-=","*=","/=","%=","&=","^^","^=","|=","(",")","[","]",".","!","~","*","/","%","+","-","<",">","&","^","|","?",":","=",",",";","{","}"]},{}],409:[function(t,e,r){var n=t("./index");e.exports=function(t,e){var r=n(e),a=[];return a=(a=a.concat(r(t))).concat(r(null))}},{"./index":403}],410:[function(t,e,r){e.exports=function(t){"string"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||"");return r.push(t[n]),r.join("")}},{}],411:[function(t,e,r){(function(r){"use strict";var n,a=t("is-browser");n="function"==typeof r.matchMedia?!r.matchMedia("(hover: none)").matches:a,e.exports=n}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"is-browser":418}],412:[function(t,e,r){"use strict";var n=t("is-browser");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},"passive",{get:function(){t=!0}});window.addEventListener("test",null,e),window.removeEventListener("test",null,e)}catch(e){t=!1}return t}()},{"is-browser":418}],413:[function(t,e,r){r.read=function(t,e,r,n,a){var i,o,s=8*a-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?a-1:0,f=r?-1:1,p=t[e+h];for(h+=f,i=p&(1<<-u)-1,p>>=-u,u+=s;u>0;i=256*i+t[e+h],h+=f,u-=8);for(o=i&(1<<-u)-1,i>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===i)i=1-c;else{if(i===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),i-=c}return(p?-1:1)*o*Math.pow(2,i-n)},r.write=function(t,e,r,n,a,i){var o,s,l,c=8*i-a-1,u=(1<<c)-1,h=u>>1,f=23===a?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:i-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,a),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,a),o=0));a>=8;t[r+p]=255&s,p+=d,s/=256,a-=8);for(o=o<<a|s,c+=a;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g}},{}],414:[function(t,e,r){"use strict";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error("Must have at least d+1 points");var a=t[0].length;if(r<=a)throw new Error("Must input at least d+1 points");var o=t.slice(0,a+1),s=n.apply(void 0,o);if(0===s)throw new Error("Input not in general position");for(var l=new Array(a+1),u=0;u<=a;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);for(var h=new i(l,new Array(a+1),!1),f=h.adjacent,p=new Array(a+2),u=0;u<=a;++u){for(var d=l.slice(),g=0;g<=a;++g)g===u&&(d[g]=-1);var v=d[0];d[0]=d[1],d[1]=v;var m=new i(d,new Array(a+1),!0);f[u]=m,p[u]=m}p[a+1]=h;for(var u=0;u<=a;++u)for(var d=f[u].vertices,y=f[u].adjacent,g=0;g<=a;++g){var x=d[g];if(x<0)y[g]=h;else for(var b=0;b<=a;++b)f[b].vertices.indexOf(x)<0&&(y[g]=f[b])}for(var _=new c(a,o,p),w=!!e,u=a+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t("robust-orientation"),a=t("simplicial-complex").compareCells;function i(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return a(t.vertices,e.vertices)}i.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter(function(t){return!t.boundary}),this.tuple=new Array(t+1);for(var a=0;a<=t;++a)this.tuple[a]=this.vertices[a];var i=l[t];i||(i=l[t]=function(t){for(var e=["function orient(){var tuple=this.tuple;return test("],r=0;r<=t;++r)r>0&&e.push(","),e.push("tuple[",r,"]");e.push(")}return orient");var a=new Function("test",e.join("")),i=n[t+1];return i||(i=n),a(i)}(t)),this.orient=i}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,a=this.tuple,i=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,h=0;h<=r;++h){var f=u[h];a[h]=f<0?e:i[f]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,a=this.vertices,i=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)i[u]=a[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var h=c[u];if(!(h.lastVisited>=r)){var f=i[u];i[u]=t;var p=this.orient();if(i[u]=f,p<0){s=h;continue t}h.boundary?h.lastVisited=-r:h.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,a=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,h=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var f=[];h.length>0;){var p=(e=h.pop()).vertices,d=e.adjacent,g=p.indexOf(r);if(!(g<0))for(var v=0;v<=n;++v)if(v!==g){var m=d[v];if(m.boundary&&!(m.lastVisited>=r)){var y=m.vertices;if(m.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=a[y[b]];if(this.orient()>0){y[x]=r,m.boundary=!1,c.push(m),h.push(m),m.lastVisited=r;continue}m.lastVisited=-r}var _=m.adjacent,w=p.slice(),k=d.slice(),T=new i(w,k,!0);u.push(T);var M=_.indexOf(e);if(!(M<0)){_[M]=T,k[g]=m,w[v]=-1,k[v]=e,d[v]=T,T.flip();for(b=0;b<=n;++b){var A=w[b];if(!(A<0||A===r)){for(var S=new Array(n-1),E=0,L=0;L<=n;++L){var C=w[L];C<0||L===b||(S[E++]=C)}f.push(new o(S,T,b))}}}}}}f.sort(s);for(v=0;v+1<f.length;v+=2){var P=f[v],O=f[v+1],z=P.index,I=O.index;z<0||I<0||(P.cell.adjacent[P.index]=O.cell,O.cell.adjacent[O.index]=P.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var a=this.dimension,i=this.tuple,o=0;o<=a;++o){var s=n.vertices[o];i[o]=s<0?t:r[s]}var l=this.orient(i);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,a=0;a<n;++a){var i=r[a];if(i.boundary){for(var o=new Array(t),s=i.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var h=o[0];o[0]=o[1],o[1]=h}e.push(o)}}return e}},{"robust-orientation":508,"simplicial-complex":518}],415:[function(t,e,r){"use strict";var n=t("binary-search-bounds"),a=0,i=1;function o(t,e,r,n,a){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=a,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new x(null);return new x(y(t))};var s=o.prototype;function l(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function c(t,e){var r=y(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function u(t,e){var r=t.intervals([]);r.push(e),c(t,r)}function h(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?a:(r.splice(n,1),c(t,r),i)}function f(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var a=r(t[n]);if(a)return a}}function p(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var a=r(t[n]);if(a)return a}}function d(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function g(t,e){return t-e}function v(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function m(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function y(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(g);var n=e[e.length>>1],a=[],i=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?a.push(l):n<l[0]?i.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(v),u.sort(m),new o(n,y(a),y(i),c,u)}function x(t){this.root=t}s.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},s.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?u(this,t):this.left.insert(t):this.left=y([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?u(this,t):this.right.insert(t):this.right=y([t]);else{var r=n.ge(this.leftPoints,t,v),a=n.ge(this.rightPoints,t,m);this.leftPoints.splice(r,0,t),this.rightPoints.splice(a,0,t)}},s.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?h(this,t):2===(c=this.left.remove(t))?(this.left=null,this.count-=1,i):(c===i&&(this.count-=1),c):a;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?h(this,t):2===(c=this.right.remove(t))?(this.right=null,this.count-=1,i):(c===i&&(this.count-=1),c):a;if(1===this.count)return this.leftPoints[0]===t?2:a;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,o=this.left;o.right;)r=o,o=o.right;if(r===this)o.right=this.right;else{var s=this.left,c=this.right;r.count-=o.count,r.right=o.left,o.left=s,o.right=c}l(this,o),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?l(this,this.left):l(this,this.right);return i}for(s=n.ge(this.leftPoints,t,v);s<this.leftPoints.length&&this.leftPoints[s][0]===t[0];++s)if(this.leftPoints[s]===t){this.count-=1,this.leftPoints.splice(s,1);for(c=n.ge(this.rightPoints,t,m);c<this.rightPoints.length&&this.rightPoints[c][1]===t[1];++c)if(this.rightPoints[c]===t)return this.rightPoints.splice(c,1),i}return a},s.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return f(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return p(this.rightPoints,t,e)}return d(this.leftPoints,e)},s.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?f(this.leftPoints,e,r):t>this.mid?p(this.rightPoints,t,r):d(this.leftPoints,r)};var b=x.prototype;b.insert=function(t){this.root?this.root.insert(t):this.root=new o(t[0],null,null,[t],[t])},b.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),e!==a}return!1},b.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},b.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(b,"count",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(b,"intervals",{get:function(){return this.root?this.root.intervals([]):[]}})},{"binary-search-bounds":93}],416:[function(t,e,r){"use strict";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],417:[function(t,e,r){"use strict";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],418:[function(t,e,r){e.exports=!0},{}],419:[function(t,e,r){function n(t){return!!t.constructor&&"function"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}e.exports=function(t){return null!=t&&(n(t)||function(t){return"function"==typeof t.readFloatLE&&"function"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],420:[function(t,e,r){"use strict";e.exports="undefined"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\//.test(navigator.appVersion))},{}],421:[function(t,e,r){"use strict";e.exports=i,e.exports.isMobile=i,e.exports.default=i;var n=/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series[46]0|symbian|treo|up\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,a=/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series[46]0|symbian|treo|up\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function i(t){t||(t={});var e=t.ua;if(e||"undefined"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&"string"==typeof e.headers["user-agent"]&&(e=e.headers["user-agent"]),"string"!=typeof e)return!1;var r=t.tablet?a.test(e):n.test(e);return!r&&t.tablet&&t.featureDetect&&navigator&&navigator.maxTouchPoints>1&&-1!==e.indexOf("Macintosh")&&-1!==e.indexOf("Safari")&&(r=!0),r}},{}],422:[function(t,e,r){"use strict";e.exports=function(t){var e=typeof t;return null!==t&&("object"===e||"function"===e)}},{}],423:[function(t,e,r){"use strict";var n=Object.prototype.toString;e.exports=function(t){var e;return"[object Object]"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],424:[function(t,e,r){"use strict";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],425:[function(t,e,r){"use strict";e.exports=function(t){return"string"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\dz]$/i.test(t)&&t.length>4))}},{}],426:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],427:[function(t,e,r){var n,a;n=this,a=function(){"use strict";var t,e,r;function n(n,a){if(t)if(e){var i="var sharedChunk = {}; ("+t+")(sharedChunk); ("+e+")(sharedChunk);",o={};t(o),(r=a(o)).workerUrl=window.URL.createObjectURL(new Blob([i],{type:"text/javascript"}))}else e=a;else t=a}return n(0,function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=n;function n(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}n.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},n.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},n.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},n.prototype.solveCurveX=function(t,e){var r,n,a,i,o;for(void 0===e&&(e=1e-6),a=t,o=0;o<8;o++){if(i=this.sampleCurveX(a)-t,Math.abs(i)<e)return a;var s=this.sampleCurveDerivativeX(a);if(Math.abs(s)<1e-6)break;a-=i/s}if((a=t)<(r=0))return r;if(a>(n=1))return n;for(;r<n;){if(i=this.sampleCurveX(a),Math.abs(i-t)<e)return a;t>i?r=a:n=a,a=.5*(n-r)+r}return a},n.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var a=i;function i(t,e){this.x=t,this.y=e}function o(t,e){if(Array.isArray(t)){if(!Array.isArray(e)||t.length!==e.length)return!1;for(var r=0;r<t.length;r++)if(!o(t[r],e[r]))return!1;return!0}if("object"==typeof t&&null!==t&&null!==e){if("object"!=typeof e)return!1;if(Object.keys(t).length!==Object.keys(e).length)return!1;for(var n in t)if(!o(t[n],e[n]))return!1;return!0}return t===e}function s(t,e,n,a){var i=new r(t,e,n,a);return function(t){return i.solve(t)}}i.prototype={clone:function(){return new i(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[0]*this.x+t[1]*this.y,r=t[2]*this.x+t[3]*this.y;return this.x=e,this.y=r,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=e*this.x-r*this.y,a=r*this.x+e*this.y;return this.x=n,this.y=a,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),a=e.x+r*(this.x-e.x)-n*(this.y-e.y),i=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=a,this.y=i,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},i.convert=function(t){return t instanceof i?t:Array.isArray(t)?new i(t[0],t[1]):t};var l=s(.25,.1,.25,1);function c(t,e,r){return Math.min(r,Math.max(e,t))}function u(t,e,r){var n=r-e,a=((t-e)%n+n)%n+e;return a===e?r:a}function h(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,a=e;n<a.length;n+=1){var i=a[n];for(var o in i)t[o]=i[o]}return t}var f=1;function p(){return f++}function d(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function g(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function v(t,e){t.forEach(function(t){e[t]&&(e[t]=e[t].bind(e))})}function m(t,e){return-1!==t.indexOf(e,t.length-e.length)}function y(t,e,r){var n={};for(var a in t)n[a]=e.call(r||this,t[a],a,t);return n}function x(t,e,r){var n={};for(var a in t)e.call(r||this,t[a],a,t)&&(n[a]=t[a]);return n}function b(t){return Array.isArray(t)?t.map(b):"object"==typeof t&&t?y(t,b):t}var _={};function w(t){_[t]||("undefined"!=typeof console&&console.warn(t),_[t]=!0)}function k(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function T(t){for(var e=0,r=0,n=t.length,a=n-1,i=void 0,o=void 0;r<n;a=r++)i=t[r],e+=((o=t[a]).x-i.x)*(i.y+o.y);return e}function M(t){var e={};if(t.replace(/(?:^|(?:\s*\,\s*))([^\x00-\x20\(\)<>@\,;\:\\"\/\[\]\?\=\{\}\x7F]+)(?:\=(?:([^\x00-\x20\(\)<>@\,;\:\\"\/\[\]\?\=\{\}\x7F]+)|(?:\"((?:[^"\\]|\\.)*)\")))?/g,function(t,r,n,a){var i=n||a;return e[r]=!i||i.toLowerCase(),""}),e["max-age"]){var r=parseInt(e["max-age"],10);isNaN(r)?delete e["max-age"]:e["max-age"]=r}return e}function A(t){try{var e=self[t];return e.setItem("_mapbox_test_",1),e.removeItem("_mapbox_test_"),!0}catch(t){return!1}}var S,E,L,C,P=self.performance&&self.performance.now?self.performance.now.bind(self.performance):Date.now.bind(Date),O=self.requestAnimationFrame||self.mozRequestAnimationFrame||self.webkitRequestAnimationFrame||self.msRequestAnimationFrame,z=self.cancelAnimationFrame||self.mozCancelAnimationFrame||self.webkitCancelAnimationFrame||self.msCancelAnimationFrame,I={now:P,frame:function(t){var e=O(t);return{cancel:function(){return z(e)}}},getImageData:function(t){var e=self.document.createElement("canvas"),r=e.getContext("2d");if(!r)throw new Error("failed to create canvas 2d context");return e.width=t.width,e.height=t.height,r.drawImage(t,0,0,t.width,t.height),r.getImageData(0,0,t.width,t.height)},resolveURL:function(t){return S||(S=self.document.createElement("a")),S.href=t,S.href},hardwareConcurrency:self.navigator.hardwareConcurrency||4,get devicePixelRatio(){return self.devicePixelRatio},get prefersReducedMotion(){return!!self.matchMedia&&(null==E&&(E=self.matchMedia("(prefers-reduced-motion: reduce)")),E.matches)}},D={API_URL:"https://api.mapbox.com",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf("https://api.mapbox.cn")?"https://events.mapbox.cn/events/v2":0===this.API_URL.indexOf("https://api.mapbox.com")?"https://events.mapbox.com/events/v2":null:null},FEEDBACK_URL:"https://apps.mapbox.com/feedback",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},R={supported:!1,testSupport:function(t){!F&&C&&(B?N(t):L=t)}},F=!1,B=!1;function N(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,C),t.isContextLost())return;R.supported=!0}catch(t){}t.deleteTexture(e),F=!0}self.document&&((C=self.document.createElement("img")).onload=function(){L&&N(L),L=null,B=!0},C.onerror=function(){F=!0,L=null},C.src="data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=");var j="01",V=function(t,e){this._transformRequestFn=t,this._customAccessToken=e,this._createSkuToken()};function U(t){return 0===t.indexOf("mapbox:")}V.prototype._createSkuToken=function(){var t=function(){for(var t="",e=0;e<10;e++)t+="0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"[Math.floor(62*Math.random())];return{token:["1",j,t].join(""),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},V.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},V.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},V.prototype.normalizeStyleURL=function(t,e){if(!U(t))return t;var r=Y(t);return r.path="/styles/v1"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},V.prototype.normalizeGlyphsURL=function(t,e){if(!U(t))return t;var r=Y(t);return r.path="/fonts/v1"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},V.prototype.normalizeSourceURL=function(t,e){if(!U(t))return t;var r=Y(t);return r.path="/v4/"+r.authority+".json",r.params.push("secure"),this._makeAPIURL(r,this._customAccessToken||e)},V.prototype.normalizeSpriteURL=function(t,e,r,n){var a=Y(t);return U(t)?(a.path="/styles/v1"+a.path+"/sprite"+e+r,this._makeAPIURL(a,this._customAccessToken||n)):(a.path+=""+e+r,W(a))},V.prototype.normalizeTileURL=function(t,e,r){if(this._isSkuTokenExpired()&&this._createSkuToken(),!e||!U(e))return t;var n=Y(t),a=I.devicePixelRatio>=2||512===r?"@2x":"",i=R.supported?".webp":"$1";return n.path=n.path.replace(/(\.(png|jpg)\d*)(?=$)/,""+a+i),n.path=n.path.replace(/^.+\/v4\//,"/"),n.path="/v4"+n.path,D.REQUIRE_ACCESS_TOKEN&&(D.ACCESS_TOKEN||this._customAccessToken)&&this._skuToken&&n.params.push("sku="+this._skuToken),this._makeAPIURL(n,this._customAccessToken)},V.prototype.canonicalizeTileURL=function(t){var e=Y(t);if(!e.path.match(/(^\/v4\/)/)||!e.path.match(/\.[\w]+$/))return t;var r="mapbox://tiles/";r+=e.path.replace("/v4/","");var n=e.params.filter(function(t){return!t.match(/^access_token=/)});return n.length&&(r+="?"+n.join("&")),r},V.prototype.canonicalizeTileset=function(t,e){if(!U(e))return t.tiles||[];for(var r=[],n=0,a=t.tiles;n<a.length;n+=1){var i=a[n],o=this.canonicalizeTileURL(i);r.push(o)}return r},V.prototype._makeAPIURL=function(t,e){var r="See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes",n=Y(D.API_URL);if(t.protocol=n.protocol,t.authority=n.authority,"/"!==n.path&&(t.path=""+n.path+t.path),!D.REQUIRE_ACCESS_TOKEN)return W(t);if(!(e=e||D.ACCESS_TOKEN))throw new Error("An API access token is required to use Mapbox GL. "+r);if("s"===e[0])throw new Error("Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). "+r);return t.params=t.params.filter(function(t){return-1===t.indexOf("access_token")}),t.params.push("access_token="+e),W(t)};var q=/^((https?:)?\/\/)?([^\/]+\.)?mapbox\.c(n|om)(\/|\?|$)/i;function H(t){return q.test(t)}var G=/^(\w+):\/\/([^\/?]*)(\/[^?]+)?\??(.+)?/;function Y(t){var e=t.match(G);if(!e)throw new Error("Unable to parse URL object");return{protocol:e[1],authority:e[2],path:e[3]||"/",params:e[4]?e[4].split("&"):[]}}function W(t){var e=t.params.length?"?"+t.params.join("&"):"";return t.protocol+"://"+t.authority+t.path+e}function X(t){if(!t)return null;var e,r=t.split(".");if(!r||3!==r.length)return null;try{return JSON.parse((e=r[1],decodeURIComponent(self.atob(e).split("").map(function(t){return"%"+("00"+t.charCodeAt(0).toString(16)).slice(-2)}).join(""))))}catch(t){return null}}var Z=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};Z.prototype.getStorageKey=function(t){var e,r=X(D.ACCESS_TOKEN),n="";return r&&r.u?(e=r.u,n=self.btoa(encodeURIComponent(e).replace(/%([0-9A-F]{2})/g,function(t,e){return String.fromCharCode(Number("0x"+e))}))):n=D.ACCESS_TOKEN||"",t?"mapbox.eventData."+t+":"+n:"mapbox.eventData:"+n},Z.prototype.fetchEventData=function(){var t=A("localStorage"),e=this.getStorageKey(),r=this.getStorageKey("uuid");if(t)try{var n=self.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var a=self.localStorage.getItem(r);a&&(this.anonId=a)}catch(t){w("Unable to read from LocalStorage")}},Z.prototype.saveEventData=function(){var t=A("localStorage"),e=this.getStorageKey(),r=this.getStorageKey("uuid");if(t)try{self.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&self.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){w("Unable to write to LocalStorage")}},Z.prototype.processRequests=function(t){},Z.prototype.postEvent=function(t,e,r,n){var a=this;if(D.EVENTS_URL){var i=Y(D.EVENTS_URL);i.params.push("access_token="+(n||D.ACCESS_TOKEN||""));var o={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:"mapbox-gl-js",sdkVersion:"1.3.2",skuId:j,userId:this.anonId},s=e?h(o,e):o,l={url:W(i),headers:{"Content-Type":"text/plain"},body:JSON.stringify([s])};this.pendingRequest=mt(l,function(t){a.pendingRequest=null,r(t),a.saveEventData(),a.processRequests(n)})}},Z.prototype.queueRequest=function(t,e){this.queue.push(t),this.processRequests(e)};var J,K=function(t){function e(){t.call(this,"map.load"),this.success={},this.skuToken=""}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postMapLoadEvent=function(t,e,r,n){this.skuToken=r,(D.EVENTS_URL&&n||D.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return U(t)||H(t)}))&&this.queueRequest({id:e,timestamp:Date.now()},n)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){var r=this.queue.shift(),n=r.id,a=r.timestamp;n&&this.success[n]||(this.anonId||this.fetchEventData(),g(this.anonId)||(this.anonId=d()),this.postEvent(a,{skuToken:this.skuToken},function(t){t||n&&(e.success[n]=!0)},t))}},e}(Z),Q=new(function(t){function e(e){t.call(this,"appUserTurnstile"),this._customAccessToken=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postTurnstileEvent=function(t,e){D.EVENTS_URL&&D.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return U(t)||H(t)})&&this.queueRequest(Date.now(),e)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var r=X(D.ACCESS_TOKEN),n=r?r.u:D.ACCESS_TOKEN,a=n!==this.eventData.tokenU;g(this.anonId)||(this.anonId=d(),a=!0);var i=this.queue.shift();if(this.eventData.lastSuccess){var o=new Date(this.eventData.lastSuccess),s=new Date(i),l=(i-this.eventData.lastSuccess)/864e5;a=a||l>=1||l<-1||o.getDate()!==s.getDate()}else a=!0;if(!a)return this.processRequests();this.postEvent(i,{"enabled.telemetry":!1},function(t){t||(e.eventData.lastSuccess=i,e.eventData.tokenU=n)},t)}},e}(Z)),$=Q.postTurnstileEvent.bind(Q),tt=new K,et=tt.postMapLoadEvent.bind(tt),rt="mapbox-tiles",nt=500,at=50,it=42e4;function ot(t){var e=t.indexOf("?");return e<0?t:t.slice(0,e)}var st=1/0,lt={Unknown:"Unknown",Style:"Style",Source:"Source",Tile:"Tile",Glyphs:"Glyphs",SpriteImage:"SpriteImage",SpriteJSON:"SpriteJSON",Image:"Image"};"function"==typeof Object.freeze&&Object.freeze(lt);var ct=function(t){function e(e,r,n){401===r&&H(n)&&(e+=": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.toString=function(){return this.name+": "+this.message+" ("+this.status+"): "+this.url},e}(Error);function ut(){return"undefined"!=typeof WorkerGlobalScope&&"undefined"!=typeof self&&self instanceof WorkerGlobalScope}var ht=ut()?function(){return self.worker&&self.worker.referrer}:function(){return("blob:"===self.location.protocol?self.parent:self).location.href};function ft(t,e){var r,n=new self.AbortController,a=new self.Request(t.url,{method:t.method||"GET",body:t.body,credentials:t.credentials,headers:t.headers,referrer:ht(),signal:n.signal}),i=!1,o=!1,s=(r=a.url).indexOf("sku=")>0&&H(r);"json"===t.type&&a.headers.set("Accept","application/json");var l=function(r,n,i){if(!o){if(r&&"SecurityError"!==r.message&&w(r),n&&i)return c(n);var l=Date.now();self.fetch(a).then(function(r){if(r.ok){var n=s?r.clone():null;return c(r,n,l)}return e(new ct(r.statusText,r.status,t.url))}).catch(function(t){20!==t.code&&e(new Error(t.message))})}},c=function(r,n,s){("arrayBuffer"===t.type?r.arrayBuffer():"json"===t.type?r.json():r.text()).then(function(t){o||(n&&s&&function(t,e,r){if(self.caches){var n={status:e.status,statusText:e.statusText,headers:new self.Headers};e.headers.forEach(function(t,e){return n.headers.set(e,t)});var a=M(e.headers.get("Cache-Control")||"");a["no-store"]||(a["max-age"]&&n.headers.set("Expires",new Date(r+1e3*a["max-age"]).toUTCString()),new Date(n.headers.get("Expires")).getTime()-r<it||function(t,e){if(void 0===J)try{new Response(new ReadableStream),J=!0}catch(t){J=!1}J?e(t.body):t.blob().then(e)}(e,function(e){var r=new self.Response(e,n);self.caches.open(rt).then(function(e){return e.put(ot(t.url),r)}).catch(function(t){return w(t.message)})}))}}(a,n,s),i=!0,e(null,t,r.headers.get("Cache-Control"),r.headers.get("Expires")))}).catch(function(t){return e(new Error(t.message))})};return s?function(t,e){if(!self.caches)return e(null);var r=ot(t.url);self.caches.open(rt).then(function(t){t.match(r).then(function(n){var a=function(t){if(!t)return!1;var e=new Date(t.headers.get("Expires")),r=M(t.headers.get("Cache-Control")||"");return e>Date.now()&&!r["no-cache"]}(n);t.delete(r),a&&t.put(r,n.clone()),e(null,n,a)}).catch(e)}).catch(e)}(a,l):l(null,null),{cancel:function(){o=!0,i||n.abort()}}}var pt,dt,gt=function(t,e){if(r=t.url,!(/^file:/.test(r)||/^file:/.test(ht())&&!/^\w+:/.test(r))){if(self.fetch&&self.Request&&self.AbortController&&self.Request.prototype.hasOwnProperty("signal"))return ft(t,e);if(ut()&&self.worker&&self.worker.actor)return self.worker.actor.send("getResource",t,e)}var r;return function(t,e){var r=new self.XMLHttpRequest;for(var n in r.open(t.method||"GET",t.url,!0),"arrayBuffer"===t.type&&(r.responseType="arraybuffer"),t.headers)r.setRequestHeader(n,t.headers[n]);return"json"===t.type&&(r.responseType="text",r.setRequestHeader("Accept","application/json")),r.withCredentials="include"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if("json"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader("Cache-Control"),r.getResponseHeader("Expires"))}else e(new ct(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},vt=function(t,e){return gt(h(t,{type:"arrayBuffer"}),e)},mt=function(t,e){return gt(h(t,{method:"POST"}),e)};pt=[],dt=0;var yt=function(t,e){if(dt>=D.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return pt.push(r),r}dt++;var n=!1,a=function(){if(!n)for(n=!0,dt--;pt.length&&dt<D.MAX_PARALLEL_IMAGE_REQUESTS;){var t=pt.shift(),e=t.requestParameters,r=t.callback;t.cancelled||(t.cancel=yt(e,r).cancel)}},i=vt(t,function(t,r,n,i){if(a(),t)e(t);else if(r){var o=new self.Image,s=self.URL||self.webkitURL;o.onload=function(){e(null,o),s.revokeObjectURL(o.src)},o.onerror=function(){return e(new Error("Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported."))};var l=new self.Blob([new Uint8Array(r)],{type:"image/png"});o.cacheControl=n,o.expires=i,o.src=r.byteLength?s.createObjectURL(l):"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII="}});return{cancel:function(){i.cancel(),a()}}};function xt(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function bt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var _t=function(t,e){void 0===e&&(e={}),h(this,e),this.type=t},wt=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,"error",h({error:e},r))}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(_t),kt=function(){};kt.prototype.on=function(t,e){return this._listeners=this._listeners||{},xt(t,e,this._listeners),this},kt.prototype.off=function(t,e){return bt(t,e,this._listeners),bt(t,e,this._oneTimeListeners),this},kt.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},xt(t,e,this._oneTimeListeners),this},kt.prototype.fire=function(t,e){"string"==typeof t&&(t=new _t(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,a=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<a.length;n+=1)a[n].call(this,t);for(var i=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];i<o.length;i+=1){var s=o[i];bt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(h(t,"function"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof wt&&console.error(t.error);return this},kt.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},kt.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var Tt={$version:8,$root:{version:{required:!0,type:"enum",values:[8]},name:{type:"string"},metadata:{type:"*"},center:{type:"array",value:"number"},zoom:{type:"number"},bearing:{type:"number",default:0,period:360,units:"degrees"},pitch:{type:"number",default:0,units:"degrees"},light:{type:"light"},sources:{required:!0,type:"sources"},sprite:{type:"string"},glyphs:{type:"string"},transition:{type:"transition"},layers:{required:!0,type:"array",value:"layer"}},sources:{"*":{type:"source"}},source:["source_vector","source_raster","source_raster_dem","source_geojson","source_video","source_image"],source_vector:{type:{required:!0,type:"enum",values:{vector:{}}},url:{type:"string"},tiles:{type:"array",value:"string"},bounds:{type:"array",value:"number",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:"enum",values:{xyz:{},tms:{}},default:"xyz"},minzoom:{type:"number",default:0},maxzoom:{type:"number",default:22},attribution:{type:"string"},"*":{type:"*"}},source_raster:{type:{required:!0,type:"enum",values:{raster:{}}},url:{type:"string"},tiles:{type:"array",value:"string"},bounds:{type:"array",value:"number",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:"number",default:0},maxzoom:{type:"number",default:22},tileSize:{type:"number",default:512,units:"pixels"},scheme:{type:"enum",values:{xyz:{},tms:{}},default:"xyz"},attribution:{type:"string"},"*":{type:"*"}},source_raster_dem:{type:{required:!0,type:"enum",values:{"raster-dem":{}}},url:{type:"string"},tiles:{type:"array",value:"string"},bounds:{type:"array",value:"number",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:"number",default:0},maxzoom:{type:"number",default:22},tileSize:{type:"number",default:512,units:"pixels"},attribution:{type:"string"},encoding:{type:"enum",values:{terrarium:{},mapbox:{}},default:"mapbox"},"*":{type:"*"}},source_geojson:{type:{required:!0,type:"enum",values:{geojson:{}}},data:{type:"*"},maxzoom:{type:"number",default:18},attribution:{type:"string"},buffer:{type:"number",default:128,maximum:512,minimum:0},tolerance:{type:"number",default:.375},cluster:{type:"boolean",default:!1},clusterRadius:{type:"number",default:50,minimum:0},clusterMaxZoom:{type:"number"},clusterProperties:{type:"*"},lineMetrics:{type:"boolean",default:!1},generateId:{type:"boolean",default:!1}},source_video:{type:{required:!0,type:"enum",values:{video:{}}},urls:{required:!0,type:"array",value:"string"},coordinates:{required:!0,type:"array",length:4,value:{type:"array",length:2,value:"number"}}},source_image:{type:{required:!0,type:"enum",values:{image:{}}},url:{required:!0,type:"string"},coordinates:{required:!0,type:"array",length:4,value:{type:"array",length:2,value:"number"}}},layer:{id:{type:"string",required:!0},type:{type:"enum",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},"fill-extrusion":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:"*"},source:{type:"string"},"source-layer":{type:"string"},minzoom:{type:"number",minimum:0,maximum:24},maxzoom:{type:"number",minimum:0,maximum:24},filter:{type:"filter"},layout:{type:"layout"},paint:{type:"paint"}},layout:["layout_fill","layout_line","layout_circle","layout_heatmap","layout_fill-extrusion","layout_symbol","layout_raster","layout_hillshade","layout_background"],layout_background:{visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},layout_fill:{"fill-sort-key":{type:"number",expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},layout_circle:{"circle-sort-key":{type:"number",expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},layout_heatmap:{visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},"layout_fill-extrusion":{visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},layout_line:{"line-cap":{type:"enum",values:{butt:{},round:{},square:{}},default:"butt",expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"line-join":{type:"enum",values:{bevel:{},round:{},miter:{}},default:"miter",expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"line-miter-limit":{type:"number",default:2,requires:[{"line-join":"miter"}],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"line-round-limit":{type:"number",default:1.05,requires:[{"line-join":"round"}],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"line-sort-key":{type:"number",expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},layout_symbol:{"symbol-placement":{type:"enum",values:{point:{},line:{},"line-center":{}},default:"point",expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"symbol-spacing":{type:"number",default:250,minimum:1,units:"pixels",requires:[{"symbol-placement":"line"}],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"symbol-avoid-edges":{type:"boolean",default:!1,expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"symbol-sort-key":{type:"number",expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"symbol-z-order":{type:"enum",values:{auto:{},"viewport-y":{},source:{}},default:"auto",expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"icon-allow-overlap":{type:"boolean",default:!1,requires:["icon-image"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"icon-ignore-placement":{type:"boolean",default:!1,requires:["icon-image"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"icon-optional":{type:"boolean",default:!1,requires:["icon-image","text-field"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"icon-rotation-alignment":{type:"enum",values:{map:{},viewport:{},auto:{}},default:"auto",requires:["icon-image"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"icon-size":{type:"number",default:1,minimum:0,units:"factor of the original icon size",requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom","feature"]},"property-type":"data-driven"},"icon-text-fit":{type:"enum",values:{none:{},width:{},height:{},both:{}},default:"none",requires:["icon-image","text-field"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"icon-text-fit-padding":{type:"array",value:"number",length:4,default:[0,0,0,0],units:"pixels",requires:["icon-image","text-field",{"icon-text-fit":["both","width","height"]}],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"icon-image":{type:"string",tokens:!0,expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"icon-rotate":{type:"number",default:0,period:360,units:"degrees",requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom","feature"]},"property-type":"data-driven"},"icon-padding":{type:"number",default:2,minimum:0,units:"pixels",requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"icon-keep-upright":{type:"boolean",default:!1,requires:["icon-image",{"icon-rotation-alignment":"map"},{"symbol-placement":["line","line-center"]}],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"icon-offset":{type:"array",value:"number",length:2,default:[0,0],requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom","feature"]},"property-type":"data-driven"},"icon-anchor":{type:"enum",values:{center:{},left:{},right:{},top:{},bottom:{},"top-left":{},"top-right":{},"bottom-left":{},"bottom-right":{}},default:"center",requires:["icon-image"],expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"icon-pitch-alignment":{type:"enum",values:{map:{},viewport:{},auto:{}},default:"auto",requires:["icon-image"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-pitch-alignment":{type:"enum",values:{map:{},viewport:{},auto:{}},default:"auto",requires:["text-field"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-rotation-alignment":{type:"enum",values:{map:{},viewport:{},auto:{}},default:"auto",requires:["text-field"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-field":{type:"formatted",default:"",tokens:!0,expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-font":{type:"array",value:"string",default:["Open Sans Regular","Arial Unicode MS Regular"],requires:["text-field"],expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-size":{type:"number",default:16,minimum:0,units:"pixels",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-max-width":{type:"number",default:10,minimum:0,units:"ems",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-line-height":{type:"number",default:1.2,units:"ems",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"text-letter-spacing":{type:"number",default:0,units:"ems",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-justify":{type:"enum",values:{auto:{},left:{},center:{},right:{}},default:"center",requires:["text-field"],expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-radial-offset":{type:"number",units:"ems",default:0,requires:["text-field"],"property-type":"data-driven",expression:{interpolated:!0,parameters:["zoom","feature"]}},"text-variable-anchor":{type:"array",value:"enum",values:{center:{},left:{},right:{},top:{},bottom:{},"top-left":{},"top-right":{},"bottom-left":{},"bottom-right":{}},requires:["text-field",{"symbol-placement":["point"]}],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-anchor":{type:"enum",values:{center:{},left:{},right:{},top:{},bottom:{},"top-left":{},"top-right":{},"bottom-left":{},"bottom-right":{}},default:"center",requires:["text-field",{"!":"text-variable-anchor"}],expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-max-angle":{type:"number",default:45,units:"degrees",requires:["text-field",{"symbol-placement":["line","line-center"]}],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"text-writing-mode":{type:"array",value:"enum",values:{horizontal:{},vertical:{}},requires:["text-field",{"symbol-placement":["point"]}],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-rotate":{type:"number",default:0,period:360,units:"degrees",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-padding":{type:"number",default:2,minimum:0,units:"pixels",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"text-keep-upright":{type:"boolean",default:!0,requires:["text-field",{"text-rotation-alignment":"map"},{"symbol-placement":["line","line-center"]}],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-transform":{type:"enum",values:{none:{},uppercase:{},lowercase:{}},default:"none",requires:["text-field"],expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-offset":{type:"array",value:"number",units:"ems",length:2,default:[0,0],requires:["text-field",{"!":"text-radial-offset"},{"!":"text-variable-anchor"}],expression:{interpolated:!0,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-allow-overlap":{type:"boolean",default:!1,requires:["text-field"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-ignore-placement":{type:"boolean",default:!1,requires:["text-field"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-optional":{type:"boolean",default:!1,requires:["text-field","icon-image"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},layout_raster:{visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},layout_hillshade:{visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},filter:{type:"array",value:"*"},filter_operator:{type:"enum",values:{"==":{},"!=":{},">":{},">=":{},"<":{},"<=":{},in:{},"!in":{},all:{},any:{},none:{},has:{},"!has":{}}},geometry_type:{type:"enum",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:"expression"},stops:{type:"array",value:"function_stop"},base:{type:"number",default:1,minimum:0},property:{type:"string",default:"$zoom"},type:{type:"enum",values:{identity:{},exponential:{},interval:{},categorical:{}},default:"exponential"},colorSpace:{type:"enum",values:{rgb:{},lab:{},hcl:{}},default:"rgb"},default:{type:"*",required:!1}},function_stop:{type:"array",minimum:0,maximum:22,value:["number","color"],length:2},expression:{type:"array",value:"*",minimum:1},expression_name:{type:"enum",values:{let:{group:"Variable binding"},var:{group:"Variable binding"},literal:{group:"Types"},array:{group:"Types"},at:{group:"Lookup"},case:{group:"Decision"},match:{group:"Decision"},coalesce:{group:"Decision"},step:{group:"Ramps, scales, curves"},interpolate:{group:"Ramps, scales, curves"},"interpolate-hcl":{group:"Ramps, scales, curves"},"interpolate-lab":{group:"Ramps, scales, curves"},ln2:{group:"Math"},pi:{group:"Math"},e:{group:"Math"},typeof:{group:"Types"},string:{group:"Types"},number:{group:"Types"},boolean:{group:"Types"},object:{group:"Types"},collator:{group:"Types"},format:{group:"Types"},"number-format":{group:"Types"},"to-string":{group:"Types"},"to-number":{group:"Types"},"to-boolean":{group:"Types"},"to-rgba":{group:"Color"},"to-color":{group:"Types"},rgb:{group:"Color"},rgba:{group:"Color"},get:{group:"Lookup"},has:{group:"Lookup"},length:{group:"Lookup"},properties:{group:"Feature data"},"feature-state":{group:"Feature data"},"geometry-type":{group:"Feature data"},id:{group:"Feature data"},zoom:{group:"Zoom"},"heatmap-density":{group:"Heatmap"},"line-progress":{group:"Feature data"},accumulated:{group:"Feature data"},"+":{group:"Math"},"*":{group:"Math"},"-":{group:"Math"},"/":{group:"Math"},"%":{group:"Math"},"^":{group:"Math"},sqrt:{group:"Math"},log10:{group:"Math"},ln:{group:"Math"},log2:{group:"Math"},sin:{group:"Math"},cos:{group:"Math"},tan:{group:"Math"},asin:{group:"Math"},acos:{group:"Math"},atan:{group:"Math"},min:{group:"Math"},max:{group:"Math"},round:{group:"Math"},abs:{group:"Math"},ceil:{group:"Math"},floor:{group:"Math"},"==":{group:"Decision"},"!=":{group:"Decision"},">":{group:"Decision"},"<":{group:"Decision"},">=":{group:"Decision"},"<=":{group:"Decision"},all:{group:"Decision"},any:{group:"Decision"},"!":{group:"Decision"},"is-supported-script":{group:"String"},upcase:{group:"String"},downcase:{group:"String"},concat:{group:"String"},"resolved-locale":{group:"String"}}},light:{anchor:{type:"enum",default:"viewport",values:{map:{},viewport:{}},"property-type":"data-constant",transition:!1,expression:{interpolated:!1,parameters:["zoom"]}},position:{type:"array",default:[1.15,210,30],length:3,value:"number","property-type":"data-constant",transition:!0,expression:{interpolated:!0,parameters:["zoom"]}},color:{type:"color","property-type":"data-constant",default:"#ffffff",expression:{interpolated:!0,parameters:["zoom"]},transition:!0},intensity:{type:"number","property-type":"data-constant",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:["zoom"]},transition:!0}},paint:["paint_fill","paint_line","paint_circle","paint_heatmap","paint_fill-extrusion","paint_symbol","paint_raster","paint_hillshade","paint_background"],paint_fill:{"fill-antialias":{type:"boolean",default:!0,expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"fill-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"fill-color":{type:"color",default:"#000000",transition:!0,requires:[{"!":"fill-pattern"}],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"fill-outline-color":{type:"color",transition:!0,requires:[{"!":"fill-pattern"},{"fill-antialias":!0}],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"fill-translate":{type:"array",value:"number",length:2,default:[0,0],transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"fill-translate-anchor":{type:"enum",values:{map:{},viewport:{}},default:"map",requires:["fill-translate"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"fill-pattern":{type:"string",transition:!0,expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"cross-faded-data-driven"}},"paint_fill-extrusion":{"fill-extrusion-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"fill-extrusion-color":{type:"color",default:"#000000",transition:!0,requires:[{"!":"fill-extrusion-pattern"}],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"fill-extrusion-translate":{type:"array",value:"number",length:2,default:[0,0],transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"fill-extrusion-translate-anchor":{type:"enum",values:{map:{},viewport:{}},default:"map",requires:["fill-extrusion-translate"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"fill-extrusion-pattern":{type:"string",transition:!0,expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"cross-faded-data-driven"},"fill-extrusion-height":{type:"number",default:0,minimum:0,units:"meters",transition:!0,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"fill-extrusion-base":{type:"number",default:0,minimum:0,units:"meters",transition:!0,requires:["fill-extrusion-height"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"fill-extrusion-vertical-gradient":{type:"boolean",default:!0,transition:!1,expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"}},paint_line:{"line-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"line-color":{type:"color",default:"#000000",transition:!0,requires:[{"!":"line-pattern"}],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"line-translate":{type:"array",value:"number",length:2,default:[0,0],transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"line-translate-anchor":{type:"enum",values:{map:{},viewport:{}},default:"map",requires:["line-translate"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"line-width":{type:"number",default:1,minimum:0,transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"line-gap-width":{type:"number",default:0,minimum:0,transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"line-offset":{type:"number",default:0,transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"line-blur":{type:"number",default:0,minimum:0,transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"line-dasharray":{type:"array",value:"number",minimum:0,transition:!0,units:"line widths",requires:[{"!":"line-pattern"}],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"cross-faded"},"line-pattern":{type:"string",transition:!0,expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"cross-faded-data-driven"},"line-gradient":{type:"color",transition:!1,requires:[{"!":"line-dasharray"},{"!":"line-pattern"},{source:"geojson",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:["line-progress"]},"property-type":"color-ramp"}},paint_circle:{"circle-radius":{type:"number",default:5,minimum:0,transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"circle-color":{type:"color",default:"#000000",transition:!0,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"circle-blur":{type:"number",default:0,transition:!0,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"circle-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"circle-translate":{type:"array",value:"number",length:2,default:[0,0],transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"circle-translate-anchor":{type:"enum",values:{map:{},viewport:{}},default:"map",requires:["circle-translate"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"circle-pitch-scale":{type:"enum",values:{map:{},viewport:{}},default:"map",expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"circle-pitch-alignment":{type:"enum",values:{map:{},viewport:{}},default:"viewport",expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"circle-stroke-width":{type:"number",default:0,minimum:0,transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"circle-stroke-color":{type:"color",default:"#000000",transition:!0,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"circle-stroke-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"}},paint_heatmap:{"heatmap-radius":{type:"number",default:30,minimum:1,transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"heatmap-weight":{type:"number",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"heatmap-intensity":{type:"number",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"heatmap-color":{type:"color",default:["interpolate",["linear"],["heatmap-density"],0,"rgba(0, 0, 255, 0)",.1,"royalblue",.3,"cyan",.5,"lime",.7,"yellow",1,"red"],transition:!1,expression:{interpolated:!0,parameters:["heatmap-density"]},"property-type":"color-ramp"},"heatmap-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"}},paint_symbol:{"icon-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"icon-color":{type:"color",default:"#000000",transition:!0,requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"icon-halo-color":{type:"color",default:"rgba(0, 0, 0, 0)",transition:!0,requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"icon-halo-width":{type:"number",default:0,minimum:0,transition:!0,units:"pixels",requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"icon-halo-blur":{type:"number",default:0,minimum:0,transition:!0,units:"pixels",requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"icon-translate":{type:"array",value:"number",length:2,default:[0,0],transition:!0,units:"pixels",requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"icon-translate-anchor":{type:"enum",values:{map:{},viewport:{}},default:"map",requires:["icon-image","icon-translate"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"text-color":{type:"color",default:"#000000",transition:!0,overridable:!0,requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"text-halo-color":{type:"color",default:"rgba(0, 0, 0, 0)",transition:!0,requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"text-halo-width":{type:"number",default:0,minimum:0,transition:!0,units:"pixels",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"text-halo-blur":{type:"number",default:0,minimum:0,transition:!0,units:"pixels",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"text-translate":{type:"array",value:"number",length:2,default:[0,0],transition:!0,units:"pixels",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"text-translate-anchor":{type:"enum",values:{map:{},viewport:{}},default:"map",requires:["text-field","text-translate"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"}},paint_raster:{"raster-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"raster-hue-rotate":{type:"number",default:0,period:360,transition:!0,units:"degrees",expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"raster-brightness-min":{type:"number",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"raster-brightness-max":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"raster-saturation":{type:"number",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"raster-contrast":{type:"number",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"raster-resampling":{type:"enum",values:{linear:{},nearest:{}},default:"linear",expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"raster-fade-duration":{type:"number",default:300,minimum:0,transition:!1,units:"milliseconds",expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"}},paint_hillshade:{"hillshade-illumination-direction":{type:"number",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"hillshade-illumination-anchor":{type:"enum",values:{map:{},viewport:{}},default:"viewport",expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"hillshade-exaggeration":{type:"number",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"hillshade-shadow-color":{type:"color",default:"#000000",transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"hillshade-highlight-color":{type:"color",default:"#FFFFFF",transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"hillshade-accent-color":{type:"color",default:"#000000",transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"}},paint_background:{"background-color":{type:"color",default:"#000000",transition:!0,requires:[{"!":"background-pattern"}],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"background-pattern":{type:"string",transition:!0,expression:{interpolated:!1,parameters:["zoom"]},"property-type":"cross-faded"},"background-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"}},transition:{duration:{type:"number",default:300,minimum:0,units:"milliseconds"},delay:{type:"number",default:0,minimum:0,units:"milliseconds"}},"property-type":{"data-driven":{type:"property-type"},"cross-faded":{type:"property-type"},"cross-faded-data-driven":{type:"property-type"},"color-ramp":{type:"property-type"},"data-constant":{type:"property-type"},constant:{type:"property-type"}}},Mt=function(t,e,r,n){this.message=(t?t+": ":"")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function At(t){var e=t.key,r=t.value;return r?[new Mt(e,r,"constants have been deprecated as of v8")]:[]}function St(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,a=e;n<a.length;n+=1){var i=a[n];for(var o in i)t[o]=i[o]}return t}function Et(t){return t instanceof Number||t instanceof String||t instanceof Boolean}function Lt(t){return Et(t)?t.valueOf():t}function Ct(t){if(Array.isArray(t))return t.map(Ct);if(t instanceof Object&&!Et(t)){var e={};for(var r in t)e[r]=Ct(t[r]);return e}return Lt(t)}var Pt=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Error),Ot=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var a=n[r],i=a[0],o=a[1];this.bindings[i]=o}};Ot.prototype.concat=function(t){return new Ot(this,t)},Ot.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+" not found in scope.")},Ot.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var zt={kind:"null"},It={kind:"number"},Dt={kind:"string"},Rt={kind:"boolean"},Ft={kind:"color"},Bt={kind:"object"},Nt={kind:"value"},jt={kind:"collator"},Vt={kind:"formatted"};function Ut(t,e){return{kind:"array",itemType:t,N:e}}function qt(t){if("array"===t.kind){var e=qt(t.itemType);return"number"==typeof t.N?"array<"+e+", "+t.N+">":"value"===t.itemType.kind?"array":"array<"+e+">"}return t.kind}var Ht=[zt,It,Dt,Rt,Ft,Vt,Bt,Ut(Nt)];function Gt(t,e){if("error"===e.kind)return null;if("array"===t.kind){if("array"===e.kind&&(0===e.N&&"value"===e.itemType.kind||!Gt(t.itemType,e.itemType))&&("number"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if("value"===t.kind)for(var r=0,n=Ht;r<n.length;r+=1)if(!Gt(n[r],e))return null}return"Expected "+qt(t)+" but found "+qt(e)+" instead."}var Yt=e(function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function a(t){return t<0?0:t>1?1:t}function i(t){return"%"===t[t.length-1]?n(parseFloat(t)/100*255):n(parseInt(t))}function o(t){return"%"===t[t.length-1]?a(parseFloat(t)/100):a(parseFloat(t))}function s(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,a=t.replace(/ /g,"").toLowerCase();if(a in r)return r[a].slice();if("#"===a[0])return 4===a.length?(e=parseInt(a.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===a.length&&(e=parseInt(a.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=a.indexOf("("),c=a.indexOf(")");if(-1!==l&&c+1===a.length){var u=a.substr(0,l),h=a.substr(l+1,c-(l+1)).split(","),f=1;switch(u){case"rgba":if(4!==h.length)return null;f=o(h.pop());case"rgb":return 3!==h.length?null:[i(h[0]),i(h[1]),i(h[2]),f];case"hsla":if(4!==h.length)return null;f=o(h.pop());case"hsl":if(3!==h.length)return null;var p=(parseFloat(h[0])%360+360)%360/360,d=o(h[1]),g=o(h[2]),v=g<=.5?g*(d+1):g+d-g*d,m=2*g-v;return[n(255*s(m,v,p+1/3)),n(255*s(m,v,p)),n(255*s(m,v,p-1/3)),f];default:return null}}return null}}catch(t){}}).parseCSSColor,Wt=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};Wt.parse=function(t){if(t){if(t instanceof Wt)return t;if("string"==typeof t){var e=Yt(t);if(e)return new Wt(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},Wt.prototype.toString=function(){var t=this.toArray(),e=t[0],r=t[1],n=t[2],a=t[3];return"rgba("+Math.round(e)+","+Math.round(r)+","+Math.round(n)+","+a+")"},Wt.prototype.toArray=function(){var t=this.r,e=this.g,r=this.b,n=this.a;return 0===n?[0,0,0,0]:[255*t/n,255*e/n,255*r/n,n]},Wt.black=new Wt(0,0,0,1),Wt.white=new Wt(1,1,1,1),Wt.transparent=new Wt(0,0,0,0),Wt.red=new Wt(1,0,0,1);var Xt=function(t,e,r){this.sensitivity=t?e?"variant":"case":e?"accent":"base",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:"search"})};Xt.prototype.compare=function(t,e){return this.collator.compare(t,e)},Xt.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var Zt=function(t,e,r,n){this.text=t,this.scale=e,this.fontStack=r,this.textColor=n},Jt=function(t){this.sections=t};function Kt(t,e,r,n){return"number"==typeof t&&t>=0&&t<=255&&"number"==typeof e&&e>=0&&e<=255&&"number"==typeof r&&r>=0&&r<=255?void 0===n||"number"==typeof n&&n>=0&&n<=1?null:"Invalid rgba value ["+[t,e,r,n].join(", ")+"]: 'a' must be between 0 and 1.":"Invalid rgba value ["+("number"==typeof n?[t,e,r,n]:[t,e,r]).join(", ")+"]: 'r', 'g', and 'b' must be between 0 and 255."}function Qt(t){if(null===t)return zt;if("string"==typeof t)return Dt;if("boolean"==typeof t)return Rt;if("number"==typeof t)return It;if(t instanceof Wt)return Ft;if(t instanceof Xt)return jt;if(t instanceof Jt)return Vt;if(Array.isArray(t)){for(var e,r=t.length,n=0,a=t;n<a.length;n+=1){var i=Qt(a[n]);if(e){if(e===i)continue;e=Nt;break}e=i}return Ut(e||Nt,r)}return Bt}function $t(t){var e=typeof t;return null===t?"":"string"===e||"number"===e||"boolean"===e?String(t):t instanceof Wt||t instanceof Jt?t.toString():JSON.stringify(t)}Jt.fromString=function(t){return new Jt([new Zt(t,null,null,null)])},Jt.prototype.toString=function(){return this.sections.map(function(t){return t.text}).join("")},Jt.prototype.serialize=function(){for(var t=["format"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text);var a={};n.fontStack&&(a["text-font"]=["literal",n.fontStack.split(",")]),n.scale&&(a["font-scale"]=n.scale),n.textColor&&(a["text-color"]=["rgba"].concat(n.textColor.toArray())),t.push(a)}return t};var te=function(t,e){this.type=t,this.value=e};te.parse=function(t,e){if(2!==t.length)return e.error("'literal' expression requires exactly one argument, but found "+(t.length-1)+" instead.");if(!function t(e){if(null===e)return!0;if("string"==typeof e)return!0;if("boolean"==typeof e)return!0;if("number"==typeof e)return!0;if(e instanceof Wt)return!0;if(e instanceof Xt)return!0;if(e instanceof Jt)return!0;if(Array.isArray(e)){for(var r=0,n=e;r<n.length;r+=1)if(!t(n[r]))return!1;return!0}if("object"==typeof e){for(var a in e)if(!t(e[a]))return!1;return!0}return!1}(t[1]))return e.error("invalid value");var r=t[1],n=Qt(r),a=e.expectedType;return"array"!==n.kind||0!==n.N||!a||"array"!==a.kind||"number"==typeof a.N&&0!==a.N||(n=a),new te(n,r)},te.prototype.evaluate=function(){return this.value},te.prototype.eachChild=function(){},te.prototype.possibleOutputs=function(){return[this.value]},te.prototype.serialize=function(){return"array"===this.type.kind||"object"===this.type.kind?["literal",this.value]:this.value instanceof Wt?["rgba"].concat(this.value.toArray()):this.value instanceof Jt?this.value.serialize():this.value};var ee=function(t){this.name="ExpressionEvaluationError",this.message=t};ee.prototype.toJSON=function(){return this.message};var re={string:Dt,number:It,boolean:Rt,object:Bt},ne=function(t,e){this.type=t,this.args=e};ne.parse=function(t,e){if(t.length<2)return e.error("Expected at least one argument.");var r,n=1,a=t[0];if("array"===a){var i,o;if(t.length>2){var s=t[1];if("string"!=typeof s||!(s in re)||"object"===s)return e.error('The item type argument of "array" must be one of string, number, boolean',1);i=re[s],n++}else i=Nt;if(t.length>3){if(null!==t[2]&&("number"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to "array" must be a positive integer literal',2);o=t[2],n++}r=Ut(i,o)}else r=re[a];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,Nt);if(!c)return null;l.push(c)}return new ne(r,l)},ne.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!Gt(this.type,Qt(r)))return r;if(e===this.args.length-1)throw new ee("Expected value to be of type "+qt(this.type)+", but found "+qt(Qt(r))+" instead.")}return null},ne.prototype.eachChild=function(t){this.args.forEach(t)},ne.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},ne.prototype.serialize=function(){var t=this.type,e=[t.kind];if("array"===t.kind){var r=t.itemType;if("string"===r.kind||"number"===r.kind||"boolean"===r.kind){e.push(r.kind);var n=t.N;("number"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map(function(t){return t.serialize()}))};var ae=function(t){this.type=Vt,this.sections=t};ae.parse=function(t,e){if(t.length<3)return e.error("Expected at least two arguments.");if((t.length-1)%2!=0)return e.error("Expected an even number of arguments.");for(var r=[],n=1;n<t.length-1;n+=2){var a=e.parse(t[n],1,Nt);if(!a)return null;var i=a.type.kind;if("string"!==i&&"value"!==i&&"null"!==i)return e.error("Formatted text type must be 'string', 'value', or 'null'.");var o=t[n+1];if("object"!=typeof o||Array.isArray(o))return e.error("Format options argument must be an object.");var s=null;if(o["font-scale"]&&!(s=e.parse(o["font-scale"],1,It)))return null;var l=null;if(o["text-font"]&&!(l=e.parse(o["text-font"],1,Ut(Dt))))return null;var c=null;if(o["text-color"]&&!(c=e.parse(o["text-color"],1,Ft)))return null;r.push({text:a,scale:s,font:l,textColor:c})}return new ae(r)},ae.prototype.evaluate=function(t){return new Jt(this.sections.map(function(e){return new Zt($t(e.text.evaluate(t)),e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(","):null,e.textColor?e.textColor.evaluate(t):null)}))},ae.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.text),n.scale&&t(n.scale),n.font&&t(n.font),n.textColor&&t(n.textColor)}},ae.prototype.possibleOutputs=function(){return[void 0]},ae.prototype.serialize=function(){for(var t=["format"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text.serialize());var a={};n.scale&&(a["font-scale"]=n.scale.serialize()),n.font&&(a["text-font"]=n.font.serialize()),n.textColor&&(a["text-color"]=n.textColor.serialize()),t.push(a)}return t};var ie={"to-boolean":Rt,"to-color":Ft,"to-number":It,"to-string":Dt},oe=function(t,e){this.type=t,this.args=e};oe.parse=function(t,e){if(t.length<2)return e.error("Expected at least one argument.");var r=t[0];if(("to-boolean"===r||"to-string"===r)&&2!==t.length)return e.error("Expected one argument.");for(var n=ie[r],a=[],i=1;i<t.length;i++){var o=e.parse(t[i],i,Nt);if(!o)return null;a.push(o)}return new oe(n,a)},oe.prototype.evaluate=function(t){if("boolean"===this.type.kind)return Boolean(this.args[0].evaluate(t));if("color"===this.type.kind){for(var e,r,n=0,a=this.args;n<a.length;n+=1){if(r=null,(e=a[n].evaluate(t))instanceof Wt)return e;if("string"==typeof e){var i=t.parseColor(e);if(i)return i}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?"Invalid rbga value "+JSON.stringify(e)+": expected an array containing either three or four numeric values.":Kt(e[0],e[1],e[2],e[3])))return new Wt(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new ee(r||"Could not parse color from value '"+("string"==typeof e?e:String(JSON.stringify(e)))+"'")}if("number"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new ee("Could not convert "+JSON.stringify(o)+" to number.")}return"formatted"===this.type.kind?Jt.fromString($t(this.args[0].evaluate(t))):$t(this.args[0].evaluate(t))},oe.prototype.eachChild=function(t){this.args.forEach(t)},oe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},oe.prototype.serialize=function(){if("formatted"===this.type.kind)return new ae([{text:this.args[0],scale:null,font:null,textColor:null}]).serialize();var t=["to-"+this.type.kind];return this.eachChild(function(e){t.push(e.serialize())}),t};var se=["Unknown","Point","LineString","Polygon"],le=function(){this.globals=null,this.feature=null,this.featureState=null,this.formattedSection=null,this._parseColorCache={}};le.prototype.id=function(){return this.feature&&"id"in this.feature?this.feature.id:null},le.prototype.geometryType=function(){return this.feature?"number"==typeof this.feature.type?se[this.feature.type]:this.feature.type:null},le.prototype.properties=function(){return this.feature&&this.feature.properties||{}},le.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=Wt.parse(t)),e};var ce=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};ce.prototype.evaluate=function(t){return this._evaluate(t,this.args)},ce.prototype.eachChild=function(t){this.args.forEach(t)},ce.prototype.possibleOutputs=function(){return[void 0]},ce.prototype.serialize=function(){return[this.name].concat(this.args.map(function(t){return t.serialize()}))},ce.parse=function(t,e){var r,n=t[0],a=ce.definitions[n];if(!a)return e.error('Unknown expression "'+n+'". If you wanted a literal array, use ["literal", [...]].',0);for(var i=Array.isArray(a)?a[0]:a.type,o=Array.isArray(a)?[[a[1],a[2]]]:a.overloads,s=o.filter(function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1}),l=null,c=0,u=s;c<u.length;c+=1){var h=u[c],f=h[0],p=h[1];l=new ge(e.registry,e.path,null,e.scope);for(var d=[],g=!1,v=1;v<t.length;v++){var m=t[v],y=Array.isArray(f)?f[v-1]:f.type,x=l.parse(m,1+d.length,y);if(!x){g=!0;break}d.push(x)}if(!g)if(Array.isArray(f)&&f.length!==d.length)l.error("Expected "+f.length+" arguments, but found "+d.length+" instead.");else{for(var b=0;b<d.length;b++){var _=Array.isArray(f)?f[b]:f.type,w=d[b];l.concat(b+1).checkSubtype(_,w.type)}if(0===l.errors.length)return new ce(n,i,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var k=(s.length?s:o).map(function(t){var e;return e=t[0],Array.isArray(e)?"("+e.map(qt).join(", ")+")":"("+qt(e.type)+"...)"}).join(" | "),T=[],M=1;M<t.length;M++){var A=e.parse(t[M],1+T.length);if(!A)return null;T.push(qt(A.type))}e.error("Expected arguments of type "+k+", but found ("+T.join(", ")+") instead.")}return null},ce.register=function(t,e){for(var r in ce.definitions=e,e)t[r]=ce};var ue=function(t,e,r){this.type=jt,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};function he(t){if(t instanceof ce){if("get"===t.name&&1===t.args.length)return!1;if("feature-state"===t.name)return!1;if("has"===t.name&&1===t.args.length)return!1;if("properties"===t.name||"geometry-type"===t.name||"id"===t.name)return!1;if(/^filter-/.test(t.name))return!1}var e=!0;return t.eachChild(function(t){e&&!he(t)&&(e=!1)}),e}function fe(t){if(t instanceof ce&&"feature-state"===t.name)return!1;var e=!0;return t.eachChild(function(t){e&&!fe(t)&&(e=!1)}),e}function pe(t,e){if(t instanceof ce&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild(function(t){r&&!pe(t,e)&&(r=!1)}),r}ue.parse=function(t,e){if(2!==t.length)return e.error("Expected one argument.");var r=t[1];if("object"!=typeof r||Array.isArray(r))return e.error("Collator options argument must be an object.");var n=e.parse(void 0!==r["case-sensitive"]&&r["case-sensitive"],1,Rt);if(!n)return null;var a=e.parse(void 0!==r["diacritic-sensitive"]&&r["diacritic-sensitive"],1,Rt);if(!a)return null;var i=null;return r.locale&&!(i=e.parse(r.locale,1,Dt))?null:new ue(n,a,i)},ue.prototype.evaluate=function(t){return new Xt(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},ue.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},ue.prototype.possibleOutputs=function(){return[void 0]},ue.prototype.serialize=function(){var t={};return t["case-sensitive"]=this.caseSensitive.serialize(),t["diacritic-sensitive"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),["collator",t]};var de=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};de.parse=function(t,e){if(2!==t.length||"string"!=typeof t[1])return e.error("'var' expression requires exactly one string literal argument.");var r=t[1];return e.scope.has(r)?new de(r,e.scope.get(r)):e.error('Unknown variable "'+r+'". Make sure "'+r+'" has been bound in an enclosing "let" expression before using it.',1)},de.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},de.prototype.eachChild=function(){},de.prototype.possibleOutputs=function(){return[void 0]},de.prototype.serialize=function(){return["var",this.name]};var ge=function(t,e,r,n,a){void 0===e&&(e=[]),void 0===n&&(n=new Ot),void 0===a&&(a=[]),this.registry=t,this.path=e,this.key=e.map(function(t){return"["+t+"]"}).join(""),this.scope=n,this.errors=a,this.expectedType=r};function ve(t,e){for(var r,n,a=t.length-1,i=0,o=a,s=0;i<=o;)if(r=t[s=Math.floor((i+o)/2)],n=t[s+1],r<=e){if(s===a||e<n)return s;i=s+1}else{if(!(r>e))throw new ee("Input is not a number.");o=s-1}return 0}ge.prototype.parse=function(t,e,r,n,a){return void 0===a&&(a={}),e?this.concat(e,r,n)._parse(t,a):this._parse(t,a)},ge.prototype._parse=function(t,e){function r(t,e,r){return"assert"===r?new ne(e,[t]):"coerce"===r?new oe(e,[t]):t}if(null!==t&&"string"!=typeof t&&"boolean"!=typeof t&&"number"!=typeof t||(t=["literal",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use ["literal", []].');var n=t[0];if("string"!=typeof n)return this.error("Expression name must be a string, but found "+typeof n+' instead. If you wanted a literal array, use ["literal", [...]].',0),null;var a=this.registry[n];if(a){var i=a.parse(t,this);if(!i)return null;if(this.expectedType){var o=this.expectedType,s=i.type;if("string"!==o.kind&&"number"!==o.kind&&"boolean"!==o.kind&&"object"!==o.kind&&"array"!==o.kind||"value"!==s.kind)if("color"!==o.kind&&"formatted"!==o.kind||"value"!==s.kind&&"string"!==s.kind){if(this.checkSubtype(o,s))return null}else i=r(i,o,e.typeAnnotation||"coerce");else i=r(i,o,e.typeAnnotation||"assert")}if(!(i instanceof te)&&function t(e){if(e instanceof de)return t(e.boundExpression);if(e instanceof ce&&"error"===e.name)return!1;if(e instanceof ue)return!1;var r=e instanceof oe||e instanceof ne,n=!0;return e.eachChild(function(e){n=r?n&&t(e):n&&e instanceof te}),!!n&&(he(e)&&pe(e,["zoom","heatmap-density","line-progress","accumulated","is-supported-script"]))}(i)){var l=new le;try{i=new te(i.type,i.evaluate(l))}catch(t){return this.error(t.message),null}}return i}return this.error('Unknown expression "'+n+'". If you wanted a literal array, use ["literal", [...]].',0)}return void 0===t?this.error("'undefined' value invalid. Use null instead."):"object"==typeof t?this.error('Bare objects invalid. Use ["literal", {...}] instead.'):this.error("Expected an array, but found "+typeof t+" instead.")},ge.prototype.concat=function(t,e,r){var n="number"==typeof t?this.path.concat(t):this.path,a=r?this.scope.concat(r):this.scope;return new ge(this.registry,n,e||null,a,this.errors)},ge.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=""+this.key+e.map(function(t){return"["+t+"]"}).join("");this.errors.push(new Pt(n,t))},ge.prototype.checkSubtype=function(t,e){var r=Gt(t,e);return r&&this.error(r),r};var me=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,a=r;n<a.length;n+=1){var i=a[n],o=i[0],s=i[1];this.labels.push(o),this.outputs.push(s)}};function ye(t,e,r){return t*(1-r)+e*r}me.parse=function(t,e){if(t.length-1<4)return e.error("Expected at least 4 arguments, but found only "+(t.length-1)+".");if((t.length-1)%2!=0)return e.error("Expected an even number of arguments.");var r=e.parse(t[1],1,It);if(!r)return null;var n=[],a=null;e.expectedType&&"value"!==e.expectedType.kind&&(a=e.expectedType);for(var i=1;i<t.length;i+=2){var o=1===i?-1/0:t[i],s=t[i+1],l=i,c=i+1;if("number"!=typeof o)return e.error('Input/output pairs for "step" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for "step" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,a);if(!u)return null;a=a||u.type,n.push([o,u])}return new me(a,r,n)},me.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var a=e.length;return n>=e[a-1]?r[a-1].evaluate(t):r[ve(e,n)].evaluate(t)},me.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},me.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},me.prototype.serialize=function(){for(var t=["step",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var xe=Object.freeze({number:ye,color:function(t,e,r){return new Wt(ye(t.r,e.r,r),ye(t.g,e.g,r),ye(t.b,e.b,r),ye(t.a,e.a,r))},array:function(t,e,r){return t.map(function(t,n){return ye(t,e[n],r)})}}),be=.95047,_e=1,we=1.08883,ke=4/29,Te=6/29,Me=3*Te*Te,Ae=Te*Te*Te,Se=Math.PI/180,Ee=180/Math.PI;function Le(t){return t>Ae?Math.pow(t,1/3):t/Me+ke}function Ce(t){return t>Te?t*t*t:Me*(t-ke)}function Pe(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function Oe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function ze(t){var e=Oe(t.r),r=Oe(t.g),n=Oe(t.b),a=Le((.4124564*e+.3575761*r+.1804375*n)/be),i=Le((.2126729*e+.7151522*r+.072175*n)/_e);return{l:116*i-16,a:500*(a-i),b:200*(i-Le((.0193339*e+.119192*r+.9503041*n)/we)),alpha:t.a}}function Ie(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=_e*Ce(e),r=be*Ce(r),n=we*Ce(n),new Wt(Pe(3.2404542*r-1.5371385*e-.4985314*n),Pe(-.969266*r+1.8760108*e+.041556*n),Pe(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}function De(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}var Re={forward:ze,reverse:Ie,interpolate:function(t,e,r){return{l:ye(t.l,e.l,r),a:ye(t.a,e.a,r),b:ye(t.b,e.b,r),alpha:ye(t.alpha,e.alpha,r)}}},Fe={forward:function(t){var e=ze(t),r=e.l,n=e.a,a=e.b,i=Math.atan2(a,n)*Ee;return{h:i<0?i+360:i,c:Math.sqrt(n*n+a*a),l:r,alpha:t.a}},reverse:function(t){var e=t.h*Se,r=t.c;return Ie({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:De(t.h,e.h,r),c:ye(t.c,e.c,r),l:ye(t.l,e.l,r),alpha:ye(t.alpha,e.alpha,r)}}},Be=Object.freeze({lab:Re,hcl:Fe}),Ne=function(t,e,r,n,a){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var i=0,o=a;i<o.length;i+=1){var s=o[i],l=s[0],c=s[1];this.labels.push(l),this.outputs.push(c)}};function je(t,e,r,n){var a=n-r,i=t-r;return 0===a?0:1===e?i/a:(Math.pow(e,i)-1)/(Math.pow(e,a)-1)}Ne.interpolationFactor=function(t,e,n,a){var i=0;if("exponential"===t.name)i=je(e,t.base,n,a);else if("linear"===t.name)i=je(e,1,n,a);else if("cubic-bezier"===t.name){var o=t.controlPoints;i=new r(o[0],o[1],o[2],o[3]).solve(je(e,1,n,a))}return i},Ne.parse=function(t,e){var r=t[0],n=t[1],a=t[2],i=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error("Expected an interpolation type expression.",1);if("linear"===n[0])n={name:"linear"};else if("exponential"===n[0]){var o=n[1];if("number"!=typeof o)return e.error("Exponential interpolation requires a numeric base.",1,1);n={name:"exponential",base:o}}else{if("cubic-bezier"!==n[0])return e.error("Unknown interpolation type "+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some(function(t){return"number"!=typeof t||t<0||t>1}))return e.error("Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.",1);n={name:"cubic-bezier",controlPoints:s}}if(t.length-1<4)return e.error("Expected at least 4 arguments, but found only "+(t.length-1)+".");if((t.length-1)%2!=0)return e.error("Expected an even number of arguments.");if(!(a=e.parse(a,2,It)))return null;var l=[],c=null;"interpolate-hcl"===r||"interpolate-lab"===r?c=Ft:e.expectedType&&"value"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<i.length;u+=2){var h=i[u],f=i[u+1],p=u+3,d=u+4;if("number"!=typeof h)return e.error('Input/output pairs for "interpolate" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=h)return e.error('Input/output pairs for "interpolate" expressions must be arranged with input values in strictly ascending order.',p);var g=e.parse(f,d,c);if(!g)return null;c=c||g.type,l.push([h,g])}return"number"===c.kind||"color"===c.kind||"array"===c.kind&&"number"===c.itemType.kind&&"number"==typeof c.N?new Ne(c,r,n,a,l):e.error("Type "+qt(c)+" is not interpolatable.")},Ne.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var a=e.length;if(n>=e[a-1])return r[a-1].evaluate(t);var i=ve(e,n),o=e[i],s=e[i+1],l=Ne.interpolationFactor(this.interpolation,n,o,s),c=r[i].evaluate(t),u=r[i+1].evaluate(t);return"interpolate"===this.operator?xe[this.type.kind.toLowerCase()](c,u,l):"interpolate-hcl"===this.operator?Fe.reverse(Fe.interpolate(Fe.forward(c),Fe.forward(u),l)):Re.reverse(Re.interpolate(Re.forward(c),Re.forward(u),l))},Ne.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Ne.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Ne.prototype.serialize=function(){var t;t="linear"===this.interpolation.name?["linear"]:"exponential"===this.interpolation.name?1===this.interpolation.base?["linear"]:["exponential",this.interpolation.base]:["cubic-bezier"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var Ve=function(t,e){this.type=t,this.args=e};Ve.parse=function(t,e){if(t.length<2)return e.error("Expectected at least one argument.");var r=null,n=e.expectedType;n&&"value"!==n.kind&&(r=n);for(var a=[],i=0,o=t.slice(1);i<o.length;i+=1){var s=o[i],l=e.parse(s,1+a.length,r,void 0,{typeAnnotation:"omit"});if(!l)return null;r=r||l.type,a.push(l)}var c=n&&a.some(function(t){return Gt(n,t.type)});return new Ve(c?Nt:r,a)},Ve.prototype.evaluate=function(t){for(var e=null,r=0,n=this.args;r<n.length&&null===(e=n[r].evaluate(t));r+=1);return e},Ve.prototype.eachChild=function(t){this.args.forEach(t)},Ve.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},Ve.prototype.serialize=function(){var t=["coalesce"];return this.eachChild(function(e){t.push(e.serialize())}),t};var Ue=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};Ue.prototype.evaluate=function(t){return this.result.evaluate(t)},Ue.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},Ue.parse=function(t,e){if(t.length<4)return e.error("Expected at least 3 arguments, but found "+(t.length-1)+" instead.");for(var r=[],n=1;n<t.length-1;n+=2){var a=t[n];if("string"!=typeof a)return e.error("Expected string, but found "+typeof a+" instead.",n);if(/[^a-zA-Z0-9_]/.test(a))return e.error("Variable names must contain only alphanumeric characters or '_'.",n);var i=e.parse(t[n+1],n+1);if(!i)return null;r.push([a,i])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new Ue(r,o):null},Ue.prototype.possibleOutputs=function(){return this.result.possibleOutputs()},Ue.prototype.serialize=function(){for(var t=["let"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e],a=n[0],i=n[1];t.push(a,i.serialize())}return t.push(this.result.serialize()),t};var qe=function(t,e,r){this.type=t,this.index=e,this.input=r};qe.parse=function(t,e){if(3!==t.length)return e.error("Expected 2 arguments, but found "+(t.length-1)+" instead.");var r=e.parse(t[1],1,It),n=e.parse(t[2],2,Ut(e.expectedType||Nt));if(!r||!n)return null;var a=n.type;return new qe(a.itemType,r,n)},qe.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new ee("Array index out of bounds: "+e+" < 0.");if(e>=r.length)throw new ee("Array index out of bounds: "+e+" > "+(r.length-1)+".");if(e!==Math.floor(e))throw new ee("Array index must be an integer, but found "+e+" instead.");return r[e]},qe.prototype.eachChild=function(t){t(this.index),t(this.input)},qe.prototype.possibleOutputs=function(){return[void 0]},qe.prototype.serialize=function(){return["at",this.index.serialize(),this.input.serialize()]};var He=function(t,e,r,n,a,i){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=a,this.otherwise=i};He.parse=function(t,e){if(t.length<5)return e.error("Expected at least 4 arguments, but found only "+(t.length-1)+".");if(t.length%2!=1)return e.error("Expected an even number of arguments.");var r,n;e.expectedType&&"value"!==e.expectedType.kind&&(n=e.expectedType);for(var a={},i=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error("Expected at least one branch label.");for(var u=0,h=s;u<h.length;u+=1){var f=h[u];if("number"!=typeof f&&"string"!=typeof f)return c.error("Branch labels must be numbers or strings.");if("number"==typeof f&&Math.abs(f)>Number.MAX_SAFE_INTEGER)return c.error("Branch labels must be integers no larger than "+Number.MAX_SAFE_INTEGER+".");if("number"==typeof f&&Math.floor(f)!==f)return c.error("Numeric branch labels must be integer values.");if(r){if(c.checkSubtype(r,Qt(f)))return null}else r=Qt(f);if(void 0!==a[String(f)])return c.error("Branch labels must be unique.");a[String(f)]=i.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,i.push(p)}var d=e.parse(t[1],1,Nt);if(!d)return null;var g=e.parse(t[t.length-1],t.length-1,n);return g?"value"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new He(r,n,d,a,i,g):null},He.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(Qt(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},He.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},He.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()})).concat(this.otherwise.possibleOutputs())},He.prototype.serialize=function(){for(var t=this,e=["match",this.input.serialize()],r=[],n={},a=0,i=Object.keys(this.cases).sort();a<i.length;a+=1){var o=i[a];void 0===(h=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[h][1].push(o)}for(var s=function(e){return"number"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],h=u[0],f=u[1];1===f.length?e.push(s(f[0])):e.push(f.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var Ge=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};function Ye(t,e){return"=="===t||"!="===t?"boolean"===e.kind||"string"===e.kind||"number"===e.kind||"null"===e.kind||"value"===e.kind:"string"===e.kind||"number"===e.kind||"value"===e.kind}function We(t,e,r,n){return 0===n.compare(e,r)}function Xe(t,e,r){var n="=="!==t&&"!="!==t;return function(){function a(t,e,r){this.type=Rt,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument="value"===t.type.kind||"value"===e.type.kind}return a.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error("Expected two or three arguments.");var r=t[0],i=e.parse(t[1],1,Nt);if(!i)return null;if(!Ye(r,i.type))return e.concat(1).error('"'+r+"\" comparisons are not supported for type '"+qt(i.type)+"'.");var o=e.parse(t[2],2,Nt);if(!o)return null;if(!Ye(r,o.type))return e.concat(2).error('"'+r+"\" comparisons are not supported for type '"+qt(o.type)+"'.");if(i.type.kind!==o.type.kind&&"value"!==i.type.kind&&"value"!==o.type.kind)return e.error("Cannot compare types '"+qt(i.type)+"' and '"+qt(o.type)+"'.");n&&("value"===i.type.kind&&"value"!==o.type.kind?i=new ne(o.type,[i]):"value"!==i.type.kind&&"value"===o.type.kind&&(o=new ne(i.type,[o])));var s=null;if(4===t.length){if("string"!==i.type.kind&&"string"!==o.type.kind&&"value"!==i.type.kind&&"value"!==o.type.kind)return e.error("Cannot use collator to compare non-string types.");if(!(s=e.parse(t[3],3,jt)))return null}return new a(i,o,s)},a.prototype.evaluate=function(a){var i=this.lhs.evaluate(a),o=this.rhs.evaluate(a);if(n&&this.hasUntypedArgument){var s=Qt(i),l=Qt(o);if(s.kind!==l.kind||"string"!==s.kind&&"number"!==s.kind)throw new ee('Expected arguments for "'+t+'" to be (string, string) or (number, number), but found ('+s.kind+", "+l.kind+") instead.")}if(this.collator&&!n&&this.hasUntypedArgument){var c=Qt(i),u=Qt(o);if("string"!==c.kind||"string"!==u.kind)return e(a,i,o)}return this.collator?r(a,i,o,this.collator.evaluate(a)):e(a,i,o)},a.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},a.prototype.possibleOutputs=function(){return[!0,!1]},a.prototype.serialize=function(){var e=[t];return this.eachChild(function(t){e.push(t.serialize())}),e},a}()}Ge.parse=function(t,e){if(t.length<4)return e.error("Expected at least 3 arguments, but found only "+(t.length-1)+".");if(t.length%2!=0)return e.error("Expected an odd number of arguments.");var r;e.expectedType&&"value"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],a=1;a<t.length-1;a+=2){var i=e.parse(t[a],a,Rt);if(!i)return null;var o=e.parse(t[a+1],a+1,r);if(!o)return null;n.push([i,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new Ge(r,n,s):null},Ge.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],a=n[0],i=n[1];if(a.evaluate(t))return i.evaluate(t)}return this.otherwise.evaluate(t)},Ge.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],a=n[0],i=n[1];t(a),t(i)}t(this.otherwise)},Ge.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.branches.map(function(t){return t[0],t[1].possibleOutputs()})).concat(this.otherwise.possibleOutputs())},Ge.prototype.serialize=function(){var t=["case"];return this.eachChild(function(e){t.push(e.serialize())}),t};var Ze=Xe("==",function(t,e,r){return e===r},We),Je=Xe("!=",function(t,e,r){return e!==r},function(t,e,r,n){return!We(0,e,r,n)}),Ke=Xe("<",function(t,e,r){return e<r},function(t,e,r,n){return n.compare(e,r)<0}),Qe=Xe(">",function(t,e,r){return e>r},function(t,e,r,n){return n.compare(e,r)>0}),$e=Xe("<=",function(t,e,r){return e<=r},function(t,e,r,n){return n.compare(e,r)<=0}),tr=Xe(">=",function(t,e,r){return e>=r},function(t,e,r,n){return n.compare(e,r)>=0}),er=function(t,e,r,n,a){this.type=Dt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=a};er.parse=function(t,e){if(3!==t.length)return e.error("Expected two arguments.");var r=e.parse(t[1],1,It);if(!r)return null;var n=t[2];if("object"!=typeof n||Array.isArray(n))return e.error("NumberFormat options argument must be an object.");var a=null;if(n.locale&&!(a=e.parse(n.locale,1,Dt)))return null;var i=null;if(n.currency&&!(i=e.parse(n.currency,1,Dt)))return null;var o=null;if(n["min-fraction-digits"]&&!(o=e.parse(n["min-fraction-digits"],1,It)))return null;var s=null;return n["max-fraction-digits"]&&!(s=e.parse(n["max-fraction-digits"],1,It))?null:new er(r,a,i,o,s)},er.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?"currency":"decimal",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},er.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},er.prototype.possibleOutputs=function(){return[void 0]},er.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t["min-fraction-digits"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t["max-fraction-digits"]=this.maxFractionDigits.serialize()),["number-format",this.number.serialize(),t]};var rr=function(t){this.type=It,this.input=t};rr.parse=function(t,e){if(2!==t.length)return e.error("Expected 1 argument, but found "+(t.length-1)+" instead.");var r=e.parse(t[1],1);return r?"array"!==r.type.kind&&"string"!==r.type.kind&&"value"!==r.type.kind?e.error("Expected argument of type string or array, but found "+qt(r.type)+" instead."):new rr(r):null},rr.prototype.evaluate=function(t){var e=this.input.evaluate(t);if("string"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new ee("Expected value to be of type string or array, but found "+qt(Qt(e))+" instead.")},rr.prototype.eachChild=function(t){t(this.input)},rr.prototype.possibleOutputs=function(){return[void 0]},rr.prototype.serialize=function(){var t=["length"];return this.eachChild(function(e){t.push(e.serialize())}),t};var nr={"==":Ze,"!=":Je,">":Qe,"<":Ke,">=":tr,"<=":$e,array:ne,at:qe,boolean:ne,case:Ge,coalesce:Ve,collator:ue,format:ae,interpolate:Ne,"interpolate-hcl":Ne,"interpolate-lab":Ne,length:rr,let:Ue,literal:te,match:He,number:ne,"number-format":er,object:ne,step:me,string:ne,"to-boolean":oe,"to-color":oe,"to-number":oe,"to-string":oe,var:de};function ar(t,e){var r=e[0],n=e[1],a=e[2],i=e[3];r=r.evaluate(t),n=n.evaluate(t),a=a.evaluate(t);var o=i?i.evaluate(t):1,s=Kt(r,n,a,o);if(s)throw new ee(s);return new Wt(r/255*o,n/255*o,a/255*o,o)}function ir(t,e){return t in e}function or(t,e){var r=e[t];return void 0===r?null:r}function sr(t){return{type:t}}function lr(t){return{result:"success",value:t}}function cr(t){return{result:"error",value:t}}function ur(t){return"data-driven"===t["property-type"]||"cross-faded-data-driven"===t["property-type"]}function hr(t){return!!t.expression&&t.expression.parameters.indexOf("zoom")>-1}function fr(t){return!!t.expression&&t.expression.interpolated}function pr(t){return t instanceof Number?"number":t instanceof String?"string":t instanceof Boolean?"boolean":Array.isArray(t)?"array":null===t?"null":typeof t}function dr(t){return"object"==typeof t&&null!==t&&!Array.isArray(t)}function gr(t){return t}function vr(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function mr(t,e,r,n,a){return vr(typeof r===a?n[r]:void 0,t.default,e.default)}function yr(t,e,r){if("number"!==pr(r))return vr(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var a=ve(t.stops.map(function(t){return t[0]}),r);return t.stops[a][1]}function xr(t,e,r){var n=void 0!==t.base?t.base:1;if("number"!==pr(r))return vr(t.default,e.default);var a=t.stops.length;if(1===a)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[a-1][0])return t.stops[a-1][1];var i=ve(t.stops.map(function(t){return t[0]}),r),o=function(t,e,r,n){var a=n-r,i=t-r;return 0===a?0:1===e?i/a:(Math.pow(e,i)-1)/(Math.pow(e,a)-1)}(r,n,t.stops[i][0],t.stops[i+1][0]),s=t.stops[i][1],l=t.stops[i+1][1],c=xe[e.type]||gr;if(t.colorSpace&&"rgb"!==t.colorSpace){var u=Be[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return"function"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function br(t,e,r){return"color"===e.type?r=Wt.parse(r):"formatted"===e.type?r=Jt.fromString(r.toString()):pr(r)===e.type||"enum"===e.type&&e.values[r]||(r=void 0),vr(r,t.default,e.default)}ce.register(nr,{error:[{kind:"error"},[Dt],function(t,e){var r=e[0];throw new ee(r.evaluate(t))}],typeof:[Dt,[Nt],function(t,e){return qt(Qt(e[0].evaluate(t)))}],"to-rgba":[Ut(It,4),[Ft],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Ft,[It,It,It],ar],rgba:[Ft,[It,It,It,It],ar],has:{type:Rt,overloads:[[[Dt],function(t,e){return ir(e[0].evaluate(t),t.properties())}],[[Dt,Bt],function(t,e){var r=e[0],n=e[1];return ir(r.evaluate(t),n.evaluate(t))}]]},get:{type:Nt,overloads:[[[Dt],function(t,e){return or(e[0].evaluate(t),t.properties())}],[[Dt,Bt],function(t,e){var r=e[0],n=e[1];return or(r.evaluate(t),n.evaluate(t))}]]},"feature-state":[Nt,[Dt],function(t,e){return or(e[0].evaluate(t),t.featureState||{})}],properties:[Bt,[],function(t){return t.properties()}],"geometry-type":[Dt,[],function(t){return t.geometryType()}],id:[Nt,[],function(t){return t.id()}],zoom:[It,[],function(t){return t.globals.zoom}],"heatmap-density":[It,[],function(t){return t.globals.heatmapDensity||0}],"line-progress":[It,[],function(t){return t.globals.lineProgress||0}],accumulated:[Nt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],"+":[It,sr(It),function(t,e){for(var r=0,n=0,a=e;n<a.length;n+=1)r+=a[n].evaluate(t);return r}],"*":[It,sr(It),function(t,e){for(var r=1,n=0,a=e;n<a.length;n+=1)r*=a[n].evaluate(t);return r}],"-":{type:It,overloads:[[[It,It],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)-n.evaluate(t)}],[[It],function(t,e){return-e[0].evaluate(t)}]]},"/":[It,[It,It],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)/n.evaluate(t)}],"%":[It,[It,It],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)%n.evaluate(t)}],ln2:[It,[],function(){return Math.LN2}],pi:[It,[],function(){return Math.PI}],e:[It,[],function(){return Math.E}],"^":[It,[It,It],function(t,e){var r=e[0],n=e[1];return Math.pow(r.evaluate(t),n.evaluate(t))}],sqrt:[It,[It],function(t,e){var r=e[0];return Math.sqrt(r.evaluate(t))}],log10:[It,[It],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN10}],ln:[It,[It],function(t,e){var r=e[0];return Math.log(r.evaluate(t))}],log2:[It,[It],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN2}],sin:[It,[It],function(t,e){var r=e[0];return Math.sin(r.evaluate(t))}],cos:[It,[It],function(t,e){var r=e[0];return Math.cos(r.evaluate(t))}],tan:[It,[It],function(t,e){var r=e[0];return Math.tan(r.evaluate(t))}],asin:[It,[It],function(t,e){var r=e[0];return Math.asin(r.evaluate(t))}],acos:[It,[It],function(t,e){var r=e[0];return Math.acos(r.evaluate(t))}],atan:[It,[It],function(t,e){var r=e[0];return Math.atan(r.evaluate(t))}],min:[It,sr(It),function(t,e){return Math.min.apply(Math,e.map(function(e){return e.evaluate(t)}))}],max:[It,sr(It),function(t,e){return Math.max.apply(Math,e.map(function(e){return e.evaluate(t)}))}],abs:[It,[It],function(t,e){var r=e[0];return Math.abs(r.evaluate(t))}],round:[It,[It],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[It,[It],function(t,e){var r=e[0];return Math.floor(r.evaluate(t))}],ceil:[It,[It],function(t,e){var r=e[0];return Math.ceil(r.evaluate(t))}],"filter-==":[Rt,[Dt,Nt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],"filter-id-==":[Rt,[Nt],function(t,e){var r=e[0];return t.id()===r.value}],"filter-type-==":[Rt,[Dt],function(t,e){var r=e[0];return t.geometryType()===r.value}],"filter-<":[Rt,[Dt,Nt],function(t,e){var r=e[0],n=e[1],a=t.properties()[r.value],i=n.value;return typeof a==typeof i&&a<i}],"filter-id-<":[Rt,[Nt],function(t,e){var r=e[0],n=t.id(),a=r.value;return typeof n==typeof a&&n<a}],"filter->":[Rt,[Dt,Nt],function(t,e){var r=e[0],n=e[1],a=t.properties()[r.value],i=n.value;return typeof a==typeof i&&a>i}],"filter-id->":[Rt,[Nt],function(t,e){var r=e[0],n=t.id(),a=r.value;return typeof n==typeof a&&n>a}],"filter-<=":[Rt,[Dt,Nt],function(t,e){var r=e[0],n=e[1],a=t.properties()[r.value],i=n.value;return typeof a==typeof i&&a<=i}],"filter-id-<=":[Rt,[Nt],function(t,e){var r=e[0],n=t.id(),a=r.value;return typeof n==typeof a&&n<=a}],"filter->=":[Rt,[Dt,Nt],function(t,e){var r=e[0],n=e[1],a=t.properties()[r.value],i=n.value;return typeof a==typeof i&&a>=i}],"filter-id->=":[Rt,[Nt],function(t,e){var r=e[0],n=t.id(),a=r.value;return typeof n==typeof a&&n>=a}],"filter-has":[Rt,[Nt],function(t,e){return e[0].value in t.properties()}],"filter-has-id":[Rt,[],function(t){return null!==t.id()}],"filter-type-in":[Rt,[Ut(Dt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],"filter-id-in":[Rt,[Ut(Nt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],"filter-in-small":[Rt,[Dt,Ut(Nt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],"filter-in-large":[Rt,[Dt,Ut(Nt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var a=r+n>>1;if(e[a]===t)return!0;e[a]>t?n=a-1:r=a+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:Rt,overloads:[[[Rt,Rt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)&&n.evaluate(t)}],[sr(Rt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:Rt,overloads:[[[Rt,Rt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)||n.evaluate(t)}],[sr(Rt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},"!":[Rt,[Rt],function(t,e){return!e[0].evaluate(t)}],"is-supported-script":[Rt,[Dt],function(t,e){var r=e[0],n=t.globals&&t.globals.isSupportedScript;return!n||n(r.evaluate(t))}],upcase:[Dt,[Dt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Dt,[Dt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Dt,sr(Nt),function(t,e){return e.map(function(e){return $t(e.evaluate(t))}).join("")}],"resolved-locale":[Dt,[jt],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var _r=function(t,e){this.expression=t,this._warningHistory={},this._evaluator=new le,this._defaultValue=e?function(t){return"color"===t.type&&dr(t.default)?new Wt(0,0,0,0):"color"===t.type?Wt.parse(t.default)||null:void 0===t.default?null:t.default}(e):null,this._enumValues=e&&"enum"===e.type?e.values:null};function wr(t){return Array.isArray(t)&&t.length>0&&"string"==typeof t[0]&&t[0]in nr}function kr(t,e){var r=new ge(nr,[],e?function(t){var e={color:Ft,string:Dt,number:It,enum:Dt,boolean:Rt,formatted:Vt};return"array"===t.type?Ut(e[t.value]||Nt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&"string"===e.type?{typeAnnotation:"coerce"}:void 0);return n?lr(new _r(n,e)):cr(r.errors)}_r.prototype.evaluateWithoutErrorHandling=function(t,e,r,n){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this._evaluator.formattedSection=n,this.expression.evaluate(this._evaluator)},_r.prototype.evaluate=function(t,e,r,n){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null,this._evaluator.formattedSection=n||null;try{var a=this.expression.evaluate(this._evaluator);if(null==a)return this._defaultValue;if(this._enumValues&&!(a in this._enumValues))throw new ee("Expected value to be one of "+Object.keys(this._enumValues).map(function(t){return JSON.stringify(t)}).join(", ")+", but found "+JSON.stringify(a)+" instead.");return a}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,"undefined"!=typeof console&&console.warn(t.message)),this._defaultValue}};var Tr=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent="constant"!==t&&!fe(e.expression)};Tr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n)},Tr.prototype.evaluate=function(t,e,r,n){return this._styleExpression.evaluate(t,e,r,n)};var Mr=function(t,e,r,n){this.kind=t,this.zoomStops=r,this._styleExpression=e,this.isStateDependent="camera"!==t&&!fe(e.expression),this.interpolationType=n};function Ar(t,e){if("error"===(t=kr(t,e)).result)return t;var r=t.value.expression,n=he(r);if(!n&&!ur(e))return cr([new Pt("","data expressions not supported")]);var a=pe(r,["zoom"]);if(!a&&!hr(e))return cr([new Pt("","zoom expressions not supported")]);var i=function t(e){var r=null;if(e instanceof Ue)r=t(e.result);else if(e instanceof Ve)for(var n=0,a=e.args;n<a.length;n+=1){var i=a[n];if(r=t(i))break}else(e instanceof me||e instanceof Ne)&&e.input instanceof ce&&"zoom"===e.input.name&&(r=e);return r instanceof Pt?r:(e.eachChild(function(e){var n=t(e);n instanceof Pt?r=n:!r&&n?r=new Pt("",'"zoom" expression may only be used as input to a top-level "step" or "interpolate" expression.'):r&&n&&r!==n&&(r=new Pt("",'Only one zoom-based "step" or "interpolate" subexpression may be used in an expression.'))}),r)}(r);if(!i&&!a)return cr([new Pt("",'"zoom" expression may only be used as input to a top-level "step" or "interpolate" expression.')]);if(i instanceof Pt)return cr([i]);if(i instanceof Ne&&!fr(e))return cr([new Pt("",'"interpolate" expressions cannot be used with this property')]);if(!i)return lr(new Tr(n?"constant":"source",t.value));var o=i instanceof Ne?i.interpolation:void 0;return lr(new Mr(n?"camera":"composite",t.value,i.labels,o))}Mr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n)},Mr.prototype.evaluate=function(t,e,r,n){return this._styleExpression.evaluate(t,e,r,n)},Mr.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?Ne.interpolationFactor(this.interpolationType,t,e,r):0};var Sr=function(t,e){this._parameters=t,this._specification=e,St(this,function t(e,r){var n,a,i,o="color"===r.type,s=e.stops&&"object"==typeof e.stops[0][0],l=s||void 0!==e.property,c=s||!l,u=e.type||(fr(r)?"exponential":"interval");if(o&&((e=St({},e)).stops&&(e.stops=e.stops.map(function(t){return[t[0],Wt.parse(t[1])]})),e.default?e.default=Wt.parse(e.default):e.default=Wt.parse(r.default)),e.colorSpace&&"rgb"!==e.colorSpace&&!Be[e.colorSpace])throw new Error("Unknown color space: "+e.colorSpace);if("exponential"===u)n=xr;else if("interval"===u)n=yr;else if("categorical"===u){n=mr,a=Object.create(null);for(var h=0,f=e.stops;h<f.length;h+=1){var p=f[h];a[p[0]]=p[1]}i=typeof e.stops[0][0]}else{if("identity"!==u)throw new Error('Unknown function type "'+u+'"');n=br}if(s){for(var d={},g=[],v=0;v<e.stops.length;v++){var m=e.stops[v],y=m[0].zoom;void 0===d[y]&&(d[y]={zoom:y,type:e.type,property:e.property,default:e.default,stops:[]},g.push(y)),d[y].stops.push([m[0].value,m[1]])}for(var x=[],b=0,_=g;b<_.length;b+=1){var w=_[b];x.push([d[w].zoom,t(d[w],r)])}var k={name:"linear"};return{kind:"composite",interpolationType:k,interpolationFactor:Ne.interpolationFactor.bind(void 0,k),zoomStops:x.map(function(t){return t[0]}),evaluate:function(t,n){var a=t.zoom;return xr({stops:x,base:e.base},r,a).evaluate(a,n)}}}if(c){var T="exponential"===u?{name:"exponential",base:void 0!==e.base?e.base:1}:null;return{kind:"camera",interpolationType:T,interpolationFactor:Ne.interpolationFactor.bind(void 0,T),zoomStops:e.stops.map(function(t){return t[0]}),evaluate:function(t){var o=t.zoom;return n(e,r,o,a,i)}}}return{kind:"source",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?vr(e.default,r.default):n(e,r,s,a,i)}}}(this._parameters,this._specification))};function Er(t){var e=t.key,r=t.value,n=t.valueSpec||{},a=t.objectElementValidators||{},i=t.style,o=t.styleSpec,s=[],l=pr(r);if("object"!==l)return[new Mt(e,r,"object expected, "+l+" found")];for(var c in r){var u=c.split(".")[0],h=n[u]||n["*"],f=void 0;if(a[u])f=a[u];else if(n[u])f=Qr;else if(a["*"])f=a["*"];else{if(!n["*"]){s.push(new Mt(e,r[c],'unknown property "'+c+'"'));continue}f=Qr}s=s.concat(f({key:(e?e+".":e)+c,value:r[c],valueSpec:h,style:i,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)a[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new Mt(e,r,'missing required property "'+p+'"'));return s}function Lr(t){var e=t.value,r=t.valueSpec,n=t.style,a=t.styleSpec,i=t.key,o=t.arrayElementValidator||Qr;if("array"!==pr(e))return[new Mt(i,e,"array expected, "+pr(e)+" found")];if(r.length&&e.length!==r.length)return[new Mt(i,e,"array length "+r.length+" expected, length "+e.length+" found")];if(r["min-length"]&&e.length<r["min-length"])return[new Mt(i,e,"array length at least "+r["min-length"]+" expected, length "+e.length+" found")];var s={type:r.value,values:r.values};a.$version<7&&(s.function=r.function),"object"===pr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:a,key:i+"["+c+"]"}));return l}function Cr(t){var e=t.key,r=t.value,n=t.valueSpec,a=pr(r);return"number"!==a?[new Mt(e,r,"number expected, "+a+" found")]:"minimum"in n&&r<n.minimum?[new Mt(e,r,r+" is less than the minimum value "+n.minimum)]:"maximum"in n&&r>n.maximum?[new Mt(e,r,r+" is greater than the maximum value "+n.maximum)]:[]}function Pr(t){var e,r,n,a=t.valueSpec,i=Lt(t.value.type),o={},s="categorical"!==i&&void 0===t.value.property,l=!s,c="array"===pr(t.value.stops)&&"array"===pr(t.value.stops[0])&&"object"===pr(t.value.stops[0][0]),u=Er({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if("identity"===i)return[new Mt(t.key,t.value,'identity function may not have a "stops" property')];var e=[],r=t.value;return e=e.concat(Lr({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:h})),"array"===pr(r)&&0===r.length&&e.push(new Mt(t.key,r,"array must have at least one stop")),e},default:function(t){return Qr({key:t.key,value:t.value,valueSpec:a,style:t.style,styleSpec:t.styleSpec})}}});return"identity"===i&&s&&u.push(new Mt(t.key,t.value,'missing required property "property"')),"identity"===i||t.value.stops||u.push(new Mt(t.key,t.value,'missing required property "stops"')),"exponential"===i&&t.valueSpec.expression&&!fr(t.valueSpec)&&u.push(new Mt(t.key,t.value,"exponential functions not supported")),t.styleSpec.$version>=8&&(l&&!ur(t.valueSpec)?u.push(new Mt(t.key,t.value,"property functions not supported")):s&&!hr(t.valueSpec)&&u.push(new Mt(t.key,t.value,"zoom functions not supported"))),"categorical"!==i&&!c||void 0!==t.value.property||u.push(new Mt(t.key,t.value,'"property" property is required')),u;function h(t){var e=[],i=t.value,s=t.key;if("array"!==pr(i))return[new Mt(s,i,"array expected, "+pr(i)+" found")];if(2!==i.length)return[new Mt(s,i,"array length 2 expected, length "+i.length+" found")];if(c){if("object"!==pr(i[0]))return[new Mt(s,i,"object expected, "+pr(i[0])+" found")];if(void 0===i[0].zoom)return[new Mt(s,i,"object stop key must have zoom")];if(void 0===i[0].value)return[new Mt(s,i,"object stop key must have value")];if(n&&n>Lt(i[0].zoom))return[new Mt(s,i[0].zoom,"stop zoom values must appear in ascending order")];Lt(i[0].zoom)!==n&&(n=Lt(i[0].zoom),r=void 0,o={}),e=e.concat(Er({key:s+"[0]",value:i[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Cr,value:f}}))}else e=e.concat(f({key:s+"[0]",value:i[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},i));return wr(Ct(i[1]))?e.concat([new Mt(s+"[1]",i[1],"expressions are not allowed in function stops.")]):e.concat(Qr({key:s+"[1]",value:i[1],valueSpec:a,style:t.style,styleSpec:t.styleSpec}))}function f(t,n){var s=pr(t.value),l=Lt(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new Mt(t.key,c,s+" stop domain type must match previous stop domain type "+e)]}else e=s;if("number"!==s&&"string"!==s&&"boolean"!==s)return[new Mt(t.key,c,"stop domain value must be a number, string, or boolean")];if("number"!==s&&"categorical"!==i){var u="number expected, "+s+" found";return ur(a)&&void 0===i&&(u+='\nIf you intended to use a categorical function, specify `"type": "categorical"`.'),[new Mt(t.key,c,u)]}return"categorical"!==i||"number"!==s||isFinite(l)&&Math.floor(l)===l?"categorical"!==i&&"number"===s&&void 0!==r&&l<r?[new Mt(t.key,c,"stop domain values must appear in ascending order")]:(r=l,"categorical"===i&&l in o?[new Mt(t.key,c,"stop domain values must be unique")]:(o[l]=!0,[])):[new Mt(t.key,c,"integer expected, found "+l)]}}function Or(t){var e=("property"===t.expressionContext?Ar:kr)(Ct(t.value),t.valueSpec);if("error"===e.result)return e.value.map(function(e){return new Mt(""+t.key+e.key,t.value,e.message)});var r=e.value.expression||e.value._styleExpression.expression;if("property"===t.expressionContext&&"text-font"===t.propertyKey&&-1!==r.possibleOutputs().indexOf(void 0))return[new Mt(t.key,t.value,'Invalid data expression for "'+t.propertyKey+'". Output values must be contained as literals within the expression.')];if("property"===t.expressionContext&&"layout"===t.propertyType&&!fe(r))return[new Mt(t.key,t.value,'"feature-state" data expressions are not supported with layout properties.')];if("filter"===t.expressionContext&&!fe(r))return[new Mt(t.key,t.value,'"feature-state" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf("cluster")){if(!pe(r,["zoom","feature-state"]))return[new Mt(t.key,t.value,'"zoom" and "feature-state" expressions are not supported with cluster properties.')];if("cluster-initial"===t.expressionContext&&!he(r))return[new Mt(t.key,t.value,"Feature data expressions are not supported with initial expression part of cluster properties.")]}return[]}function zr(t){var e=t.key,r=t.value,n=t.valueSpec,a=[];return Array.isArray(n.values)?-1===n.values.indexOf(Lt(r))&&a.push(new Mt(e,r,"expected one of ["+n.values.join(", ")+"], "+JSON.stringify(r)+" found")):-1===Object.keys(n.values).indexOf(Lt(r))&&a.push(new Mt(e,r,"expected one of ["+Object.keys(n.values).join(", ")+"], "+JSON.stringify(r)+" found")),a}function Ir(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case"has":return t.length>=2&&"$id"!==t[1]&&"$type"!==t[1];case"in":case"!in":case"!has":case"none":return!1;case"==":case"!=":case">":case">=":case"<":case"<=":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case"any":case"all":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!Ir(n)&&"boolean"!=typeof n)return!1}return!0;default:return!0}}Sr.deserialize=function(t){return new Sr(t._parameters,t._specification)},Sr.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var Dr={type:"boolean",default:!1,transition:!1,"property-type":"data-driven",expression:{interpolated:!1,parameters:["zoom","feature"]}};function Rr(t){if(null==t)return function(){return!0};Ir(t)||(t=Br(t));var e=kr(t,Dr);if("error"===e.result)throw new Error(e.value.map(function(t){return t.key+": "+t.message}).join(", "));return function(t,r){return e.value.evaluate(t,r)}}function Fr(t,e){return t<e?-1:t>e?1:0}function Br(t){if(!t)return!0;var e,r=t[0];return t.length<=1?"any"!==r:"=="===r?Nr(t[1],t[2],"=="):"!="===r?Ur(Nr(t[1],t[2],"==")):"<"===r||">"===r||"<="===r||">="===r?Nr(t[1],t[2],r):"any"===r?(e=t.slice(1),["any"].concat(e.map(Br))):"all"===r?["all"].concat(t.slice(1).map(Br)):"none"===r?["all"].concat(t.slice(1).map(Br).map(Ur)):"in"===r?jr(t[1],t.slice(2)):"!in"===r?Ur(jr(t[1],t.slice(2))):"has"===r?Vr(t[1]):"!has"!==r||Ur(Vr(t[1]))}function Nr(t,e,r){switch(t){case"$type":return["filter-type-"+r,e];case"$id":return["filter-id-"+r,e];default:return["filter-"+r,t,e]}}function jr(t,e){if(0===e.length)return!1;switch(t){case"$type":return["filter-type-in",["literal",e]];case"$id":return["filter-id-in",["literal",e]];default:return e.length>200&&!e.some(function(t){return typeof t!=typeof e[0]})?["filter-in-large",t,["literal",e.sort(Fr)]]:["filter-in-small",t,["literal",e]]}}function Vr(t){switch(t){case"$type":return!0;case"$id":return["filter-has-id"];default:return["filter-has",t]}}function Ur(t){return["!",t]}function qr(t){return Ir(Ct(t.value))?Or(St({},t,{expressionContext:"filter",valueSpec:{value:"boolean"}})):function t(e){var r=e.value,n=e.key;if("array"!==pr(r))return[new Mt(n,r,"array expected, "+pr(r)+" found")];var a,i=e.styleSpec,o=[];if(r.length<1)return[new Mt(n,r,"filter array must have at least 1 element")];switch(o=o.concat(zr({key:n+"[0]",value:r[0],valueSpec:i.filter_operator,style:e.style,styleSpec:e.styleSpec})),Lt(r[0])){case"<":case"<=":case">":case">=":r.length>=2&&"$type"===Lt(r[1])&&o.push(new Mt(n,r,'"$type" cannot be use with operator "'+r[0]+'"'));case"==":case"!=":3!==r.length&&o.push(new Mt(n,r,'filter array for operator "'+r[0]+'" must have 3 elements'));case"in":case"!in":r.length>=2&&"string"!==(a=pr(r[1]))&&o.push(new Mt(n+"[1]",r[1],"string expected, "+a+" found"));for(var s=2;s<r.length;s++)a=pr(r[s]),"$type"===Lt(r[1])?o=o.concat(zr({key:n+"["+s+"]",value:r[s],valueSpec:i.geometry_type,style:e.style,styleSpec:e.styleSpec})):"string"!==a&&"number"!==a&&"boolean"!==a&&o.push(new Mt(n+"["+s+"]",r[s],"string, number, or boolean expected, "+a+" found"));break;case"any":case"all":case"none":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+"["+l+"]",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case"has":case"!has":a=pr(r[1]),2!==r.length?o.push(new Mt(n,r,'filter array for "'+r[0]+'" operator must have 2 elements')):"string"!==a&&o.push(new Mt(n+"[1]",r[1],"string expected, "+a+" found"))}return o}(t)}function Hr(t,e){var r=t.key,n=t.style,a=t.styleSpec,i=t.value,o=t.objectKey,s=a[e+"_"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if("paint"===e&&l&&s[l[1]]&&s[l[1]].transition)return Qr({key:r,value:i,valueSpec:a.transition,style:n,styleSpec:a});var c,u=t.valueSpec||s[o];if(!u)return[new Mt(r,i,'unknown property "'+o+'"')];if("string"===pr(i)&&ur(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(i)))return[new Mt(r,i,'"'+o+'" does not support interpolation syntax\nUse an identity property function instead: `{ "type": "identity", "property": '+JSON.stringify(c[1])+" }`.")];var h=[];return"symbol"===t.layerType&&("text-field"===o&&n&&!n.glyphs&&h.push(new Mt(r,i,'use of "text-field" requires a style "glyphs" property')),"text-font"===o&&dr(Ct(i))&&"identity"===Lt(i.type)&&h.push(new Mt(r,i,'"text-font" does not support identity functions'))),h.concat(Qr({key:t.key,value:i,valueSpec:u,style:n,styleSpec:a,expressionContext:"property",propertyType:e,propertyKey:o}))}function Gr(t){return Hr(t,"paint")}function Yr(t){return Hr(t,"layout")}function Wr(t){var e=[],r=t.value,n=t.key,a=t.style,i=t.styleSpec;r.type||r.ref||e.push(new Mt(n,r,'either "type" or "ref" is required'));var o,s=Lt(r.type),l=Lt(r.ref);if(r.id)for(var c=Lt(r.id),u=0;u<t.arrayIndex;u++){var h=a.layers[u];Lt(h.id)===c&&e.push(new Mt(n,r.id,'duplicate layer id "'+r.id+'", previously used at line '+h.id.__line__))}if("ref"in r)["type","source","source-layer","filter","layout"].forEach(function(t){t in r&&e.push(new Mt(n,r[t],'"'+t+'" is prohibited for ref layers'))}),a.layers.forEach(function(t){Lt(t.id)===l&&(o=t)}),o?o.ref?e.push(new Mt(n,r.ref,"ref cannot reference another ref layer")):s=Lt(o.type):e.push(new Mt(n,r.ref,'ref layer "'+l+'" not found'));else if("background"!==s)if(r.source){var f=a.sources&&a.sources[r.source],p=f&&Lt(f.type);f?"vector"===p&&"raster"===s?e.push(new Mt(n,r.source,'layer "'+r.id+'" requires a raster source')):"raster"===p&&"raster"!==s?e.push(new Mt(n,r.source,'layer "'+r.id+'" requires a vector source')):"vector"!==p||r["source-layer"]?"raster-dem"===p&&"hillshade"!==s?e.push(new Mt(n,r.source,"raster-dem source can only be used with layer type 'hillshade'.")):"line"!==s||!r.paint||!r.paint["line-gradient"]||"geojson"===p&&f.lineMetrics||e.push(new Mt(n,r,'layer "'+r.id+'" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new Mt(n,r,'layer "'+r.id+'" must specify a "source-layer"')):e.push(new Mt(n,r.source,'source "'+r.source+'" not found'))}else e.push(new Mt(n,r,'missing required property "source"'));return e=e.concat(Er({key:n,value:r,valueSpec:i.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{"*":function(){return[]},type:function(){return Qr({key:n+".type",value:r.type,valueSpec:i.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:"type"})},filter:qr,layout:function(t){return Er({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{"*":function(t){return Yr(St({layerType:s},t))}}})},paint:function(t){return Er({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{"*":function(t){return Gr(St({layerType:s},t))}}})}}}))}function Xr(t){var e=t.value,r=t.key,n=t.styleSpec,a=t.style;if(!e.type)return[new Mt(r,e,'"type" is required')];var i,o=Lt(e.type);switch(o){case"vector":case"raster":case"raster-dem":return Er({key:r,value:e,valueSpec:n["source_"+o.replace("-","_")],style:t.style,styleSpec:n});case"geojson":if(i=Er({key:r,value:e,valueSpec:n.source_geojson,style:a,styleSpec:n}),e.cluster)for(var s in e.clusterProperties){var l=e.clusterProperties[s],c=l[0],u=l[1],h="string"==typeof c?[c,["accumulated"],["get",s]]:c;i.push.apply(i,Or({key:r+"."+s+".map",value:u,expressionContext:"cluster-map"})),i.push.apply(i,Or({key:r+"."+s+".reduce",value:h,expressionContext:"cluster-reduce"}))}return i;case"video":return Er({key:r,value:e,valueSpec:n.source_video,style:a,styleSpec:n});case"image":return Er({key:r,value:e,valueSpec:n.source_image,style:a,styleSpec:n});case"canvas":return[new Mt(r,null,"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.","source.canvas")];default:return zr({key:r+".type",value:e.type,valueSpec:{values:["vector","raster","raster-dem","geojson","video","image"]},style:a,styleSpec:n})}}function Zr(t){var e=t.value,r=t.styleSpec,n=r.light,a=t.style,i=[],o=pr(e);if(void 0===e)return i;if("object"!==o)return i.concat([new Mt("light",e,"object expected, "+o+" found")]);for(var s in e){var l=s.match(/^(.*)-transition$/);i=l&&n[l[1]]&&n[l[1]].transition?i.concat(Qr({key:s,value:e[s],valueSpec:r.transition,style:a,styleSpec:r})):n[s]?i.concat(Qr({key:s,value:e[s],valueSpec:n[s],style:a,styleSpec:r})):i.concat([new Mt(s,e[s],'unknown property "'+s+'"')])}return i}function Jr(t){var e=t.value,r=t.key,n=pr(e);return"string"!==n?[new Mt(r,e,"string expected, "+n+" found")]:[]}var Kr={"*":function(){return[]},array:Lr,boolean:function(t){var e=t.value,r=t.key,n=pr(e);return"boolean"!==n?[new Mt(r,e,"boolean expected, "+n+" found")]:[]},number:Cr,color:function(t){var e=t.key,r=t.value,n=pr(r);return"string"!==n?[new Mt(e,r,"color expected, "+n+" found")]:null===Yt(r)?[new Mt(e,r,'color expected, "'+r+'" found')]:[]},constants:At,enum:zr,filter:qr,function:Pr,layer:Wr,object:Er,source:Xr,light:Zr,string:Jr,formatted:function(t){return 0===Jr(t).length?[]:Or(t)}};function Qr(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&dr(Lt(e))?Pr(t):r.expression&&wr(Ct(e))?Or(t):r.type&&Kr[r.type]?Kr[r.type](t):Er(St({},t,{valueSpec:r.type?n[r.type]:r}))}function $r(t){var e=t.value,r=t.key,n=Jr(t);return n.length?n:(-1===e.indexOf("{fontstack}")&&n.push(new Mt(r,e,'"glyphs" url must include a "{fontstack}" token')),-1===e.indexOf("{range}")&&n.push(new Mt(r,e,'"glyphs" url must include a "{range}" token')),n)}function tn(t,e){e=e||Tt;var r=[];return r=r.concat(Qr({key:"",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:$r,"*":function(){return[]}}})),t.constants&&(r=r.concat(At({key:"constants",value:t.constants,style:t,styleSpec:e}))),en(r)}function en(t){return[].concat(t).sort(function(t,e){return t.line-e.line})}function rn(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return en(t.apply(this,e))}}tn.source=rn(Xr),tn.light=rn(Zr),tn.layer=rn(Wr),tn.filter=rn(qr),tn.paintProperty=rn(Gr),tn.layoutProperty=rn(Yr);var nn=tn,an=nn.light,on=nn.paintProperty,sn=nn.layoutProperty;function ln(t,e){var r=!1;if(e&&e.length)for(var n=0,a=e;n<a.length;n+=1){var i=a[n];t.fire(new wt(new Error(i.message))),r=!0}return r}var cn=hn,un=3;function hn(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var a=new Int32Array(this.arrayBuffer);t=a[0],e=a[1],r=a[2],this.d=e+2*r;for(var i=0;i<this.d*this.d;i++){var o=a[un+i],s=a[un+i+1];n.push(o===s?null:a.subarray(o,s))}var l=a[un+n.length],c=a[un+n.length+1];this.keys=a.subarray(l,c),this.bboxes=a.subarray(c),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var u=0;u<this.d*this.d;u++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var h=r/e*t;this.min=-h,this.max=t+h}hn.prototype.insert=function(t,e,r,n,a){this._forEachCell(e,r,n,a,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(a)},hn.prototype._insertReadonly=function(){throw"Cannot insert into a GridIndex created from an ArrayBuffer."},hn.prototype._insertCell=function(t,e,r,n,a,i){this.cells[a].push(i)},hn.prototype.query=function(t,e,r,n,a){var i=this.min,o=this.max;if(t<=i&&e<=i&&o<=r&&o<=n&&!a)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},a),s},hn.prototype._queryCell=function(t,e,r,n,a,i,o,s){var l=this.cells[a];if(null!==l)for(var c=this.keys,u=this.bboxes,h=0;h<l.length;h++){var f=l[h];if(void 0===o[f]){var p=4*f;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[f]=!0,i.push(c[f])):o[f]=!1}}},hn.prototype._forEachCell=function(t,e,r,n,a,i,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),h=this._convertToCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.d*p+f;if((!s||s(this._convertFromCellCoord(f),this._convertFromCellCoord(p),this._convertFromCellCoord(f+1),this._convertFromCellCoord(p+1)))&&a.call(this,t,e,r,n,d,i,o,s))return}},hn.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},hn.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},hn.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=un+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var a=new Int32Array(e+r+this.keys.length+this.bboxes.length);a[0]=this.extent,a[1]=this.n,a[2]=this.padding;for(var i=e,o=0;o<t.length;o++){var s=t[o];a[un+o]=i,a.set(s,i),i+=s.length}return a[un+t.length]=i,a.set(this.keys,i),i+=this.keys.length,a[un+t.length+1]=i,a.set(this.bboxes,i),i+=this.bboxes.length,a.buffer};var fn=self.ImageData,pn={};function dn(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,"_classRegistryKey",{value:t,writeable:!1}),pn[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var gn in dn("Object",Object),cn.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},cn.deserialize=function(t){return new cn(t.buffer)},dn("Grid",cn),dn("Color",Wt),dn("Error",Error),dn("StylePropertyFunction",Sr),dn("StyleExpression",_r,{omit:["_evaluator"]}),dn("ZoomDependentExpression",Mr),dn("ZoomConstantExpression",Tr),dn("CompoundExpression",ce,{omit:["_evaluate"]}),nr)nr[gn]._classRegistryKey||dn("Expression_"+gn,nr[gn]);function vn(t,e){if(null==t||"boolean"==typeof t||"number"==typeof t||"string"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(t instanceof ArrayBuffer)return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof fn)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],a=0,i=t;a<i.length;a+=1){var o=i[a];n.push(vn(o,e))}return n}if("object"==typeof t){var s=t.constructor,l=s._classRegistryKey;if(!l)throw new Error("can't serialize object of unregistered class");var c=s.serialize?s.serialize(t,e):{};if(!s.serialize){for(var u in t)if(t.hasOwnProperty(u)&&!(pn[l].omit.indexOf(u)>=0)){var h=t[u];c[u]=pn[l].shallow.indexOf(u)>=0?h:vn(h,e)}t instanceof Error&&(c.message=t.message)}if(c.$name)throw new Error("$name property is reserved for worker serialization logic.");return"Object"!==l&&(c.$name=l),c}throw new Error("can't serialize object of type "+typeof t)}function mn(t){if(null==t||"boolean"==typeof t||"number"==typeof t||"string"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||t instanceof ArrayBuffer||ArrayBuffer.isView(t)||t instanceof fn)return t;if(Array.isArray(t))return t.map(mn);if("object"==typeof t){var e=t.$name||"Object",r=pn[e].klass;if(!r)throw new Error("can't deserialize unregistered class "+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),a=0,i=Object.keys(t);a<i.length;a+=1){var o=i[a];if("$name"!==o){var s=t[o];n[o]=pn[e].shallow.indexOf(o)>=0?s:mn(s)}}return n}throw new Error("can't deserialize object of type "+typeof t)}var yn=function(){this.first=!0};yn.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var xn={"Latin-1 Supplement":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},"Arabic Supplement":function(t){return t>=1872&&t<=1919},"Arabic Extended-A":function(t){return t>=2208&&t<=2303},"Hangul Jamo":function(t){return t>=4352&&t<=4607},"Unified Canadian Aboriginal Syllabics":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},"Unified Canadian Aboriginal Syllabics Extended":function(t){return t>=6320&&t<=6399},"General Punctuation":function(t){return t>=8192&&t<=8303},"Letterlike Symbols":function(t){return t>=8448&&t<=8527},"Number Forms":function(t){return t>=8528&&t<=8591},"Miscellaneous Technical":function(t){return t>=8960&&t<=9215},"Control Pictures":function(t){return t>=9216&&t<=9279},"Optical Character Recognition":function(t){return t>=9280&&t<=9311},"Enclosed Alphanumerics":function(t){return t>=9312&&t<=9471},"Geometric Shapes":function(t){return t>=9632&&t<=9727},"Miscellaneous Symbols":function(t){return t>=9728&&t<=9983},"Miscellaneous Symbols and Arrows":function(t){return t>=11008&&t<=11263},"CJK Radicals Supplement":function(t){return t>=11904&&t<=12031},"Kangxi Radicals":function(t){return t>=12032&&t<=12255},"Ideographic Description Characters":function(t){return t>=12272&&t<=12287},"CJK Symbols and Punctuation":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},"Hangul Compatibility Jamo":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},"Bopomofo Extended":function(t){return t>=12704&&t<=12735},"CJK Strokes":function(t){return t>=12736&&t<=12783},"Katakana Phonetic Extensions":function(t){return t>=12784&&t<=12799},"Enclosed CJK Letters and Months":function(t){return t>=12800&&t<=13055},"CJK Compatibility":function(t){return t>=13056&&t<=13311},"CJK Unified Ideographs Extension A":function(t){return t>=13312&&t<=19903},"Yijing Hexagram Symbols":function(t){return t>=19904&&t<=19967},"CJK Unified Ideographs":function(t){return t>=19968&&t<=40959},"Yi Syllables":function(t){return t>=40960&&t<=42127},"Yi Radicals":function(t){return t>=42128&&t<=42191},"Hangul Jamo Extended-A":function(t){return t>=43360&&t<=43391},"Hangul Syllables":function(t){return t>=44032&&t<=55215},"Hangul Jamo Extended-B":function(t){return t>=55216&&t<=55295},"Private Use Area":function(t){return t>=57344&&t<=63743},"CJK Compatibility Ideographs":function(t){return t>=63744&&t<=64255},"Arabic Presentation Forms-A":function(t){return t>=64336&&t<=65023},"Vertical Forms":function(t){return t>=65040&&t<=65055},"CJK Compatibility Forms":function(t){return t>=65072&&t<=65103},"Small Form Variants":function(t){return t>=65104&&t<=65135},"Arabic Presentation Forms-B":function(t){return t>=65136&&t<=65279},"Halfwidth and Fullwidth Forms":function(t){return t>=65280&&t<=65519}};function bn(t){for(var e=0,r=t;e<r.length;e+=1)if(wn(r[e].charCodeAt(0)))return!0;return!1}function _n(t){return!(xn.Arabic(t)||xn["Arabic Supplement"](t)||xn["Arabic Extended-A"](t)||xn["Arabic Presentation Forms-A"](t)||xn["Arabic Presentation Forms-B"](t))}function wn(t){return!!(746===t||747===t||!(t<4352)&&(xn["Bopomofo Extended"](t)||xn.Bopomofo(t)||xn["CJK Compatibility Forms"](t)&&!(t>=65097&&t<=65103)||xn["CJK Compatibility Ideographs"](t)||xn["CJK Compatibility"](t)||xn["CJK Radicals Supplement"](t)||xn["CJK Strokes"](t)||!(!xn["CJK Symbols and Punctuation"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||xn["CJK Unified Ideographs Extension A"](t)||xn["CJK Unified Ideographs"](t)||xn["Enclosed CJK Letters and Months"](t)||xn["Hangul Compatibility Jamo"](t)||xn["Hangul Jamo Extended-A"](t)||xn["Hangul Jamo Extended-B"](t)||xn["Hangul Jamo"](t)||xn["Hangul Syllables"](t)||xn.Hiragana(t)||xn["Ideographic Description Characters"](t)||xn.Kanbun(t)||xn["Kangxi Radicals"](t)||xn["Katakana Phonetic Extensions"](t)||xn.Katakana(t)&&12540!==t||!(!xn["Halfwidth and Fullwidth Forms"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!xn["Small Form Variants"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||xn["Unified Canadian Aboriginal Syllabics"](t)||xn["Unified Canadian Aboriginal Syllabics Extended"](t)||xn["Vertical Forms"](t)||xn["Yijing Hexagram Symbols"](t)||xn["Yi Syllables"](t)||xn["Yi Radicals"](t)))}function kn(t){return!(wn(t)||function(t){return!!(xn["Latin-1 Supplement"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||xn["General Punctuation"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||xn["Letterlike Symbols"](t)||xn["Number Forms"](t)||xn["Miscellaneous Technical"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||xn["Control Pictures"](t)&&9251!==t||xn["Optical Character Recognition"](t)||xn["Enclosed Alphanumerics"](t)||xn["Geometric Shapes"](t)||xn["Miscellaneous Symbols"](t)&&!(t>=9754&&t<=9759)||xn["Miscellaneous Symbols and Arrows"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||xn["CJK Symbols and Punctuation"](t)||xn.Katakana(t)||xn["Private Use Area"](t)||xn["CJK Compatibility Forms"](t)||xn["Small Form Variants"](t)||xn["Halfwidth and Fullwidth Forms"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function Tn(t,e){return!(!e&&(t>=1424&&t<=2303||xn["Arabic Presentation Forms-A"](t)||xn["Arabic Presentation Forms-B"](t))||t>=2304&&t<=3583||t>=3840&&t<=4255||xn.Khmer(t))}var Mn,An=!1,Sn=null,En=!1,Ln=new kt,Cn={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return En||null!=Cn.applyArabicShaping}},Pn=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new yn,this.transition={})};Pn.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!Tn(n[r].charCodeAt(0),e))return!1;return!0}(t,Cn.isLoaded())},Pn.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},Pn.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var On=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(dr(t))return new Sr(t,e);if(wr(t)){var r=Ar(t,e);if("error"===r.result)throw new Error(r.value.map(function(t){return t.key+": "+t.message}).join(", "));return r.value}var n=t;return"string"==typeof t&&"color"===e.type&&(n=Wt.parse(t)),{kind:"constant",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};On.prototype.isDataDriven=function(){return"source"===this.expression.kind||"composite"===this.expression.kind},On.prototype.possiblyEvaluate=function(t){return this.property.possiblyEvaluate(this,t)};var zn=function(t){this.property=t,this.value=new On(t,void 0)};zn.prototype.transitioned=function(t,e){return new Dn(this.property,this.value,e,h({},t.transition,this.transition),t.now)},zn.prototype.untransitioned=function(){return new Dn(this.property,this.value,null,{},0)};var In=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};In.prototype.getValue=function(t){return b(this._values[t].value.value)},In.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new zn(this._values[t].property)),this._values[t].value=new On(this._values[t].property,null===e?void 0:b(e))},In.prototype.getTransition=function(t){return b(this._values[t].transition)},In.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new zn(this._values[t].property)),this._values[t].transition=b(e)||void 0},In.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],a=this.getValue(n);void 0!==a&&(t[n]=a);var i=this.getTransition(n);void 0!==i&&(t[n+"-transition"]=i)}return t},In.prototype.transitioned=function(t,e){for(var r=new Rn(this._properties),n=0,a=Object.keys(this._values);n<a.length;n+=1){var i=a[n];r._values[i]=this._values[i].transitioned(t,e._values[i])}return r},In.prototype.untransitioned=function(){for(var t=new Rn(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var Dn=function(t,e,r,n,a){this.property=t,this.value=e,this.begin=a+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};Dn.prototype.possiblyEvaluate=function(t){var e=t.now||0,r=this.value.possiblyEvaluate(t),n=this.prior;if(n){if(e>this.end)return this.prior=null,r;if(this.value.isDataDriven())return this.prior=null,r;if(e<this.begin)return n.possiblyEvaluate(t);var a=(e-this.begin)/(this.end-this.begin);return this.property.interpolate(n.possiblyEvaluate(t),r,function(t){if(a<=0)return 0;if(a>=1)return 1;var e=a*a,r=e*a;return 4*(a<.5?r:3*(a-e)+r-.75)}())}return r};var Rn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};Rn.prototype.possiblyEvaluate=function(t){for(var e=new Nn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var a=n[r];e._values[a]=this._values[a].possiblyEvaluate(t)}return e},Rn.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1){var r=e[t];if(this._values[r].prior)return!0}return!1};var Fn=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};Fn.prototype.getValue=function(t){return b(this._values[t].value)},Fn.prototype.setValue=function(t,e){this._values[t]=new On(this._values[t].property,null===e?void 0:b(e))},Fn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],a=this.getValue(n);void 0!==a&&(t[n]=a)}return t},Fn.prototype.possiblyEvaluate=function(t){for(var e=new Nn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var a=n[r];e._values[a]=this._values[a].possiblyEvaluate(t)}return e};var Bn=function(t,e,r){this.property=t,this.value=e,this.parameters=r};Bn.prototype.isConstant=function(){return"constant"===this.value.kind},Bn.prototype.constantOr=function(t){return"constant"===this.value.kind?this.value.value:t},Bn.prototype.evaluate=function(t,e){return this.property.evaluate(this.value,this.parameters,t,e)};var Nn=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};Nn.prototype.get=function(t){return this._values[t]};var jn=function(t){this.specification=t};jn.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},jn.prototype.interpolate=function(t,e,r){var n=xe[this.specification.type];return n?n(t,e,r):t};var Vn=function(t,e){this.specification=t,this.overrides=e};Vn.prototype.possiblyEvaluate=function(t,e){return"constant"===t.expression.kind||"camera"===t.expression.kind?new Bn(this,{kind:"constant",value:t.expression.evaluate(e)},e):new Bn(this,t.expression,e)},Vn.prototype.interpolate=function(t,e,r){if("constant"!==t.value.kind||"constant"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new Bn(this,{kind:"constant",value:void 0},t.parameters);var n=xe[this.specification.type];return n?new Bn(this,{kind:"constant",value:n(t.value.value,e.value.value,r)},t.parameters):t},Vn.prototype.evaluate=function(t,e,r,n){return"constant"===t.kind?t.value:t.evaluate(e,r,n)};var Un=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(t,e){if(void 0===t.value)return new Bn(this,{kind:"constant",value:void 0},e);if("constant"===t.expression.kind){var r=t.expression.evaluate(e),n=this._calculate(r,r,r,e);return new Bn(this,{kind:"constant",value:n},e)}if("camera"===t.expression.kind){var a=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new Bn(this,{kind:"constant",value:a},e)}return new Bn(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n){if("source"===t.kind){var a=t.evaluate(e,r,n);return this._calculate(a,a,a,e)}return"composite"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(Vn),qn=function(t){this.specification=t};qn.prototype.possiblyEvaluate=function(t,e){if(void 0!==t.value){if("constant"===t.expression.kind){var r=t.expression.evaluate(e);return this._calculate(r,r,r,e)}return this._calculate(t.expression.evaluate(new Pn(Math.floor(e.zoom-1),e)),t.expression.evaluate(new Pn(Math.floor(e.zoom),e)),t.expression.evaluate(new Pn(Math.floor(e.zoom+1),e)),e)}},qn.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},qn.prototype.interpolate=function(t){return t};var Hn=function(t){this.specification=t};Hn.prototype.possiblyEvaluate=function(t,e){return!!t.expression.evaluate(e)},Hn.prototype.interpolate=function(){return!1};var Gn=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},this.overridableProperties=[],t){var r=t[e];r.specification.overridable&&this.overridableProperties.push(e);var n=this.defaultPropertyValues[e]=new On(r,void 0),a=this.defaultTransitionablePropertyValues[e]=new zn(r);this.defaultTransitioningPropertyValues[e]=a.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};dn("DataDrivenProperty",Vn),dn("DataConstantProperty",jn),dn("CrossFadedDataDrivenProperty",Un),dn("CrossFadedProperty",qn),dn("ColorRampProperty",Hn);var Yn=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter=function(){return!0},"custom"!==e.type&&(e=e,this.metadata=e.metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,"background"!==e.type&&(this.source=e.source,this.sourceLayer=e["source-layer"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new Fn(r.layout)),r.paint)){for(var n in this._transitionablePaint=new In(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var a in e.layout)this.setLayoutProperty(a,e.layout[a],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned()}}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return"visibility"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n="layers."+this.id+".layout."+t;if(this._validate(sn,n,t,e,r))return}"visibility"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e},e.prototype.getPaintProperty=function(t){return m(t,"-transition")?this._transitionablePaint.getTransition(t.slice(0,-"-transition".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n="layers."+this.id+".paint."+t;if(this._validate(on,n,t,e,r))return!1}if(m(t,"-transition"))return this._transitionablePaint.setTransition(t.slice(0,-"-transition".length),e||void 0),!1;var a=this._transitionablePaint._values[t],i="cross-faded-data-driven"===a.property.specification["property-type"],o=a.value.isDataDriven(),s=a.value;this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t);var l=this._transitionablePaint._values[t].value;return l.isDataDriven()||o||i||this._handleOverridablePaintPropertyUpdate(t,s,l)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype._handleOverridablePaintPropertyUpdate=function(t,e,r){return!1},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||"none"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t)),this.paint=this._transitioningPaint.possiblyEvaluate(t)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,"source-layer":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),x(t,function(t,e){return!(void 0===t||"layout"===e&&!Object.keys(t).length||"paint"===e&&!Object.keys(t).length)})},e.prototype._validate=function(t,e,r,n,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&ln(this,t.call(nn,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:Tt,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof Bn&&ur(e.property.specification)&&("source"===e.value.kind||"composite"===e.value.kind)&&e.value.isStateDependent)return!0}return!1},e}(kt),Wn={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},Xn=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},Zn=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function Jn(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map(function(t){var a,i=(a=t.type,Wn[a].BYTES_PER_ELEMENT),o=r=Kn(r,Math.max(e,i)),s=t.components||1;return n=Math.max(n,i),r+=i*s,{name:t.name,type:t.type,components:s,offset:o}}),size:Kn(r,Math.max(n,e)),alignment:e}}function Kn(t,e){return Math.ceil(t/e)*e}Zn.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},Zn.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},Zn.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},Zn.prototype.clear=function(){this.length=0},Zn.prototype.resize=function(t){this.reserve(t),this.length=t},Zn.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},Zn.prototype._refreshViews=function(){throw new Error("_refreshViews() must be implemented by each concrete StructArray layout")};var Qn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(Zn);Qn.prototype.bytesPerElement=4,dn("StructArrayLayout2i4",Qn);var $n=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var a=this.length;return this.resize(a+1),this.emplace(a,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,a){var i=4*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,this.int16[i+3]=a,t},e}(Zn);$n.prototype.bytesPerElement=8,dn("StructArrayLayout4i8",$n);var ta=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,a,i)},e.prototype.emplace=function(t,e,r,n,a,i,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=a,this.int16[s+4]=i,this.int16[s+5]=o,t},e}(Zn);ta.prototype.bytesPerElement=12,dn("StructArrayLayout2i4i12",ta);var ea=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,a,i)},e.prototype.emplace=function(t,e,r,n,a,i,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=a,this.uint8[l+6]=i,this.uint8[l+7]=o,t},e}(Zn);ea.prototype.bytesPerElement=8,dn("StructArrayLayout2i4ub8",ea);var ra=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,a,i,o,s)},e.prototype.emplace=function(t,e,r,n,a,i,o,s,l){var c=8*t;return this.uint16[c+0]=e,this.uint16[c+1]=r,this.uint16[c+2]=n,this.uint16[c+3]=a,this.uint16[c+4]=i,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(Zn);ra.prototype.bytesPerElement=16,dn("StructArrayLayout8ui16",ra);var na=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,a,i,o,s)},e.prototype.emplace=function(t,e,r,n,a,i,o,s,l){var c=8*t;return this.int16[c+0]=e,this.int16[c+1]=r,this.int16[c+2]=n,this.int16[c+3]=a,this.uint16[c+4]=i,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(Zn);na.prototype.bytesPerElement=16,dn("StructArrayLayout4i4ui16",na);var aa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var a=3*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,t},e}(Zn);aa.prototype.bytesPerElement=12,dn("StructArrayLayout3f12",aa);var ia=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint32[r+0]=e,t},e}(Zn);ia.prototype.bytesPerElement=4,dn("StructArrayLayout1ul4",ia);var oa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i,o,s,l,c,u){var h=this.length;return this.resize(h+1),this.emplace(h,t,e,r,n,a,i,o,s,l,c,u)},e.prototype.emplace=function(t,e,r,n,a,i,o,s,l,c,u,h){var f=12*t,p=6*t;return this.int16[f+0]=e,this.int16[f+1]=r,this.int16[f+2]=n,this.int16[f+3]=a,this.int16[f+4]=i,this.int16[f+5]=o,this.uint32[p+3]=s,this.uint16[f+8]=l,this.uint16[f+9]=c,this.int16[f+10]=u,this.int16[f+11]=h,t},e}(Zn);oa.prototype.bytesPerElement=24,dn("StructArrayLayout6i1ul2ui2i24",oa);var sa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,a,i)},e.prototype.emplace=function(t,e,r,n,a,i,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=a,this.int16[s+4]=i,this.int16[s+5]=o,t},e}(Zn);sa.prototype.bytesPerElement=12,dn("StructArrayLayout2i2i2i12",sa);var la=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var a=this.length;return this.resize(a+1),this.emplace(a,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,a){var i=12*t,o=3*t;return this.uint8[i+0]=e,this.uint8[i+1]=r,this.float32[o+1]=n,this.float32[o+2]=a,t},e}(Zn);la.prototype.bytesPerElement=12,dn("StructArrayLayout2ub2f12",la);var ca=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g){var v=this.length;return this.resize(v+1),this.emplace(v,t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g)},e.prototype.emplace=function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,v){var m=22*t,y=11*t,x=44*t;return this.int16[m+0]=e,this.int16[m+1]=r,this.uint16[m+2]=n,this.uint16[m+3]=a,this.uint32[y+2]=i,this.uint32[y+3]=o,this.uint32[y+4]=s,this.uint16[m+10]=l,this.uint16[m+11]=c,this.uint16[m+12]=u,this.float32[y+7]=h,this.float32[y+8]=f,this.uint8[x+36]=p,this.uint8[x+37]=d,this.uint8[x+38]=g,this.uint32[y+10]=v,t},e}(Zn);ca.prototype.bytesPerElement=44,dn("StructArrayLayout2i2ui3ul3ui2f3ub1ul44",ca);var ua=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,v,m,y,x){var b=this.length;return this.resize(b+1),this.emplace(b,t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,v,m,y,x)},e.prototype.emplace=function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b){var _=24*t,w=12*t;return this.int16[_+0]=e,this.int16[_+1]=r,this.int16[_+2]=n,this.int16[_+3]=a,this.int16[_+4]=i,this.int16[_+5]=o,this.uint16[_+6]=s,this.uint16[_+7]=l,this.uint16[_+8]=c,this.uint16[_+9]=u,this.uint16[_+10]=h,this.uint16[_+11]=f,this.uint16[_+12]=p,this.uint16[_+13]=d,this.uint16[_+14]=g,this.uint16[_+15]=v,this.uint16[_+16]=m,this.uint32[w+9]=y,this.float32[w+10]=x,this.float32[w+11]=b,t},e}(Zn);ua.prototype.bytesPerElement=48,dn("StructArrayLayout6i11ui1ul2f48",ua);var ha=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.float32[r+0]=e,t},e}(Zn);ha.prototype.bytesPerElement=4,dn("StructArrayLayout1f4",ha);var fa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var a=3*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,t},e}(Zn);fa.prototype.bytesPerElement=6,dn("StructArrayLayout3i6",fa);var pa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var a=2*t,i=4*t;return this.uint32[a+0]=e,this.uint16[i+2]=r,this.uint16[i+3]=n,t},e}(Zn);pa.prototype.bytesPerElement=8,dn("StructArrayLayout1ul2ui8",pa);var da=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var a=3*t;return this.uint16[a+0]=e,this.uint16[a+1]=r,this.uint16[a+2]=n,t},e}(Zn);da.prototype.bytesPerElement=6,dn("StructArrayLayout3ui6",da);var ga=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(Zn);ga.prototype.bytesPerElement=4,dn("StructArrayLayout2ui4",ga);var va=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint16[r+0]=e,t},e}(Zn);va.prototype.bytesPerElement=2,dn("StructArrayLayout1ui2",va);var ma=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(Zn);ma.prototype.bytesPerElement=8,dn("StructArrayLayout2f8",ma);var ya=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var a=this.length;return this.resize(a+1),this.emplace(a,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,a){var i=4*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,this.float32[i+3]=a,t},e}(Zn);ya.prototype.bytesPerElement=16,dn("StructArrayLayout4f16",ya);var xa=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},radius:{configurable:!0},signedDistanceFromAnchor:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorPointY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.x1.set=function(t){this._structArray.int16[this._pos2+2]=t},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.y1.set=function(t){this._structArray.int16[this._pos2+3]=t},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.x2.set=function(t){this._structArray.int16[this._pos2+4]=t},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.y2.set=function(t){this._structArray.int16[this._pos2+5]=t},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.radius.get=function(){return this._structArray.int16[this._pos2+10]},r.radius.set=function(t){this._structArray.int16[this._pos2+10]=t},r.signedDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+11]},r.signedDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+11]=t},r.anchorPoint.get=function(){return new a(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(Xn);xa.prototype.size=24;var ba=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new xa(this,t)},e}(oa);dn("CollisionBoxArray",ba);var _a=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},placedOrientation:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.glyphStartIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.numGlyphs.set=function(t){this._structArray.uint16[this._pos2+3]=t},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.vertexStartIndex.set=function(t){this._structArray.uint32[this._pos4+2]=t},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineStartIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.lineLength.set=function(t){this._structArray.uint32[this._pos4+4]=t},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.segment.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.lowerSize.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.upperSize.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetX.set=function(t){this._structArray.float32[this._pos4+7]=t},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.lineOffsetY.set=function(t){this._structArray.float32[this._pos4+8]=t},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.writingMode.set=function(t){this._structArray.uint8[this._pos1+36]=t},r.placedOrientation.get=function(){return this._structArray.uint8[this._pos1+37]},r.placedOrientation.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+38]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+38]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(Xn);_a.prototype.size=44;var wa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new _a(this,t)},e}(ca);dn("PlacedSymbolArray",wa);var ka=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},verticalTextBoxStartIndex:{configurable:!0},verticalTextBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},radialTextOffset:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.rightJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+2]=t},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.centerJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+3]=t},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.leftJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+4]=t},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.verticalPlacedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+5]=t},r.key.get=function(){return this._structArray.uint16[this._pos2+6]},r.key.set=function(t){this._structArray.uint16[this._pos2+6]=t},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+7]},r.textBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+7]=t},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.verticalTextBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.verticalTextBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.verticalTextBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.verticalTextBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.iconBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+12]},r.iconBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+13]},r.featureIndex.set=function(t){this._structArray.uint16[this._pos2+13]=t},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+14]},r.numHorizontalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+14]=t},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+15]},r.numVerticalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+15]=t},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+16]},r.numIconVertices.set=function(t){this._structArray.uint16[this._pos2+16]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+9]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+9]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+10]},r.textBoxScale.set=function(t){this._structArray.float32[this._pos4+10]=t},r.radialTextOffset.get=function(){return this._structArray.float32[this._pos4+11]},r.radialTextOffset.set=function(t){this._structArray.float32[this._pos4+11]=t},Object.defineProperties(e.prototype,r),e}(Xn);ka.prototype.size=48;var Ta=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new ka(this,t)},e}(ua);dn("SymbolInstanceArray",Ta);var Ma=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={offsetX:{configurable:!0}};return r.offsetX.get=function(){return this._structArray.float32[this._pos4+0]},r.offsetX.set=function(t){this._structArray.float32[this._pos4+0]=t},Object.defineProperties(e.prototype,r),e}(Xn);Ma.prototype.size=4;var Aa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e.prototype.get=function(t){return new Ma(this,t)},e}(ha);dn("GlyphOffsetArray",Aa);var Sa=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={x:{configurable:!0},y:{configurable:!0},tileUnitDistanceFromAnchor:{configurable:!0}};return r.x.get=function(){return this._structArray.int16[this._pos2+0]},r.x.set=function(t){this._structArray.int16[this._pos2+0]=t},r.y.get=function(){return this._structArray.int16[this._pos2+1]},r.y.set=function(t){this._structArray.int16[this._pos2+1]=t},r.tileUnitDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+2]},r.tileUnitDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+2]=t},Object.defineProperties(e.prototype,r),e}(Xn);Sa.prototype.size=6;var Ea=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e.prototype.get=function(t){return new Sa(this,t)},e}(fa);dn("SymbolLineVertexArray",Ea);var La=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+0]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+3]=t},Object.defineProperties(e.prototype,r),e}(Xn);La.prototype.size=8;var Ca=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new La(this,t)},e}(pa);dn("FeatureIndexArray",Ca);var Pa=Jn([{name:"a_pos",components:2,type:"Int16"}],4).members,Oa=function(t){void 0===t&&(t=[]),this.segments=t};function za(t,e){return 256*(t=c(Math.floor(t),0,255))+c(Math.floor(e),0,255)}Oa.prototype.prepareSegment=function(t,e,r,n){var a=this.segments[this.segments.length-1];return t>Oa.MAX_VERTEX_ARRAY_LENGTH&&w("Max vertices per segment is "+Oa.MAX_VERTEX_ARRAY_LENGTH+": bucket requested "+t),(!a||a.vertexLength+t>Oa.MAX_VERTEX_ARRAY_LENGTH||a.sortKey!==n)&&(a={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(a.sortKey=n),this.segments.push(a)),a},Oa.prototype.get=function(){return this.segments},Oa.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},Oa.simpleSegment=function(t,e,r,n){return new Oa([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},Oa.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,dn("SegmentVector",Oa);var Ia=function(){this.ids=[],this.positions=[],this.indexed=!1};function Da(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}Ia.prototype.add=function(t,e,r,n){this.ids.push(t),this.positions.push(e,r,n)},Ia.prototype.getPositions=function(t){for(var e=0,r=this.ids.length-1;e<r;){var n=e+r>>1;this.ids[n]>=t?r=n:e=n+1}for(var a=[];this.ids[e]===t;){var i=this.positions[3*e],o=this.positions[3*e+1],s=this.positions[3*e+2];a.push({index:i,start:o,end:s}),e++}return a},Ia.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return function t(e,r,n,a){if(!(n>=a)){for(var i=e[n+a>>1],o=n-1,s=a+1;;){do{o++}while(e[o]<i);do{s--}while(e[s]>i);if(o>=s)break;Da(e,o,s),Da(r,3*o,3*s),Da(r,3*o+1,3*s+1),Da(r,3*o+2,3*s+2)}t(e,r,n,s),t(e,r,s+1,a)}}(r,n,0,r.length-1),e.push(r.buffer,n.buffer),{ids:r,positions:n}},Ia.deserialize=function(t){var e=new Ia;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e},dn("FeaturePositionMap",Ia);var Ra=function(t,e){this.gl=t.gl,this.location=e},Fa=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(Ra),Ba=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(Ra),Na=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(Ra),ja=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(Ra),Va=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(Ra),Ua=function(t){function e(e,r){t.call(this,e,r),this.current=Wt.transparent}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(Ra),qa=new Float32Array(16),Ha=function(t){function e(e,r){t.call(this,e,r),this.current=qa}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(Ra);function Ga(t){return[za(255*t.r,255*t.g),za(255*t.b,255*t.a)]}var Ya=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return"u_"+t}),this.type=r,this.maxValue=-1/0};Ya.prototype.defines=function(){return this.names.map(function(t){return"#define HAS_UNIFORM_u_"+t})},Ya.prototype.setConstantPatternPositions=function(){},Ya.prototype.populatePaintArray=function(){},Ya.prototype.updatePaintArray=function(){},Ya.prototype.upload=function(){},Ya.prototype.destroy=function(){},Ya.prototype.setUniforms=function(t,e,r,n){e.set(n.constantOr(this.value))},Ya.prototype.getBinding=function(t,e){return"color"===this.type?new Ua(t,e):new Ba(t,e)},Ya.serialize=function(t){var e=t.value,r=t.names,n=t.type;return{value:vn(e),names:r,type:n}},Ya.deserialize=function(t){var e=t.value,r=t.names,n=t.type;return new Ya(mn(e),r,n)};var Wa=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return"u_"+t}),this.type=r,this.maxValue=-1/0,this.patternPositions={patternTo:null,patternFrom:null}};Wa.prototype.defines=function(){return this.names.map(function(t){return"#define HAS_UNIFORM_u_"+t})},Wa.prototype.populatePaintArray=function(){},Wa.prototype.updatePaintArray=function(){},Wa.prototype.upload=function(){},Wa.prototype.destroy=function(){},Wa.prototype.setConstantPatternPositions=function(t,e){this.patternPositions.patternTo=t.tlbr,this.patternPositions.patternFrom=e.tlbr},Wa.prototype.setUniforms=function(t,e,r,n,a){var i=this.patternPositions;"u_pattern_to"===a&&i.patternTo&&e.set(i.patternTo),"u_pattern_from"===a&&i.patternFrom&&e.set(i.patternFrom)},Wa.prototype.getBinding=function(t,e){return new Va(t,e)};var Xa=function(t,e,r,n){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return"a_"+t}),this.maxValue=-1/0,this.paintVertexAttributes=e.map(function(t){return{name:"a_"+t,type:"Float32",components:"color"===r?2:1,offset:0}}),this.paintVertexArray=new n};Xa.prototype.defines=function(){return[]},Xa.prototype.setConstantPatternPositions=function(){},Xa.prototype.populatePaintArray=function(t,e,r,n){var a=this.paintVertexArray,i=a.length;a.reserve(t);var o=this.expression.evaluate(new Pn(0),e,{},n);if("color"===this.type)for(var s=Ga(o),l=i;l<t;l++)a.emplaceBack(s[0],s[1]);else{for(var c=i;c<t;c++)a.emplaceBack(o);this.maxValue=Math.max(this.maxValue,o)}},Xa.prototype.updatePaintArray=function(t,e,r,n){var a=this.paintVertexArray,i=this.expression.evaluate({zoom:0},r,n);if("color"===this.type)for(var o=Ga(i),s=t;s<e;s++)a.emplace(s,o[0],o[1]);else{for(var l=t;l<e;l++)a.emplace(l,i);this.maxValue=Math.max(this.maxValue,i)}},Xa.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Xa.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},Xa.prototype.setUniforms=function(t,e){e.set(0)},Xa.prototype.getBinding=function(t,e){return new Ba(t,e)};var Za=function(t,e,r,n,a,i){this.expression=t,this.names=e,this.uniformNames=this.names.map(function(t){return"u_"+t+"_t"}),this.type=r,this.useIntegerZoom=n,this.zoom=a,this.maxValue=-1/0;var o=i;this.paintVertexAttributes=e.map(function(t){return{name:"a_"+t,type:"Float32",components:"color"===r?4:2,offset:0}}),this.paintVertexArray=new o};Za.prototype.defines=function(){return[]},Za.prototype.setConstantPatternPositions=function(){},Za.prototype.populatePaintArray=function(t,e,r,n){var a=this.paintVertexArray,i=a.length;a.reserve(t);var o=this.expression.evaluate(new Pn(this.zoom),e,{},n),s=this.expression.evaluate(new Pn(this.zoom+1),e,{},n);if("color"===this.type)for(var l=Ga(o),c=Ga(s),u=i;u<t;u++)a.emplaceBack(l[0],l[1],c[0],c[1]);else{for(var h=i;h<t;h++)a.emplaceBack(o,s);this.maxValue=Math.max(this.maxValue,o,s)}},Za.prototype.updatePaintArray=function(t,e,r,n){var a=this.paintVertexArray,i=this.expression.evaluate({zoom:this.zoom},r,n),o=this.expression.evaluate({zoom:this.zoom+1},r,n);if("color"===this.type)for(var s=Ga(i),l=Ga(o),c=t;c<e;c++)a.emplace(c,s[0],s[1],l[0],l[1]);else{for(var u=t;u<e;u++)a.emplace(u,i,o);this.maxValue=Math.max(this.maxValue,i,o)}},Za.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Za.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},Za.prototype.interpolationFactor=function(t){return this.useIntegerZoom?this.expression.interpolationFactor(Math.floor(t),this.zoom,this.zoom+1):this.expression.interpolationFactor(t,this.zoom,this.zoom+1)},Za.prototype.setUniforms=function(t,e,r){e.set(this.interpolationFactor(r.zoom))},Za.prototype.getBinding=function(t,e){return new Ba(t,e)};var Ja=function(t,e,r,n,a,i,o){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return"u_"+t+"_t"}),this.useIntegerZoom=n,this.zoom=a,this.maxValue=-1/0,this.layerId=o,this.paintVertexAttributes=e.map(function(t){return{name:"a_"+t,type:"Uint16",components:4,offset:0}}),this.zoomInPaintVertexArray=new i,this.zoomOutPaintVertexArray=new i};Ja.prototype.defines=function(){return[]},Ja.prototype.setConstantPatternPositions=function(){},Ja.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray,a=this.zoomOutPaintVertexArray,i=this.layerId,o=n.length;if(n.reserve(t),a.reserve(t),r&&e.patterns&&e.patterns[i]){var s=e.patterns[i],l=s.min,c=s.mid,u=s.max,h=r[l],f=r[c],p=r[u];if(!h||!f||!p)return;for(var d=o;d<t;d++)n.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],h.tl[0],h.tl[1],h.br[0],h.br[1]),a.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],p.tl[0],p.tl[1],p.br[0],p.br[1])}},Ja.prototype.updatePaintArray=function(t,e,r,n,a){var i=this.zoomInPaintVertexArray,o=this.zoomOutPaintVertexArray,s=this.layerId;if(a&&r.patterns&&r.patterns[s]){var l=r.patterns[s],c=l.min,u=l.mid,h=l.max,f=a[c],p=a[u],d=a[h];if(!f||!p||!d)return;for(var g=t;g<e;g++)i.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],f.tl[0],f.tl[1],f.br[0],f.br[1]),o.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],d.tl[0],d.tl[1],d.br[0],d.br[1])}},Ja.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Ja.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()},Ja.prototype.setUniforms=function(t,e){e.set(0)},Ja.prototype.getBinding=function(t,e){return new Ba(t,e)};var Ka=function(){this.binders={},this.cacheKey="",this._buffers=[],this._featureMap=new Ia,this._bufferOffset=0};Ka.createDynamic=function(t,e,r){var n=new Ka,a=[];for(var i in t.paint._values)if(r(i)){var o=t.paint.get(i);if(o instanceof Bn&&ur(o.property.specification)){var s=$a(i,t.type),l=o.property.specification.type,c=o.property.useIntegerZoom;if("cross-faded"===o.property.specification["property-type"]||"cross-faded-data-driven"===o.property.specification["property-type"])if("constant"===o.value.kind)n.binders[i]=new Wa(o.value.value,s,l),a.push("/u_"+i);else{var u=ti(i,l,"source");n.binders[i]=new Ja(o.value,s,l,c,e,u,t.id),a.push("/a_"+i)}else if("constant"===o.value.kind)n.binders[i]=new Ya(o.value.value,s,l),a.push("/u_"+i);else if("source"===o.value.kind){var h=ti(i,l,"source");n.binders[i]=new Xa(o.value,s,l,h),a.push("/a_"+i)}else{var f=ti(i,l,"composite");n.binders[i]=new Za(o.value,s,l,c,e,f),a.push("/z_"+i)}}}return n.cacheKey=a.sort().join(""),n},Ka.prototype.populatePaintArrays=function(t,e,r,n,a){for(var i in this.binders)this.binders[i].populatePaintArray(t,e,n,a);void 0!==e.id&&this._featureMap.add(+e.id,r,this._bufferOffset,t),this._bufferOffset=t},Ka.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders)this.binders[r].setConstantPatternPositions(t,e)},Ka.prototype.updatePaintArrays=function(t,e,r,n){var a=!1;for(var i in t)for(var o=0,s=this._featureMap.getPositions(+i);o<s.length;o+=1){var l=s[o],c=e.feature(l.index);for(var u in this.binders){var h=this.binders[u];if(!(h instanceof Ya||h instanceof Wa)&&!0===h.expression.isStateDependent){var f=r.paint.get(u);h.expression=f.value,h.updatePaintArray(l.start,l.end,c,t[i],n),a=!0}}}return a},Ka.prototype.defines=function(){var t=[];for(var e in this.binders)t.push.apply(t,this.binders[e].defines());return t},Ka.prototype.getPaintVertexBuffers=function(){return this._buffers},Ka.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders)for(var a=this.binders[n],i=0,o=a.uniformNames;i<o.length;i+=1){var s=o[i];if(e[s]){var l=a.getBinding(t,e[s]);r.push({name:s,property:n,binding:l})}}return r},Ka.prototype.setUniforms=function(t,e,r,n){for(var a=0,i=e;a<i.length;a+=1){var o=i[a],s=o.name,l=o.property,c=o.binding;this.binders[l].setUniforms(t,c,n,r.get(l),s)}},Ka.prototype.updatePatternPaintBuffers=function(t){var e=[];for(var r in this.binders){var n=this.binders[r];if(n instanceof Ja){var a=2===t.fromScale?n.zoomInPaintVertexBuffer:n.zoomOutPaintVertexBuffer;a&&e.push(a)}else(n instanceof Xa||n instanceof Za)&&n.paintVertexBuffer&&e.push(n.paintVertexBuffer)}this._buffers=e},Ka.prototype.upload=function(t){for(var e in this.binders)this.binders[e].upload(t);var r=[];for(var n in this.binders){var a=this.binders[n];(a instanceof Xa||a instanceof Za)&&a.paintVertexBuffer&&r.push(a.paintVertexBuffer)}this._buffers=r},Ka.prototype.destroy=function(){for(var t in this.binders)this.binders[t].destroy()};var Qa=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var a=0,i=e;a<i.length;a+=1){var o=i[a];this.programConfigurations[o.id]=Ka.createDynamic(o,r,n),this.programConfigurations[o.id].layoutAttributes=t}this.needsUpload=!1};function $a(t,e){return{"text-opacity":["opacity"],"icon-opacity":["opacity"],"text-color":["fill_color"],"icon-color":["fill_color"],"text-halo-color":["halo_color"],"icon-halo-color":["halo_color"],"text-halo-blur":["halo_blur"],"icon-halo-blur":["halo_blur"],"text-halo-width":["halo_width"],"icon-halo-width":["halo_width"],"line-gap-width":["gapwidth"],"line-pattern":["pattern_to","pattern_from"],"fill-pattern":["pattern_to","pattern_from"],"fill-extrusion-pattern":["pattern_to","pattern_from"]}[t]||[t.replace(e+"-","").replace(/-/g,"_")]}function ti(t,e,r){var n={color:{source:ma,composite:ya},number:{source:ha,composite:ma}},a=function(t){return{"line-pattern":{source:ra,composite:ra},"fill-pattern":{source:ra,composite:ra},"fill-extrusion-pattern":{source:ra,composite:ra}}[t]}(t);return a&&a[r]||n[e][r]}Qa.prototype.populatePaintArrays=function(t,e,r,n,a){for(var i in this.programConfigurations)this.programConfigurations[i].populatePaintArrays(t,e,r,n,a);this.needsUpload=!0},Qa.prototype.updatePaintArrays=function(t,e,r,n){for(var a=0,i=r;a<i.length;a+=1){var o=i[a];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,e,o,n)||this.needsUpload}},Qa.prototype.get=function(t){return this.programConfigurations[t]},Qa.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},Qa.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},dn("ConstantBinder",Ya),dn("CrossFadedConstantBinder",Wa),dn("SourceExpressionBinder",Xa),dn("CrossFadedCompositeBinder",Ja),dn("CompositeExpressionBinder",Za),dn("ProgramConfiguration",Ka,{omit:["_buffers"]}),dn("ProgramConfigurationSet",Qa);var ei=8192,ri=(15,{min:-1*Math.pow(2,14),max:Math.pow(2,14)-1});function ni(t){for(var e=ei/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var a=r[n],i=0;i<a.length;i++){var o=a[i];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<ri.min||o.x>ri.max||o.y<ri.min||o.y>ri.max)&&(w("Geometry exceeds allowed extent, reduce your vector tile buffer size"),o.x=c(o.x,ri.min,ri.max),o.y=c(o.y,ri.min,ri.max))}return r}function ai(t,e,r,n,a){t.emplaceBack(2*e+(n+1)/2,2*r+(a+1)/2)}var ii=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new Qn,this.indexArray=new da,this.segments=new Oa,this.programConfigurations=new Qa(Pa,t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function oi(t,e){for(var r=0;r<t.length;r++)if(gi(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(gi(t,e[n]))return!0;return!!ui(t,e)}function si(t,e,r){return!!gi(t,e)||!!fi(e,t,r)}function li(t,e){if(1===t.length)return di(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],a=0;a<n.length;a++)if(gi(t,n[a]))return!0;for(var i=0;i<t.length;i++)if(di(e,t[i]))return!0;for(var o=0;o<e.length;o++)if(ui(t,e[o]))return!0;return!1}function ci(t,e,r){if(t.length>1){if(ui(t,e))return!0;for(var n=0;n<e.length;n++)if(fi(e[n],t,r))return!0}for(var a=0;a<t.length;a++)if(fi(t[a],e,r))return!0;return!1}function ui(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],a=t[r+1],i=0;i<e.length-1;i++)if(hi(n,a,e[i],e[i+1]))return!0;return!1}function hi(t,e,r,n){return k(t,r,n)!==k(e,r,n)&&k(t,e,r)!==k(t,e,n)}function fi(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var a=1;a<e.length;a++)if(pi(t,e[a-1],e[a])<n)return!0;return!1}function pi(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var a=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return a<0?t.distSqr(e):a>1?t.distSqr(r):t.distSqr(r.sub(e)._mult(a)._add(e))}function di(t,e){for(var r,n,a,i=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)n=r[s],a=r[l],n.y>e.y!=a.y>e.y&&e.x<(a.x-n.x)*(e.y-n.y)/(a.y-n.y)+n.x&&(i=!i);return i}function gi(t,e){for(var r=!1,n=0,a=t.length-1;n<t.length;a=n++){var i=t[n],o=t[a];i.y>e.y!=o.y>e.y&&e.x<(o.x-i.x)*(e.y-i.y)/(o.y-i.y)+i.x&&(r=!r)}return r}function vi(t,e,r){var n=r[0],a=r[2];if(t.x<n.x&&e.x<n.x||t.x>a.x&&e.x>a.x||t.y<n.y&&e.y<n.y||t.y>a.y&&e.y>a.y)return!1;var i=k(t,e,r[0]);return i!==k(t,e,r[1])||i!==k(t,e,r[2])||i!==k(t,e,r[3])}function mi(t,e,r){var n=e.paint.get(t).value;return"constant"===n.kind?n.value:r.programConfigurations.get(e.id).binders[t].maxValue}function yi(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function xi(t,e,r,n,i){if(!e[0]&&!e[1])return t;var o=a.convert(e)._mult(i);"viewport"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++){var c=t[l];s.push(c.sub(o))}return s}ii.prototype.populate=function(t,e){var r=this.layers[0],n=[],a=null;"circle"===r.type&&(a=r.layout.get("circle-sort-key"));for(var i=0,o=t;i<o.length;i+=1){var s=o[i],l=s.feature,c=s.index,u=s.sourceLayerIndex;if(this.layers[0]._featureFilter(new Pn(this.zoom),l)){var h=ni(l),f=a?a.evaluate(l,{}):void 0,p={id:l.id,properties:l.properties,type:l.type,sourceLayerIndex:u,index:c,geometry:h,patterns:{},sortKey:f};n.push(p)}}a&&n.sort(function(t,e){return t.sortKey-e.sortKey});for(var d=0,g=n;d<g.length;d+=1){var v=g[d],m=v,y=m.geometry,x=m.index,b=m.sourceLayerIndex,_=t[x].feature;this.addFeature(v,y,x),e.featureIndex.insert(_,y,x,b,this.index)}},ii.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},ii.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},ii.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},ii.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Pa),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},ii.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},ii.prototype.addFeature=function(t,e,r){for(var n=0,a=e;n<a.length;n+=1)for(var i=0,o=a[n];i<o.length;i+=1){var s=o[i],l=s.x,c=s.y;if(!(l<0||l>=ei||c<0||c>=ei)){var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray,t.sortKey),h=u.vertexLength;ai(this.layoutVertexArray,l,c,-1,-1),ai(this.layoutVertexArray,l,c,1,-1),ai(this.layoutVertexArray,l,c,1,1),ai(this.layoutVertexArray,l,c,-1,1),this.indexArray.emplaceBack(h,h+1,h+2),this.indexArray.emplaceBack(h,h+3,h+2),u.vertexLength+=4,u.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{})},dn("CircleBucket",ii,{omit:["layers"]});var bi,_i=new Gn({"circle-sort-key":new Vn(Tt.layout_circle["circle-sort-key"])}),wi={paint:new Gn({"circle-radius":new Vn(Tt.paint_circle["circle-radius"]),"circle-color":new Vn(Tt.paint_circle["circle-color"]),"circle-blur":new Vn(Tt.paint_circle["circle-blur"]),"circle-opacity":new Vn(Tt.paint_circle["circle-opacity"]),"circle-translate":new jn(Tt.paint_circle["circle-translate"]),"circle-translate-anchor":new jn(Tt.paint_circle["circle-translate-anchor"]),"circle-pitch-scale":new jn(Tt.paint_circle["circle-pitch-scale"]),"circle-pitch-alignment":new jn(Tt.paint_circle["circle-pitch-alignment"]),"circle-stroke-width":new Vn(Tt.paint_circle["circle-stroke-width"]),"circle-stroke-color":new Vn(Tt.paint_circle["circle-stroke-color"]),"circle-stroke-opacity":new Vn(Tt.paint_circle["circle-stroke-opacity"])}),layout:_i},ki="undefined"!=typeof Float32Array?Float32Array:Array;function Ti(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3];return t[0]=r[0]*n+r[4]*a+r[8]*i+r[12]*o,t[1]=r[1]*n+r[5]*a+r[9]*i+r[13]*o,t[2]=r[2]*n+r[6]*a+r[10]*i+r[14]*o,t[3]=r[3]*n+r[7]*a+r[11]*i+r[15]*o,t}Math.hypot||(Math.hypot=function(){for(var t=arguments,e=0,r=arguments.length;r--;)e+=t[r]*t[r];return Math.sqrt(e)}),bi=new ki(3),ki!=Float32Array&&(bi[0]=0,bi[1]=0,bi[2]=0),function(){var t=new ki(4);ki!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0)}();var Mi=function(t){function e(e){t.call(this,e,wi)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new ii(t)},e.prototype.queryRadius=function(t){var e=t;return mi("circle-radius",this,e)+mi("circle-stroke-width",this,e)+yi(this.paint.get("circle-translate"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,i,o,s){for(var l=xi(t,this.paint.get("circle-translate"),this.paint.get("circle-translate-anchor"),i.angle,o),c=this.paint.get("circle-radius").evaluate(e,r)+this.paint.get("circle-stroke-width").evaluate(e,r),u="map"===this.paint.get("circle-pitch-alignment"),h=u?l:function(t,e){return l.map(function(t){return Ai(t,e)})}(0,s),f=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var g=0,v=d[p];g<v.length;g+=1){var m=v[g],y=u?m:Ai(m,s),x=f,b=Ti([],[m.x,m.y,0,1],s);if("viewport"===this.paint.get("circle-pitch-scale")&&"map"===this.paint.get("circle-pitch-alignment")?x*=b[3]/i.cameraToCenterDistance:"map"===this.paint.get("circle-pitch-scale")&&"viewport"===this.paint.get("circle-pitch-alignment")&&(x*=i.cameraToCenterDistance/b[3]),si(h,y,x))return!0}return!1},e}(Yn);function Ai(t,e){var r=Ti([],[t.x,t.y,0,1],e);return new a(r[0]/r[3],r[1]/r[3])}var Si=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ii);function Ei(t,e,r,n){var a=e.width,i=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==a*i*r)throw new RangeError("mismatched image size")}else n=new Uint8Array(a*i*r);return t.width=a,t.height=i,t.data=n,t}function Li(t,e,r){var n=e.width,a=e.height;if(n!==t.width||a!==t.height){var i=Ei({},{width:n,height:a},r);Ci(t,i,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,a)},r),t.width=n,t.height=a,t.data=i.data}}function Ci(t,e,r,n,a,i){if(0===a.width||0===a.height)return e;if(a.width>t.width||a.height>t.height||r.x>t.width-a.width||r.y>t.height-a.height)throw new RangeError("out of range source coordinates for image copy");if(a.width>e.width||a.height>e.height||n.x>e.width-a.width||n.y>e.height-a.height)throw new RangeError("out of range destination coordinates for image copy");for(var o=t.data,s=e.data,l=0;l<a.height;l++)for(var c=((r.y+l)*t.width+r.x)*i,u=((n.y+l)*e.width+n.x)*i,h=0;h<a.width*i;h++)s[u+h]=o[c+h];return e}dn("HeatmapBucket",Si,{omit:["layers"]});var Pi=function(t,e){Ei(this,t,1,e)};Pi.prototype.resize=function(t){Li(this,t,1)},Pi.prototype.clone=function(){return new Pi({width:this.width,height:this.height},new Uint8Array(this.data))},Pi.copy=function(t,e,r,n,a){Ci(t,e,r,n,a,1)};var Oi=function(t,e){Ei(this,t,4,e)};Oi.prototype.resize=function(t){Li(this,t,4)},Oi.prototype.replace=function(t,e){e?this.data.set(t):t instanceof Uint8ClampedArray?this.data=new Uint8Array(t.buffer):this.data=t},Oi.prototype.clone=function(){return new Oi({width:this.width,height:this.height},new Uint8Array(this.data))},Oi.copy=function(t,e,r,n,a){Ci(t,e,r,n,a,4)},dn("AlphaImage",Pi),dn("RGBAImage",Oi);var zi={paint:new Gn({"heatmap-radius":new Vn(Tt.paint_heatmap["heatmap-radius"]),"heatmap-weight":new Vn(Tt.paint_heatmap["heatmap-weight"]),"heatmap-intensity":new jn(Tt.paint_heatmap["heatmap-intensity"]),"heatmap-color":new Hn(Tt.paint_heatmap["heatmap-color"]),"heatmap-opacity":new jn(Tt.paint_heatmap["heatmap-opacity"])})};function Ii(t,e){for(var r=new Uint8Array(1024),n={},a=0,i=0;a<256;a++,i+=4){n[e]=a/255;var o=t.evaluate(n);r[i+0]=Math.floor(255*o.r/o.a),r[i+1]=Math.floor(255*o.g/o.a),r[i+2]=Math.floor(255*o.b/o.a),r[i+3]=Math.floor(255*o.a)}return new Oi({width:256,height:1},r)}var Di=function(t){function e(e){t.call(this,e,zi),this._updateColorRamp()}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Si(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){"heatmap-color"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){var t=this._transitionablePaint._values["heatmap-color"].value.expression;this.colorRamp=Ii(t,"heatmapDensity"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get("heatmap-opacity")&&"none"!==this.visibility},e}(Yn),Ri={paint:new Gn({"hillshade-illumination-direction":new jn(Tt.paint_hillshade["hillshade-illumination-direction"]),"hillshade-illumination-anchor":new jn(Tt.paint_hillshade["hillshade-illumination-anchor"]),"hillshade-exaggeration":new jn(Tt.paint_hillshade["hillshade-exaggeration"]),"hillshade-shadow-color":new jn(Tt.paint_hillshade["hillshade-shadow-color"]),"hillshade-highlight-color":new jn(Tt.paint_hillshade["hillshade-highlight-color"]),"hillshade-accent-color":new jn(Tt.paint_hillshade["hillshade-accent-color"])})},Fi=function(t){function e(e){t.call(this,e,Ri)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get("hillshade-exaggeration")&&"none"!==this.visibility},e}(Yn),Bi=Jn([{name:"a_pos",components:2,type:"Int16"}],4).members,Ni=Vi,ji=Vi;function Vi(t,e,r){r=r||2;var n,a,i,o,s,l,c,u=e&&e.length,h=u?e[0]*r:t.length,f=Ui(t,0,h,r,!0),p=[];if(!f||f.next===f.prev)return p;if(u&&(f=function(t,e,r,n){var a,i,o,s=[];for(a=0,i=e.length;a<i;a++)(o=Ui(t,e[a]*n,a<i-1?e[a+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push($i(o));for(s.sort(Zi),a=0;a<s.length;a++)Ji(s[a],r),r=qi(r,r.next);return r}(t,e,f,r)),t.length>80*r){n=i=t[0],a=o=t[1];for(var d=r;d<h;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<a&&(a=l),s>i&&(i=s),l>o&&(o=l);c=0!==(c=Math.max(i-n,o-a))?1/c:0}return Hi(f,p,r,n,a,c),p}function Ui(t,e,r,n,a){var i,o;if(a===fo(t,e,r,n)>0)for(i=e;i<r;i+=n)o=co(i,t[i],t[i+1],o);else for(i=r-n;i>=e;i-=n)o=co(i,t[i],t[i+1],o);return o&&no(o,o.next)&&(uo(o),o=o.next),o}function qi(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!no(n,n.next)&&0!==ro(n.prev,n,n.next))n=n.next;else{if(uo(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function Hi(t,e,r,n,a,i,o){if(t){!o&&i&&function(t,e,r,n){var a=t;do{null===a.z&&(a.z=Qi(a.x,a.y,e,r,n)),a.prevZ=a.prev,a.nextZ=a.next,a=a.next}while(a!==t);a.prevZ.nextZ=null,a.prevZ=null,function(t){var e,r,n,a,i,o,s,l,c=1;do{for(r=t,t=null,i=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(a=r,r=r.nextZ,s--):(a=n,n=n.nextZ,l--),i?i.nextZ=a:t=a,a.prevZ=i,i=a;r=n}i.nextZ=null,c*=2}while(o>1)}(a)}(t,n,a,i);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,i?Yi(t,n,a,i):Gi(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),uo(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?Hi(t=Wi(qi(t),e,r),e,r,n,a,i,2):2===o&&Xi(t,e,r,n,a,i):Hi(qi(t),e,r,n,a,i,1);break}}}function Gi(t){var e=t.prev,r=t,n=t.next;if(ro(e,r,n)>=0)return!1;for(var a=t.next.next;a!==t.prev;){if(to(e.x,e.y,r.x,r.y,n.x,n.y,a.x,a.y)&&ro(a.prev,a,a.next)>=0)return!1;a=a.next}return!0}function Yi(t,e,r,n){var a=t.prev,i=t,o=t.next;if(ro(a,i,o)>=0)return!1;for(var s=a.x<i.x?a.x<o.x?a.x:o.x:i.x<o.x?i.x:o.x,l=a.y<i.y?a.y<o.y?a.y:o.y:i.y<o.y?i.y:o.y,c=a.x>i.x?a.x>o.x?a.x:o.x:i.x>o.x?i.x:o.x,u=a.y>i.y?a.y>o.y?a.y:o.y:i.y>o.y?i.y:o.y,h=Qi(s,l,e,r,n),f=Qi(c,u,e,r,n),p=t.prevZ,d=t.nextZ;p&&p.z>=h&&d&&d.z<=f;){if(p!==t.prev&&p!==t.next&&to(a.x,a.y,i.x,i.y,o.x,o.y,p.x,p.y)&&ro(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,d!==t.prev&&d!==t.next&&to(a.x,a.y,i.x,i.y,o.x,o.y,d.x,d.y)&&ro(d.prev,d,d.next)>=0)return!1;d=d.nextZ}for(;p&&p.z>=h;){if(p!==t.prev&&p!==t.next&&to(a.x,a.y,i.x,i.y,o.x,o.y,p.x,p.y)&&ro(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;d&&d.z<=f;){if(d!==t.prev&&d!==t.next&&to(a.x,a.y,i.x,i.y,o.x,o.y,d.x,d.y)&&ro(d.prev,d,d.next)>=0)return!1;d=d.nextZ}return!0}function Wi(t,e,r){var n=t;do{var a=n.prev,i=n.next.next;!no(a,i)&&ao(a,n,n.next,i)&&so(a,i)&&so(i,a)&&(e.push(a.i/r),e.push(n.i/r),e.push(i.i/r),uo(n),uo(n.next),n=t=i),n=n.next}while(n!==t);return qi(n)}function Xi(t,e,r,n,a,i){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&eo(o,s)){var l=lo(o,s);return o=qi(o,o.next),l=qi(l,l.next),Hi(o,e,r,n,a,i),void Hi(l,e,r,n,a,i)}s=s.next}o=o.next}while(o!==t)}function Zi(t,e){return t.x-e.x}function Ji(t,e){if(e=function(t,e){var r,n=e,a=t.x,i=t.y,o=-1/0;do{if(i<=n.y&&i>=n.next.y&&n.next.y!==n.y){var s=n.x+(i-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=a&&s>o){if(o=s,s===a){if(i===n.y)return n;if(i===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(a===o)return r;var l,c=r,u=r.x,h=r.y,f=1/0;n=r;do{a>=n.x&&n.x>=u&&a!==n.x&&to(i<h?a:o,i,u,h,i<h?o:a,i,n.x,n.y)&&(l=Math.abs(i-n.y)/(a-n.x),so(n,t)&&(l<f||l===f&&(n.x>r.x||n.x===r.x&&Ki(r,n)))&&(r=n,f=l)),n=n.next}while(n!==c);return r}(t,e)){var r=lo(e,t);qi(r,r.next)}}function Ki(t,e){return ro(t.prev,t,e.prev)<0&&ro(e.next,t,t.next)<0}function Qi(t,e,r,n,a){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*a)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*a)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function $i(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function to(t,e,r,n,a,i,o,s){return(a-o)*(e-s)-(t-o)*(i-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(i-s)-(a-o)*(n-s)>=0}function eo(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&ao(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(so(t,e)&&so(e,t)&&function(t,e){var r=t,n=!1,a=(t.x+e.x)/2,i=(t.y+e.y)/2;do{r.y>i!=r.next.y>i&&r.next.y!==r.y&&a<(r.next.x-r.x)*(i-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(ro(t.prev,t,e.prev)||ro(t,e.prev,e))||no(t,e)&&ro(t.prev,t,t.next)>0&&ro(e.prev,e,e.next)>0)}function ro(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function no(t,e){return t.x===e.x&&t.y===e.y}function ao(t,e,r,n){var a=oo(ro(t,e,r)),i=oo(ro(t,e,n)),o=oo(ro(r,n,t)),s=oo(ro(r,n,e));return a!==i&&o!==s||!(0!==a||!io(t,r,e))||!(0!==i||!io(t,n,e))||!(0!==o||!io(r,t,n))||!(0!==s||!io(r,e,n))}function io(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function oo(t){return t>0?1:t<0?-1:0}function so(t,e){return ro(t.prev,t,t.next)<0?ro(t,e,t.next)>=0&&ro(t,t.prev,e)>=0:ro(t,e,t.prev)<0||ro(t,t.next,e)<0}function lo(t,e){var r=new ho(t.i,t.x,t.y),n=new ho(e.i,e.x,e.y),a=t.next,i=e.prev;return t.next=e,e.prev=t,r.next=a,a.prev=r,n.next=r,r.prev=n,i.next=n,n.prev=i,n}function co(t,e,r,n){var a=new ho(t,e,r);return n?(a.next=n.next,a.prev=n,n.next.prev=a,n.next=a):(a.prev=a,a.next=a),a}function uo(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function ho(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function fo(t,e,r,n){for(var a=0,i=e,o=r-n;i<r;i+=n)a+=(t[o]-t[i])*(t[i+1]+t[o+1]),o=i;return a}function po(t,e,r,n,a){!function t(e,r,n,a,i){for(;a>n;){if(a-n>600){var o=a-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);t(e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(a,Math.floor(r+(o-s)*c/o+u)),i)}var h=e[r],f=n,p=a;for(go(e,n,r),i(e[a],h)>0&&go(e,n,a);f<p;){for(go(e,f,p),f++,p--;i(e[f],h)<0;)f++;for(;i(e[p],h)>0;)p--}0===i(e[n],h)?go(e,n,p):go(e,++p,a),p<=r&&(n=p+1),r<=p&&(a=p-1)}}(t,e,r||0,n||t.length-1,a||vo)}function go(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function vo(t,e){return t<e?-1:t>e?1:0}function mo(t,e){var r=t.length;if(r<=1)return[t];for(var n,a,i=[],o=0;o<r;o++){var s=T(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===a&&(a=s<0),a===s<0?(n&&i.push(n),n=[t[o]]):n.push(t[o]))}if(n&&i.push(n),e>1)for(var l=0;l<i.length;l++)i[l].length<=e||(po(i[l],e,1,i[l].length-1,yo),i[l]=i[l].slice(0,e));return i}function yo(t,e){return e.area-t.area}function xo(t,e,r){for(var n=r.patternDependencies,a=!1,i=0,o=e;i<o.length;i+=1){var s=o[i].paint.get(t+"-pattern");s.isConstant()||(a=!0);var l=s.constantOr(null);l&&(a=!0,n[l.to]=!0,n[l.from]=!0)}return a}function bo(t,e,r,n,a){for(var i=a.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+"-pattern").value;if("constant"!==c.kind){var u=c.evaluate({zoom:n-1},r,{}),h=c.evaluate({zoom:n},r,{}),f=c.evaluate({zoom:n+1},r,{});i[u]=!0,i[h]=!0,i[f]=!0,r.patterns[l.id]={min:u,mid:h,max:f}}}return r}Vi.deviation=function(t,e,r,n){var a=e&&e.length,i=a?e[0]*r:t.length,o=Math.abs(fo(t,0,i,r));if(a)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(fo(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},Vi.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,a=0;a<t.length;a++){for(var i=0;i<t[a].length;i++)for(var o=0;o<e;o++)r.vertices.push(t[a][i][o]);a>0&&(n+=t[a-1].length,r.holes.push(n))}return r},Ni.default=ji;var _o=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new Qn,this.indexArray=new da,this.indexArray2=new ga,this.programConfigurations=new Qa(Bi,t.layers,t.zoom),this.segments=new Oa,this.segments2=new Oa,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};_o.prototype.populate=function(t,e){this.hasPattern=xo("fill",this.layers,e);for(var r=this.layers[0].layout.get("fill-sort-key"),n=[],a=0,i=t;a<i.length;a+=1){var o=i[a],s=o.feature,l=o.index,c=o.sourceLayerIndex;if(this.layers[0]._featureFilter(new Pn(this.zoom),s)){var u=ni(s),h=r?r.evaluate(s,{}):void 0,f={id:s.id,properties:s.properties,type:s.type,sourceLayerIndex:c,index:l,geometry:u,patterns:{},sortKey:h};n.push(f)}}r&&n.sort(function(t,e){return t.sortKey-e.sortKey});for(var p=0,d=n;p<d.length;p+=1){var g=d[p],v=g,m=v.geometry,y=v.index,x=v.sourceLayerIndex;if(this.hasPattern){var b=bo("fill",this.layers,g,this.zoom,e);this.patternFeatures.push(b)}else this.addFeature(g,m,y,{});var _=t[y].feature;e.featureIndex.insert(_,m,y,x,this.index)}},_o.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},_o.prototype.addFeatures=function(t,e){for(var r=0,n=this.patternFeatures;r<n.length;r+=1){var a=n[r];this.addFeature(a,a.geometry,a.index,e)}},_o.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},_o.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},_o.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Bi),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},_o.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},_o.prototype.addFeature=function(t,e,r,n){for(var a=0,i=mo(e,500);a<i.length;a+=1){for(var o=i[a],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray),h=u.vertexLength,f=[],p=[],d=0,g=o;d<g.length;d+=1){var v=g[d];if(0!==v.length){v!==o[0]&&p.push(f.length/2);var m=this.segments2.prepareSegment(v.length,this.layoutVertexArray,this.indexArray2),y=m.vertexLength;this.layoutVertexArray.emplaceBack(v[0].x,v[0].y),this.indexArray2.emplaceBack(y+v.length-1,y),f.push(v[0].x),f.push(v[0].y);for(var x=1;x<v.length;x++)this.layoutVertexArray.emplaceBack(v[x].x,v[x].y),this.indexArray2.emplaceBack(y+x-1,y+x),f.push(v[x].x),f.push(v[x].y);m.vertexLength+=v.length,m.primitiveLength+=v.length}}for(var b=Ni(f,p),_=0;_<b.length;_+=3)this.indexArray.emplaceBack(h+b[_],h+b[_+1],h+b[_+2]);u.vertexLength+=s,u.primitiveLength+=b.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},dn("FillBucket",_o,{omit:["layers","patternFeatures"]});var wo=new Gn({"fill-sort-key":new Vn(Tt.layout_fill["fill-sort-key"])}),ko={paint:new Gn({"fill-antialias":new jn(Tt.paint_fill["fill-antialias"]),"fill-opacity":new Vn(Tt.paint_fill["fill-opacity"]),"fill-color":new Vn(Tt.paint_fill["fill-color"]),"fill-outline-color":new Vn(Tt.paint_fill["fill-outline-color"]),"fill-translate":new jn(Tt.paint_fill["fill-translate"]),"fill-translate-anchor":new jn(Tt.paint_fill["fill-translate-anchor"]),"fill-pattern":new Un(Tt.paint_fill["fill-pattern"])}),layout:wo},To=function(t){function e(e){t.call(this,e,ko)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e);var r=this.paint._values["fill-outline-color"];"constant"===r.value.kind&&void 0===r.value.value&&(this.paint._values["fill-outline-color"]=this.paint._values["fill-color"])},e.prototype.createBucket=function(t){return new _o(t)},e.prototype.queryRadius=function(){return yi(this.paint.get("fill-translate"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,i,o){return li(xi(t,this.paint.get("fill-translate"),this.paint.get("fill-translate-anchor"),i.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}(Yn),Mo=Jn([{name:"a_pos",components:2,type:"Int16"},{name:"a_normal_ed",components:4,type:"Int16"}],4).members,Ao=So;function So(t,e,r,n,a){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=a,t.readFields(Eo,this,e)}function Eo(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],a=e._values[t.readVarint()];e.properties[n]=a}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function Lo(t){for(var e,r,n=0,a=0,i=t.length,o=i-1;a<i;o=a++)e=t[a],n+=((r=t[o]).x-e.x)*(e.y+r.y);return n}So.types=["Unknown","Point","LineString","Polygon"],So.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,i=0,o=0,s=0,l=[];t.pos<r;){if(i<=0){var c=t.readVarint();n=7&c,i=c>>3}if(i--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new a(o,s));else{if(7!==n)throw new Error("unknown command "+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},So.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,a=0,i=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(a+=t.readSVarint())<o&&(o=a),a>s&&(s=a),(i+=t.readSVarint())<l&&(l=i),i>c&&(c=i);else if(7!==r)throw new Error("unknown command "+r)}return[o,l,s,c]},So.prototype.toGeoJSON=function(t,e,r){var n,a,i=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=So.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e],n=180-360*(r.y+s)/i;t[e]=[360*(r.x+o)/i-180,360/Math.PI*Math.atan(Math.exp(n*Math.PI/180))-90]}}switch(this.type){case 1:var h=[];for(n=0;n<l.length;n++)h[n]=l[n][0];u(l=h);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,a=[],i=0;i<e;i++){var o=Lo(t[i]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&a.push(r),r=[t[i]]):r.push(t[i]))}return r&&a.push(r),a}(l),n=0;n<l.length;n++)for(a=0;a<l[n].length;a++)u(l[n][a])}1===l.length?l=l[0]:c="Multi"+c;var f={type:"Feature",geometry:{type:c,coordinates:l},properties:this.properties};return"id"in this&&(f.id=this.id),f};var Co=Po;function Po(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(Oo,this,e),this.length=this._features.length}function Oo(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function zo(t,e,r){if(3===t){var n=new Co(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}Po.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error("feature index out of bounds");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new Ao(this._pbf,e,this.extent,this._keys,this._values)};var Io={VectorTile:function(t,e){this.layers=t.readFields(zo,{},e)},VectorTileFeature:Ao,VectorTileLayer:Co},Do=Io.VectorTileFeature.types,Ro=Math.pow(2,13);function Fo(t,e,r,n,a,i,o,s){t.emplaceBack(e,r,2*Math.floor(n*Ro)+o,a*Ro*2,i*Ro*2,Math.round(s))}var Bo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new ta,this.indexArray=new da,this.programConfigurations=new Qa(Mo,t.layers,t.zoom),this.segments=new Oa,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function No(t,e){return t.x===e.x&&(t.x<0||t.x>ei)||t.y===e.y&&(t.y<0||t.y>ei)}function jo(t){return t.every(function(t){return t.x<0})||t.every(function(t){return t.x>ei})||t.every(function(t){return t.y<0})||t.every(function(t){return t.y>ei})}Bo.prototype.populate=function(t,e){this.features=[],this.hasPattern=xo("fill-extrusion",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var a=n[r],i=a.feature,o=a.index,s=a.sourceLayerIndex;if(this.layers[0]._featureFilter(new Pn(this.zoom),i)){var l=ni(i),c={sourceLayerIndex:s,index:o,geometry:l,properties:i.properties,type:i.type,patterns:{}};void 0!==i.id&&(c.id=i.id),this.hasPattern?this.features.push(bo("fill-extrusion",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(i,l,o,s,this.index,!0)}}},Bo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var a=n[r],i=a.geometry;this.addFeature(a,i,a.index,e)}},Bo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Bo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Bo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Bo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Mo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Bo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Bo.prototype.addFeature=function(t,e,r,n){for(var a=0,i=mo(e,500);a<i.length;a+=1){for(var o=i[a],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=0,f=o;h<f.length;h+=1){var p=f[h];if(0!==p.length&&!jo(p))for(var d=0,g=0;g<p.length;g++){var v=p[g];if(g>=1){var m=p[g-1];if(!No(v,m)){u.vertexLength+4>Oa.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var y=v.sub(m)._perp()._unit(),x=m.dist(v);d+x>32768&&(d=0),Fo(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,0,d),Fo(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,1,d),d+=x,Fo(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,0,d),Fo(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,1,d);var b=u.vertexLength;this.indexArray.emplaceBack(b,b+2,b+1),this.indexArray.emplaceBack(b+1,b+2,b+3),u.vertexLength+=4,u.primitiveLength+=2}}}}if(u.vertexLength+s>Oa.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray)),"Polygon"===Do[t.type]){for(var _=[],w=[],k=u.vertexLength,T=0,M=o;T<M.length;T+=1){var A=M[T];if(0!==A.length){A!==o[0]&&w.push(_.length/2);for(var S=0;S<A.length;S++){var E=A[S];Fo(this.layoutVertexArray,E.x,E.y,0,0,1,1,0),_.push(E.x),_.push(E.y)}}}for(var L=Ni(_,w),C=0;C<L.length;C+=3)this.indexArray.emplaceBack(k+L[C],k+L[C+2],k+L[C+1]);u.primitiveLength+=L.length/3,u.vertexLength+=s}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},dn("FillExtrusionBucket",Bo,{omit:["layers","features"]});var Vo={paint:new Gn({"fill-extrusion-opacity":new jn(Tt["paint_fill-extrusion"]["fill-extrusion-opacity"]),"fill-extrusion-color":new Vn(Tt["paint_fill-extrusion"]["fill-extrusion-color"]),"fill-extrusion-translate":new jn(Tt["paint_fill-extrusion"]["fill-extrusion-translate"]),"fill-extrusion-translate-anchor":new jn(Tt["paint_fill-extrusion"]["fill-extrusion-translate-anchor"]),"fill-extrusion-pattern":new Un(Tt["paint_fill-extrusion"]["fill-extrusion-pattern"]),"fill-extrusion-height":new Vn(Tt["paint_fill-extrusion"]["fill-extrusion-height"]),"fill-extrusion-base":new Vn(Tt["paint_fill-extrusion"]["fill-extrusion-base"]),"fill-extrusion-vertical-gradient":new jn(Tt["paint_fill-extrusion"]["fill-extrusion-vertical-gradient"])})},Uo=function(t){function e(e){t.call(this,e,Vo)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Bo(t)},e.prototype.queryRadius=function(){return yi(this.paint.get("fill-extrusion-translate"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,o,s,l){var c=xi(t,this.paint.get("fill-extrusion-translate"),this.paint.get("fill-extrusion-translate-anchor"),o.angle,s),u=this.paint.get("fill-extrusion-height").evaluate(e,r),h=this.paint.get("fill-extrusion-base").evaluate(e,r),f=function(t,e,r,n){for(var i=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,0,1];Ti(c,c,e),i.push(new a(c[0]/c[3],c[1]/c[3]))}return i}(c,l),p=function(t,e,r,n){for(var i=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,h=n[8]*r,f=n[9]*r,p=n[10]*r,d=n[11]*r,g=0,v=t;g<v.length;g+=1){for(var m=[],y=[],x=0,b=v[g];x<b.length;x+=1){var _=b[x],w=_.x,k=_.y,T=n[0]*w+n[4]*k+n[12],M=n[1]*w+n[5]*k+n[13],A=n[2]*w+n[6]*k+n[14],S=n[3]*w+n[7]*k+n[15],E=A+c,L=S+u,C=T+h,P=M+f,O=A+p,z=S+d,I=new a((T+s)/L,(M+l)/L);I.z=E/L,m.push(I);var D=new a(C/z,P/z);D.z=O/z,y.push(D)}i.push(m),o.push(y)}return[i,o]}(n,h,u,l);return function(t,e,r){var n=1/0;li(r,e)&&(n=Ho(r,e[0]));for(var a=0;a<e.length;a++)for(var i=e[a],o=t[a],s=0;s<i.length-1;s++){var l=i[s],c=i[s+1],u=o[s],h=[l,c,o[s+1],u,l];oi(r,h)&&(n=Math.min(n,Ho(r,h)))}return n!==1/0&&n}(p[0],p[1],f)},e}(Yn);function qo(t,e){return t.x*e.x+t.y*e.y}function Ho(t,e){if(1===t.length){var r=e[0],n=e[1],a=e[3],i=t[0],o=n.sub(r),s=a.sub(r),l=i.sub(r),c=qo(o,o),u=qo(o,s),h=qo(s,s),f=qo(l,o),p=qo(l,s),d=c*h-u*u,g=(h*f-u*p)/d,v=(c*p-u*f)/d,m=1-g-v;return r.z*m+n.z*g+a.z*v}for(var y=1/0,x=0,b=e;x<b.length;x+=1){var _=b[x];y=Math.min(y,_.z)}return y}var Go=Jn([{name:"a_pos_normal",components:2,type:"Int16"},{name:"a_data",components:4,type:"Uint8"}],4).members,Yo=Io.VectorTileFeature.types,Wo=Math.cos(Math.PI/180*37.5),Xo=Math.pow(2,14)/.5,Zo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new ea,this.indexArray=new da,this.programConfigurations=new Qa(Go,t.layers,t.zoom),this.segments=new Oa,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};Zo.prototype.populate=function(t,e){this.hasPattern=xo("line",this.layers,e);for(var r=this.layers[0].layout.get("line-sort-key"),n=[],a=0,i=t;a<i.length;a+=1){var o=i[a],s=o.feature,l=o.index,c=o.sourceLayerIndex;if(this.layers[0]._featureFilter(new Pn(this.zoom),s)){var u=ni(s),h=r?r.evaluate(s,{}):void 0,f={id:s.id,properties:s.properties,type:s.type,sourceLayerIndex:c,index:l,geometry:u,patterns:{},sortKey:h};n.push(f)}}r&&n.sort(function(t,e){return t.sortKey-e.sortKey});for(var p=0,d=n;p<d.length;p+=1){var g=d[p],v=g,m=v.geometry,y=v.index,x=v.sourceLayerIndex;if(this.hasPattern){var b=bo("line",this.layers,g,this.zoom,e);this.patternFeatures.push(b)}else this.addFeature(g,m,y,{});var _=t[y].feature;e.featureIndex.insert(_,m,y,x,this.index)}},Zo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Zo.prototype.addFeatures=function(t,e){for(var r=0,n=this.patternFeatures;r<n.length;r+=1){var a=n[r];this.addFeature(a,a.geometry,a.index,e)}},Zo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Zo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Zo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Go),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Zo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Zo.prototype.addFeature=function(t,e,r,n){for(var a=this.layers[0].layout,i=a.get("line-join").evaluate(t,{}),o=a.get("line-cap"),s=a.get("line-miter-limit"),l=a.get("line-round-limit"),c=0,u=e;c<u.length;c+=1){var h=u[c];this.addLine(h,t,i,o,s,l,r,n)}},Zo.prototype.addLine=function(t,e,r,n,a,i,o,s){if(this.distance=0,this.scaledDistance=0,this.totalDistance=0,e.properties&&e.properties.hasOwnProperty("mapbox_clip_start")&&e.properties.hasOwnProperty("mapbox_clip_end")){this.clipStart=+e.properties.mapbox_clip_start,this.clipEnd=+e.properties.mapbox_clip_end;for(var l=0;l<t.length-1;l++)this.totalDistance+=t[l].dist(t[l+1])}for(var c="Polygon"===Yo[e.type],u=t.length;u>=2&&t[u-1].equals(t[u-2]);)u--;for(var h=0;h<u-1&&t[h].equals(t[h+1]);)h++;if(!(u<(c?3:2))){"bevel"===r&&(a=1.05);var f,p=ei/(512*this.overscaling)*15,d=this.segments.prepareSegment(10*u,this.layoutVertexArray,this.indexArray),g=void 0,v=void 0,m=void 0,y=void 0;this.e1=this.e2=-1,c&&(f=t[u-2],y=t[h].sub(f)._unit()._perp());for(var x=h;x<u;x++)if(!(v=c&&x===u-1?t[h+1]:t[x+1])||!t[x].equals(v)){y&&(m=y),f&&(g=f),f=t[x],y=v?v.sub(f)._unit()._perp():m;var b=(m=m||y).add(y);0===b.x&&0===b.y||b._unit();var _=m.x*y.x+m.y*y.y,w=b.x*y.x+b.y*y.y,k=0!==w?1/w:1/0,T=2*Math.sqrt(2-2*w),M=w<Wo&&g&&v,A=m.x*y.y-m.y*y.x>0;if(M&&x>h){var S=f.dist(g);if(S>2*p){var E=f.sub(f.sub(g)._mult(p/S)._round());this.updateDistance(g,E),this.addCurrentVertex(E,m,0,0,d),g=E}}var L=g&&v,C=L?r:c?"butt":n;if(L&&"round"===C&&(k<i?C="miter":k<=2&&(C="fakeround")),"miter"===C&&k>a&&(C="bevel"),"bevel"===C&&(k>2&&(C="flipbevel"),k<a&&(C="miter")),g&&this.updateDistance(g,f),"miter"===C)b._mult(k),this.addCurrentVertex(f,b,0,0,d);else if("flipbevel"===C){if(k>100)b=y.mult(-1);else{var P=k*m.add(y).mag()/m.sub(y).mag();b._perp()._mult(P*(A?-1:1))}this.addCurrentVertex(f,b,0,0,d),this.addCurrentVertex(f,b.mult(-1),0,0,d)}else if("bevel"===C||"fakeround"===C){var O=-Math.sqrt(k*k-1),z=A?O:0,I=A?0:O;if(g&&this.addCurrentVertex(f,m,z,I,d),"fakeround"===C)for(var D=Math.round(180*T/Math.PI/20),R=1;R<D;R++){var F=R/D;if(.5!==F){var B=F-.5;F+=F*B*(F-1)*((1.0904+_*(_*(3.55645-1.43519*_)-3.2452))*B*B+(.848013+_*(.215638*_-1.06021)))}var N=y.sub(m)._mult(F)._add(m)._unit()._mult(A?-1:1);this.addHalfVertex(f,N.x,N.y,!1,A,0,d)}v&&this.addCurrentVertex(f,y,-z,-I,d)}else if("butt"===C)this.addCurrentVertex(f,b,0,0,d);else if("square"===C){var j=g?1:-1;this.addCurrentVertex(f,b,j,j,d)}else"round"===C&&(g&&(this.addCurrentVertex(f,m,0,0,d),this.addCurrentVertex(f,m,1,1,d,!0)),v&&(this.addCurrentVertex(f,y,-1,-1,d,!0),this.addCurrentVertex(f,y,0,0,d)));if(M&&x<u-1){var V=f.dist(v);if(V>2*p){var U=f.add(v.sub(f)._mult(p/V)._round());this.updateDistance(f,U),this.addCurrentVertex(U,y,0,0,d),f=U}}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,e,o,s)}},Zo.prototype.addCurrentVertex=function(t,e,r,n,a,i){void 0===i&&(i=!1);var o=e.x+e.y*r,s=e.y-e.x*r,l=-e.x+e.y*n,c=-e.y-e.x*n;this.addHalfVertex(t,o,s,i,!1,r,a),this.addHalfVertex(t,l,c,i,!0,-n,a),this.distance>Xo/2&&0===this.totalDistance&&(this.distance=0,this.addCurrentVertex(t,e,r,n,a,i))},Zo.prototype.addHalfVertex=function(t,e,r,n,a,i,o){var s=t.x,l=t.y,c=.5*this.scaledDistance;this.layoutVertexArray.emplaceBack((s<<1)+(n?1:0),(l<<1)+(a?1:0),Math.round(63*e)+128,Math.round(63*r)+128,1+(0===i?0:i<0?-1:1)|(63&c)<<2,c>>6);var u=o.vertexLength++;this.e1>=0&&this.e2>=0&&(this.indexArray.emplaceBack(this.e1,this.e2,u),o.primitiveLength++),a?this.e2=u:this.e1=u},Zo.prototype.updateDistance=function(t,e){this.distance+=t.dist(e),this.scaledDistance=this.totalDistance>0?(this.clipStart+(this.clipEnd-this.clipStart)*this.distance/this.totalDistance)*(Xo-1):this.distance},dn("LineBucket",Zo,{omit:["layers","patternFeatures"]});var Jo=new Gn({"line-cap":new jn(Tt.layout_line["line-cap"]),"line-join":new Vn(Tt.layout_line["line-join"]),"line-miter-limit":new jn(Tt.layout_line["line-miter-limit"]),"line-round-limit":new jn(Tt.layout_line["line-round-limit"]),"line-sort-key":new Vn(Tt.layout_line["line-sort-key"])}),Ko={paint:new Gn({"line-opacity":new Vn(Tt.paint_line["line-opacity"]),"line-color":new Vn(Tt.paint_line["line-color"]),"line-translate":new jn(Tt.paint_line["line-translate"]),"line-translate-anchor":new jn(Tt.paint_line["line-translate-anchor"]),"line-width":new Vn(Tt.paint_line["line-width"]),"line-gap-width":new Vn(Tt.paint_line["line-gap-width"]),"line-offset":new Vn(Tt.paint_line["line-offset"]),"line-blur":new Vn(Tt.paint_line["line-blur"]),"line-dasharray":new qn(Tt.paint_line["line-dasharray"]),"line-pattern":new Un(Tt.paint_line["line-pattern"]),"line-gradient":new Hn(Tt.paint_line["line-gradient"])}),layout:Jo},Qo=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new Pn(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,a){return r=h({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,a)},e}(Vn))(Ko.paint.properties["line-width"].specification);Qo.useIntegerZoom=!0;var $o=function(t){function e(e){t.call(this,e,Ko)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){"line-gradient"===t&&this._updateGradient()},e.prototype._updateGradient=function(){var t=this._transitionablePaint._values["line-gradient"].value.expression;this.gradient=Ii(t,"lineProgress"),this.gradientTexture=null},e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),this.paint._values["line-floorwidth"]=Qo.possiblyEvaluate(this._transitioningPaint._values["line-width"].value,e)},e.prototype.createBucket=function(t){return new Zo(t)},e.prototype.queryRadius=function(t){var e=t,r=ts(mi("line-width",this,e),mi("line-gap-width",this,e)),n=mi("line-offset",this,e);return r/2+Math.abs(n)+yi(this.paint.get("line-translate"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,o,s){var l=xi(t,this.paint.get("line-translate"),this.paint.get("line-translate-anchor"),o.angle,s),c=s/2*ts(this.paint.get("line-width").evaluate(e,r),this.paint.get("line-gap-width").evaluate(e,r)),u=this.paint.get("line-offset").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new a(0,0),i=0;i<t.length;i++){for(var o=t[i],s=[],l=0;l<o.length;l++){var c=o[l-1],u=o[l],h=o[l+1],f=0===l?n:u.sub(c)._unit()._perp(),p=l===o.length-1?n:h.sub(u)._unit()._perp(),d=f._add(p)._unit(),g=d.x*p.x+d.y*p.y;d._mult(1/g),s.push(d._mult(e)._add(u))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var a=e[n];if(t.length>=3)for(var i=0;i<a.length;i++)if(gi(t,a[i]))return!0;if(ci(t,a,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}(Yn);function ts(t,e){return e>0?e+2*t:t}var es=Jn([{name:"a_pos_offset",components:4,type:"Int16"},{name:"a_data",components:4,type:"Uint16"}]),rs=Jn([{name:"a_projected_pos",components:3,type:"Float32"}],4),ns=(Jn([{name:"a_fade_opacity",components:1,type:"Uint32"}],4),Jn([{name:"a_placed",components:2,type:"Uint8"},{name:"a_shift",components:2,type:"Float32"}])),as=(Jn([{type:"Int16",name:"anchorPointX"},{type:"Int16",name:"anchorPointY"},{type:"Int16",name:"x1"},{type:"Int16",name:"y1"},{type:"Int16",name:"x2"},{type:"Int16",name:"y2"},{type:"Uint32",name:"featureIndex"},{type:"Uint16",name:"sourceLayerIndex"},{type:"Uint16",name:"bucketIndex"},{type:"Int16",name:"radius"},{type:"Int16",name:"signedDistanceFromAnchor"}]),Jn([{name:"a_pos",components:2,type:"Int16"},{name:"a_anchor_pos",components:2,type:"Int16"},{name:"a_extrude",components:2,type:"Int16"}],4)),is=Jn([{name:"a_pos",components:2,type:"Int16"},{name:"a_anchor_pos",components:2,type:"Int16"},{name:"a_extrude",components:2,type:"Int16"}],4);function os(t,e,r){return t.sections.forEach(function(t){t.text=function(t,e,r){var n=e.layout.get("text-transform").evaluate(r,{});return"uppercase"===n?t=t.toLocaleUpperCase():"lowercase"===n&&(t=t.toLocaleLowerCase()),Cn.applyArabicShaping&&(t=Cn.applyArabicShaping(t)),t}(t.text,e,r)}),t}Jn([{type:"Int16",name:"anchorX"},{type:"Int16",name:"anchorY"},{type:"Uint16",name:"glyphStartIndex"},{type:"Uint16",name:"numGlyphs"},{type:"Uint32",name:"vertexStartIndex"},{type:"Uint32",name:"lineStartIndex"},{type:"Uint32",name:"lineLength"},{type:"Uint16",name:"segment"},{type:"Uint16",name:"lowerSize"},{type:"Uint16",name:"upperSize"},{type:"Float32",name:"lineOffsetX"},{type:"Float32",name:"lineOffsetY"},{type:"Uint8",name:"writingMode"},{type:"Uint8",name:"placedOrientation"},{type:"Uint8",name:"hidden"},{type:"Uint32",name:"crossTileID"}]),Jn([{type:"Int16",name:"anchorX"},{type:"Int16",name:"anchorY"},{type:"Int16",name:"rightJustifiedTextSymbolIndex"},{type:"Int16",name:"centerJustifiedTextSymbolIndex"},{type:"Int16",name:"leftJustifiedTextSymbolIndex"},{type:"Int16",name:"verticalPlacedTextSymbolIndex"},{type:"Uint16",name:"key"},{type:"Uint16",name:"textBoxStartIndex"},{type:"Uint16",name:"textBoxEndIndex"},{type:"Uint16",name:"verticalTextBoxStartIndex"},{type:"Uint16",name:"verticalTextBoxEndIndex"},{type:"Uint16",name:"iconBoxStartIndex"},{type:"Uint16",name:"iconBoxEndIndex"},{type:"Uint16",name:"featureIndex"},{type:"Uint16",name:"numHorizontalGlyphVertices"},{type:"Uint16",name:"numVerticalGlyphVertices"},{type:"Uint16",name:"numIconVertices"},{type:"Uint32",name:"crossTileID"},{type:"Float32",name:"textBoxScale"},{type:"Float32",name:"radialTextOffset"}]),Jn([{type:"Float32",name:"offsetX"}]),Jn([{type:"Int16",name:"x"},{type:"Int16",name:"y"},{type:"Int16",name:"tileUnitDistanceFromAnchor"}]);var ss={"!":"\ufe15","#":"\uff03",$:"\uff04","%":"\uff05","&":"\uff06","(":"\ufe35",")":"\ufe36","*":"\uff0a","+":"\uff0b",",":"\ufe10","-":"\ufe32",".":"\u30fb","/":"\uff0f",":":"\ufe13",";":"\ufe14","<":"\ufe3f","=":"\uff1d",">":"\ufe40","?":"\ufe16","@":"\uff20","[":"\ufe47","\\":"\uff3c","]":"\ufe48","^":"\uff3e",_:"\ufe33","`":"\uff40","{":"\ufe37","|":"\u2015","}":"\ufe38","~":"\uff5e","\xa2":"\uffe0","\xa3":"\uffe1","\xa5":"\uffe5","\xa6":"\uffe4","\xac":"\uffe2","\xaf":"\uffe3","\u2013":"\ufe32","\u2014":"\ufe31","\u2018":"\ufe43","\u2019":"\ufe44","\u201c":"\ufe41","\u201d":"\ufe42","\u2026":"\ufe19","\u2027":"\u30fb","\u20a9":"\uffe6","\u3001":"\ufe11","\u3002":"\ufe12","\u3008":"\ufe3f","\u3009":"\ufe40","\u300a":"\ufe3d","\u300b":"\ufe3e","\u300c":"\ufe41","\u300d":"\ufe42","\u300e":"\ufe43","\u300f":"\ufe44","\u3010":"\ufe3b","\u3011":"\ufe3c","\u3014":"\ufe39","\u3015":"\ufe3a","\u3016":"\ufe17","\u3017":"\ufe18","\uff01":"\ufe15","\uff08":"\ufe35","\uff09":"\ufe36","\uff0c":"\ufe10","\uff0d":"\ufe32","\uff0e":"\u30fb","\uff1a":"\ufe13","\uff1b":"\ufe14","\uff1c":"\ufe3f","\uff1e":"\ufe40","\uff1f":"\ufe16","\uff3b":"\ufe47","\uff3d":"\ufe48","\uff3f":"\ufe33","\uff5b":"\ufe37","\uff5c":"\u2015","\uff5d":"\ufe38","\uff5f":"\ufe35","\uff60":"\ufe36","\uff61":"\ufe12","\uff62":"\ufe41","\uff63":"\ufe42"},ls=24,cs={horizontal:1,vertical:2,horizontalOnly:3},us=function(){this.text="",this.sectionIndex=[],this.sections=[]};function hs(t,e,r,n,a,i,o,s,l,c,u){var h,f=us.fromFeature(t,r);c===cs.vertical&&f.verticalizePunctuation();var p=Cn.processBidirectionalText,d=Cn.processStyledBidirectionalText;if(p&&1===f.sections.length){h=[];for(var g=0,v=p(f.toString(),ms(f,s,n,e));g<v.length;g+=1){var m=v[g],y=new us;y.text=m,y.sections=f.sections;for(var x=0;x<m.length;x++)y.sectionIndex.push(0);h.push(y)}}else if(d){h=[];for(var b=0,_=d(f.text,f.sectionIndex,ms(f,s,n,e));b<_.length;b+=1){var w=_[b],k=new us;k.text=w[0],k.sectionIndex=w[1],k.sections=f.sections,h.push(k)}}else h=function(t,e){for(var r=[],n=t.text,a=0,i=0,o=e;i<o.length;i+=1){var s=o[i];r.push(t.substring(a,s)),a=s}return a<n.length&&r.push(t.substring(a,n.length)),r}(f,ms(f,s,n,e));var T=[],M={positionedGlyphs:T,text:f.toString(),top:l[1],bottom:l[1],left:l[0],right:l[0],writingMode:c,lineCount:h.length,yOffset:-17};return function(t,e,r,n,a,i,o,s,l){for(var c=0,u=t.yOffset,h=0,f=t.positionedGlyphs,p="right"===i?1:"left"===i?0:.5,d=0,g=r;d<g.length;d+=1){var v=g[d];v.trim();var m=v.getMaxScale();if(v.length()){for(var y=f.length,x=0;x<v.length();x++){var b=v.getSection(x),_=v.getSectionIndex(x),w=v.getCharCode(x),k=24*(m-b.scale),T=e[b.fontStack],M=T&&T[w];M&&(o===cs.horizontal||!l&&!wn(w)||l&&(fs[w]||(S=w,xn.Arabic(S)||xn["Arabic Supplement"](S)||xn["Arabic Extended-A"](S)||xn["Arabic Presentation Forms-A"](S)||xn["Arabic Presentation Forms-B"](S)))?(f.push({glyph:w,x:c,y:u+k,vertical:!1,scale:b.scale,fontStack:b.fontStack,sectionIndex:_}),c+=M.metrics.advance*b.scale+s):(f.push({glyph:w,x:c,y:u+k,vertical:!0,scale:b.scale,fontStack:b.fontStack,sectionIndex:_}),c+=ls*b.scale+s))}if(f.length!==y){var A=c-s;h=Math.max(A,h),xs(f,e,y,f.length-1,p)}c=0,u+=n*m}else u+=n}var S,E=ys(a),L=E.horizontalAlign,C=E.verticalAlign;!function(t,e,r,n,a,i,o){for(var s=(e-r)*a,l=(-n*o+.5)*i,c=0;c<t.length;c++)t[c].x+=s,t[c].y+=l}(f,p,L,C,h,n,r.length);var P=u-t.yOffset;t.top+=-C*P,t.bottom=t.top+P,t.left+=-L*h,t.right=t.left+h}(M,e,h,a,i,o,c,s,u),!!T.length&&M}us.fromFeature=function(t,e){for(var r=new us,n=0;n<t.sections.length;n++){var a=t.sections[n];r.sections.push({scale:a.scale||1,fontStack:a.fontStack||e}),r.text+=a.text;for(var i=0;i<a.text.length;i++)r.sectionIndex.push(n)}return r},us.prototype.length=function(){return this.text.length},us.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},us.prototype.getSectionIndex=function(t){return this.sectionIndex[t]},us.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},us.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e="",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,a=t.charCodeAt(r-1)||null;n&&kn(n)&&!ss[t[r+1]]||a&&kn(a)&&!ss[t[r-1]]||!ss[t[r]]?e+=t[r]:e+=ss[t[r]]}return e}(this.text)},us.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&fs[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&fs[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},us.prototype.substring=function(t,e){var r=new us;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},us.prototype.toString=function(){return this.text},us.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce(function(e,r){return Math.max(e,t.sections[r].scale)},0)};var fs={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},ps={};function ds(t,e,r,n){var a=Math.pow(t-e,2);return n?t<e?a/2:2*a:a+Math.abs(r)*r}function gs(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function vs(t,e,r,n,a,i){for(var o=null,s=ds(e,r,a,i),l=0,c=n;l<c.length;l+=1){var u=c[l],h=ds(e-u.x,r,a,i)+u.badness;h<=s&&(o=u,s=h)}return{index:t,x:e,priorBreak:o,badness:s}}function ms(t,e,r,n){if(!r)return[];if(!t)return[];for(var a,i=[],o=function(t,e,r,n){for(var a=0,i=0;i<t.length();i++){var o=t.getSection(i),s=n[o.fontStack],l=s&&s[t.getCharCode(i)];l&&(a+=l.metrics.advance*o.scale+e)}return a/Math.max(1,Math.ceil(a/r))}(t,e,r,n),s=t.text.indexOf("\u200b")>=0,l=0,c=0;c<t.length();c++){var u=t.getSection(c),h=t.getCharCode(c),f=n[u.fontStack],p=f&&f[h];if(p&&!fs[h]&&(l+=p.metrics.advance*u.scale+e),c<t.length()-1){var d=!((a=h)<11904||!(xn["Bopomofo Extended"](a)||xn.Bopomofo(a)||xn["CJK Compatibility Forms"](a)||xn["CJK Compatibility Ideographs"](a)||xn["CJK Compatibility"](a)||xn["CJK Radicals Supplement"](a)||xn["CJK Strokes"](a)||xn["CJK Symbols and Punctuation"](a)||xn["CJK Unified Ideographs Extension A"](a)||xn["CJK Unified Ideographs"](a)||xn["Enclosed CJK Letters and Months"](a)||xn["Halfwidth and Fullwidth Forms"](a)||xn.Hiragana(a)||xn["Ideographic Description Characters"](a)||xn["Kangxi Radicals"](a)||xn["Katakana Phonetic Extensions"](a)||xn.Katakana(a)||xn["Vertical Forms"](a)||xn["Yi Radicals"](a)||xn["Yi Syllables"](a)));(ps[h]||d)&&i.push(vs(c+1,l,o,i,gs(h,t.getCharCode(c+1),d&&s),!1))}}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(vs(t.length(),l,o,i,0,!0))}function ys(t){var e=.5,r=.5;switch(t){case"right":case"top-right":case"bottom-right":e=1;break;case"left":case"top-left":case"bottom-left":e=0}switch(t){case"bottom":case"bottom-right":case"bottom-left":r=1;break;case"top":case"top-right":case"top-left":r=0}return{horizontalAlign:e,verticalAlign:r}}function xs(t,e,r,n,a){if(a){var i=t[n],o=e[i.fontStack],s=o&&o[i.glyph];if(s)for(var l=s.metrics.advance*i.scale,c=(t[n].x+l)*a,u=r;u<=n;u++)t[u].x-=c}}ps[10]=!0,ps[32]=!0,ps[38]=!0,ps[40]=!0,ps[41]=!0,ps[43]=!0,ps[45]=!0,ps[47]=!0,ps[173]=!0,ps[183]=!0,ps[8203]=!0,ps[8208]=!0,ps[8211]=!0,ps[8231]=!0;var bs=function(t){function e(e,r,n,a){t.call(this,e,r),this.angle=n,void 0!==a&&(this.segment=a)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(a);dn("Anchor",bs);var _s=256;function ws(t,e){var r=e.expression;if("constant"===r.kind)return{kind:"constant",layoutSize:r.evaluate(new Pn(t+1))};if("source"===r.kind)return{kind:"source"};for(var n=r.zoomStops,a=r.interpolationType,i=0;i<n.length&&n[i]<=t;)i++;for(var o=i=Math.max(0,i-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[i],l=n[o];return"composite"===r.kind?{kind:"composite",minZoom:s,maxZoom:l,interpolationType:a}:{kind:"camera",minZoom:s,maxZoom:l,minSize:r.evaluate(new Pn(s)),maxSize:r.evaluate(new Pn(l)),interpolationType:a}}function ks(t,e,r){var n=e.uSize,a=e.uSizeT,i=r.lowerSize,o=r.upperSize;return"source"===t.kind?i/_s:"composite"===t.kind?ye(i/_s,o/_s,a):n}function Ts(t,e){var r=0,n=0;if("constant"===t.kind)n=t.layoutSize;else if("source"!==t.kind){var a=t.interpolationType,i=t.minZoom,o=t.maxZoom,s=a?c(Ne.interpolationFactor(a,e,i,o),0,1):0;"camera"===t.kind?n=ye(t.minSize,t.maxSize,s):r=s}return{uSizeT:r,uSize:n}}var Ms=Object.freeze({getSizeData:ws,evaluateSizeForFeature:ks,evaluateSizeForZoom:Ts,SIZE_PACK_FACTOR:_s}),As=Io.VectorTileFeature.types,Ss=[{name:"a_fade_opacity",components:1,type:"Uint8",offset:0}];function Es(t,e,r,n,a,i,o,s){t.emplaceBack(e,r,Math.round(32*n),Math.round(32*a),i,o,s?s[0]:0,s?s[1]:0)}function Ls(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}var Cs=function(t){this.layoutVertexArray=new na,this.indexArray=new da,this.programConfigurations=t,this.segments=new Oa,this.dynamicLayoutVertexArray=new aa,this.opacityVertexArray=new ia,this.placedSymbolArray=new wa};Cs.prototype.upload=function(t,e,r,n){r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,es.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,rs.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,Ss,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t)},Cs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},dn("SymbolBuffers",Cs);var Ps=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new Oa,this.collisionVertexArray=new la};Ps.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,ns.members,!0)},Ps.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},dn("CollisionBuffers",Ps);var Os=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1,this.hasPaintOverrides=!1;var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=ws(this.zoom,e["text-size"]),this.iconSizeData=ws(this.zoom,e["icon-size"]);var r=this.layers[0].layout,n=r.get("symbol-sort-key"),a=r.get("symbol-z-order");this.sortFeaturesByKey="viewport-y"!==a&&void 0!==n.constantOr(1);var i="viewport-y"===a||"auto"===a&&!this.sortFeaturesByKey;this.sortFeaturesByY=i&&(r.get("text-allow-overlap")||r.get("icon-allow-overlap")||r.get("text-ignore-placement")||r.get("icon-ignore-placement")),"point"===r.get("symbol-placement")&&(this.writingModes=r.get("text-writing-mode").map(function(t){return cs[t]})),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id}),this.sourceID=t.sourceID};Os.prototype.createArrays=function(){var t=this.layers[0].layout;this.hasPaintOverrides=Rs.hasPaintOverrides(t),this.text=new Cs(new Qa(es.members,this.layers,this.zoom,function(t){return/^text/.test(t)})),this.icon=new Cs(new Qa(es.members,this.layers,this.zoom,function(t){return/^icon/.test(t)})),this.collisionBox=new Ps(sa,as.members,ga),this.collisionCircle=new Ps(sa,is.members,da),this.glyphOffsetArray=new Aa,this.lineVertexArray=new Ea,this.symbolInstances=new Ta},Os.prototype.calculateGlyphDependencies=function(t,e,r,n,a){for(var i=0;i<t.length;i++)if(e[t.charCodeAt(i)]=!0,(r||n)&&a){var o=ss[t.charAt(i)];o&&(e[o.charCodeAt(0)]=!0)}},Os.prototype.populate=function(t,e){var r=this.layers[0],n=r.layout,a=n.get("text-font"),i=n.get("text-field"),o=n.get("icon-image"),s=("constant"!==i.value.kind||i.value.value.toString().length>0)&&("constant"!==a.value.kind||a.value.value.length>0),l="constant"!==o.value.kind||o.value.value&&o.value.value.length>0,c=n.get("symbol-sort-key");if(this.features=[],s||l){for(var u=e.iconDependencies,h=e.glyphDependencies,f=new Pn(this.zoom),p=0,d=t;p<d.length;p+=1){var g=d[p],v=g.feature,m=g.index,y=g.sourceLayerIndex;if(r._featureFilter(f,v)){var x=void 0;if(s){var b=r.getValueAndResolveTokens("text-field",v);x=os(b instanceof Jt?b:Jt.fromString(b),r,v)}var _=void 0;if(l&&(_=r.getValueAndResolveTokens("icon-image",v)),x||_){var w=this.sortFeaturesByKey?c.evaluate(v,{}):void 0,k={text:x,icon:_,index:m,sourceLayerIndex:y,geometry:ni(v),properties:v.properties,type:As[v.type],sortKey:w};if(void 0!==v.id&&(k.id=v.id),this.features.push(k),_&&(u[_]=!0),x){var T=a.evaluate(v,{}).join(","),M="map"===n.get("text-rotation-alignment")&&"point"!==n.get("symbol-placement");this.allowVerticalPlacement=this.writingModes&&this.writingModes.indexOf(cs.vertical)>=0;for(var A=0,S=x.sections;A<S.length;A+=1){var E=S[A],L=bn(x.toString()),C=E.fontStack||T,P=h[C]=h[C]||{};this.calculateGlyphDependencies(E.text,P,M,this.allowVerticalPlacement,L)}}}}}"line"===n.get("symbol-placement")&&(this.features=function(t){var e={},r={},n=[],a=0;function i(e){n.push(t[e]),a++}function o(t,e,a){var i=r[t];return delete r[t],r[e]=i,n[i].geometry[0].pop(),n[i].geometry[0]=n[i].geometry[0].concat(a[0]),i}function s(t,r,a){var i=e[r];return delete e[r],e[t]=i,n[i].geometry[0].shift(),n[i].geometry[0]=a[0].concat(n[i].geometry[0]),i}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+":"+n.x+":"+n.y}for(var c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.text?u.text.toString():null;if(f){var p=l(f,h),d=l(f,h,!0);if(p in r&&d in e&&r[p]!==e[d]){var g=s(p,d,h),v=o(p,d,n[g].geometry);delete e[p],delete r[d],r[l(f,n[v].geometry,!0)]=v,n[g].geometry=null}else p in r?o(p,d,h):d in e?s(p,d,h):(i(c),e[p]=a-1,r[d]=a-1)}else i(c)}return n.filter(function(t){return t.geometry})}(this.features)),this.sortFeaturesByKey&&this.features.sort(function(t,e){return t.sortKey-e.sortKey})}},Os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},Os.prototype.isEmpty=function(){return 0===this.symbolInstances.length},Os.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},Os.prototype.upload=function(t){this.uploaded||(this.collisionBox.upload(t),this.collisionCircle.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},Os.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.collisionBox.destroy(),this.collisionCircle.destroy()},Os.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),a=t.dist(e[t.segment]),i={},o=t.segment+1;o<e.length;o++)i[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)i[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:a},s>0&&(a+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=i[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},Os.prototype.addSymbols=function(t,e,r,n,a,i,o,s,l,c){var u=this,h=t.indexArray,f=t.layoutVertexArray,p=t.dynamicLayoutVertexArray,d=t.segments.prepareSegment(4*e.length,t.layoutVertexArray,t.indexArray,i.sortKey),g=this.glyphOffsetArray.length,v=d.vertexLength,m=this.allowVerticalPlacement&&o===cs.vertical?Math.PI/2:0,y=function(t){var e=t.tl,n=t.tr,a=t.bl,i=t.br,o=t.tex,l=d.vertexLength,c=t.glyphOffset[1];Es(f,s.x,s.y,e.x,c+e.y,o.x,o.y,r),Es(f,s.x,s.y,n.x,c+n.y,o.x+o.w,o.y,r),Es(f,s.x,s.y,a.x,c+a.y,o.x,o.y+o.h,r),Es(f,s.x,s.y,i.x,c+i.y,o.x+o.w,o.y+o.h,r),Ls(p,s,m),h.emplaceBack(l,l+1,l+2),h.emplaceBack(l+1,l+2,l+3),d.vertexLength+=4,d.primitiveLength+=2,u.glyphOffsetArray.emplaceBack(t.glyphOffset[0])};if(i.text&&i.text.sections){var x=i.text.sections;if(this.hasPaintOverrides){for(var b,_=function(e,r){void 0===b||b===e&&!r||t.programConfigurations.populatePaintArrays(t.layoutVertexArray.length,i,i.index,{},x[b]),b=e},w=0,k=e;w<k.length;w+=1){var T=k[w];_(T.sectionIndex,!1),y(T)}_(b,!0)}else{for(var M=0,A=e;M<A.length;M+=1)y(A[M]);t.programConfigurations.populatePaintArrays(t.layoutVertexArray.length,i,i.index,{},x[0])}}else{for(var S=0,E=e;S<E.length;S+=1)y(E[S]);t.programConfigurations.populatePaintArrays(t.layoutVertexArray.length,i,i.index,{})}t.placedSymbolArray.emplaceBack(s.x,s.y,g,this.glyphOffsetArray.length-g,v,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,0,!1,0)},Os.prototype._addCollisionDebugVertex=function(t,e,r,n,a,i){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,a,Math.round(i.x),Math.round(i.y))},Os.prototype.addCollisionDebugVertices=function(t,e,r,n,i,o,s,l){var c=i.segments.prepareSegment(4,i.layoutVertexArray,i.indexArray),u=c.vertexLength,h=i.layoutVertexArray,f=i.collisionVertexArray,p=s.anchorX,d=s.anchorY;if(this._addCollisionDebugVertex(h,f,o,p,d,new a(t,e)),this._addCollisionDebugVertex(h,f,o,p,d,new a(r,e)),this._addCollisionDebugVertex(h,f,o,p,d,new a(r,n)),this._addCollisionDebugVertex(h,f,o,p,d,new a(t,n)),c.vertexLength+=4,l){var g=i.indexArray;g.emplaceBack(u,u+1,u+2),g.emplaceBack(u,u+2,u+3),c.primitiveLength+=2}else{var v=i.indexArray;v.emplaceBack(u,u+1),v.emplaceBack(u+1,u+2),v.emplaceBack(u+2,u+3),v.emplaceBack(u+3,u),c.primitiveLength+=4}},Os.prototype.addDebugCollisionBoxes=function(t,e,r){for(var n=t;n<e;n++){var a=this.collisionBoxArray.get(n),i=a.x1,o=a.y1,s=a.x2,l=a.y2,c=a.radius>0;this.addCollisionDebugVertices(i,o,s,l,c?this.collisionCircle:this.collisionBox,a.anchorPoint,r,c)}},Os.prototype.generateCollisionDebugBuffers=function(){for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e),this.addDebugCollisionBoxes(e.verticalTextBoxStartIndex,e.verticalTextBoxEndIndex,e),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e)}},Os.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,a,i,o){for(var s={},l=e;l<r;l++){var c=t.get(l);if(0===c.radius){s.textBox={x1:c.x1,y1:c.y1,x2:c.x2,y2:c.y2,anchorPointX:c.anchorPointX,anchorPointY:c.anchorPointY},s.textFeatureIndex=c.featureIndex;break}s.textCircles||(s.textCircles=[],s.textFeatureIndex=c.featureIndex),s.textCircles.push(c.anchorPointX,c.anchorPointY,c.radius,c.signedDistanceFromAnchor,1)}for(var u=n;u<a;u++){var h=t.get(u);if(0===h.radius){s.verticalTextBox={x1:h.x1,y1:h.y1,x2:h.x2,y2:h.y2,anchorPointX:h.anchorPointX,anchorPointY:h.anchorPointY},s.verticalTextFeatureIndex=h.featureIndex;break}}for(var f=i;f<o;f++){var p=t.get(f);if(0===p.radius){s.iconBox={x1:p.x1,y1:p.y1,x2:p.x2,y2:p.y2,anchorPointX:p.anchorPointX,anchorPointY:p.anchorPointY},s.iconFeatureIndex=p.featureIndex;break}}return s},Os.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.verticalTextBoxStartIndex,r.verticalTextBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex))}},Os.prototype.hasTextData=function(){return this.text.segments.get().length>0},Os.prototype.hasIconData=function(){return this.icon.segments.get().length>0},Os.prototype.hasCollisionBoxData=function(){return this.collisionBox.segments.get().length>0},Os.prototype.hasCollisionCircleData=function(){return this.collisionCircle.segments.get().length>0},Os.prototype.addIndicesForPlacedTextSymbol=function(t){for(var e=this.text.placedSymbolArray.get(t),r=e.vertexStartIndex+4*e.numGlyphs,n=e.vertexStartIndex;n<r;n+=4)this.text.indexArray.emplaceBack(n,n+1,n+2),this.text.indexArray.emplaceBack(n+1,n+2,n+3)},Os.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],a=[],i=[],o=0;o<this.symbolInstances.length;++o){i.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),a.push(s.featureIndex)}return i.sort(function(t,e){return n[t]-n[e]||a[e]-a[t]}),i},Os.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var a=n[r],i=this.symbolInstances.get(a);this.featureSortOrder.push(i.featureIndex),[i.rightJustifiedTextSymbolIndex,i.centerJustifiedTextSymbolIndex,i.leftJustifiedTextSymbolIndex].forEach(function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedTextSymbol(t)}),i.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedTextSymbol(i.verticalPlacedTextSymbolIndex);var o=this.icon.placedSymbolArray.get(a);if(o.numGlyphs){var s=o.vertexStartIndex;this.icon.indexArray.emplaceBack(s,s+1,s+2),this.icon.indexArray.emplaceBack(s+1,s+2,s+3)}}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},dn("SymbolBucket",Os,{omit:["layers","collisionBoxArray","features","compareText"]}),Os.MAX_GLYPHS=65535,Os.addDynamicAttributes=Ls;var zs=new Gn({"symbol-placement":new jn(Tt.layout_symbol["symbol-placement"]),"symbol-spacing":new jn(Tt.layout_symbol["symbol-spacing"]),"symbol-avoid-edges":new jn(Tt.layout_symbol["symbol-avoid-edges"]),"symbol-sort-key":new Vn(Tt.layout_symbol["symbol-sort-key"]),"symbol-z-order":new jn(Tt.layout_symbol["symbol-z-order"]),"icon-allow-overlap":new jn(Tt.layout_symbol["icon-allow-overlap"]),"icon-ignore-placement":new jn(Tt.layout_symbol["icon-ignore-placement"]),"icon-optional":new jn(Tt.layout_symbol["icon-optional"]),"icon-rotation-alignment":new jn(Tt.layout_symbol["icon-rotation-alignment"]),"icon-size":new Vn(Tt.layout_symbol["icon-size"]),"icon-text-fit":new jn(Tt.layout_symbol["icon-text-fit"]),"icon-text-fit-padding":new jn(Tt.layout_symbol["icon-text-fit-padding"]),"icon-image":new Vn(Tt.layout_symbol["icon-image"]),"icon-rotate":new Vn(Tt.layout_symbol["icon-rotate"]),"icon-padding":new jn(Tt.layout_symbol["icon-padding"]),"icon-keep-upright":new jn(Tt.layout_symbol["icon-keep-upright"]),"icon-offset":new Vn(Tt.layout_symbol["icon-offset"]),"icon-anchor":new Vn(Tt.layout_symbol["icon-anchor"]),"icon-pitch-alignment":new jn(Tt.layout_symbol["icon-pitch-alignment"]),"text-pitch-alignment":new jn(Tt.layout_symbol["text-pitch-alignment"]),"text-rotation-alignment":new jn(Tt.layout_symbol["text-rotation-alignment"]),"text-field":new Vn(Tt.layout_symbol["text-field"]),"text-font":new Vn(Tt.layout_symbol["text-font"]),"text-size":new Vn(Tt.layout_symbol["text-size"]),"text-max-width":new Vn(Tt.layout_symbol["text-max-width"]),"text-line-height":new jn(Tt.layout_symbol["text-line-height"]),"text-letter-spacing":new Vn(Tt.layout_symbol["text-letter-spacing"]),"text-justify":new Vn(Tt.layout_symbol["text-justify"]),"text-radial-offset":new Vn(Tt.layout_symbol["text-radial-offset"]),"text-variable-anchor":new jn(Tt.layout_symbol["text-variable-anchor"]),"text-anchor":new Vn(Tt.layout_symbol["text-anchor"]),"text-max-angle":new jn(Tt.layout_symbol["text-max-angle"]),"text-writing-mode":new jn(Tt.layout_symbol["text-writing-mode"]),"text-rotate":new Vn(Tt.layout_symbol["text-rotate"]),"text-padding":new jn(Tt.layout_symbol["text-padding"]),"text-keep-upright":new jn(Tt.layout_symbol["text-keep-upright"]),"text-transform":new Vn(Tt.layout_symbol["text-transform"]),"text-offset":new Vn(Tt.layout_symbol["text-offset"]),"text-allow-overlap":new jn(Tt.layout_symbol["text-allow-overlap"]),"text-ignore-placement":new jn(Tt.layout_symbol["text-ignore-placement"]),"text-optional":new jn(Tt.layout_symbol["text-optional"])}),Is={paint:new Gn({"icon-opacity":new Vn(Tt.paint_symbol["icon-opacity"]),"icon-color":new Vn(Tt.paint_symbol["icon-color"]),"icon-halo-color":new Vn(Tt.paint_symbol["icon-halo-color"]),"icon-halo-width":new Vn(Tt.paint_symbol["icon-halo-width"]),"icon-halo-blur":new Vn(Tt.paint_symbol["icon-halo-blur"]),"icon-translate":new jn(Tt.paint_symbol["icon-translate"]),"icon-translate-anchor":new jn(Tt.paint_symbol["icon-translate-anchor"]),"text-opacity":new Vn(Tt.paint_symbol["text-opacity"]),"text-color":new Vn(Tt.paint_symbol["text-color"],{runtimeType:Ft,getOverride:function(t){return t.textColor},hasOverride:function(t){return!!t.textColor}}),"text-halo-color":new Vn(Tt.paint_symbol["text-halo-color"]),"text-halo-width":new Vn(Tt.paint_symbol["text-halo-width"]),"text-halo-blur":new Vn(Tt.paint_symbol["text-halo-blur"]),"text-translate":new jn(Tt.paint_symbol["text-translate"]),"text-translate-anchor":new jn(Tt.paint_symbol["text-translate-anchor"])}),layout:zs},Ds=function(t){this.type=t.property.overrides?t.property.overrides.runtimeType:zt,this.defaultValue=t};Ds.prototype.evaluate=function(t){if(t.formattedSection){var e=this.defaultValue.property.overrides;if(e&&e.hasOverride(t.formattedSection))return e.getOverride(t.formattedSection)}return t.feature&&t.featureState?this.defaultValue.evaluate(t.feature,t.featureState):this.defaultValue.property.specification.default},Ds.prototype.eachChild=function(t){this.defaultValue.isConstant()||t(this.defaultValue.value._styleExpression.expression)},Ds.prototype.possibleOutputs=function(){return[void 0]},Ds.prototype.serialize=function(){return null},dn("FormatSectionOverride",Ds,{omit:["defaultValue"]});var Rs=function(t){function e(e){t.call(this,e,Is)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){if(t.prototype.recalculate.call(this,e),"auto"===this.layout.get("icon-rotation-alignment")&&("point"!==this.layout.get("symbol-placement")?this.layout._values["icon-rotation-alignment"]="map":this.layout._values["icon-rotation-alignment"]="viewport"),"auto"===this.layout.get("text-rotation-alignment")&&("point"!==this.layout.get("symbol-placement")?this.layout._values["text-rotation-alignment"]="map":this.layout._values["text-rotation-alignment"]="viewport"),"auto"===this.layout.get("text-pitch-alignment")&&(this.layout._values["text-pitch-alignment"]=this.layout.get("text-rotation-alignment")),"auto"===this.layout.get("icon-pitch-alignment")&&(this.layout._values["icon-pitch-alignment"]=this.layout.get("icon-rotation-alignment")),"point"===this.layout.get("symbol-placement")){var r=this.layout.get("text-writing-mode");if(r){for(var n=[],a=0,i=r;a<i.length;a+=1){var o=i[a];n.indexOf(o)<0&&n.push(o)}this.layout._values["text-writing-mode"]=n}else this.layout._values["text-writing-mode"]=["horizontal"]}this._setPaintOverrides()},e.prototype.getValueAndResolveTokens=function(t,e){var r=this.layout.get(t).evaluate(e,{}),n=this._unevaluatedLayout._values[t];return n.isDataDriven()||wr(n.value)?r:function(t,e){return r.replace(/{([^{}]+)}/g,function(e,r){return r in t?String(t[r]):""})}(e.properties)},e.prototype.createBucket=function(t){return new Os(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype._setPaintOverrides=function(){for(var t=0,r=Is.paint.overridableProperties;t<r.length;t+=1){var n=r[t];if(e.hasPaintOverride(this.layout,n)){var a,i=this.paint.get(n),o=new Ds(i),s=new _r(o,i.property.specification);a="constant"===i.value.kind||"source"===i.value.kind?new Tr("source",s):new Mr("composite",s,i.value.zoomStops,i.value._interpolationType),this.paint._values[n]=new Bn(i.property,a,i.parameters)}}},e.prototype._handleOverridablePaintPropertyUpdate=function(t,r,n){return!(!this.layout||r.isDataDriven()||n.isDataDriven())&&e.hasPaintOverride(this.layout,t)},e.hasPaintOverride=function(t,e){var r=t.get("text-field"),n=Is.paint.properties[e],a=!1,i=function(t){for(var e=0,r=t;e<r.length;e+=1){var i=r[e];if(n.overrides&&n.overrides.hasOverride(i))return void(a=!0)}};if("constant"===r.value.kind&&r.value.value instanceof Jt)i(r.value.value.sections);else if("source"===r.value.kind){var o=function(t){if(!a)if(t instanceof te&&Qt(t.value)===Vt){var e=t.value;i(e.sections)}else t instanceof ae?i(t.sections):t.eachChild(o)},s=r.value;s._styleExpression&&o(s._styleExpression.expression)}return a},e.hasPaintOverrides=function(t){for(var r=0,n=Is.paint.overridableProperties;r<n.length;r+=1){var a=n[r];if(e.hasPaintOverride(t,a))return!0}return!1},e}(Yn),Fs={paint:new Gn({"background-color":new jn(Tt.paint_background["background-color"]),"background-pattern":new qn(Tt.paint_background["background-pattern"]),"background-opacity":new jn(Tt.paint_background["background-opacity"])})},Bs=function(t){function e(e){t.call(this,e,Fs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Yn),Ns={paint:new Gn({"raster-opacity":new jn(Tt.paint_raster["raster-opacity"]),"raster-hue-rotate":new jn(Tt.paint_raster["raster-hue-rotate"]),"raster-brightness-min":new jn(Tt.paint_raster["raster-brightness-min"]),"raster-brightness-max":new jn(Tt.paint_raster["raster-brightness-max"]),"raster-saturation":new jn(Tt.paint_raster["raster-saturation"]),"raster-contrast":new jn(Tt.paint_raster["raster-contrast"]),"raster-resampling":new jn(Tt.paint_raster["raster-resampling"]),"raster-fade-duration":new jn(Tt.paint_raster["raster-fade-duration"])})},js=function(t){function e(e){t.call(this,e,Ns)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Yn),Vs=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.is3D=function(){return"3d"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}(Yn),Us={circle:Mi,heatmap:Di,hillshade:Fi,fill:To,"fill-extrusion":Uo,line:$o,symbol:Rs,background:Bs,raster:js};function qs(t){for(var e=0,r=0,n=0,a=t;n<a.length;n+=1){var i=a[n];e+=i.w*i.h,r=Math.max(r,i.w)}t.sort(function(t,e){return e.h-t.h});for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var h=u[c],f=o.length-1;f>=0;f--){var p=o[f];if(!(h.w>p.w||h.h>p.h)){if(h.x=p.x,h.y=p.y,l=Math.max(l,h.y+h.h),s=Math.max(s,h.x+h.w),h.w===p.w&&h.h===p.h){var d=o.pop();f<o.length&&(o[f]=d)}else h.h===p.h?(p.x+=h.w,p.w-=h.w):h.w===p.w?(p.y+=h.h,p.h-=h.h):(o.push({x:p.x+h.w,y:p.y,w:p.w-h.w,h:h.h}),p.y+=h.h,p.h-=h.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}var Hs=function(t,e){var r=e.pixelRatio,n=e.version;this.paddedRect=t,this.pixelRatio=r,this.version=n},Gs={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};Gs.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},Gs.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},Gs.tlbr.get=function(){return this.tl.concat(this.br)},Gs.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(Hs.prototype,Gs);var Ys=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var a=[];this.addImages(t,r,a),this.addImages(e,n,a);var i=qs(a),o=i.w,s=i.h,l=new Oi({width:o||1,height:s||1});for(var c in t){var u=t[c],h=r[c].paddedRect;Oi.copy(u.data,l,{x:0,y:0},{x:h.x+1,y:h.y+1},u.data)}for(var f in e){var p=e[f],d=n[f].paddedRect,g=d.x+1,v=d.y+1,m=p.data.width,y=p.data.height;Oi.copy(p.data,l,{x:0,y:0},{x:g,y:v},p.data),Oi.copy(p.data,l,{x:0,y:y-1},{x:g,y:v-1},{width:m,height:1}),Oi.copy(p.data,l,{x:0,y:0},{x:g,y:v+y},{width:m,height:1}),Oi.copy(p.data,l,{x:m-1,y:0},{x:g-1,y:v},{width:1,height:y}),Oi.copy(p.data,l,{x:0,y:0},{x:g+m,y:v},{width:1,height:y})}this.image=l,this.iconPositions=r,this.patternPositions=n};Ys.prototype.addImages=function(t,e,r){for(var n in t){var a=t[n],i={x:0,y:0,w:a.data.width+2,h:a.data.height+2};r.push(i),e[n]=new Hs(i,a),a.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},Ys.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},Ys.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl,a=n[0],i=n[1];r.update(e.data,void 0,{x:a,y:i})}},dn("ImagePosition",Hs),dn("ImageAtlas",Ys);var Ws=self.HTMLImageElement,Xs=self.HTMLCanvasElement,Zs=self.HTMLVideoElement,Js=self.ImageData,Ks=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Ks.prototype.update=function(t,e,r){var n=t.width,a=t.height,i=!(this.size&&this.size[0]===n&&this.size[1]===a||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),i)this.size=[n,a],t instanceof Ws||t instanceof Xs||t instanceof Zs||t instanceof Js?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,a,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof Ws||t instanceof Xs||t instanceof Zs||t instanceof Js?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,a,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Ks.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Ks.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Ks.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var Qs=function(t,e,r,n,a){var i,o,s=8*a-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?a-1:0,f=r?-1:1,p=t[e+h];for(h+=f,i=p&(1<<-u)-1,p>>=-u,u+=s;u>0;i=256*i+t[e+h],h+=f,u-=8);for(o=i&(1<<-u)-1,i>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===i)i=1-c;else{if(i===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),i-=c}return(p?-1:1)*o*Math.pow(2,i-n)},$s=function(t,e,r,n,a,i){var o,s,l,c=8*i-a-1,u=(1<<c)-1,h=u>>1,f=23===a?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:i-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,a),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,a),o=0));a>=8;t[r+p]=255&s,p+=d,s/=256,a-=8);for(o=o<<a|s,c+=a;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g},tl=el;function el(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}function rl(t){return t.type===el.Bytes?t.readVarint()+t.pos:t.pos+1}function nl(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function al(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var a=r.pos-1;a>=t;a--)r.buf[a+n]=r.buf[a]}function il(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function ol(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function sl(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function ll(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function cl(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function ul(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function hl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function fl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function pl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function dl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function gl(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function vl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}el.Varint=0,el.Fixed64=1,el.Bytes=2,el.Fixed32=5,el.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),a=n>>3,i=this.pos;this.type=7&n,t(a,e,this),this.pos===i&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=dl(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=vl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=dl(this.buf,this.pos)+4294967296*dl(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=dl(this.buf,this.pos)+4294967296*vl(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=Qs(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=Qs(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,a,i=r.buf;if(n=(112&(a=i[r.pos++]))>>4,a<128)return nl(t,n,e);if(n|=(127&(a=i[r.pos++]))<<3,a<128)return nl(t,n,e);if(n|=(127&(a=i[r.pos++]))<<10,a<128)return nl(t,n,e);if(n|=(127&(a=i[r.pos++]))<<17,a<128)return nl(t,n,e);if(n|=(127&(a=i[r.pos++]))<<24,a<128)return nl(t,n,e);if(n|=(1&(a=i[r.pos++]))<<31,a<128)return nl(t,n,e);throw new Error("Expected varint not more than 10 bytes")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=function(t,e,r){for(var n="",a=e;a<r;){var i,o,s,l=t[a],c=null,u=l>239?4:l>223?3:l>191?2:1;if(a+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(i=t[a+1]))&&(c=(31&l)<<6|63&i)<=127&&(c=null):3===u?(i=t[a+1],o=t[a+2],128==(192&i)&&128==(192&o)&&((c=(15&l)<<12|(63&i)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(i=t[a+1],o=t[a+2],s=t[a+3],128==(192&i)&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&i)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),a+=u}return n}(this.buf,this.pos,t);return this.pos=t,e},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==el.Bytes)return t.push(this.readVarint(e));var r=rl(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==el.Bytes)return t.push(this.readSVarint());var e=rl(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==el.Bytes)return t.push(this.readBoolean());var e=rl(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==el.Bytes)return t.push(this.readFloat());var e=rl(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==el.Bytes)return t.push(this.readDouble());var e=rl(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==el.Bytes)return t.push(this.readFixed32());var e=rl(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==el.Bytes)return t.push(this.readSFixed32());var e=rl(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==el.Bytes)return t.push(this.readFixed64());var e=rl(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==el.Bytes)return t.push(this.readSFixed64());var e=rl(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===el.Varint)for(;this.buf[this.pos++]>127;);else if(e===el.Bytes)this.pos=this.readVarint()+this.pos;else if(e===el.Fixed32)this.pos+=4;else{if(e!==el.Fixed64)throw new Error("Unimplemented type: "+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),gl(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),gl(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),gl(this.buf,-1&t,this.pos),gl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),gl(this.buf,-1&t,this.pos),gl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error("Given varint doesn't fit into 10 bytes");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos]=127&t}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,a,i=0;i<e.length;i++){if((n=e.charCodeAt(i))>55295&&n<57344){if(!a){n>56319||i+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):a=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,a=n;continue}n=a-55296<<10|n-56320|65536,a=null}else a&&(t[r++]=239,t[r++]=191,t[r++]=189,a=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&al(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),$s(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),$s(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&al(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,el.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,il,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,ol,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,cl,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,sl,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,ll,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,ul,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,hl,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,fl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,pl,e)},writeBytesField:function(t,e){this.writeTag(t,el.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,el.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,el.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,el.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,el.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,el.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,el.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,el.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,el.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,el.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var ml=3;function yl(t,e,r){1===t&&r.readMessage(xl,e)}function xl(t,e,r){if(3===t){var n=r.readMessage(bl,{}),a=n.id,i=n.bitmap,o=n.width,s=n.height,l=n.left,c=n.top,u=n.advance;e.push({id:a,bitmap:new Pi({width:o+2*ml,height:s+2*ml},i),metrics:{width:o,height:s,left:l,top:c,advance:u}})}}function bl(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}var _l=ml,wl=function(t){var e=this;this._callback=t,this._triggered=!1,"undefined"!=typeof MessageChannel&&(this._channel=new MessageChannel,this._channel.port2.onmessage=function(){e._triggered=!1,e._callback()})};wl.prototype.trigger=function(){var t=this;this._triggered||(this._triggered=!0,this._channel?this._channel.port1.postMessage(!0):setTimeout(function(){t._triggered=!1,t._callback()},0))};var kl=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.tasks={},this.taskQueue=[],this.cancelCallbacks={},v(["receive","process"],this),this.invoker=new wl(this.process),this.target.addEventListener("message",this.receive,!1)};function Tl(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}kl.prototype.send=function(t,e,r,n){var a=this,i=Math.round(1e18*Math.random()).toString(36).substring(0,10);r&&(this.callbacks[i]=r);var o=[];return this.target.postMessage({id:i,type:t,hasCallback:!!r,targetMapId:n,sourceMapId:this.mapId,data:vn(e,o)},o),{cancel:function(){r&&delete a.callbacks[i],a.target.postMessage({id:i,type:"<cancel>",targetMapId:n,sourceMapId:a.mapId})}}},kl.prototype.receive=function(t){var e=t.data,r=e.id;if(r&&(!e.targetMapId||this.mapId===e.targetMapId))if("<cancel>"===e.type){delete this.tasks[r];var n=this.cancelCallbacks[r];delete this.cancelCallbacks[r],n&&n()}else this.tasks[r]=e,this.taskQueue.push(r),this.invoker.trigger()},kl.prototype.process=function(){var t=this;if(this.taskQueue.length){var e=this.taskQueue.shift(),r=this.tasks[e];if(delete this.tasks[e],this.taskQueue.length&&this.invoker.trigger(),r)if("<response>"===r.type){var n=this.callbacks[e];delete this.callbacks[e],n&&(r.error?n(mn(r.error)):n(null,mn(r.data)))}else{var a=!1,i=r.hasCallback?function(r,n){a=!0,delete t.cancelCallbacks[e];var i=[];t.target.postMessage({id:e,type:"<response>",sourceMapId:t.mapId,error:r?vn(r):null,data:vn(n,i)},i)}:function(t){a=!0},o=null,s=mn(r.data);if(this.parent[r.type])o=this.parent[r.type](r.sourceMapId,s,i);else if(this.parent.getWorkerSource){var l=r.type.split(".");o=this.parent.getWorkerSource(r.sourceMapId,l[0],s.source)[l[1]](s,i)}else i(new Error("Could not find function "+r.type));!a&&o&&o.cancel&&(this.cancelCallbacks[e]=o.cancel)}}},kl.prototype.remove=function(){this.target.removeEventListener("message",this.receive,!1)};var Ml=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};Ml.prototype.setNorthEast=function(t){return this._ne=t instanceof Al?new Al(t.lng,t.lat):Al.convert(t),this},Ml.prototype.setSouthWest=function(t){return this._sw=t instanceof Al?new Al(t.lng,t.lat):Al.convert(t),this},Ml.prototype.extend=function(t){var e,r,n=this._sw,a=this._ne;if(t instanceof Al)e=t,r=t;else{if(!(t instanceof Ml))return Array.isArray(t)?t.every(Array.isArray)?this.extend(Ml.convert(t)):this.extend(Al.convert(t)):this;if(e=t._sw,r=t._ne,!e||!r)return this}return n||a?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),a.lng=Math.max(r.lng,a.lng),a.lat=Math.max(r.lat,a.lat)):(this._sw=new Al(e.lng,e.lat),this._ne=new Al(r.lng,r.lat)),this},Ml.prototype.getCenter=function(){return new Al((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},Ml.prototype.getSouthWest=function(){return this._sw},Ml.prototype.getNorthEast=function(){return this._ne},Ml.prototype.getNorthWest=function(){return new Al(this.getWest(),this.getNorth())},Ml.prototype.getSouthEast=function(){return new Al(this.getEast(),this.getSouth())},Ml.prototype.getWest=function(){return this._sw.lng},Ml.prototype.getSouth=function(){return this._sw.lat},Ml.prototype.getEast=function(){return this._ne.lng},Ml.prototype.getNorth=function(){return this._ne.lat},Ml.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},Ml.prototype.toString=function(){return"LngLatBounds("+this._sw.toString()+", "+this._ne.toString()+")"},Ml.prototype.isEmpty=function(){return!(this._sw&&this._ne)},Ml.convert=function(t){return!t||t instanceof Ml?t:new Ml(t)};var Al=function(t,e){if(isNaN(t)||isNaN(e))throw new Error("Invalid LngLat object: ("+t+", "+e+")");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error("Invalid LngLat latitude value: must be between -90 and 90")};Al.prototype.wrap=function(){return new Al(u(this.lng,-180,180),this.lat)},Al.prototype.toArray=function(){return[this.lng,this.lat]},Al.prototype.toString=function(){return"LngLat("+this.lng+", "+this.lat+")"},Al.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new Ml(new Al(this.lng-r,this.lat-e),new Al(this.lng+r,this.lat+e))},Al.convert=function(t){if(t instanceof Al)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Al(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&"object"==typeof t&&null!==t)return new Al(Number("lng"in t?t.lng:t.lon),Number(t.lat));throw new Error("`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]")};var Sl=2*Math.PI*6378137;function El(t){return Sl*Math.cos(t*Math.PI/180)}function Ll(t){return(180+t)/360}function Cl(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function Pl(t,e){return t/El(e)}function Ol(t){var e=180-360*t;return 360/Math.PI*Math.atan(Math.exp(e*Math.PI/180))-90}var zl=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};zl.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Al.convert(t);return new zl(Ll(r.lng),Cl(r.lat),Pl(e,r.lat))},zl.prototype.toLngLat=function(){return new Al(360*this.x-180,Ol(this.y))},zl.prototype.toAltitude=function(){return this.z*El(Ol(this.y))},zl.prototype.meterInMercatorCoordinateUnits=function(){return 1/Sl*(t=Ol(this.y),1/Math.cos(t*Math.PI/180));var t};var Il=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=Fl(0,t,e,r)};Il.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},Il.prototype.url=function(t,e){var r,n,a,i,o,s=(r=this.x,n=this.y,a=this.z,i=Tl(256*r,256*(n=Math.pow(2,a)-n-1),a),o=Tl(256*(r+1),256*(n+1),a),i[0]+","+i[1]+","+o[0]+","+o[1]),l=function(t,e,r){for(var n,a="",i=t;i>0;i--)a+=(e&(n=1<<i-1)?1:0)+(r&n?2:0);return a}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace("{prefix}",(this.x%16).toString(16)+(this.y%16).toString(16)).replace("{z}",String(this.z)).replace("{x}",String(this.x)).replace("{y}",String("tms"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace("{quadkey}",l).replace("{bbox-epsg-3857}",s)},Il.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new a((t.x*e-this.x)*ei,(t.y*e-this.y)*ei)};var Dl=function(t,e){this.wrap=t,this.canonical=e,this.key=Fl(t,e.z,e.x,e.y)},Rl=function(t,e,r,n,a){this.overscaledZ=t,this.wrap=e,this.canonical=new Il(r,+n,+a),this.key=Fl(e,t,n,a)};function Fl(t,e,r,n){(t*=2)<0&&(t=-1*t-1);var a=1<<e;return 32*(a*a*t+a*n+r)+e}Rl.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},Rl.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new Rl(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new Rl(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},Rl.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},Rl.prototype.children=function(t){if(this.overscaledZ>=t)return[new Rl(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new Rl(e,this.wrap,e,r,n),new Rl(e,this.wrap,e,r+1,n),new Rl(e,this.wrap,e,r,n+1),new Rl(e,this.wrap,e,r+1,n+1)]},Rl.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},Rl.prototype.wrapped=function(){return new Rl(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},Rl.prototype.unwrapTo=function(t){return new Rl(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},Rl.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},Rl.prototype.toUnwrapped=function(){return new Dl(this.wrap,this.canonical)},Rl.prototype.toString=function(){return this.overscaledZ+"/"+this.canonical.x+"/"+this.canonical.y},Rl.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new zl(t.x-this.wrap,t.y))},dn("CanonicalTileID",Il),dn("OverscaledTileID",Rl,{omit:["posMatrix"]});var Bl=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError("DEM tiles must be square");if(r&&"mapbox"!==r&&"terrarium"!==r)return w('"'+r+'" is not a valid encoding type. Valid types include "mapbox" and "terrarium".');var n=this.dim=e.height;this.stride=this.dim+2,this.data=new Int32Array(this.stride*this.stride);for(var a=e.data,i="terrarium"===r?this._unpackTerrarium:this._unpackMapbox,o=0;o<n;o++)for(var s=0;s<n;s++){var l=4*(o*n+s);this.set(s,o,i(a[l],a[l+1],a[l+2]))}for(var c=0;c<n;c++)this.set(-1,c,this.get(0,c)),this.set(n,c,this.get(n-1,c)),this.set(c,-1,this.get(c,0)),this.set(c,n,this.get(c,n-1));this.set(-1,-1,this.get(0,0)),this.set(n,-1,this.get(n-1,0)),this.set(-1,n,this.get(0,n-1)),this.set(n,n,this.get(n-1,n-1))};Bl.prototype.set=function(t,e,r){this.data[this._idx(t,e)]=r+65536},Bl.prototype.get=function(t,e){return this.data[this._idx(t,e)]-65536},Bl.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError("out of range source coordinates for DEM data");return(e+1)*this.stride+(t+1)},Bl.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Bl.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Bl.prototype.getPixels=function(){return new Oi({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},Bl.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error("dem dimension mismatch");var n=e*this.dim,a=e*this.dim+this.dim,i=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=a-1;break;case 1:a=n+1}switch(r){case-1:i=o-1;break;case 1:o=i+1}for(var s=-e*this.dim,l=-r*this.dim,c=i;c<o;c++)for(var u=n;u<a;u++)this.set(u,c,t.get(u+s,c+l))},dn("DEMData",Bl);var Nl=Jn([{name:"a_pos",type:"Int16",components:2},{name:"a_texture_pos",type:"Int16",components:2}]),jl=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};jl.prototype.encode=function(t){return this._stringToNumber[t]},jl.prototype.decode=function(t){return this._numberToString[t]};var Vl=function(t,e,r,n){this.type="Feature",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,null!=t.id&&(this.id=t.id)},Ul={geometry:{configurable:!0}};Ul.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Ul.geometry.set=function(t){this._geometry=t},Vl.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)"_geometry"!==e&&"_vectorTileFeature"!==e&&(t[e]=this[e]);return t},Object.defineProperties(Vl.prototype,Ul);var ql=function(){this.state={},this.stateChanges={},this.deletedStates={}};ql.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},h(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var a in this.deletedStates[t]={},this.state[t])a!==n&&(this.deletedStates[t][a]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var i in this.deletedStates[t][n]={},this.state[t][n])r[i]||(this.deletedStates[t][n][i]=null);else for(var o in r)this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]},ql.prototype.removeFeatureState=function(t,e,r){if(null!==this.deletedStates[t]){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e&&e>=0)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e&&e>=0)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}},ql.prototype.getState=function(t,e){var r=String(e),n=this.state[t]||{},a=this.stateChanges[t]||{},i=h({},n[r],a[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var o=this.deletedStates[t][e];if(null===o)return{};for(var s in o)delete i[s]}return i},ql.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},ql.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var a={};for(var i in this.stateChanges[n])this.state[n][i]||(this.state[n][i]={}),h(this.state[n][i],this.stateChanges[n][i]),a[i]=this.state[n][i];r[n]=a}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var u=0,f=Object.keys(this.deletedStates[o][c]);u<f.length;u+=1){var p=f[u];delete this.state[o][c][p]}s[c]=this.state[o][c]}r[o]=r[o]||{},h(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var d in t)t[d].setFeatureState(r,e)};var Hl=function(t,e,r){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=e||new cn(ei,16,0),this.grid3D=new cn(ei,16,0),this.featureIndexArray=r||new Ca};function Gl(t){for(var e=1/0,r=1/0,n=-1/0,a=-1/0,i=0,o=t;i<o.length;i+=1){var s=o[i];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),a=Math.max(a,s.y)}return{minX:e,minY:r,maxX:n,maxY:a}}function Yl(t,e){return e-t}Hl.prototype.insert=function(t,e,r,n,a,i){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,a);for(var s=i?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],h=0;h<c.length;h++){var f=c[h];u[0]=Math.min(u[0],f.x),u[1]=Math.min(u[1],f.y),u[2]=Math.max(u[2],f.x),u[3]=Math.max(u[3],f.y)}u[0]<ei&&u[1]<ei&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},Hl.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new Io.VectorTile(new tl(this.rawTileData)).layers,this.sourceLayerCoder=new jl(this.vtLayers?Object.keys(this.vtLayers).sort():["_geojsonTileLayer"])),this.vtLayers},Hl.prototype.query=function(t,e,r){var n=this;this.loadVTLayers();for(var i=t.params||{},o=ei/t.tileSize/t.scale,s=Rr(i.filter),l=t.queryGeometry,c=t.queryPadding*o,u=Gl(l),h=this.grid.query(u.minX-c,u.minY-c,u.maxX+c,u.maxY+c),f=Gl(t.cameraQueryGeometry),p=0,d=this.grid3D.query(f.minX-c,f.minY-c,f.maxX+c,f.maxY+c,function(e,r,n,i){return function(t,e,r,n,i){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&i>=l.y)return!0}var c=[new a(e,r),new a(e,i),new a(n,i),new a(n,r)];if(t.length>2)for(var u=0,h=c;u<h.length;u+=1)if(gi(t,h[u]))return!0;for(var f=0;f<t.length-1;f++)if(vi(t[f],t[f+1],c))return!0;return!1}(t.cameraQueryGeometry,e-c,r-c,n+c,i+c)});p<d.length;p+=1){var g=d[p];h.push(g)}h.sort(Yl);for(var v,m={},y=function(a){var c=h[a];if(c!==v){v=c;var u=n.featureIndexArray.get(c),f=null;n.loadMatchingFeature(m,u.bucketIndex,u.sourceLayerIndex,u.featureIndex,s,i.layers,e,function(e,a){f||(f=ni(e));var i={};return e.id&&(i=r.getState(a.sourceLayer||"_geojsonTileLayer",e.id)),a.queryIntersectsFeature(l,e,i,f,n.z,t.transform,o,t.pixelPosMatrix)})}},x=0;x<h.length;x++)y(x);return m},Hl.prototype.loadMatchingFeature=function(t,e,r,n,a,i,o,s){var l=this.bucketLayerIDs[e];if(!i||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(i,l)){var c=this.sourceLayerCoder.decode(r),u=this.vtLayers[c].feature(n);if(a(new Pn(this.tileID.overscaledZ),u))for(var h=0;h<l.length;h++){var f=l[h];if(!(i&&i.indexOf(f)<0)){var p=o[f];if(p){var d=!s||s(u,p);if(d){var g=new Vl(u,this.z,this.x,this.y);g.layer=p.serialize();var v=t[f];void 0===v&&(v=t[f]=[]),v.push({featureIndex:n,feature:g,intersectionZ:d})}}}}}},Hl.prototype.lookupSymbolFeatures=function(t,e,r,n,a,i){var o={};this.loadVTLayers();for(var s=Rr(n),l=0,c=t;l<c.length;l+=1){var u=c[l];this.loadMatchingFeature(o,e,r,u,s,a,i)}return o},Hl.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,a=r[e];n<a.length;n+=1)if(t===a[n])return!0;return!1},dn("FeatureIndex",Hl,{omit:["rawTileData","sourceLayerCoder"]});var Wl=function(t,e){this.tileID=t,this.uid=p(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.expiredRequestCount=0,this.state="loading"};function Xl(t,e,r,n,a){if(void 0===e.segment)return!0;for(var i=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(i),i=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o-1],h=t[o],f=t[o+1];if(!f)return!1;var p=u.angleTo(h)-h.angleTo(f);for(p=Math.abs((p+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:p}),c+=p;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>a)return!1;o++,s+=h.dist(f)}return!0}function Zl(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function Jl(t,e,r){return t?.6*e*r:0}function Kl(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function Ql(t,e,r,n,a,i){for(var o=Jl(r,a,i),s=Kl(r,n)*i,l=0,c=Zl(t)/2,u=0;u<t.length-1;u++){var h=t[u],f=t[u+1],p=h.dist(f);if(l+p>c){var d=(c-l)/p,g=ye(h.x,f.x,d),v=ye(h.y,f.y,d),m=new bs(g,v,f.angleTo(h),u);return m._round(),!o||Xl(t,m,s,o,e)?m:void 0}l+=p}}function $l(t,e,r,n,a,i,o,s,l){var c=Jl(n,i,o),u=Kl(n,a),h=u*o,f=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-h<e/4&&(e=h+e/4),function t(e,r,n,a,i,o,s,l,c){for(var u=o/2,h=Zl(e),f=0,p=r-n,d=[],g=0;g<e.length-1;g++){for(var v=e[g],m=e[g+1],y=v.dist(m),x=m.angleTo(v);p+n<f+y;){var b=((p+=n)-f)/y,_=ye(v.x,m.x,b),w=ye(v.y,m.y,b);if(_>=0&&_<c&&w>=0&&w<c&&p-u>=0&&p+u<=h){var k=new bs(_,w,x,g);k._round(),a&&!Xl(e,k,o,a,i)||d.push(k)}}f+=y}return l||d.length||s||(d=t(e,f/2,n,a,i,o,s,!0,c)),d}(t,f?e/2*s%e:(u/2+2*i)*o*s%e,e,c,r,h,f,!1,l)}Wl.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<I.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},Wl.prototype.wasRequested=function(){return"errored"===this.state||"loaded"===this.state||"reloading"===this.state},Wl.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state="loaded",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=i[a],n=t.layerIds.map(function(t){return e.getLayer(t)}).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map(function(t){return n.filter(function(e){return e.id===t})[0]}));for(var o=0,s=n;o<s.length;o+=1){var l=s[o];r[l.id]=t}}},a=0,i=t;a<i.length;a+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var a=this.buckets[n];if(a instanceof Os){if(this.hasSymbolBuckets=!0,!r)break;a.justReloaded=!0}}for(var i in this.queryPadding=0,this.buckets){var o=this.buckets[i];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(i).queryRadius(o))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new ba},Wl.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state="unloaded"},Wl.prototype.unloadDEMData=function(){this.dem=null,this.neighboringTiles=null,this.state="unloaded"},Wl.prototype.getBucket=function(t){return this.buckets[t.id]},Wl.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Ks(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Ks(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},Wl.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},Wl.prototype.queryRenderedFeatures=function(t,e,r,n,a,i,o,s,l){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:r,cameraQueryGeometry:n,scale:a,tileSize:this.tileSize,pixelPosMatrix:l,transform:o,params:i,queryPadding:this.queryPadding*s},t,e):{}},Wl.prototype.querySourceFeatures=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData){var r=this.latestFeatureIndex.loadVTLayers(),n=e?e.sourceLayer:"",a=r._geojsonTileLayer||r[n];if(a)for(var i=Rr(e&&e.filter),o=this.tileID.canonical,s=o.z,l=o.x,c=o.y,u={z:s,x:l,y:c},h=0;h<a.length;h++){var f=a.feature(h);if(i(new Pn(this.tileID.overscaledZ),f)){var p=new Vl(f,s,l,c);p.tile=u,t.push(p)}}}},Wl.prototype.clearMask=function(){this.segments&&(this.segments.destroy(),delete this.segments),this.maskedBoundsBuffer&&(this.maskedBoundsBuffer.destroy(),delete this.maskedBoundsBuffer),this.maskedIndexBuffer&&(this.maskedIndexBuffer.destroy(),delete this.maskedIndexBuffer)},Wl.prototype.setMask=function(t,e){if(!o(this.mask,t)&&(this.mask=t,this.clearMask(),!o(t,{0:!0}))){var r=new $n,n=new da;this.segments=new Oa,this.segments.prepareSegment(0,r,n);for(var i=Object.keys(t),s=0;s<i.length;s++){var l=t[+i[s]],c=ei>>l.z,u=new a(l.x*c,l.y*c),h=new a(u.x+c,u.y+c),f=this.segments.prepareSegment(4,r,n);r.emplaceBack(u.x,u.y,u.x,u.y),r.emplaceBack(h.x,u.y,h.x,u.y),r.emplaceBack(u.x,h.y,u.x,h.y),r.emplaceBack(h.x,h.y,h.x,h.y);var p=f.vertexLength;n.emplaceBack(p,p+1,p+2),n.emplaceBack(p+1,p+2,p+3),f.vertexLength+=4,f.primitiveLength+=2}this.maskedBoundsBuffer=e.createVertexBuffer(r,Nl.members),this.maskedIndexBuffer=e.createIndexBuffer(n)}},Wl.prototype.hasData=function(){return"loaded"===this.state||"reloading"===this.state||"expired"===this.state},Wl.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},Wl.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=M(t.cacheControl);r["max-age"]&&(this.expirationTime=Date.now()+1e3*r["max-age"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),a=!1;if(this.expirationTime>n)a=!1;else if(e)if(this.expirationTime<e)a=!0;else{var i=this.expirationTime-e;i?this.expirationTime=n+Math.max(i,3e4):a=!0}else a=!0;a?(this.expiredRequestCount++,this.state="expired"):this.expiredRequestCount=0}},Wl.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},Wl.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets){var a=this.buckets[n],i=a.layers[0].sourceLayer||"_geojsonTileLayer",o=r[i],s=t[i];o&&s&&0!==Object.keys(s).length&&(a.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{}),e&&e.style&&(this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(n).queryRadius(a))))}}},Wl.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},Wl.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<I.now()},Wl.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},Wl.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=I.now()+t};var tc=function(t,e,r,n,i,o,s,l,c,u,h,f){var p=s.top*l-c,d=s.bottom*l+c,g=s.left*l-c,v=s.right*l+c;if(this.boxStartIndex=t.length,u){var m=d-p,y=v-g;m>0&&(m=Math.max(10*l,m),this._addLineCollisionCircles(t,e,r,r.segment,y,m,n,i,o,h))}else{if(f){var x=new a(g,p),b=new a(v,p),_=new a(g,d),w=new a(v,d),k=f*Math.PI/180;x._rotate(k),b._rotate(k),_._rotate(k),w._rotate(k),g=Math.min(x.x,b.x,_.x,w.x),v=Math.max(x.x,b.x,_.x,w.x),p=Math.min(x.y,b.y,_.y,w.y),d=Math.max(x.y,b.y,_.y,w.y)}t.emplaceBack(r.x,r.y,g,p,v,d,n,i,o,0,0)}this.boxEndIndex=t.length};tc.prototype._addLineCollisionCircles=function(t,e,r,n,a,i,o,s,l,c){var u=i/2,h=Math.floor(a/u)||1,f=1+.4*Math.log(c)/Math.LN2,p=Math.floor(h*f/2),d=-i/2,g=r,v=n+1,m=d,y=-a/2,x=y-a/4;do{if(--v<0){if(m>y)return;v=0;break}m-=e[v].dist(g),g=e[v]}while(m>x);for(var b=e[v].dist(e[v+1]),_=-p;_<h+p;_++){var w=_*u,k=y+w;if(w<0&&(k+=w),w>a&&(k+=w-a),!(k<m)){for(;m+b<k;){if(m+=b,++v+1>=e.length)return;b=e[v].dist(e[v+1])}var T=k-m,M=e[v],A=e[v+1].sub(M)._unit()._mult(T)._add(M)._round(),S=Math.abs(k-d)<u?0:.8*(k-d);t.emplaceBack(A.x,A.y,-i/2,-i/2,i/2,i/2,o,s,l,i/2,S)}}};var ec=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=rc),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function rc(t,e){return t<e?-1:t>e?1:0}function nc(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,i=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<i)&&(i=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var h=o-n,f=s-i,p=Math.min(h,f),d=p/2,g=new ec([],ac);if(0===p)return new a(n,i);for(var v=n;v<o;v+=p)for(var m=i;m<s;m+=p)g.push(new ic(v+d,m+d,d,t));for(var y=function(t){for(var e=0,r=0,n=0,a=t[0],i=0,o=a.length,s=o-1;i<o;s=i++){var l=a[i],c=a[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new ic(r/e,n/e,0,t)}(t),x=g.length;g.length;){var b=g.pop();(b.d>y.d||!y.d)&&(y=b,r&&console.log("found best %d after %d probes",Math.round(1e4*b.d)/1e4,x)),b.max-y.d<=e||(d=b.h/2,g.push(new ic(b.p.x-d,b.p.y-d,d,t)),g.push(new ic(b.p.x+d,b.p.y-d,d,t)),g.push(new ic(b.p.x-d,b.p.y+d,d,t)),g.push(new ic(b.p.x+d,b.p.y+d,d,t)),x+=4)}return r&&(console.log("num probes: "+x),console.log("best distance: "+y.d)),y.p}function ac(t,e){return e.max-t.max}function ic(t,e,r,n){this.p=new a(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,a=0;a<e.length;a++)for(var i=e[a],o=0,s=i.length,l=s-1;o<s;l=o++){var c=i[o],u=i[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,pi(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}ec.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},ec.prototype.pop=function(){if(0!==this.length){var t=this.data[0],e=this.data.pop();return this.length--,this.length>0&&(this.data[0]=e,this._down(0)),t}},ec.prototype.peek=function(){return this.data[0]},ec.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var a=t-1>>1,i=e[a];if(r(n,i)>=0)break;e[t]=i,t=a}e[t]=n},ec.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,a=e[t];t<n;){var i=1+(t<<1),o=e[i],s=i+1;if(s<this.length&&r(e[s],o)<0&&(i=s,o=e[s]),r(o,a)>=0)break;e[t]=o,t=i}e[t]=a};var oc=e(function(t){t.exports=function(t,e){var r,n,a,i,o,s,l,c;for(r=3&t.length,n=t.length-r,a=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,a=27492+(65535&(i=5*(65535&(a=(a^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|a>>>19))+((5*(a>>>16)&65535)<<16)&4294967295))+((58964+(i>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:a^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return a^=t.length,a=2246822507*(65535&(a^=a>>>16))+((2246822507*(a>>>16)&65535)<<16)&4294967295,a=3266489909*(65535&(a^=a>>>13))+((3266489909*(a>>>16)&65535)<<16)&4294967295,(a^=a>>>16)>>>0}}),sc=e(function(t){t.exports=function(t,e){for(var r,n=t.length,a=e^n,i=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(i)|(255&t.charCodeAt(++i))<<8|(255&t.charCodeAt(++i))<<16|(255&t.charCodeAt(++i))<<24))+((1540483477*(r>>>16)&65535)<<16),a=1540483477*(65535&a)+((1540483477*(a>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++i;switch(n){case 3:a^=(255&t.charCodeAt(i+2))<<16;case 2:a^=(255&t.charCodeAt(i+1))<<8;case 1:a=1540483477*(65535&(a^=255&t.charCodeAt(i)))+((1540483477*(a>>>16)&65535)<<16)}return a=1540483477*(65535&(a^=a>>>13))+((1540483477*(a>>>16)&65535)<<16),(a^=a>>>15)>>>0}}),lc=oc,cc=oc,uc=sc;lc.murmur3=cc,lc.murmur2=uc;var hc=7;function fc(t,e){var r=0,n=0,a=e/Math.sqrt(2);switch(t){case"top-right":case"top-left":n=a-hc;break;case"bottom-right":case"bottom-left":n=-a+hc;break;case"bottom":n=-e+hc;break;case"top":n=e-hc}switch(t){case"top-right":case"bottom-right":r=-a;break;case"top-left":case"bottom-left":r=a;break;case"left":r=e;break;case"right":r=-e}return[r,n]}function pc(t){switch(t){case"right":case"top-right":case"bottom-right":return"right";case"left":case"top-left":case"bottom-left":return"left"}return"center"}var dc=65535;function gc(t,e,r,n,i,o,s,l,c,u,h,f,p){var d=function(t,e,r,n,i,o,s,l){for(var c=n.layout.get("text-rotate").evaluate(o,{})*Math.PI/180,u=e.positionedGlyphs,h=[],f=0;f<u.length;f++){var p=u[f],d=s[p.fontStack],g=d&&d[p.glyph];if(g){var v=g.rect;if(v){var m=_l+1,y=g.metrics.advance*p.scale/2,x=i?[p.x+y,p.y]:[0,0],b=i?[0,0]:[p.x+y+r[0],p.y+r[1]],_=(i||l)&&p.vertical,w=[0,0];_&&(w=b,b=[0,0]);var k=(g.metrics.left-m)*p.scale-y+b[0],T=(-g.metrics.top-m)*p.scale+b[1],M=k+v.w*p.scale,A=T+v.h*p.scale,S=new a(k,T),E=new a(M,T),L=new a(k,A),C=new a(M,A);if(_){var P=new a(-y,y-e.yOffset),O=-Math.PI/2,z=ls/2-y,I=new a(5-e.yOffset-z,0),D=new(Function.prototype.bind.apply(a,[null].concat(w)));S._rotateAround(O,P)._add(I)._add(D),E._rotateAround(O,P)._add(I)._add(D),L._rotateAround(O,P)._add(I)._add(D),C._rotateAround(O,P)._add(I)._add(D)}if(c){var R=Math.sin(c),F=Math.cos(c),B=[F,-R,R,F];S._matMult(B),E._matMult(B),L._matMult(B),C._matMult(B)}h.push({tl:S,tr:E,bl:L,br:C,tex:v,writingMode:e.writingMode,glyphOffset:x,sectionIndex:p.sectionIndex})}}}return h}(0,r,s,n,i,o,f,t.allowVerticalPlacement),g=t.textSizeData,v=null;"source"===g.kind?(v=[_s*n.layout.get("text-size").evaluate(o,{})])[0]>dc&&w(t.layerIds[0]+': Value for "text-size" is >= 256. Reduce your "text-size".'):"composite"===g.kind&&((v=[_s*p.compositeTextSizes[0].evaluate(o,{}),_s*p.compositeTextSizes[1].evaluate(o,{})])[0]>dc||v[1]>dc)&&w(t.layerIds[0]+': Value for "text-size" is >= 256. Reduce your "text-size".'),t.addSymbols(t.text,d,v,s,i,o,c,e,l.lineStartIndex,l.lineLength);for(var m=0,y=u;m<y.length;m+=1)h[y[m]]=t.text.placedSymbolArray.length-1;return 4*d.length}function vc(t){for(var e in t)return t[e];return null}function mc(t,e,r,n){var a=t.compareText;if(e in a){for(var i=a[e],o=i.length-1;o>=0;o--)if(n.dist(i[o])<r)return!0}else a[e]=[];return a[e].push(n),!1}t.Actor=kl,t.AlphaImage=Pi,t.CanonicalTileID=Il,t.CollisionBoxArray=ba,t.Color=Wt,t.DEMData=Bl,t.DataConstantProperty=jn,t.DictionaryCoder=jl,t.EXTENT=ei,t.ErrorEvent=wt,t.EvaluationParameters=Pn,t.Event=_t,t.Evented=kt,t.FeatureIndex=Hl,t.FillBucket=_o,t.FillExtrusionBucket=Bo,t.ImageAtlas=Ys,t.ImagePosition=Hs,t.LineBucket=Zo,t.LngLat=Al,t.LngLatBounds=Ml,t.MercatorCoordinate=zl,t.ONE_EM=ls,t.OverscaledTileID=Rl,t.Point=a,t.Point$1=a,t.ProgramConfiguration=Ka,t.Properties=Gn,t.Protobuf=tl,t.RGBAImage=Oi,t.RequestManager=V,t.ResourceType=lt,t.SegmentVector=Oa,t.SourceFeatureState=ql,t.StructArrayLayout1ui2=va,t.StructArrayLayout2i4=Qn,t.StructArrayLayout2ui4=ga,t.StructArrayLayout3ui6=da,t.StructArrayLayout4i8=$n,t.SymbolBucket=Os,t.Texture=Ks,t.Tile=Wl,t.Transitionable=In,t.Uniform1f=Ba,t.Uniform1i=Fa,t.Uniform2f=Na,t.Uniform3f=ja,t.Uniform4f=Va,t.UniformColor=Ua,t.UniformMatrix4f=Ha,t.UnwrappedTileID=Dl,t.ValidationError=Mt,t.WritingMode=cs,t.ZoomHistory=yn,t.addDynamicAttributes=Ls,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,a=new Array(t.length),i=null;t.forEach(function(t,o){e(t,function(t,e){t&&(i=t),a[o]=e,0==--n&&r(i,a)})})},t.bezier=s,t.bindAll=v,t.browser=I,t.cacheEntryPossiblyAdded=function(t){++st>at&&(t.getActor().send("enforceCacheSizeLimit",nt),st=0)},t.clamp=c,t.clearTileCache=function(t){var e=self.caches.delete(rt);t&&e.catch(t).then(function(){return t()})},t.clone=function(t){var e=new ki(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=b,t.config=D,t.create=function(){var t=new ki(16);return ki!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=function(){var t=new ki(9);return ki!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t},t.create$2=function(){var t=new ki(4);return ki!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=kr,t.createLayout=Jn,t.createStyleLayer=function(t){return"custom"===t.type?new Vs(t):new Us[t.type](t)},t.deepEqual=o,t.ease=l,t.emitValidationErrors=ln,t.endsWith=m,t.enforceCacheSizeLimit=function(t){self.caches&&self.caches.open(rt).then(function(e){e.keys().then(function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])})})},t.evaluateRadialOffset=fc,t.evaluateSizeForFeature=ks,t.evaluateSizeForZoom=Ts,t.evented=Ln,t.extend=h,t.featureFilter=Rr,t.filterObject=x,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=ys,t.getAnchorJustification=pc,t.getArrayBuffer=vt,t.getImage=yt,t.getJSON=function(t,e){return gt(h(t,{type:"json"}),e)},t.getReferrer=ht,t.getVideo=function(t,e){var r,n,a=self.document.createElement("video");a.muted=!0,a.onloadstart=function(){e(null,a)};for(var i=0;i<t.length;i++){var o=self.document.createElement("source");r=t[i],n=void 0,(n=self.document.createElement("a")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(a.crossOrigin="Anonymous"),o.src=t[i],a.appendChild(o)}return{cancel:function(){}}},t.identity=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t},t.invert=function(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-a*o,b=r*c-i*o,_=n*l-a*s,w=n*c-i*s,k=a*c-i*l,T=u*g-h*d,M=u*v-f*d,A=u*m-p*d,S=h*v-f*g,E=h*m-p*g,L=f*m-p*v,C=y*L-x*E+b*S+_*A-w*M+k*T;return C?(C=1/C,t[0]=(s*L-l*E+c*S)*C,t[1]=(a*E-n*L-i*S)*C,t[2]=(g*k-v*w+m*_)*C,t[3]=(f*w-h*k-p*_)*C,t[4]=(l*A-o*L-c*M)*C,t[5]=(r*L-a*A+i*M)*C,t[6]=(v*b-d*k-m*x)*C,t[7]=(u*k-f*b+p*x)*C,t[8]=(o*E-s*A+c*T)*C,t[9]=(n*A-r*E-i*T)*C,t[10]=(d*w-g*b+m*y)*C,t[11]=(h*b-u*w-p*y)*C,t[12]=(s*M-o*S-l*T)*C,t[13]=(r*S-n*M+a*T)*C,t[14]=(g*x-d*_-v*y)*C,t[15]=(u*_-h*x+f*y)*C,t):null},t.isChar=xn,t.isMapboxURL=U,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=gt,t.mapObject=y,t.mercatorXfromLng=Ll,t.mercatorYfromLat=Cl,t.mercatorZfromAltitude=Pl,t.multiply=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*a+b*l+_*f+w*v,t[2]=x*i+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*a+b*l+_*f+w*v,t[6]=x*i+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*a+b*l+_*f+w*v,t[10]=x*i+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*a+b*l+_*f+w*v,t[14]=x*i+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t},t.mvt=Io,t.number=ye,t.ortho=function(t,e,r,n,a,i,o){var s=1/(e-r),l=1/(n-a),c=1/(i-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(a+n)*l,t[14]=(o+i)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new tl(t).readFields(yl,[])},t.pbf=tl,t.performSymbolLayout=function(t,e,r,n,i,o){t.createArrays();var s=512*t.overscaling;t.tilePixelRatio=ei/s,t.compareText={},t.iconsNeedLinear=!1;var l=t.layers[0].layout,c=t.layers[0]._unevaluatedLayout._values,u={};if("composite"===t.textSizeData.kind){var h=t.textSizeData,f=h.minZoom,p=h.maxZoom;u.compositeTextSizes=[c["text-size"].possiblyEvaluate(new Pn(f)),c["text-size"].possiblyEvaluate(new Pn(p))]}if("composite"===t.iconSizeData.kind){var d=t.iconSizeData,g=d.minZoom,v=d.maxZoom;u.compositeIconSizes=[c["icon-size"].possiblyEvaluate(new Pn(g)),c["icon-size"].possiblyEvaluate(new Pn(v))]}u.layoutTextSize=c["text-size"].possiblyEvaluate(new Pn(t.zoom+1)),u.layoutIconSize=c["icon-size"].possiblyEvaluate(new Pn(t.zoom+1)),u.textMaxSize=c["text-size"].possiblyEvaluate(new Pn(18));for(var m=l.get("text-line-height")*ls,y="map"===l.get("text-rotation-alignment")&&"point"!==l.get("symbol-placement"),x=l.get("text-keep-upright"),b=function(){var o=k[_],s=l.get("text-font").evaluate(o,{}).join(","),c=r,h={horizontal:{},vertical:void 0},f=o.text,p=[0,0];if(f){var d=f.toString(),g=l.get("text-letter-spacing").evaluate(o,{})*ls,v=function(t){for(var e=0,r=d;e<r.length;e+=1)if(!_n(r[e].charCodeAt(0)))return!1;return!0}()?g:0,b=l.get("text-anchor").evaluate(o,{}),T=l.get("text-variable-anchor"),M=l.get("text-radial-offset").evaluate(o,{});T||(p=M?fc(b,M*ls):l.get("text-offset").evaluate(o,{}).map(function(t){return t*ls}));var A=y?"center":l.get("text-justify").evaluate(o,{}),S="point"===l.get("symbol-placement")?l.get("text-max-width").evaluate(o,{})*ls:0,E=function(){t.allowVerticalPlacement&&bn(d)&&(h.vertical=hs(f,e,s,S,m,b,"left",v,p,cs.vertical,!0))};if(!y&&T){for(var L="auto"===A?T.map(function(t){return pc(t)}):[A],C=!1,P=0;P<L.length;P++){var O=L[P];if(!h.horizontal[O])if(C)h.horizontal[O]=h.horizontal[0];else{var z=hs(f,e,s,S,m,"center",O,v,p,cs.horizontal,!1);z&&(h.horizontal[O]=z,C=1===z.lineCount)}}E()}else{"auto"===A&&(A=pc(b));var I=hs(f,e,s,S,m,b,A,v,p,cs.horizontal,!1);I&&(h.horizontal[A]=I),E(),bn(d)&&y&&x&&(h.vertical=hs(f,e,s,S,m,b,A,v,p,cs.vertical,!1))}}var D=void 0;if(o.icon){var R=n[o.icon];R&&(D=function(t,e,r){var n=ys(r),a=n.horizontalAlign,i=n.verticalAlign,o=e[0],s=e[1],l=o-t.displaySize[0]*a,c=l+t.displaySize[0],u=s-t.displaySize[1]*i;return{image:t,top:u,bottom:u+t.displaySize[1],left:l,right:c}}(i[o.icon],l.get("icon-offset").evaluate(o,{}),l.get("icon-anchor").evaluate(o,{})),void 0===t.sdfIcons?t.sdfIcons=R.sdf:t.sdfIcons!==R.sdf&&w("Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer"),R.pixelRatio!==t.pixelRatio?t.iconsNeedLinear=!0:0!==l.get("icon-rotate").constantOr(1)&&(t.iconsNeedLinear=!0))}(Object.keys(h.horizontal).length||D)&&function(t,e,r,n,i,o,s){var l=o.layoutTextSize.evaluate(e,{}),c=o.layoutIconSize.evaluate(e,{}),u=o.textMaxSize.evaluate(e,{});void 0===u&&(u=l);var h=t.layers[0].layout,f=h.get("icon-offset").evaluate(e,{}),p=vc(r.horizontal),d=l/24,g=t.tilePixelRatio*d,v=t.tilePixelRatio*u/24,m=t.tilePixelRatio*c,y=t.tilePixelRatio*h.get("symbol-spacing"),x=h.get("text-padding")*t.tilePixelRatio,b=h.get("icon-padding")*t.tilePixelRatio,_=h.get("text-max-angle")/180*Math.PI,k="map"===h.get("text-rotation-alignment")&&"point"!==h.get("symbol-placement"),T="map"===h.get("icon-rotation-alignment")&&"point"!==h.get("symbol-placement"),M=h.get("symbol-placement"),A=y/2,S=function(l,c){c.x<0||c.x>=ei||c.y<0||c.y>=ei||function(t,e,r,n,i,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_){var k,T,M,A=t.addToLineVertexArray(e,r),S=0,E=0,L=0,C={},P=lc(""),O=(o.layout.get("text-radial-offset").evaluate(x,{})||0)*ls;if(t.allowVerticalPlacement&&n.vertical){var z=o.layout.get("text-rotate").evaluate(x,{})+90,I=n.vertical;M=new tc(s,r,e,l,c,u,I,h,f,p,t.overscaling,z)}for(var D in n.horizontal){var R=n.horizontal[D];if(!k){P=lc(R.text);var F=o.layout.get("text-rotate").evaluate(x,{});k=new tc(s,r,e,l,c,u,R,h,f,p,t.overscaling,F)}var B=1===R.lineCount;if(E+=gc(t,e,R,o,p,x,d,A,n.vertical?cs.horizontal:cs.horizontalOnly,B?Object.keys(n.horizontal):[D],C,b,_),B)break}n.vertical&&(L+=gc(t,e,n.vertical,o,p,x,d,A,cs.vertical,["vertical"],C,b,_));var N=k?k.boxStartIndex:t.collisionBoxArray.length,j=k?k.boxEndIndex:t.collisionBoxArray.length,V=M?M.boxStartIndex:t.collisionBoxArray.length,U=M?M.boxEndIndex:t.collisionBoxArray.length;if(i){var q=function(t,e,r,n,i,o){var s,l,c,u,h=e.image,f=r.layout,p=e.top-1/h.pixelRatio,d=e.left-1/h.pixelRatio,g=e.bottom+1/h.pixelRatio,v=e.right+1/h.pixelRatio;if("none"!==f.get("icon-text-fit")&&i){var m=v-d,y=g-p,x=f.get("text-size").evaluate(o,{})/24,b=i.left*x,_=i.right*x,w=i.top*x,k=_-b,T=i.bottom*x-w,M=f.get("icon-text-fit-padding")[0],A=f.get("icon-text-fit-padding")[1],S=f.get("icon-text-fit-padding")[2],E=f.get("icon-text-fit-padding")[3],L="width"===f.get("icon-text-fit")?.5*(T-y):0,C="height"===f.get("icon-text-fit")?.5*(k-m):0,P="width"===f.get("icon-text-fit")||"both"===f.get("icon-text-fit")?k:m,O="height"===f.get("icon-text-fit")||"both"===f.get("icon-text-fit")?T:y;s=new a(b+C-E,w+L-M),l=new a(b+C+A+P,w+L-M),c=new a(b+C+A+P,w+L+S+O),u=new a(b+C-E,w+L+S+O)}else s=new a(d,p),l=new a(v,p),c=new a(v,g),u=new a(d,g);var z=r.layout.get("icon-rotate").evaluate(o,{})*Math.PI/180;if(z){var I=Math.sin(z),D=Math.cos(z),R=[D,-I,I,D];s._matMult(R),l._matMult(R),u._matMult(R),c._matMult(R)}return[{tl:s,tr:l,bl:u,br:c,tex:h.paddedRect,writingMode:void 0,glyphOffset:[0,0],sectionIndex:0}]}(0,i,o,0,vc(n.horizontal),x),H=o.layout.get("icon-rotate").evaluate(x,{});T=new tc(s,r,e,l,c,u,i,g,v,!1,t.overscaling,H),S=4*q.length;var G=t.iconSizeData,Y=null;"source"===G.kind?(Y=[_s*o.layout.get("icon-size").evaluate(x,{})])[0]>dc&&w(t.layerIds[0]+': Value for "icon-size" is >= 256. Reduce your "icon-size".'):"composite"===G.kind&&((Y=[_s*_.compositeIconSizes[0].evaluate(x,{}),_s*_.compositeIconSizes[1].evaluate(x,{})])[0]>dc||Y[1]>dc)&&w(t.layerIds[0]+': Value for "icon-size" is >= 256. Reduce your "icon-size".'),t.addSymbols(t.icon,q,Y,y,m,x,!1,e,A.lineStartIndex,A.lineLength)}var W=T?T.boxStartIndex:t.collisionBoxArray.length,X=T?T.boxEndIndex:t.collisionBoxArray.length;t.glyphOffsetArray.length>=Os.MAX_GLYPHS&&w("Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907"),t.symbolInstances.emplaceBack(e.x,e.y,C.right>=0?C.right:-1,C.center>=0?C.center:-1,C.left>=0?C.left:-1,C.vertical||-1,P,N,j,V,U,W,X,l,E,L,S,0,h,O)}(t,c,l,r,n,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,g,x,k,s,m,b,T,f,e,i,o)};if("line"===M)for(var E=0,L=function(t,e,r,n,i){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var h=l[u],f=l[u+1];h.x<0&&f.x<0||(h.x<0?h=new a(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round():f.x<0&&(f=new a(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round()),h.y<0&&f.y<0||(h.y<0?h=new a(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round():f.y<0&&(f=new a(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round()),h.x>=n&&f.x>=n||(h.x>=n?h=new a(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round():f.x>=n&&(f=new a(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round()),h.y>=i&&f.y>=i||(h.y>=i?h=new a(h.x+(f.x-h.x)*((i-h.y)/(f.y-h.y)),i)._round():f.y>=i&&(f=new a(h.x+(f.x-h.x)*((i-h.y)/(f.y-h.y)),i)._round()),c&&h.equals(c[c.length-1])||(c=[h],o.push(c)),c.push(f)))))}return o}(e.geometry,0,0,ei,ei);E<L.length;E+=1)for(var C=L[E],P=0,O=$l(C,y,_,r.vertical||p,n,24,v,t.overscaling,ei);P<O.length;P+=1){var z=O[P];p&&mc(t,p.text,A,z)||S(C,z)}else if("line-center"===M)for(var I=0,D=e.geometry;I<D.length;I+=1){var R=D[I];if(R.length>1){var F=Ql(R,_,r.vertical||p,n,24,v);F&&S(R,F)}}else if("Polygon"===e.type)for(var B=0,N=mo(e.geometry,0);B<N.length;B+=1){var j=N[B],V=nc(j,16);S(j[0],new bs(V.x,V.y,0))}else if("LineString"===e.type)for(var U=0,q=e.geometry;U<q.length;U+=1){var H=q[U];S(H,new bs(H[0].x,H[0].y,0))}else if("Point"===e.type)for(var G=0,Y=e.geometry;G<Y.length;G+=1)for(var W=0,X=Y[G];W<X.length;W+=1){var Z=X[W];S([Z],new bs(Z.x,Z.y,0))}}(t,o,h,D,c,u,p)},_=0,k=t.features;_<k.length;_+=1)b();o&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,a){var i,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=a&&a!==1/0?(i=1/(n-a),t[10]=(a+n)*i,t[14]=2*a*n*i):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var a=e[n];a in t&&(r[a]=t[a])}return r},t.plugin=Cn,t.polygonIntersectsPolygon=oi,t.postMapLoadEvent=et,t.postTurnstileEvent=$,t.potpack=qs,t.rasterBoundsAttributes=Nl,t.refProperties=["type","source","source-layer","minzoom","maxzoom","filter","layout"],t.register=dn,t.registerForPluginAvailability=function(t){return Sn?t({pluginURL:Sn,completionCallback:Mn}):Ln.once("pluginAvailable",t),t},t.rotate=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+i*s,t[1]=a*l+o*s,t[2]=n*-s+i*l,t[3]=a*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),a=Math.cos(r),i=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=i*a+c*n,t[5]=o*a+u*n,t[6]=s*a+h*n,t[7]=l*a+f*n,t[8]=c*a-i*n,t[9]=u*a-o*n,t[10]=h*a-s*n,t[11]=f*a-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),a=Math.cos(r),i=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=i*a+c*n,t[1]=o*a+u*n,t[2]=s*a+h*n,t[3]=l*a+f*n,t[4]=c*a-i*n,t[5]=u*a-o*n,t[6]=h*a-s*n,t[7]=f*a-l*n,t},t.scale=function(t,e,r){var n=r[0],a=r[1],i=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*a,t[5]=e[5]*a,t[6]=e[6]*a,t[7]=e[7]*a,t[8]=e[8]*i,t[9]=e[9]*i,t[10]=e[10]*i,t[11]=e[11]*i,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.setCacheLimits=function(t,e){nt=t,at=e},t.setRTLTextPlugin=function(t,e){if(An)throw new Error("setRTLTextPlugin cannot be called multiple times.");An=!0,Sn=I.resolveURL(t),Mn=function(t){t?(An=!1,Sn=null,e&&e(t)):En=!0},Ln.fire(new _t("pluginAvailable",{pluginURL:Sn,completionCallback:Mn}))},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.styleSpec=Tt,t.symbolSize=Ms,t.transformMat3=function(t,e,r){var n=e[0],a=e[1],i=e[2];return t[0]=n*r[0]+a*r[3]+i*r[6],t[1]=n*r[1]+a*r[4]+i*r[7],t[2]=n*r[2]+a*r[5]+i*r[8],t},t.transformMat4=Ti,t.translate=function(t,e,r){var n,a,i,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];return e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],a=e[1],i=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=a,t[2]=i,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=a*g+l*v+f*m+e[13],t[14]=i*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]),t},t.uniqueId=p,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:"layers."+r+': missing required property "id"'}),void 0===t.render&&e.push({message:"layers."+r+': missing required method "render"'}),t.renderingMode&&"2d"!==t.renderingMode&&"3d"!==t.renderingMode&&e.push({message:"layers."+r+': property "renderingMode" must be either "2d" or "3d"'}),e},t.validateLight=an,t.validateStyle=nn,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=Io,t.version="1.3.2",t.warnOnce=w,t.webpSupported=R,t.window=self,t.wrap=u}),n(0,function(t){function e(t){var r=typeof t;if("number"===r||"boolean"===r||"string"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n="[",a=0,i=t;a<i.length;a+=1)n+=e(i[a])+",";return n+"]"}for(var o=Object.keys(t).sort(),s="{",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+":"+e(t[o[l]])+",";return s+"}"}function r(r){for(var n="",a=0,i=t.refProperties;a<i.length;a+=1)n+="/"+e(r[i[a]]);return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var a=this,i=0,o=e;i<o.length;i+=1){var s=o[i];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var h=u[c];delete this.keyCache[h],delete this._layerConfigs[h],delete this._layers[h]}this.familiesBySource={};for(var f=0,p=function(t,e){for(var n={},a=0;a<t.length;a++){var i=e&&e[t[a].id]||r(t[a]);e&&(e[t[a].id]=i);var o=n[i];o||(o=n[i]=[]),o.push(t[a])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);f<p.length;f+=1){var d=p[f].map(function(t){return a._layers[t.id]}),g=d[0];if("none"!==g.visibility){var v=g.source||"",m=this.familiesBySource[v];m||(m=this.familiesBySource[v]={});var y=g.sourceLayer||"_geojsonTileLayer",x=m[y];x||(x=m[y]=[]),x.push(d)}}};var a=function(e){var r={},n=[];for(var a in e){var i=e[a],o=r[a]={};for(var s in i){var l=i[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),h=u.w,f=u.h,p=new t.AlphaImage({width:h||1,height:f||1});for(var d in e){var g=e[d];for(var v in g){var m=g[+v];if(m&&0!==m.bitmap.width&&0!==m.bitmap.height){var y=r[d][v].rect;t.AlphaImage.copy(m.bitmap,p,{x:0,y:0},{x:y.x+1,y:y.y+1},m.bitmap)}}}this.image=p,this.positions=r};t.register("GlyphAtlas",a);var i=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies};function o(e,r){for(var n=new t.EvaluationParameters(r),a=0,i=e;a<i.length;a+=1)i[a].recalculate(n)}i.prototype.parse=function(e,r,n,i){var s=this;this.status="parsing",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var l=new t.DictionaryCoder(Object.keys(e.layers).sort()),c=new t.FeatureIndex(this.tileID);c.bucketLayerIDs=[];var u,h,f,p,d={},g={featureIndex:c,iconDependencies:{},patternDependencies:{},glyphDependencies:{}},v=r.familiesBySource[this.source];for(var m in v){var y=e.layers[m];if(y){1===y.version&&t.warnOnce('Vector tile source "'+this.source+'" layer "'+m+'" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var x=l.encode(m),b=[],_=0;_<y.length;_++){var w=y.feature(_);b.push({feature:w,index:_,sourceLayerIndex:x})}for(var k=0,T=v[m];k<T.length;k+=1){var M=T[k],A=M[0];A.minzoom&&this.zoom<Math.floor(A.minzoom)||A.maxzoom&&this.zoom>=A.maxzoom||"none"!==A.visibility&&(o(M,this.zoom),(d[A.id]=A.createBucket({index:c.bucketLayerIDs.length,layers:M,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:x,sourceID:this.source})).populate(b,g),c.bucketLayerIDs.push(M.map(function(t){return t.id})))}}}var S=t.mapObject(g.glyphDependencies,function(t){return Object.keys(t).map(Number)});Object.keys(S).length?n.send("getGlyphs",{uid:this.uid,stacks:S},function(t,e){u||(u=t,h=e,C.call(s))}):h={};var E=Object.keys(g.iconDependencies);E.length?n.send("getImages",{icons:E},function(t,e){u||(u=t,f=e,C.call(s))}):f={};var L=Object.keys(g.patternDependencies);function C(){if(u)return i(u);if(h&&f&&p){var e=new a(h),r=new t.ImageAtlas(f,p);for(var n in d){var s=d[n];s instanceof t.SymbolBucket?(o(s.layers,this.zoom),t.performSymbolLayout(s,h,e.positions,f,r.iconPositions,this.showCollisionBoxes)):s.hasPattern&&(s instanceof t.LineBucket||s instanceof t.FillBucket||s instanceof t.FillExtrusionBucket)&&(o(s.layers,this.zoom),s.addFeatures(g,r.patternPositions))}this.status="done",i(null,{buckets:t.values(d).filter(function(t){return!t.isEmpty()}),featureIndex:c,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?h:null,iconMap:this.returnDependencies?f:null,glyphPositions:this.returnDependencies?e.positions:null})}}L.length?n.send("getImages",{icons:L},function(t,e){u||(u=t,p=e,C.call(s))}):p={},C.call(this)};var s="undefined"!=typeof performance,l={getEntriesByName:function(t){return!!(s&&performance&&performance.getEntriesByName)&&performance.getEntriesByName(t)},mark:function(t){return!!(s&&performance&&performance.mark)&&performance.mark(t)},measure:function(t,e,r){return!!(s&&performance&&performance.measure)&&performance.measure(t,e,r)},clearMarks:function(t){return!!(s&&performance&&performance.clearMarks)&&performance.clearMarks(t)},clearMeasures:function(t){return!!(s&&performance&&performance.clearMeasures)&&performance.clearMeasures(t)}},c=function(t){this._marks={start:[t.url,"start"].join("#"),end:[t.url,"end"].join("#"),measure:t.url.toString()},l.mark(this._marks.start)};function u(e,r){var n=t.getArrayBuffer(e.request,function(e,n,a,i){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:a,expires:i})});return function(){n.cancel(),r()}}c.prototype.finish=function(){l.mark(this._marks.end);var t=l.getEntriesByName(this._marks.measure);return 0===t.length&&(l.measure(this._marks.measure,this._marks.start,this._marks.end),t=l.getEntriesByName(this._marks.measure),l.clearMarks(this._marks.start),l.clearMarks(this._marks.end),l.clearMeasures(this._marks.measure)),t},l.Performance=c;var h=function(t,e,r){this.actor=t,this.layerIndex=e,this.loadVectorData=r||u,this.loading={},this.loaded={}};h.prototype.loadTile=function(e,r){var n=this,a=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new l.Performance(e.request),s=this.loading[a]=new i(e);s.abort=this.loadVectorData(e,function(e,i){if(delete n.loading[a],e||!i)return s.status="done",n.loaded[a]=s,r(e);var l=i.rawData,c={};i.expires&&(c.expires=i.expires),i.cacheControl&&(c.cacheControl=i.cacheControl);var u={};if(o){var h=o.finish();h&&(u.resourceTiming=JSON.parse(JSON.stringify(h)))}s.vectorTile=i.vectorTile,s.parse(i.vectorTile,n.layerIndex,n.actor,function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))}),n.loaded=n.loaded||{},n.loaded[a]=s})},h.prototype.reloadTile=function(t,e){var r=this.loaded,n=t.uid,a=this;if(r&&r[n]){var i=r[n];i.showCollisionBoxes=t.showCollisionBoxes;var o=function(t,r){var n=i.reloadCallback;n&&(delete i.reloadCallback,i.parse(i.vectorTile,a.layerIndex,a.actor,n)),e(t,r)};"parsing"===i.status?i.reloadCallback=o:"done"===i.status&&(i.vectorTile?i.parse(i.vectorTile,this.layerIndex,this.actor,o):o())}},h.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},h.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var f=function(){this.loaded={}};f.prototype.loadTile=function(e,r){var n=e.uid,a=e.encoding,i=e.rawImageData,o=new t.DEMData(n,i,a);this.loaded=this.loaded||{},this.loaded[n]=o,r(null,o)},f.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var p={RADIUS:6378137,FLATTENING:1/298.257223563,POLAR_RADIUS:6356752.3142};function d(t){var e=0;if(t&&t.length>0){e+=Math.abs(g(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(g(t[r]))}return e}function g(t){var e,r,n,a,i,o,s=0,l=t.length;if(l>2){for(o=0;o<l;o++)o===l-2?(n=l-2,a=l-1,i=0):o===l-1?(n=l-1,a=0,i=1):(n=o,a=o+1,i=o+2),e=t[n],r=t[a],s+=(v(t[i][0])-v(e[0]))*Math.sin(v(r[1]));s=s*p.RADIUS*p.RADIUS/2}return s}function v(t){return t*Math.PI/180}var m={geometry:function t(e){var r,n=0;switch(e.type){case"Polygon":return d(e.coordinates);case"MultiPolygon":for(r=0;r<e.coordinates.length;r++)n+=d(e.coordinates[r]);return n;case"Point":case"MultiPoint":case"LineString":case"MultiLineString":return 0;case"GeometryCollection":for(r=0;r<e.geometries.length;r++)n+=t(e.geometries[r]);return n}},ring:g};function y(t,e){return function(r){return t(r,e)}}function x(t,e){e=!!e,t[0]=b(t[0],e);for(var r=1;r<t.length;r++)t[r]=b(t[r],!e);return t}function b(t,e){return function(t){return m.ring(t)>=0}(t)===e?t:t.reverse()}var _=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,w=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,"id"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};w.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var a=n[r];e.push([new t.Point$1(a[0],a[1])])}return e}for(var i=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var h=u[c];l.push(new t.Point$1(h[0],h[1]))}i.push(l)}return i},w.prototype.toGeoJSON=function(t,e,r){return _.call(this,t,e,r)};var k=function(e){this.layers={_geojsonTileLayer:this},this.name="_geojsonTileLayer",this.extent=t.EXTENT,this.length=e.length,this._features=e};k.prototype.feature=function(t){return new w(this._features[t])};var T=t.vectorTile.VectorTileFeature,M=A;function A(t,e){this.options=e||{},this.features=t,this.length=t.length}function S(t,e){this.id="number"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}A.prototype.feature=function(t){return new S(this.features[t],this.options.extent)},S.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],a=[],i=0;i<n.length;i++)a.push(new t.Point$1(n[i][0],n[i][1]));this.geometry.push(a)}return this.geometry},S.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,a=-1/0,i=0;i<t.length;i++)for(var o=t[i],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),a=Math.max(a,l.y)}return[e,n,r,a]},S.prototype.toGeoJSON=T.prototype.toGeoJSON;var E=P,L=P,C=M;function P(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,O,t.layers[r])}(e,r),r.finish()}function O(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||""),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,z,n);var a=n.keys;for(r=0;r<a.length;r++)e.writeStringField(3,a[r]);var i=n.values;for(r=0;r<i.length;r++)e.writeMessage(4,B,i[r])}function z(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,I,t),e.writeVarintField(3,r.type),e.writeMessage(4,F,r)}function I(t,e){var r=t.feature,n=t.keys,a=t.values,i=t.keycache,o=t.valuecache;for(var s in r.properties){var l=i[s];void 0===l&&(n.push(s),l=n.length-1,i[s]=l),e.writeVarint(l);var c=r.properties[s],u=typeof c;"string"!==u&&"boolean"!==u&&"number"!==u&&(c=JSON.stringify(c));var h=u+":"+c,f=o[h];void 0===f&&(a.push(c),f=a.length-1,o[h]=f),e.writeVarint(f)}}function D(t,e){return(e<<3)+(7&t)}function R(t){return t<<1^t>>31}function F(t,e){for(var r=t.loadGeometry(),n=t.type,a=0,i=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(D(1,c));for(var u=3===n?l.length-1:l.length,h=0;h<u;h++){1===h&&1!==n&&e.writeVarint(D(2,u-1));var f=l[h].x-a,p=l[h].y-i;e.writeVarint(R(f)),e.writeVarint(R(p)),a+=f,i+=p}3===n&&e.writeVarint(D(7,1))}}function B(t,e){var r=typeof t;"string"===r?e.writeStringField(1,t):"boolean"===r?e.writeBooleanField(7,t):"number"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function N(t,e,r,n){j(t,r,n),j(e,2*r,2*n),j(e,2*r+1,2*n+1)}function j(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function V(t,e,r,n){var a=t-r,i=e-n;return a*a+i*i}E.fromVectorTileJs=L,E.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new M(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return P({layers:r})},E.GeoJSONWrapper=C;var U=function(t){return t[0]},q=function(t){return t[1]},H=function(t,e,r,n,a){void 0===e&&(e=U),void 0===r&&(r=q),void 0===n&&(n=64),void 0===a&&(a=Float64Array),this.nodeSize=n,this.points=t;for(var i=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new i(t.length),s=this.coords=new a(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);!function t(e,r,n,a,i,o){if(!(i-a<=n)){var s=a+i>>1;!function t(e,r,n,a,i,o){for(;i>a;){if(i-a>600){var s=i-a+1,l=n-a+1,c=Math.log(s),u=.5*Math.exp(2*c/3),h=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1);t(e,r,n,Math.max(a,Math.floor(n-l*u/s+h)),Math.min(i,Math.floor(n+(s-l)*u/s+h)),o)}var f=r[2*n+o],p=a,d=i;for(N(e,r,a,n),r[2*i+o]>f&&N(e,r,a,i);p<d;){for(N(e,r,p,d),p++,d--;r[2*p+o]<f;)p++;for(;r[2*d+o]>f;)d--}r[2*a+o]===f?N(e,r,a,d):N(e,r,++d,i),d<=n&&(a=d+1),n<=d&&(i=d-1)}}(e,r,s,a,i,o%2),t(e,r,n,a,s-1,o+1),t(e,r,n,s+1,i,o+1)}}(o,s,n,0,o.length-1,0)};H.prototype.range=function(t,e,r,n){return function(t,e,r,n,a,i,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var h=c.pop(),f=c.pop(),p=c.pop();if(f-p<=o)for(var d=p;d<=f;d++)s=e[2*d],l=e[2*d+1],s>=r&&s<=a&&l>=n&&l<=i&&u.push(t[d]);else{var g=Math.floor((p+f)/2);s=e[2*g],l=e[2*g+1],s>=r&&s<=a&&l>=n&&l<=i&&u.push(t[g]);var v=(h+1)%2;(0===h?r<=s:n<=l)&&(c.push(p),c.push(g-1),c.push(v)),(0===h?a>=s:i>=l)&&(c.push(g+1),c.push(f),c.push(v))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},H.prototype.within=function(t,e,r){return function(t,e,r,n,a,i){for(var o=[0,t.length-1,0],s=[],l=a*a;o.length;){var c=o.pop(),u=o.pop(),h=o.pop();if(u-h<=i)for(var f=h;f<=u;f++)V(e[2*f],e[2*f+1],r,n)<=l&&s.push(t[f]);else{var p=Math.floor((h+u)/2),d=e[2*p],g=e[2*p+1];V(d,g,r,n)<=l&&s.push(t[p]);var v=(c+1)%2;(0===c?r-a<=d:n-a<=g)&&(o.push(h),o.push(p-1),o.push(v)),(0===c?r+a>=d:n+a>=g)&&(o.push(p+1),o.push(u),o.push(v))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var G={minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,reduce:null,map:function(t){return t}},Y=function(t){this.options=$(Object.create(G),t),this.trees=new Array(this.options.maxZoom+1)};function W(t,e,r,n,a){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:a}}function X(t,e){var r=t.geometry.coordinates,n=r[0],a=r[1];return{x:K(n),y:Q(a),zoom:1/0,index:e,parentId:-1}}function Z(t){return{type:"Feature",id:t.id,properties:J(t),geometry:{type:"Point",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function J(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+"k":e>=1e3?Math.round(e/100)/10+"k":e;return $($({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function K(t){return t/360+.5}function Q(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function $(t,e){for(var r in e)t[r]=e[r];return t}function tt(t){return t.x}function et(t){return t.y}function rt(t,e,r,n,a,i){var o=a-r,s=i-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=a,n=i):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function nt(t,e,r,n){var a={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if("Point"===r||"MultiPoint"===r||"LineString"===r)at(t,e);else if("Polygon"===r||"MultiLineString"===r)for(var n=0;n<e.length;n++)at(t,e[n]);else if("MultiPolygon"===r)for(n=0;n<e.length;n++)for(var a=0;a<e[n].length;a++)at(t,e[n][a])}(a),a}function at(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function it(t,e,r,n){if(e.geometry){var a=e.geometry.coordinates,i=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),"Point"===i)ot(a,s);else if("MultiPoint"===i)for(var c=0;c<a.length;c++)ot(a[c],s);else if("LineString"===i)st(a,s,o,!1);else if("MultiLineString"===i){if(r.lineMetrics){for(c=0;c<a.length;c++)s=[],st(a[c],s,o,!1),t.push(nt(l,"LineString",s,e.properties));return}lt(a,s,o,!1)}else if("Polygon"===i)lt(a,s,o,!0);else{if("MultiPolygon"!==i){if("GeometryCollection"===i){for(c=0;c<e.geometry.geometries.length;c++)it(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error("Input data is not a valid GeoJSON object.")}for(c=0;c<a.length;c++){var u=[];lt(a[c],u,o,!0),s.push(u)}}t.push(nt(l,i,s,e.properties))}}function ot(t,e){e.push(ct(t[0])),e.push(ut(t[1])),e.push(0)}function st(t,e,r,n){for(var a,i,o=0,s=0;s<t.length;s++){var l=ct(t[s][0]),c=ut(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(a*c-l*i)/2:Math.sqrt(Math.pow(l-a,2)+Math.pow(c-i,2))),a=l,i=c}var u=e.length-3;e[2]=1,function t(e,r,n,a){for(var i,o=a,s=n-r>>1,l=n-r,c=e[r],u=e[r+1],h=e[n],f=e[n+1],p=r+3;p<n;p+=3){var d=rt(e[p],e[p+1],c,u,h,f);if(d>o)i=p,o=d;else if(d===o){var g=Math.abs(p-s);g<l&&(i=p,l=g)}}o>a&&(i-r>3&&t(e,r,i,a),e[i+2]=o,n-i>3&&t(e,i,n,a))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function lt(t,e,r,n){for(var a=0;a<t.length;a++){var i=[];st(t[a],i,r,n),e.push(i)}}function ct(t){return t/360+.5}function ut(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function ht(t,e,r,n,a,i,o,s){if(n/=e,i>=(r/=e)&&o<n)return t;if(o<r||i>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.type,p=0===a?u.minX:u.minY,d=0===a?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var g=[];if("Point"===f||"MultiPoint"===f)ft(h,g,r,n,a);else if("LineString"===f)pt(h,g,r,n,a,!1,s.lineMetrics);else if("MultiLineString"===f)gt(h,g,r,n,a,!1);else if("Polygon"===f)gt(h,g,r,n,a,!0);else if("MultiPolygon"===f)for(var v=0;v<h.length;v++){var m=[];gt(h[v],m,r,n,a,!0),m.length&&g.push(m)}if(g.length){if(s.lineMetrics&&"LineString"===f){for(v=0;v<g.length;v++)l.push(nt(u.id,f,g[v],u.tags));continue}"LineString"!==f&&"MultiLineString"!==f||(1===g.length?(f="LineString",g=g[0]):f="MultiLineString"),"Point"!==f&&"MultiPoint"!==f||(f=3===g.length?"Point":"MultiPoint"),l.push(nt(u.id,f,g,u.tags))}}}return l.length?l:null}function ft(t,e,r,n,a){for(var i=0;i<t.length;i+=3){var o=t[i+a];o>=r&&o<=n&&(e.push(t[i]),e.push(t[i+1]),e.push(t[i+2]))}}function pt(t,e,r,n,a,i,o){for(var s,l,c=dt(t),u=0===a?mt:yt,h=t.start,f=0;f<t.length-3;f+=3){var p=t[f],d=t[f+1],g=t[f+2],v=t[f+3],m=t[f+4],y=0===a?p:d,x=0===a?v:m,b=!1;o&&(s=Math.sqrt(Math.pow(p-v,2)+Math.pow(d-m,2))),y<r?x>r&&(l=u(c,p,d,v,m,r),o&&(c.start=h+s*l)):y>n?x<n&&(l=u(c,p,d,v,m,n),o&&(c.start=h+s*l)):vt(c,p,d,g),x<r&&y>=r&&(l=u(c,p,d,v,m,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,v,m,n),b=!0),!i&&b&&(o&&(c.end=h+s*l),e.push(c),c=dt(t)),o&&(h+=s)}var _=t.length-3;p=t[_],d=t[_+1],g=t[_+2],(y=0===a?p:d)>=r&&y<=n&&vt(c,p,d,g),_=c.length-3,i&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&vt(c,c[0],c[1],c[2]),c.length&&e.push(c)}function dt(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function gt(t,e,r,n,a,i){for(var o=0;o<t.length;o++)pt(t[o],e,r,n,a,i,!1)}function vt(t,e,r,n){t.push(e),t.push(r),t.push(n)}function mt(t,e,r,n,a,i){var o=(i-e)/(n-e);return t.push(i),t.push(r+(a-r)*o),t.push(1),o}function yt(t,e,r,n,a,i){var o=(i-r)/(a-r);return t.push(e+(n-e)*o),t.push(i),t.push(1),o}function xt(t,e){for(var r=[],n=0;n<t.length;n++){var a,i=t[n],o=i.type;if("Point"===o||"MultiPoint"===o||"LineString"===o)a=bt(i.geometry,e);else if("MultiLineString"===o||"Polygon"===o){a=[];for(var s=0;s<i.geometry.length;s++)a.push(bt(i.geometry[s],e))}else if("MultiPolygon"===o)for(a=[],s=0;s<i.geometry.length;s++){for(var l=[],c=0;c<i.geometry[s].length;c++)l.push(bt(i.geometry[s][c],e));a.push(l)}r.push(nt(i.id,o,a,i.tags))}return r}function bt(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function _t(t,e){if(t.transformed)return t;var r,n,a,i=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(wt(c[n],c[n+1],e,i,o,s));else for(n=0;n<c.length;n++){var h=[];for(a=0;a<c[n].length;a+=2)h.push(wt(c[n][a],c[n][a+1],e,i,o,s));l.geometry.push(h)}}return t.transformed=!0,t}function wt(t,e,r,n,a,i){return[Math.round(r*(t*n-a)),Math.round(r*(e*n-i))]}function kt(t,e,r,n,a){for(var i=e===a.maxZoom?0:a.tolerance/((1<<e)*a.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,Tt(o,t[s],i,a);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,h=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),h>o.maxY&&(o.maxY=h)}return o}function Tt(t,e,r,n){var a=e.geometry,i=e.type,o=[];if("Point"===i||"MultiPoint"===i)for(var s=0;s<a.length;s+=3)o.push(a[s]),o.push(a[s+1]),t.numPoints++,t.numSimplified++;else if("LineString"===i)Mt(o,a,t,r,!1,!1);else if("MultiLineString"===i||"Polygon"===i)for(s=0;s<a.length;s++)Mt(o,a[s],t,r,"Polygon"===i,0===s);else if("MultiPolygon"===i)for(var l=0;l<a.length;l++){var c=a[l];for(s=0;s<c.length;s++)Mt(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if("LineString"===i&&n.lineMetrics){for(var h in u={},e.tags)u[h]=e.tags[h];u.mapbox_clip_start=a.start/a.size,u.mapbox_clip_end=a.end/a.size}var f={geometry:o,type:"Polygon"===i||"MultiPolygon"===i?3:"LineString"===i||"MultiLineString"===i?2:1,tags:u};null!==e.id&&(f.id=e.id),t.features.push(f)}}function Mt(t,e,r,n,a,i){var o=n*n;if(n>0&&e.size<(a?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;a&&function(t,e){for(var r=0,n=0,a=t.length,i=a-2;n<a;i=n,n+=2)r+=(t[n]-t[i])*(t[n+1]+t[i+1]);if(r>0===e)for(n=0,a=t.length;n<a/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[a-2-n],t[n+1]=t[a-1-n],t[a-2-n]=o,t[a-1-n]=s}}(s,i),t.push(s)}}function At(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time("preprocess data"),e.maxZoom<0||e.maxZoom>24)throw new Error("maxZoom should be in the 0-24 range");if(e.promoteId&&e.generateId)throw new Error("promoteId and generateId cannot be used together.");var n=function(t,e){var r=[];if("FeatureCollection"===t.type)for(var n=0;n<t.features.length;n++)it(r,t.features[n],e,n);else"Feature"===t.type?it(r,t,e):it(r,{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd("preprocess data"),console.log("index: maxZoom: %d, maxPoints: %d",e.indexMaxZoom,e.indexMaxPoints),console.time("generate tiles"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,a=ht(t,1,-1-r,r,0,-1,2,e),i=ht(t,1,1-r,2+r,0,-1,2,e);return(a||i)&&(n=ht(t,1,-r,1+r,0,-1,2,e)||[],a&&(n=xt(a,1).concat(n)),i&&(n=n.concat(xt(i,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log("features: %d, points: %d",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd("generate tiles"),console.log("tiles generated:",this.total,JSON.stringify(this.stats)))}function St(t,e,r){return 32*((1<<t)*r+e)+t}function Et(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var a=new k(n.features),i=E(a);0===i.byteOffset&&i.byteLength===i.buffer.byteLength||(i=new Uint8Array(i)),e(null,{vectorTile:a,rawData:i.buffer})}Y.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,a=e.maxZoom,i=e.nodeSize;r&&console.time("total time");var o="prepare "+t.length+" points";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(X(t[l],l));this.trees[a+1]=new H(s,tt,et,i,Float32Array),r&&console.timeEnd(o);for(var c=a;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new H(s,tt,et,i,Float32Array),r&&console.log("z%d: %d clusters in %dms",c,s.length,+Date.now()-u)}return r&&console.timeEnd("total time"),this},Y.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),a=180===t[2]?180:((t[2]+180)%360+360)%360-180,i=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,a=180;else if(r>a){var o=this.getClusters([r,n,180,i],e),s=this.getClusters([-180,n,a,i],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,h=l.range(K(r),Q(i),K(a),Q(n));u<h.length;u+=1){var f=h[u],p=l.points[f];c.push(p.numPoints?Z(p):this.points[p.index])}return c},Y.prototype.getChildren=function(t){var e=t>>5,r=t%32,n="No cluster with the specified id.",a=this.trees[r];if(!a)throw new Error(n);var i=a.points[e];if(!i)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=a.within(i.x,i.y,o);l<c.length;l+=1){var u=c[l],h=a.points[u];h.parentId===t&&s.push(h.numPoints?Z(h):this.points[h.index])}if(0===s.length)throw new Error(n);return s},Y.prototype.getLeaves=function(t,e,r){e=e||10,r=r||0;var n=[];return this._appendLeaves(n,t,e,r,0),n},Y.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],a=Math.pow(2,t),i=this.options,o=i.extent,s=i.radius/o,l=(r-s)/a,c=(r+1+s)/a,u={features:[]};return this._addTileFeatures(n.range((e-s)/a,l,(e+1+s)/a,c),n.points,e,r,a,u),0===e&&this._addTileFeatures(n.range(1-s/a,l,1,c),n.points,a,r,a,u),e===a-1&&this._addTileFeatures(n.range(0,l,s/a,c),n.points,-1,r,a,u),u.features.length?u:null},Y.prototype.getClusterExpansionZoom=function(t){for(var e=t%32-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},Y.prototype._appendLeaves=function(t,e,r,n,a){for(var i=0,o=this.getChildren(e);i<o.length;i+=1){var s=o[i],l=s.properties;if(l&&l.cluster?a+l.point_count<=n?a+=l.point_count:a=this._appendLeaves(t,l.cluster_id,r,n,a):a<n?a++:t.push(s),t.length===r)break}return a},Y.prototype._addTileFeatures=function(t,e,r,n,a,i){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c={type:1,geometry:[[Math.round(this.options.extent*(l.x*a-r)),Math.round(this.options.extent*(l.y*a-n))]],tags:l.numPoints?J(l):this.points[l.index].properties},u=l.numPoints?l.id:this.points[l.index].id;void 0!==u&&(c.id=u),i.features.push(c)}},Y.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},Y.prototype._cluster=function(t,e){for(var r=[],n=this.options,a=n.radius,i=n.extent,o=n.reduce,s=a/(i*Math.pow(2,e)),l=0;l<t.length;l++){var c=t[l];if(!(c.zoom<=e)){c.zoom=e;for(var u=this.trees[e+1],h=u.within(c.x,c.y,s),f=c.numPoints||1,p=c.x*f,d=c.y*f,g=o&&f>1?this._map(c,!0):null,v=(l<<5)+(e+1),m=0,y=h;m<y.length;m+=1){var x=y[m],b=u.points[x];if(!(b.zoom<=e)){b.zoom=e;var _=b.numPoints||1;p+=b.x*_,d+=b.y*_,f+=_,b.parentId=v,o&&(g||(g=this._map(c,!0)),o(g,this._map(b)))}}1===f?r.push(c):(c.parentId=v,r.push(W(p/f,d/f,v,f,g)))}}return r},Y.prototype._map=function(t,e){if(t.numPoints)return e?$({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?$({},n):n},At.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},At.prototype.splitTile=function(t,e,r,n,a,i,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,h=St(e,r,n),f=this.tiles[h];if(!f&&(c>1&&console.time("creation"),f=this.tiles[h]=kt(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log("tile z%d-%d-%d (features: %d, points: %d, simplified: %d)",e,r,n,f.numFeatures,f.numPoints,f.numSimplified),console.timeEnd("creation"));var p="z"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(f.source=t,a){if(e===l.maxZoom||e===a)continue;var d=1<<a-e;if(r!==Math.floor(i/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||f.numPoints<=l.indexMaxPoints)continue;if(f.source=null,0!==t.length){c>1&&console.time("clipping");var g,v,m,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,k=.5+_,T=1+_;g=v=m=y=null,x=ht(t,u,r-_,r+k,0,f.minX,f.maxX,l),b=ht(t,u,r+w,r+T,0,f.minX,f.maxX,l),t=null,x&&(g=ht(x,u,n-_,n+k,1,f.minY,f.maxY,l),v=ht(x,u,n+w,n+T,1,f.minY,f.maxY,l),x=null),b&&(m=ht(b,u,n-_,n+k,1,f.minY,f.maxY,l),y=ht(b,u,n+w,n+T,1,f.minY,f.maxY,l),b=null),c>1&&console.timeEnd("clipping"),s.push(g||[],e+1,2*r,2*n),s.push(v||[],e+1,2*r,2*n+1),s.push(m||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},At.prototype.getTile=function(t,e,r){var n=this.options,a=n.extent,i=n.debug;if(t<0||t>24)return null;var o=1<<t,s=St(t,e=(e%o+o)%o,r);if(this.tiles[s])return _t(this.tiles[s],a);i>1&&console.log("drilling down to z%d-%d-%d",t,e,r);for(var l,c=t,u=e,h=r;!l&&c>0;)c--,u=Math.floor(u/2),h=Math.floor(h/2),l=this.tiles[St(c,u,h)];return l&&l.source?(i>1&&console.log("found parent tile z%d-%d-%d",c,u,h),i>1&&console.time("drilling down"),this.splitTile(l.source,c,u,h,t,e,r),i>1&&console.timeEnd("drilling down"),this.tiles[s]?_t(this.tiles[s],a):null):null};var Lt=function(e){function r(t,r,n){e.call(this,t,r,Et),n&&(this.loadGeoJSON=n)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&"Idle"!==this._state?this._state="NeedsLoadData":(this._state="Coalescing",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var a=!!(n&&n.request&&n.request.collectResourceTiming)&&new l.Performance(n.request);this.loadGeoJSON(n,function(i,o){if(i||!o)return r(i);if("object"!=typeof o)return r(new Error("Input data given to '"+n.source+"' is not a valid GeoJSON object."));!function t(e,r){switch(e&&e.type||null){case"FeatureCollection":return e.features=e.features.map(y(t,r)),e;case"GeometryCollection":return e.geometries=e.geometries.map(y(t,r)),e;case"Feature":return e.geometry=t(e.geometry,r),e;case"Polygon":case"MultiPolygon":return function(t,e){return"Polygon"===t.type?t.coordinates=x(t.coordinates,e):"MultiPolygon"===t.type&&(t.coordinates=t.coordinates.map(y(x,e))),t}(e,r);default:return e}}(o,!0);try{e._geoJSONIndex=n.cluster?new Y(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var a={},i={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var h=u[c],f=n[h],p=f[0],d=f[1],g=t.createExpression(d),v=t.createExpression("string"==typeof p?[p,["accumulated"],["get",h]]:p);a[h]=g.value,i[h]=v.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var i=n[r];e[i]=a[i].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var a=n[r];o.accumulated=t[a],t[a]=i[a].evaluate(o,s)}},r}(n)).load(o.features):new At(o,n.geojsonVtOptions)}catch(i){return r(i)}e.loaded={};var s={};if(a){var l=a.finish();l&&(s.resourceTiming={},s.resourceTiming[n.source]=JSON.parse(JSON.stringify(l)))}r(null,s)})}},r.prototype.coalesce=function(){"Coalescing"===this._state?this._state="Idle":"NeedsLoadData"===this._state&&(this._state="Coalescing",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded,a=t.uid;return n&&n[a]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if("string"!=typeof e.data)return r(new Error("Input data given to '"+e.source+"' is not a valid GeoJSON object."));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error("Input data given to '"+e.source+"' is not a valid GeoJSON object."))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))},r.prototype.getClusterChildren=function(t,e){e(null,this._geoJSONIndex.getChildren(t.clusterId))},r.prototype.getClusterLeaves=function(t,e){e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))},r}(h),Ct=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.workerSourceTypes={vector:h,geojson:Lt},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name "'+t+'" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isLoaded())throw new Error("RTL text plugin already registered.");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return Ct.prototype.setReferrer=function(t,e){this.referrer=e},Ct.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},Ct.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},Ct.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},Ct.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},Ct.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},Ct.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},Ct.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},Ct.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},Ct.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},Ct.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},Ct.prototype.loadRTLTextPlugin=function(e,r,n){try{t.plugin.isLoaded()||(this.self.importScripts(r),n(t.plugin.isLoaded()?null:new Error("RTL Text Plugin failed to import scripts from "+r)))}catch(t){n(t.toString())}},Ct.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},Ct.prototype.getWorkerSource=function(t,e,r){var n=this;if(this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),!this.workerSources[t][e][r]){var a={send:function(e,r,a){n.actor.send(e,r,a,t)}};this.workerSources[t][e][r]=new this.workerSourceTypes[e](a,this.getLayerIndex(t))}return this.workerSources[t][e][r]},Ct.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new f),this.demWorkerSources[t][e]},Ct.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},"undefined"!=typeof WorkerGlobalScope&&void 0!==t.window&&t.window instanceof WorkerGlobalScope&&(t.window.worker=new Ct(t.window)),Ct}),n(0,function(t){var e=t.createCommonjsModule(function(t){function e(t){return!!("undefined"!=typeof window&&"undefined"!=typeof document&&Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray&&Function.prototype&&Function.prototype.bind&&Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions&&"JSON"in window&&"parse"in JSON&&"stringify"in JSON&&function(){if(!("Worker"in window&&"Blob"in window&&"URL"in window))return!1;var t,e,r=new Blob([""],{type:"text/javascript"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()&&"Uint8ClampedArray"in window&&ArrayBuffer.isView&&function(t){return void 0===r[t]&&(r[t]=function(t){var r=document.createElement("canvas"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext("webgl",n)||r.probablySupportsContext("experimental-webgl",n):r.supportsContext?r.supportsContext("webgl",n)||r.supportsContext("experimental-webgl",n):r.getContext("webgl",n)||r.getContext("experimental-webgl",n)}(t)),r[t]}(t&&t.failIfMajorPerformanceCaveat))}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e);var r={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}}),r={create:function(e,r,n){var a=t.window.document.createElement(e);return void 0!==r&&(a.className=r),n&&n.appendChild(a),a},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document.documentElement.style;function a(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var i,o=a(["userSelect","MozUserSelect","WebkitUserSelect","msUserSelect"]);r.disableDrag=function(){n&&o&&(i=n[o],n[o]="none")},r.enableDrag=function(){n&&o&&(n[o]=i)};var s=a(["transform","WebkitTransform"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},"passive",{get:function(){l=!0}});t.window.addEventListener("test",c,c),t.window.removeEventListener("test",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),"passive"in n&&l?t.addEventListener(e,r,n):t.addEventListener(e,r,n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),"passive"in n&&l?t.removeEventListener(e,r,n):t.removeEventListener(e,r,n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener("click",u,!0)};function h(t){var e=t.userImage;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}r.suppressClick=function(){t.window.addEventListener("click",u,!0),t.window.setTimeout(function(){t.window.removeEventListener("click",u,!0)},0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect(),a=t.window.TouchEvent&&r instanceof t.window.TouchEvent?r.touches[0]:r;return new t.Point(a.clientX-n.left-e.clientLeft,a.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),a=[],i="touchend"===r.type?r.changedTouches:r.touches,o=0;o<i.length;o++)a.push(new t.Point(i[o].clientX-n.left-e.clientLeft,i[o].clientY-n.top-e.clientTop));return a},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf("MAC")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var f=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e],a=n.ids,i=n.callback;this._notify(a,i)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this.images[t]=e},r.prototype.updateImage=function(t,e){var r=this.images[t];e.version=r.version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,a=t;n<a.length;n+=1){var i=a[n];this.images[i]||(r=!1)}this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},a=0,i=e;a<i.length;a+=1){var o=i[a];this.images[o]||this.fire(new t.Event("styleimagemissing",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image "'+o+'" could not be loaded. Please make sure you have added the image with map.addImage() or a "sprite" property in your style. You can provide missing images by listening for the "styleimagemissing" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var a={w:n.data.width+2,h:n.data.height+2,x:0,y:0},i=new t.ImagePosition(a,n);this.patterns[e]={bin:a,position:i}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),a=n.w,i=n.h,o=this.atlasImage;for(var s in o.resize({width:a||1,height:i||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,h=this.images[s].data,f=h.width,p=h.height;t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u},{width:f,height:p}),t.RGBAImage.copy(h,o,{x:0,y:p-1},{x:c,y:u-1},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u+p},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:f-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c+f,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var a=this.images[n];h(a)&&this.updateImage(n,a)}}},r}(t.Evented),p=v,d=v,g=1e20;function v(t,e,r,n,a,i){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=a||"sans-serif",this.fontWeight=i||"normal",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement("canvas"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext("2d"),this.ctx.font=this.fontWeight+" "+this.fontSize+"px "+this.fontFamily,this.ctx.textBaseline="middle",this.ctx.fillStyle="black",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf("Gecko/")>=0?1.2:1))}function m(t,e,r,n,a,i,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(y(n,a,i,o,r),l=0;l<r;l++)t[l*e+s]=a[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(y(n,a,i,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(a[s])}}function y(t,e,r,n,a){r[0]=0,n[0]=-g,n[1]=+g;for(var i=1,o=0;i<a;i++){for(var s=(t[i]+i*i-(t[r[o]]+r[o]*r[o]))/(2*i-2*r[o]);s<=n[o];)o--,s=(t[i]+i*i-(t[r[o]]+r[o]*r[o]))/(2*i-2*r[o]);r[++o]=i,n[o]=s,n[o+1]=+g}for(i=0,o=0;i<a;i++){for(;n[o+1]<i;)o++;e[i]=(i-r[o])*(i-r[o])+t[r[o]]}}v.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var a=e.data[4*n+3]/255;this.gridOuter[n]=1===a?0:0===a?g:Math.pow(Math.max(0,.5-a),2),this.gridInner[n]=1===a?g:0===a?0:Math.pow(Math.max(0,a-.5),2)}for(m(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),m(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++){var i=this.gridOuter[n]-this.gridInner[n];r[n]=Math.max(0,Math.min(255,Math.round(255-255*(i/this.radius+this.cutoff))))}return r},p.default=d;var x=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};x.prototype.setURL=function(t){this.url=t},x.prototype.getGlyphs=function(e,r){var n=this,a=[];for(var i in e)for(var o=0,s=e[i];o<s.length;o+=1){var l=s[o];a.push({stack:i,id:l})}t.asyncAll(a,function(t,e){var r=t.stack,a=t.id,i=n.entries[r];i||(i=n.entries[r]={glyphs:{},requests:{}});var o=i.glyphs[a];if(void 0===o){if(o=n._tinySDF(i,r,a))return i.glyphs[a]=o,void e(null,{stack:r,id:a,glyph:o});var s=Math.floor(a/256);if(256*s>65535)e(new Error("glyphs > 65535 not supported"));else{var l=i.requests[s];l||(l=i.requests[s]=[],x.loadGlyphRange(r,s,n.url,n.requestManager,function(t,e){if(e)for(var r in e)n._doesCharSupportLocalGlyph(+r)||(i.glyphs[+r]=e[+r]);for(var a=0,o=l;a<o.length;a+=1)(0,o[a])(t,e);delete i.requests[s]})),l.push(function(t,n){t?e(t):n&&e(null,{stack:r,id:a,glyph:n[a]||null})})}}else e(null,{stack:r,id:a,glyph:o})},function(t,e){if(t)r(t);else if(e){for(var n={},a=0,i=e;a<i.length;a+=1){var o=i[a],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}})},x.prototype._doesCharSupportLocalGlyph=function(e){return!!this.localIdeographFontFamily&&(t.isChar["CJK Unified Ideographs"](e)||t.isChar["Hangul Syllables"](e)||t.isChar.Hiragana(e)||t.isChar.Katakana(e))},x.prototype._tinySDF=function(e,r,n){var a=this.localIdeographFontFamily;if(a&&this._doesCharSupportLocalGlyph(n)){var i=e.tinySDF;if(!i){var o="400";/bold/i.test(r)?o="900":/medium/i.test(r)?o="500":/light/i.test(r)&&(o="200"),i=e.tinySDF=new x.TinySDF(24,3,8,.25,a,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},i.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},x.loadGlyphRange=function(e,r,n,a,i){var o=256*r,s=o+255,l=a.transformRequest(a.normalizeGlyphsURL(n).replace("{fontstack}",e).replace("{range}",o+"-"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,function(e,r){if(e)i(e);else if(r){for(var n={},a=0,o=t.parseGlyphPBF(r);a<o.length;a+=1){var s=o[a];n[s.id]=s}i(null,n)}})},x.TinySDF=p;var b=function(){this.specification=t.styleSpec.light.position};b.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},b.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var _=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new b,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),w=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(_),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var a=e[n];t.endsWith(n,"-transition")?this._transitionable.setTransition(n.slice(0,-"-transition".length),a):this._transitionable.setValue(n,a)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),k=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.bytes=4,this.data=new Uint8Array(this.width*this.height*this.bytes),this.positions={}};k.prototype.getDash=function(t,e){var r=t.join(",")+String(e);return this.positions[r]||(this.positions[r]=this.addDash(t,e)),this.positions[r]},k.prototype.addDash=function(e,r){var n=r?7:0,a=2*n+1;if(this.nextRow+a>this.height)return t.warnOnce("LineAtlas out of space"),null;for(var i=0,o=0;o<e.length;o++)i+=e[o];for(var s=this.width/i,l=s/2,c=e.length%2==1,u=-n;u<=n;u++)for(var h=this.nextRow+n+u,f=this.width*h,p=c?-e[e.length-1]:0,d=e[0],g=1,v=0;v<this.width;v++){for(;d<v/s;)p=d,d+=e[g],c&&g===e.length-1&&(d+=e[0]),g++;var m=Math.abs(v-p*s),y=Math.abs(v-d*s),x=Math.min(m,y),b=g%2==1,_=void 0;if(r){var w=n?u/n*(l+1):0;if(b){var k=l-Math.abs(w);_=Math.sqrt(x*x+k*k)}else _=l-Math.sqrt(x*x+w*w)}else _=(b?1:-1)*x;this.data[3+4*(f+v)]=Math.max(0,Math.min(255,_+128))}var T={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:i};return this.nextRow+=a,this.dirty=!0,T},k.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.RGBA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.RGBA,this.width,this.height,0,e.RGBA,e.UNSIGNED_BYTE,this.data))};var T=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var a=this.workerPool.acquire(this.id),i=0;i<a.length;i++){var o=a[i],s=new e.Actor(o,n,this.id);s.name="Worker "+i,this.actors.push(s)}};function M(e,r,n){var a=function(a,i){if(a)return n(a);if(i){var o=t.pick(t.extend(i,e),["tiles","minzoom","maxzoom","attribution","mapbox_logo","bounds","scheme","tileSize","encoding"]);i.vector_layers&&(o.vectorLayers=i.vector_layers,o.vectorLayerIds=o.vectorLayers.map(function(t){return t.id})),e.url&&(o.tiles=r.canonicalizeTileset(o,e.url)),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),a):t.browser.frame(function(){return a(null,e)})}T.prototype.broadcast=function(e,r,n){n=n||function(){},t.asyncAll(this.actors,function(t,n){t.send(e,r,n)},n)},T.prototype.getActor=function(){return this.currentActor=(this.currentActor+1)%this.actors.length,this.actors[this.currentActor]},T.prototype.remove=function(){this.actors.forEach(function(t){t.remove()}),this.actors=[],this.workerPool.release(this.id)},T.Actor=t.Actor;var A=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};A.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},A.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),a=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),i=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<i&&e.y>=a&&e.y<o};var S=function(e){function r(r,n,a,i){if(e.call(this),this.id=r,this.dispatcher=a,this.type="vector",this.minzoom=0,this.maxzoom=22,this.scheme="xyz",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,this._loaded=!1,t.extend(this,t.pick(n,["url","scheme","tileSize"])),this._options=t.extend({type:"vector"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error("vector tile sources must have a tileSize of 512");this.setEventedParent(i)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event("dataloading",{dataType:"source"})),this._tileJSONRequest=M(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles,e.map._requestManager._customAccessToken),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken,e.map._requestManager._customAccessToken),e.fire(new t.Event("data",{dataType:"source",sourceDataType:"metadata"})),e.fire(new t.Event("data",{dataType:"source",sourceDataType:"content"})))})},r.prototype.loaded=function(){return this._loaded},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,null),a={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};function i(n,a){return delete e.request,e.aborted?r(null):n&&404!==n.status?r(n):(a&&a.resourceTiming&&(e.resourceTiming=a.resourceTiming),this.map._refreshExpiredTiles&&a&&e.setExpiryData(a),e.loadVectorData(a,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}a.request.collectResourceTiming=this._collectResourceTiming,e.actor&&"expired"!==e.state?"loading"===e.state?e.reloadCallback=r:e.request=e.actor.send("reloadTile",a,i.bind(this)):(e.actor=this.dispatcher.getActor(),e.request=e.actor.send("loadTile",a,i.bind(this)))},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.actor&&t.actor.send("abortTile",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.unloadTile=function(t){t.unloadVectorData(),t.actor&&t.actor.send("removeTile",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),E=function(e){function r(r,n,a,i){e.call(this),this.id=r,this.dispatcher=a,this.setEventedParent(i),this.type="raster",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme="xyz",this.tileSize=512,this._loaded=!1,this._options=t.extend({type:"raster"},n),t.extend(this,t.pick(n,["url","scheme","tileSize"]))}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event("dataloading",{dataType:"source"})),this._tileJSONRequest=M(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event("data",{dataType:"source",sourceDataType:"metadata"})),e.fire(new t.Event("data",{dataType:"source",sourceDataType:"content"})))})},r.prototype.loaded=function(){return this._loaded},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,a=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(a,t.ResourceType.Tile),function(a,i){if(delete e.request,e.aborted)e.state="unloaded",r(null);else if(a)e.state="errored",r(a);else if(i){n.map._refreshExpiredTiles&&e.setExpiryData(i),delete i.cacheControl,delete i.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(i.width),e.texture?e.texture.update(i,{useMipmap:!0}):(e.texture=new t.Texture(o,i,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state="loaded",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}})},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),L=function(e){function r(r,n,a,i){e.call(this,r,n,a,i),this.type="raster-dem",this.maxzoom=22,this._options=t.extend({type:"raster-dem"},n),this.encoding=n.encoding||"mapbox"}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.serialize=function(){return{type:"raster-dem",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,a){if(delete e.request,e.aborted)e.state="unloaded",r(null);else if(n)e.state="errored",r(n);else if(a){this.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var i=t.browser.getImageData(a),o={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:i,encoding:this.encoding};e.actor&&"expired"!==e.state||(e.actor=this.dispatcher.getActor(),e.actor.send("loadDEMTile",o,function(t,n){t&&(e.state="errored",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state="loaded",r(null))}.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),a=(r.x-1+n)%n,i=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,i,r.z,a,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,i,r.z,a,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,i,r.z,a,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state="unloaded",t.actor&&t.actor.send("removeDEMTile",{uid:t.uid,source:this.id})},r}(E),C=function(e){function r(r,n,a,i){e.call(this),this.id=r,this.type="geojson",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this._loaded=!1,this.actor=a.getActor(),this.setEventedParent(i),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution);var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1},clusterProperties:n.clusterProperties},n.workerOptions)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event("dataloading",{dataType:"source"})),this._updateWorkerData(function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:"source",sourceDataType:"metadata"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event("data",n))}})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event("dataloading",{dataType:"source"})),this._updateWorkerData(function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:"source",sourceDataType:"content"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event("data",n))}}),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.actor.send("geojson.getClusterExpansionZoom",{clusterId:t,source:this.id},e),this},r.prototype.getClusterChildren=function(t,e){return this.actor.send("geojson.getClusterChildren",{clusterId:t,source:this.id},e),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.actor.send("geojson.getClusterLeaves",{source:this.id,clusterId:t,limit:e,offset:r},n),this},r.prototype._updateWorkerData=function(e){var r=this;this._loaded=!1;var n=t.extend({},this.workerOptions),a=this._data;"string"==typeof a?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(a),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(a),this.actor.send(this.type+".loadData",n,function(t,a){r._removed||a&&a.abandoned||(r._loaded=!0,a&&a.resourceTiming&&a.resourceTiming[r.id]&&(r._resourceTiming=a.resourceTiming[r.id].slice(0)),r.actor.send(r.type+".coalesce",{source:n.source},null),e(t))})},r.prototype.loaded=function(){return this._loaded},r.prototype.loadTile=function(e,r){var n=this,a=e.actor?"reloadTile":"loadTile";e.actor=this.actor;var i={type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};e.request=this.actor.send(a,i,function(t,i){return delete e.request,e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(i,n.map.painter,"reloadTile"===a),r(null))})},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.actor.send("removeTile",{uid:t.uid,type:this.type,source:this.id})},r.prototype.onRemove=function(){this._removed=!0,this.actor.send("removeSource",{type:this.type,source:this.id})},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),P=function(e){function r(t,r,n,a){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type="image",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this._loaded=!1,this.setEventedParent(a),this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(e,r){var n=this;this._loaded=!1,this.fire(new t.Event("dataloading",{dataType:"source"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),function(a,i){n._loaded=!0,a?n.fire(new t.ErrorEvent(a)):i&&(n.image=i,e&&(n.coordinates=e),r&&r(),n._finishLoading())})},r.prototype.loaded=function(){return this._loaded},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,function(){e.texture=null}),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event("data",{dataType:"source",sourceDataType:"metadata"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,a=-1/0,i=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),a=Math.max(a,l.x),i=Math.max(i,l.y)}var c=a-r,u=i-n,h=Math.max(c,u),f=Math.max(0,Math.floor(-Math.log(h)/Math.LN2)),p=Math.pow(2,f);return new t.CanonicalTileID(f,Math.floor((r+a)/2*p),Math.floor((n+i)/2*p))}(n),this.minzoom=this.maxzoom=this.tileID.z;var a=n.map(function(t){return r.tileID.getTilePoint(t)._round()});return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(a[0].x,a[0].y,0,0),this._boundsArray.emplaceBack(a[1].x,a[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(a[3].x,a[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(a[2].x,a[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event("data",{dataType:"source",sourceDataType:"content"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var a=this.tiles[n];"loaded"!==a.state&&(a.state="loaded",a.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state="errored",e(null))},r.prototype.serialize=function(){return{type:"image",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented),O=function(e){function r(t,r,n,a){e.call(this,t,r,n,a),this.roundZoom=!0,this.type="video",this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1;var r=this.options;this.urls=[];for(var n=0,a=r.urls;n<a.length;n+=1){var i=a[n];this.urls.push(this.map._requestManager.transformRequest(i,t.ResourceType.Source).url)}t.getVideo(this.urls,function(r,n){e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener("playing",function(){e.map.triggerRepaint()}),e.map&&e.video.play(),e._finishLoading())})},r.prototype.pause=function(){this.video&&this.video.pause()},r.prototype.play=function(){this.video&&this.video.play()},r.prototype.seek=function(e){if(this.video){var r=this.video.seekable;e<r.start(0)||e>r.end(0)?this.fire(new t.ErrorEvent(new t.ValidationError("Playback for this video can be set only between the "+r.start(0)+" and "+r.end(0)+"-second mark."))):this.video.currentTime=e}},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var a=this.tiles[n];"loaded"!==a.state&&(a.state="loaded",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:"video",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(P),z=function(e){function r(r,n,a,i){e.call(this,r,n,a,i),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some(function(t){return!Array.isArray(t)||2!==t.length||t.some(function(t){return"number"!=typeof t})})||this.fire(new t.ErrorEvent(new t.ValidationError("sources."+r,null,'"coordinates" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError("sources."+r,null,'missing required property "coordinates"'))),n.animate&&"boolean"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError("sources."+r,null,'optional "animate" property must be a boolean value'))),n.canvas?"string"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError("sources."+r,null,'"canvas" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError("sources."+r,null,'missing required property "canvas"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){this._loaded=!0,this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error("Canvas dimensions cannot be less than or equal to zero."))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var a in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var i=this.tiles[a];"loaded"!==i.state&&(i.state="loaded",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:"canvas",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(P),I={vector:S,raster:E,"raster-dem":L,geojson:C,video:O,image:P,canvas:z},D=function(e,r,n,a){var i=new I[r.type](e,r,n,a);if(i.id!==e)throw new Error("Expected Source id to be "+e+" instead of "+i.id);return t.bindAll(["load","abort","unload","serialize","prepare"],i),i};function R(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function F(t,e,r,n,a){var i=function(t,e,r){if(t)for(var n=0,a=t;n<a.length;n+=1){var i=e[a[n]];if(i&&i.source===r&&"fill-extrusion"===i.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&"fill-extrusion"===s.type)return!0}return!1}(n&&n.layers,e,t.id),o=a.maxPitchScaleFactor(),s=t.tilesIn(r,o,i);s.sort(B);for(var l=[],c=0,u=s;c<u.length;c+=1){var h=u[c];l.push({wrappedTileID:h.tileID.wrapped().key,queryResults:h.tile.queryRenderedFeatures(e,t._state,h.queryGeometry,h.cameraQueryGeometry,h.scale,n,a,o,R(t.transform,h.tileID))})}var f=function(t){for(var e={},r={},n=0,a=t;n<a.length;n+=1){var i=a[n],o=i.queryResults,s=i.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],h=l[c]=l[c]||{},f=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var g=d[p];h[g.featureIndex]||(h[g.featureIndex]=!0,f.push(g))}}return e}(l);for(var p in f)f[p].forEach(function(e){var r=e.feature,n=t.getFeatureState(r.layer["source-layer"],r.id);r.source=r.layer.source,r.layer["source-layer"]&&(r.sourceLayer=r.layer["source-layer"]),r.state=n});return f}function B(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var N=function(t,e){this.max=t,this.onRemove=e,this.reset()};N.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},N.prototype.add=function(t,e,r){var n=this,a=t.wrapped().key;void 0===this.data[a]&&(this.data[a]=[]);var i={value:e,timeout:void 0};if(void 0!==r&&(i.timeout=setTimeout(function(){n.remove(t,i)},r)),this.data[a].push(i),this.order.push(a),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},N.prototype.has=function(t){return t.wrapped().key in this.data},N.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},N.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},N.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},N.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),a=this.data[r][n];return this.data[r].splice(n,1),a.timeout&&clearTimeout(a.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(a.value),this.order.splice(this.order.indexOf(r),1),this},N.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this};var j=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};j.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},j.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},j.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var V={Int8:"BYTE",Uint8:"UNSIGNED_BYTE",Int16:"SHORT",Uint16:"UNSIGNED_SHORT",Int32:"INT",Uint32:"UNSIGNED_INT",Float32:"FLOAT"},U=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var a=t.gl;this.buffer=a.createBuffer(),t.bindVertexBuffer.set(this.buffer),a.bufferData(a.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?a.DYNAMIC_DRAW:a.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};U.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},U.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},U.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=this.attributes[r],a=e.attributes[n.name];void 0!==a&&t.enableVertexAttribArray(a)}},U.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var a=this.attributes[n],i=e.attributes[a.name];void 0!==i&&t.vertexAttribPointer(i,a.components,t[V[a.type]],!1,this.itemSize,a.offset+this.itemSize*(r||0))}},U.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var q=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};q.prototype.get=function(){return this.current},q.prototype.set=function(t){},q.prototype.getDefault=function(){return this.default},q.prototype.setDefault=function(){this.set(this.default)};var H=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(q),G=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(q),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(q),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(q),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(q),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(q),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(q),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(q),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(q),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(q),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(q),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(q),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(q),nt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(q),at=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(q),it=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(q),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(q),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(q),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(q),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(q),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(q),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(q),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(q),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(q),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(q),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(q),vt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(q),mt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(q),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(q),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(q),bt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(q),_t=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e}(q),wt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(_t),kt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(_t),Tt=function(t,e,r){this.context=t,this.width=e,this.height=r;var n=t.gl,a=this.framebuffer=n.createFramebuffer();this.colorAttachment=new wt(t,a),this.depthAttachment=new kt(t,a)};Tt.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();e&&t.deleteTexture(e);var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r),t.deleteFramebuffer(this.framebuffer)};var Mt=function(t,e,r){this.func=t,this.mask=e,this.range=r};Mt.ReadOnly=!1,Mt.ReadWrite=!0,Mt.disabled=new Mt(519,Mt.ReadOnly,[0,1]);var At=function(t,e,r,n,a,i){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=a,this.pass=i};At.disabled=new At({func:519,mask:0},0,0,7680,7680,7680);var St=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};St.disabled=new St(St.Replace=[1,0],t.Color.transparent,[!1,!1,!1,!1]),St.unblended=new St(St.Replace,t.Color.transparent,[!0,!0,!0,!0]),St.alphaBlended=new St([1,771],t.Color.transparent,[!0,!0,!0,!0]);var Et=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};Et.disabled=new Et(!1,1029,2305),Et.backCCW=new Et(!0,1029,2305);var Lt=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension("OES_vertex_array_object"),this.clearColor=new H(this),this.clearDepth=new G(this),this.clearStencil=new Y(this),this.colorMask=new W(this),this.depthMask=new X(this),this.stencilMask=new Z(this),this.stencilFunc=new J(this),this.stencilOp=new K(this),this.stencilTest=new Q(this),this.depthRange=new $(this),this.depthTest=new tt(this),this.depthFunc=new et(this),this.blend=new rt(this),this.blendFunc=new nt(this),this.blendColor=new at(this),this.blendEquation=new it(this),this.cullFace=new ot(this),this.cullFaceSide=new st(this),this.frontFace=new lt(this),this.program=new ct(this),this.activeTexture=new ut(this),this.viewport=new ht(this),this.bindFramebuffer=new ft(this),this.bindRenderbuffer=new pt(this),this.bindTexture=new dt(this),this.bindVertexBuffer=new gt(this),this.bindElementBuffer=new vt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new mt(this),this.pixelStoreUnpack=new yt(this),this.pixelStoreUnpackPremultiplyAlpha=new xt(this),this.pixelStoreUnpackFlipY=new bt(this),this.extTextureFilterAnisotropic=t.getExtension("EXT_texture_filter_anisotropic")||t.getExtension("MOZ_EXT_texture_filter_anisotropic")||t.getExtension("WEBKIT_EXT_texture_filter_anisotropic"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension("OES_texture_half_float"),this.extTextureHalfFloat&&t.getExtension("OES_texture_half_float_linear")};Lt.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},Lt.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},Lt.prototype.createIndexBuffer=function(t,e){return new j(this,t,e)},Lt.prototype.createVertexBuffer=function(t,e,r){return new U(this,t,e,r)},Lt.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,a=n.createRenderbuffer();return this.bindRenderbuffer.set(a),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),a},Lt.prototype.createFramebuffer=function(t,e){return new Tt(this,t,e)},Lt.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,a=0;e&&(a|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(a|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(a)},Lt.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},Lt.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Lt.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Lt.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,St.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},Lt.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Ct=function(e){function r(r,n,a){var i=this;e.call(this),this.id=r,this.dispatcher=a,this.on("data",function(t){"source"===t.dataType&&"metadata"===t.sourceDataType&&(i._sourceLoaded=!0),i._sourceLoaded&&!i._paused&&"source"===t.dataType&&"content"===t.sourceDataType&&(i.reload(),i.transform&&i.update(i.transform))}),this.on("error",function(){i._sourceErrored=!0}),this._source=D(r,n,a,this),this._tiles={},this._cache=new N(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;if(!this._source.loaded())return!1;for(var t in this._tiles){var e=this._tiles[t];if("loaded"!==e.state&&"errored"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,function(){})},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,function(){})},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return Object.keys(this._tiles).map(Number).sort(Pt)},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var a in this._tiles)this._isIdRenderable(+a,e)&&n.push(+a);return e?n.sort(function(e,n){var a=r._tiles[e].tileID,i=r._tiles[n].tileID,o=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle),s=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle);return a.overscaledZ-i.overscaledZ||s.y-o.y||s.x-o.x}):n.sort(Pt)},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)"errored"!==this._tiles[t].state&&this._reloadTile(t,"reloading")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&("loading"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,a){if(a)return e.state="errored",void(404!==a.status?this._source.fire(new t.ErrorEvent(a,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),"expired"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),"raster-dem"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event("data",{dataType:"source",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var a=this.getTileByID(n);i(t,a),i(a,t)}}function i(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,a=Math.pow(2,t.tileID.canonical.z),i=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+a)?r+=a:1===Math.abs(r-a)&&(r-=a)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[i]&&(t.neighboringTiles[i].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype.getZoom=function(t){return t.zoom+t.scaleZoom(t.tileSize/this._source.tileSize)},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var a in this._tiles){var i=this._tiles[a];if(!(n[a]||!i.hasData()||i.tileID.overscaledZ<=e||i.tileID.overscaledZ>r)){for(var o=i.tileID;i&&i.tileID.overscaledZ>e+1;){var s=i.tileID.scaledTo(i.tileID.overscaledZ-1);(i=this._tiles[s.key])&&i.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){for(var r=t.overscaledZ-1;r>=e;r--){var n=t.scaledTo(r);if(!n)return;var a=String(n.key),i=this._tiles[a];if(i&&i.hasData())return i;if(this._cache.has(n))return this._cache.get(n)}},r.prototype.updateCacheSize=function(t){var e=(Math.ceil(t.width/this._source.tileSize)+1)*(Math.ceil(t.height/this._source.tileSize)+1),r=Math.floor(5*e),n="number"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,r):r;this._cache.setMaxSize(n)},r.prototype.handleWrapJump=function(t){var e=(t-(void 0===this._prevLng?t:this._prevLng))/360,r=Math.round(e);if(this._prevLng=t,r){var n={};for(var a in this._tiles){var i=this._tiles[a];i.tileID=i.tileID.unwrapTo(i.tileID.wrap+r),n[i.tileID.key]=i}for(var o in this._tiles=n,this._timers)clearTimeout(this._timers[o]),delete this._timers[o];for(var s in this._tiles){var l=this._tiles[s];this._setTileReloadTimer(s,l)}}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var a;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?a=e.getVisibleUnwrappedCoordinates(this._source.tileID).map(function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)}):(a=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(a=a.filter(function(t){return n._source.hasTile(t)}))):a=[];var i=(this._source.roundZoom?Math.round:Math.floor)(this.getZoom(e)),o=Math.max(i-r.maxOverzooming,this._source.minzoom),s=Math.max(i+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(a,i);if(Ot(this._source.type)){for(var c={},u={},h=0,f=Object.keys(l);h<f.length;h+=1){var p=f[h],d=l[p],g=this._tiles[p];if(g&&!(g.fadeEndTime&&g.fadeEndTime<=t.browser.now())){var v=this.findLoadedParent(d,o);v&&(this._addTile(v.tileID),c[v.tileID.key]=v.tileID),u[p]=d}}for(var m in this._retainLoadedChildren(u,i,s,l),c)l[m]||(this._coveredTiles[m]=!0,l[m]=c[m])}for(var y in l)this._tiles[y].clearFadeHold();for(var x=0,b=t.keysDifference(this._tiles,l);x<b.length;x+=1){var _=b[x],w=this._tiles[_];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(_)}}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},a={},i=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],h=this._addTile(u);n[u.key]=u,h.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var f=0,p=t;f<p.length;f+=1){var d=p[f],g=this._tiles[d.key];if(!g.hasData()){if(e+1>this._source.maxzoom){var v=d.children(this._source.maxzoom)[0],m=this.getTile(v);if(m&&m.hasData()){n[v.key]=v;continue}}else{var y=d.children(this._source.maxzoom);if(n[y[0].key]&&n[y[1].key]&&n[y[2].key]&&n[y[3].key])continue}for(var x=g.wasRequested(),b=d.overscaledZ-1;b>=i;--b){var _=d.scaledTo(b);if(a[_.key])break;if(a[_.key]=!0,!(g=this.getTile(_))&&x&&(g=this._addTile(_)),g&&(n[_.key]=_,x=g.wasRequested(),g.hasData()))break}}}return n},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event("dataloading",{tile:r,coord:r.tileID,dataType:"source"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout(function(){r._reloadTile(t,"expired"),delete r._timers[t]},n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()&&"reloading"!==e.state?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var a=this,i=[],o=this.transform;if(!o)return i;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map(function(t){return o.pointCoordinate(t)}),c=s.map(function(t){return o.pointCoordinate(t)}),u=this.getIds(),h=1/0,f=1/0,p=-1/0,d=-1/0,g=0,v=c;g<v.length;g+=1){var m=v[g];h=Math.min(h,m.x),f=Math.min(f,m.y),p=Math.max(p,m.x),d=Math.max(d,m.y)}for(var y=function(e){var n=a._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,g=Math.pow(2,o.zoom-n.tileID.overscaledZ),v=r*n.queryPadding*t.EXTENT/n.tileSize/g,m=[s.getTilePoint(new t.MercatorCoordinate(h,f)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(m[0].x-v<t.EXTENT&&m[0].y-v<t.EXTENT&&m[1].x+v>=0&&m[1].y+v>=0){var y=l.map(function(t){return s.getTilePoint(t)}),x=c.map(function(t){return s.getTilePoint(t)});i.push({tile:n,tileID:s,queryGeometry:y,cameraQueryGeometry:x,scale:g})}}},x=0;x<u.length;x++)y(x);return i},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map(function(t){return e._tiles[t].tileID}),n=0,a=r;n<a.length;n+=1){var i=a[n];i.posMatrix=this.transform.calculatePosMatrix(i.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(Ot(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){t=t||"_geojsonTileLayer",this._state.updateState(t,e,r)},r.prototype.removeFeatureState=function(t,e,r){t=t||"_geojsonTileLayer",this._state.removeFeatureState(t,e,r)},r.prototype.getFeatureState=function(t,e){return t=t||"_geojsonTileLayer",this._state.getState(t,e)},r}(t.Evented);function Pt(t,e){return t%32-e%32||e-t}function Ot(t){return"raster"===t||"image"===t||"video"===t}function zt(){return new t.window.Worker($n.workerUrl)}Ct.maxOverzooming=10,Ct.maxUnderzooming=3;var It=function(){this.active={}};It.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<It.workerCount;)this.workers.push(new zt);return this.active[t]=!0,this.workers.slice()},It.prototype.release=function(t){delete this.active[t],0===Object.keys(this.active).length&&(this.workers.forEach(function(t){t.terminate()}),this.workers=null)};var Dt,Rt=Math.floor(t.browser.hardwareConcurrency/2);function Ft(e,r){var n={};for(var a in e)"ref"!==a&&(n[a]=e[a]);return t.refProperties.forEach(function(t){t in r&&(n[t]=r[t])}),n}function Bt(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)"ref"in t[n]&&(t[n]=Ft(t[n],e[t[n].ref]));return t}It.workerCount=Math.max(Math.min(Rt,6),1);var Nt={setStyle:"setStyle",addLayer:"addLayer",removeLayer:"removeLayer",setPaintProperty:"setPaintProperty",setLayoutProperty:"setLayoutProperty",setFilter:"setFilter",addSource:"addSource",removeSource:"removeSource",setGeoJSONSourceData:"setGeoJSONSourceData",setLayerZoomRange:"setLayerZoomRange",setLayerProperty:"setLayerProperty",setCenter:"setCenter",setZoom:"setZoom",setBearing:"setBearing",setPitch:"setPitch",setSprite:"setSprite",setGlyphs:"setGlyphs",setTransition:"setTransition",setLight:"setLight"};function jt(t,e,r){r.push({command:Nt.addSource,args:[t,e[t]]})}function Vt(t,e,r){e.push({command:Nt.removeSource,args:[t]}),r[t]=!0}function Ut(t,e,r,n){Vt(t,r,n),jt(t,e,r)}function qt(e,r,n){var a;for(a in e[n])if(e[n].hasOwnProperty(a)&&"data"!==a&&!t.deepEqual(e[n][a],r[n][a]))return!1;for(a in r[n])if(r[n].hasOwnProperty(a)&&"data"!==a&&!t.deepEqual(e[n][a],r[n][a]))return!1;return!0}function Ht(e,r,n,a,i,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[a,s,r[s],i]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[a,s,r[s],i]}))}function Gt(t){return t.id}function Yt(t,e){return t[e.id]=e,t}var Wt=function(t,e,r){var n=this.boxCells=[],a=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var i=0;i<this.xCellCount*this.yCellCount;i++)n.push([]),a.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function Xt(e,r,n,a,i){var o=t.create();return r?(t.scale(o,o,[1/i,1/i,1]),n||t.rotateZ(o,o,a.angle)):t.multiply(o,a.labelPlaneMatrix,e),o}function Zt(e,r,n,a,i){if(r){var o=t.clone(e);return t.scale(o,o,[i,i,1]),n||t.rotateZ(o,o,-a.angle),o}return a.glCoordMatrix}function Jt(e,r){var n=[e.x,e.y,0,1];oe(n,n,r);var a=n[3];return{point:new t.Point(n[0]/a,n[1]/a),signedDistanceFromCamera:a}}function Kt(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function Qt(e,r,n,a,i,o,s,l){var c=a?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),h=[256/n.width*2+1,256/n.height*2+1],f=a?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;f.clear();for(var p=e.lineVertexArray,d=a?e.text.placedSymbolArray:e.icon.placedSymbolArray,g=n.transform.width/n.transform.height,v=!1,m=0;m<d.length;m++){var y=d.get(m);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!v)ie(y.numGlyphs,f);else{v=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.transformMat4(x,x,r),Kt(x,h)){var b=.5+x[3]/n.transform.cameraToCenterDistance*.5,_=t.evaluateSizeForFeature(c,u,y),w=s?_*b:_/b,k=new t.Point(y.anchorX,y.anchorY),T=Jt(k,i).point,M={},A=ee(y,w,!1,l,r,i,o,e.glyphOffsetArray,p,f,T,k,M,g);v=A.useVertical,(A.notEnoughRoom||v||A.needsFlipping&&ee(y,w,!0,l,r,i,o,e.glyphOffsetArray,p,f,T,k,M,g).notEnoughRoom)&&ie(y.numGlyphs,f)}else ie(y.numGlyphs,f)}}a?e.text.dynamicLayoutVertexBuffer.updateData(f):e.icon.dynamicLayoutVertexBuffer.updateData(f)}function $t(t,e,r,n,a,i,o,s,l,c,u,h){var f=s.glyphStartIndex+s.numGlyphs,p=s.lineStartIndex,d=s.lineStartIndex+s.lineLength,g=e.getoffsetX(s.glyphStartIndex),v=e.getoffsetX(f-1),m=ne(t*g,r,n,a,i,o,s.segment,p,d,l,c,u,h);if(!m)return null;var y=ne(t*v,r,n,a,i,o,s.segment,p,d,l,c,u,h);return y?{first:m,last:y}:null}function te(e,r,n,a){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*a?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function ee(e,r,n,a,i,o,s,l,c,u,h,f,p,d){var g,v=r/24,m=e.lineOffsetX*v,y=e.lineOffsetY*v;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=$t(v,l,m,y,n,h,f,e,c,o,p,!1);if(!w)return{notEnoughRoom:!0};var k=Jt(w.first.point,s).point,T=Jt(w.last.point,s).point;if(a&&!n){var M=te(e.writingMode,k,T,d);if(M)return M}g=[w.first];for(var A=e.glyphStartIndex+1;A<x-1;A++)g.push(ne(v*l.getoffsetX(A),m,y,n,h,f,e.segment,b,_,c,o,p,!1));g.push(w.last)}else{if(a&&!n){var S=Jt(f,i).point,E=e.lineStartIndex+e.segment+1,L=new t.Point(c.getx(E),c.gety(E)),C=Jt(L,i),P=C.signedDistanceFromCamera>0?C.point:re(f,L,S,1,i),O=te(e.writingMode,S,P,d);if(O)return O}var z=ne(v*l.getoffsetX(e.glyphStartIndex),m,y,n,h,f,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p,!1);if(!z)return{notEnoughRoom:!0};g=[z]}for(var I=0,D=g;I<D.length;I+=1){var R=D[I];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function re(t,e,r,n,a){var i=Jt(t.add(t.sub(e)._unit()),a).point,o=r.sub(i);return r.add(o._mult(n/o.mag()))}function ne(e,r,n,a,i,o,s,l,c,u,h,f,p){var d=a?e-r:e+r,g=d>0?1:-1,v=0;a&&(g*=-1,v=Math.PI),g<0&&(v+=Math.PI);for(var m=g>0?l+s:l+s+1,y=m,x=i,b=i,_=0,w=0,k=Math.abs(d);_+w<=k;){if((m+=g)<l||m>=c)return null;if(b=x,void 0===(x=f[m])){var T=new t.Point(u.getx(m),u.gety(m)),M=Jt(T,h);if(M.signedDistanceFromCamera>0)x=f[m]=M.point;else{var A=m-g;x=re(0===_?o:new t.Point(u.getx(A),u.gety(A)),T,b,k-_+1,h)}}_+=w,w=b.dist(x)}var S=(k-_)/w,E=x.sub(b),L=E.mult(S)._add(b);return L._add(E._unit()._perp()._mult(n*g)),{point:L,angle:v+Math.atan2(x.y-b.y,x.x-b.x),tileDistance:p?{prevTileDistance:m-g===y?0:u.gettileUnitDistanceFromAnchor(m-g),lastSegmentViewportDistance:k-_}:null}}Wt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Wt.prototype.insert=function(t,e,r,n,a){this._forEachCell(e,r,n,a,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(a)},Wt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Wt.prototype._insertBoxCell=function(t,e,r,n,a,i){this.boxCells[a].push(i)},Wt.prototype._insertCircleCell=function(t,e,r,n,a,i){this.circleCells[a].push(i)},Wt.prototype._query=function(t,e,r,n,a,i){if(r<0||t>this.width||n<0||e>this.height)return!a&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(a)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],h=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-h,y1:u-h,x2:c+h,y2:u+h})}return i?o.filter(i):o}var f={hitTest:a,seenUids:{box:{},circle:{}}};return this._forEachCell(t,e,r,n,this._queryCell,o,f,i),a?o.length>0:o},Wt.prototype._queryCircle=function(t,e,r,n,a){var i=t-r,o=t+r,s=e-r,l=e+r;if(o<0||i>this.width||l<0||s>this.height)return!n&&[];var c=[],u={hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}};return this._forEachCell(i,s,o,l,this._queryCellCircle,c,u,a),n?c.length>0:c},Wt.prototype.query=function(t,e,r,n,a){return this._query(t,e,r,n,!1,a)},Wt.prototype.hitTest=function(t,e,r,n,a){return this._query(t,e,r,n,!0,a)},Wt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Wt.prototype._queryCell=function(t,e,r,n,a,i,o,s){var l=o.seenUids,c=this.boxCells[a];if(null!==c)for(var u=this.bboxes,h=0,f=c;h<f.length;h+=1){var p=f[h];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return i.push(!0),!0;i.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var g=this.circleCells[a];if(null!==g)for(var v=this.circles,m=0,y=g;m<y.length;m+=1){var x=y[m];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circleAndRectCollide(v[b],v[b+1],v[b+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return i.push(!0),!0;var _=v[b],w=v[b+1],k=v[b+2];i.push({key:this.circleKeys[x],x1:_-k,y1:w-k,x2:_+k,y2:w+k})}}}},Wt.prototype._queryCellCircle=function(t,e,r,n,a,i,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[a];if(null!==u)for(var h=this.bboxes,f=0,p=u;f<p.length;f+=1){var d=p[f];if(!c.box[d]){c.box[d]=!0;var g=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,h[g+0],h[g+1],h[g+2],h[g+3])&&(!s||s(this.boxKeys[d])))return i.push(!0),!0}}var v=this.circleCells[a];if(null!==v)for(var m=this.circles,y=0,x=v;y<x.length;y+=1){var b=x[y];if(!c.circle[b]){c.circle[b]=!0;var _=3*b;if(this._circlesCollide(m[_],m[_+1],m[_+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[b])))return i.push(!0),!0}}},Wt.prototype._forEachCell=function(t,e,r,n,a,i,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),h=this._convertToYCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.xCellCount*p+f;if(a.call(this,t,e,r,n,d,i,o,s))return}},Wt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Wt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Wt.prototype._circlesCollide=function(t,e,r,n,a,i){var o=n-t,s=a-e,l=r+i;return l*l>o*o+s*s},Wt.prototype._circleAndRectCollide=function(t,e,r,n,a,i,o){var s=(i-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-a)/2,u=Math.abs(e-(a+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var h=l-s,f=u-c;return h*h+f*f<=r*r};var ae=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function ie(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(ae,3*n)}}function oe(t,e,r){var n=e[0],a=e[1];return t[0]=r[0]*n+r[4]*a+r[12],t[1]=r[1]*n+r[5]*a+r[13],t[3]=r[3]*n+r[7]*a+r[15],t}var se=function(t,e,r){void 0===e&&(e=new Wt(t.width+200,t.height+200,25)),void 0===r&&(r=new Wt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function le(t,e,r){t[e+4]=r?1:0}function ce(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}se.prototype.placeCollisionBox=function(t,e,r,n,a){var i=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*i.perspectiveRatio,s=t.x1*o+i.point.x,l=t.y1*o+i.point.y,c=t.x2*o+i.point.x,u=t.y2*o+i.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,a)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},se.prototype.approximateTileDistance=function(t,e,r,n,a){var i=a?1:n/this.pitchfactor,o=t.lastSegmentViewportDistance*r;return t.prevTileDistance+o+(i-1)*o*Math.abs(Math.sin(e))},se.prototype.placeCollisionCircles=function(e,r,n,a,i,o,s,l,c,u,h,f,p){var d=[],g=this.projectAnchor(c,i.anchorX,i.anchorY),v=l/24,m=i.lineOffsetX*l,y=i.lineOffsetY*l,x=new t.Point(i.anchorX,i.anchorY),b=$t(v,s,m,y,!1,Jt(x,u).point,x,i,o,u,{},!0),_=!1,w=!1,k=!0,T=g.perspectiveRatio*a,M=1/(a*n),A=0,S=0;b&&(A=this.approximateTileDistance(b.first.tileDistance,b.first.angle,M,g.cameraDistance,f),S=this.approximateTileDistance(b.last.tileDistance,b.last.angle,M,g.cameraDistance,f));for(var E=0;E<e.length;E+=5){var L=e[E],C=e[E+1],P=e[E+2],O=e[E+3];if(!b||O<-A||O>S)le(e,E,!1);else{var z=this.projectPoint(c,L,C),I=P*T;if(d.length>0){var D=z.x-d[d.length-4],R=z.y-d[d.length-3];if(I*I*2>D*D+R*R&&E+8<e.length){var F=e[E+8];if(F>-A&&F<S){le(e,E,!1);continue}}}var B=E/5;d.push(z.x,z.y,I,B),le(e,E,!0);var N=z.x-I,j=z.y-I,V=z.x+I,U=z.y+I;if(k=k&&this.isOffscreen(N,j,V,U),w=w||this.isInsideGrid(N,j,V,U),!r&&this.grid.hitTestCircle(z.x,z.y,I,p)){if(!h)return{circles:[],offscreen:!1};_=!0}}}return{circles:_||!w?[]:d,offscreen:k}},se.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,a=1/0,i=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+100,c.y+100);n=Math.min(n,u.x),a=Math.min(a,u.y),i=Math.max(i,u.x),o=Math.max(o,u.y),r.push(u)}for(var h={},f={},p=0,d=this.grid.query(n,a,i,o).concat(this.ignoredGrid.query(n,a,i,o));p<d.length;p+=1){var g=d[p],v=g.key;if(void 0===h[v.bucketInstanceId]&&(h[v.bucketInstanceId]={}),!h[v.bucketInstanceId][v.featureIndex]){var m=[new t.Point(g.x1,g.y1),new t.Point(g.x2,g.y1),new t.Point(g.x2,g.y2),new t.Point(g.x1,g.y2)];t.polygonIntersectsPolygon(r,m)&&(h[v.bucketInstanceId][v.featureIndex]=!0,void 0===f[v.bucketInstanceId]&&(f[v.bucketInstanceId]=[]),f[v.bucketInstanceId].push(v.featureIndex))}}return f},se.prototype.insertCollisionBox=function(t,e,r,n,a){var i={bucketInstanceId:r,featureIndex:n,collisionGroupID:a};(e?this.ignoredGrid:this.grid).insert(i,t[0],t[1],t[2],t[3])},se.prototype.insertCollisionCircles=function(t,e,r,n,a){for(var i=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:a},s=0;s<t.length;s+=4)i.insertCircle(o,t[s],t[s+1],t[s+2])},se.prototype.projectAnchor=function(t,e,r){var n=[e,r,0,1];return oe(n,n,t),{perspectiveRatio:.5+this.transform.cameraToCenterDistance/n[3]*.5,cameraDistance:n[3]}},se.prototype.projectPoint=function(e,r,n){var a=[r,n,0,1];return oe(a,a,e),new t.Point((a[0]/a[3]+1)/2*this.transform.width+100,(-a[1]/a[3]+1)/2*this.transform.height+100)},se.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var a=[r,n,0,1];return oe(a,a,e),{point:new t.Point((a[0]/a[3]+1)/2*this.transform.width+100,(-a[1]/a[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/a[3]*.5}},se.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary},se.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary};var ue=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};ue.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var he=function(t,e,r,n,a){this.text=new ue(t?t.text:null,e,r,a),this.icon=new ue(t?t.icon:null,e,n,a)};he.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var fe=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},pe=function(t,e,r,n,a){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=a},de=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function ge(e,r,n,a,i){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateRadialOffset(e,a);return new t.Point(s+c[0]*i,l+c[1]*i)}de.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var ve=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new se(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new de(r),this.prevPlacement=n,n&&(n.prevPlacement=void 0),this.placedOrientations={}};function me(t,e,r,n,a){t.emplaceBack(e?1:0,r?1:0,n||0,a||0),t.emplaceBack(e?1:0,r?1:0,n||0,a||0),t.emplaceBack(e?1:0,r?1:0,n||0,a||0),t.emplaceBack(e?1:0,r?1:0,n||0,a||0)}ve.prototype.placeLayerTile=function(e,r,n,a){var i=r.getBucket(e),o=r.latestFeatureIndex;if(i&&o&&e.id===i.layerIds[0]){var s=r.collisionBoxArray,l=i.layers[0].layout,c=Math.pow(2,this.transform.zoom-r.tileID.overscaledZ),u=r.tileSize/t.EXTENT,h=this.transform.calculatePosMatrix(r.tileID.toUnwrapped()),f=Xt(h,"map"===l.get("text-pitch-alignment"),"map"===l.get("text-rotation-alignment"),this.transform,ce(r,1,this.transform.zoom)),p=Xt(h,"map"===l.get("icon-pitch-alignment"),"map"===l.get("icon-rotation-alignment"),this.transform,ce(r,1,this.transform.zoom));this.retainedQueryData[i.bucketInstanceId]=new pe(i.bucketInstanceId,o,i.sourceLayerIndex,i.index,r.tileID),this.placeLayerBucket(i,h,f,p,c,u,n,r.holdingForFade(),a,s)}},ve.prototype.attemptAnchorPlacement=function(e,r,n,a,i,o,s,l,c,u,h,f,p,d,g){var v,m=ge(e,n,a,i,o),y=this.collisionIndex.placeCollisionBox(function(e,r,n,a,i,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,h=e.anchorPointX,f=e.anchorPointY,p=new t.Point(r,n);return a&&p._rotate(i?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:h,anchorPointY:f}}(r,m.x,m.y,s,l,this.transform.angle),f,c,u,h.predicate);if(y.box.length>0)return this.prevPlacement&&this.prevPlacement.variableOffsets[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID].text&&(v=this.prevPlacement.variableOffsets[p.crossTileID].anchor),this.variableOffsets[p.crossTileID]={radialOffset:i,width:n,height:a,anchor:e,textBoxScale:o,prevAnchor:v},this.markUsedJustification(d,e,p,g),d.allowVerticalPlacement&&(this.markUsedOrientation(d,g,p),this.placedOrientations[p.crossTileID]=g),y},ve.prototype.placeLayerBucket=function(e,r,n,a,i,o,s,l,c,u){var h=this,f=e.layers[0].layout,p=t.evaluateSizeForZoom(e.textSizeData,this.transform.zoom),d=f.get("text-optional"),g=f.get("icon-optional"),v=f.get("text-allow-overlap"),m=f.get("icon-allow-overlap"),y=v&&(m||!e.hasIconData()||g),x=m&&(v||!e.hasTextData()||d),b=this.collisionGroups.get(e.sourceID),_="map"===f.get("text-rotation-alignment"),w="map"===f.get("text-pitch-alignment"),k="viewport-y"===f.get("symbol-z-order");!e.collisionArrays&&u&&e.deserializeCollisionBoxes(u);var T=function(a,u){if(!c[a.crossTileID])if(l)h.placements[a.crossTileID]=new fe(!1,!1,!1);else{var m,k=!1,T=!1,M=!0,A={box:null,offscreen:null},S={box:null,offscreen:null},E=null,L=null,C=0,P=0,O=0;u.textFeatureIndex&&(C=u.textFeatureIndex),u.verticalTextFeatureIndex&&(P=u.verticalTextFeatureIndex);var z=u.textBox;if(z){var I=function(r){var n=t.WritingMode.horizontal;if(e.allowVerticalPlacement&&!r&&h.prevPlacement){var i=h.prevPlacement.placedOrientations[a.crossTileID];i&&(h.placedOrientations[a.crossTileID]=i,n=i,h.markUsedOrientation(e,n,a))}return n},D=function(r,n){if(e.allowVerticalPlacement&&a.numVerticalGlyphVertices>0&&u.verticalTextBox)for(var i=0,o=e.writingModes;i<o.length&&(o[i]===t.WritingMode.vertical?(A=n(),S=A):A=r(),!(A&&A.box&&A.box.length));i+=1);else A=r()};if(f.get("text-variable-anchor")){var R=f.get("text-variable-anchor");if(h.prevPlacement&&h.prevPlacement.variableOffsets[a.crossTileID]){var F=h.prevPlacement.variableOffsets[a.crossTileID];R.indexOf(F.anchor)>0&&(R=R.filter(function(t){return t!==F.anchor})).unshift(F.anchor)}var B=function(t,n){for(var i=t.x2-t.x1,s=t.y2-t.y1,l=a.textBoxScale,c={box:[],offscreen:!1},u=v?2*R.length:R.length,f=0;f<u;++f){var p=R[f%R.length],d=f>=R.length;if((c=h.attemptAnchorPlacement(p,t,i,s,a.radialTextOffset,l,_,w,o,r,b,d,a,e,n))&&c.box&&c.box.length){k=!0;break}}return c};D(function(){return B(z,t.WritingMode.horizontal)},function(){var r=u.verticalTextBox,n=A&&A.box&&A.box.length;return e.allowVerticalPlacement&&!n&&a.numVerticalGlyphVertices>0&&r?B(r,t.WritingMode.vertical):{box:null,offscreen:null}}),A&&(k=A.box,M=A.offscreen);var N=I(A&&A.box);if(!k&&h.prevPlacement){var j=h.prevPlacement.variableOffsets[a.crossTileID];j&&(h.variableOffsets[a.crossTileID]=j,h.markUsedJustification(e,j.anchor,a,N))}}else{var V=function(t,n){var i=h.collisionIndex.placeCollisionBox(t,f.get("text-allow-overlap"),o,r,b.predicate);return i&&i.box&&i.box.length&&(h.markUsedOrientation(e,n,a),h.placedOrientations[a.crossTileID]=n),i};D(function(){return V(z,t.WritingMode.horizontal)},function(){var r=u.verticalTextBox;return e.allowVerticalPlacement&&a.numVerticalGlyphVertices>0&&r?V(r,t.WritingMode.vertical):{box:null,offscreen:null}}),I(A&&A.box&&A.box.length)}}k=(m=A)&&m.box&&m.box.length>0,M=m&&m.offscreen;var U=u.textCircles;if(U){var q=e.text.placedSymbolArray.get(a.centerJustifiedTextSymbolIndex),H=t.evaluateSizeForFeature(e.textSizeData,p,q);E=h.collisionIndex.placeCollisionCircles(U,f.get("text-allow-overlap"),i,o,q,e.lineVertexArray,e.glyphOffsetArray,H,r,n,s,w,b.predicate),k=f.get("text-allow-overlap")||E.circles.length>0,M=M&&E.offscreen}u.iconFeatureIndex&&(O=u.iconFeatureIndex),u.iconBox&&(T=(L=h.collisionIndex.placeCollisionBox(u.iconBox,f.get("icon-allow-overlap"),o,r,b.predicate)).box.length>0,M=M&&L.offscreen);var G=d||0===a.numHorizontalGlyphVertices&&0===a.numVerticalGlyphVertices,Y=g||0===a.numIconVertices;G||Y?Y?G||(T=T&&k):k=T&&k:T=k=T&&k,k&&m&&m.box&&(S&&S.box&&P?h.collisionIndex.insertCollisionBox(m.box,f.get("text-ignore-placement"),e.bucketInstanceId,P,b.ID):h.collisionIndex.insertCollisionBox(m.box,f.get("text-ignore-placement"),e.bucketInstanceId,C,b.ID)),T&&L&&h.collisionIndex.insertCollisionBox(L.box,f.get("icon-ignore-placement"),e.bucketInstanceId,O,b.ID),k&&E&&h.collisionIndex.insertCollisionCircles(E.circles,f.get("text-ignore-placement"),e.bucketInstanceId,C,b.ID),h.placements[a.crossTileID]=new fe(k||y,T||x,M||e.justReloaded),c[a.crossTileID]=!0}};if(k)for(var M=e.getSortedSymbolIndexes(this.transform.angle),A=M.length-1;A>=0;--A){var S=M[A];T(e.symbolInstances.get(S),e.collisionArrays[S])}else for(var E=0;E<e.symbolInstances.length;++E)T(e.symbolInstances.get(E),e.collisionArrays[E]);e.justReloaded=!1},ve.prototype.markUsedJustification=function(e,r,n,a){var i,o={left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex};i=a===t.WritingMode.vertical?n.verticalPlacedTextSymbolIndex:o[t.getAnchorJustification(r)];for(var s=0,l=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex,n.verticalPlacedTextSymbolIndex];s<l.length;s+=1){var c=l[s];c>=0&&(e.text.placedSymbolArray.get(c).crossTileID=i>=0&&c!==i?0:n.crossTileID)}},ve.prototype.markUsedOrientation=function(e,r,n){for(var a=r===t.WritingMode.horizontal||r===t.WritingMode.horizontalOnly?r:0,i=r===t.WritingMode.vertical?r:0,o=0,s=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex];o<s.length;o+=1){var l=s[o];e.text.placedSymbolArray.get(l).placedOrientation=a}n.verticalPlacedTextSymbolIndex&&(e.text.placedSymbolArray.get(n.verticalPlacedTextSymbolIndex).placedOrientation=i)},ve.prototype.commit=function(t){this.commitTime=t;var e=this.prevPlacement,r=!1,n=e&&0!==this.fadeDuration?(this.commitTime-e.commitTime)/this.fadeDuration:1,a=e?e.opacities:{},i=e?e.variableOffsets:{},o=e?e.placedOrientations:{};for(var s in this.placements){var l=this.placements[s],c=a[s];c?(this.opacities[s]=new he(c,n,l.text,l.icon),r=r||l.text!==c.text.placed||l.icon!==c.icon.placed):(this.opacities[s]=new he(null,n,l.text,l.icon,l.skipFade),r=r||l.text||l.icon)}for(var u in a){var h=a[u];if(!this.opacities[u]){var f=new he(h,n,!1,!1);f.isHidden()||(this.opacities[u]=f,r=r||h.text.placed||h.icon.placed)}}for(var p in i)this.variableOffsets[p]||!this.opacities[p]||this.opacities[p].isHidden()||(this.variableOffsets[p]=i[p]);for(var d in o)this.placedOrientations[d]||!this.opacities[d]||this.opacities[d].isHidden()||(this.placedOrientations[d]=o[d]);r?this.lastPlacementChangeTime=t:"number"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},ve.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,a=e;n<a.length;n+=1){var i=a[n],o=i.getBucket(t);o&&i.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,i.collisionBoxArray)}},ve.prototype.updateBucketOpacities=function(e,r,n){e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexArray.clear(),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexArray.clear();var a=e.layers[0].layout,i=new he(null,0,!1,!1,!0),o=a.get("text-allow-overlap"),s=a.get("icon-allow-overlap"),l=a.get("text-variable-anchor"),c="map"===a.get("text-rotation-alignment"),u="map"===a.get("text-pitch-alignment"),h=new he(null,0,o&&(s||!e.hasIconData()||a.get("icon-optional")),s&&(o||!e.hasTextData()||a.get("text-optional")),!0);!e.collisionArrays&&n&&(e.hasCollisionBoxData()||e.hasCollisionCircleData())&&e.deserializeCollisionBoxes(n);for(var f=0;f<e.symbolInstances.length;f++){var p=e.symbolInstances.get(f),d=p.numHorizontalGlyphVertices,g=p.numVerticalGlyphVertices,v=p.crossTileID,m=r[v],y=this.opacities[v];m?y=i:y||(y=h,this.opacities[v]=y),r[v]=!0;var x=d>0||g>0,b=p.numIconVertices>0;if(x){for(var _=Me(y.text),w=(d+g)/4,k=0;k<w;k++)e.text.opacityVertexArray.emplaceBack(_);var T=y.text.isHidden()?1:0,M=this.placedOrientations[p.crossTileID],A=M===t.WritingMode.horizontal||M===t.WritingMode.horizontalOnly?1:0,S=M===t.WritingMode.vertical?1:0;[p.rightJustifiedTextSymbolIndex,p.centerJustifiedTextSymbolIndex,p.leftJustifiedTextSymbolIndex].forEach(function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=T||S)}),p.verticalPlacedTextSymbolIndex>=0&&(e.text.placedSymbolArray.get(p.verticalPlacedTextSymbolIndex).hidden=T||A);var E=this.variableOffsets[p.crossTileID];E&&this.markUsedJustification(e,E.anchor,p,M);var L=this.placedOrientations[p.crossTileID];L&&(this.markUsedJustification(e,"left",p,L),this.markUsedOrientation(e,L,p))}if(b){for(var C=Me(y.icon),P=0;P<p.numIconVertices/4;P++)e.icon.opacityVertexArray.emplaceBack(C);e.icon.placedSymbolArray.get(f).hidden=y.icon.isHidden()}if(e.hasCollisionBoxData()||e.hasCollisionCircleData()){var O=e.collisionArrays[f];if(O){if(O.textBox){var z=new t.Point(0,0),I=!0;if(l){var D=this.variableOffsets[v];D?(z=ge(D.anchor,D.width,D.height,D.radialOffset,D.textBoxScale),c&&z._rotate(u?this.transform.angle:-this.transform.angle)):I=!1}me(e.collisionBox.collisionVertexArray,y.text.placed,!I,z.x,z.y)}O.iconBox&&me(e.collisionBox.collisionVertexArray,y.icon.placed,!1);var R=O.textCircles;if(R&&e.hasCollisionCircleData())for(var F=0;F<R.length;F+=5){var B=m||0===R[F+4];me(e.collisionCircle.collisionVertexArray,y.text.placed,B)}}}}e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexBuffer&&e.collisionBox.collisionVertexBuffer.updateData(e.collisionBox.collisionVertexArray),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexBuffer&&e.collisionCircle.collisionVertexBuffer.updateData(e.collisionCircle.collisionVertexArray)},ve.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration},ve.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},ve.prototype.stillRecent=function(t){return this.commitTime+this.fadeDuration>t},ve.prototype.setStale=function(){this.stale=!0};var ye=Math.pow(2,25),xe=Math.pow(2,24),be=Math.pow(2,17),_e=Math.pow(2,16),we=Math.pow(2,9),ke=Math.pow(2,8),Te=Math.pow(2,1);function Me(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*ye+e*xe+r*be+e*_e+r*we+e*ke+r*Te+e}var Ae=function(){this._currentTileIndex=0,this._seenCrossTileIDs={}};Ae.prototype.continuePlacement=function(t,e,r,n,a){for(;this._currentTileIndex<t.length;){var i=t[this._currentTileIndex];if(e.placeLayerTile(n,i,r,this._seenCrossTileIDs),this._currentTileIndex++,a())return!0}};var Se=function(t,e,r,n,a,i,o){this.placement=new ve(t,a,i,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};Se.prototype.isDone=function(){return this._done},Se.prototype.continuePlacement=function(e,r,n){for(var a=this,i=t.browser.now(),o=function(){var e=t.browser.now()-i;return!a._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if("symbol"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Ae),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},Se.prototype.commit=function(t){return this.placement.commit(t),this.placement};var Ee=512/t.EXTENT/2,Le=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var a=e.get(n),i=a.key;this.indexedSymbolInstances[i]||(this.indexedSymbolInstances[i]=[]),this.indexedSymbolInstances[i].push({crossTileID:a.crossTileID,coord:this.getScaledCoordinates(a,t)})}};Le.prototype.getScaledCoordinates=function(e,r){var n=r.canonical.z-this.tileID.canonical.z,a=Ee/Math.pow(2,n);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*a),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*a)}},Le.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),a=0;a<t.length;a++){var i=t.get(a);if(!i.crossTileID){var o=this.indexedSymbolInstances[i.key];if(o)for(var s=this.getScaledCoordinates(i,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,i.crossTileID=u.crossTileID;break}}}}};var Ce=function(){this.maxCrossTileID=0};Ce.prototype.generate=function(){return++this.maxCrossTileID};var Pe=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Pe.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],a={};for(var i in n){var o=n[i];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),a[o.tileID.key]=o}this.indexes[r]=a}this.lng=t},Pe.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++)e.symbolInstances.get(n).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var a=this.usedCrossTileIDs[t.overscaledZ];for(var i in this.indexes){var o=this.indexes[i];if(Number(i)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,a)}else{var c=o[t.scaledTo(Number(i)).key];c&&c.findMatches(e.symbolInstances,t,a)}}for(var u=0;u<e.symbolInstances.length;u++){var h=e.symbolInstances.get(u);h.crossTileID||(h.crossTileID=r.generate(),a[h.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new Le(t,e.symbolInstances,e.bucketInstanceId),!0},Pe.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,a=e.indexedSymbolInstances[r];n<a.length;n+=1){var i=a[n];delete this.usedCrossTileIDs[t][i.crossTileID]}},Pe.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var a in n)t[n[a].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[a]),delete n[a],e=!0)}return e};var Oe=function(){this.layerIndexes={},this.crossTileIDs=new Ce,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Oe.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Pe);var a=!1,i={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(a=!0),i[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(i)&&(a=!0),a},Oe.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach(function(t){e[t]=!0}),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var ze=function(e,r){return t.emitValidationErrors(e,r&&r.filter(function(t){return"source.canvas"!==t.identifier}))},Ie=t.pick(Nt,["addLayer","removeLayer","setPaintProperty","setLayoutProperty","setFilter","addSource","removeSource","setLayerZoomRange","setLight","setTransition","setGeoJSONSourceData"]),De=t.pick(Nt,["setCenter","setZoom","setBearing","setPitch"]),Re=function(e){function r(n,a){var i=this;void 0===a&&(a={}),e.call(this),this.map=n,this.dispatcher=new T((Dt||(Dt=new It),Dt),this),this.imageManager=new f,this.imageManager.setEventedParent(this),this.glyphManager=new x(n._requestManager,a.localIdeographFontFamily),this.lineAtlas=new k(256,512),this.crossTileSymbolIndex=new Oe,this._layers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._resetUpdates(),this.dispatcher.broadcast("setReferrer",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginAvailability(function(t){for(var e in o.dispatcher.broadcast("loadRTLTextPlugin",t.pluginURL,t.completionCallback),o.sourceCaches)o.sourceCaches[e].reload()}),this.on("data",function(t){if("source"===t.dataType&&"metadata"===t.sourceDataType){var e=i.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in i._layers){var a=i._layers[n];a.source===r.id&&i._validateLayer(a)}}}})}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event("dataloading",{dataType:"style"}));var a="boolean"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var i=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(i,function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,a)})},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event("dataloading",{dataType:"style"})),this._request=t.browser.frame(function(){n._request=null,n._load(e,!1!==r.validate)})},r.prototype._load=function(e,r){var n=this;if(!r||!ze(this,t.validateStyle(e))){for(var a in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(a,e.sources[a],{validate:!1});e.sprite?this._spriteRequest=function(e,r,n){var a,i,o,s=t.browser.devicePixelRatio>1?"@2x":"",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,".json"),t.ResourceType.SpriteJSON),function(t,e){l=null,o||(o=t,a=e,u())}),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,".png"),t.ResourceType.SpriteImage),function(t,e){c=null,o||(o=t,i=e,u())});function u(){if(o)n(o);else if(a&&i){var e=t.browser.getImageData(i),r={};for(var s in a){var l=a[s],c=l.width,u=l.height,h=l.x,f=l.y,p=l.sdf,d=l.pixelRatio,g=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,g,{x:h,y:f},{x:0,y:0},{width:c,height:u}),r[s]={data:g,pixelRatio:d,sdf:p}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e.sprite,this.map._requestManager,function(e,r){if(n._spriteRequest=null,e)n.fire(new t.ErrorEvent(e));else if(r)for(var a in r)n.imageManager.addImage(a,r[a]);n.imageManager.setLoaded(!0),n.fire(new t.Event("data",{dataType:"style"}))}):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var i=Bt(this.stylesheet.layers);this._order=i.map(function(t){return t.id}),this._layers={};for(var o=0,s=i;o<s.length;o+=1){var l=s[o];(l=t.createStyleLayer(l)).setEventedParent(this,{layer:{id:l.id}}),this._layers[l.id]=l}this.dispatcher.broadcast("setLayers",this._serializeLayers(this._order)),this.light=new w(this.stylesheet.light),this.fire(new t.Event("data",{dataType:"style"})),this.fire(new t.Event("style.load"))}},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var a=r.getSource();("geojson"===a.type||a.vectorLayerIds&&-1===a.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer "'+n+'" does not exist on source "'+a.id+'" as specified by style layer "'+e.id+'"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var a=n[r],i=this._layers[a];"custom"!==i.type&&e.push(i.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error("Style is not done loading")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),a=Object.keys(this._removedLayers);for(var i in(n.length||a.length)&&this._updateWorkerLayers(n,a),this._updatedSources){var o=this._updatedSources[i];"reload"===o?this._reloadSource(i):"clear"===o&&this._clearSource(i)}for(var s in this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}for(var l in this.sourceCaches)this.sourceCaches[l].used=!1;for(var c=0,u=this._order;c<u.length;c+=1){var h=u[c],f=this._layers[h];f.recalculate(e),!f.isHidden(e.zoom)&&f.source&&(this.sourceCaches[f.source].used=!0)}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event("data",{dataType:"style"}))}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast("updateLayers",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),ze(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=Bt(e.layers);var n=function(e,r){if(!e)return[{command:Nt.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:Nt.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:Nt.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:Nt.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:Nt.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:Nt.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:Nt.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:Nt.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:Nt.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:Nt.setLight,args:[r.light]});var a={},i=[];!function(e,r,n,a){var i;for(i in r=r||{},e=e||{})e.hasOwnProperty(i)&&(r.hasOwnProperty(i)||Vt(i,n,a));for(i in r)r.hasOwnProperty(i)&&(e.hasOwnProperty(i)?t.deepEqual(e[i],r[i])||("geojson"===e[i].type&&"geojson"===r[i].type&&qt(e,r,i)?n.push({command:Nt.setGeoJSONSourceData,args:[i,r[i].data]}):Ut(i,r,n,a)):jt(i,r,n))}(e.sources,r.sources,i,a);var o=[];e.layers&&e.layers.forEach(function(t){a[t.source]?n.push({command:Nt.removeLayer,args:[t.id]}):o.push(t)}),n=n.concat(i),function(e,r,n){r=r||[];var a,i,o,s,l,c,u,h=(e=e||[]).map(Gt),f=r.map(Gt),p=e.reduce(Yt,{}),d=r.reduce(Yt,{}),g=h.slice(),v=Object.create(null);for(a=0,i=0;a<h.length;a++)o=h[a],d.hasOwnProperty(o)?i++:(n.push({command:Nt.removeLayer,args:[o]}),g.splice(g.indexOf(o,i),1));for(a=0,i=0;a<f.length;a++)o=f[f.length-1-a],g[g.length-1-a]!==o&&(p.hasOwnProperty(o)?(n.push({command:Nt.removeLayer,args:[o]}),g.splice(g.lastIndexOf(o,g.length-i),1)):i++,c=g[g.length-a],n.push({command:Nt.addLayer,args:[d[o],c]}),g.splice(g.length-a,0,o),v[o]=!0);for(a=0;a<f.length;a++)if(s=p[o=f[a]],l=d[o],!v[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s["source-layer"],l["source-layer"])&&t.deepEqual(s.type,l.type)){for(u in Ht(s.layout,l.layout,n,o,null,Nt.setLayoutProperty),Ht(s.paint,l.paint,n,o,null,Nt.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:Nt.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:Nt.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&"layout"!==u&&"paint"!==u&&"filter"!==u&&"metadata"!==u&&"minzoom"!==u&&"maxzoom"!==u&&(0===u.indexOf("paint.")?Ht(s[u],l[u],n,o,u.slice(6),Nt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Nt.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&"layout"!==u&&"paint"!==u&&"filter"!==u&&"metadata"!==u&&"minzoom"!==u&&"maxzoom"!==u&&(0===u.indexOf("paint.")?Ht(s[u],l[u],n,o,u.slice(6),Nt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Nt.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:Nt.removeLayer,args:[o]}),c=g[g.lastIndexOf(o)+1],n.push({command:Nt.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn("Unable to compute style diff:",t),n=[{command:Nt.setStyle,args:[r]}]}return n}(this.serialize(),e).filter(function(t){return!(t.command in De)});if(0===n.length)return!1;var a=n.filter(function(t){return!(t.command in Ie)});if(a.length>0)throw new Error("Unimplemented: "+a.map(function(t){return t.command}).join(", ")+".");return n.forEach(function(t){"setTransition"!==t.command&&r[t.command].apply(r,t.args)}),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error("An image with this name already exists.")));this.imageManager.addImage(e,r),this.fire(new t.Event("data",{dataType:"style"}))},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error("No image with this name exists.")));this.imageManager.removeImage(e),this.fire(new t.Event("data",{dataType:"style"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var a=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error("There is already a source with this ID");if(!r.type)throw new Error("The type property must be defined, but the only the following properties were given: "+Object.keys(r).join(", ")+".");if(!(["vector","raster","geojson","video","image"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,"sources."+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var i=this.sourceCaches[e]=new Ct(e,r,this.dispatcher);i.style=this,i.setEventedParent(this,function(){return{isSourceLoaded:a.loaded(),source:i.serialize(),sourceId:e}}),i.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error("There is no source with this ID");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source "'+e+'" cannot be removed while layer "'+r+'" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event("data",{sourceDataType:"metadata",dataType:"source",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var a=e.id;if(this.getLayer(a))this.fire(new t.ErrorEvent(new Error('Layer with id "'+a+'" already exists on this map')));else{var i;if("custom"===e.type){if(ze(this,t.validateCustomStyleLayer(e)))return;i=t.createStyleLayer(e)}else{if("object"==typeof e.source&&(this.addSource(a,e.source),e=t.clone$1(e),e=t.extend(e,{source:a})),this._validate(t.validateStyle.layer,"layers."+a,e,{arrayIndex:-1},n))return;i=t.createStyleLayer(e),this._validateLayer(i),i.setEventedParent(this,{layer:{id:a}})}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id "'+r+'" does not exist on this map.')));else{if(this._order.splice(o,0,a),this._layerOrderChanged=!0,this._layers[a]=i,this._removedLayers[a]&&i.source&&"custom"!==i.type){var s=this._removedLayers[a];delete this._removedLayers[a],s.type!==i.type?this._updatedSources[i.source]="clear":(this._updatedSources[i.source]="reload",this.sourceCaches[i.source].pause())}this._updateLayer(i),i.onAdd&&i.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var a=r?this._order.indexOf(r):this._order.length;r&&-1===a?this.fire(new t.ErrorEvent(new Error('Layer with id "'+r+'" does not exist on this map.'))):(this._order.splice(a,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error("The layer '"+e+"' does not exist in the map's style and cannot be moved.")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error("The layer '"+e+"' does not exist in the map's style and cannot be removed.")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var a=this.getLayer(e);a?a.minzoom===r&&a.maxzoom===n||(null!=r&&(a.minzoom=r),null!=n&&(a.maxzoom=n),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error("The layer '"+e+"' does not exist in the map's style and cannot have zoom extent.")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var a=this.getLayer(e);if(a){if(!t.deepEqual(a.filter,r))return null==r?(a.filter=void 0,void this._updateLayer(a)):void(this._validate(t.validateStyle.filter,"layers."+a.id+".filter",r,null,n)||(a.filter=t.clone$1(r),this._updateLayer(a)))}else this.fire(new t.ErrorEvent(new Error("The layer '"+e+"' does not exist in the map's style and cannot be filtered.")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,a){void 0===a&&(a={}),this._checkLoaded();var i=this.getLayer(e);i?t.deepEqual(i.getLayoutProperty(r),n)||(i.setLayoutProperty(r,n,a),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error("The layer '"+e+"' does not exist in the map's style and cannot be styled.")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error("The layer '"+e+"' does not exist in the map's style.")))},r.prototype.setPaintProperty=function(e,r,n,a){void 0===a&&(a={}),this._checkLoaded();var i=this.getLayer(e);i?t.deepEqual(i.getPaintProperty(r),n)||(i.setPaintProperty(r,n,a)&&this._updateLayer(i),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error("The layer '"+e+"' does not exist in the map's style and cannot be styled.")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,a=e.sourceLayer,i=this.sourceCaches[n],o=parseInt(e.id,10);if(void 0!==i){var s=i.getSource().type;"geojson"===s&&a?this.fire(new t.ErrorEvent(new Error("GeoJSON sources cannot have a sourceLayer parameter."))):"vector"!==s||a?isNaN(o)||o<0?this.fire(new t.ErrorEvent(new Error("The feature id parameter must be provided and non-negative."))):i.setFeatureState(a,o,r):this.fire(new t.ErrorEvent(new Error("The sourceLayer parameter must be provided for vector source types.")))}else this.fire(new t.ErrorEvent(new Error("The source '"+n+"' does not exist in the map's style.")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,a=this.sourceCaches[n];if(void 0!==a){var i=a.getSource().type,o="vector"===i?e.sourceLayer:void 0,s=parseInt(e.id,10);"vector"!==i||o?void 0!==e.id&&isNaN(s)||s<0?this.fire(new t.ErrorEvent(new Error("The feature id parameter must be non-negative."))):r&&"string"!=typeof e.id&&"number"!=typeof e.id?this.fire(new t.ErrorEvent(new Error("A feature id is requred to remove its specific state property."))):a.removeFeatureState(o,s,r):this.fire(new t.ErrorEvent(new Error("The sourceLayer parameter must be provided for vector source types.")))}else this.fire(new t.ErrorEvent(new Error("The source '"+n+"' does not exist in the map's style.")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,a=this.sourceCaches[r],i=parseInt(e.id,10);if(void 0!==a)if("vector"!==a.getSource().type||n){if(!(isNaN(i)||i<0))return a.getFeatureState(n,i);this.fire(new t.ErrorEvent(new Error("The feature id parameter must be provided and non-negative.")))}else this.fire(new t.ErrorEvent(new Error("The sourceLayer parameter must be provided for vector source types.")));else this.fire(new t.ErrorEvent(new Error("The source '"+r+"' does not exist in the map's style.")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,function(t){return t.serialize()}),layers:this._serializeLayers(this._order)},function(t){return void 0!==t})},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&(this._updatedSources[t.source]="reload",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return"fill-extrusion"===e._layers[t].type},n={},a=[],i=this._order.length-1;i>=0;i--){var o=this._order[i];if(r(o)){n[o]=i;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,h=c;u<h.length;u+=1){var f=h[u];a.push(f)}}}}a.sort(function(t,e){return e.intersectionZ-t.intersectionZ});for(var p=[],d=this._order.length-1;d>=0;d--){var g=this._order[d];if(r(g))for(var v=a.length-1;v>=0;v--){var m=a[v].feature;if(n[m.layer.id]<d)break;p.push(m),a.pop()}else for(var y=0,x=t;y<x.length;y+=1){var b=x[y][g];if(b)for(var _=0,w=b;_<w.length;_+=1){var k=w[_];p.push(k.feature)}}}return p},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,"queryRenderedFeatures.filter",r.filter,null,r);var a={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error("parameters.layers must be an Array."))),[];for(var i=0,o=r.layers;i<o.length;i+=1){var s=o[i],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error("The layer '"+s+"' does not exist in the map's style and cannot be queried for features."))),[];a[l.source]=!0}}var c=[];for(var u in this.sourceCaches)r.layers&&!a[u]||c.push(F(this.sourceCaches[u],this._layers,e,r,n));return this.placement&&c.push(function(t,e,r,n,a,i){for(var o={},s=a.queryRenderedSymbols(r),l=[],c=0,u=Object.keys(s).map(Number);c<u.length;c+=1){var h=u[c];l.push(i[h])}l.sort(B);for(var f=function(){var e=d[p],r=e.featureIndex.lookupSymbolFeatures(s[e.bucketInstanceId],e.bucketIndex,e.sourceLayerIndex,n.filter,n.layers,t);for(var a in r){var i=o[a]=o[a]||[],l=r[a];l.sort(function(t,r){var n=e.featureSortOrder;if(n){var a=n.indexOf(t.featureIndex);return n.indexOf(r.featureIndex)-a}return r.featureIndex-t.featureIndex});for(var c=0,u=l;c<u.length;c+=1){var h=u[c];i.push(h)}}},p=0,d=l;p<d.length;p+=1)f();var g=function(r){o[r].forEach(function(n){var a=n.feature,i=t[r],o=e[i.source].getFeatureState(a.layer["source-layer"],a.id);a.source=a.layer.source,a.layer["source-layer"]&&(a.sourceLayer=a.layer["source-layer"]),a.state=o})};for(var v in o)g(v);return o}(this._layers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,"querySourceFeatures.filter",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map(function(e){return t.getTileByID(e)}),n=[],a={},i=0;i<r.length;i++){var o=r[i],s=o.tileID.canonical.key;a[s]||(a[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called "'+t+'" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast("loadWorkerSource",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),a=!1;for(var i in e)if(!t.deepEqual(e[i],n[i])){a=!0;break}if(a){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,a,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&ze(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},a)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off("pluginAvailable",this._rtlTextPluginCallback),this.sourceCaches)this.sourceCaches[e].clearTiles();this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,a){for(var i=!1,o=!1,s={},l=0,c=this._order;l<c.length;l+=1){var u=c[l],h=this._layers[u];if("symbol"===h.type){if(!s[h.source]){var f=this.sourceCaches[h.source];s[h.source]=f.getRenderableIds(!0).map(function(t){return f.getTileByID(t)}).sort(function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)})}var p=this.crossTileSymbolIndex.addLayer(h,s[h.source],e.center.lng);i=i||p}}this.crossTileSymbolIndex.pruneUnusedLayers(this._order);var d=this._layerOrderChanged||0===n;if((d||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now()))&&(this.pauseablePlacement=new Se(e,this._order,d,r,n,a,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,s),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),o=!0),i&&this.pauseablePlacement.placement.setStale()),o||i)for(var g=0,v=this._order;g<v.length;g+=1){var m=v[g],y=this._layers[m];"symbol"===y.type&&this.placement.updateLayerOpacities(y,s[y.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);Re.getSourceType=function(t){return I[t]},Re.setSourceType=function(t,e){I[t]=e},Re.registerForPluginAvailability=t.registerForPluginAvailability;var Fe=t.createLayout([{name:"a_pos",type:"Int16",components:2}]),Be=cr("#ifdef GL_ES\nprecision mediump float;\n#else\n#if !defined(lowp)\n#define lowp\n#endif\n#if !defined(mediump)\n#define mediump\n#endif\n#if !defined(highp)\n#define highp\n#endif\n#endif","#ifdef GL_ES\nprecision highp float;\n#else\n#if !defined(lowp)\n#define lowp\n#endif\n#if !defined(mediump)\n#define mediump\n#endif\n#if !defined(highp)\n#define highp\n#endif\n#endif\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}"),Ne=cr("uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}"),je=cr("uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}"),Ve=cr("varying vec3 v_data;\n#pragma mapbox: define highp vec4 color\n#pragma mapbox: define mediump float radius\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define highp vec4 stroke_color\n#pragma mapbox: define mediump float stroke_width\n#pragma mapbox: define lowp float stroke_opacity\nvoid main() {\n#pragma mapbox: initialize highp vec4 color\n#pragma mapbox: initialize mediump float radius\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize highp vec4 stroke_color\n#pragma mapbox: initialize mediump float stroke_width\n#pragma mapbox: initialize lowp float stroke_opacity\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\n#pragma mapbox: define highp vec4 color\n#pragma mapbox: define mediump float radius\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define highp vec4 stroke_color\n#pragma mapbox: define mediump float stroke_width\n#pragma mapbox: define lowp float stroke_opacity\nvoid main(void) {\n#pragma mapbox: initialize highp vec4 color\n#pragma mapbox: initialize mediump float radius\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize highp vec4 stroke_color\n#pragma mapbox: initialize mediump float stroke_width\n#pragma mapbox: initialize lowp float stroke_opacity\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}"),Ue=cr("void main() {gl_FragColor=vec4(1.0);}","attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}"),qe=cr("uniform highp float u_intensity;varying vec2 v_extrude;\n#pragma mapbox: define highp float weight\n#define GAUSS_COEF 0.3989422804014327\nvoid main() {\n#pragma mapbox: initialize highp float weight\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\n#pragma mapbox: define highp float weight\n#pragma mapbox: define mediump float radius\nconst highp float ZERO=1.0/255.0/16.0;\n#define GAUSS_COEF 0.3989422804014327\nvoid main(void) {\n#pragma mapbox: initialize highp float weight\n#pragma mapbox: initialize mediump float radius\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}"),He=cr("uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(0.0);\n#endif\n}","uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}"),Ge=cr("varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}","attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}"),Ye=cr("uniform float u_overscale_factor;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {float alpha=0.5;vec4 color=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {color=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {color*=.2;}float extrude_scale_length=length(v_extrude_scale);float extrude_length=length(v_extrude)*extrude_scale_length;float stroke_width=15.0*extrude_scale_length/u_overscale_factor;float radius=v_radius*extrude_scale_length;float distance_to_edge=abs(extrude_length-radius);float opacity_t=smoothstep(-stroke_width,0.0,-distance_to_edge);gl_FragColor=opacity_t*color;}","attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);highp float padding_factor=1.2;gl_Position.xy+=a_extrude*u_extrude_scale*padding_factor*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;v_radius=abs(a_extrude.y);v_extrude=a_extrude*padding_factor;v_extrude_scale=u_extrude_scale*u_camera_to_center_distance*collision_perspective_ratio;}"),We=cr("uniform highp vec4 u_color;void main() {gl_FragColor=u_color;}","attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}"),Xe=cr("#pragma mapbox: define highp vec4 color\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize highp vec4 color\n#pragma mapbox: initialize lowp float opacity\ngl_FragColor=color*opacity;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","attribute vec2 a_pos;uniform mat4 u_matrix;\n#pragma mapbox: define highp vec4 color\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize highp vec4 color\n#pragma mapbox: initialize lowp float opacity\ngl_Position=u_matrix*vec4(a_pos,0,1);}"),Ze=cr("varying vec2 v_pos;\n#pragma mapbox: define highp vec4 outline_color\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize highp vec4 outline_color\n#pragma mapbox: initialize lowp float opacity\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\n#pragma mapbox: define highp vec4 outline_color\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize highp vec4 outline_color\n#pragma mapbox: initialize lowp float opacity\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}"),Je=cr("uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define lowp vec4 pattern_from\n#pragma mapbox: define lowp vec4 pattern_to\nvoid main() {\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize mediump vec4 pattern_from\n#pragma mapbox: initialize mediump vec4 pattern_to\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define lowp vec4 pattern_from\n#pragma mapbox: define lowp vec4 pattern_to\nvoid main() {\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize mediump vec4 pattern_from\n#pragma mapbox: initialize mediump vec4 pattern_to\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}"),Ke=cr("uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define lowp vec4 pattern_from\n#pragma mapbox: define lowp vec4 pattern_to\nvoid main() {\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize mediump vec4 pattern_from\n#pragma mapbox: initialize mediump vec4 pattern_to\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define lowp vec4 pattern_from\n#pragma mapbox: define lowp vec4 pattern_to\nvoid main() {\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize mediump vec4 pattern_from\n#pragma mapbox: initialize mediump vec4 pattern_to\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}"),Qe=cr("varying vec4 v_color;void main() {gl_FragColor=v_color;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\n#pragma mapbox: define highp float base\n#pragma mapbox: define highp float height\n#pragma mapbox: define highp vec4 color\nvoid main() {\n#pragma mapbox: initialize highp float base\n#pragma mapbox: initialize highp float height\n#pragma mapbox: initialize highp vec4 color\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}"),$e=cr("uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\n#pragma mapbox: define lowp float base\n#pragma mapbox: define lowp float height\n#pragma mapbox: define lowp vec4 pattern_from\n#pragma mapbox: define lowp vec4 pattern_to\nvoid main() {\n#pragma mapbox: initialize lowp float base\n#pragma mapbox: initialize lowp float height\n#pragma mapbox: initialize mediump vec4 pattern_from\n#pragma mapbox: initialize mediump vec4 pattern_to\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec4 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\n#pragma mapbox: define lowp float base\n#pragma mapbox: define lowp float height\n#pragma mapbox: define lowp vec4 pattern_from\n#pragma mapbox: define lowp vec4 pattern_to\nvoid main() {\n#pragma mapbox: initialize lowp float base\n#pragma mapbox: initialize lowp float height\n#pragma mapbox: initialize mediump vec4 pattern_from\n#pragma mapbox: initialize mediump vec4 pattern_to\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\n? a_pos\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}"),tr=cr("#ifdef GL_ES\nprecision highp float;\n#endif\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform float u_maxzoom;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;return (data.r+data.g*256.0+data.b*256.0*256.0)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggeration=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/ pow(2.0,(u_zoom-u_maxzoom)*exaggeration+19.2562-u_zoom);gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}"),er=cr("uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\n#define PI 3.141592653589793\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}"),rr=cr("uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\n#pragma mapbox: define highp vec4 color\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize highp vec4 color\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","\n#define scale 0.015873016\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\n#pragma mapbox: define highp vec4 color\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define mediump float gapwidth\n#pragma mapbox: define lowp float offset\n#pragma mapbox: define mediump float width\nvoid main() {\n#pragma mapbox: initialize highp vec4 color\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize mediump float gapwidth\n#pragma mapbox: initialize lowp float offset\n#pragma mapbox: initialize mediump float width\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}"),nr=cr("uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp float v_lineprogress;\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,vec2(v_lineprogress,0.5));gl_FragColor=color*(alpha*opacity);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","\n#define MAX_LINE_DISTANCE 32767.0\n#define scale 0.015873016\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_lineprogress;\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define mediump float gapwidth\n#pragma mapbox: define lowp float offset\n#pragma mapbox: define mediump float width\nvoid main() {\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize mediump float gapwidth\n#pragma mapbox: initialize lowp float offset\n#pragma mapbox: initialize mediump float width\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_lineprogress=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0/MAX_LINE_DISTANCE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}"),ar=cr("uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec4 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\n#pragma mapbox: define lowp vec4 pattern_from\n#pragma mapbox: define lowp vec4 pattern_to\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize mediump vec4 pattern_from\n#pragma mapbox: initialize mediump vec4 pattern_to\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x,1.0);float x_b=mod(v_linesofar/pattern_size_b.x,1.0);float y_a=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_a.y+2.0)/2.0)/pattern_size_a.y);float y_b=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_b.y+2.0)/2.0)/pattern_size_b.y);vec2 pos_a=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,vec2(x_a,y_a));vec2 pos_b=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,vec2(x_b,y_b));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","\n#define scale 0.015873016\n#define LINE_DISTANCE_SCALE 2.0\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define lowp float offset\n#pragma mapbox: define mediump float gapwidth\n#pragma mapbox: define mediump float width\n#pragma mapbox: define lowp vec4 pattern_from\n#pragma mapbox: define lowp vec4 pattern_to\nvoid main() {\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize lowp float offset\n#pragma mapbox: initialize mediump float gapwidth\n#pragma mapbox: initialize mediump float width\n#pragma mapbox: initialize mediump vec4 pattern_from\n#pragma mapbox: initialize mediump vec4 pattern_to\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);}"),ir=cr("uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\n#pragma mapbox: define highp vec4 color\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define mediump float width\n#pragma mapbox: define lowp float floorwidth\nvoid main() {\n#pragma mapbox: initialize highp vec4 color\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize mediump float width\n#pragma mapbox: initialize lowp float floorwidth\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","\n#define scale 0.015873016\n#define LINE_DISTANCE_SCALE 2.0\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\n#pragma mapbox: define highp vec4 color\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define mediump float gapwidth\n#pragma mapbox: define lowp float offset\n#pragma mapbox: define mediump float width\n#pragma mapbox: define lowp float floorwidth\nvoid main() {\n#pragma mapbox: initialize highp vec4 color\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize mediump float gapwidth\n#pragma mapbox: initialize lowp float offset\n#pragma mapbox: initialize mediump float width\n#pragma mapbox: initialize lowp float floorwidth\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}"),or=cr("uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}"),sr=cr("uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize lowp float opacity\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize lowp float opacity\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\ncamera_to_anchor_distance/u_camera_to_center_distance :\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}"),lr=cr("#define SDF_PX 8.0\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\n#pragma mapbox: define highp vec4 fill_color\n#pragma mapbox: define highp vec4 halo_color\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define lowp float halo_width\n#pragma mapbox: define lowp float halo_blur\nvoid main() {\n#pragma mapbox: initialize highp vec4 fill_color\n#pragma mapbox: initialize highp vec4 halo_color\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize lowp float halo_width\n#pragma mapbox: initialize lowp float halo_blur\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\n#pragma mapbox: define highp vec4 fill_color\n#pragma mapbox: define highp vec4 halo_color\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define lowp float halo_width\n#pragma mapbox: define lowp float halo_blur\nvoid main() {\n#pragma mapbox: initialize highp vec4 fill_color\n#pragma mapbox: initialize highp vec4 halo_color\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize lowp float halo_width\n#pragma mapbox: initialize lowp float halo_blur\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\ncamera_to_anchor_distance/u_camera_to_center_distance :\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=vec2(tex.x,tex.y);v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}");function cr(t,e){var r=/#pragma mapbox: ([\w]+) ([\w]+) ([\w]+) ([\w]+)/g,n={};return{fragmentSource:t=t.replace(r,function(t,e,r,a,i){return n[i]=!0,"define"===e?"\n#ifndef HAS_UNIFORM_u_"+i+"\nvarying "+r+" "+a+" "+i+";\n#else\nuniform "+r+" "+a+" u_"+i+";\n#endif\n":"\n#ifdef HAS_UNIFORM_u_"+i+"\n    "+r+" "+a+" "+i+" = u_"+i+";\n#endif\n"}),vertexSource:e=e.replace(r,function(t,e,r,a,i){var o="float"===a?"vec2":"vec4",s=i.match(/color/)?"color":o;return n[i]?"define"===e?"\n#ifndef HAS_UNIFORM_u_"+i+"\nuniform lowp float u_"+i+"_t;\nattribute "+r+" "+o+" a_"+i+";\nvarying "+r+" "+a+" "+i+";\n#else\nuniform "+r+" "+a+" u_"+i+";\n#endif\n":"vec4"===s?"\n#ifndef HAS_UNIFORM_u_"+i+"\n    "+i+" = a_"+i+";\n#else\n    "+r+" "+a+" "+i+" = u_"+i+";\n#endif\n":"\n#ifndef HAS_UNIFORM_u_"+i+"\n    "+i+" = unpack_mix_"+s+"(a_"+i+", u_"+i+"_t);\n#else\n    "+r+" "+a+" "+i+" = u_"+i+";\n#endif\n":"define"===e?"\n#ifndef HAS_UNIFORM_u_"+i+"\nuniform lowp float u_"+i+"_t;\nattribute "+r+" "+o+" a_"+i+";\n#else\nuniform "+r+" "+a+" u_"+i+";\n#endif\n":"vec4"===s?"\n#ifndef HAS_UNIFORM_u_"+i+"\n    "+r+" "+a+" "+i+" = a_"+i+";\n#else\n    "+r+" "+a+" "+i+" = u_"+i+";\n#endif\n":"\n#ifndef HAS_UNIFORM_u_"+i+"\n    "+r+" "+a+" "+i+" = unpack_mix_"+s+"(a_"+i+", u_"+i+"_t);\n#else\n    "+r+" "+a+" "+i+" = u_"+i+";\n#endif\n"})}}var ur=Object.freeze({prelude:Be,background:Ne,backgroundPattern:je,circle:Ve,clippingMask:Ue,heatmap:qe,heatmapTexture:He,collisionBox:Ge,collisionCircle:Ye,debug:We,fill:Xe,fillOutline:Ze,fillOutlinePattern:Je,fillPattern:Ke,fillExtrusion:Qe,fillExtrusionPattern:$e,hillshadePrepare:tr,hillshade:er,line:rr,lineGradient:nr,linePattern:ar,lineSDF:ir,raster:or,symbolIcon:sr,symbolSDF:lr}),hr=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};hr.prototype.bind=function(t,e,r,n,a,i,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);var u=!this.vao||this.boundProgram!==e||this.boundLayoutVertexBuffer!==r||l||this.boundIndexBuffer!==a||this.boundVertexOffset!==i||this.boundDynamicVertexBuffer!==o||this.boundDynamicVertexBuffer2!==s;!t.extVertexArrayObject||u?this.freshBind(e,r,n,a,i,o,s):(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),a&&a.dynamicDraw&&a.bind(),s&&s.bind())},hr.prototype.freshBind=function(t,e,r,n,a,i,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=a,this.boundDynamicVertexBuffer=i,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var h=l;h<s;h++)u.disableVertexAttribArray(h)}e.enableAttributes(u,t);for(var f=0,p=r;f<p.length;f+=1)p[f].enableAttributes(u,t);i&&i.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,a);for(var d=0,g=r;d<g.length;d+=1){var v=g[d];v.bind(),v.setVertexAttribPointers(u,t,a)}i&&(i.bind(),i.setVertexAttribPointers(u,t,a)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,a)),c.currentNumAttributes=l},hr.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var fr=function(t,e,r,n,a){var i=t.gl;this.program=i.createProgram();var o=r.defines();a&&o.push("#define OVERDRAW_INSPECTOR;");var s=o.concat(Be.fragmentSource,e.fragmentSource).join("\n"),l=o.concat(Be.vertexSource,e.vertexSource).join("\n"),c=i.createShader(i.FRAGMENT_SHADER);i.shaderSource(c,s),i.compileShader(c),i.attachShader(this.program,c);var u=i.createShader(i.VERTEX_SHADER);i.shaderSource(u,l),i.compileShader(u),i.attachShader(this.program,u);for(var h=r.layoutAttributes||[],f=0;f<h.length;f++)i.bindAttribLocation(this.program,f,h[f].name);i.linkProgram(this.program),this.numAttributes=i.getProgramParameter(this.program,i.ACTIVE_ATTRIBUTES),this.attributes={};for(var p={},d=0;d<this.numAttributes;d++){var g=i.getActiveAttrib(this.program,d);g&&(this.attributes[g.name]=i.getAttribLocation(this.program,g.name))}for(var v=i.getProgramParameter(this.program,i.ACTIVE_UNIFORMS),m=0;m<v;m++){var y=i.getActiveUniform(this.program,m);y&&(p[y.name]=i.getUniformLocation(this.program,y.name))}this.fixedUniforms=n(t,p),this.binderUniforms=r.getUniforms(t,p)};function pr(e,r,n){var a=1/ce(n,1,r.transform.tileZoom),i=Math.pow(2,n.tileID.overscaledZ),o=n.tileSize*Math.pow(2,r.transform.tileZoom)/i,s=o*(n.tileID.canonical.x+n.tileID.wrap*i),l=o*n.tileID.canonical.y;return{u_image:0,u_texsize:n.imageAtlasTexture.size,u_scale:[t.browser.devicePixelRatio,a,e.fromScale,e.toScale],u_fade:e.t,u_pixel_coord_upper:[s>>16,l>>16],u_pixel_coord_lower:[65535&s,65535&l]}}fr.prototype.draw=function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g){var v,m=t.gl;for(var y in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(a),t.setCullFace(i),this.fixedUniforms)this.fixedUniforms[y].set(o[y]);p&&p.setUniforms(t,this.binderUniforms,h,{zoom:f});for(var x=(v={},v[m.LINES]=2,v[m.TRIANGLES]=3,v[m.LINE_STRIP]=1,v)[e],b=0,_=u.get();b<_.length;b+=1){var w=_[b],k=w.vaos||(w.vaos={});(k[s]||(k[s]=new hr)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,g),m.drawElements(e,w.primitiveLength*x,m.UNSIGNED_SHORT,w.primitiveOffset*x*2)}};var dr=function(e,r,n,a){var i=r.style.light,o=i.properties.get("position"),s=[o.x,o.y,o.z],l=t.create$1();"viewport"===i.properties.get("anchor")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=i.properties.get("color");return{u_matrix:e,u_lightpos:s,u_lightintensity:i.properties.get("intensity"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:a}},gr=function(e,r,n,a,i,o,s){return t.extend(dr(e,r,n,a),pr(o,r,s),{u_height_factor:-Math.pow(2,i.overscaledZ)/s.tileSize/8})},vr=function(t){return{u_matrix:t}},mr=function(e,r,n,a){return t.extend(vr(e),pr(n,r,a))},yr=function(t,e){return{u_matrix:t,u_world:e}},xr=function(e,r,n,a,i){return t.extend(mr(e,r,n,a),{u_world:i})},br=function(e,r,n,a){var i,o,s=e.transform;if("map"===a.paint.get("circle-pitch-alignment")){var l=ce(n,1,s.zoom);i=!0,o=[l,l]}else i=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+("map"===a.paint.get("circle-pitch-scale")),u_matrix:e.translatePosMatrix(r.posMatrix,n,a.paint.get("circle-translate"),a.paint.get("circle-translate-anchor")),u_pitch_with_map:+i,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},_r=function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},wr=function(t,e,r){var n=ce(r,1,e.zoom),a=Math.pow(2,e.zoom-r.tileID.overscaledZ),i=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*a),e.pixelsToGLUnits[1]/(n*a)],u_overscale_factor:i}},kr=function(t,e){return{u_matrix:t,u_color:e}},Tr=function(t){return{u_matrix:t}},Mr=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:ce(e,1,r),u_intensity:n}},Ar=function(t,e,r){var n=r.paint.get("hillshade-shadow-color"),a=r.paint.get("hillshade-highlight-color"),i=r.paint.get("hillshade-accent-color"),o=r.paint.get("hillshade-illumination-direction")*(Math.PI/180);"viewport"===r.paint.get("hillshade-illumination-anchor")&&(o-=t.transform.angle);var s=!t.options.moving;return{u_matrix:t.transform.calculatePosMatrix(e.tileID.toUnwrapped(),s),u_image:0,u_latrange:Er(t,e.tileID),u_light:[r.paint.get("hillshade-exaggeration"),o],u_shadow:n,u_highlight:a,u_accent:i}},Sr=function(e,r){var n=e.dem.stride,a=t.create();return t.ortho(a,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(a,a,[0,-t.EXTENT,0]),{u_matrix:a,u_image:1,u_dimension:[n,n],u_zoom:e.tileID.overscaledZ,u_maxzoom:r}};function Er(e,r){var n=Math.pow(2,r.canonical.z),a=r.canonical.y;return[new t.MercatorCoordinate(0,a/n).toLngLat().lat,new t.MercatorCoordinate(0,(a+1)/n).toLngLat().lat]}var Lr=function(e,r,n){var a=e.transform;return{u_matrix:Ir(e,r,n),u_ratio:1/ce(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Cr=function(e,r,n){return t.extend(Lr(e,r,n),{u_image:0})},Pr=function(e,r,n,a){var i=e.transform,o=zr(r,i);return{u_matrix:Ir(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/ce(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[t.browser.devicePixelRatio,o,a.fromScale,a.toScale],u_fade:a.t,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},Or=function(e,r,n,a,i){var o=e.transform,s=e.lineAtlas,l=zr(r,o),c="round"===n.layout.get("line-cap"),u=s.getDash(a.from,c),h=s.getDash(a.to,c),f=u.width*i.fromScale,p=h.width*i.toScale;return t.extend(Lr(e,r,n),{u_patternscale_a:[l/f,-u.height/2],u_patternscale_b:[l/p,-h.height/2],u_sdfgamma:s.width/(256*Math.min(f,p)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:u.y,u_tex_y_b:h.y,u_mix:i.t})};function zr(t,e){return 1/ce(t,1,e.tileZoom)}function Ir(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get("line-translate"),r.paint.get("line-translate-anchor"))}var Dr=function(t,e,r,n,a){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*a.paint.get("raster-opacity"),u_image0:0,u_image1:1,u_brightness_low:a.paint.get("raster-brightness-min"),u_brightness_high:a.paint.get("raster-brightness-max"),u_saturation_factor:(o=a.paint.get("raster-saturation"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(i=a.paint.get("raster-contrast"),i>0?1/(1-i):1+i),u_spin_weights:Rr(a.paint.get("raster-hue-rotate"))};var i,o};function Rr(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}var Fr=function(t,e,r,n,a,i,o,s,l,c){var u=a.transform;return{u_is_size_zoom_constant:+("constant"===t||"source"===t),u_is_size_feature_constant:+("constant"===t||"camera"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:a.options.fadeDuration?a.symbolFadeChange:1,u_matrix:i,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Br=function(e,r,n,a,i,o,s,l,c,u,h){var f=i.transform;return t.extend(Fr(e,r,n,a,i,o,s,l,c,u),{u_gamma_scale:a?Math.cos(f._pitch)*f.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+h})},Nr=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},jr=function(e,r,n,a,i,o){return t.extend(function(t,e,r,n){var a=r.imageManager.getPattern(t.from),i=r.imageManager.getPattern(t.to),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,h=u*(n.tileID.canonical.x+n.tileID.wrap*c),f=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:a.tl,u_pattern_br_a:a.br,u_pattern_tl_b:i.tl,u_pattern_br_b:i.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:a.displaySize,u_pattern_size_b:i.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/ce(n,1,r.transform.tileZoom),u_pixel_coord_upper:[h>>16,f>>16],u_pixel_coord_lower:[65535&h,65535&f]}}(a,o,n,i),{u_matrix:e,u_opacity:r})},Vr={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:_r,collisionCircle:_r,debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_maxzoom:new t.Uniform1f(e,r.u_maxzoom)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1f(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function Ur(e,r){for(var n=e.sort(function(t,e){return t.tileID.isLessThan(e.tileID)?-1:e.tileID.isLessThan(t.tileID)?1:0}),a=0;a<n.length;a++){var i={},o=n[a],s=n.slice(a+1);qr(o.tileID.wrapped(),o.tileID,s,new t.OverscaledTileID(0,o.tileID.wrap+1,0,0,0),i),o.setMask(i,r)}}function qr(e,r,n,a,i){for(var o=0;o<n.length;o++){var s=n[o];if(a.isLessThan(s.tileID))break;if(r.key===s.tileID.key)return;if(s.tileID.isChildOf(r)){for(var l=r.children(1/0),c=0;c<l.length;c++)qr(e,l[c],n.slice(o),a,i);return}}var u=r.overscaledZ-e.overscaledZ,h=new t.CanonicalTileID(u,r.canonical.x-(e.canonical.x<<u),r.canonical.y-(e.canonical.y<<u));i[h.key]=i[h.key]||h}function Hr(t,e,r,n,a){for(var i=t.context,o=i.gl,s=a?t.useProgram("collisionCircle"):t.useProgram("collisionBox"),l=0;l<n.length;l++){var c=n[l],u=e.getTile(c),h=u.getBucket(r);if(h){var f=a?h.collisionCircle:h.collisionBox;f&&s.draw(i,a?o.TRIANGLES:o.LINES,Mt.disabled,At.disabled,t.colorModeForRenderPass(),Et.disabled,wr(c.posMatrix,t.transform,u),r.id,f.layoutVertexBuffer,f.indexBuffer,f.segments,null,t.transform.zoom,null,null,f.collisionVertexBuffer)}}}var Gr=t.identity(new Float32Array(16));function Yr(e,r,n,a,i,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateRadialOffset(e,a);return new t.Point((l/i+u[0])*o,(c/i+u[1])*o)}function Wr(e,r,n,a,i,o,s,l,c,u){var h=e.text.placedSymbolArray,f=e.text.dynamicLayoutVertexArray;f.clear();for(var p=0;p<h.length;p++){var d=h.get(p),g=e.allowVerticalPlacement&&!d.placedOrientation,v=d.hidden||!d.crossTileID||g?null:a[d.crossTileID];if(v){var m=new t.Point(d.anchorX,d.anchorY),y=Jt(m,n?l:s),x=.5+o.cameraToCenterDistance/y.signedDistanceFromCamera*.5,b=i.evaluateSizeForFeature(e.textSizeData,u,d)*x/t.ONE_EM;n&&(b*=e.tilePixelRatio/c);for(var _=v.width,w=v.height,k=v.radialOffset,T=v.textBoxScale,M=Yr(v.anchor,_,w,k,T,b),A=n?Jt(m.add(M),s).point:y.point.add(r?M.rotate(-o.angle):M),S=e.allowVerticalPlacement&&d.placedOrientation===t.WritingMode.vertical?Math.PI/2:0,E=0;E<d.numGlyphs;E++)t.addDynamicAttributes(f,A,S)}else ie(d.numGlyphs,f)}e.text.dynamicLayoutVertexBuffer.updateData(f)}function Xr(e){var r=e.text.placedSymbolArray,n=e.text.dynamicLayoutVertexArray;n.clear();for(var a=0;a<r.length;a++){var i=r.get(a);if(i.hidden||!i.placedOrientation)ie(i.numGlyphs,n);else for(var o=new t.Point(i.anchorX,i.anchorY),s=e.allowVerticalPlacement&&i.placedOrientation===t.WritingMode.vertical?Math.PI/2:0,l=0;l<i.numGlyphs;l++)t.addDynamicAttributes(n,o,s)}e.text.dynamicLayoutVertexBuffer.updateData(n)}function Zr(e,r,n,a,i,o,s,l,c,u,h,f,p){for(var d,g,v=e.context,m=v.gl,y=e.transform,x="map"===l,b="map"===c,_=x&&"point"!==n.layout.get("symbol-placement"),w=x&&!b&&!_,k=void 0!==n.layout.get("symbol-sort-key").constantOr(1),T=e.depthModeForSublayer(0,Mt.ReadOnly),M=n.layout.get("text-variable-anchor"),A=[],S=0,E=a;S<E.length;S+=1){var L=E[S],C=r.getTile(L),P=C.getBucket(n);if(P){var O=i?P.text:P.icon;if(O&&O.segments.get().length){var z=O.programConfigurations.get(n.id),I=i||P.sdfIcons,D=i?P.textSizeData:P.iconSizeData;d||(d=e.useProgram(I?"symbolSDF":"symbolIcon",z),g=t.evaluateSizeForZoom(D,y.zoom)),v.activeTexture.set(m.TEXTURE0);var R=void 0,F=void 0,B=void 0;if(i)F=C.glyphAtlasTexture,B=m.LINEAR,R=C.glyphAtlasTexture.size;else{var N=1!==n.layout.get("icon-size").constantOr(0)||P.iconsNeedLinear,j=b||0!==y.pitch;F=C.imageAtlasTexture,B=I||e.options.rotating||e.options.zooming||N||j?m.LINEAR:m.NEAREST,R=C.imageAtlasTexture.size}var V=ce(C,1,e.transform.zoom),U=Xt(L.posMatrix,b,x,e.transform,V),q=Zt(L.posMatrix,b,x,e.transform,V);if(_)Qt(P,L.posMatrix,e,i,U,q,b,u);else if(i&&g&&M){var H=Math.pow(2,y.zoom-C.tileID.overscaledZ);Wr(P,x,b,p,t.symbolSize,y,U,L.posMatrix,H,g)}else i&&g&&P.allowVerticalPlacement&&Xr(P);var G=e.translatePosMatrix(L.posMatrix,C,o,s),Y=_||i&&M?Gr:U,W=e.translatePosMatrix(q,C,o,s,!0),X=I&&0!==n.paint.get(i?"text-halo-width":"icon-halo-width").constantOr(1),Z={program:d,buffers:O,uniformValues:I?Br(D.kind,g,w,b,e,G,Y,W,i,R,!0):Fr(D.kind,g,w,b,e,G,Y,W,i,R),atlasTexture:F,atlasInterpolation:B,isSDF:I,hasHalo:X};if(k)for(var J=0,K=O.segments.get();J<K.length;J+=1){var Q=K[J];A.push({segments:new t.SegmentVector([Q]),sortKey:Q.sortKey,state:Z})}else A.push({segments:O.segments,sortKey:0,state:Z})}}}k&&A.sort(function(t,e){return t.sortKey-e.sortKey});for(var $=0,tt=A;$<tt.length;$+=1){var et=tt[$],rt=et.state;if(rt.atlasTexture.bind(rt.atlasInterpolation,m.CLAMP_TO_EDGE),rt.isSDF){var nt=rt.uniformValues;rt.hasHalo&&(nt.u_is_halo=1,Jr(rt.buffers,et.segments,n,e,rt.program,T,h,f,nt)),nt.u_is_halo=0}Jr(rt.buffers,et.segments,n,e,rt.program,T,h,f,rt.uniformValues)}}function Jr(t,e,r,n,a,i,o,s,l){var c=n.context,u=c.gl;a.draw(c,u.TRIANGLES,i,o,s,Et.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function Kr(t,e,r,n,a,i,o){var s,l,c,u,h,f=t.context.gl,p=r.paint.get("fill-pattern"),d=p&&p.constantOr(1),g=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty("fill-outline-color")?"fillOutlinePattern":"fillOutline",s=f.LINES):(l=d?"fillPattern":"fill",s=f.TRIANGLES);for(var v=0,m=n;v<m.length;v+=1){var y=m[v],x=e.getTile(y);if(!d||x.patternsLoaded()){var b=x.getBucket(r);if(b){var _=b.programConfigurations.get(r.id),w=t.useProgram(l,_);d&&(t.context.activeTexture.set(f.TEXTURE0),x.imageAtlasTexture.bind(f.LINEAR,f.CLAMP_TO_EDGE),_.updatePatternPaintBuffers(g));var k=p.constantOr(null);if(k&&x.imageAtlas){var T=x.imageAtlas.patternPositions[k.to],M=x.imageAtlas.patternPositions[k.from];T&&M&&_.setConstantPatternPositions(T,M)}var A=t.translatePosMatrix(y.posMatrix,x,r.paint.get("fill-translate"),r.paint.get("fill-translate-anchor"));if(o){u=b.indexBuffer2,h=b.segments2;var S=[f.drawingBufferWidth,f.drawingBufferHeight];c="fillOutlinePattern"===l&&d?xr(A,t,g,x,S):yr(A,S)}else u=b.indexBuffer,h=b.segments,c=d?mr(A,t,g,x):vr(A);w.draw(t.context,s,a,t.stencilModeForClipping(y),i,Et.disabled,c,r.id,b.layoutVertexBuffer,u,h,r.paint,t.transform.zoom,_)}}}}function Qr(t,e,r,n,a,i,o){for(var s=t.context,l=s.gl,c=r.paint.get("fill-extrusion-pattern"),u=c.constantOr(1),h=r.getCrossfadeParameters(),f=r.paint.get("fill-extrusion-opacity"),p=0,d=n;p<d.length;p+=1){var g=d[p],v=e.getTile(g),m=v.getBucket(r);if(m){var y=m.programConfigurations.get(r.id),x=t.useProgram(u?"fillExtrusionPattern":"fillExtrusion",y);u&&(t.context.activeTexture.set(l.TEXTURE0),v.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePatternPaintBuffers(h));var b=c.constantOr(null);if(b&&v.imageAtlas){var _=v.imageAtlas.patternPositions[b.to],w=v.imageAtlas.patternPositions[b.from];_&&w&&y.setConstantPatternPositions(_,w)}var k=t.translatePosMatrix(g.posMatrix,v,r.paint.get("fill-extrusion-translate"),r.paint.get("fill-extrusion-translate-anchor")),T=r.paint.get("fill-extrusion-vertical-gradient"),M=u?gr(k,t,T,f,g,h,v):dr(k,t,T,f);x.draw(s,s.gl.TRIANGLES,a,i,o,Et.backCCW,M,r.id,m.layoutVertexBuffer,m.indexBuffer,m.segments,r.paint,t.transform.zoom,y)}}}function $r(t,e,r,n,a,i){var o=t.context,s=o.gl,l=e.fbo;if(l){var c=t.useProgram("hillshade");o.activeTexture.set(s.TEXTURE0),s.bindTexture(s.TEXTURE_2D,l.colorAttachment.get());var u=Ar(t,e,r);e.maskedBoundsBuffer&&e.maskedIndexBuffer&&e.segments?c.draw(o,s.TRIANGLES,n,a,i,Et.disabled,u,r.id,e.maskedBoundsBuffer,e.maskedIndexBuffer,e.segments):c.draw(o,s.TRIANGLES,n,a,i,Et.disabled,u,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}}function tn(e,r,n,a,i,o,s){var l=e.context,c=l.gl;if(r.dem&&r.dem.data){var u=r.dem.dim,h=r.dem.stride,f=r.dem.getPixels();if(l.activeTexture.set(c.TEXTURE1),l.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(h),r.demTexture){var p=r.demTexture;p.update(f,{premultiply:!1}),p.bind(c.NEAREST,c.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(l,f,c.RGBA,{premultiply:!1}),r.demTexture.bind(c.NEAREST,c.CLAMP_TO_EDGE);l.activeTexture.set(c.TEXTURE0);var d=r.fbo;if(!d){var g=new t.Texture(l,{width:u,height:u,data:null},c.RGBA);g.bind(c.LINEAR,c.CLAMP_TO_EDGE),(d=r.fbo=l.createFramebuffer(u,u)).colorAttachment.set(g.texture)}l.bindFramebuffer.set(d.framebuffer),l.viewport.set([0,0,u,u]),e.useProgram("hillshadePrepare").draw(l,c.TRIANGLES,i,o,s,Et.disabled,Sr(r,a),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function en(e,r,n,a,i){var o=a.paint.get("raster-fade-duration");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),h=i.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),f=!r||Math.abs(r.tileID.overscaledZ-h)>Math.abs(e.tileID.overscaledZ-h),p=f&&e.refreshedUponExpiration?1:t.clamp(f?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}function rn(e,r,n){var a=e.context,i=a.gl,o=n.posMatrix,s=e.useProgram("debug"),l=Mt.disabled,c=At.disabled,u=e.colorModeForRenderPass(),h="$debug";s.draw(a,i.LINE_STRIP,l,c,u,Et.disabled,kr(o,t.Color.red),h,e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);for(var f=r.getTileByID(n.key).latestRawTileData,p=f&&f.byteLength||0,d=Math.floor(p/1024),g=r.getTile(n).tileSize,v=512/Math.min(g,512),m=function(t,e,r,n){n=n||1;var a,i,o,s,l,c,u,h,f=[];for(a=0,i=t.length;a<i;a++)if(l=nn[t[a]]){for(h=null,o=0,s=l[1].length;o<s;o+=2)-1===l[1][o]&&-1===l[1][o+1]?h=null:(c=e+l[1][o]*n,u=r-l[1][o+1]*n,h&&f.push(h.x,h.y,c,u),h={x:c,y:u});e+=l[0]*n}return f}(n.toString()+" "+d+"kb",50,200*v,5*v),y=new t.StructArrayLayout2i4,x=new t.StructArrayLayout2ui4,b=0;b<m.length;b+=2)y.emplaceBack(m[b],m[b+1]),x.emplaceBack(b,b+1);for(var _=a.createVertexBuffer(y,Fe.members),w=a.createIndexBuffer(x),k=t.SegmentVector.simpleSegment(0,0,y.length/2,y.length/2),T=t.EXTENT/(Math.pow(2,e.transform.zoom-n.overscaledZ)*g*v),M=[],A=-1;A<=1;A++)for(var S=-1;S<=1&&(0!==A||0!==S);S++)M.push([A,S]);for(var E=0;E<M.length;E++){var L=M[E];s.draw(a,i.LINES,l,c,u,Et.disabled,kr(t.translate([],o,[T*L[0],T*L[1],0]),t.Color.white),h,_,w,k)}s.draw(a,i.LINES,l,c,u,Et.disabled,kr(o,t.Color.black),h,_,w,k)}var nn={" ":[16,[]],"!":[10,[5,21,5,7,-1,-1,5,2,4,1,5,0,6,1,5,2]],'"':[16,[4,21,4,14,-1,-1,12,21,12,14]],"#":[21,[11,25,4,-7,-1,-1,17,25,10,-7,-1,-1,4,12,18,12,-1,-1,3,6,17,6]],$:[20,[8,25,8,-4,-1,-1,12,25,12,-4,-1,-1,17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],"%":[24,[21,21,3,0,-1,-1,8,21,10,19,10,17,9,15,7,14,5,14,3,16,3,18,4,20,6,21,8,21,10,20,13,19,16,19,19,20,21,21,-1,-1,17,7,15,6,14,4,14,2,16,0,18,0,20,1,21,3,21,5,19,7,17,7]],"&":[26,[23,12,23,13,22,14,21,14,20,13,19,11,17,6,15,3,13,1,11,0,7,0,5,1,4,2,3,4,3,6,4,8,5,9,12,13,13,14,14,16,14,18,13,20,11,21,9,20,8,18,8,16,9,13,11,10,16,3,18,1,20,0,22,0,23,1,23,2]],"'":[10,[5,19,4,20,5,21,6,20,6,18,5,16,4,15]],"(":[14,[11,25,9,23,7,20,5,16,4,11,4,7,5,2,7,-2,9,-5,11,-7]],")":[14,[3,25,5,23,7,20,9,16,10,11,10,7,9,2,7,-2,5,-5,3,-7]],"*":[16,[8,21,8,9,-1,-1,3,18,13,12,-1,-1,13,18,3,12]],"+":[26,[13,18,13,0,-1,-1,4,9,22,9]],",":[10,[6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],"-":[26,[4,9,22,9]],".":[10,[5,2,4,1,5,0,6,1,5,2]],"/":[22,[20,25,2,-7]],0:[20,[9,21,6,20,4,17,3,12,3,9,4,4,6,1,9,0,11,0,14,1,16,4,17,9,17,12,16,17,14,20,11,21,9,21]],1:[20,[6,17,8,18,11,21,11,0]],2:[20,[4,16,4,17,5,19,6,20,8,21,12,21,14,20,15,19,16,17,16,15,15,13,13,10,3,0,17,0]],3:[20,[5,21,16,21,10,13,13,13,15,12,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],4:[20,[13,21,3,7,18,7,-1,-1,13,21,13,0]],5:[20,[15,21,5,21,4,12,5,13,8,14,11,14,14,13,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],6:[20,[16,18,15,20,12,21,10,21,7,20,5,17,4,12,4,7,5,3,7,1,10,0,11,0,14,1,16,3,17,6,17,7,16,10,14,12,11,13,10,13,7,12,5,10,4,7]],7:[20,[17,21,7,0,-1,-1,3,21,17,21]],8:[20,[8,21,5,20,4,18,4,16,5,14,7,13,11,12,14,11,16,9,17,7,17,4,16,2,15,1,12,0,8,0,5,1,4,2,3,4,3,7,4,9,6,11,9,12,13,13,15,14,16,16,16,18,15,20,12,21,8,21]],9:[20,[16,14,15,11,13,9,10,8,9,8,6,9,4,11,3,14,3,15,4,18,6,20,9,21,10,21,13,20,15,18,16,14,16,9,15,4,13,1,10,0,8,0,5,1,4,3]],":":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,5,2,4,1,5,0,6,1,5,2]],";":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],"<":[24,[20,18,4,9,20,0]],"=":[26,[4,12,22,12,-1,-1,4,6,22,6]],">":[24,[4,18,20,9,4,0]],"?":[18,[3,16,3,17,4,19,5,20,7,21,11,21,13,20,14,19,15,17,15,15,14,13,13,12,9,10,9,7,-1,-1,9,2,8,1,9,0,10,1,9,2]],"@":[27,[18,13,17,15,15,16,12,16,10,15,9,14,8,11,8,8,9,6,11,5,14,5,16,6,17,8,-1,-1,12,16,10,14,9,11,9,8,10,6,11,5,-1,-1,18,16,17,8,17,6,19,5,21,5,23,7,24,10,24,12,23,15,22,17,20,19,18,20,15,21,12,21,9,20,7,19,5,17,4,15,3,12,3,9,4,6,5,4,7,2,9,1,12,0,15,0,18,1,20,2,21,3,-1,-1,19,16,18,8,18,6,19,5]],A:[18,[9,21,1,0,-1,-1,9,21,17,0,-1,-1,4,7,14,7]],B:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,-1,-1,4,11,13,11,16,10,17,9,18,7,18,4,17,2,16,1,13,0,4,0]],C:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5]],D:[21,[4,21,4,0,-1,-1,4,21,11,21,14,20,16,18,17,16,18,13,18,8,17,5,16,3,14,1,11,0,4,0]],E:[19,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11,-1,-1,4,0,17,0]],F:[18,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11]],G:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,18,8,-1,-1,13,8,18,8]],H:[22,[4,21,4,0,-1,-1,18,21,18,0,-1,-1,4,11,18,11]],I:[8,[4,21,4,0]],J:[16,[12,21,12,5,11,2,10,1,8,0,6,0,4,1,3,2,2,5,2,7]],K:[21,[4,21,4,0,-1,-1,18,21,4,7,-1,-1,9,12,18,0]],L:[17,[4,21,4,0,-1,-1,4,0,16,0]],M:[24,[4,21,4,0,-1,-1,4,21,12,0,-1,-1,20,21,12,0,-1,-1,20,21,20,0]],N:[22,[4,21,4,0,-1,-1,4,21,18,0,-1,-1,18,21,18,0]],O:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21]],P:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,14,17,12,16,11,13,10,4,10]],Q:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21,-1,-1,12,4,18,-2]],R:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,4,11,-1,-1,11,11,18,0]],S:[20,[17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],T:[16,[8,21,8,0,-1,-1,1,21,15,21]],U:[22,[4,21,4,6,5,3,7,1,10,0,12,0,15,1,17,3,18,6,18,21]],V:[18,[1,21,9,0,-1,-1,17,21,9,0]],W:[24,[2,21,7,0,-1,-1,12,21,7,0,-1,-1,12,21,17,0,-1,-1,22,21,17,0]],X:[20,[3,21,17,0,-1,-1,17,21,3,0]],Y:[18,[1,21,9,11,9,0,-1,-1,17,21,9,11]],Z:[20,[17,21,3,0,-1,-1,3,21,17,21,-1,-1,3,0,17,0]],"[":[14,[4,25,4,-7,-1,-1,5,25,5,-7,-1,-1,4,25,11,25,-1,-1,4,-7,11,-7]],"\\":[14,[0,21,14,-3]],"]":[14,[9,25,9,-7,-1,-1,10,25,10,-7,-1,-1,3,25,10,25,-1,-1,3,-7,10,-7]],"^":[16,[6,15,8,18,10,15,-1,-1,3,12,8,17,13,12,-1,-1,8,17,8,0]],_:[16,[0,-2,16,-2]],"`":[10,[6,21,5,20,4,18,4,16,5,15,6,16,5,17]],a:[19,[15,14,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],b:[19,[4,21,4,0,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],c:[18,[15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],d:[19,[15,21,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],e:[18,[3,8,15,8,15,10,14,12,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],f:[12,[10,21,8,21,6,20,5,17,5,0,-1,-1,2,14,9,14]],g:[19,[15,14,15,-2,14,-5,13,-6,11,-7,8,-7,6,-6,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],h:[19,[4,21,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],i:[8,[3,21,4,20,5,21,4,22,3,21,-1,-1,4,14,4,0]],j:[10,[5,21,6,20,7,21,6,22,5,21,-1,-1,6,14,6,-3,5,-6,3,-7,1,-7]],k:[17,[4,21,4,0,-1,-1,14,14,4,4,-1,-1,8,8,15,0]],l:[8,[4,21,4,0]],m:[30,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0,-1,-1,15,10,18,13,20,14,23,14,25,13,26,10,26,0]],n:[19,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],o:[19,[8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3,16,6,16,8,15,11,13,13,11,14,8,14]],p:[19,[4,14,4,-7,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],q:[19,[15,14,15,-7,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],r:[13,[4,14,4,0,-1,-1,4,8,5,11,7,13,9,14,12,14]],s:[17,[14,11,13,13,10,14,7,14,4,13,3,11,4,9,6,8,11,7,13,6,14,4,14,3,13,1,10,0,7,0,4,1,3,3]],t:[12,[5,21,5,4,6,1,8,0,10,0,-1,-1,2,14,9,14]],u:[19,[4,14,4,4,5,1,7,0,10,0,12,1,15,4,-1,-1,15,14,15,0]],v:[16,[2,14,8,0,-1,-1,14,14,8,0]],w:[22,[3,14,7,0,-1,-1,11,14,7,0,-1,-1,11,14,15,0,-1,-1,19,14,15,0]],x:[17,[3,14,14,0,-1,-1,14,14,3,0]],y:[16,[2,14,8,0,-1,-1,14,14,8,0,6,-4,4,-6,2,-7,1,-7]],z:[17,[14,14,3,0,-1,-1,3,14,14,14,-1,-1,3,0,14,0]],"{":[14,[9,25,7,24,6,23,5,21,5,19,6,17,7,16,8,14,8,12,6,10,-1,-1,7,24,6,22,6,20,7,18,8,17,9,15,9,13,8,11,4,9,8,7,9,5,9,3,8,1,7,0,6,-2,6,-4,7,-6,-1,-1,6,8,8,6,8,4,7,2,6,1,5,-1,5,-3,6,-5,7,-6,9,-7]],"|":[8,[4,25,4,-7]],"}":[14,[5,25,7,24,8,23,9,21,9,19,8,17,7,16,6,14,6,12,8,10,-1,-1,7,24,8,22,8,20,7,18,6,17,5,15,5,13,6,11,10,9,6,7,5,5,5,3,6,1,7,0,8,-2,8,-4,7,-6,-1,-1,8,8,6,6,6,4,7,2,8,1,9,-1,9,-3,8,-5,7,-6,5,-7]],"~":[24,[3,6,3,8,4,11,6,12,8,12,10,11,14,8,16,7,18,7,20,8,21,10,-1,-1,3,8,4,10,6,11,8,11,10,10,14,7,16,6,18,6,20,7,21,10,21,12]]},an={symbol:function(t,e,r,n,a){if("translucent"===t.renderPass){var i=At.disabled,o=t.colorModeForRenderPass();0!==r.paint.get("icon-opacity").constantOr(1)&&Zr(t,e,r,n,!1,r.paint.get("icon-translate"),r.paint.get("icon-translate-anchor"),r.layout.get("icon-rotation-alignment"),r.layout.get("icon-pitch-alignment"),r.layout.get("icon-keep-upright"),i,o,a),0!==r.paint.get("text-opacity").constantOr(1)&&Zr(t,e,r,n,!0,r.paint.get("text-translate"),r.paint.get("text-translate-anchor"),r.layout.get("text-rotation-alignment"),r.layout.get("text-pitch-alignment"),r.layout.get("text-keep-upright"),i,o,a),e.map.showCollisionBoxes&&function(t,e,r,n){Hr(t,e,r,n,!1),Hr(t,e,r,n,!0)}(t,e,r,n)}},circle:function(e,r,n,a){if("translucent"===e.renderPass){var i=n.paint.get("circle-opacity"),o=n.paint.get("circle-stroke-width"),s=n.paint.get("circle-stroke-opacity"),l=void 0!==n.layout.get("circle-sort-key").constantOr(1);if(0!==i.constantOr(1)||0!==o.constantOr(1)&&0!==s.constantOr(1)){for(var c=e.context,u=c.gl,h=e.depthModeForSublayer(0,Mt.ReadOnly),f=At.disabled,p=e.colorModeForRenderPass(),d=[],g=0;g<a.length;g++){var v=a[g],m=r.getTile(v),y=m.getBucket(n);if(y){var x=y.programConfigurations.get(n.id),b={programConfiguration:x,program:e.useProgram("circle",x),layoutVertexBuffer:y.layoutVertexBuffer,indexBuffer:y.indexBuffer,uniformValues:br(e,v,m,n)};if(l)for(var _=0,w=y.segments.get();_<w.length;_+=1){var k=w[_];d.push({segments:new t.SegmentVector([k]),sortKey:k.sortKey,state:b})}else d.push({segments:y.segments,sortKey:0,state:b})}}l&&d.sort(function(t,e){return t.sortKey-e.sortKey});for(var T=0,M=d;T<M.length;T+=1){var A=M[T],S=A.state,E=S.programConfiguration,L=S.program,C=S.layoutVertexBuffer,P=S.indexBuffer,O=S.uniformValues,z=A.segments;L.draw(c,u.TRIANGLES,h,f,p,Et.disabled,O,n.id,C,P,z,n.paint,e.transform.zoom,E)}}}},heatmap:function(e,r,n,a){if(0!==n.paint.get("heatmap-opacity"))if("offscreen"===e.renderPass){var i=e.context,o=i.gl,s=e.depthModeForSublayer(0,Mt.ReadOnly),l=At.disabled,c=new St([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);!function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var a=r.heatmapFbo;if(a)n.bindTexture(n.TEXTURE_2D,a.colorAttachment.get()),t.bindFramebuffer.set(a.framebuffer);else{var i=n.createTexture();n.bindTexture(n.TEXTURE_2D,i),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),a=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4),function t(e,r,n,a){var i=e.gl;i.texImage2D(i.TEXTURE_2D,0,i.RGBA,r.width/4,r.height/4,0,i.RGBA,e.extTextureHalfFloat?e.extTextureHalfFloat.HALF_FLOAT_OES:i.UNSIGNED_BYTE,null),a.colorAttachment.set(n),e.extTextureHalfFloat&&i.checkFramebufferStatus(i.FRAMEBUFFER)!==i.FRAMEBUFFER_COMPLETE&&(e.extTextureHalfFloat=null,a.colorAttachment.setDirty(),t(e,r,n,a))}(t,e,i,a)}}(i,e,n),i.clear({color:t.Color.transparent});for(var u=0;u<a.length;u++){var h=a[u];if(!r.hasRenderableParent(h)){var f=r.getTile(h),p=f.getBucket(n);if(p){var d=p.programConfigurations.get(n.id),g=e.useProgram("heatmap",d),v=e.transform.zoom;g.draw(i,o.TRIANGLES,s,l,c,Et.disabled,Mr(h.posMatrix,f,v,n.paint.get("heatmap-intensity")),n.id,p.layoutVertexBuffer,p.indexBuffer,p.segments,n.paint,e.transform.zoom,d)}}}i.viewport.set([0,0,e.width,e.height])}else"translucent"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,a=n.gl,i=r.heatmapFbo;if(i){n.activeTexture.set(a.TEXTURE0),a.bindTexture(a.TEXTURE_2D,i.colorAttachment.get()),n.activeTexture.set(a.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,a.RGBA)),o.bind(a.LINEAR,a.CLAMP_TO_EDGE),e.useProgram("heatmapTexture").draw(n,a.TRIANGLES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,function(e,r,n,a){var i=t.create();t.ortho(i,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:i,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:n,u_color_ramp:a,u_opacity:r.paint.get("heatmap-opacity")}}(e,r,0,1),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}}(e,n))},line:function(e,r,n,a){if("translucent"===e.renderPass){var i=n.paint.get("line-opacity"),o=n.paint.get("line-width");if(0!==i.constantOr(1)&&0!==o.constantOr(1)){var s=e.depthModeForSublayer(0,Mt.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get("line-dasharray"),u=n.paint.get("line-pattern"),h=u.constantOr(1),f=n.paint.get("line-gradient"),p=n.getCrossfadeParameters(),d=c?"lineSDF":h?"linePattern":f?"lineGradient":"line",g=e.context,v=g.gl,m=!0;if(f){g.activeTexture.set(v.TEXTURE0);var y=n.gradientTexture;if(!n.gradient)return;y||(y=n.gradientTexture=new t.Texture(g,n.gradient,v.RGBA)),y.bind(v.LINEAR,v.CLAMP_TO_EDGE)}for(var x=0,b=a;x<b.length;x+=1){var _=b[x],w=r.getTile(_);if(!h||w.patternsLoaded()){var k=w.getBucket(n);if(k){var T=k.programConfigurations.get(n.id),M=e.context.program.get(),A=e.useProgram(d,T),S=m||A.program!==M,E=u.constantOr(null);if(E&&w.imageAtlas){var L=w.imageAtlas.patternPositions[E.to],C=w.imageAtlas.patternPositions[E.from];L&&C&&T.setConstantPatternPositions(L,C)}var P=c?Or(e,w,n,c,p):h?Pr(e,w,n,p):f?Cr(e,w,n):Lr(e,w,n);c&&(S||e.lineAtlas.dirty)?(g.activeTexture.set(v.TEXTURE0),e.lineAtlas.bind(g)):h&&(g.activeTexture.set(v.TEXTURE0),w.imageAtlasTexture.bind(v.LINEAR,v.CLAMP_TO_EDGE),T.updatePatternPaintBuffers(p)),A.draw(g,v.TRIANGLES,s,e.stencilModeForClipping(_),l,Et.disabled,P,n.id,k.layoutVertexBuffer,k.indexBuffer,k.segments,n.paint,e.transform.zoom,T),m=!1}}}}}},fill:function(e,r,n,a){var i=n.paint.get("fill-color"),o=n.paint.get("fill-opacity");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get("fill-pattern"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===i.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?"opaque":"translucent";if(e.renderPass===c){var u=e.depthModeForSublayer(1,"opaque"===e.renderPass?Mt.ReadWrite:Mt.ReadOnly);Kr(e,r,n,a,u,s,!1)}if("translucent"===e.renderPass&&n.paint.get("fill-antialias")){var h=e.depthModeForSublayer(n.getPaintProperty("fill-outline-color")?2:0,Mt.ReadOnly);Kr(e,r,n,a,h,s,!0)}}},"fill-extrusion":function(t,e,r,n){var a=r.paint.get("fill-extrusion-opacity");if(0!==a&&"translucent"===t.renderPass){var i=new Mt(t.context.gl.LEQUAL,Mt.ReadWrite,t.depthRangeFor3D);if(1!==a||r.paint.get("fill-extrusion-pattern").constantOr(1))Qr(t,e,r,n,i,At.disabled,St.disabled),Qr(t,e,r,n,i,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();Qr(t,e,r,n,i,At.disabled,o)}}},hillshade:function(t,e,r,n){if("offscreen"===t.renderPass||"translucent"===t.renderPass){for(var a=t.context,i=e.getSource().maxzoom,o=t.depthModeForSublayer(0,Mt.ReadOnly),s=At.disabled,l=t.colorModeForRenderPass(),c=0,u=n;c<u.length;c+=1){var h=u[c],f=e.getTile(h);f.needsHillshadePrepare&&"offscreen"===t.renderPass?tn(t,f,r,i,o,s,l):"translucent"===t.renderPass&&$r(t,f,r,o,s,l)}a.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if("translucent"===t.renderPass&&0!==r.paint.get("raster-opacity"))for(var a=t.context,i=a.gl,o=e.getSource(),s=t.useProgram("raster"),l=At.disabled,c=t.colorModeForRenderPass(),u=n.length&&n[0].overscaledZ,h=!t.options.moving,f=0,p=n;f<p.length;f+=1){var d=p[f],g=t.depthModeForSublayer(d.overscaledZ-u,1===r.paint.get("raster-opacity")?Mt.ReadWrite:Mt.ReadOnly,i.LESS),v=e.getTile(d),m=t.transform.calculatePosMatrix(d.toUnwrapped(),h);v.registerFadeDuration(r.paint.get("raster-fade-duration"));var y=e.findLoadedParent(d,0),x=en(v,y,e,r,t.transform),b=void 0,_=void 0,w="nearest"===r.paint.get("raster-resampling")?i.NEAREST:i.LINEAR;a.activeTexture.set(i.TEXTURE0),v.texture.bind(w,i.CLAMP_TO_EDGE,i.LINEAR_MIPMAP_NEAREST),a.activeTexture.set(i.TEXTURE1),y?(y.texture.bind(w,i.CLAMP_TO_EDGE,i.LINEAR_MIPMAP_NEAREST),b=Math.pow(2,y.tileID.overscaledZ-v.tileID.overscaledZ),_=[v.tileID.canonical.x*b%1,v.tileID.canonical.y*b%1]):v.texture.bind(w,i.CLAMP_TO_EDGE,i.LINEAR_MIPMAP_NEAREST);var k=Dr(m,_||[0,0],b||1,x,r);o instanceof P?s.draw(a,i.TRIANGLES,g,l,c,Et.disabled,k,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):v.maskedBoundsBuffer&&v.maskedIndexBuffer&&v.segments?s.draw(a,i.TRIANGLES,g,l,c,Et.disabled,k,r.id,v.maskedBoundsBuffer,v.maskedIndexBuffer,v.segments,r.paint,t.transform.zoom):s.draw(a,i.TRIANGLES,g,l,c,Et.disabled,k,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get("background-color"),a=r.paint.get("background-opacity");if(0!==a){var i=t.context,o=i.gl,s=t.transform,l=s.tileSize,c=r.paint.get("background-pattern");if(!t.isPatternMissing(c)){var u=!c&&1===n.a&&1===a&&t.opaquePassEnabledForLayer()?"opaque":"translucent";if(t.renderPass===u){var h=At.disabled,f=t.depthModeForSublayer(0,"opaque"===u?Mt.ReadWrite:Mt.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?"backgroundPattern":"background"),g=s.coveringTiles({tileSize:l});c&&(i.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var v=r.getCrossfadeParameters(),m=0,y=g;m<y.length;m+=1){var x=y[m],b=t.transform.calculatePosMatrix(x.toUnwrapped()),_=c?jr(b,a,t,c,{tileID:x,tileSize:l},v):Nr(b,a,n);d.draw(i,o.TRIANGLES,f,h,p,Et.disabled,_,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)rn(t,e,r[n])},custom:function(t,e,r){var n=t.context,a=r.implementation;if("offscreen"===t.renderPass){var i=a.prerender;i&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),i.call(a,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if("translucent"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(At.disabled);var o="3d"===a.renderingMode?new Mt(t.context.gl.LEQUAL,Mt.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,Mt.ReadOnly);n.setDepthMode(o),a.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},on=function(e,r){this.context=new Lt(e),this.transform=r,this._tileTextures={},this.setup(),this.numSublayers=Ct.maxUnderzooming+Ct.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.depthRboNeedsClear=!0,this.emptyProgramConfiguration=new t.ProgramConfiguration,this.crossTileSymbolIndex=new Oe};function sn(t,e){if(t.y>e.y){var r=t;t=e,e=r}return{x0:t.x,y0:t.y,x1:e.x,y1:e.y,dx:e.x-t.x,dy:e.y-t.y}}function ln(t,e,r,n,a){var i=Math.max(r,Math.floor(e.y0)),o=Math.min(n,Math.ceil(e.y1));if(t.x0===e.x0&&t.y0===e.y0?t.x0+e.dy/t.dy*t.dx<e.x1:t.x1-e.dy/t.dy*t.dx<e.x0){var s=t;t=e,e=s}for(var l=t.dx/t.dy,c=e.dx/e.dy,u=t.dx>0,h=e.dx<0,f=i;f<o;f++){var p=l*Math.max(0,Math.min(t.dy,f+u-t.y0))+t.x0,d=c*Math.max(0,Math.min(e.dy,f+h-e.y0))+e.x0;a(Math.floor(d),Math.ceil(p),f)}}function cn(t,e,r,n,a,i){var o,s=sn(t,e),l=sn(e,r),c=sn(r,t);s.dy>l.dy&&(o=s,s=l,l=o),s.dy>c.dy&&(o=s,s=c,c=o),l.dy>c.dy&&(o=l,l=c,c=o),s.dy&&ln(c,s,n,a,i),l.dy&&ln(c,l,n,a,i)}on.prototype.resize=function(e,r){var n=this.context.gl;if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var a=0,i=this.style._order;a<i.length;a+=1){var o=i[a];this.style._layers[o].resize()}this.depthRbo&&(n.deleteRenderbuffer(this.depthRbo),this.depthRbo=null)},on.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,Fe.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,Fe.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var a=new t.StructArrayLayout4i8;a.emplaceBack(0,0,0,0),a.emplaceBack(t.EXTENT,0,t.EXTENT,0),a.emplaceBack(0,t.EXTENT,0,t.EXTENT),a.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(a,t.rasterBoundsAttributes.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var i=new t.StructArrayLayout2i4;i.emplaceBack(0,0),i.emplaceBack(1,0),i.emplaceBack(0,1),i.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(i,Fe.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s);var l=this.context.gl;this.stencilClearMode=new At({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},on.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram("clippingMask").draw(e,r.TRIANGLES,Mt.disabled,this.stencilClearMode,St.disabled,Et.disabled,Tr(n),"$clipping",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},on.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(St.disabled),r.setDepthMode(Mt.disabled);var a=this.useProgram("clippingMask");this._tileClippingMaskIDs={};for(var i=0,o=e;i<o.length;i+=1){var s=o[i],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;a.draw(r,n.TRIANGLES,Mt.disabled,new At({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),St.disabled,Et.disabled,Tr(s.posMatrix),"$clipping",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},on.prototype.stencilModeFor3D=function(){this.currentStencilSource=void 0,this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new At({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},on.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new At({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},on.prototype.colorModeForRenderPass=function(){var e=this.context.gl;return this._showOverdrawInspector?new St([e.CONSTANT_COLOR,e.ONE],new t.Color(1/8,1/8,1/8,0),[!0,!0,!0,!0]):"opaque"===this.renderPass?St.unblended:St.alphaBlended},on.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return Mt.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new Mt(r||this.context.gl.LEQUAL,e,[n,n])},on.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},on.prototype.render=function(e,r){this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var n=this.style._order,a=this.style.sourceCaches;for(var i in a){var o=a[i];o.used&&o.prepare(this.context)}var s={},l={},c={};for(var u in a){var h=a[u];s[u]=h.getVisibleCoordinates(),l[u]=s[u].slice().reverse(),c[u]=h.getVisibleCoordinates(!0).reverse()}for(var f in a){var p=a[f],d=p.getSource();if("raster"===d.type||"raster-dem"===d.type){for(var g=[],v=0,m=s[f];v<m.length;v+=1){var y=m[v];g.push(p.getTile(y))}Ur(g,this.context)}}this.opaquePassCutoff=1/0;for(var x=0;x<n.length;x++){var b=n[x];if(this.style._layers[b].is3D()){this.opaquePassCutoff=x;break}}this.renderPass="offscreen",this.depthRboNeedsClear=!0;for(var _=0,w=n;_<w.length;_+=1){var k=w[_],T=this.style._layers[k];if(T.hasOffscreenPass()&&!T.isHidden(this.transform.zoom)){var M=l[T.source];("custom"===T.type||M.length)&&this.renderLayer(this,a[T.source],T,M)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass="opaque",this.currentLayer=n.length-1;this.currentLayer>=0;this.currentLayer--){var A=this.style._layers[n[this.currentLayer]],S=a[A.source],E=s[A.source];this._renderTileClippingMasks(A,E),this.renderLayer(this,S,A,E)}for(this.renderPass="translucent",this.currentLayer=0;this.currentLayer<n.length;this.currentLayer++){var L=this.style._layers[n[this.currentLayer]],C=a[L.source],P=("symbol"===L.type?c:l)[L.source];this._renderTileClippingMasks(L,s[L.source]),this.renderLayer(this,C,L,P)}if(this.options.showTileBoundaries)for(var O in a){an.debug(this,a[O],s[O]);break}this.context.setDefault()},on.prototype.setupOffscreenDepthRenderbuffer=function(){var t=this.context;this.depthRbo||(this.depthRbo=t.createRenderbuffer(t.gl.DEPTH_COMPONENT16,this.width,this.height))},on.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||("background"===r.type||"custom"===r.type||n.length)&&(this.id=r.id,an[r.type](t,e,r,n,this.style.placement.variableOffsets))},on.prototype.translatePosMatrix=function(e,r,n,a,i){if(!n[0]&&!n[1])return e;var o=i?"map"===a?this.transform.angle:0:"viewport"===a?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[i?n[0]:ce(r,n[0],this.transform.zoom),i?n[1]:ce(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},on.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},on.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},on.prototype.isPatternMissing=function(t){if(!t)return!1;var e=this.imageManager.getPattern(t.from),r=this.imageManager.getPattern(t.to);return!e||!r},on.prototype.useProgram=function(t,e){void 0===e&&(e=this.emptyProgramConfiguration),this.cache=this.cache||{};var r=""+t+(e.cacheKey||"")+(this._showOverdrawInspector?"/overdraw":"");return this.cache[r]||(this.cache[r]=new fr(this.context,ur[t],e,Vr[t],this._showOverdrawInspector)),this.cache[r]},on.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},on.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)};var un=function(e,r,n){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===n||n,this._minZoom=e||0,this._maxZoom=r||22,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._posMatrixCache={},this._alignedPosMatrixCache={}},hn={minZoom:{configurable:!0},maxZoom:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerPoint:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};un.prototype.clone=function(){var t=new un(this._minZoom,this._maxZoom,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._calcMatrices(),t},hn.minZoom.get=function(){return this._minZoom},hn.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},hn.maxZoom.get=function(){return this._maxZoom},hn.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},hn.renderWorldCopies.get=function(){return this._renderWorldCopies},hn.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},hn.worldSize.get=function(){return this.tileSize*this.scale},hn.centerPoint.get=function(){return this.size._div(2)},hn.size.get=function(){return new t.Point(this.width,this.height)},hn.bearing.get=function(){return-this.angle/Math.PI*180},hn.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},hn.pitch.get=function(){return this._pitch/Math.PI*180},hn.pitch.set=function(e){var r=t.clamp(e,0,60)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},hn.fov.get=function(){return this._fov/Math.PI*180},hn.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},hn.zoom.get=function(){return this._zoom},hn.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},hn.center.get=function(){return this._center},hn.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},un.prototype.coveringZoomLevel=function(t){return(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize))},un.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),a=this.pointCoordinate(new t.Point(this.width,0)),i=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,a.x,i.x,o.x)),l=Math.floor(Math.max(n.x,a.x,i.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},un.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var a=t.MercatorCoordinate.fromLngLat(this.center),i=Math.pow(2,r),o=new t.Point(i*a.x-.5,i*a.y-.5);return function(e,r,n,a){void 0===a&&(a=!0);var i=1<<e,o={};function s(r,s,l){var c,u,h,f;if(l>=0&&l<=i)for(c=r;c<s;c++)u=Math.floor(c/i),h=(c%i+i)%i,0!==u&&!0!==a||(f=new t.OverscaledTileID(n,u,e,h,l),o[f.key]=f)}var l=r.map(function(e){return new t.Point(e.x,e.y)._mult(i)});return cn(l[0],l[1],l[2],0,i,s),cn(l[2],l[3],l[0],0,i,s),Object.keys(o).map(function(t){return o[t]})}(r,[this.pointCoordinate(new t.Point(0,0)),this.pointCoordinate(new t.Point(this.width,0)),this.pointCoordinate(new t.Point(this.width,this.height)),this.pointCoordinate(new t.Point(0,this.height))],e.reparseOverscaled?n:r,this._renderWorldCopies).sort(function(t,e){return o.dist(t.canonical)-o.dist(e.canonical)})},un.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},hn.unmodified.get=function(){return this._unmodified},un.prototype.zoomScale=function(t){return Math.pow(2,t)},un.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},un.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},un.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},hn.point.get=function(){return this.project(this.center)},un.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),a=this.pointCoordinate(this.centerPoint),i=this.locationCoordinate(e),o=new t.MercatorCoordinate(i.x-(n.x-a.x),i.y-(n.y-a.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},un.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},un.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},un.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},un.prototype.coordinateLocation=function(t){return t.toLngLat()},un.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var a=r[3],i=n[3],o=r[0]/a,s=n[0]/i,l=r[1]/a,c=n[1]/i,u=r[2]/a,h=n[2]/i,f=u===h?0:(0-u)/(h-u);return new t.MercatorCoordinate(t.number(o,s,f)/this.worldSize,t.number(l,c,f)/this.worldSize)},un.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},un.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},un.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},un.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},un.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,a=r?this._alignedPosMatrixCache:this._posMatrixCache;if(a[n])return a[n];var i=e.canonical,o=this.worldSize/this.zoomScale(i.z),s=i.x+Math.pow(2,i.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,i.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),a[n]=new Float32Array(l),a[n]},un.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},un.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,a,i=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var h=this.latRange;i=t.mercatorYfromLat(h[1])*this.worldSize,e=(o=t.mercatorYfromLat(h[0])*this.worldSize)-i<c.y?c.y/(o-i):0}if(this.lngRange){var f=this.lngRange;s=t.mercatorXfromLng(f[0])*this.worldSize,r=(l=t.mercatorXfromLng(f[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+i)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var g=p.y,v=c.y/2;g-v<i&&(a=i+v),g+v>o&&(a=o-v)}if(this.lngRange){var m=p.x,y=c.x/2;m-y<s&&(n=s+y),m+y>l&&(n=l-y)}void 0===n&&void 0===a||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==a?a:p.y))),this._unmodified=u,this._constraining=!1}},un.prototype._calcMatrices=function(){if(this.height){this.cameraToCenterDistance=.5/Math.tan(this._fov/2)*this.height;var e=this._fov/2,r=Math.PI/2+this._pitch,n=Math.sin(e)*this.cameraToCenterDistance/Math.sin(Math.PI-r-e),a=this.point,i=a.x,o=a.y,s=1.01*(Math.cos(Math.PI/2-this._pitch)*n+this.cameraToCenterDistance),l=this.height/50,c=new Float64Array(16);t.perspective(c,this._fov,this.width/this.height,l,s),t.scale(c,c,[1,-1,1]),t.translate(c,c,[0,0,-this.cameraToCenterDistance]),t.rotateX(c,c,this._pitch),t.rotateZ(c,c,this.angle),t.translate(c,c,[-i,-o,0]),this.mercatorMatrix=t.scale([],c,[this.worldSize,this.worldSize,this.worldSize]),t.scale(c,c,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=c;var u=this.width%2/2,h=this.height%2/2,f=Math.cos(this.angle),p=Math.sin(this.angle),d=i-Math.round(i)+f*u+p*h,g=o-Math.round(o)+f*h+p*u,v=new Float64Array(c);if(t.translate(v,v,[d>.5?d-1:d,g>.5?g-1:g,0]),this.alignedProjMatrix=v,c=t.create(),t.scale(c,c,[this.width/2,-this.height/2,1]),t.translate(c,c,[1,-1,0]),this.labelPlaneMatrix=c,c=t.create(),t.scale(c,c,[1,-1,1]),t.translate(c,c,[-1,-1,0]),t.scale(c,c,[2/this.width,2/this.height,1]),this.glCoordMatrix=c,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(c=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error("failed to invert matrix");this.pixelMatrixInverse=c,this._posMatrixCache={},this._alignedPosMatrixCache={}}},un.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},un.prototype.getCameraPoint=function(){var e=this._pitch,r=Math.tan(e)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,r))},un.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,a=r.y,i=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),a=Math.min(a,c.y),i=Math.max(i,c.x),o=Math.max(o,c.y)}return[new t.Point(n,a),new t.Point(i,a),new t.Point(i,o),new t.Point(n,o),new t.Point(n,a)]},Object.defineProperties(un.prototype,hn);var fn=function(){var e,r,n,a;t.bindAll(["_onHashChange","_updateHash"],this),this._updateHash=(e=this._updateHashUnthrottled.bind(this),300,r=!1,n=null,a=function(){n=null,r&&(e(),n=setTimeout(a,300),r=!1)},function(){return r=!0,n||a(),n})};fn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener("hashchange",this._onHashChange,!1),this._map.on("moveend",this._updateHash),this},fn.prototype.remove=function(){return t.window.removeEventListener("hashchange",this._onHashChange,!1),this._map.off("moveend",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},fn.prototype.getHashString=function(t){var e=this._map.getCenter(),r=Math.round(100*this._map.getZoom())/100,n=Math.ceil((r*Math.LN2+Math.log(512/360/.5))/Math.LN10),a=Math.pow(10,n),i=Math.round(e.lng*a)/a,o=Math.round(e.lat*a)/a,s=this._map.getBearing(),l=this._map.getPitch(),c="";return c+=t?"#/"+i+"/"+o+"/"+r:"#"+r+"/"+o+"/"+i,(s||l)&&(c+="/"+Math.round(10*s)/10),l&&(c+="/"+Math.round(l)),c},fn.prototype._onHashChange=function(){var e=t.window.location.hash.replace("#","").split("/");return e.length>=3&&(this._map.jumpTo({center:[+e[2],+e[1]],zoom:+e[0],bearing:+(e[3]||0),pitch:+(e[4]||0)}),!0)},fn.prototype._updateHashUnthrottled=function(){var e=this.getHashString();try{t.window.history.replaceState(t.window.history.state,"",e)}catch(t){}};var pn=function(e){function n(n,a,i,o){void 0===o&&(o={});var s=r.mousePos(a.getCanvasContainer(),i),l=a.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:i},o)),this._defaultPrevented=!1,this.target=a}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var a={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},a.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,a),n}(t.Event),dn=function(e){function n(n,a,i){var o=r.touchPos(a.getCanvasContainer(),i),s=o.map(function(t){return a.unproject(t)}),l=o.reduce(function(t,e,r,n){return t.add(e.div(n.length))},new t.Point(0,0)),c=a.unproject(l);e.call(this,n,{points:o,point:l,lngLats:s,lngLat:c,originalEvent:i}),this._defaultPrevented=!1}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var a={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},a.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,a),n}(t.Event),gn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),vn=function(e){this._map=e,this._el=e.getCanvasContainer(),this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=1/450,t.bindAll(["_onWheel","_onTimeout","_onScrollFrame","_onScrollFinished"],this)};vn.prototype.setZoomRate=function(t){this._defaultZoomRate=t},vn.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},vn.prototype.isEnabled=function(){return!!this._enabled},vn.prototype.isActive=function(){return!!this._active},vn.prototype.isZooming=function(){return!!this._zooming},vn.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&"center"===t.around)},vn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},vn.prototype.onWheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),a=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type="wheel":0!==r&&Math.abs(r)<4?this._type="trackpad":a>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(a*r)<200?"trackpad":"wheel",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this.isActive()||this._start(e)),e.preventDefault()}},vn.prototype._onTimeout=function(t){this._type="wheel",this._delta-=this._lastValue,this.isActive()||this._start(t)},vn.prototype._start=function(e){if(this._delta){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0,this._map.fire(new t.Event("movestart",{originalEvent:e})),this._map.fire(new t.Event("zoomstart",{originalEvent:e}))),this._finishTimeout&&clearTimeout(this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame))}},vn.prototype._onScrollFrame=function(){var e=this;if(this._frameId=null,this.isActive()){var r=this._map.transform;if(0!==this._delta){var n="wheel"===this._type&&Math.abs(this._delta)>4.000244140625?this._wheelZoomRate:this._defaultZoomRate,a=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==a&&(a=1/a);var i="number"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(i*a))),"wheel"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o="number"==typeof this._targetZoom?this._targetZoom:r.zoom,s=this._startZoom,l=this._easing,c=!1;if("wheel"===this._type&&s&&l){var u=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),h=l(u);r.zoom=t.number(s,o,h),u<1?this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame)):c=!0}else r.zoom=o,c=!0;r.setLocationAtPoint(this._around,this._aroundPoint),this._map.fire(new t.Event("move",{originalEvent:this._lastWheelEvent})),this._map.fire(new t.Event("zoom",{originalEvent:this._lastWheelEvent})),c&&(this._active=!1,this._finishTimeout=setTimeout(function(){e._zooming=!1,e._map.fire(new t.Event("zoomend",{originalEvent:e._lastWheelEvent})),e._map.fire(new t.Event("moveend",{originalEvent:e._lastWheelEvent})),delete e._targetZoom},200))}},vn.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,a=(t.browser.now()-n.start)/n.duration,i=n.easing(a+.01)-n.easing(a),o=.27/Math.sqrt(i*i+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r};var mn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._container=e.getContainer(),this._clickTolerance=r.clickTolerance||1,t.bindAll(["_onMouseMove","_onMouseUp","_onKeyDown"],this)};mn.prototype.isEnabled=function(){return!!this._enabled},mn.prototype.isActive=function(){return!!this._active},mn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},mn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},mn.prototype.onMouseDown=function(e){this.isEnabled()&&e.shiftKey&&0===e.button&&(t.window.document.addEventListener("mousemove",this._onMouseMove,!1),t.window.document.addEventListener("keydown",this._onKeyDown,!1),t.window.document.addEventListener("mouseup",this._onMouseUp,!1),r.disableDrag(),this._startPos=this._lastPos=r.mousePos(this._el,e),this._active=!0)},mn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);if(!(this._lastPos.equals(e)||!this._box&&e.dist(this._startPos)<this._clickTolerance)){var n=this._startPos;this._lastPos=e,this._box||(this._box=r.create("div","mapboxgl-boxzoom",this._container),this._container.classList.add("mapboxgl-crosshair"),this._fireEvent("boxzoomstart",t));var a=Math.min(n.x,e.x),i=Math.max(n.x,e.x),o=Math.min(n.y,e.y),s=Math.max(n.y,e.y);r.setTransform(this._box,"translate("+a+"px,"+o+"px)"),this._box.style.width=i-a+"px",this._box.style.height=s-o+"px"}},mn.prototype._onMouseUp=function(e){if(0===e.button){var n=this._startPos,a=r.mousePos(this._el,e);this._finish(),r.suppressClick(),n.x===a.x&&n.y===a.y?this._fireEvent("boxzoomcancel",e):this._map.fitScreenCoordinates(n,a,this._map.getBearing(),{linear:!0}).fire(new t.Event("boxzoomend",{originalEvent:e}))}},mn.prototype._onKeyDown=function(t){27===t.keyCode&&(this._finish(),this._fireEvent("boxzoomcancel",t))},mn.prototype._finish=function(){this._active=!1,t.window.document.removeEventListener("mousemove",this._onMouseMove,!1),t.window.document.removeEventListener("keydown",this._onKeyDown,!1),t.window.document.removeEventListener("mouseup",this._onMouseUp,!1),this._container.classList.remove("mapboxgl-crosshair"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},mn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var yn=t.bezier(0,0,.25,1),xn=function(e,r){this._map=e,this._el=r.element||e.getCanvasContainer(),this._state="disabled",this._button=r.button||"right",this._bearingSnap=r.bearingSnap||0,this._pitchWithRotate=!1!==r.pitchWithRotate,t.bindAll(["onMouseDown","_onMouseMove","_onMouseUp","_onBlur","_onDragFrame"],this)};xn.prototype.isEnabled=function(){return"disabled"!==this._state},xn.prototype.isActive=function(){return"active"===this._state},xn.prototype.enable=function(){this.isEnabled()||(this._state="enabled")},xn.prototype.disable=function(){if(this.isEnabled())switch(this._state){case"active":this._state="disabled",this._unbind(),this._deactivate(),this._fireEvent("rotateend"),this._pitchWithRotate&&this._fireEvent("pitchend"),this._fireEvent("moveend");break;case"pending":this._state="disabled",this._unbind();break;default:this._state="disabled"}},xn.prototype.onMouseDown=function(e){if("enabled"===this._state){var n="touchstart"===e.type;if(n)this._startTime=Date.now();else if("right"===this._button){if(this._eventButton=r.mouseButton(e),this._eventButton!==(e.ctrlKey?0:2))return}else{if(e.ctrlKey||0!==r.mouseButton(e))return;this._eventButton=0}r.disableDrag(),n?(t.window.document.addEventListener("touchmove",this._onMouseMove,{capture:!0}),t.window.document.addEventListener("touchend",this._onMouseUp)):(t.window.document.addEventListener("mousemove",this._onMouseMove,{capture:!0}),t.window.document.addEventListener("mouseup",this._onMouseUp)),t.window.addEventListener("blur",this._onBlur),this._state="pending",this._inertia=[[t.browser.now(),this._map.getBearing()]],this._startPos=this._prevPos=this._lastPos=r.mousePos(this._el,e),this._center=this._map.transform.centerPoint,e.preventDefault()}},xn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);this._lastPos.equals(e)||(this._lastMoveEvent=t,this._lastPos=e,"pending"===this._state&&(this._state="active",this._fireEvent("rotatestart",t),this._fireEvent("movestart",t),this._pitchWithRotate&&this._fireEvent("pitchstart",t)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},xn.prototype._onDragFrame=function(){this._frameId=null;var e=this._lastMoveEvent;if(e){var r=this._map.transform,n=this._prevPos,a=this._lastPos,i=.8*(n.x-a.x),o=-.5*(n.y-a.y),s=r.bearing-i,l=r.pitch-o,c=this._inertia,u=c[c.length-1];this._drainInertiaBuffer(),c.push([t.browser.now(),this._map._normalizeBearing(s,u[1])]),r.bearing=s,this._pitchWithRotate&&(this._fireEvent("pitch",e),r.pitch=l),this._fireEvent("rotate",e),this._fireEvent("move",e),delete this._lastMoveEvent,this._prevPos=this._lastPos}},xn.prototype._onMouseUp=function(t){if("touchend"===t.type&&this._startPos===this._lastPos&&Date.now()-this._startTime<300&&this._el.click(),r.mouseButton(t)===this._eventButton)switch(this._state){case"active":this._state="enabled",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialRotate(t);break;case"pending":this._state="enabled",this._unbind()}},xn.prototype._onBlur=function(t){switch(this._state){case"active":this._state="enabled",this._unbind(),this._deactivate(),this._fireEvent("rotateend",t),this._pitchWithRotate&&this._fireEvent("pitchend",t),this._fireEvent("moveend",t);break;case"pending":this._state="enabled",this._unbind()}},xn.prototype._unbind=function(){t.window.document.removeEventListener("mousemove",this._onMouseMove,{capture:!0}),t.window.document.removeEventListener("mouseup",this._onMouseUp),t.window.document.removeEventListener("touchmove",this._onMouseMove,{capture:!0}),t.window.document.removeEventListener("touchend",this._onMouseUp),t.window.removeEventListener("blur",this._onBlur),r.enableDrag()},xn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._prevPos,delete this._lastPos},xn.prototype._inertialRotate=function(t){var e=this;this._fireEvent("rotateend",t),this._drainInertiaBuffer();var r=this._map,n=r.getBearing(),a=this._inertia,i=function(){Math.abs(n)<e._bearingSnap?r.resetNorth({noMoveStart:!0},{originalEvent:t}):e._fireEvent("moveend",t),e._pitchWithRotate&&e._fireEvent("pitchend",t)};if(a.length<2)i();else{var o=a[0],s=a[a.length-1],l=a[a.length-2],c=r._normalizeBearing(n,l[1]),u=s[1]-o[1],h=u<0?-1:1,f=(s[0]-o[0])/1e3;if(0!==u&&0!==f){var p=Math.abs(u*(.25/f));p>180&&(p=180);var d=p/180;c+=h*p*(d/2),Math.abs(r._normalizeBearing(c,0))<this._bearingSnap&&(c=r._normalizeBearing(0,c)),r.rotateTo(c,{duration:1e3*d,easing:yn,noMoveStart:!0},{originalEvent:t})}else i()}},xn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},xn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var bn=t.bezier(0,0,.3,1),_n=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._state="disabled",this._clickTolerance=r.clickTolerance||1,t.bindAll(["_onMove","_onMouseUp","_onTouchEnd","_onBlur","_onDragFrame"],this)};_n.prototype.isEnabled=function(){return"disabled"!==this._state},_n.prototype.isActive=function(){return"active"===this._state},_n.prototype.enable=function(){this.isEnabled()||(this._el.classList.add("mapboxgl-touch-drag-pan"),this._state="enabled")},_n.prototype.disable=function(){if(this.isEnabled())switch(this._el.classList.remove("mapboxgl-touch-drag-pan"),this._state){case"active":this._state="disabled",this._unbind(),this._deactivate(),this._fireEvent("dragend"),this._fireEvent("moveend");break;case"pending":this._state="disabled",this._unbind();break;default:this._state="disabled"}},_n.prototype.onMouseDown=function(e){"enabled"===this._state&&(e.ctrlKey||0!==r.mouseButton(e)||(r.addEventListener(t.window.document,"mousemove",this._onMove,{capture:!0}),r.addEventListener(t.window.document,"mouseup",this._onMouseUp),this._start(e)))},_n.prototype.onTouchStart=function(e){"enabled"===this._state&&(e.touches.length>1||(r.addEventListener(t.window.document,"touchmove",this._onMove,{capture:!0,passive:!1}),r.addEventListener(t.window.document,"touchend",this._onTouchEnd),this._start(e)))},_n.prototype._start=function(e){t.window.addEventListener("blur",this._onBlur),this._state="pending",this._startPos=this._mouseDownPos=this._prevPos=this._lastPos=r.mousePos(this._el,e),this._inertia=[[t.browser.now(),this._startPos]]},_n.prototype._onMove=function(e){e.preventDefault();var n=r.mousePos(this._el,e);this._lastPos.equals(n)||"pending"===this._state&&n.dist(this._mouseDownPos)<this._clickTolerance||(this._lastMoveEvent=e,this._lastPos=n,this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),this._lastPos]),"pending"===this._state&&(this._state="active",this._fireEvent("dragstart",e),this._fireEvent("movestart",e)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},_n.prototype._onDragFrame=function(){this._frameId=null;var t=this._lastMoveEvent;if(t){var e=this._map.transform;e.setLocationAtPoint(e.pointLocation(this._prevPos),this._lastPos),this._fireEvent("drag",t),this._fireEvent("move",t),this._prevPos=this._lastPos,delete this._lastMoveEvent}},_n.prototype._onMouseUp=function(t){if(0===r.mouseButton(t))switch(this._state){case"active":this._state="enabled",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialPan(t);break;case"pending":this._state="enabled",this._unbind()}},_n.prototype._onTouchEnd=function(t){switch(this._state){case"active":this._state="enabled",this._unbind(),this._deactivate(),this._inertialPan(t);break;case"pending":this._state="enabled",this._unbind()}},_n.prototype._onBlur=function(t){switch(this._state){case"active":this._state="enabled",this._unbind(),this._deactivate(),this._fireEvent("dragend",t),this._fireEvent("moveend",t);break;case"pending":this._state="enabled",this._unbind()}},_n.prototype._unbind=function(){r.removeEventListener(t.window.document,"touchmove",this._onMove,{capture:!0,passive:!1}),r.removeEventListener(t.window.document,"touchend",this._onTouchEnd),r.removeEventListener(t.window.document,"mousemove",this._onMove,{capture:!0}),r.removeEventListener(t.window.document,"mouseup",this._onMouseUp),r.removeEventListener(t.window,"blur",this._onBlur)},_n.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._prevPos,delete this._mouseDownPos,delete this._lastPos},_n.prototype._inertialPan=function(t){this._fireEvent("dragend",t),this._drainInertiaBuffer();var e=this._inertia;if(e.length<2)this._fireEvent("moveend",t);else{var r=e[e.length-1],n=e[0],a=r[1].sub(n[1]),i=(r[0]-n[0])/1e3;if(0===i||r[1].equals(n[1]))this._fireEvent("moveend",t);else{var o=a.mult(.3/i),s=o.mag();s>1400&&(s=1400,o._unit()._mult(s));var l=s/750,c=o.mult(-l/2);this._map.panBy(c,{duration:1e3*l,easing:bn,noMoveStart:!0},{originalEvent:t})}}},_n.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},_n.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var wn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll(["_onKeyDown"],this)};function kn(t){return t*(2-t)}wn.prototype.isEnabled=function(){return!!this._enabled},wn.prototype.enable=function(){this.isEnabled()||(this._el.addEventListener("keydown",this._onKeyDown,!1),this._enabled=!0)},wn.prototype.disable=function(){this.isEnabled()&&(this._el.removeEventListener("keydown",this._onKeyDown),this._enabled=!1)},wn.prototype._onKeyDown=function(t){if(!(t.altKey||t.ctrlKey||t.metaKey)){var e=0,r=0,n=0,a=0,i=0;switch(t.keyCode){case 61:case 107:case 171:case 187:e=1;break;case 189:case 109:case 173:e=-1;break;case 37:t.shiftKey?r=-1:(t.preventDefault(),a=-1);break;case 39:t.shiftKey?r=1:(t.preventDefault(),a=1);break;case 38:t.shiftKey?n=1:(t.preventDefault(),i=-1);break;case 40:t.shiftKey?n=-1:(i=1,t.preventDefault());break;default:return}var o=this._map,s=o.getZoom(),l={duration:300,delayEndEvents:500,easing:kn,zoom:e?Math.round(s)+e*(t.shiftKey?2:1):s,bearing:o.getBearing()+15*r,pitch:o.getPitch()+10*n,offset:[100*-a,100*-i],center:o.getCenter()};o.easeTo(l,{originalEvent:t})}};var Tn=function(e){this._map=e,t.bindAll(["_onDblClick","_onZoomEnd"],this)};Tn.prototype.isEnabled=function(){return!!this._enabled},Tn.prototype.isActive=function(){return!!this._active},Tn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},Tn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},Tn.prototype.onTouchStart=function(t){var e=this;if(this.isEnabled()&&!(t.points.length>1))if(this._tapped){var r=t.points[0],n=this._tappedPoint;if(n&&n.dist(r)<=30){t.originalEvent.preventDefault();var a=function(){e._tapped&&e._zoom(t),e._map.off("touchcancel",i),e._resetTapped()},i=function(){e._map.off("touchend",a),e._resetTapped()};this._map.once("touchend",a),this._map.once("touchcancel",i)}else this._resetTapped()}else this._tappedPoint=t.points[0],this._tapped=setTimeout(function(){e._tapped=null,e._tappedPoint=null},300)},Tn.prototype._resetTapped=function(){clearTimeout(this._tapped),this._tapped=null,this._tappedPoint=null},Tn.prototype.onDblClick=function(t){this.isEnabled()&&(t.originalEvent.preventDefault(),this._zoom(t))},Tn.prototype._zoom=function(t){this._active=!0,this._map.on("zoomend",this._onZoomEnd),this._map.zoomTo(this._map.getZoom()+(t.originalEvent.shiftKey?-1:1),{around:t.lngLat},t)},Tn.prototype._onZoomEnd=function(){this._active=!1,this._map.off("zoomend",this._onZoomEnd)};var Mn=t.bezier(0,0,.15,1),An=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll(["_onMove","_onEnd","_onTouchFrame"],this)};An.prototype.isEnabled=function(){return!!this._enabled},An.prototype.enable=function(t){this.isEnabled()||(this._el.classList.add("mapboxgl-touch-zoom-rotate"),this._enabled=!0,this._aroundCenter=!!t&&"center"===t.around)},An.prototype.disable=function(){this.isEnabled()&&(this._el.classList.remove("mapboxgl-touch-zoom-rotate"),this._enabled=!1)},An.prototype.disableRotation=function(){this._rotationDisabled=!0},An.prototype.enableRotation=function(){this._rotationDisabled=!1},An.prototype.onStart=function(e){if(this.isEnabled()&&2===e.touches.length){var n=r.mousePos(this._el,e.touches[0]),a=r.mousePos(this._el,e.touches[1]),i=n.add(a).div(2);this._startVec=n.sub(a),this._startAround=this._map.transform.pointLocation(i),this._gestureIntent=void 0,this._inertia=[],r.addEventListener(t.window.document,"touchmove",this._onMove,{passive:!1}),r.addEventListener(t.window.document,"touchend",this._onEnd)}},An.prototype._getTouchEventData=function(t){var e=r.mousePos(this._el,t.touches[0]),n=r.mousePos(this._el,t.touches[1]),a=e.sub(n);return{vec:a,center:e.add(n).div(2),scale:a.mag()/this._startVec.mag(),bearing:this._rotationDisabled?0:180*a.angleWith(this._startVec)/Math.PI}},An.prototype._onMove=function(e){if(2===e.touches.length){var r=this._getTouchEventData(e),n=r.vec,a=r.scale,i=r.bearing;if(!this._gestureIntent){var o=this._rotationDisabled&&1!==a||Math.abs(1-a)>.15;Math.abs(i)>10?this._gestureIntent="rotate":o&&(this._gestureIntent="zoom"),this._gestureIntent&&(this._map.fire(new t.Event(this._gestureIntent+"start",{originalEvent:e})),this._map.fire(new t.Event("movestart",{originalEvent:e})),this._startVec=n)}this._lastTouchEvent=e,this._frameId||(this._frameId=this._map._requestRenderFrame(this._onTouchFrame)),e.preventDefault()}},An.prototype._onTouchFrame=function(){this._frameId=null;var e=this._gestureIntent;if(e){var r=this._map.transform;this._startScale||(this._startScale=r.scale,this._startBearing=r.bearing);var n=this._getTouchEventData(this._lastTouchEvent),a=n.center,i=n.bearing,o=n.scale,s=r.pointLocation(a),l=r.locationPoint(s);"rotate"===e&&(r.bearing=this._startBearing+i),r.zoom=r.scaleZoom(this._startScale*o),r.setLocationAtPoint(this._startAround,l),this._map.fire(new t.Event(e,{originalEvent:this._lastTouchEvent})),this._map.fire(new t.Event("move",{originalEvent:this._lastTouchEvent})),this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),o,a])}},An.prototype._onEnd=function(e){r.removeEventListener(t.window.document,"touchmove",this._onMove,{passive:!1}),r.removeEventListener(t.window.document,"touchend",this._onEnd);var n=this._gestureIntent,a=this._startScale;if(this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._gestureIntent,delete this._startScale,delete this._startBearing,delete this._lastTouchEvent,n){this._map.fire(new t.Event(n+"end",{originalEvent:e})),this._drainInertiaBuffer();var i=this._inertia,o=this._map;if(i.length<2)o.snapToNorth({},{originalEvent:e});else{var s=i[i.length-1],l=i[0],c=o.transform.scaleZoom(a*s[1]),u=o.transform.scaleZoom(a*l[1]),h=c-u,f=(s[0]-l[0])/1e3,p=s[2];if(0!==f&&c!==u){var d=.15*h/f;Math.abs(d)>2.5&&(d=d>0?2.5:-2.5);var g=1e3*Math.abs(d/(12*.15)),v=c+d*g/2e3;v<0&&(v=0),o.easeTo({zoom:v,duration:g,easing:Mn,around:this._aroundCenter?o.getCenter():o.unproject(p),noMoveStart:!0},{originalEvent:e})}else o.snapToNorth({},{originalEvent:e})}}},An.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>2&&r-e[0][0]>160;)e.shift()};var Sn={scrollZoom:vn,boxZoom:mn,dragRotate:xn,dragPan:_n,keyboard:wn,doubleClickZoom:Tn,touchZoomRotate:An},En=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll(["_renderFrameCallback"],this)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.resetNorthPitch=function(e,r){return this.easeTo(t.extend({bearing:0,pitch:0,duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){return e=t.LngLatBounds.convert(e),this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),0,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,a){if("number"==typeof(a=t.extend({padding:{top:0,bottom:0,right:0,left:0},offset:[0,0],maxZoom:this.transform.maxZoom},a)).padding){var i=a.padding;a.padding={top:i,bottom:i,right:i,left:i}}if(t.deepEqual(Object.keys(a.padding).sort(function(t,e){return t<e?-1:t>e?1:0}),["bottom","left","right","top"])){var o=this.transform,s=o.project(t.LngLat.convert(e)),l=o.project(t.LngLat.convert(r)),c=s.rotate(-n*Math.PI/180),u=l.rotate(-n*Math.PI/180),h=new t.Point(Math.max(c.x,u.x),Math.max(c.y,u.y)),f=new t.Point(Math.min(c.x,u.x),Math.min(c.y,u.y)),p=h.sub(f),d=(o.width-a.padding.left-a.padding.right)/p.x,g=(o.height-a.padding.top-a.padding.bottom)/p.y;if(!(g<0||d<0)){var v=Math.min(o.scaleZoom(o.scale*Math.min(d,g)),a.maxZoom),m=t.Point.convert(a.offset),y=(a.padding.left-a.padding.right)/2,x=(a.padding.top-a.padding.bottom)/2,b=new t.Point(m.x+y,m.y+x).mult(o.scale/o.zoomScale(v));return{center:o.unproject(s.add(l).div(2).sub(b)),zoom:v,bearing:n}}t.warnOnce("Map cannot fit within canvas with the given bounds, padding, and/or offset.")}else t.warnOnce("options.padding must be a positive number, or an Object with keys 'bottom', 'left', 'right', 'top'")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,a,i){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,a),a,i)},r.prototype._fitInternal=function(e,r,n){return e?(r=t.extend(e,r)).linear?this.easeTo(r,n):this.flyTo(r,n):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,a=!1,i=!1,o=!1;return"zoom"in e&&n.zoom!==+e.zoom&&(a=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),"bearing"in e&&n.bearing!==+e.bearing&&(i=!0,n.bearing=+e.bearing),"pitch"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),this.fire(new t.Event("movestart",r)).fire(new t.Event("move",r)),a&&this.fire(new t.Event("zoomstart",r)).fire(new t.Event("zoom",r)).fire(new t.Event("zoomend",r)),i&&this.fire(new t.Event("rotatestart",r)).fire(new t.Event("rotate",r)).fire(new t.Event("rotateend",r)),o&&this.fire(new t.Event("pitchstart",r)).fire(new t.Event("pitch",r)).fire(new t.Event("pitchend",r)),this.fire(new t.Event("moveend",r))},r.prototype.easeTo=function(e,r){var n=this;this.stop(),(!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate||t.browser.prefersReducedMotion)&&(e.duration=0);var a=this.transform,i=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l="zoom"in e?+e.zoom:i,c="bearing"in e?this._normalizeBearing(e.bearing,o):o,u="pitch"in e?+e.pitch:s,h=a.centerPoint.add(t.Point.convert(e.offset)),f=a.pointLocation(h),p=t.LngLat.convert(e.center||f);this._normalizeCenter(p);var d,g,v=a.project(f),m=a.project(p).sub(v),y=a.zoomScale(l-i);return e.around&&(d=t.LngLat.convert(e.around),g=a.locationPoint(d)),this._zooming=l!==i,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,e.noMoveStart),clearTimeout(this._easeEndTimeoutID),this._ease(function(e){if(n._zooming&&(a.zoom=t.number(i,l,e)),n._rotating&&(a.bearing=t.number(o,c,e)),n._pitching&&(a.pitch=t.number(s,u,e)),d)a.setLocationAtPoint(d,g);else{var f=a.zoomScale(a.zoom-i),p=l>i?Math.min(2,y):Math.max(.5,y),x=Math.pow(p,1-e),b=a.unproject(v.add(m.mult(e*x)).mult(f));a.setLocationAtPoint(a.renderWorldCopies?b.wrap():b,h)}n._fireMoveEvents(r)},function(){e.delayEndEvents?n._easeEndTimeoutID=setTimeout(function(){return n._afterEase(r)},e.delayEndEvents):n._afterEase(r)},e),this},r.prototype._prepareEase=function(e,r){this._moving=!0,r||this.fire(new t.Event("movestart",e)),this._zooming&&this.fire(new t.Event("zoomstart",e)),this._rotating&&this.fire(new t.Event("rotatestart",e)),this._pitching&&this.fire(new t.Event("pitchstart",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event("move",e)),this._zooming&&this.fire(new t.Event("zoom",e)),this._rotating&&this.fire(new t.Event("rotate",e)),this._pitching&&this.fire(new t.Event("pitch",e))},r.prototype._afterEase=function(e){var r=this._zooming,n=this._rotating,a=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,r&&this.fire(new t.Event("zoomend",e)),n&&this.fire(new t.Event("rotateend",e)),a&&this.fire(new t.Event("pitchend",e)),this.fire(new t.Event("moveend",e))},r.prototype.flyTo=function(e,r){var n=this;if(t.browser.prefersReducedMotion){var a=t.pick(e,["center","zoom","bearing","pitch","around"]);return this.jumpTo(a,r)}this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var i=this.transform,o=this.getZoom(),s=this.getBearing(),l=this.getPitch(),c="zoom"in e?t.clamp(+e.zoom,i.minZoom,i.maxZoom):o,u="bearing"in e?this._normalizeBearing(e.bearing,s):s,h="pitch"in e?+e.pitch:l,f=i.zoomScale(c-o),p=i.centerPoint.add(t.Point.convert(e.offset)),d=i.pointLocation(p),g=t.LngLat.convert(e.center||d);this._normalizeCenter(g);var v=i.project(d),m=i.project(g).sub(v),y=e.curve,x=Math.max(i.width,i.height),b=x/f,_=m.mag();if("minZoom"in e){var w=t.clamp(Math.min(e.minZoom,o,c),i.minZoom,i.maxZoom),k=x/i.zoomScale(w-o);y=Math.sqrt(k/_*2)}var T=y*y;function M(t){var e=(b*b-x*x+(t?-1:1)*T*T*_*_)/(2*(t?b:x)*T*_);return Math.log(Math.sqrt(e*e+1)-e)}function A(t){return(Math.exp(t)-Math.exp(-t))/2}function S(t){return(Math.exp(t)+Math.exp(-t))/2}var E=M(0),L=function(t){return S(E)/S(E+y*t)},C=function(t){return x*((S(E)*(A(e=E+y*t)/S(e))-A(E))/T)/_;var e},P=(M(1)-E)/y;if(Math.abs(_)<1e-6||!isFinite(P)){if(Math.abs(x-b)<1e-6)return this.easeTo(e,r);var O=b<x?-1:1;P=Math.abs(Math.log(b/x))/y,C=function(){return 0},L=function(t){return Math.exp(O*y*t)}}if("duration"in e)e.duration=+e.duration;else{var z="screenSpeed"in e?+e.screenSpeed/y:+e.speed;e.duration=1e3*P/z}return e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=s!==u,this._pitching=h!==l,this._prepareEase(r,!1),this._ease(function(e){var a=e*P,f=1/L(a);i.zoom=1===e?c:o+i.scaleZoom(f),n._rotating&&(i.bearing=t.number(s,u,e)),n._pitching&&(i.pitch=t.number(l,h,e));var d=1===e?g:i.unproject(v.add(m.mult(C(a))).mult(f));i.setLocationAtPoint(i.renderWorldCopies?d.wrap():d,p),n._fireMoveEvents(r)},function(){return n._afterEase(r)},e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var t=this._onEaseEnd;delete this._onEaseEnd,t.call(this)}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),Ln=function(e){void 0===e&&(e={}),this.options=e,t.bindAll(["_updateEditLink","_updateData","_updateCompact"],this)};Ln.prototype.getDefaultPosition=function(){return"bottom-right"},Ln.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create("div","mapboxgl-ctrl mapboxgl-ctrl-attrib"),this._innerContainer=r.create("div","mapboxgl-ctrl-attrib-inner",this._container),e&&this._container.classList.add("mapboxgl-compact"),this._updateAttributions(),this._updateEditLink(),this._map.on("styledata",this._updateData),this._map.on("sourcedata",this._updateData),this._map.on("moveend",this._updateEditLink),void 0===e&&(this._map.on("resize",this._updateCompact),this._updateCompact()),this._container},Ln.prototype.onRemove=function(){r.remove(this._container),this._map.off("styledata",this._updateData),this._map.off("sourcedata",this._updateData),this._map.off("moveend",this._updateEditLink),this._map.off("resize",this._updateCompact),this._map=void 0},Ln.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(".mapbox-improve-map"));var r=[{key:"owner",value:this.styleOwner},{key:"id",value:this.styleId},{key:"access_token",value:this._map._requestManager._customAccessToken||t.config.ACCESS_TOKEN}];if(e){var n=r.reduce(function(t,e,n){return e.value&&(t+=e.key+"="+e.value+(n<r.length-1?"&":"")),t},"?");e.href=t.config.FEEDBACK_URL+"/"+n+(this._map._hash?this._map._hash.getHashString(!0):""),e.rel="noopener nofollow"}},Ln.prototype._updateData=function(t){!t||"metadata"!==t.sourceDataType&&"style"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},Ln.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map(function(t){return"string"!=typeof t?"":t})):"string"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var a=r[n];if(a.used){var i=a.getSource();i.attribution&&t.indexOf(i.attribution)<0&&t.push(i.attribution)}}t.sort(function(t,e){return t.length-e.length});var o=(t=t.filter(function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0})).join(" | ");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove("mapboxgl-attrib-empty")):this._container.classList.add("mapboxgl-attrib-empty"),this._editLink=null)}},Ln.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add("mapboxgl-compact"):this._container.classList.remove("mapboxgl-compact")};var Cn=function(){t.bindAll(["_updateLogo"],this),t.bindAll(["_updateCompact"],this)};Cn.prototype.onAdd=function(t){this._map=t,this._container=r.create("div","mapboxgl-ctrl");var e=r.create("a","mapboxgl-ctrl-logo");return e.target="_blank",e.rel="noopener nofollow",e.href="https://www.mapbox.com/",e.setAttribute("aria-label","Mapbox logo"),e.setAttribute("rel","noopener nofollow"),this._container.appendChild(e),this._container.style.display="none",this._map.on("sourcedata",this._updateLogo),this._updateLogo(),this._map.on("resize",this._updateCompact),this._updateCompact(),this._container},Cn.prototype.onRemove=function(){r.remove(this._container),this._map.off("sourcedata",this._updateLogo),this._map.off("resize",this._updateCompact)},Cn.prototype.getDefaultPosition=function(){return"bottom-left"},Cn.prototype._updateLogo=function(t){t&&"metadata"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?"block":"none")},Cn.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}},Cn.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add("mapboxgl-compact"):e.classList.remove("mapboxgl-compact")}};var Pn=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};Pn.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},Pn.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var a=n[r];if(a.id===t)return void(a.cancelled=!0)}},Pn.prototype.run=function(){var t=this._currentlyRunning=this._queue;this._queue=[];for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!n.cancelled&&(n.callback(),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},Pn.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var On=t.window.HTMLImageElement,zn=t.window.HTMLElement,In={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:0,maxZoom:22,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,bearingSnap:7,clickTolerance:3,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:"sans-serif",transformRequest:null,accessToken:null,fadeDuration:300,crossSourceCollisions:!0},Dn=function(n){function a(e){var a=this;if(null!=(e=t.extend({},In,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error("maxZoom must be greater than minZoom");var i=new un(e.minZoom,e.maxZoom,e.renderWorldCopies);if(n.call(this,i,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new Pn,this._controls=[],this._mapId=t.uniqueId(),this._requestManager=new t.RequestManager(e.transformRequest,e.accessToken),"string"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error("Container '"+e.container+"' not found.")}else{if(!(e.container instanceof zn))throw new Error("Invalid type: 'container' must be a String or HTMLElement.");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll(["_onWindowOnline","_onWindowResize","_contextLost","_contextRestored"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error("Failed to initialize WebGL.");this.on("move",function(){return a._update(!1)}),this.on("moveend",function(){return a._update(!1)}),this.on("zoom",function(){return a._update(!0)}),void 0!==t.window&&(t.window.addEventListener("online",this._onWindowOnline,!1),t.window.addEventListener("resize",this._onWindowResize,!1)),function(t,e){var n=t.getCanvasContainer(),a=null,i=!1,o=null;for(var s in Sn)t[s]=new Sn[s](t,e),e.interactive&&e[s]&&t[s].enable(e[s]);r.addEventListener(n,"mouseout",function(e){t.fire(new pn("mouseout",t,e))}),r.addEventListener(n,"mousedown",function(a){i=!0,o=r.mousePos(n,a);var s=new pn("mousedown",t,a);t.fire(s),s.defaultPrevented||(e.interactive&&!t.doubleClickZoom.isActive()&&t.stop(),t.boxZoom.onMouseDown(a),t.boxZoom.isActive()||t.dragPan.isActive()||t.dragRotate.onMouseDown(a),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onMouseDown(a))}),r.addEventListener(n,"mouseup",function(e){var r=t.dragRotate.isActive();a&&!r&&t.fire(new pn("contextmenu",t,a)),a=null,i=!1,t.fire(new pn("mouseup",t,e))}),r.addEventListener(n,"mousemove",function(e){if(!t.dragPan.isActive()&&!t.dragRotate.isActive()){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new pn("mousemove",t,e))}}),r.addEventListener(n,"mouseover",function(e){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new pn("mouseover",t,e))}),r.addEventListener(n,"touchstart",function(r){var n=new dn("touchstart",t,r);t.fire(n),n.defaultPrevented||(e.interactive&&t.stop(),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onTouchStart(r),t.touchZoomRotate.onStart(r),t.doubleClickZoom.onTouchStart(n))},{passive:!1}),r.addEventListener(n,"touchmove",function(e){t.fire(new dn("touchmove",t,e))},{passive:!1}),r.addEventListener(n,"touchend",function(e){t.fire(new dn("touchend",t,e))}),r.addEventListener(n,"touchcancel",function(e){t.fire(new dn("touchcancel",t,e))}),r.addEventListener(n,"click",function(a){var i=r.mousePos(n,a);(!o||i.equals(o)||i.dist(o)<e.clickTolerance)&&t.fire(new pn("click",t,a))}),r.addEventListener(n,"dblclick",function(e){var r=new pn("dblclick",t,e);t.fire(r),r.defaultPrevented||t.doubleClickZoom.onDblClick(r)}),r.addEventListener(n,"contextmenu",function(e){var r=t.dragRotate.isActive();i||r?i&&(a=e):t.fire(new pn("contextmenu",t,e)),(t.dragRotate.isEnabled()||t.listens("contextmenu"))&&e.preventDefault()}),r.addEventListener(n,"wheel",function(r){e.interactive&&t.stop();var n=new gn("wheel",t,r);t.fire(n),n.defaultPrevented||t.scrollZoom.onWheel(r)},{passive:!1})}(this,e),this._hash=e.hash&&(new fn).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new Ln({customAttribution:e.customAttribution})),this.addControl(new Cn,e.logoPosition),this.on("style.load",function(){a.transform.unmodified&&a.jumpTo(a.style.stylesheet)}),this.on("data",function(e){a._update("style"===e.dataType),a.fire(new t.Event(e.dataType+"data",e))}),this.on("dataloading",function(e){a.fire(new t.Event(e.dataType+"dataloading",e))})}n&&(a.__proto__=n),a.prototype=Object.create(n&&n.prototype),a.prototype.constructor=a;var i={showTileBoundaries:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0},version:{configurable:!0}};return a.prototype._getMapId=function(){return this._mapId},a.prototype.addControl=function(e,r){if(void 0===r&&e.getDefaultPosition&&(r=e.getDefaultPosition()),void 0===r&&(r="top-right"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error("Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.")));var n=e.onAdd(this);this._controls.push(e);var a=this._controlPositions[r];return-1!==r.indexOf("bottom")?a.insertBefore(n,a.firstChild):a.appendChild(n),this},a.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error("Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},a.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],a=r[1];return this._resizeCanvas(n,a),this.transform.resize(n,a),this.painter.resize(n,a),this.fire(new t.Event("movestart",e)).fire(new t.Event("move",e)).fire(new t.Event("resize",e)).fire(new t.Event("moveend",e)),this},a.prototype.getBounds=function(){return this.transform.getBounds()},a.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},a.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},a.prototype.setMinZoom=function(t){if((t=null==t?0:t)>=0&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error("minZoom must be between 0 and the current maxZoom, inclusive")},a.prototype.getMinZoom=function(){return this.transform.minZoom},a.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error("maxZoom must be greater than the current minZoom")},a.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},a.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},a.prototype.getMaxZoom=function(){return this.transform.maxZoom},a.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},a.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},a.prototype.isMoving=function(){return this._moving||this.dragPan.isActive()||this.dragRotate.isActive()||this.scrollZoom.isActive()},a.prototype.isZooming=function(){return this._zooming||this.scrollZoom.isZooming()},a.prototype.isRotating=function(){return this._rotating||this.dragRotate.isActive()},a.prototype.on=function(t,e,r){var a=this;if(void 0===r)return n.prototype.on.call(this,t,e);var i=function(){var n;if("mouseenter"===t||"mouseover"===t){var i=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=a.getLayer(e)?a.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?i||(i=!0,r.call(a,new pn(t,a,n.originalEvent,{features:o}))):i=!1},mouseout:function(){i=!1}}}}if("mouseleave"===t||"mouseout"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(a.getLayer(e)?a.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(a,new pn(t,a,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(a,new pn(t,a,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=a.getLayer(e)?a.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(a,t),delete t.features)},n)}}();for(var o in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(i),i.delegates)this.on(o,i.delegates[o]);return this},a.prototype.off=function(t,e,r){if(void 0===r)return n.prototype.off.call(this,t,e);if(this._delegatedListeners&&this._delegatedListeners[t])for(var a=this._delegatedListeners[t],i=0;i<a.length;i++){var o=a[i];if(o.layer===e&&o.listener===r){for(var s in o.delegates)this.off(s,o.delegates[s]);return a.splice(i,1),this}}return this},a.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||"number"==typeof e[0])n=[t.Point.convert(e)];else{var a=t.Point.convert(e[0]),i=t.Point.convert(e[1]);n=[a,new t.Point(i.x,a.y),i,new t.Point(a.x,i.y),a]}return this.style.queryRenderedFeatures(n,r,this.transform)},a.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},a.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:this._localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},a.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new Re(this,e||{}),this.style.setEventedParent(this,{style:this.style}),"string"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},a.prototype._diffStyle=function(e,r){var n=this;if("string"==typeof e){var a=this._requestManager.normalizeStyleURL(e),i=this._requestManager.transformRequest(a,t.ResourceType.Style);t.getJSON(i,function(e,a){e?n.fire(new t.ErrorEvent(e)):a&&n._updateDiff(a,r)})}else"object"==typeof e&&this._updateDiff(e,r)},a.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce("Unable to perform style diff: "+(n.message||n.error||n)+".  Rebuilding the style from scratch."),this._updateStyle(e,r)}},a.prototype.getStyle=function(){if(this.style)return this.style.serialize()},a.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce("There is no style added to the map.")},a.prototype.addSource=function(t,e){return this.style.addSource(t,e),this._update(!0)},a.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error("There is no source with ID '"+e+"'")))},a.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var a=r[n];if("loaded"!==a.state&&"errored"!==a.state)return!1}}return!0},a.prototype.addSourceType=function(t,e,r){return this.style.addSourceType(t,e,r)},a.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},a.prototype.getSource=function(t){return this.style.getSource(t)},a.prototype.addImage=function(e,r,n){void 0===n&&(n={});var a=n.pixelRatio;void 0===a&&(a=1);var i=n.sdf;if(void 0===i&&(i=!1),r instanceof On){var o=t.browser.getImageData(r),s=o.width,l=o.height,c=o.data;this.style.addImage(e,{data:new t.RGBAImage({width:s,height:l},c),pixelRatio:a,sdf:i,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error("Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`")));var u=r.width,h=r.height,f=r.data,p=r;this.style.addImage(e,{data:new t.RGBAImage({width:u,height:h},new Uint8Array(f)),pixelRatio:a,sdf:i,version:0,userImage:p}),p.onAdd&&p.onAdd(this,e)}},a.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error("The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.")));var a=r instanceof On?t.browser.getImageData(r):r,i=a.width,o=a.height,s=a.data;if(void 0===i||void 0===o)return this.fire(new t.ErrorEvent(new Error("Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`")));if(i!==n.data.width||o!==n.data.height)return this.fire(new t.ErrorEvent(new Error("The width and height of the updated image must be that same as the previous version of the image")));var l=!(r instanceof On);n.data.replace(s,l),this.style.updateImage(e,n)},a.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error("Missing required image id"))),!1)},a.prototype.removeImage=function(t){this.style.removeImage(t)},a.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},a.prototype.listImages=function(){return this.style.listImages()},a.prototype.addLayer=function(t,e){return this.style.addLayer(t,e),this._update(!0)},a.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},a.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},a.prototype.getLayer=function(t){return this.style.getLayer(t)},a.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},a.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},a.prototype.getFilter=function(t){return this.style.getFilter(t)},a.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},a.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},a.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},a.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},a.prototype.setLight=function(t,e){return void 0===e&&(e={}),this.style.setLight(t,e),this._update(!0)},a.prototype.getLight=function(){return this.style.getLight()},a.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},a.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},a.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},a.prototype.getContainer=function(){return this._container},a.prototype.getCanvasContainer=function(){return this._canvasContainer},a.prototype.getCanvas=function(){return this._canvas},a.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},a.prototype._detectMissingCSS=function(){"rgb(250, 128, 114)"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue("background-color")&&t.warnOnce("This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.")},a.prototype._setupContainer=function(){var t=this._container;t.classList.add("mapboxgl-map"),(this._missingCSSCanary=r.create("div","mapboxgl-canary",t)).style.visibility="hidden",this._detectMissingCSS();var e=this._canvasContainer=r.create("div","mapboxgl-canvas-container",t);this._interactive&&e.classList.add("mapboxgl-interactive"),this._canvas=r.create("canvas","mapboxgl-canvas",e),this._canvas.style.position="absolute",this._canvas.addEventListener("webglcontextlost",this._contextLost,!1),this._canvas.addEventListener("webglcontextrestored",this._contextRestored,!1),this._canvas.setAttribute("tabindex","0"),this._canvas.setAttribute("aria-label","Map");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var a=this._controlContainer=r.create("div","mapboxgl-control-container",t),i=this._controlPositions={};["top-left","top-right","bottom-left","bottom-right"].forEach(function(t){i[t]=r.create("div","mapboxgl-ctrl-"+t,a)})},a.prototype._resizeCanvas=function(e,r){var n=t.window.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+"px",this._canvas.style.height=r+"px"},a.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext("webgl",r)||this._canvas.getContext("experimental-webgl",r);n?(this.painter=new on(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error("Failed to initialize WebGL")))},a.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event("webglcontextlost",{originalEvent:e}))},a.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event("webglcontextrestored",{originalEvent:e}))},a.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},a.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},a.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},a.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},a.prototype._render=function(){this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run();var e=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var r=this.transform.zoom,n=t.browser.now();this.style.zoomHistory.update(r,n);var a=new t.EvaluationParameters(r,{now:n,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),i=a.crossFadingFactor();1===i&&i===this._crossFadingFactor||(e=!0,this._crossFadingFactor=i),this.style.update(a)}return this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration}),this.fire(new t.Event("render")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event("load"))),this.style&&(this.style.hasTransitions()||e)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this._sourcesDirty||this._repaint||this._styleDirty||this._placementDirty?this.triggerRepaint():!this.isMoving()&&this.loaded()&&this.fire(new t.Event("idle")),this},a.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1)r[e].onRemove(this);this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener("resize",this._onWindowResize,!1),t.window.removeEventListener("online",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension("WEBGL_lose_context");n&&n.loseContext(),Rn(this._canvasContainer),Rn(this._controlContainer),Rn(this._missingCSSCanary),this._container.classList.remove("mapboxgl-map"),this.fire(new t.Event("remove"))},a.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame(function(){e._frame=null,e._render()}))},a.prototype._onWindowOnline=function(){this._update()},a.prototype._onWindowResize=function(){this._trackResize&&this.resize()._update()},i.showTileBoundaries.get=function(){return!!this._showTileBoundaries},i.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},i.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},i.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},i.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},i.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},i.repaint.get=function(){return!!this._repaint},i.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},i.vertices.get=function(){return!!this._vertices},i.vertices.set=function(t){this._vertices=t,this._update()},a.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},i.version.get=function(){return t.version},Object.defineProperties(a.prototype,i),a}(En);function Rn(t){t.parentNode&&t.parentNode.removeChild(t)}var Fn={showCompass:!0,showZoom:!0,visualizePitch:!1},Bn=function(e){var n=this;this.options=t.extend({},Fn,e),this._container=r.create("div","mapboxgl-ctrl mapboxgl-ctrl-group"),this._container.addEventListener("contextmenu",function(t){return t.preventDefault()}),this.options.showZoom&&(t.bindAll(["_updateZoomButtons"],this),this._zoomInButton=this._createButton("mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-in","Zoom in",function(){return n._map.zoomIn()}),this._zoomOutButton=this._createButton("mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-out","Zoom out",function(){return n._map.zoomOut()})),this.options.showCompass&&(t.bindAll(["_rotateCompassArrow"],this),this._compass=this._createButton("mapboxgl-ctrl-icon mapboxgl-ctrl-compass","Reset bearing to north",function(){n.options.visualizePitch?n._map.resetNorthPitch():n._map.resetNorth()}),this._compassArrow=r.create("span","mapboxgl-ctrl-compass-arrow",this._compass))};function Nn(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var a=new t.LngLat(e.lng-360,e.lat),i=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(a).distSqr(r)<o?e=a:n.locationPoint(i).distSqr(r)<o&&(e=i)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Bn.prototype._updateZoomButtons=function(){var t=this._map.getZoom();t===this._map.getMaxZoom()?this._zoomInButton.classList.add("mapboxgl-ctrl-icon-disabled"):this._zoomInButton.classList.remove("mapboxgl-ctrl-icon-disabled"),t===this._map.getMinZoom()?this._zoomOutButton.classList.add("mapboxgl-ctrl-icon-disabled"):this._zoomOutButton.classList.remove("mapboxgl-ctrl-icon-disabled")},Bn.prototype._rotateCompassArrow=function(){var t=this.options.visualizePitch?"scale("+1/Math.pow(Math.cos(this._map.transform.pitch*(Math.PI/180)),.5)+") rotateX("+this._map.transform.pitch+"deg) rotateZ("+this._map.transform.angle*(180/Math.PI)+"deg)":"rotate("+this._map.transform.angle*(180/Math.PI)+"deg)";this._compassArrow.style.transform=t},Bn.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._map.on("zoom",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this.options.visualizePitch&&this._map.on("pitch",this._rotateCompassArrow),this._map.on("rotate",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new xn(t,{button:"left",element:this._compass}),r.addEventListener(this._compass,"mousedown",this._handler.onMouseDown),r.addEventListener(this._compass,"touchstart",this._handler.onMouseDown,{passive:!1}),this._handler.enable()),this._container},Bn.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off("zoom",this._updateZoomButtons),this.options.showCompass&&(this.options.visualizePitch&&this._map.off("pitch",this._rotateCompassArrow),this._map.off("rotate",this._rotateCompassArrow),r.removeEventListener(this._compass,"mousedown",this._handler.onMouseDown),r.removeEventListener(this._compass,"touchstart",this._handler.onMouseDown,{passive:!1}),this._handler.disable(),delete this._handler),delete this._map},Bn.prototype._createButton=function(t,e,n){var a=r.create("button",t,this._container);return a.type="button",a.title=e,a.setAttribute("aria-label",e),a.addEventListener("click",n),a};var jn={center:"translate(-50%,-50%)",top:"translate(-50%,0)","top-left":"translate(0,0)","top-right":"translate(-100%,0)",bottom:"translate(-50%,-100%)","bottom-left":"translate(0,-100%)","bottom-right":"translate(-100%,-100%)",left:"translate(0,-50%)",right:"translate(-100%,-50%)"};function Vn(t,e,r){var n=t.classList;for(var a in jn)n.remove("mapboxgl-"+r+"-anchor-"+a);n.add("mapboxgl-"+r+"-anchor-"+e)}var Un,qn=function(e){function n(n,a){if(e.call(this),(n instanceof t.window.HTMLElement||a)&&(n=t.extend({element:n},a)),t.bindAll(["_update","_onMove","_onUp","_addDragHandler","_onMapClick"],this),this._anchor=n&&n.anchor||"center",this._color=n&&n.color||"#3FB1CE",this._draggable=n&&n.draggable||!1,this._state="inactive",n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create("div");var i=r.createNS("http://www.w3.org/2000/svg","svg");i.setAttributeNS(null,"display","block"),i.setAttributeNS(null,"height","41px"),i.setAttributeNS(null,"width","27px"),i.setAttributeNS(null,"viewBox","0 0 27 41");var o=r.createNS("http://www.w3.org/2000/svg","g");o.setAttributeNS(null,"stroke","none"),o.setAttributeNS(null,"stroke-width","1"),o.setAttributeNS(null,"fill","none"),o.setAttributeNS(null,"fill-rule","evenodd");var s=r.createNS("http://www.w3.org/2000/svg","g");s.setAttributeNS(null,"fill-rule","nonzero");var l=r.createNS("http://www.w3.org/2000/svg","g");l.setAttributeNS(null,"transform","translate(3.0, 29.0)"),l.setAttributeNS(null,"fill","#000000");for(var c=0,u=[{rx:"10.5",ry:"5.25002273"},{rx:"10.5",ry:"5.25002273"},{rx:"9.5",ry:"4.77275007"},{rx:"8.5",ry:"4.29549936"},{rx:"7.5",ry:"3.81822308"},{rx:"6.5",ry:"3.34094679"},{rx:"5.5",ry:"2.86367051"},{rx:"4.5",ry:"2.38636864"}];c<u.length;c+=1){var h=u[c],f=r.createNS("http://www.w3.org/2000/svg","ellipse");f.setAttributeNS(null,"opacity","0.04"),f.setAttributeNS(null,"cx","10.5"),f.setAttributeNS(null,"cy","5.80029008"),f.setAttributeNS(null,"rx",h.rx),f.setAttributeNS(null,"ry",h.ry),l.appendChild(f)}var p=r.createNS("http://www.w3.org/2000/svg","g");p.setAttributeNS(null,"fill",this._color);var d=r.createNS("http://www.w3.org/2000/svg","path");d.setAttributeNS(null,"d","M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z"),p.appendChild(d);var g=r.createNS("http://www.w3.org/2000/svg","g");g.setAttributeNS(null,"opacity","0.25"),g.setAttributeNS(null,"fill","#000000");var v=r.createNS("http://www.w3.org/2000/svg","path");v.setAttributeNS(null,"d","M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z"),g.appendChild(v);var m=r.createNS("http://www.w3.org/2000/svg","g");m.setAttributeNS(null,"transform","translate(6.0, 7.0)"),m.setAttributeNS(null,"fill","#FFFFFF");var y=r.createNS("http://www.w3.org/2000/svg","g");y.setAttributeNS(null,"transform","translate(8.0, 8.0)");var x=r.createNS("http://www.w3.org/2000/svg","circle");x.setAttributeNS(null,"fill","#000000"),x.setAttributeNS(null,"opacity","0.25"),x.setAttributeNS(null,"cx","5.5"),x.setAttributeNS(null,"cy","5.5"),x.setAttributeNS(null,"r","5.4999962");var b=r.createNS("http://www.w3.org/2000/svg","circle");b.setAttributeNS(null,"fill","#FFFFFF"),b.setAttributeNS(null,"cx","5.5"),b.setAttributeNS(null,"cy","5.5"),b.setAttributeNS(null,"r","5.4999962"),y.appendChild(x),y.appendChild(b),s.appendChild(l),s.appendChild(p),s.appendChild(g),s.appendChild(m),s.appendChild(y),i.appendChild(s),this._element.appendChild(i),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add("mapboxgl-marker"),this._element.addEventListener("dragstart",function(t){t.preventDefault()}),Vn(this._element,this._anchor,"marker"),this._popup=null}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on("move",this._update),t.on("moveend",this._update),this.setDraggable(this._draggable),this._update(),this._map.on("click",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off("click",this._onMapClick),this._map.off("move",this._update),this._map.off("moveend",this._update),this._map.off("mousedown",this._addDragHandler),this._map.off("touchstart",this._addDragHandler),this._map.off("mouseup",this._onUp),this._map.off("touchend",this._onUp),this._map.off("mousemove",this._onMove),this._map.off("touchmove",this._onMove),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null),t){if(!("offset"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],"top-left":[0,0],"top-right":[0,0],bottom:[0,-38.1],"bottom-left":[e,-1*(24.6+e)],"bottom-right":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat)}return this},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){this._map&&(this._map.transform.renderWorldCopies&&(this._lngLat=Nn(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset),t&&"moveend"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,jn[this._anchor]+" translate("+this._pos.x+"px, "+this._pos.y+"px)"))},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents="none","pending"===this._state&&(this._state="active",this.fire(new t.Event("dragstart"))),this.fire(new t.Event("drag"))},n.prototype._onUp=function(){this._element.style.pointerEvents="auto",this._positionDelta=null,this._map.off("mousemove",this._onMove),this._map.off("touchmove",this._onMove),"active"===this._state&&this.fire(new t.Event("dragend")),this._state="inactive"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._state="pending",this._map.on("mousemove",this._onMove),this._map.on("touchmove",this._onMove),this._map.once("mouseup",this._onUp),this._map.once("touchend",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on("mousedown",this._addDragHandler),this._map.on("touchstart",this._addDragHandler)):(this._map.off("mousedown",this._addDragHandler),this._map.off("touchstart",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n}(t.Evented),Hn={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showUserLocation:!0},Gn=function(e){function n(r){e.call(this),this.options=t.extend({},Hn,r),t.bindAll(["_onSuccess","_onError","_finish","_setupUI","_updateCamera","_updateMarker"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.onAdd=function(e){var n;return this._map=e,this._container=r.create("div","mapboxgl-ctrl mapboxgl-ctrl-group"),n=this._setupUI,void 0!==Un?n(Un):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:"geolocation"}).then(function(t){Un="denied"!==t.state,n(Un)}):(Un=!!t.window.navigator.geolocation,n(Un)),this._container},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),r.remove(this._container),this._map=void 0},n.prototype._onSuccess=function(e){if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case"WAITING_ACTIVE":case"ACTIVE_LOCK":case"ACTIVE_ERROR":this._watchState="ACTIVE_LOCK",this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-active-error"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-active");break;case"BACKGROUND":case"BACKGROUND_ERROR":this._watchState="BACKGROUND",this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-background-error"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-background")}this.options.showUserLocation&&"OFF"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&"ACTIVE_LOCK"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove("mapboxgl-user-location-dot-stale"),this.fire(new t.Event("geolocate",e)),this._finish()},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,a=this._map.getBearing(),i=t.extend({bearing:a},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),i,{geolocateSource:!0})},n.prototype._updateMarker=function(t){t?this._userLocationDotMarker.setLngLat([t.coords.longitude,t.coords.latitude]).addTo(this._map):this._userLocationDotMarker.remove()},n.prototype._onError=function(e){if(this.options.trackUserLocation)if(1===e.code)this._watchState="OFF",this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-active"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-active-error"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-background"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-background-error"),void 0!==this._geolocationWatchID&&this._clearWatch();else switch(this._watchState){case"WAITING_ACTIVE":this._watchState="ACTIVE_ERROR",this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-active"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-active-error");break;case"ACTIVE_LOCK":this._watchState="ACTIVE_ERROR",this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-active"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-active-error"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-waiting");break;case"BACKGROUND":this._watchState="BACKGROUND_ERROR",this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-background"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-background-error"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-waiting")}"OFF"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add("mapboxgl-user-location-dot-stale"),this.fire(new t.Event("error",e)),this._finish()},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;!1!==e?(this._container.addEventListener("contextmenu",function(t){return t.preventDefault()}),this._geolocateButton=r.create("button","mapboxgl-ctrl-icon mapboxgl-ctrl-geolocate",this._container),this._geolocateButton.type="button",this._geolocateButton.setAttribute("aria-label","Geolocate"),this.options.trackUserLocation&&(this._geolocateButton.setAttribute("aria-pressed","false"),this._watchState="OFF"),this.options.showUserLocation&&(this._dotElement=r.create("div","mapboxgl-user-location-dot"),this._userLocationDotMarker=new qn(this._dotElement),this.options.trackUserLocation&&(this._watchState="OFF")),this._geolocateButton.addEventListener("click",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on("movestart",function(e){e.geolocateSource||"ACTIVE_LOCK"!==n._watchState||(n._watchState="BACKGROUND",n._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-background"),n._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-active"),n.fire(new t.Event("trackuserlocationend")))})):t.warnOnce("Geolocation support is not available, the GeolocateControl will not be visible.")},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce("Geolocate control triggered before added to a map"),!1;if(this.options.trackUserLocation){switch(this._watchState){case"OFF":this._watchState="WAITING_ACTIVE",this.fire(new t.Event("trackuserlocationstart"));break;case"WAITING_ACTIVE":case"ACTIVE_LOCK":case"ACTIVE_ERROR":case"BACKGROUND_ERROR":this._watchState="OFF",this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-active"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-active-error"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-background"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-background-error"),this.fire(new t.Event("trackuserlocationend"));break;case"BACKGROUND":this._watchState="ACTIVE_LOCK",this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-background"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event("trackuserlocationstart"))}switch(this._watchState){case"WAITING_ACTIVE":this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-active");break;case"ACTIVE_LOCK":this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-active");break;case"ACTIVE_ERROR":this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-active-error");break;case"BACKGROUND":this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-background");break;case"BACKGROUND_ERROR":this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-background-error")}"OFF"===this._watchState&&void 0!==this._geolocationWatchID?this._clearWatch():void 0===this._geolocationWatchID&&(this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.setAttribute("aria-pressed","true"),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,this.options.positionOptions))}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.setAttribute("aria-pressed","false"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),Yn={maxWidth:100,unit:"metric"},Wn=function(e){this.options=t.extend({},Yn,e),t.bindAll(["_onMove","setUnit"],this)};function Xn(t,e,r){var n,a,i,o,s,l,c=r&&r.maxWidth||100,u=t._container.clientHeight/2,h=(n=t.unproject([0,u]),a=t.unproject([c,u]),i=Math.PI/180,o=n.lat*i,s=a.lat*i,l=Math.sin(o)*Math.sin(s)+Math.cos(o)*Math.cos(s)*Math.cos((a.lng-n.lng)*i),6371e3*Math.acos(Math.min(l,1)));if(r&&"imperial"===r.unit){var f=3.2808*h;f>5280?Zn(e,c,f/5280,"mi"):Zn(e,c,f,"ft")}else r&&"nautical"===r.unit?Zn(e,c,h/1852,"nm"):Zn(e,c,h,"m")}function Zn(t,e,r,n){var a,i,o,s=(a=r,(i=Math.pow(10,(""+Math.floor(a)).length-1))*(o=(o=a/i)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o))),l=s/r;"m"===n&&s>=1e3&&(s/=1e3,n="km"),t.style.width=e*l+"px",t.innerHTML=s+n}Wn.prototype.getDefaultPosition=function(){return"bottom-left"},Wn.prototype._onMove=function(){Xn(this._map,this._container,this.options)},Wn.prototype.onAdd=function(t){return this._map=t,this._container=r.create("div","mapboxgl-ctrl mapboxgl-ctrl-scale",t.getContainer()),this._map.on("move",this._onMove),this._onMove(),this._container},Wn.prototype.onRemove=function(){r.remove(this._container),this._map.off("move",this._onMove),this._map=void 0},Wn.prototype.setUnit=function(t){this.options.unit=t,Xn(this._map,this._container,this.options)};var Jn=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce("Full screen control 'container' must be a DOM element.")),t.bindAll(["_onClickFullscreen","_changeIcon"],this),"onfullscreenchange"in t.window.document?this._fullscreenchange="fullscreenchange":"onmozfullscreenchange"in t.window.document?this._fullscreenchange="mozfullscreenchange":"onwebkitfullscreenchange"in t.window.document?this._fullscreenchange="webkitfullscreenchange":"onmsfullscreenchange"in t.window.document&&(this._fullscreenchange="MSFullscreenChange"),this._className="mapboxgl-ctrl"};Jn.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create("div",this._className+" mapboxgl-ctrl-group"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display="none",t.warnOnce("This device does not support fullscreen mode.")),this._controlContainer},Jn.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},Jn.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},Jn.prototype._setupUI=function(){(this._fullscreenButton=r.create("button",this._className+"-icon "+this._className+"-fullscreen",this._controlContainer)).type="button",this._updateTitle(),this._fullscreenButton.addEventListener("click",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},Jn.prototype._updateTitle=function(){var t=this._isFullscreen()?"Exit fullscreen":"Enter fullscreen";this._fullscreenButton.setAttribute("aria-label",t),this._fullscreenButton.title=t},Jn.prototype._isFullscreen=function(){return this._fullscreen},Jn.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(this._className+"-shrink"),this._fullscreenButton.classList.toggle(this._className+"-fullscreen"),this._updateTitle())},Jn.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var Kn={closeButton:!0,closeOnClick:!0,className:"",maxWidth:"240px"},Qn=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(Kn),r),t.bindAll(["_update","_onClickClose","remove"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(e){var r=this;return this._map=e,this.options.closeOnClick&&this._map.on("click",this._onClickClose),this._map.on("remove",this.remove),this._update(),this._trackPointer?(this._map.on("mousemove",function(t){r._update(t.point)}),this._map.on("mouseup",function(t){r._update(t.point)}),this._container.classList.add("mapboxgl-popup-track-pointer"),this._map._canvasContainer.classList.add("mapboxgl-track-pointer")):this._map.on("move",this._update),this.fire(new t.Event("open")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off("move",this._update),this._map.off("click",this._onClickClose),this._map.off("remove",this.remove),this._map.off("mousemove"),delete this._map),this.fire(new t.Event("close")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._trackPointer=!1,this._update(),this._map&&(this._map.on("move",this._update),this._map.off("mousemove"),this._container.classList.remove("mapboxgl-popup-track-pointer"),this._map._canvasContainer.classList.remove("mapboxgl-track-pointer")),this},n.prototype.trackPointer=function(){var t=this;return this._trackPointer=!0,this._pos=null,this._map&&(this._map.off("move",this._update),this._map.on("mousemove",function(e){t._update(e.point)}),this._map.on("drag",function(e){t._update(e.point)}),this._container.classList.add("mapboxgl-popup-track-pointer"),this._map._canvasContainer.classList.add("mapboxgl-track-pointer")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),a=t.window.document.createElement("body");for(a.innerHTML=e;r=a.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},n.prototype._createContent=function(){this._content&&r.remove(this._content),this._content=r.create("div","mapboxgl-popup-content",this._container),this.options.closeButton&&(this._closeButton=r.create("button","mapboxgl-popup-close-button",this._content),this._closeButton.type="button",this._closeButton.setAttribute("aria-label","Close popup"),this._closeButton.innerHTML="&#215;",this._closeButton.addEventListener("click",this._onClickClose))},n.prototype._update=function(e){var n=this,a=this._lngLat||this._trackPointer;if(this._map&&a&&this._content&&(this._container||(this._container=r.create("div","mapboxgl-popup",this._map.getContainer()),this._tip=r.create("div","mapboxgl-popup-tip",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(" ").forEach(function(t){return n._container.classList.add(t)})),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=Nn(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||e)){var i=this._pos=this._trackPointer&&e?e:this._map.project(this._lngLat),o=this.options.anchor,s=function e(r){if(r){if("number"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.Point(0,0),top:new t.Point(0,r),"top-left":new t.Point(n,n),"top-right":new t.Point(-n,n),bottom:new t.Point(0,-r),"bottom-left":new t.Point(n,-n),"bottom-right":new t.Point(-n,-n),left:new t.Point(r,0),right:new t.Point(-r,0)}}if(r instanceof t.Point||Array.isArray(r)){var a=t.Point.convert(r);return{center:a,top:a,"top-left":a,"top-right":a,bottom:a,"bottom-left":a,"bottom-right":a,left:a,right:a}}return{center:t.Point.convert(r.center||[0,0]),top:t.Point.convert(r.top||[0,0]),"top-left":t.Point.convert(r["top-left"]||[0,0]),"top-right":t.Point.convert(r["top-right"]||[0,0]),bottom:t.Point.convert(r.bottom||[0,0]),"bottom-left":t.Point.convert(r["bottom-left"]||[0,0]),"bottom-right":t.Point.convert(r["bottom-right"]||[0,0]),left:t.Point.convert(r.left||[0,0]),right:t.Point.convert(r.right||[0,0])}}return e(new t.Point(0,0))}(this.options.offset);if(!o){var l,c=this._container.offsetWidth,u=this._container.offsetHeight;l=i.y+s.bottom.y<u?["top"]:i.y>this._map.transform.height-u?["bottom"]:[],i.x<c/2?l.push("left"):i.x>this._map.transform.width-c/2&&l.push("right"),o=0===l.length?"bottom":l.join("-")}var h=i.add(s[o]).round();r.setTransform(this._container,jn[o]+" translate("+h.x+"px,"+h.y+"px)"),Vn(this._container,o,"popup")}},n.prototype._onClickClose=function(){this.remove()},n}(t.Evented),$n={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,Map:Dn,NavigationControl:Bn,GeolocateControl:Gn,AttributionControl:Ln,ScaleControl:Wn,FullscreenControl:Jn,Popup:Qn,Marker:qn,Style:Re,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return It.workerCount},set workerCount(t){It.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:""};return $n}),r},"object"==typeof r&&"undefined"!=typeof e?e.exports=a():(n=n||self).mapboxgl=a()},{}],428:[function(t,e,r){"use strict";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=i(t,n);return r};var n=t("convex-hull");function a(t,e,r){for(var n=new Array(t),a=0;a<t;++a)n[a]=0,a===e&&(n[a]+=.5),a===r&&(n[a]+=.5);return n}function i(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],i=[],o=0;o<=t;++o)if(e&1<<o){r.push(a(t,o-1,o-1)),i.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(a(t,o-1,s-1)),i.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],h=[];for(s=0;s<u.length;++s){if(!i[u[s]])continue t;h.push(i[u[s]].slice())}c.push(h)}return c}},{"convex-hull":132}],429:[function(t,e,r){var n=t("./normalize"),a=t("gl-mat4/create"),i=t("gl-mat4/clone"),o=t("gl-mat4/determinant"),s=t("gl-mat4/invert"),l=t("gl-mat4/transpose"),c={length:t("gl-vec3/length"),normalize:t("gl-vec3/normalize"),dot:t("gl-vec3/dot"),cross:t("gl-vec3/cross")},u=a(),h=a(),f=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function g(t,e,r,n,a){t[0]=e[0]*n+r[0]*a,t[1]=e[1]*n+r[1]*a,t[2]=e[2]*n+r[2]*a}e.exports=function(t,e,r,a,v,m){if(e||(e=[0,0,0]),r||(r=[0,0,0]),a||(a=[0,0,0]),v||(v=[0,0,0,1]),m||(m=[0,0,0,1]),!n(u,t))return!1;if(i(h,u),h[3]=0,h[7]=0,h[11]=0,h[15]=1,Math.abs(o(h)<1e-8))return!1;var y,x,b,_,w,k,T,M=u[3],A=u[7],S=u[11],E=u[12],L=u[13],C=u[14],P=u[15];if(0!==M||0!==A||0!==S){if(f[0]=M,f[1]=A,f[2]=S,f[3]=P,!s(h,h))return!1;l(h,h),y=v,b=h,_=(x=f)[0],w=x[1],k=x[2],T=x[3],y[0]=b[0]*_+b[4]*w+b[8]*k+b[12]*T,y[1]=b[1]*_+b[5]*w+b[9]*k+b[13]*T,y[2]=b[2]*_+b[6]*w+b[10]*k+b[14]*T,y[3]=b[3]*_+b[7]*w+b[11]*k+b[15]*T}else v[0]=v[1]=v[2]=0,v[3]=1;if(e[0]=E,e[1]=L,e[2]=C,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),a[0]=c.dot(p[0],p[1]),g(p[1],p[1],p[0],1,-a[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),a[0]/=r[1],a[1]=c.dot(p[0],p[2]),g(p[2],p[2],p[0],1,-a[1]),a[2]=c.dot(p[1],p[2]),g(p[2],p[2],p[1],1,-a[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),a[1]/=r[2],a[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var O=0;O<3;O++)r[O]*=-1,p[O][0]*=-1,p[O][1]*=-1,p[O][2]*=-1;return m[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),m[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),m[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),m[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(m[0]=-m[0]),p[0][2]>p[2][0]&&(m[1]=-m[1]),p[1][0]>p[0][1]&&(m[2]=-m[2]),!0}},{"./normalize":430,"gl-mat4/clone":262,"gl-mat4/create":263,"gl-mat4/determinant":264,"gl-mat4/invert":268,"gl-mat4/transpose":279,"gl-vec3/cross":336,"gl-vec3/dot":341,"gl-vec3/length":351,"gl-vec3/normalize":358}],430:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,a=0;a<16;a++)t[a]=e[a]*n;return!0}},{}],431:[function(t,e,r){var n=t("gl-vec3/lerp"),a=t("mat4-recompose"),i=t("mat4-decompose"),o=t("gl-mat4/determinant"),s=t("quat-slerp"),l=h(),c=h(),u=h();function h(){return{translate:f(),scale:f(1),skew:f(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function f(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,h){if(0===o(e)||0===o(r))return!1;var f=i(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=i(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!f||!p||(n(u.translate,l.translate,c.translate,h),n(u.skew,l.skew,c.skew,h),n(u.scale,l.scale,c.scale,h),n(u.perspective,l.perspective,c.perspective,h),s(u.quaternion,l.quaternion,c.quaternion,h),a(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),0))}},{"gl-mat4/determinant":264,"gl-vec3/lerp":352,"mat4-decompose":429,"mat4-recompose":432,"quat-slerp":484}],432:[function(t,e,r){var n={identity:t("gl-mat4/identity"),translate:t("gl-mat4/translate"),multiply:t("gl-mat4/multiply"),create:t("gl-mat4/create"),scale:t("gl-mat4/scale"),fromRotationTranslation:t("gl-mat4/fromRotationTranslation")},a=(n.create(),n.create());e.exports=function(t,e,r,i,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(a),0!==i[2]&&(a[9]=i[2],n.multiply(t,t,a)),0!==i[1]&&(a[9]=0,a[8]=i[1],n.multiply(t,t,a)),0!==i[0]&&(a[8]=0,a[4]=i[0],n.multiply(t,t,a)),n.scale(t,t,r),t}},{"gl-mat4/create":263,"gl-mat4/fromRotationTranslation":266,"gl-mat4/identity":267,"gl-mat4/multiply":270,"gl-mat4/scale":277,"gl-mat4/translate":278}],433:[function(t,e,r){"use strict";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],434:[function(t,e,r){"use strict";var n=t("binary-search-bounds"),a=t("mat4-interpolate"),i=t("gl-mat4/invert"),o=t("gl-mat4/rotateX"),s=t("gl-mat4/rotateY"),l=t("gl-mat4/rotateZ"),c=t("gl-mat4/lookAt"),u=t("gl-mat4/translate"),h=(t("gl-mat4/scale"),t("gl-vec3/normalize")),f=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],f=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)f[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&f[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=f[c];else a(o,f,d,(t-e[r])/u)}var g=this.computedUp;g[0]=o[1],g[1]=o[5],g[2]=o[9],h(g,g);var v=this.computedInverse;i(v,o);var m=this.computedEye,y=v[15];m[0]=v[12]/y,m[1]=v[13]/y,m[2]=v[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=m[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||f,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var a=0,i=0;i<3;++i)a+=Math.pow(r[i]-e[i],2);a=Math.log(Math.sqrt(a)),this.computedRadius[0]=a},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var a=this.computedInverse;e&&s(a,a,e),r&&o(a,a,r),n&&l(a,a,n),this.setMatrix(t,i(this.computedMatrix,a))};var g=[0,0,0];d.pan=function(t,e,r,n){g[0]=-(e||0),g[1]=-(r||0),g[2]=-(n||0),this.recalcMatrix(t);var a=this.computedInverse;u(a,a,g),this.setMatrix(t,i(a,a))},d.translate=function(t,e,r,n){g[0]=e||0,g[1]=r||0,g[2]=n||0,this.recalcMatrix(t);var a=this.computedMatrix;u(a,a,g),this.setMatrix(t,a)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{"binary-search-bounds":93,"gl-mat4/invert":268,"gl-mat4/lookAt":269,"gl-mat4/rotateX":274,"gl-mat4/rotateY":275,"gl-mat4/rotateZ":276,"gl-mat4/scale":277,"gl-mat4/translate":278,"gl-vec3/normalize":358,"mat4-interpolate":431}],435:[function(t,e,r){"use strict";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),a=0;a<e;++a)r[a]=a;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}for(var i=new Array(e),a=0;a<e;++a)i[a]=a;i.sort(function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]});for(var o=[i[0],i[1]],s=[i[0],i[1]],a=2;a<e;++a){for(var l=i[a],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}for(var r=new Array(s.length+o.length-2),h=0,a=0,f=o.length;a<f;++a)r[h++]=o[a];for(var p=s.length-2;p>0;--p)r[h++]=s[p];return r};var n=t("robust-orientation")[3]},{"robust-orientation":508}],436:[function(t,e,r){"use strict";e.exports=function(t,e){e||(e=t,t=window);var r=0,a=0,i=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return"altKey"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),"shiftKey"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),"ctrlKey"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),"metaKey"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);"buttons"in s&&(t=0|s.buttons),(t!==r||c!==a||u!==i||l(s))&&(r=0|t,a=c||0,i=u||0,e&&e(r,a,i,o))}function u(t){c(0,t)}function h(){(r||a||i||o.shift||o.alt||o.meta||o.control)&&(a=i=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function f(t){l(t)&&e&&e(r,a,i,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function g(t){c(r&~n.buttons(t),t)}function v(){s||(s=!0,t.addEventListener("mousemove",p),t.addEventListener("mousedown",d),t.addEventListener("mouseup",g),t.addEventListener("mouseleave",u),t.addEventListener("mouseenter",u),t.addEventListener("mouseout",u),t.addEventListener("mouseover",u),t.addEventListener("blur",h),t.addEventListener("keyup",f),t.addEventListener("keydown",f),t.addEventListener("keypress",f),t!==window&&(window.addEventListener("blur",h),window.addEventListener("keyup",f),window.addEventListener("keydown",f),window.addEventListener("keypress",f)))}v();var m={element:t};return Object.defineProperties(m,{enabled:{get:function(){return s},set:function(e){e?v():s&&(s=!1,t.removeEventListener("mousemove",p),t.removeEventListener("mousedown",d),t.removeEventListener("mouseup",g),t.removeEventListener("mouseleave",u),t.removeEventListener("mouseenter",u),t.removeEventListener("mouseout",u),t.removeEventListener("mouseover",u),t.removeEventListener("blur",h),t.removeEventListener("keyup",f),t.removeEventListener("keydown",f),t.removeEventListener("keypress",f),t!==window&&(window.removeEventListener("blur",h),window.removeEventListener("keyup",f),window.removeEventListener("keydown",f),window.removeEventListener("keypress",f)))},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return a},enumerable:!0},y:{get:function(){return i},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),m};var n=t("mouse-event")},{"mouse-event":438}],437:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var a=t.clientX||0,i=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=a-o.left,r[1]=i-o.top,r}},{}],438:[function(t,e,r){"use strict";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if("object"==typeof t){if("buttons"in t)return t.buttons;if("which"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if("button"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if("object"==typeof t){if("offsetX"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if("object"==typeof t){if("offsetY"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],439:[function(t,e,r){"use strict";var n=t("to-px");e.exports=function(t,e,r){"function"==typeof t&&(r=!!e,e=t,t=window);var a=n("ex",t),i=function(t){r&&t.preventDefault();var n=t.deltaX||0,i=t.deltaY||0,o=t.deltaZ||0,s=t.deltaMode,l=1;switch(s){case 1:l=a;break;case 2:l=window.innerHeight}if(i*=l,o*=l,(n*=l)||i||o)return e(n,i,o,t)};return t.addEventListener("wheel",i),i}},{"to-px":537}],440:[function(t,e,r){"use strict";var n=t("typedarray-pool");function a(t){return"a"+t}function i(t){return"d"+t}function o(t,e){return"c"+t+"_"+e}function s(t){return"s"+t}function l(t,e){return"t"+t+"_"+e}function c(t){return"o"+t}function u(t){return"x"+t}function h(t){return"p"+t}function f(t,e){return"d"+t+"_"+e}function p(t){return"i"+t}function d(t,e){return"u"+t+"_"+e}function g(t){return"b"+t}function v(t){return"y"+t}function m(t){return"e"+t}function y(t){return"v"+t}e.exports=function(t){function e(t){throw new Error("ndarray-extract-contour: "+t)}"object"!=typeof t&&e("Must specify arguments");var r=t.order;Array.isArray(r)||e("Must specify order");var A=t.arrayArguments||1;A<1&&e("Must have at least one array argument");var S=t.scalarArguments||0;S<0&&e("Scalar arg count must be > 0");"function"!=typeof t.vertex&&e("Must specify vertex creation function");"function"!=typeof t.cell&&e("Must specify cell creation function");"function"!=typeof t.phase&&e("Must specify phase function");for(var E=t.getters||[],L=new Array(A),C=0;C<A;++C)E.indexOf(C)>=0?L[C]=!0:L[C]=!1;return function(t,e,r,A,S,E){var L=E.length,C=S.length;if(C<2)throw new Error("ndarray-extract-contour: Dimension must be at least 2");for(var P="extractContour"+S.join("_"),O=[],z=[],I=[],D=0;D<L;++D)I.push(a(D));for(var D=0;D<A;++D)I.push(u(D));for(var D=0;D<C;++D)z.push(s(D)+"="+a(0)+".shape["+D+"]|0");for(var D=0;D<L;++D){z.push(i(D)+"="+a(D)+".data",c(D)+"="+a(D)+".offset|0");for(var R=0;R<C;++R)z.push(l(D,R)+"="+a(D)+".stride["+R+"]|0")}for(var D=0;D<L;++D){z.push(h(D)+"="+c(D)),z.push(o(D,0));for(var R=1;R<1<<C;++R){for(var F=[],B=0;B<C;++B)R&1<<B&&F.push("-"+l(D,B));z.push(f(D,R)+"=("+F.join("")+")|0"),z.push(o(D,R)+"=0")}}for(var D=0;D<L;++D)for(var R=0;R<C;++R){var N=[l(D,S[R])];R>0&&N.push(l(D,S[R-1])+"*"+s(S[R-1])),z.push(d(D,S[R])+"=("+N.join("-")+")|0")}for(var D=0;D<C;++D)z.push(p(D)+"=0");z.push(_+"=0");for(var j=["2"],D=C-2;D>=0;--D)j.push(s(S[D]));z.push(w+"=("+j.join("*")+")|0",b+"=mallocUint32("+w+")",x+"=mallocUint32("+w+")",k+"=0"),z.push(g(0)+"=0");for(var R=1;R<1<<C;++R){for(var V=[],U=[],B=0;B<C;++B)R&1<<B&&(0===U.length?V.push("1"):V.unshift(U.join("*"))),U.push(s(S[B]));var q="";V[0].indexOf(s(S[C-2]))<0&&(q="-");var H=M(C,R,S);z.push(m(H)+"=(-"+V.join("-")+")|0",v(H)+"=("+q+V.join("-")+")|0",g(H)+"=0")}function G(t,e){O.push("for(",p(S[t]),"=",e,";",p(S[t]),"<",s(S[t]),";","++",p(S[t]),"){")}function Y(t){for(var e=0;e<L;++e)O.push(h(e),"+=",d(e,S[t]),";");O.push("}")}function W(){for(var t=1;t<1<<C;++t)O.push(T,"=",m(t),";",m(t),"=",v(t),";",v(t),"=",T,";")}z.push(y(0)+"=0",T+"=0"),function t(e,r){if(e<0)return void function(t){for(var e=0;e<L;++e)E[e]?O.push(o(e,0),"=",i(e),".get(",h(e),");"):O.push(o(e,0),"=",i(e),"[",h(e),"];");for(var r=[],e=0;e<L;++e)r.push(o(e,0));for(var e=0;e<A;++e)r.push(u(e));O.push(g(0),"=",b,"[",k,"]=phase(",r.join(),");");for(var n=1;n<1<<C;++n)O.push(g(n),"=",b,"[",k,"+",m(n),"];");for(var a=[],n=1;n<1<<C;++n)a.push("("+g(0)+"!=="+g(n)+")");O.push("if(",a.join("||"),"){");for(var s=[],e=0;e<C;++e)s.push(p(e));for(var e=0;e<L;++e){s.push(o(e,0));for(var n=1;n<1<<C;++n)E[e]?O.push(o(e,n),"=",i(e),".get(",h(e),"+",f(e,n),");"):O.push(o(e,n),"=",i(e),"[",h(e),"+",f(e,n),"];"),s.push(o(e,n))}for(var e=0;e<1<<C;++e)s.push(g(e));for(var e=0;e<A;++e)s.push(u(e));O.push("vertex(",s.join(),");",y(0),"=",x,"[",k,"]=",_,"++;");for(var l=(1<<C)-1,c=g(l),n=0;n<C;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,v=g(d),w=[],T=d;T>0;T=T-1&d)w.push(x+"["+k+"+"+m(T)+"]");w.push(y(0));for(var T=0;T<L;++T)1&n?w.push(o(T,l),o(T,d)):w.push(o(T,d),o(T,l));1&n?w.push(c,v):w.push(v,c);for(var T=0;T<A;++T)w.push(u(T));O.push("if(",c,"!==",v,"){","face(",w.join(),")}")}O.push("}",k,"+=1;")}(r);!function(t){for(var e=t-1;e>=0;--e)G(e,0);for(var r=[],e=0;e<L;++e)E[e]?r.push(i(e)+".get("+h(e)+")"):r.push(i(e)+"["+h(e)+"]");for(var e=0;e<A;++e)r.push(u(e));O.push(b,"[",k,"++]=phase(",r.join(),");");for(var e=0;e<t;++e)Y(e);for(var n=0;n<L;++n)O.push(h(n),"+=",d(n,S[t]),";")}(e);O.push("if(",s(S[e]),">0){",p(S[e]),"=1;");t(e-1,r|1<<S[e]);for(var n=0;n<L;++n)O.push(h(n),"+=",d(n,S[e]),";");e===C-1&&(O.push(k,"=0;"),W());G(e,2);t(e-1,r);e===C-1&&(O.push("if(",p(S[C-1]),"&1){",k,"=0;}"),W());Y(e);O.push("}")}(C-1,0),O.push("freeUint32(",x,");freeUint32(",b,");");var X=["'use strict';","function ",P,"(",I.join(),"){","var ",z.join(),";",O.join(""),"}","return ",P].join("");return new Function("vertex","face","phase","mallocUint32","freeUint32",X)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,S,r,L)};var x="V",b="P",_="N",w="Q",k="X",T="T";function M(t,e,r){for(var n=0,a=0;a<t;++a)e&1<<a&&(n|=1<<r[a]);return n}},{"typedarray-pool":543}],441:[function(t,e,r){"use strict";var n=t("cwise/lib/wrapper")({args:["index","array","scalar"],pre:{body:"{}",args:[],thisVars:[],localVars:[]},body:{body:"{_inline_1_arg1_=_inline_1_arg2_.apply(void 0,_inline_1_arg0_)}",args:[{name:"_inline_1_arg0_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_1_arg1_",lvalue:!0,rvalue:!1,count:1},{name:"_inline_1_arg2_",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[]},post:{body:"{}",args:[],thisVars:[],localVars:[]},debug:!1,funcName:"cwise",blockSize:64});e.exports=function(t,e){return n(t,e),t}},{"cwise/lib/wrapper":151}],442:[function(t,e,r){"use strict";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error("ndarray-gradient: invalid boundary conditions")}else r=n(e.dimension,"string"==typeof r?r:"clamp");if(t.dimension!==e.dimension+1)throw new Error("ndarray-gradient: output dimension must be +1 input dimension");if(t.shape[e.dimension]!==e.dimension)throw new Error("ndarray-gradient: output shape must match input shape");for(var a=0;a<e.dimension;++a)if(t.shape[a]!==e.shape[a])throw new Error("ndarray-gradient: shape mismatch");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(m=o[e])return m;var r=t.length,n=["function gradient(dst,src){var s=src.shape.slice();"];function a(e){for(var a=r-e.length,i=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push("0"):e.indexOf(-(l+1))>=0?s.push("s["+l+"]-1"):(s.push("-1"),i.push("1"),o.push("s["+l+"]-2"));var c=".lo("+i.join()+").hi("+o.join()+")";if(0===i.length&&(c=""),a>0){n.push("if(1");for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push("&&s[",l,"]>2");n.push("){grad",a,"(src.pick(",s.join(),")",c);for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(",dst.pick(",s.join(),",",l,")",c);n.push(");")}for(var l=0;l<e.length;++l){var u=Math.abs(e[l])-1,h="dst.pick("+s.join()+","+u+")"+c;switch(t[u]){case"clamp":var f=s.slice(),p=s.slice();e[l]<0?f[u]="s["+u+"]-2":p[u]="1",0===a?n.push("if(s[",u,"]>1){dst.set(",s.join(),",",u,",0.5*(src.get(",f.join(),")-src.get(",p.join(),")))}else{dst.set(",s.join(),",",u,",0)};"):n.push("if(s[",u,"]>1){diff(",h,",src.pick(",f.join(),")",c,",src.pick(",p.join(),")",c,");}else{zero(",h,");};");break;case"mirror":0===a?n.push("dst.set(",s.join(),",",u,",0);"):n.push("zero(",h,");");break;case"wrap":var d=s.slice(),g=s.slice();e[l]<0?(d[u]="s["+u+"]-2",g[u]="0"):(d[u]="s["+u+"]-1",g[u]="1"),0===a?n.push("if(s[",u,"]>2){dst.set(",s.join(),",",u,",0.5*(src.get(",d.join(),")-src.get(",g.join(),")))}else{dst.set(",s.join(),",",u,",0)};"):n.push("if(s[",u,"]>2){diff(",h,",src.pick(",d.join(),")",c,",src.pick(",g.join(),")",c,");}else{zero(",h,");};");break;default:throw new Error("ndarray-gradient: Invalid boundary condition")}}a>0&&n.push("};")}for(var s=0;s<1<<r;++s){for(var h=[],f=0;f<r;++f)s&1<<f&&h.push(f+1);for(var p=0;p<1<<h.length;++p){for(var d=h.slice(),f=0;f<h.length;++f)p&1<<f&&(d[f]=-d[f]);a(d)}}n.push("return dst;};return gradient");for(var g=["diff","zero"],v=[l,c],s=1;s<=r;++s)g.push("grad"+s),v.push(u(s));g.push(n.join(""));var m=Function.apply(void 0,g).apply(void 0,v);return i[e]=m,m}(r)(t,e)};var n=t("dup"),a=t("cwise-compiler"),i={},o={},s={body:"",args:[],thisVars:[],localVars:[]},l=a({args:["array","array","array"],pre:s,post:s,body:{args:[{name:"out",lvalue:!0,rvalue:!1,count:1},{name:"left",lvalue:!1,rvalue:!0,count:1},{name:"right",lvalue:!1,rvalue:!0,count:1}],body:"out=0.5*(left-right)",thisVars:[],localVars:[]},funcName:"cdiff"}),c=a({args:["array"],pre:s,post:s,body:{args:[{name:"out",lvalue:!0,rvalue:!1,count:1}],body:"out=0",thisVars:[],localVars:[]},funcName:"zero"});function u(t){if(t in i)return i[t];for(var e=[],r=0;r<t;++r)e.push("out",r,"s=0.5*(inp",r,"l-inp",r,"r);");var o=["array"],l=["junk"];for(r=0;r<t;++r){o.push("array"),l.push("out"+r+"s");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push("inp"+r+"l","inp"+r+"r")}return i[t]=a({args:o,pre:s,post:s,body:{body:e.join(""),args:l.map(function(t){return{name:t,lvalue:0===t.indexOf("out"),rvalue:0===t.indexOf("inp"),count:"junk"!==t|0}}),thisVars:[],localVars:[]},funcName:"fdTemplate"+t})}},{"cwise-compiler":148,dup:172}],443:[function(t,e,r){"use strict";var n=t("ndarray-warp"),a=t("gl-matrix-invert");e.exports=function(t,e,r){var i=e.dimension,o=a([],r);return n(t,e,function(t,e){for(var r=0;r<i;++r){t[r]=o[(i+1)*i+r];for(var n=0;n<i;++n)t[r]+=o[(i+1)*n+r]*e[n]}var a=o[(i+1)*(i+1)-1];for(n=0;n<i;++n)a+=o[(i+1)*n+i]*e[n];var s=1/a;for(r=0;r<i;++r)t[r]*=s;return t}),t}},{"gl-matrix-invert":280,"ndarray-warp":450}],444:[function(t,e,r){"use strict";function n(t,e){var r=Math.floor(e),n=e-r,a=0<=r&&r<t.shape[0],i=0<=r+1&&r+1<t.shape[0];return(1-n)*(a?+t.get(r):0)+n*(i?+t.get(r+1):0)}function a(t,e,r){var n=Math.floor(e),a=e-n,i=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],h=i&&c?t.get(n,s):0,f=i&&u?t.get(n,s+1):0;return(1-l)*((1-a)*h+a*(o&&c?t.get(n+1,s):0))+l*((1-a)*f+a*(o&&u?t.get(n+1,s+1):0))}function i(t,e,r,n){var a=Math.floor(e),i=e-a,o=0<=a&&a<t.shape[0],s=0<=a+1&&a+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],h=0<=l+1&&l+1<t.shape[1],f=Math.floor(n),p=n-f,d=0<=f&&f<t.shape[2],g=0<=f+1&&f+1<t.shape[2],v=o&&u&&d?t.get(a,l,f):0,m=o&&h&&d?t.get(a,l+1,f):0,y=s&&u&&d?t.get(a+1,l,f):0,x=s&&h&&d?t.get(a+1,l+1,f):0,b=o&&u&&g?t.get(a,l,f+1):0,_=o&&h&&g?t.get(a,l+1,f+1):0;return(1-p)*((1-c)*((1-i)*v+i*y)+c*((1-i)*m+i*x))+p*((1-c)*((1-i)*b+i*(s&&u&&g?t.get(a+1,l,f+1):0))+c*((1-i)*_+i*(s&&h&&g?t.get(a+1,l+1,f+1):0)))}e.exports=function(t,e,r,o){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return a(t,e,r);case 3:return i(t,e,r,o);default:return function(t){var e,r,n=0|t.shape.length,a=new Array(n),i=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],a[e]=Math.floor(r),i[e]=r-a[e],o[e]=0<=a[e]&&a[e]<t.shape[e],s[e]=0<=a[e]+1&&a[e]+1<t.shape[e];var l,c,u,h=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=i[l],u+=t.stride[l]*(a[l]+1)}else{if(!o[l])continue t;c*=1-i[l],u+=t.stride[l]*a[l]}h+=c*t.data[u]}return h}.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=a,e.exports.d3=i},{}],445:[function(t,e,r){"use strict";var n=t("cwise-compiler"),a={body:"",args:[],thisVars:[],localVars:[]};function i(t){if(!t)return a;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push("a"+r);return new Function("P",["return function ",t.funcName,"_ndarrayops(",e.join(","),") {P(",e.join(","),");return a0}"].join(""))(function(t){return n({args:t.args,pre:i(t.pre),body:i(t.body),post:i(t.proc),funcName:t.funcName})}(t))}var s={add:"+",sub:"-",mul:"*",div:"/",mod:"%",band:"&",bor:"|",bxor:"^",lshift:"<<",rshift:">>",rrshift:">>>"};!function(){for(var t in s){var e=s[t];r[t]=o({args:["array","array","array"],body:{args:["a","b","c"],body:"a=b"+e+"c"},funcName:t}),r[t+"eq"]=o({args:["array","array"],body:{args:["a","b"],body:"a"+e+"=b"},rvalue:!0,funcName:t+"eq"}),r[t+"s"]=o({args:["array","array","scalar"],body:{args:["a","b","s"],body:"a=b"+e+"s"},funcName:t+"s"}),r[t+"seq"]=o({args:["array","scalar"],body:{args:["a","s"],body:"a"+e+"=s"},rvalue:!0,funcName:t+"seq"})}}();var l={not:"!",bnot:"~",neg:"-",recip:"1.0/"};!function(){for(var t in l){var e=l[t];r[t]=o({args:["array","array"],body:{args:["a","b"],body:"a="+e+"b"},funcName:t}),r[t+"eq"]=o({args:["array"],body:{args:["a"],body:"a="+e+"a"},rvalue:!0,count:2,funcName:t+"eq"})}}();var c={and:"&&",or:"||",eq:"===",neq:"!==",lt:"<",gt:">",leq:"<=",geq:">="};!function(){for(var t in c){var e=c[t];r[t]=o({args:["array","array","array"],body:{args:["a","b","c"],body:"a=b"+e+"c"},funcName:t}),r[t+"s"]=o({args:["array","array","scalar"],body:{args:["a","b","s"],body:"a=b"+e+"s"},funcName:t+"s"}),r[t+"eq"]=o({args:["array","array"],body:{args:["a","b"],body:"a=a"+e+"b"},rvalue:!0,count:2,funcName:t+"eq"}),r[t+"seq"]=o({args:["array","scalar"],body:{args:["a","s"],body:"a=a"+e+"s"},rvalue:!0,count:2,funcName:t+"seq"})}}();var u=["abs","acos","asin","atan","ceil","cos","exp","floor","log","round","sin","sqrt","tan"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:["array","array"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b"],body:"a=this_f(b)",thisVars:["this_f"]},funcName:e}),r[e+"eq"]=o({args:["array"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a"],body:"a=this_f(a)",thisVars:["this_f"]},rvalue:!0,count:2,funcName:e+"eq"})}}();var h=["max","min","atan2","pow"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e]=o({args:["array","array","array"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b","c"],body:"a=this_f(b,c)",thisVars:["this_f"]},funcName:e}),r[e+"s"]=o({args:["array","array","scalar"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b","c"],body:"a=this_f(b,c)",thisVars:["this_f"]},funcName:e+"s"}),r[e+"eq"]=o({args:["array","array"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b"],body:"a=this_f(a,b)",thisVars:["this_f"]},rvalue:!0,count:2,funcName:e+"eq"}),r[e+"seq"]=o({args:["array","scalar"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b"],body:"a=this_f(a,b)",thisVars:["this_f"]},rvalue:!0,count:2,funcName:e+"seq"})}}();var f=["atan2","pow"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e+"op"]=o({args:["array","array","array"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b","c"],body:"a=this_f(c,b)",thisVars:["this_f"]},funcName:e+"op"}),r[e+"ops"]=o({args:["array","array","scalar"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b","c"],body:"a=this_f(c,b)",thisVars:["this_f"]},funcName:e+"ops"}),r[e+"opeq"]=o({args:["array","array"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b"],body:"a=this_f(b,a)",thisVars:["this_f"]},rvalue:!0,count:2,funcName:e+"opeq"}),r[e+"opseq"]=o({args:["array","scalar"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b"],body:"a=this_f(b,a)",thisVars:["this_f"]},rvalue:!0,count:2,funcName:e+"opseq"})}}(),r.any=n({args:["array"],pre:a,body:{args:[{name:"a",lvalue:!1,rvalue:!0,count:1}],body:"if(a){return true}",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:"return false"},funcName:"any"}),r.all=n({args:["array"],pre:a,body:{args:[{name:"x",lvalue:!1,rvalue:!0,count:1}],body:"if(!x){return false}",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:"return true"},funcName:"all"}),r.sum=n({args:["array"],pre:{args:[],localVars:[],thisVars:["this_s"],body:"this_s=0"},body:{args:[{name:"a",lvalue:!1,rvalue:!0,count:1}],body:"this_s+=a",localVars:[],thisVars:["this_s"]},post:{args:[],localVars:[],thisVars:["this_s"],body:"return this_s"},funcName:"sum"}),r.prod=n({args:["array"],pre:{args:[],localVars:[],thisVars:["this_s"],body:"this_s=1"},body:{args:[{name:"a",lvalue:!1,rvalue:!0,count:1}],body:"this_s*=a",localVars:[],thisVars:["this_s"]},post:{args:[],localVars:[],thisVars:["this_s"],body:"return this_s"},funcName:"prod"}),r.norm2squared=n({args:["array"],pre:{args:[],localVars:[],thisVars:["this_s"],body:"this_s=0"},body:{args:[{name:"a",lvalue:!1,rvalue:!0,count:2}],body:"this_s+=a*a",localVars:[],thisVars:["this_s"]},post:{args:[],localVars:[],thisVars:["this_s"],body:"return this_s"},funcName:"norm2squared"}),r.norm2=n({args:["array"],pre:{args:[],localVars:[],thisVars:["this_s"],body:"this_s=0"},body:{args:[{name:"a",lvalue:!1,rvalue:!0,count:2}],body:"this_s+=a*a",localVars:[],thisVars:["this_s"]},post:{args:[],localVars:[],thisVars:["this_s"],body:"return Math.sqrt(this_s)"},funcName:"norm2"}),r.norminf=n({args:["array"],pre:{args:[],localVars:[],thisVars:["this_s"],body:"this_s=0"},body:{args:[{name:"a",lvalue:!1,rvalue:!0,count:4}],body:"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}",localVars:[],thisVars:["this_s"]},post:{args:[],localVars:[],thisVars:["this_s"],body:"return this_s"},funcName:"norminf"}),r.norm1=n({args:["array"],pre:{args:[],localVars:[],thisVars:["this_s"],body:"this_s=0"},body:{args:[{name:"a",lvalue:!1,rvalue:!0,count:3}],body:"this_s+=a<0?-a:a",localVars:[],thisVars:["this_s"]},post:{args:[],localVars:[],thisVars:["this_s"],body:"return this_s"},funcName:"norm1"}),r.sup=n({args:["array"],pre:{body:"this_h=-Infinity",args:[],thisVars:["this_h"],localVars:[]},body:{body:"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_",args:[{name:"_inline_1_arg0_",lvalue:!1,rvalue:!0,count:2}],thisVars:["this_h"],localVars:[]},post:{body:"return this_h",args:[],thisVars:["this_h"],localVars:[]}}),r.inf=n({args:["array"],pre:{body:"this_h=Infinity",args:[],thisVars:["this_h"],localVars:[]},body:{body:"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_",args:[{name:"_inline_1_arg0_",lvalue:!1,rvalue:!0,count:2}],thisVars:["this_h"],localVars:[]},post:{body:"return this_h",args:[],thisVars:["this_h"],localVars:[]}}),r.argmin=n({args:["index","array","shape"],pre:{body:"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}",args:[{name:"_inline_0_arg0_",lvalue:!1,rvalue:!1,count:0},{name:"_inline_0_arg1_",lvalue:!1,rvalue:!1,count:0},{name:"_inline_0_arg2_",lvalue:!1,rvalue:!0,count:1}],thisVars:["this_i","this_v"],localVars:[]},body:{body:"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}",args:[{name:"_inline_1_arg0_",lvalue:!1,rvalue:!0,count:2},{name:"_inline_1_arg1_",lvalue:!1,rvalue:!0,count:2}],thisVars:["this_i","this_v"],localVars:["_inline_1_k"]},post:{body:"{return this_i}",args:[],thisVars:["this_i"],localVars:[]}}),r.argmax=n({args:["index","array","shape"],pre:{body:"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}",args:[{name:"_inline_0_arg0_",lvalue:!1,rvalue:!1,count:0},{name:"_inline_0_arg1_",lvalue:!1,rvalue:!1,count:0},{name:"_inline_0_arg2_",lvalue:!1,rvalue:!0,count:1}],thisVars:["this_i","this_v"],localVars:[]},body:{body:"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}",args:[{name:"_inline_1_arg0_",lvalue:!1,rvalue:!0,count:2},{name:"_inline_1_arg1_",lvalue:!1,rvalue:!0,count:2}],thisVars:["this_i","this_v"],localVars:["_inline_1_k"]},post:{body:"{return this_i}",args:[],thisVars:["this_i"],localVars:[]}}),r.random=o({args:["array"],pre:{args:[],body:"this_f=Math.random",thisVars:["this_f"]},body:{args:["a"],body:"a=this_f()",thisVars:["this_f"]},funcName:"random"}),r.assign=o({args:["array","array"],body:{args:["a","b"],body:"a=b"},funcName:"assign"}),r.assigns=o({args:["array","scalar"],body:{args:["a","b"],body:"a=b"},funcName:"assigns"}),r.equals=n({args:["array","array"],pre:a,body:{args:[{name:"x",lvalue:!1,rvalue:!0,count:1},{name:"y",lvalue:!1,rvalue:!0,count:1}],body:"if(x!==y){return false}",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:"return true"},funcName:"equals"})},{"cwise-compiler":148}],446:[function(t,e,r){"use strict";var n=t("ndarray"),a=t("./doConvert.js");e.exports=function(t,e){for(var r=[],i=t,o=1;Array.isArray(i);)r.push(i.length),o*=i.length,i=i[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),a(e,t),e)}},{"./doConvert.js":447,ndarray:451}],447:[function(t,e,r){e.exports=t("cwise-compiler")({args:["array","scalar","index"],pre:{body:"{}",args:[],thisVars:[],localVars:[]},body:{body:"{\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\n}\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\n}",args:[{name:"_inline_1_arg0_",lvalue:!0,rvalue:!1,count:1},{name:"_inline_1_arg1_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_1_arg2_",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:["_inline_1_i","_inline_1_v"]},post:{body:"{}",args:[],thisVars:[],localVars:[]},funcName:"convert",blockSize:64})},{"cwise-compiler":148}],448:[function(t,e,r){"use strict";var n=t("typedarray-pool"),a=32;function i(t){switch(t){case"uint8":return[n.mallocUint8,n.freeUint8];case"uint16":return[n.mallocUint16,n.freeUint16];case"uint32":return[n.mallocUint32,n.freeUint32];case"int8":return[n.mallocInt8,n.freeInt8];case"int16":return[n.mallocInt16,n.freeInt16];case"int32":return[n.mallocInt32,n.freeInt32];case"float32":return[n.mallocFloat,n.freeFloat];case"float64":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push("s"+r);for(r=0;r<t;++r)e.push("n"+r);for(r=1;r<t;++r)e.push("d"+r);for(r=1;r<t;++r)e.push("e"+r);for(r=1;r<t;++r)e.push("f"+r);return e}e.exports=function(t,e){var r=["'use strict'"],n=["ndarraySortWrapper",t.join("d"),e].join("");r.push(["function ",n,"(",["array"].join(","),"){"].join(""));for(var s=["data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride"],l=0;l<t.length;++l)s.push(["s",l,"=stride[",l,"]|0,n",l,"=shape[",l,"]|0"].join(""));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l)0!==(p=t[l])&&(0===u.length?c[p]="1":c[p]=u.join("*"),u.push("n"+p));var h=-1,f=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(h>0?s.push(["d",d,"=s",d,"-d",h,"*n",h].join("")):s.push(["d",d,"=s",d].join("")),h=d),0!=(p=t.length-1-l)&&(f>0?s.push(["e",p,"=s",p,"-e",f,"*n",f,",f",p,"=",c[p],"-f",f,"*n",f].join("")):s.push(["e",p,"=s",p,",f",p,"=",c[p]].join("")),f=p)}r.push("var "+s.join(","));var g=["0","n0-1","data","offset"].concat(o(t.length));r.push(["if(n0<=",a,"){","insertionSort(",g.join(","),")}else{","quickSort(",g.join(","),")}"].join("")),r.push("}return "+n);var v=new Function("insertionSort","quickSort",r.join("\n")),m=function(t,e){var r=["'use strict'"],n=["ndarrayInsertionSort",t.join("d"),e].join(""),a=["left","right","data","offset"].concat(o(t.length)),s=i(e),l=["i,j,cptr,ptr=left*s0+offset"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push("i"+u),c.push("n"+u);s?l.push("scratch=malloc("+c.join("*")+")"):l.push("scratch=new Array("+c.join("*")+")"),l.push("dptr","sptr","a","b")}else l.push("scratch");function h(t){return"generic"===e?["data.get(",t,")"].join(""):["data[",t,"]"].join("")}function f(t,r){return"generic"===e?["data.set(",t,",",r,")"].join(""):["data[",t,"]=",r].join("")}if(r.push(["function ",n,"(",a.join(","),"){var ",l.join(",")].join(""),"for(i=left+1;i<=right;++i){","j=i;ptr+=s0","cptr=ptr"),t.length>1){for(r.push("dptr=0;sptr=ptr"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push(["for(i",p,"=0;i",p,"<n",p,";++i",p,"){"].join(""));for(r.push("scratch[dptr++]=",h("sptr")),u=0;u<t.length;++u)0!==(p=t[u])&&r.push("sptr+=d"+p,"}");for(r.push("__g:while(j--\x3eleft){","dptr=0","sptr=cptr-s0"),u=1;u<t.length;++u)1===u&&r.push("__l:"),r.push(["for(i",u,"=0;i",u,"<n",u,";++i",u,"){"].join(""));for(r.push(["a=",h("sptr"),"\nb=scratch[dptr]\nif(a<b){break __g}\nif(a>b){break __l}"].join("")),u=t.length-1;u>=1;--u)r.push("sptr+=e"+u,"dptr+=f"+u,"}");for(r.push("dptr=cptr;sptr=cptr-s0"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push(["for(i",p,"=0;i",p,"<n",p,";++i",p,"){"].join(""));for(r.push(f("dptr",h("sptr"))),u=0;u<t.length;++u)0!==(p=t[u])&&r.push(["dptr+=d",p,";sptr+=d",p].join(""),"}");for(r.push("cptr-=s0\n}"),r.push("dptr=cptr;sptr=0"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push(["for(i",p,"=0;i",p,"<n",p,";++i",p,"){"].join(""));for(r.push(f("dptr","scratch[sptr++]")),u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push("dptr+=d"+p,"}")}}else r.push("scratch="+h("ptr"),"while((j--\x3eleft)&&("+h("cptr-s0")+">scratch)){",f("cptr",h("cptr-s0")),"cptr-=s0","}",f("cptr","scratch"));return r.push("}"),t.length>1&&s&&r.push("free(scratch)"),r.push("} return "+n),s?new Function("malloc","free",r.join("\n"))(s[0],s[1]):new Function(r.join("\n"))()}(t,e),y=function(t,e,r){var n=["'use strict'"],s=["ndarrayQuickSort",t.join("d"),e].join(""),l=["left","right","data","offset"].concat(o(t.length)),c=i(e),u=0;n.push(["function ",s,"(",l.join(","),"){"].join(""));var h=["sixth=((right-left+1)/6)|0","index1=left+sixth","index5=right-sixth","index3=(left+right)>>1","index2=index3-sixth","index4=index3+sixth","el1=index1","el2=index2","el3=index3","el4=index4","el5=index5","less=left+1","great=right-1","pivots_are_equal=true","tmp","tmp0","x","y","z","k","ptr0","ptr1","ptr2","comp_pivot1=0","comp_pivot2=0","comp=0"];if(t.length>1){for(var f=[],p=1;p<t.length;++p)f.push("n"+p),h.push("i"+p);for(p=0;p<8;++p)h.push("b_ptr"+p);h.push("ptr3","ptr4","ptr5","ptr6","ptr7","pivot_ptr","ptr_shift","elementSize="+f.join("*")),c?h.push("pivot1=malloc(elementSize)","pivot2=malloc(elementSize)"):h.push("pivot1=new Array(elementSize),pivot2=new Array(elementSize)")}else h.push("pivot1","pivot2");function d(t){return["(offset+",t,"*s0)"].join("")}function g(t){return"generic"===e?["data.get(",t,")"].join(""):["data[",t,"]"].join("")}function v(t,r){return"generic"===e?["data.set(",t,",",r,")"].join(""):["data[",t,"]=",r].join("")}function m(e,r,a){if(1===e.length)n.push("ptr0="+d(e[0]));else for(var i=0;i<e.length;++i)n.push(["b_ptr",i,"=s0*",e[i]].join(""));for(r&&n.push("pivot_ptr=0"),n.push("ptr_shift=offset"),i=t.length-1;i>=0;--i)0!==(o=t[i])&&n.push(["for(i",o,"=0;i",o,"<n",o,";++i",o,"){"].join(""));if(e.length>1)for(i=0;i<e.length;++i)n.push(["ptr",i,"=b_ptr",i,"+ptr_shift"].join(""));for(n.push(a),r&&n.push("++pivot_ptr"),i=0;i<t.length;++i){var o;0!==(o=t[i])&&(e.length>1?n.push("ptr_shift+=d"+o):n.push("ptr0+=d"+o),n.push("}"))}}function y(e,r,a,i){if(1===r.length)n.push("ptr0="+d(r[0]));else{for(var o=0;o<r.length;++o)n.push(["b_ptr",o,"=s0*",r[o]].join(""));n.push("ptr_shift=offset")}for(a&&n.push("pivot_ptr=0"),e&&n.push(e+":"),o=1;o<t.length;++o)n.push(["for(i",o,"=0;i",o,"<n",o,";++i",o,"){"].join(""));if(r.length>1)for(o=0;o<r.length;++o)n.push(["ptr",o,"=b_ptr",o,"+ptr_shift"].join(""));for(n.push(i),o=t.length-1;o>=1;--o)a&&n.push("pivot_ptr+=f"+o),r.length>1?n.push("ptr_shift+=e"+o):n.push("ptr0+=e"+o),n.push("}")}function x(){t.length>1&&c&&n.push("free(pivot1)","free(pivot2)")}function b(e,r){var a="el"+e,i="el"+r;if(t.length>1){var o="__l"+ ++u;y(o,[a,i],!1,["comp=",g("ptr0"),"-",g("ptr1"),"\n","if(comp>0){tmp0=",a,";",a,"=",i,";",i,"=tmp0;break ",o,"}\n","if(comp<0){break ",o,"}"].join(""))}else n.push(["if(",g(d(a)),">",g(d(i)),"){tmp0=",a,";",a,"=",i,";",i,"=tmp0}"].join(""))}function _(e,r){t.length>1?m([e,r],!1,v("ptr0",g("ptr1"))):n.push(v(d(e),g(d(r))))}function w(e,r,a){if(t.length>1){var i="__l"+ ++u;y(i,[r],!0,[e,"=",g("ptr0"),"-pivot",a,"[pivot_ptr]\n","if(",e,"!==0){break ",i,"}"].join(""))}else n.push([e,"=",g(d(r)),"-pivot",a].join(""))}function k(e,r){t.length>1?m([e,r],!1,["tmp=",g("ptr0"),"\n",v("ptr0",g("ptr1")),"\n",v("ptr1","tmp")].join("")):n.push(["ptr0=",d(e),"\n","ptr1=",d(r),"\n","tmp=",g("ptr0"),"\n",v("ptr0",g("ptr1")),"\n",v("ptr1","tmp")].join(""))}function T(e,r,a){t.length>1?(m([e,r,a],!1,["tmp=",g("ptr0"),"\n",v("ptr0",g("ptr1")),"\n",v("ptr1",g("ptr2")),"\n",v("ptr2","tmp")].join("")),n.push("++"+r,"--"+a)):n.push(["ptr0=",d(e),"\n","ptr1=",d(r),"\n","ptr2=",d(a),"\n","++",r,"\n","--",a,"\n","tmp=",g("ptr0"),"\n",v("ptr0",g("ptr1")),"\n",v("ptr1",g("ptr2")),"\n",v("ptr2","tmp")].join(""))}function M(t,e){k(t,e),n.push("--"+e)}function A(e,r,a){t.length>1?m([e,r],!0,[v("ptr0",g("ptr1")),"\n",v("ptr1",["pivot",a,"[pivot_ptr]"].join(""))].join("")):n.push(v(d(e),g(d(r))),v(d(r),"pivot"+a))}function S(e,r){n.push(["if((",r,"-",e,")<=",a,"){\n","insertionSort(",e,",",r,",data,offset,",o(t.length).join(","),")\n","}else{\n",s,"(",e,",",r,",data,offset,",o(t.length).join(","),")\n","}"].join(""))}function E(e,r,a){t.length>1?(n.push(["__l",++u,":while(true){"].join("")),m([e],!0,["if(",g("ptr0"),"!==pivot",r,"[pivot_ptr]){break __l",u,"}"].join("")),n.push(a,"}")):n.push(["while(",g(d(e)),"===pivot",r,"){",a,"}"].join(""))}return n.push("var "+h.join(",")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?m(["el1","el2","el3","el4","el5","index1","index3","index5"],!0,["pivot1[pivot_ptr]=",g("ptr1"),"\n","pivot2[pivot_ptr]=",g("ptr3"),"\n","pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\n","x=",g("ptr0"),"\n","y=",g("ptr2"),"\n","z=",g("ptr4"),"\n",v("ptr5","x"),"\n",v("ptr6","y"),"\n",v("ptr7","z")].join("")):n.push(["pivot1=",g(d("el2")),"\n","pivot2=",g(d("el4")),"\n","pivots_are_equal=pivot1===pivot2\n","x=",g(d("el1")),"\n","y=",g(d("el3")),"\n","z=",g(d("el5")),"\n",v(d("index1"),"x"),"\n",v(d("index3"),"y"),"\n",v(d("index5"),"z")].join("")),_("index2","left"),_("index4","right"),n.push("if(pivots_are_equal){"),n.push("for(k=less;k<=great;++k){"),w("comp","k",1),n.push("if(comp===0){continue}"),n.push("if(comp<0){"),n.push("if(k!==less){"),k("k","less"),n.push("}"),n.push("++less"),n.push("}else{"),n.push("while(true){"),w("comp","great",1),n.push("if(comp>0){"),n.push("great--"),n.push("}else if(comp<0){"),T("k","less","great"),n.push("break"),n.push("}else{"),M("k","great"),n.push("break"),n.push("}"),n.push("}"),n.push("}"),n.push("}"),n.push("}else{"),n.push("for(k=less;k<=great;++k){"),w("comp_pivot1","k",1),n.push("if(comp_pivot1<0){"),n.push("if(k!==less){"),k("k","less"),n.push("}"),n.push("++less"),n.push("}else{"),w("comp_pivot2","k",2),n.push("if(comp_pivot2>0){"),n.push("while(true){"),w("comp","great",2),n.push("if(comp>0){"),n.push("if(--great<k){break}"),n.push("continue"),n.push("}else{"),w("comp","great",1),n.push("if(comp<0){"),T("k","less","great"),n.push("}else{"),M("k","great"),n.push("}"),n.push("break"),n.push("}"),n.push("}"),n.push("}"),n.push("}"),n.push("}"),n.push("}"),A("left","(less-1)",1),A("right","(great+1)",2),S("left","(less-2)"),S("(great+2)","right"),n.push("if(pivots_are_equal){"),x(),n.push("return"),n.push("}"),n.push("if(less<index1&&great>index5){"),E("less",1,"++less"),E("great",2,"--great"),n.push("for(k=less;k<=great;++k){"),w("comp_pivot1","k",1),n.push("if(comp_pivot1===0){"),n.push("if(k!==less){"),k("k","less"),n.push("}"),n.push("++less"),n.push("}else{"),w("comp_pivot2","k",2),n.push("if(comp_pivot2===0){"),n.push("while(true){"),w("comp","great",2),n.push("if(comp===0){"),n.push("if(--great<k){break}"),n.push("continue"),n.push("}else{"),w("comp","great",1),n.push("if(comp<0){"),T("k","less","great"),n.push("}else{"),M("k","great"),n.push("}"),n.push("break"),n.push("}"),n.push("}"),n.push("}"),n.push("}"),n.push("}"),n.push("}"),x(),S("less","great"),n.push("}return "+s),t.length>1&&c?new Function("insertionSort","malloc","free",n.join("\n"))(r,c[0],c[1]):new Function("insertionSort",n.join("\n"))(r)}(t,e,m);return v(m,y)}},{"typedarray-pool":543}],449:[function(t,e,r){"use strict";var n=t("./lib/compile_sort.js"),a={};e.exports=function(t){var e=t.order,r=t.dtype,i=[e,r].join(":"),o=a[i];return o||(a[i]=o=n(e,r)),o(t),t}},{"./lib/compile_sort.js":448}],450:[function(t,e,r){"use strict";var n=t("ndarray-linear-interpolate"),a=t("cwise/lib/wrapper")({args:["index","array","scalar","scalar","scalar"],pre:{body:"{this_warped=new Array(_inline_3_arg4_)}",args:[{name:"_inline_3_arg0_",lvalue:!1,rvalue:!1,count:0},{name:"_inline_3_arg1_",lvalue:!1,rvalue:!1,count:0},{name:"_inline_3_arg2_",lvalue:!1,rvalue:!1,count:0},{name:"_inline_3_arg3_",lvalue:!1,rvalue:!1,count:0},{name:"_inline_3_arg4_",lvalue:!1,rvalue:!0,count:1}],thisVars:["this_warped"],localVars:[]},body:{body:"{_inline_4_arg2_(this_warped,_inline_4_arg0_),_inline_4_arg1_=_inline_4_arg3_.apply(void 0,this_warped)}",args:[{name:"_inline_4_arg0_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_4_arg1_",lvalue:!0,rvalue:!1,count:1},{name:"_inline_4_arg2_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_4_arg3_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_4_arg4_",lvalue:!1,rvalue:!1,count:0}],thisVars:["this_warped"],localVars:[]},post:{body:"{}",args:[],thisVars:[],localVars:[]},debug:!1,funcName:"warpND",blockSize:64}),i=t("cwise/lib/wrapper")({args:["index","array","scalar","scalar","scalar"],pre:{body:"{this_warped=[0]}",args:[],thisVars:["this_warped"],localVars:[]},body:{body:"{_inline_7_arg2_(this_warped,_inline_7_arg0_),_inline_7_arg1_=_inline_7_arg3_(_inline_7_arg4_,this_warped[0])}",args:[{name:"_inline_7_arg0_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_7_arg1_",lvalue:!0,rvalue:!1,count:1},{name:"_inline_7_arg2_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_7_arg3_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_7_arg4_",lvalue:!1,rvalue:!0,count:1}],thisVars:["this_warped"],localVars:[]},post:{body:"{}",args:[],thisVars:[],localVars:[]},debug:!1,funcName:"warp1D",blockSize:64}),o=t("cwise/lib/wrapper")({args:["index","array","scalar","scalar","scalar"],pre:{body:"{this_warped=[0,0]}",args:[],thisVars:["this_warped"],localVars:[]},body:{body:"{_inline_10_arg2_(this_warped,_inline_10_arg0_),_inline_10_arg1_=_inline_10_arg3_(_inline_10_arg4_,this_warped[0],this_warped[1])}",args:[{name:"_inline_10_arg0_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_10_arg1_",lvalue:!0,rvalue:!1,count:1},{name:"_inline_10_arg2_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_10_arg3_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_10_arg4_",lvalue:!1,rvalue:!0,count:1}],thisVars:["this_warped"],localVars:[]},post:{body:"{}",args:[],thisVars:[],localVars:[]},debug:!1,funcName:"warp2D",blockSize:64}),s=t("cwise/lib/wrapper")({args:["index","array","scalar","scalar","scalar"],pre:{body:"{this_warped=[0,0,0]}",args:[],thisVars:["this_warped"],localVars:[]},body:{body:"{_inline_13_arg2_(this_warped,_inline_13_arg0_),_inline_13_arg1_=_inline_13_arg3_(_inline_13_arg4_,this_warped[0],this_warped[1],this_warped[2])}",args:[{name:"_inline_13_arg0_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_13_arg1_",lvalue:!0,rvalue:!1,count:1},{name:"_inline_13_arg2_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_13_arg3_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_13_arg4_",lvalue:!1,rvalue:!0,count:1}],thisVars:["this_warped"],localVars:[]},post:{body:"{}",args:[],thisVars:[],localVars:[]},debug:!1,funcName:"warp3D",blockSize:64});e.exports=function(t,e,r){switch(e.shape.length){case 1:i(t,r,n.d1,e);break;case 2:o(t,r,n.d2,e);break;case 3:s(t,r,n.d3,e);break;default:a(t,r,n.bind(void 0,e),e.shape.length)}return t}},{"cwise/lib/wrapper":151,"ndarray-linear-interpolate":444}],451:[function(t,e,r){var n=t("iota-array"),a=t("is-buffer"),i="undefined"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=["View",e,"d",t].join("");e<0&&(r="View_Nil"+t);var a="generic"===t;if(-1===e){var i="function "+r+"(a){this.data=a;};var proto="+r+".prototype;proto.dtype='"+t+"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new "+r+"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_"+r+"(a){return new "+r+"(a);}";return new Function(i)()}if(0===e){i="function "+r+"(a,d) {this.data = a;this.offset = d};var proto="+r+".prototype;proto.dtype='"+t+"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function "+r+"_copy() {return new "+r+"(this.data,this.offset)};proto.pick=function "+r+"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function "+r+"_get(){return "+(a?"this.data.get(this.offset)":"this.data[this.offset]")+"};proto.set=function "+r+"_set(v){return "+(a?"this.data.set(this.offset,v)":"this.data[this.offset]=v")+"};return function construct_"+r+"(a,b,c,d){return new "+r+"(a,d)}";return new Function("TrivialArray",i)(c[t][0])}i=["'use strict'"];var o=n(e),l=o.map(function(t){return"i"+t}),u="this.offset+"+o.map(function(t){return"this.stride["+t+"]*i"+t}).join("+"),h=o.map(function(t){return"b"+t}).join(","),f=o.map(function(t){return"c"+t}).join(",");i.push("function "+r+"(a,"+h+","+f+",d){this.data=a","this.shape=["+h+"]","this.stride=["+f+"]","this.offset=d|0}","var proto="+r+".prototype","proto.dtype='"+t+"'","proto.dimension="+e),i.push("Object.defineProperty(proto,'size',{get:function "+r+"_size(){return "+o.map(function(t){return"this.shape["+t+"]"}).join("*"),"}})"),1===e?i.push("proto.order=[0]"):(i.push("Object.defineProperty(proto,'order',{get:"),e<4?(i.push("function "+r+"_order(){"),2===e?i.push("return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})"):3===e&&i.push("var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})")):i.push("ORDER})")),i.push("proto.set=function "+r+"_set("+l.join(",")+",v){"),a?i.push("return this.data.set("+u+",v)}"):i.push("return this.data["+u+"]=v}"),i.push("proto.get=function "+r+"_get("+l.join(",")+"){"),a?i.push("return this.data.get("+u+")}"):i.push("return this.data["+u+"]}"),i.push("proto.index=function "+r+"_index(",l.join(),"){return "+u+"}"),i.push("proto.hi=function "+r+"_hi("+l.join(",")+"){return new "+r+"(this.data,"+o.map(function(t){return["(typeof i",t,"!=='number'||i",t,"<0)?this.shape[",t,"]:i",t,"|0"].join("")}).join(",")+","+o.map(function(t){return"this.stride["+t+"]"}).join(",")+",this.offset)}");var p=o.map(function(t){return"a"+t+"=this.shape["+t+"]"}),d=o.map(function(t){return"c"+t+"=this.stride["+t+"]"});i.push("proto.lo=function "+r+"_lo("+l.join(",")+"){var b=this.offset,d=0,"+p.join(",")+","+d.join(","));for(var g=0;g<e;++g)i.push("if(typeof i"+g+"==='number'&&i"+g+">=0){d=i"+g+"|0;b+=c"+g+"*d;a"+g+"-=d}");i.push("return new "+r+"(this.data,"+o.map(function(t){return"a"+t}).join(",")+","+o.map(function(t){return"c"+t}).join(",")+",b)}"),i.push("proto.step=function "+r+"_step("+l.join(",")+"){var "+o.map(function(t){return"a"+t+"=this.shape["+t+"]"}).join(",")+","+o.map(function(t){return"b"+t+"=this.stride["+t+"]"}).join(",")+",c=this.offset,d=0,ceil=Math.ceil");for(g=0;g<e;++g)i.push("if(typeof i"+g+"==='number'){d=i"+g+"|0;if(d<0){c+=b"+g+"*(a"+g+"-1);a"+g+"=ceil(-a"+g+"/d)}else{a"+g+"=ceil(a"+g+"/d)}b"+g+"*=d}");i.push("return new "+r+"(this.data,"+o.map(function(t){return"a"+t}).join(",")+","+o.map(function(t){return"b"+t}).join(",")+",c)}");var v=new Array(e),m=new Array(e);for(g=0;g<e;++g)v[g]="a[i"+g+"]",m[g]="b[i"+g+"]";i.push("proto.transpose=function "+r+"_transpose("+l+"){"+l.map(function(t,e){return t+"=("+t+"===undefined?"+e+":"+t+"|0)"}).join(";"),"var a=this.shape,b=this.stride;return new "+r+"(this.data,"+v.join(",")+","+m.join(",")+",this.offset)}"),i.push("proto.pick=function "+r+"_pick("+l+"){var a=[],b=[],c=this.offset");for(g=0;g<e;++g)i.push("if(typeof i"+g+"==='number'&&i"+g+">=0){c=(c+this.stride["+g+"]*i"+g+")|0}else{a.push(this.shape["+g+"]);b.push(this.stride["+g+"])}");return i.push("var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}"),i.push("return function construct_"+r+"(data,shape,stride,offset){return new "+r+"(data,"+o.map(function(t){return"shape["+t+"]"}).join(",")+","+o.map(function(t){return"stride["+t+"]"}).join(",")+",offset)}"),new Function("CTOR_LIST","ORDER",i.join("\n"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);"number"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n)for(n=0,s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s]);for(var h=function(t){if(a(t))return"buffer";if(i)switch(Object.prototype.toString.call(t)){case"[object Float64Array]":return"float64";case"[object Float32Array]":return"float32";case"[object Int8Array]":return"int8";case"[object Int16Array]":return"int16";case"[object Int32Array]":return"int32";case"[object Uint8Array]":return"uint8";case"[object Uint16Array]":return"uint16";case"[object Uint32Array]":return"uint32";case"[object Uint8ClampedArray]":return"uint8_clamped"}return Array.isArray(t)?"array":"generic"}(t),f=c[h];f.length<=o+1;)f.push(l(h,f.length-1));return(0,f[o+1])(t,e,r,n)}},{"iota-array":417,"is-buffer":419}],452:[function(t,e,r){"use strict";var n=t("double-bits"),a=Math.pow(2,-1074),i=-1>>>0;e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-a:a;var r=n.hi(t),o=n.lo(t);e>t==t>0?o===i?(r+=1,o=0):o+=1:0===o?(o=i,r-=1):o-=1;return n.pack(o,r)}},{"double-bits":169}],453:[function(t,e,r){var n=Math.PI,a=c(120);function i(t,e,r,n){return["C",t,e,r,n,r,n]}function o(t,e,r,n,a,i){return["C",t/3+2/3*r,e/3+2/3*n,a/3+2/3*r,i/3+2/3*n,a,i]}function s(t,e,r,i,o,c,u,h,f,p){if(p)k=p[0],T=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var g=(t-(h=(d=l(h,f,-o)).x))/2,v=(e-(f=d.y))/2,m=g*g/(r*r)+v*v/(i*i);m>1&&(r*=m=Math.sqrt(m),i*=m);var y=r*r,x=i*i,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*v*v-x*g*g)/(y*v*v+x*g*g)));b==1/0&&(b=1);var _=b*r*v/i+(t+h)/2,w=b*-i*g/r+(e+f)/2,k=Math.asin(((e-w)/i).toFixed(9)),T=Math.asin(((f-w)/i).toFixed(9));(k=t<_?n-k:k)<0&&(k=2*n+k),(T=h<_?n-T:T)<0&&(T=2*n+T),u&&k>T&&(k-=2*n),!u&&T>k&&(T-=2*n)}if(Math.abs(T-k)>a){var M=T,A=h,S=f;T=k+a*(u&&T>k?1:-1);var E=s(h=_+r*Math.cos(T),f=w+i*Math.sin(T),r,i,o,0,u,A,S,[T,M,_,w])}var L=Math.tan((T-k)/4),C=4/3*r*L,P=4/3*i*L,O=[2*t-(t+C*Math.sin(k)),2*e-(e-P*Math.cos(k)),h+C*Math.sin(T),f-P*Math.cos(T),h,f];if(p)return O;E&&(O=O.concat(E));for(var z=0;z<O.length;){var I=l(O[z],O[z+1],o);O[z++]=I.x,O[z++]=I.y}return O}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,a=0,l=0,u=0,h=null,f=null,p=0,d=0,g=0,v=t.length;g<v;g++){var m=t[g],y=m[0];switch(y){case"M":l=m[1],u=m[2];break;case"A":(m=s(p,d,m[1],m[2],c(m[3]),m[4],m[5],m[6],m[7])).unshift("C"),m.length>7&&(r.push(m.splice(0,7)),m.unshift("C"));break;case"S":var x=p,b=d;"C"!=e&&"S"!=e||(x+=x-n,b+=b-a),m=["C",x,b,m[1],m[2],m[3],m[4]];break;case"T":"Q"==e||"T"==e?(h=2*p-h,f=2*d-f):(h=p,f=d),m=o(p,d,h,f,m[1],m[2]);break;case"Q":h=m[1],f=m[2],m=o(p,d,m[1],m[2],m[3],m[4]);break;case"L":m=i(p,d,m[1],m[2]);break;case"H":m=i(p,d,m[1],d);break;case"V":m=i(p,d,p,m[1]);break;case"Z":m=i(p,d,l,u)}e=y,p=m[m.length-2],d=m[m.length-1],m.length>4?(n=m[m.length-4],a=m[m.length-3]):(n=p,a=d),r.push(m)}return r}},{}],454:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,a=new Array(n),i=void 0===r?1e-6:r,o=0;o<n;++o)a[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],h=0;h<s.length;++h){l=c,c=u,u=s[(h+1)%s.length];for(var f=e[l],p=e[c],d=e[u],g=new Array(3),v=0,m=new Array(3),y=0,x=0;x<3;++x)g[x]=f[x]-p[x],v+=g[x]*g[x],m[x]=d[x]-p[x],y+=m[x]*m[x];if(v*y>i){var b=a[c],_=1/Math.sqrt(v*y);for(x=0;x<3;++x){var w=(x+1)%3,k=(x+2)%3;b[x]+=_*(m[w]*g[k]-m[k]*g[w])}}}for(o=0;o<n;++o){b=a[o];var T=0;for(x=0;x<3;++x)T+=b[x]*b[x];if(T>i)for(_=1/Math.sqrt(T),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return a},r.faceNormals=function(t,e,r){for(var n=t.length,a=new Array(n),i=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),h=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],h[c]=l[2][c]-l[0][c];var f=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,g=(c+2)%3;f[c]=u[d]*h[g]-u[g]*h[d],p+=f[c]*f[c]}p=p>i?1/Math.sqrt(p):0;for(c=0;c<3;++c)f[c]*=p;a[o]=f}return a}},{}],455:[function(t,e,r){"use strict";var n=Object.getOwnPropertySymbols,a=Object.prototype.hasOwnProperty,i=Object.prototype.propertyIsEnumerable;e.exports=function(){try{if(!Object.assign)return!1;var t=new String("abc");if(t[5]="de","5"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e["_"+String.fromCharCode(r)]=r;if("0123456789"!==Object.getOwnPropertyNames(e).map(function(t){return e[t]}).join(""))return!1;var n={};return"abcdefghijklmnopqrst".split("").forEach(function(t){n[t]=t}),"abcdefghijklmnopqrst"===Object.keys(Object.assign({},n)).join("")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,o,s=function(t){if(null==t)throw new TypeError("Object.assign cannot be called with null or undefined");return Object(t)}(t),l=1;l<arguments.length;l++){for(var c in r=Object(arguments[l]))a.call(r,c)&&(s[c]=r[c]);if(n){o=n(r);for(var u=0;u<o.length;u++)i.call(r,o[u])&&(s[o[u]]=r[o[u]])}}return s}},{}],456:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a,i,o,s,l,c){var u=e+i+c;if(h>0){var h=Math.sqrt(u+1);t[0]=.5*(o-l)/h,t[1]=.5*(s-n)/h,t[2]=.5*(r-i)/h,t[3]=.5*h}else{var f=Math.max(e,i,c),h=Math.sqrt(2*f-u+1);e>=f?(t[0]=.5*h,t[1]=.5*(a+r)/h,t[2]=.5*(s+n)/h,t[3]=.5*(o-l)/h):i>=f?(t[0]=.5*(r+a)/h,t[1]=.5*h,t[2]=.5*(l+o)/h,t[3]=.5*(s-n)/h):(t[0]=.5*(n+s)/h,t[1]=.5*(o+l)/h,t[2]=.5*h,t[3]=.5*(r-a)/h)}return t}},{}],457:[function(t,e,r){"use strict";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var a=new h(r,e,Math.log(n));a.setDistanceLimits(t.zoomMin,t.zoomMax),("eye"in t||"up"in t)&&a.lookAt(0,t.eye,t.center,t.up);return a};var n=t("filtered-vector"),a=t("gl-mat4/lookAt"),i=t("gl-mat4/fromQuat"),o=t("gl-mat4/invert"),s=t("./lib/quatFromFrame");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=c(r,n,a,i);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=a/o,t[3]=i/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function h(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var f=h.prototype;f.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},f.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;i(r,e);var n=this.computedCenter,a=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);a[0]=n[0]+s*r[2],a[1]=n[1]+s*r[6],a[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,h=0;h<3;++h)c+=r[l+4*h]*a[h];r[12+l]=-c}},f.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},f.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},f.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},f.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var a=this.computedMatrix,i=a[1],o=a[5],s=a[9],c=l(i,o,s);i/=c,o/=c,s/=c;var u=a[0],h=a[4],f=a[8],p=u*i+h*o+f*s,d=l(u-=i*p,h-=o*p,f-=s*p);u/=d,h/=d,f/=d;var g=a[2],v=a[6],m=a[10],y=g*i+v*o+m*s,x=g*u+v*h+m*f,b=l(g-=y*i+x*u,v-=y*o+x*h,m-=y*s+x*f);g/=b,v/=b,m/=b;var _=u*e+i*r,w=h*e+o*r,k=f*e+s*r;this.center.move(t,_,w,k);var T=Math.exp(this.computedRadius[0]);T=Math.max(1e-4,T+n),this.radius.set(t,Math.log(T))},f.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var a=this.computedMatrix,i=a[0],o=a[4],s=a[8],u=a[1],h=a[5],f=a[9],p=a[2],d=a[6],g=a[10],v=e*i+r*u,m=e*o+r*h,y=e*s+r*f,x=-(d*y-g*m),b=-(g*v-p*y),_=-(p*m-d*v),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),k=c(x,b,_,w);k>1e-6?(x/=k,b/=k,_/=k,w/=k):(x=b=_=0,w=1);var T=this.computedRotation,M=T[0],A=T[1],S=T[2],E=T[3],L=M*w+E*x+A*_-S*b,C=A*w+E*b+S*x-M*_,P=S*w+E*_+M*b-A*x,O=E*w-M*x-A*b-S*_;if(n){x=p,b=d,_=g;var z=Math.sin(n)/l(x,b,_);x*=z,b*=z,_*=z,O=O*(w=Math.cos(e))-(L=L*w+O*x+C*_-P*b)*x-(C=C*w+O*b+P*x-L*_)*b-(P=P*w+O*_+L*b-C*x)*_}var I=c(L,C,P,O);I>1e-6?(L/=I,C/=I,P/=I,O/=I):(L=C=P=0,O=1),this.rotation.set(t,L,C,P,O)},f.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var i=this.computedMatrix;a(i,e,r,n);var o=this.computedRotation;s(o,i[0],i[1],i[2],i[4],i[5],i[6],i[8],i[9],i[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},f.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},f.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var a=n[15];if(Math.abs(a)>1e-6){var i=n[12]/a,l=n[13]/a,c=n[14]/a;this.recalcMatrix(t);var h=Math.exp(this.computedRadius[0]);this.center.set(t,i-n[2]*h,l-n[6]*h,c-n[10]*h),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},f.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},f.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},f.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},f.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},f.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var a=t.distance;a&&a>0&&this.radius.set(e,Math.log(a)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{"./lib/quatFromFrame":456,"filtered-vector":229,"gl-mat4/fromQuat":265,"gl-mat4/invert":268,"gl-mat4/lookAt":269}],458:[function(t,e,r){"use strict";var n=t("repeat-string");e.exports=function(t,e,r){return n(r="undefined"!=typeof r?r+"":" ",e)+t}},{"repeat-string":501}],459:[function(t,e,r){"use strict";function n(t,e){if("string"!=typeof t)return[t];var r=[t];"string"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:["{}","[]","()"],a=e.escape||"___",i=!!e.flat;n.forEach(function(t){var e=new RegExp(["\\",t[0],"[^\\",t[0],"\\",t[1],"]*\\",t[1]].join("")),n=[];function i(e,i,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),a+s+a}r.forEach(function(t,n){for(var a,o=0;t!=a;)if(a=t,t=t.replace(e,i),o++>1e4)throw Error("References have circular dependency. Please, check them.");r[n]=t}),n=n.reverse(),r=r.map(function(e){return n.forEach(function(r){e=e.replace(new RegExp("(\\"+a+r+"\\"+a+")","g"),t[0]+"$1"+t[1])}),e})});var o=new RegExp("\\"+a+"([0-9]+)\\"+a);return i?r:function t(e,r,n){for(var a,i=[],s=0;a=o.exec(e);){if(s++>1e4)throw Error("Circular references in parenthesis");i.push(e.slice(0,a.index)),i.push(t(r[a[1]],r)),e=e.slice(a.index+a[0].length)}return i.push(e),i}(r[0],r)}function a(t,e){if(e&&e.flat){var r,n=e&&e.escape||"___",a=t[0];if(!a)return"";for(var i=new RegExp("\\"+n+"([0-9]+)\\"+n),o=0;a!=r;){if(o++>1e4)throw Error("Circular references in "+t);r=a,a=a.replace(i,s)}return a}return t.reduce(function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,"")),e+r},"");function s(e,r){if(null==t[r])throw Error("Reference "+r+"is undefined");return t[r]}}function i(t,e){return Array.isArray(t)?a(t,e):n(t,e)}i.parse=n,i.stringify=a,e.exports=i},{}],460:[function(t,e,r){"use strict";var n=t("pick-by-alias");e.exports=function(t){var e;arguments.length>1&&(t=arguments);"string"==typeof t?t=t.split(/\s/).map(parseFloat):"number"==typeof t&&(t=[t]);t.length&&"number"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:"x l left Left",top:"y t top Top",width:"w width W Width",height:"h height W Width",bottom:"b bottom Bottom",right:"r right Right"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{"pick-by-alias":466}],461:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(a,function(t,r,a){var o=r.toLowerCase();for(a=function(t){var e=t.match(i);return e?e.map(Number):[]}(a),"m"==o&&a.length>2&&(e.push([r].concat(a.splice(0,2))),o="l",r="m"==r?"l":"L");;){if(a.length==n[o])return a.unshift(r),e.push(a);if(a.length<n[o])throw new Error("malformed path data");e.push([r].concat(a.splice(0,n[o])))}}),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},a=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var i=/-?[0-9]*\.?[0-9]+(?:e[-+]?\d+)?/gi},{}],462:[function(t,e,r){e.exports=function(t,e){e||(e=[0,""]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\d.\-\+]*\s*(.*)/)[1]||"",e}},{}],463:[function(t,e,r){(function(t){(function(){var r,n,a,i,o,s;"undefined"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:"undefined"!=typeof t&&null!==t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,i=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=i-s):Date.now?(e.exports=function(){return Date.now()-a},a=Date.now()):(e.exports=function(){return(new Date).getTime()-a},a=(new Date).getTime())}).call(this)}).call(this,t("_process"))},{_process:483}],464:[function(t,e,r){"use strict";e.exports=function(t){var e=t.length;if(e<n){for(var r=1,i=0;i<e;++i)for(var o=0;o<i;++o)if(t[i]<t[o])r=-r;else if(t[i]===t[o])return 0;return r}for(var s=a.mallocUint8(e),i=0;i<e;++i)s[i]=0;for(var r=1,i=0;i<e;++i)if(!s[i]){var l=1;s[i]=1;for(var o=t[i];o!==i;o=t[o]){if(s[o])return a.freeUint8(s),0;l+=1,s[o]=1}1&l||(r=-r)}return a.freeUint8(s),r};var n=32,a=t("typedarray-pool")},{"typedarray-pool":543}],465:[function(t,e,r){"use strict";var n=t("typedarray-pool"),a=t("invert-permutation");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,i,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(a(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)i=l[o],r=s[o],s[o]=s[i],s[i]=r,l[o]=l[r],l[r]=i,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,a,i,o=1;for((r=r||new Array(t))[0]=0,i=1;i<t;++i)r[i]=i,o=o*i|0;for(i=t-1;i>0;--i)e=e-(n=e/o|0)*o|0,o=o/i|0,a=0|r[i],r[i]=0|r[n],r[n]=0|a;return r}},{"invert-permutation":416,"typedarray-pool":543}],466:[function(t,e,r){"use strict";e.exports=function(t,e,r){var n,i,o={};if("string"==typeof e&&(e=a(e)),Array.isArray(e)){var s={};for(i=0;i<e.length;i++)s[e[i]]=!0;e=s}for(n in e)e[n]=a(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(i=0;i<c.length;i++){var u=c[i];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var h=i;h<c.length;h++)l[c[h]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function a(t){return n[t]?n[t]:("string"==typeof t&&(t=n[t]=t.split(/\s*,\s*|\s+/)),t)}},{}],467:[function(t,e,r){"use strict";e.exports=function(t,e){for(var r=0|e.length,a=t.length,i=[new Array(r),new Array(r)],o=0;o<r;++o)i[0][o]=[],i[1][o]=[];for(var o=0;o<a;++o){var s=t[o];i[0][s[0]].push(s),i[1][s[1]].push(s)}for(var l=[],o=0;o<r;++o)i[0][o].length+i[1][o].length===0&&l.push([o]);function c(t,e){var r=i[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,a){for(var o,s,l,u=0;u<2;++u)if(i[u][r].length>0){o=i[u][r][0],l=u;break}s=o[1^l];for(var h=0;h<2;++h)for(var f=i[h][r],p=0;p<f.length;++p){var d=f[p],g=d[1^h],v=n(e[t],e[r],e[s],e[g]);v>0&&(o=d,s=g,l=h)}return a?s:(o&&c(o,l),s)}function h(t,r){var a=i[r][t][0],o=[t];c(a,r);for(var s=a[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(i[0][t].length+i[1][t].length===0)break;var l=o[o.length-1],h=t,f=o[1],p=u(l,h,!0);if(n(e[l],e[h],e[f],e[p])<0)break;o.push(t),s=u(l,h)}return o}function f(t,e){return e[1]===e[e.length-1]}for(var o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];i[p][o].length>0;){i[0][o].length;var g=h(o,p);f(d,g)?d.push.apply(d,g):(d.length>0&&l.push(d),d=g)}d.length>0&&l.push(d)}return l};var n=t("compare-angle")},{"compare-angle":129}],468:[function(t,e,r){"use strict";e.exports=function(t,e){for(var r=n(t,e.length),a=new Array(e.length),i=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;i[s]=l,a[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();a[c]=!1;for(var u=r[c],s=0;s<u.length;++s){var h=u[s];0==--i[h]&&o.push(h)}}for(var f=new Array(e.length),p=[],s=0;s<e.length;++s)if(a[s]){var c=p.length;f[s]=c,p.push(e[s])}else f[s]=-1;for(var d=[],s=0;s<t.length;++s){var g=t[s];a[g[0]]&&a[g[1]]&&d.push([f[g[0]],f[g[1]]])}return[d,p]};var n=t("edges-to-adjacency-list")},{"edges-to-adjacency-list":174}],469:[function(t,e,r){"use strict";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var h=(e=r[1]).length,f=(t.length,n(t,e.length)),p=0;p<h;++p)if(f[p].length%2==1)throw new Error("planar-graph-to-polyline: graph must be manifold");var d=a(t,e);for(var g=(d=d.filter(function(t){for(var r=t.length,n=[0],a=0;a<r;++a){var i=e[t[a]],l=e[t[(a+1)%r]],c=o(-i[0],i[1]),u=o(-i[0],l[1]),h=o(l[0],i[1]),f=o(l[0],l[1]);n=s(n,s(s(c,u),s(h,f)))}return n[n.length-1]>0})).length,v=new Array(g),m=new Array(g),p=0;p<g;++p){v[p]=p;var y=new Array(g),x=d[p].map(function(t){return e[t]}),b=i([x]),_=0;t:for(var w=0;w<g;++w)if(y[w]=0,p!==w){for(var k=d[w],T=k.length,M=0;M<T;++M){var A=b(e[k[M]]);if(0!==A){A<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}m[p]=[_,p,y]}m.sort(function(t,e){return e[0]-t[0]});for(var p=0;p<g;++p)for(var y=m[p],S=y[1],E=y[2],w=0;w<g;++w)E[w]&&(v[w]=S);for(var L=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(g),p=0;p<g;++p)L[p].push(v[p]),L[v[p]].push(p);for(var C={},P=u(h,!1),p=0;p<g;++p)for(var k=d[p],T=k.length,w=0;w<T;++w){var O=k[w],z=k[(w+1)%T],I=Math.min(O,z)+":"+Math.max(O,z);if(I in C){var D=C[I];L[D].push(p),L[p].push(D),P[O]=P[z]=!0}else C[I]=p}function R(t){for(var e=t.length,r=0;r<e;++r)if(!P[t[r]])return!1;return!0}for(var F=[],B=u(g,-1),p=0;p<g;++p)v[p]!==p||R(d[p])?B[p]=-1:(F.push(p),B[p]=0);var r=[];for(;F.length>0;){var N=F.pop(),j=L[N];l(j,function(t,e){return t-e});var V,U=j.length,q=B[N];if(0===q){var k=d[N];V=[k]}for(var p=0;p<U;++p){var H=j[p];if(!(B[H]>=0)&&(B[H]=1^q,F.push(H),0===q)){var k=d[H];R(k)||(k.reverse(),V.push(k))}}0===q&&r.push(V)}return r};var n=t("edges-to-adjacency-list"),a=t("planar-dual"),i=t("point-in-big-polygon"),o=t("two-product"),s=t("robust-sum"),l=t("uniq"),c=t("./lib/trim-leaves");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{"./lib/trim-leaves":468,"edges-to-adjacency-list":174,"planar-dual":467,"point-in-big-polygon":473,"robust-sum":513,"two-product":541,uniq:545}],470:[function(t,e,r){"use strict";e.exports=t("./quad")},{"./quad":472}],471:[function(t,e,r){arguments[4][113][0].apply(r,arguments)},{dup:113}],472:[function(t,e,r){"use strict";var n=t("binary-search-bounds"),a=t("clamp"),i=t("parse-rect"),o=t("array-bounds"),s=t("pick-by-alias"),l=t("defined"),c=t("flatten-vertex-data"),u=t("is-obj"),h=t("dtype"),f=t("math-log2"),p=1073741824;function d(t,e){for(var r=e[0],n=e[1],i=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=a((t[2*l]-r)*i,0,1),s[2*l+1]=a((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,"float64"),e=s(e,{bounds:"range bounds dataBox databox",maxDepth:"depth maxDepth maxdepth level maxLevel maxlevel levels",dtype:"type dtype format out dst output destination"});var r=l(e.maxDepth,255),a=l(e.bounds,o(t,2));a[0]===a[2]&&a[2]++,a[1]===a[3]&&a[3]++;var g,v=d(t,a),m=t.length>>>1;e.dtype||(e.dtype="array"),"string"==typeof e.dtype?g=new(h(e.dtype))(m):e.dtype&&(g=e.dtype,Array.isArray(g)&&(g.length=m));for(var y=0;y<m;++y)g[y]=y;var x=[],b=[],_=[],w=[];!function t(e,n,a,i,o,s){if(!i.length)return null;var l=x[o]||(x[o]=[]);var c=_[o]||(_[o]=[]);var u=b[o]||(b[o]=[]);var h=l.length;o++;if(o>r||s>p){for(var f=0;f<i.length;f++)l.push(i[f]),c.push(s),u.push(null,null,null,null);return h}l.push(i[0]);c.push(s);if(i.length<=1)return u.push(null,null,null,null),h;var d=.5*a;var g=e+d,m=n+d;var y=[],w=[],k=[],T=[];for(var M=1,A=i.length;M<A;M++){var S=i[M],E=v[2*S],L=v[2*S+1];E<g?L<m?y.push(S):w.push(S):L<m?k.push(S):T.push(S)}s<<=2;u.push(t(e,n,d,y,o,s),t(e,m,d,w,o,s+1),t(g,n,d,k,o,s+2),t(g,m,d,T,o,s+3));return h}(0,0,1,g,0,1);for(var k=0,T=0;T<x.length;T++){var M=x[T];if(g.set)g.set(M,k);else for(var A=0,S=M.length;A<S;A++)g[A+k]=M[A];var E=k+x[T].length;w[T]=[k,E],k=E}return g.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:"level maxLevel",d:"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize",lod:"lod details ranges offsets"})}else e={};r.length||(r=a);var h=i.apply(void 0,r),p=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=p[0],v=p[1],m=p[2],y=p[3],k=d([g,v,m,y],a),T=k[0],M=k[1],A=k[2],S=k[3],E=l(e.level,x.length);if(null!=e.d){var C;"number"==typeof e.d?C=[e.d,e.d]:e.d.length&&(C=e.d),E=Math.min(Math.max(Math.ceil(-f(Math.abs(C[0])/(a[2]-a[0]))),Math.ceil(-f(Math.abs(C[1])/(a[3]-a[1])))),E)}if(E=Math.min(E,x.length),e.lod)return function(t,e,r,a,i){for(var o=[],s=0;s<i;s++){var l=_[s],c=w[s][0],u=L(t,e,s),h=L(r,a,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,M,A,S,E);var P=[];return function e(r,n,a,i,o,s){if(null!==o&&null!==s){var l=r+a,c=n+a;if(!(T>l||M>c||A<r||S<n||i>=E||o===s)){var u=x[i];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=y&&P.push(f)}var _=b[i],w=_[4*o+0],k=_[4*o+1],L=_[4*o+2],C=_[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(_,o+1),z=.5*a,I=i+1;e(r,n,z,I,w,k||L||C||O),e(r,n+z,z,I,k,L||C||O),e(r+z,n,z,I,L,C||O),e(r+z,n+z,z,I,C,O)}}}(0,0,1,0,0,1),P},g;function L(t,e,r){for(var n=1,a=.5,i=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<a?e<i?0:1:e<i?2:3,o*=.5,a+=t<a?-o:o,i+=e<i?-o:o;return n}}},{"array-bounds":68,"binary-search-bounds":471,clamp:117,defined:166,dtype:171,"flatten-vertex-data":230,"is-obj":422,"math-log2":433,"parse-rect":460,"pick-by-alias":466}],473:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],i=[],s=0;s<e;++s)for(var u=t[s],h=u.length,f=h-1,p=0;p<h;f=p++){var d=u[f],g=u[p];d[0]===g[0]?i.push([d,g]):r.push([d,g])}if(0===r.length)return 0===i.length?c:(v=l(i),function(t){return v(t[0],t[1])?0:1});var v;var m=a(r),y=function(t,e){return function(r){var a=o.le(e,r[0]);if(a<0)return 1;var i=t[a];if(!i){if(!(a>0&&e[a]===r[0]))return 1;i=t[a-1]}for(var s=1;i;){var l=i.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)i=i.left;else{if(!(c>0))return 0;s=-1,i=i.right}else if(c>0)i=i.left;else{if(!(c<0))return 0;s=1,i=i.right}}return s}}(m.slabs,m.coordinates);return 0===i.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(i),y)};var n=t("robust-orientation")[3],a=t("slab-decomposition"),i=t("interval-tree-1d"),o=t("binary-search-bounds");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],a=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];a in e?e[a].push(c):e[a]=[c]}var u={},h=Object.keys(e);for(r=0;r<h.length;++r){var f=e[h[r]];u[h[r]]=i(f)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{"binary-search-bounds":93,"interval-tree-1d":415,"robust-orientation":508,"slab-decomposition":524}],474:[function(t,e,r){var n,a=t("./lib/build-log"),i=t("./lib/epsilon"),o=t("./lib/intersecter"),s=t("./lib/segment-chainer"),l=t("./lib/segment-selector"),c=t("./lib/geojson"),u=!1,h=i();function f(t,e,r){var a=n.segments(t),i=n.segments(e),o=r(n.combine(a,i));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=a():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return h.epsilon(t)},segments:function(t){var e=o(!0,h,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,h,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,h,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,h,t)},union:function(t,e){return f(t,e,n.selectUnion)},intersect:function(t,e){return f(t,e,n.selectIntersect)},difference:function(t,e){return f(t,e,n.selectDifference)},differenceRev:function(t,e){return f(t,e,n.selectDifferenceRev)},xor:function(t,e){return f(t,e,n.selectXor)}},"object"==typeof window&&(window.PolyBool=n),e.exports=n},{"./lib/build-log":475,"./lib/epsilon":476,"./lib/geojson":477,"./lib/intersecter":478,"./lib/segment-chainer":480,"./lib/segment-selector":481}],475:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n("check",{seg1:t,seg2:e})},segmentChop:function(t,e){return n("div_seg",{seg:t,pt:e}),n("chop",{seg:t,pt:e})},statusRemove:function(t){return n("pop_seg",{seg:t})},segmentUpdate:function(t){return n("seg_update",{seg:t})},segmentNew:function(t,e){return n("new_seg",{seg:t,primary:e})},segmentRemove:function(t){return n("rem_seg",{seg:t})},tempStatus:function(t,e,r){return n("temp_status",{seg:t,above:e,below:r})},rewind:function(t){return n("rewind",{seg:t})},status:function(t,e,r){return n("status",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n("vert",{x:e}))},log:function(t){return"string"!=typeof t&&(t=JSON.stringify(t,!1,"  ")),n("log",{txt:t})},reset:function(){return n("reset")},selected:function(t){return n("selected",{segs:t})},chainStart:function(t){return n("chain_start",{seg:t})},chainRemoveHead:function(t,e){return n("chain_rem_head",{index:t,pt:e})},chainRemoveTail:function(t,e){return n("chain_rem_tail",{index:t,pt:e})},chainNew:function(t,e){return n("chain_new",{pt1:t,pt2:e})},chainMatch:function(t){return n("chain_match",{index:t})},chainClose:function(t){return n("chain_close",{index:t})},chainAddHead:function(t,e){return n("chain_add_head",{index:t,pt:e})},chainAddTail:function(t,e){return n("chain_add_tail",{index:t,pt:e})},chainConnect:function(t,e){return n("chain_con",{index1:t,index2:e})},chainReverse:function(t){return n("chain_rev",{index:t})},chainJoin:function(t,e){return n("chain_join",{index1:t,index2:e})},done:function(){return n("done")}}}},{}],476:[function(t,e,r){e.exports=function(t){"number"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return"number"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var a=r[0],i=r[1],o=n[0],s=n[1],l=e[0];return(o-a)*(e[1]-i)-(s-i)*(l-a)>=-t},pointBetween:function(e,r,n){var a=e[1]-r[1],i=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*i+a*s;return!(l<t||l-(i*i+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var a=e[0]-r[0],i=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(a*s-o*i)<t},linesIntersect:function(e,r,n,a){var i=r[0]-e[0],o=r[1]-e[1],s=a[0]-n[0],l=a[1]-n[1],c=i*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],h=e[1]-n[1],f=(s*h-l*u)/c,p=(i*h-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+f*i,e[1]+f*o]};return d.alongA=f<=-t?-2:f<t?-1:f-1<=-t?0:f-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],a=e[1],i=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-a>t!=o-a>t&&(i-c)*(a-u)/(o-u)+c-n>t&&(s=!s),i=c,o=u}return s}};return e}},{}],477:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),a=1;a<e.length;a++)n=t.selectDifference(t.combine(n,r(e[a])));return n}if("Polygon"===e.type)return t.polygon(r(e.coordinates));if("MultiPolygon"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),a=0;a<e.coordinates.length;a++)n=t.selectUnion(t.combine(n,r(e.coordinates[a])));return t.polygon(n)}throw new Error("PolyBool: Cannot convert GeoJSON object to PolyBool polygon")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function a(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var i=a(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var i=a(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(i.children.push(s),t.children.splice(r,1),r--)}t.children.push(i)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(i,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],a=t[t.length-1][1],i=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];i.push([s,l]),r+=l*n-s*a,n=s,a=l}return r<0!==e&&i.reverse(),i.push([i[0][0],i[0][1]]),i}var u=[];function h(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(f(t.children[r]))}function f(t){for(var e=0;e<t.children.length;e++)h(t.children[e]);return c(t.region,!0)}for(s=0;s<i.children.length;s++)h(i.children[s]);return u.length<=0?{type:"Polygon",coordinates:[]}:1==u.length?{type:"Polygon",coordinates:u[0]}:{type:"MultiPolygon",coordinates:u}}};e.exports=n},{}],478:[function(t,e,r){var n=t("./linked-list");e.exports=function(t,e,r){function a(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var i=n.create();function o(t,r){i.insertBefore(t,function(n){return function(t,r,n,a,i,o){var s=e.pointsCompare(r,i);return 0!==s?s:e.pointsSame(n,o)?0:t!==a?t?1:-1:e.pointAboveOrOnLine(n,a?i:o,a?o:i)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0})}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var a=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=a,o(a,t.pt)}(r,t,e),r}function l(t,e){var n=a(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(a,o){var s=n.create();function c(t){return s.findTransition(function(r){var n,a,i,o,s,l;return n=t,a=r.ev,i=n.seg.start,o=n.seg.end,s=a.seg.start,l=a.seg.end,(e.pointsCollinear(i,s,l)?e.pointsCollinear(o,s,l)?1:e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(i,s,l)?1:-1)>0})}function u(t,n){var a=t.seg,i=n.seg,o=a.start,s=a.end,c=i.start,u=i.end;r&&r.checkIntersection(a,i);var h=e.linesIntersect(o,s,c,u);if(!1===h){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var f=e.pointsSame(o,c),p=e.pointsSame(s,u);if(f&&p)return n;var d=!f&&e.pointBetween(o,c,u),g=!p&&e.pointBetween(s,c,u);if(f)return g?l(n,s):l(t,u),n;d&&(p||(g?l(n,s):l(t,u)),l(n,o))}else 0===h.alongA&&(-1===h.alongB?l(t,c):0===h.alongB?l(t,h.pt):1===h.alongB&&l(t,u)),0===h.alongB&&(-1===h.alongA?l(n,o):0===h.alongA?l(n,h.pt):1===h.alongA&&l(n,s));return!1}for(var h=[];!i.isEmpty();){var f=i.getHead();if(r&&r.vert(f.pt[0]),f.isStart){r&&r.segmentNew(f.seg,f.primary);var p=c(f),d=p.before?p.before.ev:null,g=p.after?p.after.ev:null;function v(){if(d){var t=u(f,d);if(t)return t}return!!g&&u(f,g)}r&&r.tempStatus(f.seg,!!d&&d.seg,!!g&&g.seg);var m,y,x=v();if(x)t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below)&&(x.seg.myFill.above=!x.seg.myFill.above):x.seg.otherFill=f.seg.myFill,r&&r.segmentUpdate(x.seg),f.other.remove(),f.remove();if(i.getHead()!==f){r&&r.rewind(f.seg);continue}t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below,f.seg.myFill.below=g?g.seg.myFill.above:a,f.seg.myFill.above=y?!f.seg.myFill.below:f.seg.myFill.below):null===f.seg.otherFill&&(m=g?f.primary===g.primary?g.seg.otherFill.above:g.seg.myFill.above:f.primary?o:a,f.seg.otherFill={above:m,below:m}),r&&r.status(f.seg,!!d&&d.seg,!!g&&g.seg),f.other.status=p.insert(n.node({ev:f}))}else{var b=f.status;if(null===b)throw new Error("PolyBool: Zero-length segment detected; your epsilon is probably too small or too large");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!f.primary){var _=f.seg.myFill;f.seg.myFill=f.seg.otherFill,f.seg.otherFill=_}h.push(f.seg)}i.getHead().remove()}return r&&r.done(),h}return t?{addRegion:function(t){for(var n,a,i,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((a=c<0?n:o,i=c<0?o:n,{id:r?r.segmentId():-1,start:a,end:i,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach(function(t){s(a(t.start,t.end,t),!0)}),r.forEach(function(t){s(a(t.start,t.end,t),!1)}),c(e,n)}}}},{"./linked-list":479}],479:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,a=t.root.next;null!==a;){if(r(a))return e.prev=a.prev,e.next=a,a.prev.next=e,void(a.prev=e);n=a,a=a.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],480:[function(t,e,r){e.exports=function(t,e,r){var n=[],a=[];return t.forEach(function(t){var i=t.start,o=t.end;if(e.pointsSame(i,o))console.warn("PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var h=(v=n[u])[0],f=(v[1],v[v.length-1]);if(v[v.length-2],e.pointsSame(h,i)){if(T(u,!0,!0))break}else if(e.pointsSame(h,o)){if(T(u,!0,!1))break}else if(e.pointsSame(f,i)){if(T(u,!1,!0))break}else if(e.pointsSame(f,o)&&T(u,!1,!1))break}if(c===s)return n.push([i,o]),void(r&&r.chainNew(i,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:i,g=s.matches_head,v=n[p],m=g?v[0]:v[v.length-1],y=g?v[1]:v[v.length-2],x=g?v[v.length-1]:v[0],b=g?v[v.length-2]:v[1];return e.pointsCollinear(y,m,d)&&(g?(r&&r.chainRemoveHead(s.index,d),v.shift()):(r&&r.chainRemoveTail(s.index,d),v.pop()),m=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,m)&&(g?(r&&r.chainRemoveTail(s.index,m),v.pop()):(r&&r.chainRemoveHead(s.index,m),v.shift())),r&&r.chainClose(s.index),void a.push(v)):void(g?(r&&r.chainAddHead(s.index,d),v.unshift(d)):(r&&r.chainAddTail(s.index,d),v.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var k=n[_].length<n[w].length;s.matches_head?l.matches_head?k?(M(_),A(_,w)):(M(w),A(w,_)):A(w,_):l.matches_head?A(_,w):k?(M(_),A(w,_)):(M(w),A(_,w))}function T(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function M(t){r&&r.chainReverse(t),n[t].reverse()}function A(t,a){var i=n[t],o=n[a],s=i[i.length-1],l=i[i.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),i.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(a,c),o.shift()),r&&r.chainJoin(t,a),n[t]=i.concat(o),n.splice(a,1)}}),a}},{}],481:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach(function(t){var a=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[a]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[a],below:2===e[a]},otherFill:null})}),r&&r.selected(n),n}var a={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=a},{}],482:[function(t,e,r){"use strict";var n=new Float64Array(4),a=new Float64Array(4),i=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),a=new Float64Array(o.length),i=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],a[l]=e[l]-t[l],i[l]=r[l]-t[l];var c=0,u=0,h=0,f=0,p=0,d=0;for(l=0;l<o.length;++l){var g=a[l],v=i[l],m=n[l];c+=g*g,u+=g*v,h+=v*v,f+=m*g,p+=m*v,d+=m*m}var y,x,b,_,w,k=Math.abs(c*h-u*u),T=u*p-h*f,M=u*f-c*p;if(T+M<=k)if(T<0)M<0&&f<0?(M=0,-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d):(T=0,p>=0?(M=0,y=d):-p>=h?(M=1,y=h+2*p+d):y=p*(M=-p/h)+d);else if(M<0)M=0,f>=0?(T=0,y=d):-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d;else{var A=1/k;y=(T*=A)*(c*T+u*(M*=A)+2*f)+M*(u*T+h*M+2*p)+d}else T<0?(b=h+p)>(x=u+f)?(_=b-x)>=(w=c-2*u+h)?(T=1,M=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(M=1-T)+2*f)+M*(u*T+h*M+2*p)+d:(T=0,b<=0?(M=1,y=h+2*p+d):p>=0?(M=0,y=d):y=p*(M=-p/h)+d):M<0?(b=c+f)>(x=u+p)?(_=b-x)>=(w=c-2*u+h)?(M=1,T=0,y=h+2*p+d):y=(T=1-(M=_/w))*(c*T+u*M+2*f)+M*(u*T+h*M+2*p)+d:(M=0,b<=0?(T=1,y=c+2*f+d):f>=0?(T=0,y=d):y=f*(T=-f/c)+d):(_=h+p-u-f)<=0?(T=0,M=1,y=h+2*p+d):_>=(w=c-2*u+h)?(T=1,M=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(M=1-T)+2*f)+M*(u*T+h*M+2*p)+d;var S=1-T-M;for(l=0;l<o.length;++l)s[l]=S*t[l]+T*e[l]+M*r[l];return y<0?0:y}},{}],483:[function(t,e,r){var n,a,i=e.exports={};function o(){throw new Error("setTimeout has not been defined")}function s(){throw new Error("clearTimeout has not been defined")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n="function"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{a="function"==typeof clearTimeout?clearTimeout:s}catch(t){a=s}}();var c,u=[],h=!1,f=-1;function p(){h&&c&&(h=!1,c.length?u=c.concat(u):f=-1,u.length&&d())}function d(){if(!h){var t=l(p);h=!0;for(var e=u.length;e;){for(c=u,u=[];++f<e;)c&&c[f].run();f=-1,e=u.length}c=null,h=!1,function(t){if(a===clearTimeout)return clearTimeout(t);if((a===s||!a)&&clearTimeout)return a=clearTimeout,clearTimeout(t);try{a(t)}catch(e){try{return a.call(null,t)}catch(e){return a.call(this,t)}}}(t)}}function g(t,e){this.fun=t,this.array=e}function v(){}i.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new g(t,e)),1!==u.length||h||l(d)},g.prototype.run=function(){this.fun.apply(null,this.array)},i.title="browser",i.browser=!0,i.env={},i.argv=[],i.version="",i.versions={},i.on=v,i.addListener=v,i.once=v,i.off=v,i.removeListener=v,i.removeAllListeners=v,i.emit=v,i.prependListener=v,i.prependOnceListener=v,i.listeners=function(t){return[]},i.binding=function(t){throw new Error("process.binding is not supported")},i.cwd=function(){return"/"},i.chdir=function(t){throw new Error("process.chdir is not supported")},i.umask=function(){return 0}},{}],484:[function(t,e,r){e.exports=t("gl-quat/slerp")},{"gl-quat/slerp":296}],485:[function(t,e,r){(function(r){for(var n=t("performance-now"),a="undefined"==typeof window?r:window,i=["moz","webkit"],o="AnimationFrame",s=a["request"+o],l=a["cancel"+o]||a["cancelRequest"+o],c=0;!s&&c<i.length;c++)s=a[i[c]+"Request"+o],l=a[i[c]+"Cancel"+o]||a[i[c]+"CancelRequest"+o];if(!s||!l){var u=0,h=0,f=[];s=function(t){if(0===f.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout(function(){var t=f.slice(0);f.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout(function(){throw t},0)}},Math.round(r))}return f.push({handle:++h,callback:t,cancelled:!1}),h},l=function(t){for(var e=0;e<f.length;e++)f[e].handle===t&&(f[e].cancelled=!0)}}e.exports=function(t){return s.call(a,t)},e.exports.cancel=function(){l.apply(a,arguments)},e.exports.polyfill=function(t){t||(t=a),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"performance-now":463}],486:[function(t,e,r){"use strict";var n=t("big-rat/add");e.exports=function(t,e){for(var r=t.length,a=new Array(r),i=0;i<r;++i)a[i]=n(t[i],e[i]);return a}},{"big-rat/add":77}],487:[function(t,e,r){"use strict";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t("big-rat")},{"big-rat":80}],488:[function(t,e,r){"use strict";var n=t("big-rat"),a=t("big-rat/mul");e.exports=function(t,e){for(var r=n(e),i=t.length,o=new Array(i),s=0;s<i;++s)o[s]=a(t[s],r);return o}},{"big-rat":80,"big-rat/mul":89}],489:[function(t,e,r){"use strict";var n=t("big-rat/sub");e.exports=function(t,e){for(var r=t.length,a=new Array(r),i=0;i<r;++i)a[i]=n(t[i],e[i]);return a}},{"big-rat/sub":91}],490:[function(t,e,r){"use strict";var n=t("compare-cell"),a=t("compare-oriented-cell"),i=t("cell-orientation");e.exports=function(t){t.sort(a);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=i(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&i(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{"cell-orientation":114,"compare-cell":130,"compare-oriented-cell":131}],491:[function(t,e,r){"use strict";var n=t("array-bounds"),a=t("color-normalize"),i=t("update-diff"),o=t("pick-by-alias"),s=t("object-assign"),l=t("flatten-vertex-data"),c=t("to-float32"),u=c.float32,h=c.fract32;e.exports=function(t,e){"function"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension("ANGLE_instanced_arrays"))throw Error("regl-error2d: `ANGLE_instanced_arrays` extension should be enabled");var r,c,p,d,g,v,m=t._gl,y={color:"black",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:"dynamic",type:"uint8",data:new Uint8Array(0)}),c=t.buffer({usage:"dynamic",type:"float",data:new Uint8Array(0)}),p=t.buffer({usage:"dynamic",type:"float",data:new Uint8Array(0)}),g=t.buffer({usage:"dynamic",type:"float",data:new Uint8Array(0)}),v=t.buffer({usage:"static",type:"float",data:f}),k(e),r=t({vert:"\n\t\tprecision highp float;\n\n\t\tattribute vec2 position, positionFract;\n\t\tattribute vec4 error;\n\t\tattribute vec4 color;\n\n\t\tattribute vec2 direction, lineOffset, capOffset;\n\n\t\tuniform vec4 viewport;\n\t\tuniform float lineWidth, capSize;\n\t\tuniform vec2 scale, scaleFract, translate, translateFract;\n\n\t\tvarying vec4 fragColor;\n\n\t\tvoid main() {\n\t\t\tfragColor = color / 255.;\n\n\t\t\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\n\n\t\t\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\n\n\t\t\tvec2 position = position + dxy;\n\n\t\t\tvec2 pos = (position + translate) * scale\n\t\t\t\t+ (positionFract + translateFract) * scale\n\t\t\t\t+ (position + translate) * scaleFract\n\t\t\t\t+ (positionFract + translateFract) * scaleFract;\n\n\t\t\tpos += pixelOffset / viewport.zw;\n\n\t\t\tgl_Position = vec4(pos * 2. - 1., 0, 1);\n\t\t}\n\t\t",frag:"\n\t\tprecision highp float;\n\n\t\tvarying vec4 fragColor;\n\n\t\tuniform float opacity;\n\n\t\tvoid main() {\n\t\t\tgl_FragColor = fragColor;\n\t\t\tgl_FragColor.a *= opacity;\n\t\t}\n\t\t",uniforms:{range:t.prop("range"),lineWidth:t.prop("lineWidth"),capSize:t.prop("capSize"),opacity:t.prop("opacity"),scale:t.prop("scale"),translate:t.prop("translate"),scaleFract:t.prop("scaleFract"),translateFract:t.prop("translateFract"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:g,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:v,stride:24,offset:0},lineOffset:{buffer:v,stride:24,offset:8},capOffset:{buffer:v,stride:24,offset:16}},primitive:"triangles",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:"add",alpha:"add"},func:{srcRGB:"src alpha",dstRGB:"one minus src alpha",srcAlpha:"one minus dst alpha",dstAlpha:"one"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop("viewport")},viewport:t.prop("viewport"),stencil:!1,instances:t.prop("count"),count:f.length}),s(b,{update:k,draw:_,destroy:T,regl:t,gl:m,canvas:m.canvas,groups:x}),b;function b(t){t?k(t):null===t&&T(),_()}function _(e){if("number"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach(function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)})}function w(t){"number"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function k(t){if(t){null!=t.length?"number"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map(function(t,c){var u=x[c];return t?("function"==typeof t?t={after:t}:"number"==typeof t[0]&&(t={positions:t}),t=o(t,{color:"color colors fill",capSize:"capSize cap capsize cap-size",lineWidth:"lineWidth line-width width line thickness",opacity:"opacity alpha",range:"range dataBox",viewport:"viewport viewBox",errors:"errors error",positions:"positions position data points"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),i(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,"float64"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t="transparent"),!Array.isArray(t)||"number"==typeof t[0]){var n=t;t=Array(r);for(var i=0;i<r;i++)t[i]=n}if(t.length<r)throw Error("Not enough colors");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=a(t[s],"uint8");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=h(e.scale),e.translateFract=h(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:m.drawingBufferWidth,height:m.drawingBufferHeight},e}}]),u):u}),e||r){var f=x.reduce(function(t,e,r){return t+(e?e.count:0)},0),v=new Float64Array(2*f),_=new Uint8Array(4*f),w=new Float32Array(4*f);x.forEach(function(t,e){if(t){var r=t.positions,n=t.count,a=t.offset,i=t.color,o=t.errors;n&&(_.set(i,4*a),w.set(o,4*a),v.set(r,2*a))}}),c(u(v)),p(h(v)),d(_),g(w)}}}function T(){c.destroy(),p.destroy(),d.destroy(),g.destroy(),v.destroy()}};var f=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{"array-bounds":68,"color-normalize":122,"flatten-vertex-data":230,"object-assign":455,"pick-by-alias":466,"to-float32":536,"update-diff":547}],492:[function(t,e,r){"use strict";var n=t("color-normalize"),a=t("array-bounds"),i=t("object-assign"),o=t("glslify"),s=t("pick-by-alias"),l=t("flatten-vertex-data"),c=t("earcut"),u=t("array-normalize"),h=t("to-float32"),f=h.float32,p=h.fract32,d=t("es6-weak-map"),g=t("parse-rect");function v(t,e){if(!(this instanceof v))return new v(t,e);if("function"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension("ANGLE_instanced_arrays"))throw Error("regl-error2d: `ANGLE_instanced_arrays` extension should be enabled");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=v.shaders.has(t)?v.shaders.get(t):v.shaders.set(t,v.createShaders(t)).get(t),this.update(e)}e.exports=v,v.dashMult=2,v.maxPatternLength=256,v.precisionThreshold=3e6,v.maxPoints=1e4,v.maxLines=2048,v.shaders=new d,v.createShaders=function(t){var e,r=t.buffer({usage:"static",type:"float",data:[0,1,0,0,1,1,1,0]}),n={primitive:"triangle strip",instances:t.prop("count"),count:4,offset:0,uniforms:{miterMode:function(t,e){return"round"===e.join?2:1},miterLimit:t.prop("miterLimit"),scale:t.prop("scale"),scaleFract:t.prop("scaleFract"),translateFract:t.prop("translateFract"),translate:t.prop("translate"),thickness:t.prop("thickness"),dashPattern:t.prop("dashTexture"),opacity:t.prop("opacity"),pixelRatio:t.context("pixelRatio"),id:t.prop("id"),dashSize:t.prop("dashLength"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop("depth")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:"add",alpha:"add"},func:{srcRGB:"src alpha",dstRGB:"one minus src alpha",srcAlpha:"one minus dst alpha",dstAlpha:"one"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop("viewport")},viewport:t.prop("viewport")},a=t(i({vert:o(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\nattribute vec4 color;\nattribute float lineEnd, lineTop;\n\nuniform vec2 scale, scaleFract, translate, translateFract;\nuniform float thickness, pixelRatio, id, depth;\nuniform vec4 viewport;\n\nvarying vec4 fragColor;\nvarying vec2 tangent;\n\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\n\t// the order is important\n\treturn position * scale + translate\n       + positionFract * scale + translateFract\n       + position * scaleFract\n       + positionFract * scaleFract;\n}\n\nvoid main() {\n\tfloat lineStart = 1. - lineEnd;\n\tfloat lineOffset = lineTop * 2. - 1.;\n\n\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\n\ttangent = normalize(diff * scale * viewport.zw);\n\tvec2 normal = vec2(-tangent.y, tangent.x);\n\n\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\n\t\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\n\n\t\t+ thickness * normal * .5 * lineOffset / viewport.zw;\n\n\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\n\n\tfragColor = color / 255.;\n}\n"]),frag:o(["precision highp float;\n#define GLSLIFY 1\n\nuniform sampler2D dashPattern;\n\nuniform float dashSize, pixelRatio, thickness, opacity, id;\n\nvarying vec4 fragColor;\nvarying vec2 tangent;\n\nvoid main() {\n\tfloat alpha = 1.;\n\n\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\n\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\n\n\tgl_FragColor = fragColor;\n\tgl_FragColor.a *= alpha * opacity * dash;\n}\n"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop("positionBuffer"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop("positionBuffer"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop("positionFractBuffer"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop("positionFractBuffer"),stride:8,offset:16,divisor:1},color:{buffer:t.prop("colorBuffer"),stride:4,offset:0,divisor:1}}},n));try{e=t(i({cull:{enable:!0,face:"back"},vert:o(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\nattribute vec4 aColor, bColor;\nattribute float lineEnd, lineTop;\n\nuniform vec2 scale, translate;\nuniform float thickness, pixelRatio, id, depth;\nuniform vec4 viewport;\nuniform float miterLimit, miterMode;\n\nvarying vec4 fragColor;\nvarying vec4 startCutoff, endCutoff;\nvarying vec2 tangent;\nvarying vec2 startCoord, endCoord;\nvarying float enableStartMiter, enableEndMiter;\n\nconst float REVERSE_THRESHOLD = -.875;\nconst float MIN_DIFF = 1e-6;\n\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\n// TODO: precalculate dot products, normalize things beforehead etc.\n// TODO: refactor to rectangular algorithm\n\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\n\tvec2 diff = b - a;\n\tvec2 perp = normalize(vec2(-diff.y, diff.x));\n\treturn dot(p - a, perp);\n}\n\nbool isNaN( float val ){\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\n}\n\nvoid main() {\n\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\n\n  vec2 adjustedScale;\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\n\n  vec2 scaleRatio = adjustedScale * viewport.zw;\n\tvec2 normalWidth = thickness / scaleRatio;\n\n\tfloat lineStart = 1. - lineEnd;\n\tfloat lineBot = 1. - lineTop;\n\n\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\n\n\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\n\n\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\n\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\n\n\tvec2 prevDiff = aCoord - prevCoord;\n\tvec2 currDiff = bCoord - aCoord;\n\tvec2 nextDiff = nextCoord - bCoord;\n\n\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\n\tvec2 currTangent = normalize(currDiff * scaleRatio);\n\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\n\n\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\n\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\n\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\n\n\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\n\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\n\n\t// collapsed/unidirectional segment cases\n\t// FIXME: there should be more elegant solution\n\tvec2 prevTanDiff = abs(prevTangent - currTangent);\n\tvec2 nextTanDiff = abs(nextTangent - currTangent);\n\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\n\t\tstartJoinDirection = currNormal;\n\t}\n\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\n\t\tendJoinDirection = currNormal;\n\t}\n\tif (aCoord == bCoord) {\n\t\tendJoinDirection = startJoinDirection;\n\t\tcurrNormal = prevNormal;\n\t\tcurrTangent = prevTangent;\n\t}\n\n\ttangent = currTangent;\n\n\t//calculate join shifts relative to normals\n\tfloat startJoinShift = dot(currNormal, startJoinDirection);\n\tfloat endJoinShift = dot(currNormal, endJoinDirection);\n\n\tfloat startMiterRatio = abs(1. / startJoinShift);\n\tfloat endMiterRatio = abs(1. / endJoinShift);\n\n\tvec2 startJoin = startJoinDirection * startMiterRatio;\n\tvec2 endJoin = endJoinDirection * endMiterRatio;\n\n\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\n\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\n\tstartBotJoin = -startTopJoin;\n\n\tendTopJoin = sign(endJoinShift) * endJoin * .5;\n\tendBotJoin = -endTopJoin;\n\n\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\n\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\n\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\n\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\n\n\t//miter anti-clipping\n\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\n\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\n\n\t//prevent close to reverse direction switch\n\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\n\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\n\n\tif (prevReverse) {\n\t\t//make join rectangular\n\t\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\n\t\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\n\t\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\n\t\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\n\t}\n\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\n\t\t//handle miter clipping\n\t\tbTopCoord -= normalWidth * endTopJoin;\n\t\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\n\t}\n\n\tif (nextReverse) {\n\t\t//make join rectangular\n\t\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\n\t\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\n\t\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\n\t\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\n\t}\n\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\n\t\t//handle miter clipping\n\t\taBotCoord -= normalWidth * startBotJoin;\n\t\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\n\t}\n\n\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\n\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\n\n\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\n\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\n\n\t//position is normalized 0..1 coord on the screen\n\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\n\n\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\n\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\n\n\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\n\n\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\n\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\n\n\t//bevel miter cutoffs\n\tif (miterMode == 1.) {\n\t\tif (enableStartMiter == 1.) {\n\t\t\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\n\t\t\tstartCutoff = vec4(aCoord, aCoord);\n\t\t\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\n\t\t\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\n\t\t\tstartCutoff += viewport.xyxy;\n\t\t\tstartCutoff += startMiterWidth.xyxy;\n\t\t}\n\n\t\tif (enableEndMiter == 1.) {\n\t\t\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\n\t\t\tendCutoff = vec4(bCoord, bCoord);\n\t\t\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\n\t\t\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\n\t\t\tendCutoff += viewport.xyxy;\n\t\t\tendCutoff += endMiterWidth.xyxy;\n\t\t}\n\t}\n\n\t//round miter cutoffs\n\telse if (miterMode == 2.) {\n\t\tif (enableStartMiter == 1.) {\n\t\t\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\n\t\t\tstartCutoff = vec4(aCoord, aCoord);\n\t\t\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\n\t\t\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\n\t\t\tstartCutoff += viewport.xyxy;\n\t\t\tstartCutoff += startMiterWidth.xyxy;\n\t\t}\n\n\t\tif (enableEndMiter == 1.) {\n\t\t\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\n\t\t\tendCutoff = vec4(bCoord, bCoord);\n\t\t\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\n\t\t\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\n\t\t\tendCutoff += viewport.xyxy;\n\t\t\tendCutoff += endMiterWidth.xyxy;\n\t\t}\n\t}\n}\n"]),frag:o(["precision highp float;\n#define GLSLIFY 1\n\nuniform sampler2D dashPattern;\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\n\nvarying vec4 fragColor;\nvarying vec2 tangent;\nvarying vec4 startCutoff, endCutoff;\nvarying vec2 startCoord, endCoord;\nvarying float enableStartMiter, enableEndMiter;\n\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\n\tvec2 diff = b - a;\n\tvec2 perp = normalize(vec2(-diff.y, diff.x));\n\treturn dot(p - a, perp);\n}\n\nvoid main() {\n\tfloat alpha = 1., distToStart, distToEnd;\n\tfloat cutoff = thickness * .5;\n\n\t//bevel miter\n\tif (miterMode == 1.) {\n\t\tif (enableStartMiter == 1.) {\n\t\t\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\n\t\t\tif (distToStart < -1.) {\n\t\t\t\tdiscard;\n\t\t\t\treturn;\n\t\t\t}\n\t\t\talpha *= min(max(distToStart + 1., 0.), 1.);\n\t\t}\n\n\t\tif (enableEndMiter == 1.) {\n\t\t\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\n\t\t\tif (distToEnd < -1.) {\n\t\t\t\tdiscard;\n\t\t\t\treturn;\n\t\t\t}\n\t\t\talpha *= min(max(distToEnd + 1., 0.), 1.);\n\t\t}\n\t}\n\n\t// round miter\n\telse if (miterMode == 2.) {\n\t\tif (enableStartMiter == 1.) {\n\t\t\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\n\t\t\tif (distToStart < 0.) {\n\t\t\t\tfloat radius = length(gl_FragCoord.xy - startCoord);\n\n\t\t\t\tif(radius > cutoff + .5) {\n\t\t\t\t\tdiscard;\n\t\t\t\t\treturn;\n\t\t\t\t}\n\n\t\t\t\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\n\t\t\t}\n\t\t}\n\n\t\tif (enableEndMiter == 1.) {\n\t\t\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\n\t\t\tif (distToEnd < 0.) {\n\t\t\t\tfloat radius = length(gl_FragCoord.xy - endCoord);\n\n\t\t\t\tif(radius > cutoff + .5) {\n\t\t\t\t\tdiscard;\n\t\t\t\t\treturn;\n\t\t\t\t}\n\n\t\t\t\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\n\t\t\t}\n\t\t}\n\t}\n\n\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\n\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\n\n\tgl_FragColor = fragColor;\n\tgl_FragColor.a *= alpha * opacity * dash;\n}\n"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop("colorBuffer"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop("colorBuffer"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop("positionBuffer"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop("positionBuffer"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop("positionBuffer"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop("positionBuffer"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=a}return{fill:t({primitive:"triangle",elements:function(t,e){return e.triangles},offset:0,vert:o(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec2 position, positionFract;\n\nuniform vec4 color;\nuniform vec2 scale, scaleFract, translate, translateFract;\nuniform float pixelRatio, id;\nuniform vec4 viewport;\nuniform float opacity;\n\nvarying vec4 fragColor;\n\nconst float MAX_LINES = 256.;\n\nvoid main() {\n\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\n\n\tvec2 position = position * scale + translate\n       + positionFract * scale + translateFract\n       + position * scaleFract\n       + positionFract * scaleFract;\n\n\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\n\n\tfragColor = color / 255.;\n\tfragColor.a *= opacity;\n}\n"]),frag:o(["precision highp float;\n#define GLSLIFY 1\n\nvarying vec4 fragColor;\n\nvoid main() {\n\tgl_FragColor = fragColor;\n}\n"]),uniforms:{scale:t.prop("scale"),color:t.prop("fill"),scaleFract:t.prop("scaleFract"),translateFract:t.prop("translateFract"),translate:t.prop("translate"),opacity:t.prop("opacity"),pixelRatio:t.context("pixelRatio"),id:t.prop("id"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop("positionBuffer"),stride:8,offset:8},positionFract:{buffer:t.prop("positionFractBuffer"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:a,miter:e}},v.defaults={dashes:null,join:"miter",miterLimit:1,thickness:10,cap:"square",color:"black",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},v.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},v.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach(function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);"number"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>v.precisionThreshold||e.scale[1]*e.viewport.height>v.precisionThreshold?t.shaders.rect(e):"rect"===e.join||!e.join&&(e.thickness<=2||e.count>=v.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))}),this},v.prototype.update=function(t){var e=this;if(t){null!=t.length?"number"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach(function(t,h){var d=e.passes[h];if(void 0!==t)if(null!==t){if("number"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:"positions points data coords",thickness:"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth",join:"lineJoin linejoin join type mode",miterLimit:"miterlimit miterLimit",dashes:"dash dashes dasharray dash-array dashArray",color:"color colour stroke colors colours stroke-color strokeColor",fill:"fill fill-color fillColor",opacity:"alpha opacity",overlay:"overlay crease overlap intersect",close:"closed close closed-path closePath",range:"range dataBox",viewport:"viewport viewBox",hole:"holes hole hollow"}),d||(e.passes[h]=d={id:h,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:"linear",min:"linear"}),colorBuffer:r.buffer({usage:"dynamic",type:"uint8",data:new Uint8Array}),positionBuffer:r.buffer({usage:"dynamic",type:"float",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:"dynamic",type:"float",data:new Uint8Array})},t=i({},v.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,h<v.maxLines&&(d.depth=2*(v.maxLines-1-h%v.maxLines)/v.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,"uint8"):null),null!=t.viewport&&(d.viewport=g(t.viewport)),d.viewport||(d.viewport=g([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var m,y;if(t.positions.x&&t.positions.y){var x=t.positions.x,b=t.positions.y;y=d.count=Math.max(x.length,b.length),m=new Float64Array(2*y);for(var _=0;_<y;_++)m[2*_]=x[_],m[2*_+1]=b[_]}else m=l(t.positions,"float64"),y=d.count=Math.floor(m.length/2);var w=d.bounds=a(m,2);if(d.fill){for(var k=[],T={},M=0,A=0,S=0,E=d.count;A<E;A++){var L=m[2*A],C=m[2*A+1];isNaN(L)||isNaN(C)||null==L||null==C?(L=m[2*M],C=m[2*M+1],T[A]=M):M=A,k[S++]=L,k[S++]=C}for(var P=c(k,d.hole||[]),O=0,z=P.length;O<z;O++)null!=T[P[O]]&&(P[O]=T[P[O]]);d.triangles=P}var I=new Float64Array(m);u(I,2,w);var D=new Float64Array(2*y+6);d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[0]=I[2*y-4],D[1]=I[2*y-3]):(D[0]=I[2*y-2],D[1]=I[2*y-1]):(D[0]=I[0],D[1]=I[1]),D.set(I,2),d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[2*y+2]=I[2],D[2*y+3]=I[3],d.count-=1):(D[2*y+2]=I[0],D[2*y+3]=I[1],D[2*y+4]=I[2],D[2*y+5]=I[3]):(D[2*y+2]=I[2*y-2],D[2*y+3]=I[2*y-1],D[2*y+4]=I[2*y-2],D[2*y+5]=I[2*y-1]),d.positionBuffer(f(D)),d.positionFractBuffer(p(D))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var R=d.bounds,F=R[2]-R[0],B=R[3]-R[1],N=d.range[2]-d.range[0],j=d.range[3]-d.range[1];d.scale=[F/N,B/j],d.translate=[-d.range[0]/N+R[0]/N||0,-d.range[1]/j+R[1]/j||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var V,U=0;if(!t.dashes||t.dashes.length<2)U=1,V=new Uint8Array([255,255,255,255,255,255,255,255]);else{U=0;for(var q=0;q<t.dashes.length;++q)U+=t.dashes[q];V=new Uint8Array(U*v.dashMult);for(var H=0,G=255,Y=0;Y<2;Y++)for(var W=0;W<t.dashes.length;++W){for(var X=0,Z=t.dashes[W]*v.dashMult*.5;X<Z;++X)V[H++]=G;G^=255}}d.dashLength=U,d.dashTexture({channels:1,data:V,width:V.length,height:1,mag:"linear",min:"linear"},0,0)}if(t.color){var J=d.count,K=t.color;K||(K="transparent");var Q=new Uint8Array(4*J+4);if(Array.isArray(K)&&"number"!=typeof K[0]){for(var $=0;$<J;$++){var tt=n(K[$],"uint8");Q.set(tt,4*$)}Q.set(n(K[0],"uint8"),4*J)}else for(var et=n(K,"uint8"),rt=0;rt<J+1;rt++)Q.set(et,4*rt);d.colorBuffer({usage:"dynamic",type:"uint8",data:Q})}}else e.passes[h]=null}),t.length<this.passes.length){for(var h=t.length;h<this.passes.length;h++){var d=e.passes[h];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var m=[],y=0;y<this.passes.length;y++)null!==e.passes[y]&&m.push(e.passes[y]);return this.passes=m,this}},v.prototype.destroy=function(){return this.passes.forEach(function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()}),this.passes.length=0,this}},{"array-bounds":68,"array-normalize":493,"color-normalize":122,earcut:173,"es6-weak-map":494,"flatten-vertex-data":230,glslify:410,"object-assign":455,"parse-rect":460,"pick-by-alias":466,"to-float32":536}],493:[function(t,e,r){"use strict";var n=t("array-bounds");e.exports=function(t,e,r){if(!t||null==t.length)throw Error("Argument should be an array");null==e&&(e=1);null==r&&(r=n(t,e));for(var a=0;a<e;a++){var i=r[e+a],o=r[a],s=a,l=t.length;if(i===1/0&&o===-1/0)for(s=a;s<l;s+=e)t[s]=t[s]===i?1:t[s]===o?0:.5;else if(i===1/0)for(s=a;s<l;s+=e)t[s]=t[s]===i?1:0;else if(o===-1/0)for(s=a;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=i-o;for(s=a;s<l;s+=e)isNaN(t[s])||(t[s]=0===c?.5:(t[s]-o)/c)}}return t}},{"array-bounds":68}],494:[function(t,e,r){arguments[4][320][0].apply(r,arguments)},{"./is-implemented":495,"./polyfill":497,dup:320}],495:[function(t,e,r){arguments[4][321][0].apply(r,arguments)},{dup:321}],496:[function(t,e,r){arguments[4][322][0].apply(r,arguments)},{dup:322}],497:[function(t,e,r){arguments[4][323][0].apply(r,arguments)},{"./is-native-implemented":496,d:153,dup:323,"es5-ext/object/is-value":197,"es5-ext/object/set-prototype-of":203,"es5-ext/object/valid-object":207,"es5-ext/object/valid-value":208,"es5-ext/string/random-uniq":213,"es6-iterator/for-of":215,"es6-iterator/get":216,"es6-symbol":222}],498:[function(t,e,r){"use strict";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){var r=[],n=!0,a=!1,i=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){a=!0,i=t}finally{try{n||null==s.return||s.return()}finally{if(a)throw i}}return r}(t,e)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance")}()}function a(t){return function(t){if(Array.isArray(t)){for(var e=0,r=new Array(t.length);e<t.length;e++)r[e]=t[e];return r}}(t)||function(t){if(Symbol.iterator in Object(t)||"[object Arguments]"===Object.prototype.toString.call(t))return Array.from(t)}(t)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance")}()}var i=t("color-normalize"),o=t("array-bounds"),s=t("color-id"),l=t("point-cluster"),c=t("object-assign"),u=t("glslify"),h=t("pick-by-alias"),f=t("update-diff"),p=t("flatten-vertex-data"),d=t("is-iexplorer"),g=t("to-float32"),v=t("parse-rect"),m=y;function y(t,e){var r=this;if(!(this instanceof y))return new y(t,e);"function"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,a=(t=e.regl)._gl,i=[];this.tooManyColors=d,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:"uint8",format:"rgba",wrapS:"clamp",wrapT:"clamp",mag:"nearest",min:"nearest"}),c(this,{regl:t,gl:a,groups:[],markerCache:[null],markerTextures:[null],palette:i,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:a.canvas}),this.update(e);var o={uniforms:{pixelRatio:t.context("pixelRatio"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop("scale"),scaleFract:t.prop("scaleFract"),translate:t.prop("translate"),translateFract:t.prop("translateFract"),opacity:t.prop("opacity"),marker:t.prop("markerTexture")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?i.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?i.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:"src alpha",dstRGB:"one minus src alpha",srcAlpha:"one minus dst alpha",dstAlpha:"one"}},scissor:{enable:!0,box:t.prop("viewport")},viewport:t.prop("viewport"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop("elements"),count:t.prop("count"),offset:t.prop("offset"),primitive:"points"},s=c({},o);s.frag=u(["precision highp float;\n#define GLSLIFY 1\n\nvarying vec4 fragColor, fragBorderColor;\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\n\nuniform sampler2D marker;\nuniform float pixelRatio, opacity;\n\nfloat smoothStep(float x, float y) {\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\n}\n\nvoid main() {\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\n\n  // max-distance alpha\n  if (dist < 0.003) discard;\n\n  // null-border case\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\n  }\n  else {\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\n\n    vec4 color = fragBorderColor;\n    color.a *= borderColorAmt;\n    color = mix(color, fragColor, colorAmt);\n    color.a *= opacity;\n\n    gl_FragColor = color;\n  }\n\n}\n"]),s.vert=u(["precision highp float;\n#define GLSLIFY 1\n\nattribute float x, y, xFract, yFract;\nattribute float size, borderSize;\nattribute vec4 colorId, borderColorId;\nattribute float isActive;\n\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\nuniform float pixelRatio;\nuniform sampler2D palette;\n\nconst float maxSize = 100.;\nconst float borderLevel = .5;\n\nvarying vec4 fragColor, fragBorderColor;\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\n\nbool isDirect = (paletteSize.x < 1.);\n\nvec4 getColor(vec4 id) {\n  return isDirect ? id / 255. : texture2D(palette,\n    vec2(\n      (id.x + .5) / paletteSize.x,\n      (id.y + .5) / paletteSize.y\n    )\n  );\n}\n\nvoid main() {\n  if (isActive == 0.) return;\n\n  vec2 position = vec2(x, y);\n  vec2 positionFract = vec2(xFract, yFract);\n\n  vec4 color = getColor(colorId);\n  vec4 borderColor = getColor(borderColorId);\n\n  float size = size * maxSize / 255.;\n  float borderSize = borderSize * maxSize / 255.;\n\n  gl_PointSize = 2. * size * pixelRatio;\n  fragPointSize = size * pixelRatio;\n\n  vec2 pos = (position + translate) * scale\n      + (positionFract + translateFract) * scale\n      + (position + translate) * scaleFract\n      + (positionFract + translateFract) * scaleFract;\n\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\n\n  fragColor = color;\n  fragBorderColor = borderColor;\n  fragWidth = 1. / gl_PointSize;\n\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\n}"]),this.drawMarker=t(s);var l=c({},o);l.frag=u(["precision highp float;\n#define GLSLIFY 1\n\nvarying vec4 fragColor, fragBorderColor;\n\nuniform float opacity;\nvarying float fragBorderRadius, fragWidth;\n\nfloat smoothStep(float edge0, float edge1, float x) {\n\tfloat t;\n\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\n\treturn t * t * (3.0 - 2.0 * t);\n}\n\nvoid main() {\n\tfloat radius, alpha = 1.0, delta = fragWidth;\n\n\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\n\n\tif (radius > 1.0 + delta) {\n\t\tdiscard;\n\t}\n\n\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\n\n\tfloat borderRadius = fragBorderRadius;\n\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\n\tvec4 color = mix(fragColor, fragBorderColor, ratio);\n\tcolor.a *= alpha * opacity;\n\tgl_FragColor = color;\n}\n"]),l.vert=u(["precision highp float;\n#define GLSLIFY 1\n\nattribute float x, y, xFract, yFract;\nattribute float size, borderSize;\nattribute vec4 colorId, borderColorId;\nattribute float isActive;\n\nuniform vec2 scale, scaleFract, translate, translateFract;\nuniform float pixelRatio;\nuniform sampler2D palette;\nuniform vec2 paletteSize;\n\nconst float maxSize = 100.;\n\nvarying vec4 fragColor, fragBorderColor;\nvarying float fragBorderRadius, fragWidth;\n\nbool isDirect = (paletteSize.x < 1.);\n\nvec4 getColor(vec4 id) {\n  return isDirect ? id / 255. : texture2D(palette,\n    vec2(\n      (id.x + .5) / paletteSize.x,\n      (id.y + .5) / paletteSize.y\n    )\n  );\n}\n\nvoid main() {\n  // ignore inactive points\n  if (isActive == 0.) return;\n\n  vec2 position = vec2(x, y);\n  vec2 positionFract = vec2(xFract, yFract);\n\n  vec4 color = getColor(colorId);\n  vec4 borderColor = getColor(borderColorId);\n\n  float size = size * maxSize / 255.;\n  float borderSize = borderSize * maxSize / 255.;\n\n  gl_PointSize = (size + borderSize) * pixelRatio;\n\n  vec2 pos = (position + translate) * scale\n      + (positionFract + translateFract) * scale\n      + (position + translate) * scaleFract\n      + (positionFract + translateFract) * scaleFract;\n\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\n\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\n  fragColor = color;\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\n  fragWidth = 1. / gl_PointSize;\n}\n"]),d&&(l.frag=l.frag.replace("smoothstep","smoothStep"),s.frag=s.frag.replace("smoothstep","smoothStep")),this.drawCircle=t(l)}y.defaults={color:"black",borderColor:"transparent",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},y.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},y.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var a=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var i=0;i<r.length;i++)this.drawItem(i,r[i]);else a.forEach(function(e,r){t.drawItem(r)});return this},y.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if("number"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var i=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&i.push.apply(i,a(this.getMarkerDrawOptions(o,n,e)));i.length&&this.drawMarker(i)}},y.prototype.getMarkerDrawOptions=function(t,e,r){var a=e.range,i=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,u=e.count;this.regl;if(!i)return r?[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var h=[],f=i.range(a,{lod:!0,px:[(a[2]-a[0])/o.width,(a[3]-a[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(u),g=0;g<r.length;g++){var v=r[g];d[v]=p?p[v]:1}l.subdata(d)}for(var m=f.length;m--;){var y=n(f[m],2),x=y[0],b=y[1];h.push(c({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return h},y.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var a=this.groups,i=this.gl,s=this.regl,u=this.maxSize,d=this.maxColors,m=this.palette;this.groups=a=r.map(function(e,r){var n=a[r];if(void 0===e)return n;null===e?e={positions:null}:"function"==typeof e?e={ondraw:e}:"number"==typeof e[0]&&(e={positions:e}),null===(e=h(e,{positions:"positions data points",snap:"snap cluster lod tree",size:"sizes size radius",borderSize:"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline",color:"colors color fill fill-color fillColor",borderColor:"borderColors borderColor stroke stroke-color strokeColor",marker:"markers marker shape",range:"range dataBox databox",viewport:"viewport viewPort viewBox viewbox",opacity:"opacity alpha transparency",bounds:"bound bounds boundaries limits",tooManyColors:"tooManyColors palette paletteMode optimizePalette enablePalette"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(a[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:s.buffer({data:new Uint8Array(0),usage:"stream",type:"uint8"}),sizeBuffer:s.buffer({data:new Uint8Array(0),usage:"dynamic",type:"uint8"}),colorBuffer:s.buffer({data:new Uint8Array(0),usage:"dynamic",type:"uint8"}),positionBuffer:s.buffer({data:new Uint8Array(0),usage:"dynamic",type:"float"}),positionFractBuffer:s.buffer({data:new Uint8Array(0),usage:"dynamic",type:"float"})},e=c({},y.defaults,e)),!e.positions||"marker"in e||(e.marker=n.marker,delete n.marker),!e.marker||"positions"in e||(e.positions=n.positions,delete n.positions);var x=0,b=0;if(f(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=y.defaults.size),x+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=y.defaults.borderSize),x+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=y.defaults.color),e=t.updateColor(e),b++,e},borderColor:function(e,r){return null==e&&(e=y.defaults.borderColor),e=t.updateColor(e),b++,e},bounds:function(t,e,r){return"range"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,a=e.positionBuffer,i=e.positionFractBuffer,c=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:s.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:s.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=p(t,"float64");var u=e.count=Math.floor(t.length/2),h=e.bounds=u?o(t,2):null;if(r.range||e.range||(delete e.range,r.range=h),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||u>n)?e.tree=l(t,{bounds:h}):n&&n.length&&(e.tree=n),e.tree){var f={primitive:"points",usage:"static",data:e.tree,type:"uint32"};e.elements?e.elements(f):e.elements=s.elements(f)}return a({data:g.float(t),usage:"dynamic"}),i({data:g.fract(t),usage:"dynamic"}),c({data:new Uint8Array(u),type:"uint8",usage:"stream"}),t}},{marker:function(e,r,n){var a=r.activation;if(a.forEach(function(t){return t&&t.destroy&&t.destroy()}),a.length=0,e&&"number"!=typeof e[0]){for(var i=[],o=0,l=Math.min(e.length,r.count);o<l;o++){var c=t.addMarker(e[o]);i[c]||(i[c]=new Uint8Array(r.count)),i[c][o]=1}for(var u=0;u<i.length;u++)if(i[u]){var h={data:i[u],type:"uint8",usage:"static"};a[u]?a[u](h):a[u]=s.buffer(h),a[u].data=i[u]}}else{a[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=g.fract(e.scale),e.translateFract=g.fract(e.translate),t},viewport:function(t){return v(t||[i.drawingBufferWidth,i.drawingBufferHeight])}}]),x){var _=n,w=_.count,k=_.size,T=_.borderSize,M=_.sizeBuffer,A=new Uint8Array(2*w);if(k.length||T.length)for(var S=0;S<w;S++)A[2*S]=Math.round(255*(null==k[S]?k:k[S])/u),A[2*S+1]=Math.round(255*(null==T[S]?T:T[S])/u);M({data:A,usage:"dynamic"})}if(b){var E,L=n,C=L.count,P=L.color,O=L.borderColor,z=L.colorBuffer;if(t.tooManyColors){if(P.length||O.length){E=new Uint8Array(8*C);for(var I=0;I<C;I++){var D=P[I];E[8*I]=m[4*D],E[8*I+1]=m[4*D+1],E[8*I+2]=m[4*D+2],E[8*I+3]=m[4*D+3];var R=O[I];E[8*I+4]=m[4*R],E[8*I+5]=m[4*R+1],E[8*I+6]=m[4*R+2],E[8*I+7]=m[4*R+3]}}}else if(P.length||O.length){E=new Uint8Array(4*C+2);for(var F=0;F<C;F++)null!=P[F]&&(E[4*F]=P[F]%d,E[4*F+1]=Math.floor(P[F]/d)),null!=O[F]&&(E[4*F+2]=O[F]%d,E[4*F+3]=Math.floor(O[F]/d))}z({data:E||new Uint8Array(0),type:"uint8",usage:"dynamic"})}return n})}},y.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,a=this.markerCache,i=null==t?0:a.indexOf(t);if(i>=0)return i;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return i=r.length,a.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:"linear",min:"linear"})),i},y.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var a=[];if("number"==typeof t[0]){var o=[];if(Array.isArray(t))for(var l=0;l<t.length;l+=4)o.push(t.slice(l,l+4));else for(var c=0;c<t.length;c+=4)o.push(t.subarray(c,c+4));t=o}for(var u=0;u<t.length;u++){var h=t[u];h=i(h,"uint8");var f=s(h,!1);if(null==e[f]){var p=r.length;e[f]=Math.floor(p/4),r[p]=h[0],r[p+1]=h[1],r[p+2]=h[2],r[p+3]=h[3]}a[u]=e[f]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===a.length?a[0]:a},y.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var a=.25*(t=t.slice()).length%e;a<n*e;a++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},y.prototype.destroy=function(){return this.groups.forEach(function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach(function(t){return t&&t.destroy&&t.destroy()}),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()}),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach(function(t){return t&&t.destroy&&t.destroy()}),this};var x=t("object-assign");e.exports=function(t,e){var r=new m(t,e),n=r.render.bind(r);return x(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{"array-bounds":68,"color-id":120,"color-normalize":122,"flatten-vertex-data":230,glslify:410,"is-iexplorer":420,"object-assign":455,"parse-rect":460,"pick-by-alias":466,"point-cluster":470,"to-float32":536,"update-diff":547}],499:[function(t,e,r){"use strict";var n=t("regl-scatter2d"),a=t("pick-by-alias"),i=t("array-bounds"),o=t("raf"),s=t("array-range"),l=t("parse-rect"),c=t("flatten-vertex-data");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function h(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function f(t,e,r){var n,a,i,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],a=s[3]):s.length?(n=s[0],a=s[1]):(s.x,n=s.y,s.x+s.width,a=s.y+s.height),l.length>2?(i=l[0],o=l[2],l[1],l[3]):l.length?(i=l[0],o=l[1]):(i=l.x,l.y,o=l.x+l.width,l.y+l.height),[i,n,o,a]}function p(t){if("number"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o(function(){e.draw(),e.dirty=!0,e.planned=null})):(this.draw(),this.dirty=!0,o(function(){e.dirty=!1})),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var a=[],i=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)a.push(this.passes[l[c]]);s.passOffset=i,i+=s.passes.length}return(t=this.scatter).update.apply(t,a),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=a(e,{data:"data items columns rows values dimensions samples x",snap:"snap cluster",size:"sizes size radius",color:"colors color fill fill-color fillColor",opacity:"opacity alpha transparency opaque",borderSize:"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline",borderColor:"borderColors borderColor bordercolor stroke stroke-color strokeColor",marker:"markers marker shape",range:"range ranges databox dataBox",viewport:"viewport viewBox viewbox",domain:"domain domains area areas",padding:"pad padding paddings pads margin margins",transpose:"transpose transposed",diagonal:"diagonal diag showDiagonal",upper:"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf",lower:"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:"dynamic",type:"float",data:new Uint8Array}),color:"black",marker:null,size:12,borderColor:"transparent",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=i(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&"number"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&"number"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var g=s.columns,v=s.count,m=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=m/g,w=y/g;s.passes=[];for(var k=0;k<g;k++)for(var T=0;T<g;T++)if((s.diagonal||T!==k)&&(s.upper||!(k>T))&&(s.lower||!(k<T))){var M=h(s.id,k,T),A=this.passes[M]||(this.passes[M]={});if(o.data&&(o.transpose?A.positions={x:{buffer:s.buffer,offset:T,count:v,stride:g},y:{buffer:s.buffer,offset:k,count:v,stride:g}}:A.positions={x:{buffer:s.buffer,offset:T*v,count:v},y:{buffer:s.buffer,offset:k*v,count:v}},A.bounds=f(s.bounds,k,T)),o.domain||o.viewport||o.data){var S=d?f(s.padding,k,T):s.padding;if(s.domain){var E=f(s.domain,k,T),L=E[0],C=E[1],P=E[2],O=E[3];A.viewport=[x+L*m+S[0],b+C*y+S[1],x+P*m-S[2],b+O*y-S[3]]}else A.viewport=[x+T*_+_*S[0],b+k*w+w*S[1],x+(T+1)*_-_*S[2],b+(k+1)*w-w*S[3]]}o.color&&(A.color=s.color),o.size&&(A.size=s.size),o.marker&&(A.marker=s.marker),o.borderSize&&(A.borderSize=s.borderSize),o.borderColor&&(A.borderColor=s.borderColor),o.opacity&&(A.opacity=s.opacity),o.range&&(A.range=n?f(s.range,k,T):s.range||A.bounds),s.passes.push(M)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],a=0;a<e.length;a++)if("number"==typeof e[a]){var i=this.traces[e[a]],o=i.passes,l=i.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[a].length){var c=e[a],u=this.traces[a],h=u.passes,f=u.passOffset;h=h.map(function(t,e){n[f+e]=c})}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach(function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()}),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{"array-bounds":68,"array-range":69,"flatten-vertex-data":230,"parse-rect":460,"pick-by-alias":466,raf:485,"regl-scatter2d":498}],500:[function(t,e,r){var n,a;n=this,a=function(){function t(t,e){this.id=V++,this.type=t,this.data=e}function e(t){return"["+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('"'===r||"'"===r))return['"'+e.substr(1,e.length-2).replace(/\\/g,"\\\\").replace(/"/g,'\\"')+'"'];if(r=/\[(false|true|null|\d+|'[^']*'|"[^"]*")\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(".")).length)return['"'+e.replace(/\\/g,"\\\\").replace(/"/g,'\\"')+'"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join("][")+"]"}function r(t){return"string"==typeof t?t.split():t}function n(t){return"string"==typeof t?document.querySelector(t):t}function a(t){var e,a,i,o,s=t||{};t={};var l=[],c=[],u="undefined"==typeof window?1:window.devicePixelRatio,h=!1,f=function(t){},p=function(){};if("string"==typeof s?e=document.querySelector(s):"object"==typeof s&&("string"==typeof s.nodeName&&"function"==typeof s.appendChild&&"function"==typeof s.getBoundingClientRect?e=s:"function"==typeof s.drawArrays||"function"==typeof s.drawElements?i=(o=s).canvas:("gl"in s?o=s.gl:"canvas"in s?i=n(s.canvas):"container"in s&&(a=n(s.container)),"attributes"in s&&(t=s.attributes),"extensions"in s&&(l=r(s.extensions)),"optionalExtensions"in s&&(c=r(s.optionalExtensions)),"onDone"in s&&(f=s.onDone),"profile"in s&&(h=!!s.profile),"pixelRatio"in s&&(u=+s.pixelRatio))),e&&("canvas"===e.nodeName.toLowerCase()?i=e:a=e),!o){if(!i){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),a.width=r*e,a.height=r*n,j(a.style,{width:e+"px",height:n+"px"})}var a=document.createElement("canvas");return j(a.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(a),t===document.body&&(a.style.position="absolute",j(t.style,{margin:0,padding:0})),window.addEventListener("resize",n,!1),n(),{canvas:a,onDestroy:function(){window.removeEventListener("resize",n),t.removeChild(a)}}}(a||document.body,0,u)))return null;i=e.canvas,p=e.onDestroy}o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r("webgl")||r("experimental-webgl")||r("webgl-experimental")}(i,t)}return o?{gl:o,canvas:i,container:a,extensions:l,optionalExtensions:c,pixelRatio:u,profile:h,onDone:f,onDestroy:p}:(p(),f("webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org"),null)}function i(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=i(8,function(){return[]});return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&"object"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&"number"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||W(t.data))}function c(t,e,r,n,a,i){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)a[i++]=c[u]}function u(t){return 0|J[Object.prototype.toString.call(t)]}function h(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function f(t,e,r,n,a,i,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[a*l+i*c+o]}function p(t,e,r,n){function a(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function i(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,a,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){a=tt(e);for(var s=n=1;s<a.length;++s)n*=a[s];t.dimension=n,i(t,e=$(e,a,t.dtype),r),o?t.persistentData=e:G.freeType(e)}else"number"==typeof e[0]?(t.dimension=a,h(a=G.allocType(t.dtype,e.length),e),i(t,a,r),o?t.persistentData=a:G.freeType(a)):W(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,i(t,e=$(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:G.freeType(e))}else if(W(e))t.dtype=n||u(e),t.dimension=a,i(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){a=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,g=0,v=0;1===a.length?(p=a[0],d=1,g=c[0],v=0):2===a.length&&(p=a[0],d=a[1],g=c[0],v=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,f(a=G.allocType(t.dtype,p*d),e.data,p,d,g,v,s),i(t,a,r),o?t.persistentData=a:G.freeType(a)}}function s(r){e.bufferCount--;for(var a=0;a<n.state.length;++a){var i=n.state[a];i.buffer===r&&(t.disableVertexAttribArray(a),i.buffer=null)}t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};a.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},a.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach(function(e){t+=p[e].stats.size}),t}),{create:function(n,i,c,d){function g(e){var n=35044,a=null,i=0,s=0,c=1;return Array.isArray(e)||W(e)||l(e)?a=e:"number"==typeof e?i=0|e:e&&("data"in e&&(a=e.data),"usage"in e&&(n=Q[e.usage]),"type"in e&&(s=K[e.type]),"dimension"in e&&(c=0|e.dimension),"length"in e&&(i=0|e.length)),v.bind(),a?o(v,a,n,s,c,d):(i&&t.bufferData(v.type,i,n),v.dtype=s||5121,v.usage=n,v.dimension=c,v.byteLength=i),r.profile&&(v.stats.size=v.byteLength*et[v.dtype]),g}e.bufferCount++;var v=new a(i);return p[v.id]=v,c||g(n),g._reglType="buffer",g._buffer=v,g.subdata=function(e,r){var n,a=0|(r||0);if(v.bind(),W(e))t.bufferSubData(v.type,a,e);else if(Array.isArray(e)){if(0<e.length)if("number"==typeof e[0]){var i=G.allocType(v.dtype,e.length);h(i,e),t.bufferSubData(v.type,a,i),G.freeType(i)}else(Array.isArray(e[0])||W(e[0]))&&(n=tt(e),i=$(e,n,v.dtype),t.bufferSubData(v.type,a,i),G.freeType(i))}else if(l(e)){n=e.shape;var o=e.stride,s=i=0,c=0,p=0;1===n.length?(i=n[0],s=1,c=o[0],p=0):2===n.length&&(i=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?v.dtype:u(e.data),f(n=G.allocType(n,i*s),e.data,i,s,c,p,e.offset),t.bufferSubData(v.type,a,n),G.freeType(n)}return g},r.profile&&(g.stats=v.stats),g.destroy=function(){s(v)},g},createStream:function(t,e){var r=d.pop();return r||(r=new a(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){X(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof a?t._buffer:null},restore:function(){X(p).forEach(function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)})},_initBuffer:o}}function d(t,e,r,n){function a(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function i(n,a,i,o,s,c,u){if(n.buffer.bind(),a){var h=u;u||W(a)&&(!l(a)||W(a.data))||(h=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,a,i,h,3)}else t.bufferData(34963,c,i),n.buffer.dtype=h||5121,n.buffer.usage=i,n.buffer.dimension=3,n.buffer.byteLength=c;if(h=u,!u){switch(n.buffer.dtype){case 5121:case 5120:h=5121;break;case 5123:case 5122:h=5123;break;case 5125:case 5124:h=5125}n.buffer.dtype=h}n.type=h,0>(a=s)&&(a=n.buffer.byteLength,5123===h?a>>=1:5125===h&&(a>>=2)),n.vertCount=a,a=o,0>o&&(a=4,1===(o=n.buffer.dimension)&&(a=0),2===o&&(a=1),3===o&&(a=4)),n.primType=a}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),a.prototype.bind=function(){this.buffer.bind()};var h=[];return{create:function(t,e){function s(t){if(t)if("number"==typeof t)c(t),h.primType=4,h.vertCount=0|t,h.type=5121;else{var e=null,r=35044,n=-1,a=-1,o=0,f=0;Array.isArray(t)||W(t)||l(t)?e=t:("data"in t&&(e=t.data),"usage"in t&&(r=Q[t.usage]),"primitive"in t&&(n=rt[t.primitive]),"count"in t&&(a=0|t.count),"type"in t&&(f=u[t.type]),"length"in t?o=0|t.length:(o=a,5123===f||5122===f?o*=2:5125!==f&&5124!==f||(o*=4))),i(h,e,r,n,a,o,f)}else c(),h.primType=4,h.vertCount=0,h.type=5121;return s}var c=r.create(null,34963,!0),h=new a(c._buffer);return n.elementsCount++,s(t),s._reglType="elements",s._elements=h,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(h)},s},createStream:function(t){var e=h.pop();return e||(e=new a(r.create(null,34963,!0,!1)._buffer)),i(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){h.push(t)},getElements:function(t){return"function"==typeof t&&t._elements instanceof a?t._elements:null},clear:function(){X(s).forEach(o)}}}function g(t){for(var e=G.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{nt[0]=t[r];var n=(i=at[0])>>>31<<15,a=(i<<1>>>24)-127,i=i>>13&1023;e[r]=-24>a?n:-14>a?n+(i+1024>>-14-a):15<a?n+31744:n+(a+15<<10)+i}return e}function v(t){return Array.isArray(t)||W(t)}function m(t){return"[object "+t+"]"}function y(t){return Array.isArray(t)&&(0===t.length||"number"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!v(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=pt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=g(e),G.freeType(e)):t.data=e}function k(t,e,r,n,a,i){if(t="undefined"!=typeof gt[t]?gt[t]:st[t]*dt[e],i&&(t*=6),a){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function T(t,e,r,n,a,i,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if("object"==typeof e&&e){"premultiplyAlpha"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),"flipY"in e&&(t.flipY=e.flipY),"alignment"in e&&(t.unpackAlignment=e.alignment),"colorSpace"in e&&(t.colorSpace=q[e.colorSpace]),"type"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,a=t.channels,i=!1;"shape"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(a=e.shape[2],i=!0)):("radius"in e&&(r=n=e.radius),"width"in e&&(r=e.width),"height"in e&&(n=e.height),"channels"in e&&(a=e.channels,i=!0)),t.width=0|r,t.height=0|n,t.channels=0|a,r=!1,"format"in e&&(r=e.format,n=t.internalformat=Y[r],t.format=pt[n],r in H&&!("type"in e)&&(t.type=H[r]),r in K&&(t.compressed=!0),r=!0),!i&&r?t.channels=st[t.format]:i&&!r&&t.channels!==ot[t.format]&&(t.format=t.internalformat=ot[t.channels])}}function h(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function f(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),"x"in e&&(t.xOffset=0|e.x),"y"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=a.viewportWidth,i=a.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||i-t.yOffset,t.needsCopy=!0}else if(r){if(W(r))t.channels=t.channels||4,t.data=r,"type"in e||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,i=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(i=G.allocType(t.type,i)).set(n),t.data=i;break;case 36193:t.data=g(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(n)]);i=r.shape;var o,s,c,h,f=r.stride;3===i.length?(c=i[2],h=f[2]):h=c=1,o=i[0],s=i[1],i=f[0],f=f[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=ot[c],t.needsFree=!0,o=h,r=r.offset,c=t.width,h=t.height,s=t.channels;for(var p=G.allocType(36193===t.type?5126:t.type,c*h*s),d=0,m=0;m<h;++m)for(var k=0;k<c;++k)for(var T=0;T<s;++T)p[d++]=n[i*k+f*m+o*T+r];w(t,p)}else if(b(r)===lt||b(r)===ct)b(r)===lt?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ut)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===ht)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===ft)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,i=t.height||r.length,f=t.channels,f=v(r[0][0])?f||r[0][0].length:f||1,o=Z.shape(r),c=1,h=0;h<o.length;++h)c*=o[h];c=G.allocType(36193===t.type?5126:t.type,c),Z.flatten(r,o,"",c),w(t,c),t.alignment=1,t.width=n,t.height=i,t.channels=f,t.format=t.internalformat=ot[f],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,a,i,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,f=e.type,p=e.width,d=e.height;h(e),s?t.texSubImage2D(r,o,a,i,u,f,s):e.compressed?t.compressedTexSubImage2D(r,o,a,i,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,a,i,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,a,i,p,d,u,f,l)}function m(){return dt.pop()||new f}function T(t){t.needsFree&&G.freeType(t.data),f.call(t),dt.push(t)}function M(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function A(t,e,r){var n=t.images[0]=m();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,a=0;a<n.length;++a)c(r=t.images[a]=m(),t),r.width>>=a,r.height>>=a,p(r,n[a]),t.mipmask|=1<<a;else c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function E(e,r){for(var a=e.images,i=0;i<a.length&&a[i];++i){var o=a[i],s=r,l=i,c=o.element,u=o.data,f=o.internalformat,p=o.format,d=o.type,g=o.width,v=o.height,m=o.channels;h(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,f,g,v,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,g,v,0)):((o=!u)&&(u=G.zero.allocType(d,g*v*m)),t.texImage2D(s,l,p,g,v,0,p,d,u),o&&u&&G.zero.freeType(u))}}function L(){var t=gt.pop()||new M;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function C(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&T(e[r]),e[r]=null;gt.push(t)}function P(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function O(t,e){"min"in e&&(t.minFilter=U[e.min],0<=it.indexOf(t.minFilter)&&!("faces"in e)&&(t.genMipmaps=!0)),"mag"in e&&(t.magFilter=V[e.mag]);var r=t.wrapS,n=t.wrapT;if("wrap"in e){var a=e.wrap;"string"==typeof a?r=n=N[a]:Array.isArray(a)&&(r=N[a[0]],n=N[a[1]])}else"wrapS"in e&&(r=N[e.wrapS]),"wrapT"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,"anisotropic"in e&&(t.anisotropic=e.anisotropic),"mipmap"in e){switch(r=!1,typeof e.mipmap){case"string":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case"boolean":r=t.genMipmaps=e.mipmap;break;case"object":t.genMipmaps=!1,r=!0}!r||"min"in e||(t.minFilter=9984)}}function z(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function I(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new P,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=xt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,a=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(a,null),xt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete mt[e.id],i.textureCount--}var B={"don't care":4352,"dont care":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},V={nearest:9728,linear:9729},U=j({mipmap:9987,"nearest mipmap nearest":9984,"linear mipmap nearest":9985,"nearest mipmap linear":9986,"linear mipmap linear":9987},V),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,"rgb5 a1":32820},Y={alpha:6406,luminance:6409,"luminance alpha":6410,rgb:6407,rgba:6408,rgba4:32854,"rgb5 a1":32855,rgb565:36194},K={};e.ext_srgb&&(Y.srgb=35904,Y.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H["half float"]=36193),e.webgl_depth_texture&&(j(Y,{depth:6402,"depth stencil":34041}),j(H,{uint16:5123,uint32:5125,"depth stencil":34042})),e.webgl_compressed_texture_s3tc&&j(K,{"rgb s3tc dxt1":33776,"rgba s3tc dxt1":33777,"rgba s3tc dxt3":33778,"rgba s3tc dxt5":33779}),e.webgl_compressed_texture_atc&&j(K,{"rgb atc":35986,"rgba atc explicit alpha":35987,"rgba atc interpolated alpha":34798}),e.webgl_compressed_texture_pvrtc&&j(K,{"rgb pvrtc 4bppv1":35840,"rgb pvrtc 2bppv1":35841,"rgba pvrtc 4bppv1":35842,"rgba pvrtc 2bppv1":35843}),e.webgl_compressed_texture_etc1&&(K["rgb etc1"]=36196);var Q=Array.prototype.slice.call(t.getParameter(34467));Object.keys(K).forEach(function(t){var e=K[t];0<=Q.indexOf(e)&&(Y[t]=e)});var $=Object.keys(Y);r.textureFormats=$;var tt=[];Object.keys(Y).forEach(function(t){tt[Y[t]]=t});var et=[];Object.keys(H).forEach(function(t){et[H[t]]=t});var rt=[];Object.keys(V).forEach(function(t){rt[V[t]]=t});var nt=[];Object.keys(U).forEach(function(t){nt[U[t]]=t});var at=[];Object.keys(N).forEach(function(t){at[N[t]]=t});var pt=$.reduce(function(t,e){var r=Y[e];return 6409===r||6406===r||6409===r||6410===r||6402===r||34041===r?t[r]=r:32855===r||0<=e.indexOf("rgba")?t[r]=6408:t[r]=6407,t},{}),dt=[],gt=[],vt=0,mt={},yt=r.maxTextureUnits,xt=Array(yt).map(function(){return null});return j(I.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<yt;++r){var n=xt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}xt[r]=this,e=r;break}o.profile&&i.maxTextureUnits<e+1&&(i.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(i.getTotalTextureSize=function(){var t=0;return Object.keys(mt).forEach(function(e){t+=mt[e].stats.size}),t}),{create2D:function(e,r){function n(t,e){var r=a.texInfo;P.call(r);var i=L();return"number"==typeof t?A(i,0|t,"number"==typeof e?0|e:0|t):t?(O(r,t),S(i,t)):A(i,1,1),r.genMipmaps&&(i.mipmask=(i.width<<1)-1),a.mipmask=i.mipmask,c(a,i),a.internalformat=i.internalformat,n.width=i.width,n.height=i.height,D(a),E(i,3553),z(r,3553),R(),C(i),o.profile&&(a.stats.size=k(a.internalformat,a.type,i.width,i.height,r.genMipmaps,!1)),n.format=tt[a.internalformat],n.type=et[a.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=at[r.wrapS],n.wrapT=at[r.wrapT],n}var a=new I(3553);return mt[a.id]=a,i.textureCount++,n(e,r),n.subimage=function(t,e,r,i){e|=0,r|=0,i|=0;var o=m();return c(o,a),o.width=0,o.height=0,p(o,t),o.width=o.width||(a.width>>i)-e,o.height=o.height||(a.height>>i)-r,D(a),d(o,3553,e,r,i),R(),T(o),n},n.resize=function(e,r){var i=0|e,s=0|r||i;if(i===a.width&&s===a.height)return n;n.width=a.width=i,n.height=a.height=s,D(a);for(var l,c=a.channels,u=a.type,h=0;a.mipmask>>h;++h){var f=i>>h,p=s>>h;if(!f||!p)break;l=G.zero.allocType(u,f*p*c),t.texImage2D(3553,h,a.format,f,p,0,a.format,a.type,l),l&&G.zero.freeType(l)}return R(),o.profile&&(a.stats.size=k(a.internalformat,a.type,i,s,!1,!1)),n},n._reglType="texture2d",n._texture=a,o.profile&&(n.stats=a.stats),n.destroy=function(){a.decRef()},n},createCube:function(e,r,n,a,s,l){function h(t,e,r,n,a,i){var s,l=f.texInfo;for(P.call(l),s=0;6>s;++s)g[s]=L();if("number"!=typeof t&&t){if("object"==typeof t)if(e)S(g[0],t),S(g[1],e),S(g[2],r),S(g[3],n),S(g[4],a),S(g[5],i);else if(O(l,t),u(f,t),"faces"in t)for(t=t.faces,s=0;6>s;++s)c(g[s],f),S(g[s],t[s]);else for(s=0;6>s;++s)S(g[s],t)}else for(t=0|t||1,s=0;6>s;++s)A(g[s],t,t);for(c(f,g[0]),f.mipmask=l.genMipmaps?(g[0].width<<1)-1:g[0].mipmask,f.internalformat=g[0].internalformat,h.width=g[0].width,h.height=g[0].height,D(f),s=0;6>s;++s)E(g[s],34069+s);for(z(l,34067),R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,l.genMipmaps,!0)),h.format=tt[f.internalformat],h.type=et[f.type],h.mag=rt[l.magFilter],h.min=nt[l.minFilter],h.wrapS=at[l.wrapS],h.wrapT=at[l.wrapT],s=0;6>s;++s)C(g[s]);return h}var f=new I(34067);mt[f.id]=f,i.cubeCount++;var g=Array(6);return h(e,r,n,a,s,l),h.subimage=function(t,e,r,n,a){r|=0,n|=0,a|=0;var i=m();return c(i,f),i.width=0,i.height=0,p(i,e),i.width=i.width||(f.width>>a)-r,i.height=i.height||(f.height>>a)-n,D(f),d(i,34069+t,r,n,a),R(),T(i),h},h.resize=function(e){if((e|=0)!==f.width){h.width=f.width=e,h.height=f.height=e,D(f);for(var r=0;6>r;++r)for(var n=0;f.mipmask>>n;++n)t.texImage2D(34069+r,n,f.format,e>>n,e>>n,0,f.format,f.type,null);return R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,!1,!0)),h}},h._reglType="textureCube",h._texture=f,o.profile&&(h.stats=f.stats),h.destroy=function(){f.decRef()},h},clear:function(){for(var e=0;e<yt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),xt[e]=null;X(mt).forEach(F),i.cubeCount=0,i.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<yt;++e){var r=xt[e];r&&(r.bindCount=0,r.unit=-1,xt[e]=null)}X(mt).forEach(function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);z(e.texInfo,e.target)})}}}function M(t,e,r,n,a,i){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,a=t;return"object"==typeof t&&(a=t.data,"target"in t&&(e=0|t.target)),"texture2d"===(t=a._reglType)?r=a:"textureCube"===t?r=a:"renderbuffer"===t&&(n=a,e=36161),new o(e,r,n)}function h(t,e,r,i,s){return r?((t=n.create2D({width:t,height:e,format:i,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=a.create({width:t,height:e,format:i}))._renderbuffer.refCount=0,new o(36161,null,t))}function f(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=k++,T[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function g(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function v(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,i.framebufferCount--,delete T[e.id]}function m(e){var n;t.bindFramebuffer(36160,e.framebuffer);var a=e.colorAttachments;for(n=0;n<a.length;++n)c(36064+n,a[n]);for(n=a.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var a,i=0,o=0,s=!0,c=!0;a=null;var p=!0,d="rgba",v="uint8",y=1,x=null,w=null,k=null,T=!1;"number"==typeof t?(i=0|t,o=0|e||i):t?("shape"in t?(i=(o=t.shape)[0],o=o[1]):("radius"in t&&(i=o=t.radius),"width"in t&&(i=t.width),"height"in t&&(o=t.height)),("color"in t||"colors"in t)&&(a=t.color||t.colors,Array.isArray(a)),a||("colorCount"in t&&(y=0|t.colorCount),"colorTexture"in t&&(p=!!t.colorTexture,d="rgba4"),"colorType"in t&&(v=t.colorType,!p)&&("half float"===v||"float16"===v?d="rgba16f":"float"!==v&&"float32"!==v||(d="rgba32f")),"colorFormat"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),("depthTexture"in t||"depthStencilTexture"in t)&&(T=!(!t.depthTexture&&!t.depthStencilTexture)),"depth"in t&&("boolean"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),"stencil"in t&&("boolean"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),"depthStencil"in t&&("boolean"==typeof t.depthStencil?s=c=t.depthStencil:(k=t.depthStencil,c=s=!1))):i=o=1;var M=null,A=null,S=null,E=null;if(Array.isArray(a))M=a.map(u);else if(a)M=[u(a)];else for(M=Array(y),a=0;a<y;++a)M[a]=h(i,o,p,d,v);for(i=i||M[0].width,o=o||M[0].height,x?A=u(x):s&&!c&&(A=h(i,o,T,"depth","uint32")),w?S=u(w):c&&!s&&(S=h(i,o,!1,"stencil","uint8")),k?E=u(k):!x&&!w&&c&&s&&(E=h(i,o,T,"depth stencil","depth stencil")),s=null,a=0;a<M.length;++a)l(M[a]),M[a]&&M[a].texture&&(c=yt[M[a].texture._texture.format]*xt[M[a].texture._texture.type],null===s&&(s=c));return l(A),l(S),l(E),g(n),n.width=i,n.height=o,n.colorAttachments=M,n.depthAttachment=A,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=M.map(f),r.depth=f(A),r.stencil=f(S),r.depthStencil=f(E),r.width=n.width,r.height=n.height,m(n),r}var n=new d;return i.framebufferCount++,r(t,e),j(r,{resize:function(t,e){var a=Math.max(0|t,1),i=Math.max(0|e||a,1);if(a===n.width&&i===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],a,i);return p(n.depthAttachment,a,i),p(n.stencilAttachment,a,i),p(n.depthStencilAttachment,a,i),n.width=r.width=a,n.height=r.height=i,m(n),r},_reglType:"framebuffer",_framebuffer:n,destroy:function(){v(n),g(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=["rgba"],_=["rgba4","rgb565","rgb5 a1"];e.ext_srgb&&_.push("srgba"),e.ext_color_buffer_half_float&&_.push("rgba16f","rgb16f"),e.webgl_color_buffer_float&&_.push("rgba32f");var w=["uint8"];e.oes_texture_half_float&&w.push("half float","float16"),e.oes_texture_float&&w.push("float","float32");var k=0,T={};return j(x,{getFramebuffer:function(t){return"function"==typeof t&&"framebuffer"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var a,i={color:null},o=0,s=null;a="rgba";var l="uint8",c=1;if("number"==typeof t?o=0|t:t?("shape"in t?o=t.shape[0]:("radius"in t&&(o=0|t.radius),"width"in t?o=0|t.width:"height"in t&&(o=0|t.height)),("color"in t||"colors"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||("colorCount"in t&&(c=0|t.colorCount),"colorType"in t&&(l=t.colorType),"colorFormat"in t&&(a=t.colorFormat)),"depth"in t&&(i.depth=t.depth),"stencil"in t&&(i.stencil=t.stencil),"depthStencil"in t&&(i.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],a=0;a<s.length;++a)t[a]=s[a];else t=[s];else for(t=Array(c),s={radius:o,format:a,type:l},a=0;a<c;++a)t[a]=n.createCube(s);for(i.color=Array(t.length),a=0;a<t.length;++a)c=t[a],o=o||c.width,i.color[a]={target:34069,data:t[a]};for(a=0;6>a;++a){for(c=0;c<t.length;++c)i.color[c].target=34069+a;0<a&&(i.depth=r[0].depth,i.stencil=r[0].stencil,i.depthStencil=r[0].depthStencil),r[a]?r[a](i):r[a]=y(i)}return j(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),j(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var a=e.color;for(t=0;t<a.length;++t)a[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:"framebufferCube",destroy:function(){r.forEach(function(t){t.destroy()})}})},clear:function(){X(T).forEach(v)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,X(T).forEach(function(e){e.framebuffer=t.createFramebuffer(),m(e)})}})}function A(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n){function a(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function i(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,a){if(!(o=(a=35632===r?c:u)[n])){var i=e.str(n),o=t.createShader(r);t.shaderSource(o,i),t.compileShader(o),a[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s){var l,c;l=o(35632,r.fragId),c=o(35633,r.vertId);var u=r.program=t.createProgram();t.attachShader(u,l),t.attachShader(u,c),t.linkProgram(u);var h=t.getProgramParameter(u,35718);n.profile&&(r.stats.uniformsCount=h);var f=r.uniforms;for(l=0;l<h;++l)if(c=t.getActiveUniform(u,l))if(1<c.size)for(var p=0;p<c.size;++p){var d=c.name.replace("[0]","["+p+"]");i(f,new a(d,e.id(d),t.getUniformLocation(u,d),c))}else i(f,new a(c.name,e.id(c.name),t.getUniformLocation(u,c.name),c));for(h=t.getProgramParameter(u,35721),n.profile&&(r.stats.attributesCount=h),f=r.attributes,l=0;l<h;++l)(c=t.getActiveAttrib(u,l))&&i(f,new a(c.name,e.id(c.name),t.getAttribLocation(u,c.name),c))}var c={},u={},h={},f=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return f.forEach(function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)}),t},r.getMaxAttributesCount=function(){var t=0;return f.forEach(function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)}),t}),{clear:function(){var e=t.deleteShader.bind(t);X(c).forEach(e),c={},X(u).forEach(e),u={},f.forEach(function(e){t.deleteProgram(e.program)}),f.length=0,h={},r.shaderCount=0},program:function(t,e,n){var a=h[e];a||(a=h[e]={});var i=a[t];return i||(i=new s(e,t),r.shaderCount++,l(i),a[t]=i,f.push(i)),i},restore:function(){c={},u={};for(var t=0;t<f.length;++t)l(f[t])},shader:o,frag:-1,vert:-1}}function E(t,e,r,n,a,i,o){function s(a){var i;i=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return W(a)?u=a:a&&(o=0|a.x,s=0|a.y,l=0|(a.width||n.framebufferWidth-o),c=0|(a.height||n.framebufferHeight-s),u=a.data||null),r(),a=l*c*4,u||(5121===i?u=new Uint8Array(a):5126===i&&(u=u||new Float32Array(a))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,i,u),u}return function(t){return t&&"framebuffer"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},function(){r=s(t)}),r}(t):s(t)}}function L(t){return Array.prototype.slice.call(t)}function C(t){return L(t).join("")}function P(){function t(){var t=[],e=[];return j(function(){t.push.apply(t,L(arguments))},{def:function(){var n="v"+r++;return e.push(n),0<arguments.length&&(t.push(n,"="),t.push.apply(t,L(arguments)),t.push(";")),n},toString:function(){return C([0<e.length?"var "+e+";":"",C(t)])}})}function e(){function e(t,e){n(t,e,"=",r.def(t,e),";")}var r=t(),n=t(),a=r.toString,i=n.toString;return j(function(){r.apply(r,L(arguments))},{def:r.def,entry:r,exit:n,save:e,set:function(t,n,a){e(t,n),r(t,n,"=",a,";")},toString:function(){return a()+i()}})}var r=0,n=[],a=[],i=t(),o={};return{global:i,link:function(t){for(var e=0;e<a.length;++e)if(a[e]===t)return n[e];return e="g"+r++,n.push(e),a.push(t),e},block:t,proc:function(t,r){function n(){var t="a"+a.length;return a.push(t),t}var a=[];r=r||0;for(var i=0;i<r;++i)n();var s=(i=e()).toString;return o[t]=j(i,{arg:n,toString:function(){return C(["function(",a.join(),"){",s(),"}"])}})},scope:e,cond:function(){var t=C(arguments),r=e(),n=e(),a=r.toString,i=n.toString;return j(r,{then:function(){return r.apply(r,L(arguments)),this},else:function(){return n.apply(n,L(arguments)),this},toString:function(){var e=i();return e&&(e="else{"+e+"}"),C(["if(",t,"){",a(),"}",e])}})},compile:function(){var t=['"use strict";',i,"return {"];Object.keys(o).forEach(function(e){t.push('"',e,'":',o[e].toString(),",")}),t.push("}");var e=C(t).replace(/;/g,";\n").replace(/}/g,"}\n").replace(/{/g,"{\n");return Function.apply(null,n.concat(e)).apply(null,a)}}}function O(t){return Array.isArray(t)||W(t)||l(t)}function z(t){return t.sort(function(t,e){return"viewport"===t?-1:"viewport"===e?1:t<e?-1:1})}function I(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function D(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function R(t){return new I(!1,!1,!1,t)}function F(t,e){var r=t.type;return 0===r?new I(!0,1<=(r=t.data.length),2<=r,e):4===r?new I((r=t.data).thisDep,r.contextDep,r.propDep,e):new I(3===r,2===r,1===r,e)}function B(t,e,r,n,a,o,s,l,c,u,h,f,p,d,g){function m(t){return t.replace(".","_")}function y(t,e,r){var n=m(t);nt.push(t),et[n]=tt[n]=!!r,at[n]=e}function x(t,e,r){var n=m(t);nt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,it[n]=e}function b(){var t=P(),r=t.link,n=t.global;t.id=lt++,t.batchId="0";var a=r(ot),i=t.shared={props:"a0"};Object.keys(ot).forEach(function(t){i[t]=n.def(a,".",t)});var o=t.next={},s=t.current={};Object.keys(it).forEach(function(t){Array.isArray(tt[t])&&(o[t]=n.def(i.next,".",t),s[t]=n.def(i.current,".",t))});var l=t.constants={};Object.keys(st).forEach(function(t){l[t]=n.def(JSON.stringify(st[t]))}),t.invoke=function(e,n){switch(n.type){case 0:var a=["this",i.context,i.props,t.batchId];return e.def(r(n.data),".call(",a.slice(0,Math.max(n.data.length+1,4)),")");case 1:return e.def(i.props,n.data);case 2:return e.def(i.context,n.data);case 3:return e.def("this",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new Z),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if("framebuffer"in r){var a=r.framebuffer;return a?(a=l.getFramebuffer(a),R(function(t,e){var r=t.link(a),n=t.shared;return e.set(n.framebuffer,".next",r),n=n.context,e.set(n,".framebufferWidth",r+".width"),e.set(n,".framebufferHeight",r+".height"),r})):R(function(t,e){var r=t.shared;return e.set(r.framebuffer,".next","null"),r=r.context,e.set(r,".framebufferWidth",r+".drawingBufferWidth"),e.set(r,".framebufferHeight",r+".drawingBufferHeight"),"null"})}if("framebuffer"in n){var i=n.framebuffer;return F(i,function(t,e){var r=t.invoke(e,i),n=t.shared,a=n.framebuffer;r=e.def(a,".getFramebuffer(",r,")");return e.set(a,".next",r),n=n.context,e.set(n,".framebufferWidth",r+"?"+r+".width:"+n+".drawingBufferWidth"),e.set(n,".framebufferHeight",r+"?"+r+".height:"+n+".drawingBufferHeight"),r})}return null}function w(t){function r(t){if(t in n){var r=e.id(n[t]);return(t=R(function(){return r})).id=r,t}if(t in a){var i=a[t];return F(i,function(t,e){var r=t.invoke(e,i);return e.def(t.shared.strings,".id(",r,")")})}return null}var n=t.static,a=t.dynamic,i=r("frag"),o=r("vert"),s=null;return D(i)&&D(o)?(s=h.program(o.id,i.id),t=R(function(t,e){return t.link(s)})):t=new I(i&&i.thisDep||o&&o.thisDep,i&&i.contextDep||o&&o.contextDep,i&&i.propDep||o&&o.propDep,function(t,e){var r,n,a=t.shared.shader;return r=i?i.append(t,e):e.def(a,".","frag"),n=o?o.append(t,e):e.def(a,".","vert"),e.def(a+".program("+n+","+r+")")}),{frag:i,vert:o,progVar:t,program:s}}function k(t,e){function r(t,e){if(t in n){var r=0|n[t];return R(function(t,n){return e&&(t.OFFSET=r),r})}if(t in a){var o=a[t];return F(o,function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n})}return e&&i?R(function(t,e){return t.OFFSET="0",0}):null}var n=t.static,a=t.dynamic,i=function(){if("elements"in n){var t=n.elements;O(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=R(function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null});return e.value=t,e}if("elements"in a){var r=a.elements;return F(r,function(t,e){var n=(a=t.shared).isBufferArgs,a=a.elements,i=t.invoke(e,r),o=e.def("null");n=e.def(n,"(",i,")"),i=t.cond(n).then(o,"=",a,".createStream(",i,");").else(o,"=",a,".getElements(",i,");");return e.entry(i),e.exit(t.cond(n).then(a,".destroyStream(",o,");")),t.ELEMENTS=o})}return null}(),s=r("offset",!0);return{elements:i,primitive:function(){if("primitive"in n){var t=n.primitive;return R(function(e,r){return rt[t]})}if("primitive"in a){var e=a.primitive;return F(e,function(t,r){var n=t.constants.primTypes,a=t.invoke(r,e);return r.def(n,"[",a,"]")})}return i?D(i)?i.value?R(function(t,e){return e.def(t.ELEMENTS,".primType")}):R(function(){return 4}):new I(i.thisDep,i.contextDep,i.propDep,function(t,e){var r=t.ELEMENTS;return e.def(r,"?",r,".primType:",4)}):null}(),count:function(){if("count"in n){var t=0|n.count;return R(function(){return t})}if("count"in a){var e=a.count;return F(e,function(t,r){return t.invoke(r,e)})}return i?D(i)?i?s?new I(s.thisDep,s.contextDep,s.propDep,function(t,e){return e.def(t.ELEMENTS,".vertCount-",t.OFFSET)}):R(function(t,e){return e.def(t.ELEMENTS,".vertCount")}):R(function(){return-1}):new I(i.thisDep||s.thisDep,i.contextDep||s.contextDep,i.propDep||s.propDep,function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,"?",r,".vertCount-",t.OFFSET,":-1"):e.def(r,"?",r,".vertCount:-1")}):null}(),instances:r("instances",!1),offset:s}}function T(t,r){var n=t.static,i=t.dynamic,o={};return Object.keys(n).forEach(function(t){var r=n[t],i=e.id(t),s=new Z;if(O(r))s.state=1,s.buffer=a.getBuffer(a.create(r,34962,!1,!0)),s.type=0;else if(c=a.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if("constant"in r){var l=r.constant;s.buffer="null",s.state=2,"number"==typeof l?s.x=l:bt.forEach(function(t,e){e<l.length&&(s[t]=l[e])})}else{var c=O(r.buffer)?a.getBuffer(a.create(r.buffer,34962,!1,!0)):a.getBuffer(r.buffer),u=0|r.offset,h=0|r.stride,f=0|r.size,p=!!r.normalized,d=0;"type"in r&&(d=K[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=f,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=h,s.divisor=r}o[t]=R(function(t,e){var r=t.attribCache;if(i in r)return r[i];var n={isStream:!1};return Object.keys(s).forEach(function(t){n[t]=s[t]}),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+".dtype"),r[i]=n})}),Object.keys(i).forEach(function(t){var e=i[t];o[t]=F(e,function(t,r){function n(t){r(l[t],"=",a,".",t,"|0;")}var a=t.invoke(r,e),i=t.shared,o=i.isBufferArgs,s=i.buffer,l={isStream:r.def(!1)},c=new Z;c.state=1,Object.keys(c).forEach(function(t){l[t]=r.def(""+c[t])});var u=l.buffer,h=l.type;return r("if(",o,"(",a,")){",l.isStream,"=true;",u,"=",s,".createStream(",34962,",",a,");",h,"=",u,".dtype;","}else{",u,"=",s,".getBuffer(",a,");","if(",u,"){",h,"=",u,".dtype;",'}else if("constant" in ',a,"){",l.state,"=",2,";","if(typeof "+a+'.constant === "number"){',l[bt[0]],"=",a,".constant;",bt.slice(1).map(function(t){return l[t]}).join("="),"=0;","}else{",bt.map(function(t,e){return l[t]+"="+a+".constant.length>"+e+"?"+a+".constant["+e+"]:0;"}).join(""),"}}else{","if(",o,"(",a,".buffer)){",u,"=",s,".createStream(",34962,",",a,".buffer);","}else{",u,"=",s,".getBuffer(",a,".buffer);","}",h,'="type" in ',a,"?",i.glTypes,"[",a,".type]:",u,".dtype;",l.normalized,"=!!",a,".normalized;"),n("size"),n("offset"),n("stride"),n("divisor"),r("}}"),r.exit("if(",l.isStream,"){",s,".destroyStream(",u,");","}"),l})}),o}function M(t,e,r,n,a){var o=_(t),s=function(t,e,r){function n(t){if(t in a){var r=a[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return"width"in r?n=0|r.width:t=!1,"height"in r?o=0|r.height:t=!1,new I(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,function(t,e){var a=t.shared.context,i=n;"width"in r||(i=e.def(a,".","framebufferWidth","-",s));var c=o;return"height"in r||(c=e.def(a,".","framebufferHeight","-",l)),[s,l,i,c]})}if(t in i){var c=i[t];return t=F(c,function(t,e){var r=t.invoke(e,c),n=t.shared.context,a=e.def(r,".x|0"),i=e.def(r,".y|0");return[a,i,e.def('"width" in ',r,"?",r,".width|0:","(",n,".","framebufferWidth","-",a,")"),r=e.def('"height" in ',r,"?",r,".height|0:","(",n,".","framebufferHeight","-",i,")")]}),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new I(e.thisDep,e.contextDep,e.propDep,function(t,e){var r=t.shared.context;return[0,0,e.def(r,".","framebufferWidth"),e.def(r,".","framebufferHeight")]}):null}var a=t.static,i=t.dynamic;if(t=n("viewport")){var o=t;t=new I(t.thisDep,t.contextDep,t.propDep,function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,".viewportWidth",r[2]),e.set(n,".viewportHeight",r[3]),r})}return{viewport:t,scissor_box:n("scissor.box")}}(t,o),l=k(t),c=function(t,e){var r=t.static,n=t.dynamic,a={};return nt.forEach(function(t){function e(e,i){if(t in r){var s=e(r[t]);a[o]=R(function(){return s})}else if(t in n){var l=n[t];a[o]=F(l,function(t,e){return i(t,e,t.invoke(e,l))})}}var o=m(t);switch(t){case"cull.enable":case"blend.enable":case"dither":case"stencil.enable":case"depth.enable":case"scissor.enable":case"polygonOffset.enable":case"sample.alpha":case"sample.enable":case"depth.mask":return e(function(t){return t},function(t,e,r){return r});case"depth.func":return e(function(t){return kt[t]},function(t,e,r){return e.def(t.constants.compareFuncs,"[",r,"]")});case"depth.range":return e(function(t){return t},function(t,e,r){return[e.def("+",r,"[0]"),e=e.def("+",r,"[1]")]});case"blend.func":return e(function(t){return[wt["srcRGB"in t?t.srcRGB:t.src],wt["dstRGB"in t?t.dstRGB:t.dst],wt["srcAlpha"in t?t.srcAlpha:t.src],wt["dstAlpha"in t?t.dstAlpha:t.dst]]},function(t,e,r){function n(t,n){return e.def('"',t,n,'" in ',r,"?",r,".",t,n,":",r,".",t)}t=t.constants.blendFuncs;var a=n("src","RGB"),i=n("dst","RGB"),o=(a=e.def(t,"[",a,"]"),e.def(t,"[",n("src","Alpha"),"]"));return[a,i=e.def(t,"[",i,"]"),o,t=e.def(t,"[",n("dst","Alpha"),"]")]});case"blend.equation":return e(function(t){return"string"==typeof t?[J[t],J[t]]:"object"==typeof t?[J[t.rgb],J[t.alpha]]:void 0},function(t,e,r){var n=t.constants.blendEquations,a=e.def(),i=e.def();return(t=t.cond("typeof ",r,'==="string"')).then(a,"=",i,"=",n,"[",r,"];"),t.else(a,"=",n,"[",r,".rgb];",i,"=",n,"[",r,".alpha];"),e(t),[a,i]});case"blend.color":return e(function(t){return i(4,function(e){return+t[e]})},function(t,e,r){return i(4,function(t){return e.def("+",r,"[",t,"]")})});case"stencil.mask":return e(function(t){return 0|t},function(t,e,r){return e.def(r,"|0")});case"stencil.func":return e(function(t){return[kt[t.cmp||"keep"],t.ref||0,"mask"in t?t.mask:-1]},function(t,e,r){return[t=e.def('"cmp" in ',r,"?",t.constants.compareFuncs,"[",r,".cmp]",":",7680),e.def(r,".ref|0"),e=e.def('"mask" in ',r,"?",r,".mask|0:-1")]});case"stencil.opFront":case"stencil.opBack":return e(function(e){return["stencil.opBack"===t?1029:1028,Tt[e.fail||"keep"],Tt[e.zfail||"keep"],Tt[e.zpass||"keep"]]},function(e,r,n){function a(t){return r.def('"',t,'" in ',n,"?",i,"[",n,".",t,"]:",7680)}var i=e.constants.stencilOps;return["stencil.opBack"===t?1029:1028,a("fail"),a("zfail"),a("zpass")]});case"polygonOffset.offset":return e(function(t){return[0|t.factor,0|t.units]},function(t,e,r){return[e.def(r,".factor|0"),e=e.def(r,".units|0")]});case"cull.face":return e(function(t){var e=0;return"front"===t?e=1028:"back"===t&&(e=1029),e},function(t,e,r){return e.def(r,'==="front"?',1028,":",1029)});case"lineWidth":return e(function(t){return t},function(t,e,r){return r});case"frontFace":return e(function(t){return Mt[t]},function(t,e,r){return e.def(r+'==="cw"?2304:2305')});case"colorMask":return e(function(t){return t.map(function(t){return!!t})},function(t,e,r){return i(4,function(t){return"!!"+r+"["+t+"]"})});case"sample.coverage":return e(function(t){return["value"in t?t.value:1,!!t.invert]},function(t,e,r){return[e.def('"value" in ',r,"?+",r,".value:1"),e=e.def("!!",r,".invert")]})}}),a}(t),u=w(t),h=s.viewport;return h&&(c.viewport=h),(s=s[h=m("scissor.box")])&&(c[h]=s),(o={framebuffer:o,draw:l,shader:u,state:c,dirty:s=0<Object.keys(c).length}).profile=function(t){var e,r=t.static;if(t=t.dynamic,"profile"in r){var n=!!r.profile;(e=R(function(t,e){return n})).enable=n}else if("profile"in t){var a=t.profile;e=F(a,function(t,e){return t.invoke(e,a)})}return e}(t),o.uniforms=function(t,e){var r=t.static,n=t.dynamic,a={};return Object.keys(r).forEach(function(t){var e,n=r[t];if("number"==typeof n||"boolean"==typeof n)e=R(function(){return n});else if("function"==typeof n){var o=n._reglType;"texture2d"===o||"textureCube"===o?e=R(function(t){return t.link(n)}):"framebuffer"!==o&&"framebufferCube"!==o||(e=R(function(t){return t.link(n.color[0])}))}else v(n)&&(e=R(function(t){return t.global.def("[",i(n.length,function(t){return n[t]}),"]")}));e.value=n,a[t]=e}),Object.keys(n).forEach(function(t){var e=n[t];a[t]=F(e,function(t,r){return t.invoke(r,e)})}),a}(r),o.attributes=T(e),o.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach(function(t){var r=e[t];n[t]=R(function(t,e){return"number"==typeof r||"boolean"==typeof r?""+r:t.link(r)})}),Object.keys(r).forEach(function(t){var e=r[t];n[t]=F(e,function(t,r){return t.invoke(r,e)})}),n}(n),o}function A(t,e,r){var n=t.shared.context,a=t.scope();Object.keys(r).forEach(function(i){e.save(n,"."+i),a(n,".",i,"=",r[i].append(t,e),";")}),e(a)}function S(t,e,r,n){var a,i=(s=t.shared).gl,o=s.framebuffer;$&&(a=e.def(s.extensions,".webgl_draw_buffers"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,".next"),n||e("if(",t,"!==",o,".cur){"),e("if(",t,"){",i,".bindFramebuffer(",36160,",",t,".framebuffer);"),$&&e(a,".drawBuffersWEBGL(",s,"[",t,".colorAttachments.length]);"),e("}else{",i,".bindFramebuffer(",36160,",null);"),$&&e(a,".drawBuffersWEBGL(",l,");"),e("}",o,".cur=",t,";"),n||e("}")}function E(t,e,r){var n=t.shared,a=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,".dirty");nt.forEach(function(e){var n,h;if(!((e=m(e))in r.state))if(e in s){n=s[e],h=o[e];var f=i(tt[e].length,function(t){return u.def(n,"[",t,"]")});u(t.cond(f.map(function(t,e){return t+"!=="+h+"["+e+"]"}).join("||")).then(a,".",it[e],"(",f,");",f.map(function(t,e){return h+"["+e+"]="+t}).join(";"),";"))}else n=u.def(c,".",e),f=t.cond(n,"!==",l,".",e),u(f),e in at?f(t.cond(n).then(a,".enable(",at[e],");").else(a,".disable(",at[e],");"),l,".",e,"=",n,";"):f(a,".",it[e],"(",n,");",l,".",e,"=",n,";")}),0===Object.keys(r.state).length&&u(l,".dirty=false;"),e(u)}function L(t,e,r,n){var a=t.shared,i=t.current,o=a.current,s=a.gl;z(Object.keys(r)).forEach(function(a){var l=r[a];if(!n||n(l)){var c=l.append(t,e);if(at[a]){var u=at[a];D(l)?e(s,c?".enable(":".disable(",u,");"):e(t.cond(c).then(s,".enable(",u,");").else(s,".disable(",u,");")),e(o,".",a,"=",c,";")}else if(v(c)){var h=i[a];e(s,".",it[a],"(",c,");",c.map(function(t,e){return h+"["+e+"]="+t}).join(";"),";")}else e(s,".",it[a],"(",c,");",o,".",a,"=",c,";")}})}function C(t,e){Q&&(t.instancing=e.def(t.shared.extensions,".angle_instanced_arrays"))}function B(t,e,r,n,a){function i(){return"undefined"==typeof performance?"Date.now()":"performance.now()"}function o(t){t(c=e.def(),"=",i(),";"),"string"==typeof a?t(f,".count+=",a,";"):t(f,".count++;"),d&&(n?t(u=e.def(),"=",g,".getNumPendingQueries();"):t(g,".beginQuery(",f,");"))}function s(t){t(f,".cpuTime+=",i(),"-",c,";"),d&&(n?t(g,".pushScopeStats(",u,",",g,".getNumPendingQueries(),",f,");"):t(g,".endQuery();"))}function l(t){var r=e.def(p,".profile");e(p,".profile=",t,";"),e.exit(p,".profile=",r,";")}var c,u,h=t.shared,f=t.stats,p=h.current,g=h.timer;if(r=r.profile){if(D(r))return void(r.enable?(o(e),s(e.exit),l("true")):l("false"));l(r=r.append(t,e))}else r=e.def(p,".profile");o(h=t.block()),e("if(",r,"){",h,"}"),s(t=t.block()),e.exit("if(",r,"){",t,"}")}function N(t,e,r,n,a){function i(r,n,a){function i(){e("if(!",u,".buffer){",l,".enableVertexAttribArray(",c,");}");var r,i=a.type;r=a.size?e.def(a.size,"||",n):n,e("if(",u,".type!==",i,"||",u,".size!==",r,"||",p.map(function(t){return u+"."+t+"!=="+a[t]}).join("||"),"){",l,".bindBuffer(",34962,",",h,".buffer);",l,".vertexAttribPointer(",[c,r,i,a.normalized,a.stride,a.offset],");",u,".type=",i,";",u,".size=",r,";",p.map(function(t){return u+"."+t+"="+a[t]+";"}).join(""),"}"),Q&&(i=a.divisor,e("if(",u,".divisor!==",i,"){",t.instancing,".vertexAttribDivisorANGLE(",[c,i],");",u,".divisor=",i,";}"))}function s(){e("if(",u,".buffer){",l,".disableVertexAttribArray(",c,");","}if(",bt.map(function(t,e){return u+"."+t+"!=="+f[e]}).join("||"),"){",l,".vertexAttrib4f(",c,",",f,");",bt.map(function(t,e){return u+"."+t+"="+f[e]+";"}).join(""),"}")}var l=o.gl,c=e.def(r,".location"),u=e.def(o.attributes,"[",c,"]");r=a.state;var h=a.buffer,f=[a.x,a.y,a.z,a.w],p=["buffer","normalized","offset","stride"];1===r?i():2===r?s():(e("if(",r,"===",1,"){"),i(),e("}else{"),s(),e("}"))}var o=t.shared;n.forEach(function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!a(l))return;o=l.append(t,e)}else{if(!a(At))return;var c=t.scopeAttrib(s);o={},Object.keys(new Z).forEach(function(t){o[t]=e.def(c,".",t)})}i(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)})}function j(t,r,n,a,o){for(var s,l=t.shared,c=l.gl,u=0;u<a.length;++u){var h,f=(g=a[u]).name,p=g.info.type,d=n.uniforms[f],g=t.link(g)+".location";if(d){if(!o(d))continue;if(D(d)){if(f=d.value,35678===p||35680===p)r(c,".uniform1i(",g,",",(p=t.link(f._texture||f.color[0]._texture))+".bind());"),r.exit(p,".unbind();");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,".uniformMatrix",d,"fv(",g,",false,",f=t.global.def("new Float32Array(["+Array.prototype.slice.call(f)+"])"),");");else{switch(p){case 5126:s="1f";break;case 35664:s="2f";break;case 35665:s="3f";break;case 35666:s="4f";break;case 35670:case 5124:s="1i";break;case 35671:case 35667:s="2i";break;case 35672:case 35668:s="3i";break;case 35673:s="4i";break;case 35669:s="4i"}r(c,".uniform",s,"(",g,",",v(f)?Array.prototype.slice.call(f):f,");")}continue}h=d.append(t,r)}else{if(!o(At))continue;h=r.def(l.uniforms,"[",e.id(f),"]")}switch(35678===p?r("if(",h,"&&",h,'._reglType==="framebuffer"){',h,"=",h,".color[0];","}"):35680===p&&r("if(",h,"&&",h,'._reglType==="framebufferCube"){',h,"=",h,".color[0];","}"),f=1,p){case 35678:case 35680:p=r.def(h,"._texture"),r(c,".uniform1i(",g,",",p,".bind());"),r.exit(p,".unbind();");continue;case 5124:case 35670:s="1i";break;case 35667:case 35671:s="2i",f=2;break;case 35668:case 35672:s="3i",f=3;break;case 35669:case 35673:s="4i",f=4;break;case 5126:s="1f";break;case 35664:s="2f",f=2;break;case 35665:s="3f",f=3;break;case 35666:s="4f",f=4;break;case 35674:s="Matrix2fv";break;case 35675:s="Matrix3fv";break;case 35676:s="Matrix4fv"}if(r(c,".uniform",s,"(",g,","),"M"===s.charAt(0)){g=Math.pow(p-35674+2,2);var m=t.global.def("new Float32Array(",g,")");r("false,(Array.isArray(",h,")||",h," instanceof Float32Array)?",h,":(",i(g,function(t){return m+"["+t+"]="+h+"["+t+"]"}),",",m,")")}else r(1<f?i(f,function(t){return h+"["+t+"]"}):h);r(");")}}function V(t,e,r,n){function a(a){var i=f[a];return i?i.contextDep&&n.contextDynamic||i.propDep?i.append(t,r):i.append(t,e):e.def(h,".",a)}function i(){function t(){r(l,".drawElementsInstancedANGLE(",[d,v,m,g+"<<(("+m+"-5121)>>1)",s],");")}function e(){r(l,".drawArraysInstancedANGLE(",[d,g,v,s],");")}p?y?t():(r("if(",p,"){"),t(),r("}else{"),e(),r("}")):e()}function o(){function t(){r(u+".drawElements("+[d,v,m,g+"<<(("+m+"-5121)>>1)"]+");")}function e(){r(u+".drawArrays("+[d,g,v]+");")}p?y?t():(r("if(",p,"){"),t(),r("}else{"),e(),r("}")):e()}var s,l,c=t.shared,u=c.gl,h=c.draw,f=n.draw,p=function(){var a=f.elements,i=e;return a?((a.contextDep&&n.contextDynamic||a.propDep)&&(i=r),a=a.append(t,i)):a=i.def(h,".","elements"),a&&i("if("+a+")"+u+".bindBuffer(34963,"+a+".buffer.buffer);"),a}(),d=a("primitive"),g=a("offset"),v=function(){var a=f.count,i=e;return a?((a.contextDep&&n.contextDynamic||a.propDep)&&(i=r),a=a.append(t,i)):a=i.def(h,".","count"),a}();if("number"==typeof v){if(0===v)return}else r("if(",v,"){"),r.exit("}");Q&&(s=a("instances"),l=t.instancing);var m=p+".type",y=f.elements&&D(f.elements);Q&&("number"!=typeof s||0<=s)?"string"==typeof s?(r("if(",s,">0){"),i(),r("}else if(",s,"<0){"),o(),r("}")):i():o()}function q(t,e,r,n,a){return a=(e=b()).proc("body",a),Q&&(e.instancing=a.def(e.shared.extensions,".angle_instanced_arrays")),t(e,a,r,n),e.compile().body}function H(t,e,r,n){C(t,e),N(t,e,r,n.attributes,function(){return!0}),j(t,e,r,n.uniforms,function(){return!0}),V(t,e,e,r)}function G(t,e,r,n){function a(){return!0}t.batchId="a1",C(t,e),N(t,e,r,n.attributes,a),j(t,e,r,n.uniforms,a),V(t,e,e,r)}function Y(t,e,r,n){function a(t){return t.contextDep&&o||t.propDep}function i(t){return!a(t)}C(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,"for(",s,"=0;",s,"<","a1",";++",s,"){",l,"=","a0","[",s,"];",u,"}",c.exit),r.needsContext&&A(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),L(t,u,r.state,a),r.profile&&a(r.profile)&&B(t,u,r,!1,!0),n?(N(t,c,r,n.attributes,i),N(t,u,r,n.attributes,a),j(t,c,r,n.uniforms,i),j(t,u,r,n.uniforms,a),V(t,c,u,r)):(e=t.global.def("{}"),n=r.shader.progVar.append(t,u),l=u.def(n,".id"),c=u.def(e,"[",l,"]"),u(t.shared.gl,".useProgram(",n,".program);","if(!",c,"){",c,"=",e,"[",l,"]=",t.link(function(e){return q(G,t,r,e,2)}),"(",n,");}",c,".call(this,a0[",s,"],",s,");"))}function W(t,r){function n(e){var n=r.shader[e];n&&a.set(i.shader,"."+e,n.append(t,a))}var a=t.proc("scope",3);t.batchId="a2";var i=t.shared,o=i.current;A(t,a,r.context),r.framebuffer&&r.framebuffer.append(t,a),z(Object.keys(r.state)).forEach(function(e){var n=r.state[e].append(t,a);v(n)?n.forEach(function(r,n){a.set(t.next[e],"["+n+"]",r)}):a.set(i.next,"."+e,n)}),B(t,a,r,!0,!0),["elements","offset","count","instances","primitive"].forEach(function(e){var n=r.draw[e];n&&a.set(i.draw,"."+e,""+n.append(t,a))}),Object.keys(r.uniforms).forEach(function(n){a.set(i.uniforms,"["+e.id(n)+"]",r.uniforms[n].append(t,a))}),Object.keys(r.attributes).forEach(function(e){var n=r.attributes[e].append(t,a),i=t.scopeAttrib(e);Object.keys(new Z).forEach(function(t){a.set(i,"."+t,n[t])})}),n("vert"),n("frag"),0<Object.keys(r.state).length&&(a(o,".dirty=true;"),a.exit(o,".dirty=true;")),a("a1(",t.shared.context,",a0,",t.batchId,");")}function X(t,e,r){var n=e.static[r];if(n&&function(t){if("object"==typeof t&&!v(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(U.isDynamic(t[e[r]]))return!0;return!1}}(n)){var a=t.global,i=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def("{}");i.forEach(function(e){var r=n[e];if(U.isDynamic(r))"function"==typeof r&&(r=n[e]=U.unbox(r)),e=F(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(a(c,".",e,"="),typeof r){case"number":a(r);break;case"string":a('"',r,'"');break;case"object":Array.isArray(r)&&a("[",r.join(),"]");break;default:a(t.link(r))}a(";")}}),e.dynamic[r]=new U.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){i.forEach(function(r){var a=n[r];U.isDynamic(a)&&(a=t.invoke(e,a),e(c,".",r,"=",a,";"))})}}),delete e.static[r]}}var Z=u.Record,J={add:32774,subtract:32778,"reverse subtract":32779};r.ext_blend_minmax&&(J.min=32775,J.max=32776);var Q=r.angle_instanced_arrays,$=r.webgl_draw_buffers,tt={dirty:!0,profile:g.profile},et={},nt=[],at={},it={};y("dither",3024),y("blend.enable",3042),x("blend.color","blendColor",[0,0,0,0]),x("blend.equation","blendEquationSeparate",[32774,32774]),x("blend.func","blendFuncSeparate",[1,0,1,0]),y("depth.enable",2929,!0),x("depth.func","depthFunc",513),x("depth.range","depthRange",[0,1]),x("depth.mask","depthMask",!0),x("colorMask","colorMask",[!0,!0,!0,!0]),y("cull.enable",2884),x("cull.face","cullFace",1029),x("frontFace","frontFace",2305),x("lineWidth","lineWidth",1),y("polygonOffset.enable",32823),x("polygonOffset.offset","polygonOffset",[0,0]),y("sample.alpha",32926),y("sample.enable",32928),x("sample.coverage","sampleCoverage",[1,!1]),y("stencil.enable",2960),x("stencil.mask","stencilMask",-1),x("stencil.func","stencilFunc",[519,0,-1]),x("stencil.opFront","stencilOpSeparate",[1028,7680,7680,7680]),x("stencil.opBack","stencilOpSeparate",[1029,7680,7680,7680]),y("scissor.enable",3089),x("scissor.box","scissor",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x("viewport","viewport",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:f,elements:o,buffer:a,shader:h,attributes:u.state,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:O},st={primTypes:rt,compareFuncs:kt,blendFuncs:wt,blendEquations:J,stencilOps:Tt,glTypes:K,orientationType:Mt};$&&(st.backBuffer=[1029],st.drawBuffer=i(n.maxDrawbuffers,function(t){return 0===t?[0]:i(t,function(t){return 36064+t})}));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc("poll"),r=t.proc("refresh"),a=t.block();e(a),r(a);var o,s=t.shared,l=s.gl,c=s.next,u=s.current;a(u,".dirty=false;"),S(t,e),S(t,r,null,!0),Q&&(o=t.link(Q));for(var h=0;h<n.maxAttributes;++h){var f=r.def(s.attributes,"[",h,"]"),p=t.cond(f,".buffer");p.then(l,".enableVertexAttribArray(",h,");",l,".bindBuffer(",34962,",",f,".buffer.buffer);",l,".vertexAttribPointer(",h,",",f,".size,",f,".type,",f,".normalized,",f,".stride,",f,".offset);").else(l,".disableVertexAttribArray(",h,");",l,".vertexAttrib4f(",h,",",f,".x,",f,".y,",f,".z,",f,".w);",f,".buffer=null;"),r(p),Q&&r(o,".vertexAttribDivisorANGLE(",h,",",f,".divisor);")}return Object.keys(at).forEach(function(n){var i=at[n],o=a.def(c,".",n),s=t.block();s("if(",o,"){",l,".enable(",i,")}else{",l,".disable(",i,")}",u,".",n,"=",o,";"),r(s),e("if(",o,"!==",u,".",n,"){",s,"}")}),Object.keys(it).forEach(function(n){var o,s,h=it[n],f=tt[n],p=t.block();p(l,".",h,"("),v(f)?(h=f.length,o=t.global.def(c,".",n),s=t.global.def(u,".",n),p(i(h,function(t){return o+"["+t+"]"}),");",i(h,function(t){return s+"["+t+"]="+o+"["+t+"];"}).join("")),e("if(",i(h,function(t){return o+"["+t+"]!=="+s+"["+t+"]"}).join("||"),"){",p,"}")):(o=a.def(c,".",n),s=a.def(u,".",n),p(o,");",u,".",n,"=",o,";"),e("if(",o,"!==",s,"){",p,"}")),r(p)}),t.compile()}(),compile:function(t,e,r,n,a){var i=b();return i.stats=i.link(a),Object.keys(e.static).forEach(function(t){X(i,e,t)}),_t.forEach(function(e){X(i,t,e)}),r=M(t,e,r,n),function(t,e){var r=t.proc("draw",1);C(t,r),A(t,r,e.context),S(t,r,e.framebuffer),E(t,r,e),L(t,r,e.state),B(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,".useProgram(",n,".program);"),e.shader.program)H(t,r,e,e.shader.program);else{var a=t.global.def("{}"),i=r.def(n,".id"),o=r.def(a,"[",i,"]");r(t.cond(o).then(o,".call(this,a0);").else(o,"=",a,"[",i,"]=",t.link(function(r){return q(H,t,e,r,1)}),"(",n,");",o,".call(this,a0);"))}0<Object.keys(e.state).length&&r(t.shared.current,".dirty=true;")}(i,r),W(i,r),function(t,e){function r(t){return t.contextDep&&a||t.propDep}var n=t.proc("batch",2);t.batchId="0",C(t,n);var a=!1,i=!0;Object.keys(e.context).forEach(function(t){a=a||e.context[t].propDep}),a||(A(t,n,e.context),i=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?a=o=!0:s.contextDep&&a&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(a=!0),E(t,n,e),L(t,n,e.state,function(t){return!r(t)}),e.profile&&r(e.profile)||B(t,n,e,!1,"a1"),e.contextDep=a,e.needsContext=i,e.needsFramebuffer=o,(i=e.shader.progVar).contextDep&&a||i.propDep)Y(t,n,e,null);else if(i=i.append(t,n),n(t.shared.gl,".useProgram(",i,".program);"),e.shader.program)Y(t,n,e,e.shader.program);else{var s=t.global.def("{}"),l=(o=n.def(i,".id"),n.def(s,"[",o,"]"));n(t.cond(l).then(l,".call(this,a0,a1);").else(l,"=",s,"[",o,"]=",t.link(function(r){return q(Y,t,e,r,2)}),"(",i,");",l,".call(this,a0,a1);"))}0<Object.keys(e.state).length&&n(t.shared.current,".dirty=true;")}(i,r),i.compile()}}}function N(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var j=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},V=0,U={DynamicVariable:t,define:function(r,n){return new t(r,e(n+""))},isDynamic:function(e){return"function"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return"function"==typeof e?new t(0,e):e},accessor:e},q={next:"function"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:"function"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},H="undefined"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},G=s();G.zero=s();var Y=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,a=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),a=t.getParameter(36063));var i=!!e.oes_texture_float;if(i){i=t.createTexture(),t.bindTexture(3553,i),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,i,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))i=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=G.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?i=!1:(t.deleteFramebuffer(o),t.deleteTexture(i),i=1===s[0]),G.freeType(s)}}return s=!0,"undefined"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=G.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),G.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter(function(t){return!!e[t]}),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:a,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:i,npotTextureCube:s}},W=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},X=function(t){return Object.keys(t).map(function(e){return t[e]})},Z={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var a=1;if(e.length)for(var i=0;i<e.length;++i)a*=e[i];else a=0;switch(r=n||G.allocType(r,a),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],i=a=0;i<n;++i)for(var o=t[i],s=0;s<e;++s)r[a++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,a,i){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],h=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,h,r,a,i),i+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,a,i),i+=o}(t,e,0,r,0)}return r}},J={"[object Int8Array]":5120,"[object Int16Array]":5122,"[object Int32Array]":5124,"[object Uint8Array]":5121,"[object Uint8ClampedArray]":5121,"[object Uint16Array]":5123,"[object Uint32Array]":5125,"[object Float32Array]":5126,"[object Float64Array]":5121,"[object ArrayBuffer]":5121},K={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},Q={dynamic:35048,stream:35040,static:35044},$=Z.flatten,tt=Z.shape,et=[];et[5120]=1,et[5122]=2,et[5124]=4,et[5121]=1,et[5123]=2,et[5125]=4,et[5126]=4;var rt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,"line loop":2,"line strip":3,"triangle strip":5,"triangle fan":6},nt=new Float32Array(1),at=new Uint32Array(nt.buffer),it=[9984,9986,9985,9987],ot=[0,6409,6410,6407,6408],st={};st[6409]=st[6406]=st[6402]=1,st[34041]=st[6410]=2,st[6407]=st[35904]=3,st[6408]=st[35906]=4;var lt=m("HTMLCanvasElement"),ct=m("CanvasRenderingContext2D"),ut=m("ImageBitmap"),ht=m("HTMLImageElement"),ft=m("HTMLVideoElement"),pt=Object.keys(J).concat([lt,ct,ut,ht,ft]),dt=[];dt[5121]=1,dt[5126]=4,dt[36193]=2,dt[5123]=2,dt[5125]=4;var gt=[];gt[32854]=2,gt[32855]=2,gt[36194]=2,gt[34041]=4,gt[33776]=.5,gt[33777]=.5,gt[33778]=1,gt[33779]=1,gt[35986]=.5,gt[35987]=1,gt[34798]=1,gt[35840]=.5,gt[35841]=.25,gt[35842]=.5,gt[35843]=.25,gt[36196]=.5;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[33189]=2,vt[36168]=1,vt[34041]=4,vt[35907]=4,vt[34836]=16,vt[34842]=8,vt[34843]=6;var mt=function(t,e,r,n,a){function i(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,a.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,"rgb5 a1":32855,depth:33189,stencil:36168,"depth stencil":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach(function(t){l[s[t]]=t});var c=0,u={};return i.prototype.decRef=function(){0>=--this.refCount&&o(this)},a.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach(function(e){t+=u[e].stats.size}),t}),{create:function(e,r){function o(e,r){var n=0,i=0,u=32854;if("object"==typeof e&&e?("shape"in e?(n=0|(i=e.shape)[0],i=0|i[1]):("radius"in e&&(n=i=0|e.radius),"width"in e&&(n=0|e.width),"height"in e&&(i=0|e.height)),"format"in e&&(u=s[e.format])):"number"==typeof e?(n=0|e,i="number"==typeof r?0|r:n):e||(n=i=1),n!==c.width||i!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=i,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,i),a.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new i(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,i=0|r||n;return n===c.width&&i===c.height?o:(o.width=c.width=n,o.height=c.height=i,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,i),a.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o)},o._reglType="renderbuffer",o._renderbuffer=c,a.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){X(u).forEach(o)},restore:function(){X(u).forEach(function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)}),t.bindRenderbuffer(36161,null)}}},yt=[];yt[6408]=4,yt[6407]=3;var xt=[];xt[5121]=1,xt[5126]=4,xt[36193]=2;var bt=["x","y","z","w"],_t="blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset".split(" "),wt={0:0,1:1,zero:0,one:1,"src color":768,"one minus src color":769,"src alpha":770,"one minus src alpha":771,"dst color":774,"one minus dst color":775,"dst alpha":772,"one minus dst alpha":773,"constant color":32769,"one minus constant color":32770,"constant alpha":32771,"one minus constant alpha":32772,"src alpha saturate":776},kt={never:512,less:513,"<":513,equal:514,"=":514,"==":514,"===":514,lequal:515,"<=":515,greater:516,">":516,notequal:517,"!=":517,"!==":517,gequal:518,">=":518,always:519},Tt={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,"increment wrap":34055,"decrement wrap":34056,invert:5386},Mt={cw:2304,ccw:2305},At=new I(!1,!1,!1,function(){});return function(t){function e(){if(0===Z.length)w&&w.update(),$=null;else{$=q.next(e),h();for(var t=Z.length-1;0<=t;--t){var r=Z[t];r&&r(P,null,0)}v.flush(),w&&w.update()}}function r(){!$&&0<Z.length&&($=q.next(e))}function n(){$&&(q.cancel(e),$=null)}function i(t){t.preventDefault(),n(),J.forEach(function(t){t()})}function o(t){v.getError(),y.restore(),D.restore(),z.restore(),R.restore(),F.restore(),V.restore(),w&&w.restore(),G.procs.refresh(),r(),K.forEach(function(t){t()})}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach(function(n){var a=t[n];U.isDynamic(a)?r[n]=U.unbox(a,n):e[n]=a}),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),a=e(t.attributes||{}),i=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach(function(n){r[t+"."+n]=e[n]})}}var r=j({},t);return delete r.uniforms,delete r.attributes,delete r.context,"stencil"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e("blend"),e("depth"),e("cull"),e("stencil"),e("polygonOffset"),e("scissor"),e("sample"),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=G.compile(i,a,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return j(function(t,e){var r;if("function"==typeof t)return l.call(this,null,t,0);if("function"==typeof e)if("number"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if("number"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}},{stats:t})}function l(t,e){var r=0;G.procs.poll();var n=e.color;n&&(v.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),"depth"in e&&(v.clearDepth(+e.depth),r|=256),"stencil"in e&&(v.clearStencil(0|e.stencil),r|=1024),v.clear(r)}function c(t){return Z.push(t),r(),{cancel:function(){var e=N(Z,t);Z[e]=function t(){var e=N(Z,t);Z[e]=Z[Z.length-1],--Z.length,0>=Z.length&&n()}}}}function u(){var t=W.viewport,e=W.scissor_box;t[0]=t[1]=e[0]=e[1]=0,P.viewportWidth=P.framebufferWidth=P.drawingBufferWidth=t[2]=e[2]=v.drawingBufferWidth,P.viewportHeight=P.framebufferHeight=P.drawingBufferHeight=t[3]=e[3]=v.drawingBufferHeight}function h(){P.tick+=1,P.time=g(),u(),G.procs.poll()}function f(){u(),G.procs.refresh(),w&&w.update()}function g(){return(H()-k)/1e3}if(!(t=a(t)))return null;var v=t.gl,m=v.getContextAttributes();v.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},a=0;a<e.extensions.length;++a){var i=e.extensions[a];if(!r(i))return e.onDestroy(),e.onDone('"'+i+'" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach(function(t){if(n[t]&&!r(t))throw Error("(regl): error restoring extension "+t)})}}}(v,t);if(!y)return null;var x=function(){var t={"":0},e=[""];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var a=o.pop()||new r;a.startQueryIndex=t,a.endQueryIndex=e,a.sum=0,a.stats=n,s.push(a)}if(!e.ext_disjoint_timer_query)return null;var a=[],i=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=a.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),i.push(r),n(i.length-1,i.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=i.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<i.length;++r){var u=i[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),a.push(u)):i[t++]=u,l[r+1]=n,c[r+1]=t}for(i.length=t,r=t=0;r<s.length;++r){var h=(n=s[r]).startQueryIndex;u=n.endQueryIndex,n.sum+=l[u]-l[h],h=c[h],(u=c[u])===h?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=h,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return i.length},clear:function(){a.push.apply(a,i);for(var t=0;t<a.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(a[t]);i.length=0,a.length=0},restore:function(){i.length=0,a.length=0}}}(0,_),k=H(),L=v.drawingBufferWidth,C=v.drawingBufferHeight,P={tick:0,time:0,viewportWidth:L,viewportHeight:C,framebufferWidth:L,framebufferHeight:C,drawingBufferWidth:L,drawingBufferHeight:C,pixelRatio:t.pixelRatio},O=Y(v,_),z=(L=function(t,e,r,n){for(t=r.maxAttributes,e=Array(t),r=0;r<t;++r)e[r]=new A;return{Record:A,scope:{},state:e}}(v,_,O),p(v,b,t,L)),I=d(v,_,z,b),D=S(v,x,b,t),R=T(v,_,O,function(){G.procs.poll()},P,b,t),F=mt(v,_,0,b,t),V=M(v,_,O,R,F,b),G=B(v,x,_,O,z,I,0,V,{},L,D,{elements:null,primitive:4,count:-1,offset:0,instances:-1},P,w,t),W=(x=E(v,V,G.procs.poll,P),G.next),X=v.canvas,Z=[],J=[],K=[],Q=[t.onDestroy],$=null;X&&(X.addEventListener("webglcontextlost",i,!1),X.addEventListener("webglcontextrestored",o,!1));var tt=V.setFBO=s({framebuffer:U.define.call(null,1,"framebuffer")});return f(),m=j(s,{clear:function(t){if("framebuffer"in t)if(t.framebuffer&&"framebufferCube"===t.framebuffer_reglType)for(var e=0;6>e;++e)tt(j({framebuffer:t.framebuffer.faces[e]},t),l);else tt(t,l);else l(0,t)},prop:U.define.bind(null,1),context:U.define.bind(null,2),this:U.define.bind(null,3),draw:s({}),buffer:function(t){return z.create(t,34962,!1,!1)},elements:function(t){return I.create(t,!1)},texture:R.create2D,cube:R.createCube,renderbuffer:F.create,framebuffer:V.create,framebufferCube:V.createCube,attributes:m,frame:c,on:function(t,e){var r;switch(t){case"frame":return c(e);case"lost":r=J;break;case"restore":r=K;break;case"destroy":r=Q}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:O,hasExtension:function(t){return 0<=O.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){Z.length=0,n(),X&&(X.removeEventListener("webglcontextlost",i),X.removeEventListener("webglcontextrestored",o)),D.clear(),V.clear(),F.clear(),R.clear(),I.clear(),z.clear(),w&&w.clear(),Q.forEach(function(t){t()})},_gl:v,_refresh:f,poll:function(){h(),w&&w.update()},now:g,stats:b}),t.onDone(null,m),m}},"object"==typeof r&&"undefined"!=typeof e?e.exports=a():n.createREGL=a()},{}],501:[function(t,e,r){"use strict";var n,a="";e.exports=function(t,e){if("string"!=typeof t)throw new TypeError("expected a string");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||"undefined"==typeof n)n=t,a="";else if(a.length>=r)return a.substr(0,r);for(;r>a.length&&e>1;)1&e&&(a+=t),e>>=1,t+=t;return a=(a+=t).substr(0,r)}},{}],502:[function(t,e,r){(function(t){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{}],503:[function(t,e,r){"use strict";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,a=e-2;a>=0;--a){var i=r,o=t[a],s=(r=i+o)-i,l=o-s;l&&(t[--n]=r,r=l)}for(var c=0,a=n;a<e;++a){var i=t[a],o=r,s=(r=i+o)-i,l=o-s;l&&(t[c++]=l)}return t[c++]=r,t.length=c,t}},{}],504:[function(t,e,r){"use strict";var n=t("two-product"),a=t("robust-sum"),i=t("robust-scale"),o=t("robust-compress"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var a=r[n-1]=new Array(t.length-1),i=0,o=0;i<t.length;++i)i!==e&&(a[o++]=t[n][i]);return r}function c(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=["m[",r,"][",n,"]"].join("")}return e}function u(t){if(2===t.length)return["sum(prod(",t[0][0],",",t[1][1],"),prod(-",t[0][1],",",t[1][0],"))"].join("");for(var e=[],r=0;r<t.length;++r)e.push(["scale(",u(l(t,r)),",",(n=r,1&n?"-":""),t[0][r],")"].join(""));return function t(e){if(1===e.length)return e[0];if(2===e.length)return["sum(",e[0],",",e[1],")"].join("");var r=e.length>>1;return["sum(",t(e.slice(0,r)),",",t(e.slice(r)),")"].join("")}(e);var n}function h(t){return new Function("sum","scale","prod","compress",["function robustDeterminant",t,"(m){return compress(",u(c(t)),")};return robustDeterminant",t].join(""))(a,i,n,o)}var f=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;f.length<s;)f.push(h(f.length));for(var t=[],r=["function robustDeterminant(m){switch(m.length){"],n=0;n<s;++n)t.push("det"+n),r.push("case ",n,":return det",n,"(m);");r.push("}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant"),t.push("CACHE","gen",r.join(""));var a=Function.apply(void 0,t);for(e.exports=a.apply(void 0,f.concat([f,h])),n=0;n<f.length;++n)e.exports[n]=f[n]}()},{"robust-compress":503,"robust-scale":510,"robust-sum":513,"two-product":541}],505:[function(t,e,r){"use strict";var n=t("two-product"),a=t("robust-sum");e.exports=function(t,e){for(var r=n(t[0],e[0]),i=1;i<t.length;++i)r=a(r,n(t[i],e[i]));return r}},{"robust-sum":513,"two-product":541}],506:[function(t,e,r){"use strict";var n=t("two-product"),a=t("robust-sum"),i=t("robust-subtract"),o=t("robust-scale"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var a=r[n-1]=new Array(t.length-1),i=0,o=0;i<t.length;++i)i!==e&&(a[o++]=t[n][i]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return["sum(",t[0],",",t[1],")"].join("");var e=t.length>>1;return["sum(",c(t.slice(0,e)),",",c(t.slice(e)),")"].join("")}function u(t,e){if("m"===t.charAt(0)){if("w"===e.charAt(0)){var r=t.split("[");return["w",e.substr(1),"m",r[0].substr(1)].join("")}return["prod(",t,",",e,")"].join("")}return u(e,t)}function h(t){if(2===t.length)return[["diff(",u(t[0][0],t[1][1]),",",u(t[1][0],t[0][1]),")"].join("")];for(var e=[],r=0;r<t.length;++r)e.push(["scale(",c(h(l(t,r))),",",(n=r,!0&n?"-":""),t[0][r],")"].join(""));return e;var n}function f(t,e){for(var r=[],n=0;n<e-2;++n)r.push(["prod(m",t,"[",n,"],m",t,"[",n,"])"].join(""));return c(r)}function p(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=["m",n,"[",t-r-2,"]"].join("")}return e}(t),u=0;u<t;++u)s[0][u]="1",s[t-1][u]="w"+u;for(u=0;u<t;++u)0==(1&u)?e.push.apply(e,h(l(s,u))):r.push.apply(r,h(l(s,u)));var p=c(e),d=c(r),g="exactInSphere"+t,v=[];for(u=0;u<t;++u)v.push("m"+u);var m=["function ",g,"(",v.join(),"){"];for(u=0;u<t;++u){m.push("var w",u,"=",f(u,t),";");for(var y=0;y<t;++y)y!==u&&m.push("var w",u,"m",y,"=scale(w",u,",m",y,"[0]);")}return m.push("var p=",p,",n=",d,",d=diff(p,n);return d[d.length-1];}return ",g),new Function("sum","diff","prod","scale",m.join(""))(a,i,n,o)}var d=[function(){return 0},function(){return 0},function(){return 0}];function g(t){var e=d[t.length];return e||(e=d[t.length]=p(t.length)),e.apply(void 0,t)}!function(){for(;d.length<=s;)d.push(p(d.length));for(var t=[],r=["slow"],n=0;n<=s;++n)t.push("a"+n),r.push("o"+n);var a=["function testInSphere(",t.join(),"){switch(arguments.length){case 0:case 1:return 0;"];for(n=2;n<=s;++n)a.push("case ",n,":return o",n,"(",t.slice(0,n).join(),");");a.push("}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere"),r.push(a.join(""));var i=Function.apply(void 0,r);for(e.exports=i.apply(void 0,[g].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{"robust-scale":510,"robust-subtract":512,"robust-sum":513,"two-product":541}],507:[function(t,e,r){"use strict";var n=t("robust-determinant"),a=6;function i(t){for(var e="robustLinearSolve"+t+"d",r=["function ",e,"(A,b){return ["],a=0;a<t;++a){r.push("det([");for(var i=0;i<t;++i){i>0&&r.push(","),r.push("[");for(var o=0;o<t;++o)o>0&&r.push(","),o===a?r.push("+b[",i,"]"):r.push("+A[",i,"][",o,"]");r.push("]")}r.push("]),")}r.push("det(A)]}return ",e);var s=new Function("det",r.join(""));return s(t<6?n[t]:n)}var o=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;o.length<a;)o.push(i(o.length));for(var t=[],r=["function dispatchLinearSolve(A,b){switch(A.length){"],n=0;n<a;++n)t.push("s"+n),r.push("case ",n,":return s",n,"(A,b);");r.push("}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve"),t.push("CACHE","g",r.join(""));var s=Function.apply(void 0,t);for(e.exports=s.apply(void 0,o.concat([o,i])),n=0;n<a;++n)e.exports[n]=o[n]}()},{"robust-determinant":504}],508:[function(t,e,r){"use strict";var n=t("two-product"),a=t("robust-sum"),i=t("robust-scale"),o=t("robust-subtract"),s=5;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var a=r[n-1]=new Array(t.length-1),i=0,o=0;i<t.length;++i)i!==e&&(a[o++]=t[n][i]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return["sum(",t[0],",",t[1],")"].join("");var e=t.length>>1;return["sum(",c(t.slice(0,e)),",",c(t.slice(e)),")"].join("")}function u(t){if(2===t.length)return[["sum(prod(",t[0][0],",",t[1][1],"),prod(-",t[0][1],",",t[1][0],"))"].join("")];for(var e=[],r=0;r<t.length;++r)e.push(["scale(",c(u(l(t,r))),",",(n=r,1&n?"-":""),t[0][r],")"].join(""));return e;var n}function h(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=["m",n,"[",t-r-1,"]"].join("")}return e}(t),h=[],f=0;f<t;++f)0==(1&f)?e.push.apply(e,u(l(s,f))):r.push.apply(r,u(l(s,f))),h.push("m"+f);var p=c(e),d=c(r),g="orientation"+t+"Exact",v=["function ",g,"(",h.join(),"){var p=",p,",n=",d,",d=sub(p,n);return d[d.length-1];};return ",g].join("");return new Function("sum","prod","scale","sub",v)(a,n,i,o)}var f=h(3),p=h(4),d=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,a=(t[1]-r[1])*(e[0]-r[0]),i=(t[0]-r[0])*(e[1]-r[1]),o=a-i;if(a>0){if(i<=0)return o;n=a+i}else{if(!(a<0))return o;if(i>=0)return o;n=-(a+i)}var s=3.3306690738754716e-16*n;return o>=s||o<=-s?o:f(t,e,r)},function(t,e,r,n){var a=t[0]-n[0],i=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],h=e[2]-n[2],f=r[2]-n[2],d=i*c,g=o*l,v=o*s,m=a*c,y=a*l,x=i*s,b=u*(d-g)+h*(v-m)+f*(y-x),_=7.771561172376103e-16*((Math.abs(d)+Math.abs(g))*Math.abs(u)+(Math.abs(v)+Math.abs(m))*Math.abs(h)+(Math.abs(y)+Math.abs(x))*Math.abs(f));return b>_||-b>_?b:p(t,e,r,n)}];function g(t){var e=d[t.length];return e||(e=d[t.length]=h(t.length)),e.apply(void 0,t)}!function(){for(;d.length<=s;)d.push(h(d.length));for(var t=[],r=["slow"],n=0;n<=s;++n)t.push("a"+n),r.push("o"+n);var a=["function getOrientation(",t.join(),"){switch(arguments.length){case 0:case 1:return 0;"];for(n=2;n<=s;++n)a.push("case ",n,":return o",n,"(",t.slice(0,n).join(),");");a.push("}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation"),r.push(a.join(""));var i=Function.apply(void 0,r);for(e.exports=i.apply(void 0,[g].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{"robust-scale":510,"robust-subtract":512,"robust-sum":513,"two-product":541}],509:[function(t,e,r){"use strict";var n=t("robust-sum"),a=t("robust-scale");e.exports=function(t,e){if(1===t.length)return a(e,t[0]);if(1===e.length)return a(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var i=0;i<t.length;++i)r=n(r,a(e,t[i]));else for(var i=0;i<e.length;++i)r=n(r,a(t,e[i]));return r}},{"robust-scale":510,"robust-sum":513}],510:[function(t,e,r){"use strict";var n=t("two-product"),a=t("two-sum");e.exports=function(t,e){var r=t.length;if(1===r){var i=n(t[0],e);return i[0]?i:[i[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var h=s[1];a(h,l[0],s),s[0]&&(o[c++]=s[0]);var f=l[1],p=s[1],d=f+p,g=d-f,v=p-g;s[1]=d,v&&(o[c++]=v)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{"two-product":541,"two-sum":542}],511:[function(t,e,r){"use strict";e.exports=function(t,e,r,a){var i=n(t,r,a),o=n(e,r,a);if(i>0&&o>0||i<0&&o<0)return!1;var s=n(r,t,e),l=n(a,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===i&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var a=0;a<2;++a){var i=t[a],o=e[a],s=Math.min(i,o),l=Math.max(i,o),c=r[a],u=n[a],h=Math.min(c,u),f=Math.max(c,u);if(f<s||l<h)return!1}return!0}(t,e,r,a);return!0};var n=t("robust-orientation")[3]},{"robust-orientation":508}],512:[function(t,e,r){"use strict";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,a=t-(r-n)+(e-n);if(a)return[a,r];return[r]}(t[0],-e[0]);var a,i,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=-e[c],d=u(p);f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&f<d||c>=n?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));var g,v,m=a+i,y=m-a,x=i-y,b=x,_=m;for(;l<r&&c<n;)f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(i=b)-(y=(m=a+i)-a))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(i=b)-(y=(m=(a=h)+i)-a))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(i=b)-(y=(m=(a=p)+i)-a))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],513:[function(t,e,r){"use strict";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,a=t-(r-n)+(e-n);if(a)return[a,r];return[r]}(t[0],e[0]);var a,i,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=e[c],d=u(p);f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&f<d||c>=n?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));var g,v,m=a+i,y=m-a,x=i-y,b=x,_=m;for(;l<r&&c<n;)f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(i=b)-(y=(m=a+i)-a))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(i=b)-(y=(m=(a=h)+i)-a))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(i=b)-(y=(m=(a=p)+i)-a))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],514:[function(t,e,r){"use strict";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],515:[function(t,e,r){"use strict";e.exports=function(t){return a(n(t))};var n=t("boundary-cells"),a=t("reduce-simplicial-complex")},{"boundary-cells":97,"reduce-simplicial-complex":490}],516:[function(t,e,r){"use strict";e.exports=function(t,e,r,s){r=r||0,"undefined"==typeof s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=a.mallocUint8(r),i=0;i<r;++i)n[i]=t[i]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=a.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],e=u.length,h=0;h<e;++h)for(var f=0;f<h;++f){var p=u[f],d=u[h];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}i(n(s,[l/2|0,2]));for(var g=2,c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[g++]=s[c],s[g++]=s[c+1]);return n(s,[g/2|0,2])}(t,s),u=function(t,e,r,i){for(var o=t.data,s=t.shape[0],l=a.mallocDouble(s),c=0,u=0;u<s;++u){var h=o[2*u],f=o[2*u+1];if(r[h]!==r[f]){var p=e[h],d=e[f];o[2*c]=h,o[2*c+1]=f,l[c++]=(d-i)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),h=function(t,e){var r=a.mallocInt32(2*e),n=t.shape[0],i=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=i[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),f=o(s)(t,c.data,h,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),a=0;a<e;++a)n[a]=[r[2*a],r[2*a+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return a.free(l),a.free(c.data),a.free(u.data),a.free(h),{cells:f,vertexIds:p,vertexWeights:d}};var n=t("ndarray"),a=t("typedarray-pool"),i=t("ndarray-sort"),o=t("./lib/codegen")},{"./lib/codegen":517,ndarray:451,"ndarray-sort":449,"typedarray-pool":543}],517:[function(t,e,r){"use strict";e.exports=function(t){var e=i[t];e||(e=i[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var i=1;i<=t;++i)for(var o=r[i]=a(i),s=0;s<o.length;++s)e=Math.max(e,o[i].length);var l=["function B(C,E,i,j){","var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];","while(l<h){","var m=(l+h)>>1,v=E[2*m+1];","if(v===b){return m}","if(b<v){h=m}else{l=m+1}","}","return l;","};","function getContour",t,"d(F,E,C,S){","var n=F.length,R=[];","for(var i=0;i<n;++i){var c=F[i],l=c.length;"];function c(t){if(!(t.length<=0)){l.push("R.push(");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(","),l.push("[");for(var n=0;n<r.length;++n){var a=r[n];n>0&&l.push(","),l.push("B(C,E,c[",a[0],"],c[",a[1],"])")}l.push("]")}l.push(");")}}for(var i=t+1;i>1;--i){i<t+1&&l.push("else "),l.push("if(l===",i,"){");for(var u=[],s=0;s<i;++s)u.push("(S[c["+s+"]]<<"+s+")");l.push("var M=",u.join("+"),";if(M===0||M===",(1<<i)-1,"){continue}switch(M){");for(var o=r[i-1],s=0;s<o.length;++s)l.push("case ",s,":"),c(o[s]),l.push("break;");l.push("}}")}return l.push("}return R;};return getContour",t,"d"),new Function("pool",l.join(""))(n)}(t));return e};var n=t("typedarray-pool"),a=t("marching-simplex-table"),i={}},{"marching-simplex-table":428,"typedarray-pool":543}],518:[function(t,e,r){"use strict";var n=t("bit-twiddle"),a=t("union-find");function i(t,e){var r=t.length,n=t.length-e.length,a=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||a(t[0],t[1])-a(e[0],e[1]);case 3:var i=t[0]+t[1],o=e[0]+e[1];if(s=i+t[2]-(o+e[2]))return s;var s,l=a(t[0],t[1]),c=a(e[0],e[1]);return(s=a(l,t[2])-a(c,e[2]))||a(l+t[2],i)-a(c+e[2],o);default:var u=t.slice(0);u.sort();var h=e.slice(0);h.sort();for(var f=0;f<r;++f)if(n=u[f]-h[f])return n;return 0}}function o(t,e){return i(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),a=0;a<r;++a)n[a]=[t[a],e[a]];n.sort(o);for(a=0;a<r;++a)t[a]=n[a][0],e[a]=n[a][1];return t}return t.sort(i),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var a=t[n];if(i(a,t[n-1])){if(n===e){e++;continue}t[e++]=a}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,a=-1;r<=n;){var o=r+n>>1,s=i(t[o],e);s<=0?(0===s&&(a=o),r=o+1):s>0&&(n=o-1)}return a}function u(t,e){for(var r=new Array(t.length),a=0,o=r.length;a<o;++a)r[a]=[];for(var s=[],l=(a=0,e.length);a<l;++a)for(var u=e[a],h=u.length,f=1,p=1<<h;f<p;++f){s.length=n.popCount(f);for(var d=0,g=0;g<h;++g)f&1<<g&&(s[d++]=u[g]);var v=c(t,s);if(!(v<0))for(;r[v++].push(a),!(v>=t.length||0!==i(t[v],s)););}return r}function h(t,e){if(e<0)return[];for(var r=[],a=(1<<e+1)-1,i=0;i<t.length;++i)for(var o=t[i],l=a;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,h=0;h<o.length;++h)l&1<<h&&(c[u++]=o[h]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,a=t.length;n<a;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,a=t.length;n<a;++n)for(var i=t[n],o=0,s=i.length;o<s;++o)e=r(e,i[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=i,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(h(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var a=t.length;n<a;++n)for(var i=t[n],o=0,s=i.length;o<s;++o)r[i[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var a=t[r],i=0|a.length,o=1,l=1<<i;o<l;++o){for(var c=[],u=0;u<i;++u)o>>>u&1&&c.push(a[u]);e.push(c)}return s(e)},r.skeleton=h,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var a=t[r],i=0,o=a.length;i<o;++i){for(var l=new Array(a.length-1),c=0,u=0;c<o;++c)c!==i&&(l[u++]=a[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new a(e),n=0;n<t.length;++n)for(var i=t[n],o=0;o<i.length;++o)for(var s=o+1;s<i.length;++s)r.link(i[o],i[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(h(t,0))),r=new a(e.length),n=0;n<t.length;++n)for(var i=t[n],o=0;o<i.length;++o)for(var u=c(e,[i[o]]),f=o+1;f<i.length;++f)r.link(u,c(e,[i[f]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var g=r.find(c(e,[t[n][0]]));d[g]<0?(d[g]=p.length,p.push([t[n].slice(0)])):p[d[g]].push(t[n].slice(0))}return p}(t)}},{"bit-twiddle":94,"union-find":544}],519:[function(t,e,r){arguments[4][94][0].apply(r,arguments)},{dup:94}],520:[function(t,e,r){arguments[4][518][0].apply(r,arguments)},{"bit-twiddle":519,dup:518,"union-find":521}],521:[function(t,e,r){"use strict";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var a=this.ranks,i=this.roots,o=a[r],s=a[n];o<s?i[r]=n:s<o?i[n]=r:(i[n]=r,++a[r])}}},{}],522:[function(t,e,r){"use strict";e.exports=function(t,e,r){for(var i=e.length,o=t.length,s=new Array(i),l=new Array(i),c=new Array(i),u=new Array(i),h=0;h<i;++h)s[h]=l[h]=-1,c[h]=1/0,u[h]=!1;for(var h=0;h<o;++h){var f=t[h];if(2!==f.length)throw new Error("Input must be a graph");var p=f[1],d=f[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function g(t){if(u[t])return 1/0;var r,a,i,o,c,h=s[t],f=l[t];return h<0||f<0?1/0:(r=e[t],a=e[h],i=e[f],o=Math.abs(n(r,a,i)),c=Math.sqrt(Math.pow(a[0]-i[0],2)+Math.pow(a[1]-i[1],2)),o/c)}function v(t,e){var r=T[t],n=T[e];T[t]=n,T[e]=r,M[r]=e,M[n]=t}function m(t){return c[T[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=m(t);;){var r=e,n=2*t+1,a=2*(t+1),i=t;if(n<S){var o=m(n);o<r&&(i=n,r=o)}if(a<S){var s=m(a);s<r&&(i=a)}if(i===t)return t;v(t,i),t=i}}function b(t){for(var e=m(t);t>0;){var r=y(t);if(r>=0){var n=m(r);if(e<n){v(t,r),t=r;continue}}return t}}function _(){if(S>0){var t=T[0];return v(0,S-1),S-=1,x(0),t}return-1}function w(t,e){var r=T[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((S+=1)-1))}function k(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),M[e]>=0&&w(M[e],g(e)),M[r]>=0&&w(M[r],g(r))}}for(var T=[],M=new Array(i),h=0;h<i;++h){var A=c[h]=g(h);A<1/0?(M[h]=T.length,T.push(h)):M[h]=-1}for(var S=T.length,h=S>>1;h>=0;--h)x(h);for(;;){var E=_();if(E<0||c[E]>r)break;k(E)}for(var L=[],h=0;h<i;++h)u[h]||(M[h]=L.length,L.push(e[h].slice()));L.length;function C(t,e){if(t[e]<0)return e;var r=e,n=e;do{var a=t[n];if(!u[n]||a<0||a===n)break;if(a=t[n=a],!u[n]||a<0||a===n)break;n=a,r=t[r]}while(r!==n);for(var i=e;i!==n;i=t[i])t[i]=n;return n}var P=[];return t.forEach(function(t){var e=C(s,t[0]),r=C(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=M[e],a=M[r];n!==a&&P.push([n,a])}}),a.unique(a.normalize(P)),{positions:L,edges:P}};var n=t("robust-orientation"),a=t("simplicial-complex")},{"robust-orientation":508,"simplicial-complex":520}],523:[function(t,e,r){"use strict";e.exports=function(t,e){var r,i,o,s;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0]))return a(e,t);r=e[1],i=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-a(t,e);o=t[1],s=t[0]}var l=n(r,i,s),c=n(r,i,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,i),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return i[0]-s[0]};var n=t("robust-orientation");function a(t,e){var r,a,i,o;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],a=e[0]}t[0][1]<t[1][1]?(i=t[0],o=t[1]):(i=t[1],o=t[0]);var h=n(a,r,i);return h||((h=n(a,r,o))||o-a)}},{"robust-orientation":508}],524:[function(t,e,r){"use strict";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),i=0;i<e;++i){var l=t[i],c=l[0][0]<l[1][0];n[2*i]=new h(l[0][0],l,c,i),n[2*i+1]=new h(l[1][0],l,!c,i)}n.sort(function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))});for(var f=a(o),p=[],d=[],g=[],i=0;i<r;){for(var v=n[i].x,m=[];i<r;){var y=n[i];if(y.x!==v)break;i+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(m.push(new u(y.segment[0][1],y.index,!0,!0)),m.push(new u(y.segment[1][1],y.index,!1,!1))):(m.push(new u(y.segment[1][1],y.index,!0,!1)),m.push(new u(y.segment[0][1],y.index,!1,!0)))):f=y.create?f.insert(y.segment,y.index):f.remove(y.segment)}p.push(f.root),d.push(v),g.push(m)}return new s(p,d,g)};var n=t("binary-search-bounds"),a=t("functional-red-black-tree"),i=t("robust-orientation"),o=t("./lib/order-segments");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,a,o=t.key;o[0][0]<o[1][0]?(n=o[0],a=o[1]):(n=o[1],a=o[0]);var s=i(n,a,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function h(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),a=-1;if(r&&(a=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,a=u.value):(a=u.value,s=u.key))}var h=this.horizontal[e];if(h.length>0){var f=n.ge(h,t[1],l);if(f<h.length){var p=h[f];if(t[1]===p.y){if(p.closed)return p.index;for(;f<h.length-1&&h[f+1].y===t[1];)if((p=h[f+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((f+=1)>=h.length)return a;p=h[f]}}if(p.start)if(s){var d=i(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(a=p.index)}else a=p.index;else p.y!==t[1]&&(a=p.index)}}}return a}},{"./lib/order-segments":523,"binary-search-bounds":93,"functional-red-black-tree":233,"robust-orientation":508}],525:[function(t,e,r){"use strict";var n=t("robust-dot-product"),a=t("robust-sum");function i(t,e){var r=a(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var a=-e/(n-e);a<0?a=0:a>1&&(a=1);for(var i=1-a,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=a*t[l]+i*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],a=i(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=i(l=t[c],e);if(a<0&&u>0||a>0&&u<0){var h=o(s,u,l,a);r.push(h),n.push(h.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),a=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=i(t[t.length-1],e),a=t[t.length-1],s=t[0],l=0;l<t.length;++l,a=s){var c=i(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(a,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=i(t[t.length-1],e),a=t[t.length-1],s=t[0],l=0;l<t.length;++l,a=s){var c=i(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(a,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{"robust-dot-product":505,"robust-sum":513}],526:[function(t,e,r){!function(){"use strict";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\x25]+/,modulo:/^\x25{2}/,placeholder:/^\x25(?:([1-9]\d*)\$|\(([^)]+)\))?(\+)?(0|'[^$])?(-)?(\d+)?(?:\.(\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\d]*)/i,key_access:/^\.([a-z_][a-z_\d]*)/i,index_access:/^\[(\d+)\]/,sign:/^[+-]/};function e(r){return function(r,n){var a,i,o,s,l,c,u,h,f,p=1,d=r.length,g="";for(i=0;i<d;i++)if("string"==typeof r[i])g+=r[i];else if("object"==typeof r[i]){if((s=r[i]).keys)for(a=n[p],o=0;o<s.keys.length;o++){if(null==a)throw new Error(e('[sprintf] Cannot access property "%s" of undefined value "%s"',s.keys[o],s.keys[o-1]));a=a[s.keys[o]]}else a=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&a instanceof Function&&(a=a()),t.numeric_arg.test(s.type)&&"number"!=typeof a&&isNaN(a))throw new TypeError(e("[sprintf] expecting number but found %T",a));switch(t.number.test(s.type)&&(h=a>=0),s.type){case"b":a=parseInt(a,10).toString(2);break;case"c":a=String.fromCharCode(parseInt(a,10));break;case"d":case"i":a=parseInt(a,10);break;case"j":a=JSON.stringify(a,null,s.width?parseInt(s.width):0);break;case"e":a=s.precision?parseFloat(a).toExponential(s.precision):parseFloat(a).toExponential();break;case"f":a=s.precision?parseFloat(a).toFixed(s.precision):parseFloat(a);break;case"g":a=s.precision?String(Number(a.toPrecision(s.precision))):parseFloat(a);break;case"o":a=(parseInt(a,10)>>>0).toString(8);break;case"s":a=String(a),a=s.precision?a.substring(0,s.precision):a;break;case"t":a=String(!!a),a=s.precision?a.substring(0,s.precision):a;break;case"T":a=Object.prototype.toString.call(a).slice(8,-1).toLowerCase(),a=s.precision?a.substring(0,s.precision):a;break;case"u":a=parseInt(a,10)>>>0;break;case"v":a=a.valueOf(),a=s.precision?a.substring(0,s.precision):a;break;case"x":a=(parseInt(a,10)>>>0).toString(16);break;case"X":a=(parseInt(a,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?g+=a:(!t.number.test(s.type)||h&&!s.sign?f="":(f=h?"+":"-",a=a.toString().replace(t.sign,"")),c=s.pad_char?"0"===s.pad_char?"0":s.pad_char.charAt(1):" ",u=s.width-(f+a).length,l=s.width&&u>0?c.repeat(u):"",g+=s.align?f+a+l:"0"===c?f+l+a:l+f+a)}return g}(function(e){if(a[e])return a[e];var r,n=e,i=[],o=0;for(;n;){if(null!==(r=t.text.exec(n)))i.push(r[0]);else if(null!==(r=t.modulo.exec(n)))i.push("%");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError("[sprintf] unexpected placeholder");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError("[sprintf] failed to parse named argument key");for(s.push(c[1]);""!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError("[sprintf] failed to parse named argument key");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error("[sprintf] mixing positional and named placeholders is not (yet) supported");i.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return a[e]=i}(r),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}var a=Object.create(null);"undefined"!=typeof r&&(r.sprintf=e,r.vsprintf=n),"undefined"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],527:[function(t,e,r){"use strict";var n=t("parenthesis");e.exports=function(t,e,r){if(null==t)throw Error("First argument should be a string");if(null==e)throw Error("Separator should be a string or a RegExp");r?("string"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=["[]","()","{}","<>",'""',"''","``","\u201c\u201d","\xab\xbb"]:("string"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map(function(t){return 1===t.length&&(t+=t),t}));var a=n.parse(t,{flat:!0,brackets:r.ignore}),i=a[0].split(e);if(r.escape){for(var o=[],s=0;s<i.length;s++){var l=i[s],c=i[s+1];"\\"===l[l.length-1]&&"\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}i=o}for(s=0;s<i.length;s++)a[0]=i[s],i[s]=n.stringify(a,{flat:!0});return i}},{parenthesis:459}],528:[function(t,e,r){"use strict";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),a=new Array(e),i=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,a[l]=!1,i[l]=0,o[l]=-1,s[l]=[];var c,u=0,h=[],f=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,a[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(i[e]<p.length){for(var d=i[e];d<p.length;++d){var g=p[d];if(r[g]<0){r[g]=n[g]=u,a[g]=!0,u+=1,l.push(g),c.push(g);break}a[g]&&(n[e]=0|Math.min(n[e],n[g])),o[g]>=0&&s[e].push(o[g])}i[e]=d}else{if(n[e]===r[e]){for(var v=[],m=[],y=0,d=l.length-1;d>=0;--d){var x=l[d];if(a[x]=!1,v.push(x),m.push(s[x]),y+=s[x].length,o[x]=h.length,x===e){l.length=d;break}}h.push(v);for(var b=new Array(y),d=0;d<m.length;d++)for(var _=0;_<m[d].length;_++)b[--y]=m[d][_];f.push(b)}c.pop()}}}for(var l=0;l<e;++l)r[l]<0&&p(l);for(var l=0;l<f.length;l++){var d=f[l];if(0!==d.length){d.sort(function(t,e){return t-e}),c=[d[0]];for(var g=1;g<d.length;g++)d[g]!==d[g-1]&&c.push(d[g]);f[l]=c}}return{components:h,adjacencyList:f}}},{}],529:[function(t,e,r){"use strict";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=i(t,e),n=r.length,a=new Array(n),o=new Array(n),s=0;s<n;++s)a[s]=[r[s]],o[s]=[s];return{positions:a,cells:o}}(t,e);var r=t.order.join()+"-"+t.dtype,s=o[r],e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,i=["'use strict';"],o="surfaceNets"+t.join("_")+"d"+e;i.push("var contour=genContour({","order:[",t.join(),"],","scalarArguments: 3,","phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },"),"generic"===e&&i.push("getters:[0],");for(var s=[],l=[],c=0;c<r;++c)s.push("d"+c),l.push("d"+c);for(var c=0;c<1<<r;++c)s.push("v"+c),l.push("v"+c);for(var c=0;c<1<<r;++c)s.push("p"+c),l.push("p"+c);s.push("a","b","c"),l.push("a","c"),i.push("vertex:function vertexFunc(",s.join(),"){");for(var u=[],c=0;c<1<<r;++c)u.push("(p"+c+"<<"+c+")");i.push("var m=(",u.join("+"),")|0;if(m===0||m===",(1<<(1<<r))-1,"){return}");var h=[],f=[];1<<(1<<r)<=128?(i.push("switch(m){"),f=i):i.push("switch(m>>>7){");for(var c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){h.length>0&&f.push("}}");var p="vExtra"+h.length;i.push("case ",c>>>7,":",p,"(m&0x7f,",l.join(),");break;"),f=["function ",p,"(m,",l.join(),"){switch(m){"],h.push(f)}f.push("case ",127&c,":");for(var d=new Array(r),g=new Array(r),v=new Array(r),m=new Array(r),y=0,x=0;x<r;++x)d[x]=[],g[x]=[],v[x]=0,m[x]=0;for(var x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?g[b].push("v"+_+"-v"+x):(g[b].push("v"+x+"-v"+_),w=-w),w<0?(d[b].push("-v"+x+"-v"+_),v[b]+=2):(d[b].push("v"+x+"+v"+_),v[b]-=2),y+=1;for(var k=0;k<r;++k)k!==b&&(_&1<<k?m[k]+=1:m[k]-=1)}}for(var T=[],b=0;b<r;++b)if(0===d[b].length)T.push("d"+b+"-0.5");else{var M="";v[b]<0?M=v[b]+"*c":v[b]>0&&(M="+"+v[b]+"*c");var A=d[b].length/y*.5,S=.5+m[b]/y*.5;T.push("d"+b+"-"+S+"-"+A+"*("+d[b].join("+")+M+")/("+g[b].join("+")+")")}f.push("a.push([",T.join(),"]);","break;")}i.push("}},"),h.length>0&&f.push("}}");for(var E=[],c=0;c<1<<r-1;++c)E.push("v"+c);E.push("c0","c1","p0","p1","a","b","c"),i.push("cell:function cellFunc(",E.join(),"){");var L=a(r-1);i.push("if(p0){b.push(",L.map(function(t){return"["+t.map(function(t){return"v"+t})+"]"}).join(),")}else{b.push(",L.map(function(t){var e=t.slice();return e.reverse(),"["+e.map(function(t){return"v"+t})+"]"}).join(),")}}});function ",o,"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return ",o,";");for(var c=0;c<h.length;++c)i.push(h[c].join(""));return new Function("genContour",i.join(""))(n)}(t.order,t.dtype));return s(t,e)};var n=t("ndarray-extract-contour"),a=t("triangulate-hypercube"),i=t("zero-crossings");var o={}},{"ndarray-extract-contour":440,"triangulate-hypercube":539,"zero-crossings":572}],530:[function(t,e,r){"use strict";Object.defineProperty(r,"__esModule",{value:!0});var n=function(){return function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,a=!1,i=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){a=!0,i=t}finally{try{!n&&s.return&&s.return()}finally{if(a)throw i}}return r}(t,e);throw new TypeError("Invalid attempt to destructure non-iterable instance")}}(),a=2*Math.PI,i=function(t,e,r,n,a,i,o){var s=t.x,l=t.y;return{x:n*(s*=e)-a*(l*=r)+i,y:a*s+n*l+o}},o=function(t,e){var r=.551915024494*(e<0?-1:1),n=Math.cos(t),a=Math.sin(t),i=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-a*r,y:a+n*r},{x:i+o*r,y:o-i*r},{x:i,y:o}]},s=function(t,e,r,n){var a=t*n-e*r<0?-1:1,i=(t*r+e*n)/(Math.sqrt(t*t+e*e)*Math.sqrt(t*t+e*e));return i>1&&(i=1),i<-1&&(i=-1),a*Math.acos(i)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,h=t.ry,f=t.xAxisRotation,p=void 0===f?0:f,d=t.largeArcFlag,g=void 0===d?0:d,v=t.sweepFlag,m=void 0===v?0:v,y=[];if(0===u||0===h)return[];var x=Math.sin(p*a/360),b=Math.cos(p*a/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),h=Math.abs(h);var k=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(h,2);k>1&&(u*=Math.sqrt(k),h*=Math.sqrt(k));var T=function(t,e,r,n,i,o,l,c,u,h,f,p){var d=Math.pow(i,2),g=Math.pow(o,2),v=Math.pow(f,2),m=Math.pow(p,2),y=d*g-d*m-g*v;y<0&&(y=0),y/=d*m+g*v;var x=(y=Math.sqrt(y)*(l===c?-1:1))*i/o*p,b=y*-o/i*f,_=h*x-u*b+(t+r)/2,w=u*x+h*b+(e+n)/2,k=(f-x)/i,T=(p-b)/o,M=(-f-x)/i,A=(-p-b)/o,S=s(1,0,k,T),E=s(k,T,M,A);return 0===c&&E>0&&(E-=a),1===c&&E<0&&(E+=a),[_,w,S,E]}(e,r,l,c,u,h,g,m,x,b,_,w),M=n(T,4),A=M[0],S=M[1],E=M[2],L=M[3],C=Math.abs(L)/(a/4);Math.abs(1-C)<1e-7&&(C=1);var P=Math.max(Math.ceil(C),1);L/=P;for(var O=0;O<P;O++)y.push(o(E,L)),E+=L;return y.map(function(t){var e=i(t[0],u,h,b,x,A,S),r=e.x,n=e.y,a=i(t[1],u,h,b,x,A,S),o=a.x,s=a.y,l=i(t[2],u,h,b,x,A,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}})},e.exports=r.default},{}],531:[function(t,e,r){"use strict";var n=t("parse-svg-path"),a=t("abs-svg-path"),i=t("normalize-svg-path"),o=t("is-svg-path"),s=t("assert");e.exports=function(t){Array.isArray(t)&&1===t.length&&"string"==typeof t[0]&&(t=t[0]);"string"==typeof t&&(s(o(t),"String is not an SVG path."),t=n(t));if(s(Array.isArray(t),"Argument should be a string or an array of path segments."),t=a(t),!(t=i(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{"abs-svg-path":63,assert:70,"is-svg-path":425,"normalize-svg-path":532,"parse-svg-path":461}],532:[function(t,e,r){"use strict";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,h=null,f=0,p=0,d=0,g=t.length;d<g;d++){var v=t[d],m=v[0];switch(m){case"M":l=v[1],c=v[2];break;case"A":var y=n({px:f,py:p,cx:v[6],cy:v[7],rx:v[1],ry:v[2],xAxisRotation:v[3],largeArcFlag:v[4],sweepFlag:v[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],v=["C",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(v);break;case"S":var _=f,w=p;"C"!=e&&"S"!=e||(_+=_-o,w+=w-s),v=["C",_,w,v[1],v[2],v[3],v[4]];break;case"T":"Q"==e||"T"==e?(u=2*f-u,h=2*p-h):(u=f,h=p),v=i(f,p,u,h,v[1],v[2]);break;case"Q":u=v[1],h=v[2],v=i(f,p,v[1],v[2],v[3],v[4]);break;case"L":v=a(f,p,v[1],v[2]);break;case"H":v=a(f,p,v[1],p);break;case"V":v=a(f,p,f,v[1]);break;case"Z":v=a(f,p,l,c)}e=m,f=v[v.length-2],p=v[v.length-1],v.length>4?(o=v[v.length-4],s=v[v.length-3]):(o=f,s=p),r.push(v)}return r};var n=t("svg-arc-to-cubic-bezier");function a(t,e,r,n){return["C",t,e,r,n,r,n]}function i(t,e,r,n,a,i){return["C",t/3+2/3*r,e/3+2/3*n,a/3+2/3*r,i/3+2/3*n,a,i]}},{"svg-arc-to-cubic-bezier":530}],533:[function(t,e,r){"use strict";var n,a=t("svg-path-bounds"),i=t("parse-svg-path"),o=t("draw-svg-path"),s=t("is-svg-path"),l=t("bitmap-sdf"),c=document.createElement("canvas"),u=c.getContext("2d");e.exports=function(t,e){if(!s(t))throw Error("Argument should be valid svg path string");e||(e={});var r,h;e.shape?(r=e.shape[0],h=e.shape[1]):(r=c.width=e.w||e.width||200,h=c.height=e.h||e.height||200);var f=Math.min(r,h),p=e.stroke||0,d=e.viewbox||e.viewBox||a(t),g=[r/(d[2]-d[0]),h/(d[3]-d[1])],v=Math.min(g[0]||0,g[1]||0)/2;u.fillStyle="black",u.fillRect(0,0,r,h),u.fillStyle="white",p&&("number"!=typeof p&&(p=1),u.strokeStyle=p>0?"white":"black",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*h),u.scale(v,v),function(){if(null!=n)return n;var t=document.createElement("canvas").getContext("2d");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D("M0,0h1v1h-1v-1Z");t.fillStyle="black",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var m=new Path2D(t);u.fill(m),p&&u.stroke(m)}else{var y=i(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*f})}},{"bitmap-sdf":95,"draw-svg-path":170,"is-svg-path":425,"parse-svg-path":461,"svg-path-bounds":531}],534:[function(t,e,r){(function(r){"use strict";e.exports=function t(e,r,a){var a=a||{};var o=i[e];o||(o=i[e]={" ":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),a=0,i=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[a++]=c[0],n[a++]=c[1]+1.4,i=Math.max(c[0],i)}return{data:n,shape:i}}(n(r,{triangles:!0,font:e,textAlign:a.textAlign||"left",textBaseline:"alphabetic",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\d|\s)/),c=new Array(l.length),u=0,h=0,f=0;f<l.length;++f)c[f]=t(e,l[f]),u+=c[f].data.length,h+=c[f].shape,f>0&&(h+=.02);for(var p=new Float32Array(u),d=0,g=-.5*h,f=0;f<c.length;++f){for(var v=c[f].data,m=0;m<v.length;m+=2)p[d++]=v[m]+g,p[d++]=v[m+1];g+=c[f].shape+.02}s=o[r]={data:p,shape:h}}return s};var n=t("vectorize-text"),a=window||r.global||{},i=a.__TEXT_CACHE||{};a.__TEXT_CACHE={}}).call(this,t("_process"))},{_process:483,"vectorize-text":548}],535:[function(t,e,r){!function(t){var r=/^\s+/,n=/\s+$/,a=0,i=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||"")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var a={r:0,g:0,b:0},i=1,l=null,c=null,u=null,h=!1,f=!1;"string"==typeof e&&(e=function(t){t=t.replace(r,"").replace(n,"").toLowerCase();var e,a=!1;if(S[t])t=S[t],a=!0;else if("transparent"==t)return{r:0,g:0,b:0,a:0,format:"name"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),a:R(e[4]),format:a?"name":"hex8"};if(e=j.hex6.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),format:a?"name":"hex"};if(e=j.hex4.exec(t))return{r:O(e[1]+""+e[1]),g:O(e[2]+""+e[2]),b:O(e[3]+""+e[3]),a:R(e[4]+""+e[4]),format:a?"name":"hex8"};if(e=j.hex3.exec(t))return{r:O(e[1]+""+e[1]),g:O(e[2]+""+e[2]),b:O(e[3]+""+e[3]),format:a?"name":"hex"};return!1}(e));"object"==typeof e&&(V(e.r)&&V(e.g)&&V(e.b)?(p=e.r,d=e.g,g=e.b,a={r:255*C(p,255),g:255*C(d,255),b:255*C(g,255)},h=!0,f="%"===String(e.r).substr(-1)?"prgb":"rgb"):V(e.h)&&V(e.s)&&V(e.v)?(l=I(e.s),c=I(e.v),a=function(e,r,n){e=6*C(e,360),r=C(r,100),n=C(n,100);var a=t.floor(e),i=e-a,o=n*(1-r),s=n*(1-i*r),l=n*(1-(1-i)*r),c=a%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),h=!0,f="hsv"):V(e.h)&&V(e.s)&&V(e.l)&&(l=I(e.s),u=I(e.l),a=function(t,e,r){var n,a,i;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=C(t,360),e=C(e,100),r=C(r,100),0===e)n=a=i=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),a=o(l,s,t),i=o(l,s,t-1/3)}return{r:255*n,g:255*a,b:255*i}}(e.h,l,u),h=!0,f="hsl"),e.hasOwnProperty("a")&&(i=e.a));var p,d,g;return i=L(i),{ok:h,format:e.format||f,r:o(255,s(a.r,0)),g:o(255,s(a.g,0)),b:o(255,s(a.b,0)),a:i}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=i(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=i(this._r)),this._g<1&&(this._g=i(this._g)),this._b<1&&(this._b=i(this._b)),this._ok=u.ok,this._tc_id=a++}function u(t,e,r){t=C(t,255),e=C(e,255),r=C(r,255);var n,a,i=s(t,e,r),l=o(t,e,r),c=(i+l)/2;if(i==l)n=a=0;else{var u=i-l;switch(a=c>.5?u/(2-i-l):u/(i+l),i){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:a,l:c}}function h(t,e,r){t=C(t,255),e=C(e,255),r=C(r,255);var n,a,i=s(t,e,r),l=o(t,e,r),c=i,u=i-l;if(a=0===i?0:u/i,i==l)n=0;else{switch(i){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:a,v:c}}function f(t,e,r,n){var a=[z(i(t).toString(16)),z(i(e).toString(16)),z(i(r).toString(16))];return n&&a[0].charAt(0)==a[0].charAt(1)&&a[1].charAt(0)==a[1].charAt(1)&&a[2].charAt(0)==a[2].charAt(1)?a[0].charAt(0)+a[1].charAt(0)+a[2].charAt(0):a.join("")}function p(t,e,r,n){return[z(D(n)),z(i(t).toString(16)),z(i(e).toString(16)),z(i(r).toString(16))].join("")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=P(r.s),c(r)}function g(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=P(r.s),c(r)}function v(t){return c(t).desaturate(100)}function m(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=P(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-i(-e/100*255))),r.g=s(0,o(255,r.g-i(-e/100*255))),r.b=s(0,o(255,r.b-i(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=P(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function T(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function M(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),a=360/r,i=[c(t)];for(n.h=(n.h-(a*e>>1)+720)%360;--e;)n.h=(n.h+a)%360,i.push(c(n));return i}function A(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,a=r.s,i=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:a,v:i})),i=(i+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,a=this.toRgb();return e=a.r/255,r=a.g/255,n=a.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=L(t),this._roundA=i(100*this._a)/100,this},toHsv:function(){var t=h(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=h(this._r,this._g,this._b),e=i(360*t.h),r=i(100*t.s),n=i(100*t.v);return 1==this._a?"hsv("+e+", "+r+"%, "+n+"%)":"hsva("+e+", "+r+"%, "+n+"%, "+this._roundA+")"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=i(360*t.h),r=i(100*t.s),n=i(100*t.l);return 1==this._a?"hsl("+e+", "+r+"%, "+n+"%)":"hsla("+e+", "+r+"%, "+n+"%, "+this._roundA+")"},toHex:function(t){return f(this._r,this._g,this._b,t)},toHexString:function(t){return"#"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,a){var o=[z(i(t).toString(16)),z(i(e).toString(16)),z(i(r).toString(16)),z(D(n))];if(a&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join("")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return"#"+this.toHex8(t)},toRgb:function(){return{r:i(this._r),g:i(this._g),b:i(this._b),a:this._a}},toRgbString:function(){return 1==this._a?"rgb("+i(this._r)+", "+i(this._g)+", "+i(this._b)+")":"rgba("+i(this._r)+", "+i(this._g)+", "+i(this._b)+", "+this._roundA+")"},toPercentageRgb:function(){return{r:i(100*C(this._r,255))+"%",g:i(100*C(this._g,255))+"%",b:i(100*C(this._b,255))+"%",a:this._a}},toPercentageRgbString:function(){return 1==this._a?"rgb("+i(100*C(this._r,255))+"%, "+i(100*C(this._g,255))+"%, "+i(100*C(this._b,255))+"%)":"rgba("+i(100*C(this._r,255))+"%, "+i(100*C(this._g,255))+"%, "+i(100*C(this._b,255))+"%, "+this._roundA+")"},toName:function(){return 0===this._a?"transparent":!(this._a<1)&&(E[f(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e="#"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?"GradientType = 1, ":"";if(t){var a=c(t);r="#"+p(a._r,a._g,a._b,a._a)}return"progid:DXImageTransform.Microsoft.gradient("+n+"startColorstr="+e+",endColorstr="+r+")"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||"hex"!==t&&"hex6"!==t&&"hex3"!==t&&"hex4"!==t&&"hex8"!==t&&"name"!==t?("rgb"===t&&(r=this.toRgbString()),"prgb"===t&&(r=this.toPercentageRgbString()),"hex"!==t&&"hex6"!==t||(r=this.toHexString()),"hex3"===t&&(r=this.toHexString(!0)),"hex4"===t&&(r=this.toHex8String(!0)),"hex8"===t&&(r=this.toHex8String()),"name"===t&&(r=this.toName()),"hsl"===t&&(r=this.toHslString()),"hsv"===t&&(r=this.toHsvString()),r||this.toHexString()):"name"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(m,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(g,arguments)},greyscale:function(){return this._applyModification(v,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(M,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(A,arguments)},splitcomplement:function(){return this._applyCombination(T,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(k,arguments)}},c.fromRatio=function(t,e){if("object"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]="a"===n?t[n]:I(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),a=c(e).toRgb(),i=r/100;return c({r:(a.r-n.r)*i+n.r,g:(a.g-n.g)*i+n.g,b:(a.b-n.b)*i+n.b,a:(a.a-n.a)*i+n.a})},c.readability=function(e,r){var n=c(e),a=c(r);return(t.max(n.getLuminance(),a.getLuminance())+.05)/(t.min(n.getLuminance(),a.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,a,i=c.readability(t,e);switch(a=!1,(n=function(t){var e,r;e=((t=t||{level:"AA",size:"small"}).level||"AA").toUpperCase(),r=(t.size||"small").toLowerCase(),"AA"!==e&&"AAA"!==e&&(e="AA");"small"!==r&&"large"!==r&&(r="small");return{level:e,size:r}}(r)).level+n.size){case"AAsmall":case"AAAlarge":a=i>=4.5;break;case"AAlarge":a=i>=3;break;case"AAAsmall":a=i>=7}return a},c.mostReadable=function(t,e,r){var n,a,i,o,s=null,l=0;a=(r=r||{}).includeFallbackColors,i=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:i,size:o})||!a?s:(r.includeFallbackColors=!1,c.mostReadable(t,["#fff","#000"],r))};var S=c.names={aliceblue:"f0f8ff",antiquewhite:"faebd7",aqua:"0ff",aquamarine:"7fffd4",azure:"f0ffff",beige:"f5f5dc",bisque:"ffe4c4",black:"000",blanchedalmond:"ffebcd",blue:"00f",blueviolet:"8a2be2",brown:"a52a2a",burlywood:"deb887",burntsienna:"ea7e5d",cadetblue:"5f9ea0",chartreuse:"7fff00",chocolate:"d2691e",coral:"ff7f50",cornflowerblue:"6495ed",cornsilk:"fff8dc",crimson:"dc143c",cyan:"0ff",darkblue:"00008b",darkcyan:"008b8b",darkgoldenrod:"b8860b",darkgray:"a9a9a9",darkgreen:"006400",darkgrey:"a9a9a9",darkkhaki:"bdb76b",darkmagenta:"8b008b",darkolivegreen:"556b2f",darkorange:"ff8c00",darkorchid:"9932cc",darkred:"8b0000",darksalmon:"e9967a",darkseagreen:"8fbc8f",darkslateblue:"483d8b",darkslategray:"2f4f4f",darkslategrey:"2f4f4f",darkturquoise:"00ced1",darkviolet:"9400d3",deeppink:"ff1493",deepskyblue:"00bfff",dimgray:"696969",dimgrey:"696969",dodgerblue:"1e90ff",firebrick:"b22222",floralwhite:"fffaf0",forestgreen:"228b22",fuchsia:"f0f",gainsboro:"dcdcdc",ghostwhite:"f8f8ff",gold:"ffd700",goldenrod:"daa520",gray:"808080",green:"008000",greenyellow:"adff2f",grey:"808080",honeydew:"f0fff0",hotpink:"ff69b4",indianred:"cd5c5c",indigo:"4b0082",ivory:"fffff0",khaki:"f0e68c",lavender:"e6e6fa",lavenderblush:"fff0f5",lawngreen:"7cfc00",lemonchiffon:"fffacd",lightblue:"add8e6",lightcoral:"f08080",lightcyan:"e0ffff",lightgoldenrodyellow:"fafad2",lightgray:"d3d3d3",lightgreen:"90ee90",lightgrey:"d3d3d3",lightpink:"ffb6c1",lightsalmon:"ffa07a",lightseagreen:"20b2aa",lightskyblue:"87cefa",lightslategray:"789",lightslategrey:"789",lightsteelblue:"b0c4de",lightyellow:"ffffe0",lime:"0f0",limegreen:"32cd32",linen:"faf0e6",magenta:"f0f",maroon:"800000",mediumaquamarine:"66cdaa",mediumblue:"0000cd",mediumorchid:"ba55d3",mediumpurple:"9370db",mediumseagreen:"3cb371",mediumslateblue:"7b68ee",mediumspringgreen:"00fa9a",mediumturquoise:"48d1cc",mediumvioletred:"c71585",midnightblue:"191970",mintcream:"f5fffa",mistyrose:"ffe4e1",moccasin:"ffe4b5",navajowhite:"ffdead",navy:"000080",oldlace:"fdf5e6",olive:"808000",olivedrab:"6b8e23",orange:"ffa500",orangered:"ff4500",orchid:"da70d6",palegoldenrod:"eee8aa",palegreen:"98fb98",paleturquoise:"afeeee",palevioletred:"db7093",papayawhip:"ffefd5",peachpuff:"ffdab9",peru:"cd853f",pink:"ffc0cb",plum:"dda0dd",powderblue:"b0e0e6",purple:"800080",rebeccapurple:"663399",red:"f00",rosybrown:"bc8f8f",royalblue:"4169e1",saddlebrown:"8b4513",salmon:"fa8072",sandybrown:"f4a460",seagreen:"2e8b57",seashell:"fff5ee",sienna:"a0522d",silver:"c0c0c0",skyblue:"87ceeb",slateblue:"6a5acd",slategray:"708090",slategrey:"708090",snow:"fffafa",springgreen:"00ff7f",steelblue:"4682b4",tan:"d2b48c",teal:"008080",thistle:"d8bfd8",tomato:"ff6347",turquoise:"40e0d0",violet:"ee82ee",wheat:"f5deb3",white:"fff",whitesmoke:"f5f5f5",yellow:"ff0",yellowgreen:"9acd32"},E=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function L(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function C(e,r){(function(t){return"string"==typeof t&&-1!=t.indexOf(".")&&1===parseFloat(t)})(e)&&(e="100%");var n=function(t){return"string"==typeof t&&-1!=t.indexOf("%")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function P(t){return o(1,s(0,t))}function O(t){return parseInt(t,16)}function z(t){return 1==t.length?"0"+t:""+t}function I(t){return t<=1&&(t=100*t+"%"),t}function D(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return O(t)/255}var F,B,N,j=(B="[\\s|\\(]+("+(F="(?:[-\\+]?\\d*\\.\\d+%?)|(?:[-\\+]?\\d+%?)")+")[,|\\s]+("+F+")[,|\\s]+("+F+")\\s*\\)?",N="[\\s|\\(]+("+F+")[,|\\s]+("+F+")[,|\\s]+("+F+")[,|\\s]+("+F+")\\s*\\)?",{CSS_UNIT:new RegExp(F),rgb:new RegExp("rgb"+B),rgba:new RegExp("rgba"+N),hsl:new RegExp("hsl"+B),hsla:new RegExp("hsla"+N),hsv:new RegExp("hsv"+B),hsva:new RegExp("hsva"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function V(t){return!!j.CSS_UNIT.exec(t)}"undefined"!=typeof e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],536:[function(t,e,r){"use strict";e.exports=a,e.exports.float32=e.exports.float=a,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=a(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return a(t-a(t))};var n=new Float32Array(1);function a(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],537:[function(t,e,r){"use strict";var n=t("parse-unit");e.exports=o;var a=96;function i(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*o(r[1],t)}function o(t,e){switch(e=e||document.body,t=(t||"px").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case"%":return e.clientHeight/100;case"ch":case"ex":return function(t,e){var r=document.createElement("div");r.style["font-size"]="128"+t,e.appendChild(r);var n=i(r,"font-size")/128;return e.removeChild(r),n}(t,e);case"em":return i(e,"font-size");case"rem":return i(document.body,"font-size");case"vw":return window.innerWidth/100;case"vh":return window.innerHeight/100;case"vmin":return Math.min(window.innerWidth,window.innerHeight)/100;case"vmax":return Math.max(window.innerWidth,window.innerHeight)/100;case"in":return a;case"cm":return a/2.54;case"mm":return a/25.4;case"pt":return a/72;case"pc":return a/6}return 1}},{"parse-unit":462}],538:[function(t,e,r){var n;n=this,function(t){"use strict";var e=function(t){return t},r=function(t){if(null==(r=t.transform))return e;var r,n,a,i=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){return e||(n=a=0),t[0]=(n+=t[0])*i+s,t[1]=(a+=t[1])*o+l,t}},n=function(t){var e=t.bbox;function n(t){l[0]=t[0],l[1]=t[1],s(l),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}function a(t){switch(t.type){case"GeometryCollection":t.geometries.forEach(a);break;case"Point":n(t.coordinates);break;case"MultiPoint":t.coordinates.forEach(n)}}if(!e){var i,o,s=r(t),l=new Array(2),c=1/0,u=c,h=-c,f=-c;for(o in t.arcs.forEach(function(t){for(var e=-1,r=t.length;++e<r;)i=t[e],l[0]=i[0],l[1]=i[1],s(l,e),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}),t.objects)a(t.objects[o]);e=t.bbox=[c,u,h,f]}return e},a=function(t,e){for(var r,n=t.length,a=n-e;a<--n;)r=t[a],t[a++]=t[n],t[n]=r};function i(t,e){var r=e.id,n=e.bbox,a=null==e.properties?{}:e.properties,i=o(t,e);return null==r&&null==n?{type:"Feature",properties:a,geometry:i}:null==n?{type:"Feature",id:r,properties:a,geometry:i}:{type:"Feature",id:r,bbox:n,properties:a,geometry:i}}function o(t,e){var n=r(t),i=t.arcs;function o(t,e){e.length&&e.pop();for(var r=i[t<0?~t:t],o=0,s=r.length;o<s;++o)e.push(n(r[o].slice(),o));t<0&&a(e,s)}function s(t){return n(t.slice())}function l(t){for(var e=[],r=0,n=t.length;r<n;++r)o(t[r],e);return e.length<2&&e.push(e[0].slice()),e}function c(t){for(var e=l(t);e.length<4;)e.push(e[0].slice());return e}function u(t){return t.map(c)}return function t(e){var r,n=e.type;switch(n){case"GeometryCollection":return{type:n,geometries:e.geometries.map(t)};case"Point":r=s(e.coordinates);break;case"MultiPoint":r=e.coordinates.map(s);break;case"LineString":r=l(e.arcs);break;case"MultiLineString":r=e.arcs.map(l);break;case"Polygon":r=u(e.arcs);break;case"MultiPolygon":r=e.arcs.map(u);break;default:return null}return{type:n,coordinates:r}}(e)}var s=function(t,e){var r={},n={},a={},i=[],o=-1;function s(t,e){for(var n in t){var a=t[n];delete e[a.start],delete a.start,delete a.end,a.forEach(function(t){r[t<0?~t:t]=1}),i.push(a)}}return e.forEach(function(r,n){var a,i=t.arcs[r<0?~r:r];i.length<3&&!i[1][0]&&!i[1][1]&&(a=e[++o],e[o]=r,e[n]=a)}),e.forEach(function(e){var r,i,o=function(e){var r,n=t.arcs[e<0?~e:e],a=n[0];t.transform?(r=[0,0],n.forEach(function(t){r[0]+=t[0],r[1]+=t[1]})):r=n[n.length-1];return e<0?[r,a]:[a,r]}(e),s=o[0],l=o[1];if(r=a[s])if(delete a[r.end],r.push(e),r.end=l,i=n[l]){delete n[i.start];var c=i===r?r:r.concat(i);n[c.start=r.start]=a[c.end=i.end]=c}else n[r.start]=a[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,i=a[s]){delete a[i.end];var u=i===r?r:i.concat(r);n[u.start=i.start]=a[u.end=r.end]=u}else n[r.start]=a[r.end]=r;else n[(r=[e]).start=s]=a[r.end=l]=r}),s(a,n),s(n,a),e.forEach(function(t){r[t<0?~t:t]||i.push([t])}),i};function l(t,e,r){var n,a,i;if(arguments.length>1)n=function(t,e,r){var n,a=[],i=[];function o(t){var e=t<0?~t:t;(i[e]||(i[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case"GeometryCollection":e.geometries.forEach(t);break;case"LineString":s(e.arcs);break;case"MultiLineString":case"Polygon":l(e.arcs);break;case"MultiPolygon":e.arcs.forEach(l)}}(e),i.forEach(null==r?function(t){a.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&a.push(t[0].i)}),a}(0,e,r);else for(a=0,n=new Array(i=t.arcs.length);a<i;++a)n[a]=a;return{type:"MultiLineString",arcs:s(t,n)}}function c(t,e){var r={},n=[],a=[];function i(t){t.forEach(function(e){e.forEach(function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)})}),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,a=t[n-1],i=0;++r<n;)e=a,a=t[r],i+=e[0]*a[1]-e[1]*a[0];return Math.abs(i)}(o(t,{type:"Polygon",arcs:[e]}).coordinates[0])}return e.forEach(function t(e){switch(e.type){case"GeometryCollection":e.geometries.forEach(t);break;case"Polygon":i(e.arcs);break;case"MultiPolygon":e.arcs.forEach(i)}}),n.forEach(function(t){if(!t._){var e=[],n=[t];for(t._=1,a.push(e);t=n.pop();)e.push(t),t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].forEach(function(t){t._||(t._=1,n.push(t))})})})}}),n.forEach(function(t){delete t._}),{type:"MultiPolygon",arcs:a.map(function(e){var n,a=[];if(e.forEach(function(t){t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].length<2&&a.push(t)})})}),(n=(a=s(t,a)).length)>1)for(var i,o,c=1,u=l(a[0]);c<n;++c)(i=l(a[c]))>u&&(o=a[0],a[0]=a[c],a[c]=o,u=i);return a})}}var u=function(t,e){for(var r=0,n=t.length;r<n;){var a=r+n>>>1;t[a]<e?r=a+1:n=a}return r};t.bbox=n,t.feature=function(t,e){return"GeometryCollection"===e.type?{type:"FeatureCollection",features:e.geometries.map(function(e){return i(t,e)})}:i(t,e)},t.mesh=function(t){return o(t,l.apply(this,arguments))},t.meshArcs=l,t.merge=function(t){return o(t,c.apply(this,arguments))},t.mergeArcs=c,t.neighbors=function(t){var e={},r=t.map(function(){return[]});function n(t,r){t.forEach(function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]})}function a(t,e){t.forEach(function(t){n(t,e)})}var i={LineString:n,MultiLineString:a,Polygon:a,MultiPolygon:function(t,e){t.forEach(function(t){a(t,e)})}};for(var o in t.forEach(function t(e,r){"GeometryCollection"===e.type?e.geometries.forEach(function(e){t(e,r)}):e.type in i&&i[e.type](e.arcs,r)}),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var h=c+1;h<l;++h){var f,p=s[c],d=s[h];(f=r[p])[o=u(f,d)]!==d&&f.splice(o,0,d),(f=r[d])[o=u(f,p)]!==p&&f.splice(o,0,p)}return r},t.quantize=function(t,e){if(!((e=Math.floor(e))>=2))throw new Error("n must be \u22652");if(t.transform)throw new Error("already quantized");var r,a=n(t),i=a[0],o=(a[2]-i)/(e-1)||1,s=a[1],l=(a[3]-s)/(e-1)||1;function c(t){t[0]=Math.round((t[0]-i)/o),t[1]=Math.round((t[1]-s)/l)}function u(t){switch(t.type){case"GeometryCollection":t.geometries.forEach(u);break;case"Point":c(t.coordinates);break;case"MultiPoint":t.coordinates.forEach(c)}}for(r in t.arcs.forEach(function(t){for(var e,r,n,a=1,c=1,u=t.length,h=t[0],f=h[0]=Math.round((h[0]-i)/o),p=h[1]=Math.round((h[1]-s)/l);a<u;++a)h=t[a],r=Math.round((h[0]-i)/o),n=Math.round((h[1]-s)/l),r===f&&n===p||((e=t[c++])[0]=r-f,f=r,e[1]=n-p,p=n);c<2&&((e=t[c++])[0]=0,e[1]=0),t.length=c}),t.objects)u(t.objects[r]);return t.transform={scale:[o,l],translate:[i,s]},t},t.transform=r,t.untransform=function(t){if(null==(r=t.transform))return e;var r,n,a,i=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){e||(n=a=0);var r=Math.round((t[0]-s)/i),c=Math.round((t[1]-l)/o);return t[0]=r-n,n=r,t[1]=c-a,a=c,t}},Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:n.topojson=n.topojson||{})},{}],539:[function(t,e,r){"use strict";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(i(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);a(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t("permutation-rank"),a=t("permutation-parity"),i=t("gamma")},{gamma:234,"permutation-parity":464,"permutation-rank":465}],540:[function(t,e,r){"use strict";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||h(r),a=t.radius||1,i=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),"eye"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=h(r):s(n,n),a=c(d[0],d[1],d[2]);var g=l(r,d)/a,v=l(n,d)/a;u=Math.acos(g),i=Math.acos(v)}return a=Math.log(a),new f(t.zoomMin,t.zoomMax,e,r,n,a,i,u)};var n=t("filtered-vector"),a=t("gl-mat4/invert"),i=t("gl-mat4/rotate"),o=t("gl-vec3/cross"),s=t("gl-vec3/normalize"),l=t("gl-vec3/dot");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function h(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),a=[0,0,0];e>Math.max(r,n)?a[2]=1:r>Math.max(e,n)?a[0]=1:a[1]=1;for(var i=0,o=0,l=0;l<3;++l)i+=t[l]*t[l],o+=a[l]*t[l];for(l=0;l<3;++l)a[l]-=o/i*t[l];return s(a,a),a}function f(t,e,r,a,i,o,s,l){this.center=n(r),this.up=n(a),this.right=n(i),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=f.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,a=0,i=0;i<3;++i)a+=e[i]*r[i],n+=e[i]*e[i];var l=Math.sqrt(n),u=0;for(i=0;i<3;++i)r[i]-=e[i]*a/n,u+=r[i]*r[i],e[i]/=l;var h=Math.sqrt(u);for(i=0;i<3;++i)r[i]/=h;var f=this.computedToward;o(f,e,r),s(f,f);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],g=this.computedAngle[1],v=Math.cos(d),m=Math.sin(d),y=Math.cos(g),x=Math.sin(g),b=this.computedCenter,_=v*y,w=m*y,k=x,T=-v*x,M=-m*x,A=y,S=this.computedEye,E=this.computedMatrix;for(i=0;i<3;++i){var L=_*r[i]+w*f[i]+k*e[i];E[4*i+1]=T*r[i]+M*f[i]+A*e[i],E[4*i+2]=L,E[4*i+3]=0}var C=E[1],P=E[5],O=E[9],z=E[2],I=E[6],D=E[10],R=P*D-O*I,F=O*z-C*D,B=C*I-P*z,N=c(R,F,B);R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B;for(i=0;i<3;++i)S[i]=b[i]+E[2+4*i]*p;for(i=0;i<3;++i){u=0;for(var j=0;j<3;++j)u+=E[i+4*j]*S[j];E[12+i]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var a=this.computedMatrix;d[0]=a[2],d[1]=a[6],d[2]=a[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)a[4*c]=o[c],a[4*c+1]=s[c],a[4*c+2]=l[c];i(a,a,n,d);for(c=0;c<3;++c)o[c]=a[4*c],s[c]=a[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var a=this.computedMatrix,i=(Math.exp(this.computedRadius[0]),a[1]),o=a[5],s=a[9],l=c(i,o,s);i/=l,o/=l,s/=l;var u=a[0],h=a[4],f=a[8],p=u*i+h*o+f*s,d=c(u-=i*p,h-=o*p,f-=s*p),g=(u/=d)*e+i*r,v=(h/=d)*e+o*r,m=(f/=d)*e+s*r;this.center.move(t,g,v,m);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var i=1;"number"==typeof r&&(i=0|r),(i<0||i>3)&&(i=1);var o=(i+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[i],l=e[i+4],h=e[i+8];if(n){var f=Math.abs(s),p=Math.abs(l),d=Math.abs(h),g=Math.max(f,p,d);f===g?(s=s<0?-1:1,l=h=0):d===g?(h=h<0?-1:1,s=l=0):(l=l<0?-1:1,s=h=0)}else{var v=c(s,l,h);s/=v,l/=v,h/=v}var m,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*h,k=c(x-=s*w,b-=l*w,_-=h*w),T=l*(_/=k)-h*(b/=k),M=h*(x/=k)-s*_,A=s*b-l*x,S=c(T,M,A);if(T/=S,M/=S,A/=S,this.center.jump(t,H,G,Y),this.radius.idle(t),this.up.jump(t,s,l,h),this.right.jump(t,x,b,_),2===i){var E=e[1],L=e[5],C=e[9],P=E*x+L*b+C*_,O=E*T+L*M+C*A;m=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(O,P)}else{var z=e[2],I=e[6],D=e[10],R=z*s+I*l+D*h,F=z*x+I*b+D*_,B=z*T+I*M+D*A;m=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,m),this.recalcMatrix(t);var N=e[2],j=e[6],V=e[10],U=this.computedMatrix;a(U,e);var q=U[15],H=U[12]/q,G=U[13]/q,Y=U[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Y-V*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var a=(n=n||this.computedUp)[0],i=n[1],o=n[2],s=c(a,i,o);if(!(s<1e-6)){a/=s,i/=s,o/=s;var l=e[0]-r[0],h=e[1]-r[1],f=e[2]-r[2],p=c(l,h,f);if(!(p<1e-6)){l/=p,h/=p,f/=p;var d=this.computedRight,g=d[0],v=d[1],m=d[2],y=a*g+i*v+o*m,x=c(g-=y*a,v-=y*i,m-=y*o);if(!(x<.01&&(x=c(g=i*f-o*h,v=o*l-a*f,m=a*h-i*l))<1e-6)){g/=x,v/=x,m/=x,this.up.set(t,a,i,o),this.right.set(t,g,v,m),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=i*m-o*v,_=o*g-a*m,w=a*v-i*g,k=c(b,_,w),T=a*l+i*h+o*f,M=g*l+v*h+m*f,A=(b/=k)*l+(_/=k)*h+(w/=k)*f,S=Math.asin(u(T)),E=Math.atan2(A,M),L=this.angle._state,C=L[L.length-1],P=L[L.length-2];C%=2*Math.PI;var O=Math.abs(C+2*Math.PI-E),z=Math.abs(C-E),I=Math.abs(C-2*Math.PI-E);O<z&&(C+=2*Math.PI),I<z&&(C-=2*Math.PI),this.angle.jump(this.angle.lastT(),C,P),this.angle.set(t,E,S)}}}}},{"filtered-vector":229,"gl-mat4/invert":268,"gl-mat4/rotate":273,"gl-vec3/cross":336,"gl-vec3/dot":341,"gl-vec3/normalize":358}],541:[function(t,e,r){"use strict";e.exports=function(t,e,r){var a=t*e,i=n*t,o=i-(i-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,h=s*u-(a-o*c-s*c-o*u);if(r)return r[0]=h,r[1]=a,r;return[h,a]};var n=+(Math.pow(2,27)+1)},{}],542:[function(t,e,r){"use strict";e.exports=function(t,e,r){var n=t+e,a=n-t,i=e-a,o=t-(n-a);if(r)return r[0]=o+i,r[1]=n,r;return[o+i,n]}},{}],543:[function(t,e,r){(function(e,n){"use strict";var a=t("bit-twiddle"),i=t("dup");e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:i([32,0]),UINT16:i([32,0]),UINT32:i([32,0]),INT8:i([32,0]),INT16:i([32,0]),INT32:i([32,0]),FLOAT:i([32,0]),DOUBLE:i([32,0]),DATA:i([32,0]),UINT8C:i([32,0]),BUFFER:i([32,0])});var o="undefined"!=typeof Uint8ClampedArray,s=e.__TYPEDARRAY_POOL;s.UINT8C||(s.UINT8C=i([32,0])),s.BUFFER||(s.BUFFER=i([32,0]));var l=s.DATA,c=s.BUFFER;function u(t){if(t){var e=t.length||t.byteLength,r=a.log2(e);l[r].push(t)}}function h(t){t=a.nextPow2(t);var e=a.log2(t),r=l[e];return r.length>0?r.pop():new ArrayBuffer(t)}function f(t){return new Uint8Array(h(t),0,t)}function p(t){return new Uint16Array(h(2*t),0,t)}function d(t){return new Uint32Array(h(4*t),0,t)}function g(t){return new Int8Array(h(t),0,t)}function v(t){return new Int16Array(h(2*t),0,t)}function m(t){return new Int32Array(h(4*t),0,t)}function y(t){return new Float32Array(h(4*t),0,t)}function x(t){return new Float64Array(h(8*t),0,t)}function b(t){return o?new Uint8ClampedArray(h(t),0,t):f(t)}function _(t){return new DataView(h(t),0,t)}function w(t){t=a.nextPow2(t);var e=a.log2(t),r=c[e];return r.length>0?r.pop():new n(t)}r.free=function(t){if(n.isBuffer(t))c[a.log2(t.length)].push(t);else{if("[object ArrayBuffer]"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|a.log2(e);l[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeInt8=r.freeInt16=r.freeInt32=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){u(t.buffer)},r.freeArrayBuffer=u,r.freeBuffer=function(t){c[a.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||"arraybuffer"===e)return h(t);switch(e){case"uint8":return f(t);case"uint16":return p(t);case"uint32":return d(t);case"int8":return g(t);case"int16":return v(t);case"int32":return m(t);case"float":case"float32":return y(t);case"double":case"float64":return x(t);case"uint8_clamped":return b(t);case"buffer":return w(t);case"data":case"dataview":return _(t);default:return null}return null},r.mallocArrayBuffer=h,r.mallocUint8=f,r.mallocUint16=p,r.mallocUint32=d,r.mallocInt8=g,r.mallocInt16=v,r.mallocInt32=m,r.mallocFloat32=r.mallocFloat=y,r.mallocFloat64=r.mallocDouble=x,r.mallocUint8Clamped=b,r.mallocDataView=_,r.mallocBuffer=w,r.clearCache=function(){for(var t=0;t<32;++t)s.UINT8[t].length=0,s.UINT16[t].length=0,s.UINT32[t].length=0,s.INT8[t].length=0,s.INT16[t].length=0,s.INT32[t].length=0,s.FLOAT[t].length=0,s.DOUBLE[t].length=0,s.UINT8C[t].length=0,l[t].length=0,c[t].length=0}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{},t("buffer").Buffer)},{"bit-twiddle":94,buffer:107,dup:172}],544:[function(t,e,r){"use strict";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var a=n.prototype;Object.defineProperty(a,"length",{get:function(){return this.roots.length}}),a.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},a.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},a.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var a=this.ranks,i=this.roots,o=a[r],s=a[n];o<s?i[r]=n:s<o?i[n]=r:(i[n]=r,++a[r])}}},{}],545:[function(t,e,r){"use strict";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,a=t[0],i=t[0],o=1;o<n;++o)if(i=a,e(a=t[o],i)){if(o===r){r++;continue}t[r++]=a}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],a=t[0],i=1;i<r;++i,a=n)if(a=n,(n=t[i])!==a){if(i===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],546:[function(t,e,r){var n=/[\'\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):""}},{}],547:[function(t,e,r){"use strict";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,a=r.length;n<a;n++){var i=r[n];for(var o in i)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===i[o])s=e[o];else{if(!1===i[o])continue;if("function"==typeof i[o]&&void 0===(s=i[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],548:[function(t,e,r){"use strict";e.exports=function(t,e){"object"==typeof e&&null!==e||(e={});return n(t,e.canvas||a,e.context||i,e)};var n=t("./lib/vtext"),a=null,i=null;"undefined"!=typeof document&&((a=document.createElement("canvas")).width=8192,a.height=1024,i=a.getContext("2d"))},{"./lib/vtext":549}],549:[function(t,e,r){e.exports=function(t,e,r,n){var i=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(i=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,i+"px",n.font].filter(function(t){return t}).join(" "),r.textAlign="start",r.textBaseline="alphabetic",r.direction="ltr",w(function(t,e,r,n,i,o){r=r.replace(/\n/g,""),r=!0===o.breaklines?r.replace(/\<br\>/g,"\n"):r.replace(/\<br\>/g," ");var s="",l=[];for(k=0;k<r.length;++k)l[k]=s;!0===o.bolds&&(l=x(c,u,r,l)),!0===o.italics&&(l=x(h,f,r,l)),!0===o.superscripts&&(l=x(p,g,r,l)),!0===o.subscripts&&(l=x(v,y,r,l));var b=[],_="";for(k=0;k<r.length;++k)null!==l[k]&&(_+=r[k],b.push(l[k]));var w,k,T,M,A,S=_.split("\n"),E=S.length,L=Math.round(i*n),C=n,P=2*n,O=0,z=E*L+P;t.height<z&&(t.height=z),e.fillStyle="#000",e.fillRect(0,0,t.width,t.height),e.fillStyle="#fff";var I=0,D="";function R(){if(""!==D){var t=e.measureText(D).width;e.fillText(D,C+T,P+M),T+=t}}function F(){return Math.round(A)+"px "}function B(t,r){var n=""+e.font;if(!0===o.subscripts){var a=t.indexOf(m),i=r.indexOf(m),s=a>-1?parseInt(t[1+a]):0,l=i>-1?parseInt(r[1+i]):0;s!==l&&(n=n.replace(F(),"?px "),A*=Math.pow(.75,l-s),n=n.replace("?px ",F())),M+=.25*L*(l-s)}if(!0===o.superscripts){var c=t.indexOf(d),h=r.indexOf(d),p=c>-1?parseInt(t[1+c]):0,g=h>-1?parseInt(r[1+h]):0;p!==g&&(n=n.replace(F(),"?px "),A*=Math.pow(.75,g-p),n=n.replace("?px ",F())),M-=.25*L*(g-p)}if(!0===o.bolds){var v=t.indexOf(u)>-1,y=r.indexOf(u)>-1;!v&&y&&(n=x?n.replace("italic ","italic bold "):"bold "+n),v&&!y&&(n=n.replace("bold ",""))}if(!0===o.italics){var x=t.indexOf(f)>-1,b=r.indexOf(f)>-1;!x&&b&&(n="italic "+n),x&&!b&&(n=n.replace("italic ",""))}e.font=n}for(w=0;w<E;++w){var N=S[w]+"\n";for(T=0,M=w*L,A=n,D="",k=0;k<N.length;++k){var j=k+I<b.length?b[k+I]:b[b.length-1];s===j?D+=N[k]:(R(),D=N[k],void 0!==j&&(B(s,j),s=j))}R(),I+=N.length;var V=0|Math.round(T+2*C);O<V&&(O=V)}var U=O,q=P+L*E;return a(e.getImageData(0,0,U,q).data,[q,U,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,i,o,s),n,i)},e.exports.processPixels=w;var n=t("surface-nets"),a=t("ndarray"),i=t("simplify-planar-graph"),o=t("clean-pslg"),s=t("cdt2d"),l=t("planar-graph-to-polyline"),c="b",u="b|",h="i",f="i|",p="sup",d="+",g="+1",v="sub",m="-",y="-1";function x(t,e,r,n){for(var a="<"+t+">",i="</"+t+">",o=a.length,s=i.length,l=e[0]===d||e[0]===m,c=0,u=-s;c>-1&&-1!==(c=r.indexOf(a,c))&&-1!==(u=r.indexOf(i,c+o))&&!(u<=c);){for(var h=c;h<u+s;++h)if(h<c+o||h>=u)n[h]=null,r=r.substr(0,h)+" "+r.substr(h+1);else if(null!==n[h]){var f=n[h].indexOf(e[0]);-1===f?n[h]+=e:l&&(n[h]=n[h].substr(0,f+1)+(1+parseInt(n[h][f+1]))+n[h].substr(f+2))}var p=c+o,g=r.substr(p,u-p).indexOf(a);c=-1!==g?g:u+s}return n}function b(t,e){var r=n(t,128);return e?i(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function _(t,e,r,n){var a=b(t,n),i=function(t,e,r){for(var n=e.textAlign||"start",a=e.textBaseline||"alphabetic",i=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)i[u]=0|Math.min(i[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var h=0;switch(n){case"center":h=-.5*(i[0]+o[0]);break;case"right":case"end":h=-o[0];break;case"left":case"start":h=-i[0];break;default:throw new Error("vectorize-text: Unrecognized textAlign: '"+n+"'")}var f=0;switch(a){case"hanging":case"top":f=-i[1];break;case"middle":f=-.5*(i[1]+o[1]);break;case"alphabetic":case"ideographic":f=-3*r;break;case"bottom":f=-o[1];break;default:throw new Error("vectorize-text: Unrecoginized textBaseline: '"+a+"'")}var p=1/r;return"lineHeight"in e?p*=+e.lineHeight:"width"in e?p=e.width/(o[0]-i[0]):"height"in e&&(p=e.height/(o[1]-i[1])),t.map(function(t){return[p*(t[0]+h),p*(t[1]+f)]})}(a.positions,e,r),c=a.edges,u="ccw"===e.orientation;if(o(i,c),e.polygons||e.polygon||e.polyline){for(var h=l(c,i),f=new Array(h.length),p=0;p<h.length;++p){for(var d=h[p],g=new Array(d.length),v=0;v<d.length;++v){for(var m=d[v],y=new Array(m.length),x=0;x<m.length;++x)y[x]=i[m[x]].slice();u&&y.reverse(),g[v]=y}f[p]=g}return f}return e.triangles||e.triangulate||e.triangle?{cells:s(i,c,{delaunay:!1,exterior:!1,interior:!0}),positions:i}:{edges:c,positions:i}}function w(t,e,r){try{return _(t,e,r,!0)}catch(t){}try{return _(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:108,"clean-pslg":118,ndarray:451,"planar-graph-to-polyline":469,"simplify-planar-graph":522,"surface-nets":529}],550:[function(t,e,r){!function(){"use strict";if("undefined"==typeof ses||!ses.ok||ses.ok()){"undefined"!=typeof ses&&(ses.weakMapPermitHostObjects=v);var t=!1;if("function"==typeof WeakMap){var r=WeakMap;if("undefined"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,a=Object.freeze({});if(n.set(a,1),1===n.get(a))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var i=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l="weakmap:",c=l+"ident:"+Math.random()+"___";if("undefined"!=typeof crypto&&"function"==typeof crypto.getRandomValues&&"function"==typeof ArrayBuffer&&"function"==typeof Uint8Array){var u=new ArrayBuffer(25),h=new Uint8Array(u);crypto.getRandomValues(h),c=l+"rand:"+Array.prototype.map.call(h,function(t){return(t%36).toString(36)}).join("")+"___"}if(o(Object,"getOwnPropertyNames",{value:function(t){return i(t).filter(m)}}),"getPropertyNames"in Object){var f=Object.getPropertyNames;o(Object,"getPropertyNames",{value:function(t){return f(t).filter(m)}})}!function(){var t=Object.freeze;o(Object,"freeze",{value:function(e){return y(e),t(e)}});var e=Object.seal;o(Object,"seal",{value:function(t){return y(t),e(t)}});var r=Object.preventExtensions;o(Object,"preventExtensions",{value:function(t){return y(t),r(t)}})}();var p=!1,d=0,g=function(){this instanceof g||b();var t=[],e=[],r=d++;return Object.create(g.prototype,{get___:{value:x(function(n,a){var i,o=y(n);return o?r in o?o[r]:a:(i=t.indexOf(n))>=0?e[i]:a})},has___:{value:x(function(e){var n=y(e);return n?r in n:t.indexOf(e)>=0})},set___:{value:x(function(n,a){var i,o=y(n);return o?o[r]=a:(i=t.indexOf(n))>=0?e[i]=a:(i=t.length,e[i]=a,t[i]=n),this})},delete___:{value:x(function(n){var a,i,o=y(n);return o?r in o&&delete o[r]:!((a=t.indexOf(n))<0||(i=t.length-1,t[a]=void 0,e[a]=e[i],t[a]=t[i],t.length=i,e.length=i,0))})}})};g.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),"function"==typeof r?function(){function n(){this instanceof g||b();var e,n=new r,a=void 0,i=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(a||(a=new g),a.set(t,e)),this}:function(t,e){if(i)try{n.set(t,e)}catch(r){a||(a=new g),a.set___(t,e)}else n.set(t,e);return this},Object.create(g.prototype,{get___:{value:x(function(t,e){return a?n.has(t)?n.get(t):a.get___(t,e):n.get(t,e)})},has___:{value:x(function(t){return n.has(t)||!!a&&a.has___(t)})},set___:{value:x(e)},delete___:{value:x(function(t){var e=!!n.delete(t);return a&&a.delete___(t)||e})},permitHostObjects___:{value:x(function(t){if(t!==v)throw new Error("bogus call to permitHostObjects___");i=!0})}})}t&&"undefined"!=typeof Proxy&&(Proxy=void 0),n.prototype=g.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,"constructor",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():("undefined"!=typeof Proxy&&(Proxy=void 0),e.exports=g)}function v(t){t.permitHostObjects___&&t.permitHostObjects___(v)}function m(t){return!(t.substr(0,l.length)==l&&"___"===t.substr(t.length-3))}function y(t){if(t!==Object(t))throw new TypeError("Not an object: "+t);var e=t[c];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,c,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function x(t){return t.prototype=null,Object.freeze(t)}function b(){p||"undefined"==typeof console||(p=!0,console.warn("WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future."))}}()},{}],551:[function(t,e,r){var n=t("./hidden-store.js");e.exports=function(){var t={};return function(e){if(("object"!=typeof e||null===e)&&"function"!=typeof e)throw new Error("Weakmap-shim: Key must be object");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{"./hidden-store.js":552}],552:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,"valueOf",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],553:[function(t,e,r){var n=t("./create-store.js");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty("value")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return"value"in t(e)},delete:function(e){return delete t(e).value}}}},{"./create-store.js":551}],554:[function(t,e,r){var n=t("get-canvas-context");e.exports=function(t){return n("webgl",t)}},{"get-canvas-context":235}],555:[function(t,e,r){var n=t("../main"),a=t("object-assign"),i=n.instance();function o(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}o.prototype=new n.baseCalendar,a(o.prototype,{name:"Chinese",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{"":{name:"Chinese",epochs:["BEC","EC"],monthNumbers:function(t,e){if("string"==typeof t){var r=t.match(l);return r?r[0]:""}var n=this._validateYear(t),a=t.month(),i=""+this.toChineseMonth(n,a);return e&&i.length<2&&(i="0"+i),this.isIntercalaryMonth(n,a)&&(i+="i"),i},monthNames:function(t){if("string"==typeof t){var e=t.match(c);return e?e[0]:""}var r=this._validateYear(t),n=t.month(),a=["\u4e00\u6708","\u4e8c\u6708","\u4e09\u6708","\u56db\u6708","\u4e94\u6708","\u516d\u6708","\u4e03\u6708","\u516b\u6708","\u4e5d\u6708","\u5341\u6708","\u5341\u4e00\u6708","\u5341\u4e8c\u6708"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(a="\u95f0"+a),a},monthNamesShort:function(t){if("string"==typeof t){var e=t.match(u);return e?e[0]:""}var r=this._validateYear(t),n=t.month(),a=["\u4e00","\u4e8c","\u4e09","\u56db","\u4e94","\u516d","\u4e03","\u516b","\u4e5d","\u5341","\u5341\u4e00","\u5341\u4e8c"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(a="\u95f0"+a),a},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))"\u95f0"===e[0]&&(r=!0,e=e.substring(1)),"\u6708"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+["\u4e00","\u4e8c","\u4e09","\u56db","\u4e94","\u516d","\u4e03","\u516b","\u4e5d","\u5341","\u5341\u4e00","\u5341\u4e8c"].indexOf(e);else{var a=e[e.length-1];r="i"===a||"I"===a}return this.toMonthIndex(t,n,r)},dayNames:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayNamesShort:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],dayNamesMin:["Su","Mo","Tu","We","Th","Fr","Sa"],digits:null,dateFormat:"yyyy/mm/dd",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),"number"!=typeof t||t<1888||t>2111)throw e.replace(/\{0\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var a=this.intercalaryMonth(t);if(r&&e!==a||e<1||e>12)throw n.local.invalidMonth.replace(/\{0\}/,this.local.name);return a?!r&&e<=a?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\{0\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),h[t-h[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var a,o=this._validateYear(t,n.local.invalidyear),s=f[o-f[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(a=i.newDate(l,c,u)).add(4-(a.dayOfWeek()||7),"d");var h=this.toJD(t,e,r)-a.toJD();return 1+Math.floor(h/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=h[t-h[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\{0\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(a.year()),e=a.month(),r=a.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,a){var i,o,s;if("object"==typeof t)o=t,i=e||{};else{var l="number"==typeof t&&t>=1888&&t<=2111;if(!l)throw new Error("Lunar year outside range 1888-2111");var c="number"==typeof e&&e>=1&&e<=12;if(!c)throw new Error("Lunar month outside range 1 - 12");var u,p="number"==typeof r&&r>=1&&r<=30;if(!p)throw new Error("Lunar day outside range 1 - 30");"object"==typeof n?(u=!1,i=n):(u=!!n,i=a||{}),o={year:t,month:e,day:r,isIntercalary:u}}s=o.day-1;var d,g=h[o.year-h[0]],v=g>>13;d=v?o.month>v?o.month:o.isIntercalary?o.month:o.month-1:o.month-1;for(var m=0;m<d;m++){var y=g&1<<12-m?30:29;s+=y}var x=f[o.year-f[0]],b=new Date(x>>9&4095,(x>>5&15)-1,(31&x)+s);return i.year=b.getFullYear(),i.month=1+b.getMonth(),i.day=b.getDate(),i}(t,s,r,o);return i.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=i.fromJD(t),r=function(t,e,r,n){var a,i;if("object"==typeof t)a=t,i=e||{};else{var o="number"==typeof t&&t>=1888&&t<=2111;if(!o)throw new Error("Solar year outside range 1888-2111");var s="number"==typeof e&&e>=1&&e<=12;if(!s)throw new Error("Solar month outside range 1 - 12");var l="number"==typeof r&&r>=1&&r<=31;if(!l)throw new Error("Solar day outside range 1 - 31");a={year:t,month:e,day:r},i=n||{}}var c=f[a.year-f[0]],u=a.year<<9|a.month<<5|a.day;i.year=u>=c?a.year:a.year-1,c=f[i.year-f[0]];var p,d=new Date(c>>9&4095,(c>>5&15)-1,31&c),g=new Date(a.year,a.month-1,a.day);p=Math.round((g-d)/864e5);var v,m=h[i.year-h[0]];for(v=0;v<13;v++){var y=m&1<<12-v?30:29;if(p<y)break;p-=y}var x=m>>13;!x||v<x?(i.isIntercalary=!1,i.month=1+v):v===x?(i.isIntercalary=!0,i.month=v):(i.isIntercalary=!1,i.month=v);return i.day=1+p,i}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],a=!!e[3],i=this.toMonthIndex(r,n,a),o=+e[4];return this.newDate(r,i,o)},add:function(t,e,r){var n=t.year(),a=t.month(),i=this.isIntercalaryMonth(n,a),s=this.toChineseMonth(n,a),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if("y"===r){var c=l.year(),u=l.month(),h=this.isIntercalaryMonth(c,s),f=i&&h?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);f!==u&&l.month(f)}return l}});var s=/^\s*(-?\d\d\d\d|\d\d)[-/](\d?\d)([iI]?)[-/](\d?\d)/m,l=/^\d?\d[iI]?/m,c=/^\u95f0?\u5341?[\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d]?\u6708/m,u=/^\u95f0?\u5341?[\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d]?/m;n.calendars.chinese=o;var h=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],f=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{"../main":569,"object-assign":455}],556:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Coptic",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Coptic",epochs:["BAM","AM"],monthNames:["Thout","Paopi","Hathor","Koiak","Tobi","Meshir","Paremhat","Paremoude","Pashons","Paoni","Epip","Mesori","Pi Kogi Enavot"],monthNamesShort:["Tho","Pao","Hath","Koi","Tob","Mesh","Pat","Pad","Pash","Pao","Epi","Meso","PiK"],dayNames:["Tkyriaka","Pesnau","Pshoment","Peftoou","Ptiou","Psoou","Psabbaton"],dayNamesShort:["Tky","Pes","Psh","Pef","Pti","Pso","Psa"],dayNamesMin:["Tk","Pes","Psh","Pef","Pt","Pso","Psa"],digits:null,dateFormat:"dd/mm/yyyy",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[""].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return(t=a.year())<0&&t++,a.day()+30*(a.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,a=e-30*(n-1)+1;return this.newDate(r,n,a)}}),n.calendars.coptic=i},{"../main":569,"object-assign":455}],557:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Discworld",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Discworld",epochs:["BUC","UC"],monthNames:["Ick","Offle","February","March","April","May","June","Grune","August","Spune","Sektober","Ember","December"],monthNamesShort:["Ick","Off","Feb","Mar","Apr","May","Jun","Gru","Aug","Spu","Sek","Emb","Dec"],dayNames:["Sunday","Octeday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayNamesShort:["Sun","Oct","Mon","Tue","Wed","Thu","Fri","Sat"],dayNamesMin:["Su","Oc","Mo","Tu","We","Th","Fr","Sa"],digits:null,dateFormat:"yyyy/mm/dd",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),"d"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((a.year()-1)/100)+1]||""}},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return t=a.year()+(a.year()<0?1:0),e=a.month(),(r=a.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:"Fruitbat",21:"Anchovy"};n.calendars.discworld=i},{"../main":569,"object-assign":455}],558:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Ethiopian",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Ethiopian",epochs:["BEE","EE"],monthNames:["Meskerem","Tikemet","Hidar","Tahesas","Tir","Yekatit","Megabit","Miazia","Genbot","Sene","Hamle","Nehase","Pagume"],monthNamesShort:["Mes","Tik","Hid","Tah","Tir","Yek","Meg","Mia","Gen","Sen","Ham","Neh","Pag"],dayNames:["Ehud","Segno","Maksegno","Irob","Hamus","Arb","Kidame"],dayNamesShort:["Ehu","Seg","Mak","Iro","Ham","Arb","Kid"],dayNamesMin:["Eh","Se","Ma","Ir","Ha","Ar","Ki"],digits:null,dateFormat:"dd/mm/yyyy",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[""].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return(t=a.year())<0&&t++,a.day()+30*(a.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,a=e-30*(n-1)+1;return this.newDate(r,n,a)}}),n.calendars.ethiopian=i},{"../main":569,"object-assign":455}],559:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}function o(t,e){return t-e*Math.floor(t/e)}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Hebrew",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{"":{name:"Hebrew",epochs:["BAM","AM"],monthNames:["Nisan","Iyar","Sivan","Tammuz","Av","Elul","Tishrei","Cheshvan","Kislev","Tevet","Shevat","Adar","Adar II"],monthNamesShort:["Nis","Iya","Siv","Tam","Av","Elu","Tis","Che","Kis","Tev","She","Ada","Ad2"],dayNames:["Yom Rishon","Yom Sheni","Yom Shlishi","Yom Revi'i","Yom Chamishi","Yom Shishi","Yom Shabbat"],dayNamesShort:["Ris","She","Shl","Rev","Cha","Shi","Sha"],dayNamesMin:["Ri","She","Shl","Re","Ch","Shi","Sha"],digits:null,dateFormat:"dd/mm/yyyy",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)?30:8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(a)?"embolismic":"common")+" "+["deficient","regular","complete"][this.daysInYear(a)%10-3]}},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);t=a.year(),e=a.month(),r=a.day();var i=t<=0?t+1:t,o=this.jdEpoch+this._delay1(i)+this._delay2(i)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=i},{"../main":569,"object-assign":455}],560:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Islamic",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Islamic",epochs:["BH","AH"],monthNames:["Muharram","Safar","Rabi' al-awwal","Rabi' al-thani","Jumada al-awwal","Jumada al-thani","Rajab","Sha'aban","Ramadan","Shawwal","Dhu al-Qi'dah","Dhu al-Hijjah"],monthNamesShort:["Muh","Saf","Rab1","Rab2","Jum1","Jum2","Raj","Sha'","Ram","Shaw","DhuQ","DhuH"],dayNames:["Yawm al-ahad","Yawm al-ithnayn","Yawm ath-thulaathaa'","Yawm al-arbi'aa'","Yawm al-kham\u012bs","Yawm al-jum'a","Yawm as-sabt"],dayNamesShort:["Aha","Ith","Thu","Arb","Kha","Jum","Sab"],dayNamesMin:["Ah","It","Th","Ar","Kh","Ju","Sa"],digits:null,dateFormat:"yyyy/mm/dd",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return t=a.year(),e=a.month(),t=t<=0?t+1:t,(r=a.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=i},{"../main":569,"object-assign":455}],561:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Julian",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Julian",epochs:["BC","AD"],monthNames:["January","February","March","April","May","June","July","August","September","October","November","December"],monthNamesShort:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayNames:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayNamesShort:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],dayNamesMin:["Su","Mo","Tu","We","Th","Fr","Sa"],digits:null,dateFormat:"mm/dd/yyyy",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return t=a.year(),e=a.month(),r=a.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),a=Math.floor((e-n)/30.6001),i=a-Math.floor(a<14?1:13),o=r-Math.floor(i>2?4716:4715),s=e-n-Math.floor(30.6001*a);return o<=0&&o--,this.newDate(o,i,s)}}),n.calendars.julian=i},{"../main":569,"object-assign":455}],562:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Mayan",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{"":{name:"Mayan",epochs:["",""],monthNames:["0","1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17"],monthNamesShort:["0","1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17"],dayNames:["0","1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17","18","19"],dayNamesShort:["0","1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17","18","19"],dayNamesMin:["0","1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17","18","19"],digits:null,dateFormat:"YYYY.m.d",firstDay:0,isRTL:!1,haabMonths:["Pop","Uo","Zip","Zotz","Tzec","Xul","Yaxkin","Mol","Chen","Yax","Zac","Ceh","Mac","Kankin","Muan","Pax","Kayab","Cumku","Uayeb"],tzolkinMonths:["Imix","Ik","Akbal","Kan","Chicchan","Cimi","Manik","Lamat","Muluc","Oc","Chuen","Eb","Ben","Ix","Men","Cib","Caban","Etznab","Cauac","Ahau"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+"."+Math.floor(t/20)+"."+t%20},forYear:function(t){if((t=t.split(".")).length<3)throw"Invalid Mayan year";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw"Invalid Mayan year";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate).toJD(),i=this._toHaab(a),o=this._toTzolkin(a);return{haabMonthName:this.local.haabMonths[i[0]-1],haabMonth:i[0],haabDay:i[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return a.day()+20*a.month()+360*a.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=i},{"../main":569,"object-assign":455}],563:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}i.prototype=new n.baseCalendar;var o=n.instance("gregorian");a(i.prototype,{name:"Nanakshahi",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Nanakshahi",epochs:["BN","AN"],monthNames:["Chet","Vaisakh","Jeth","Harh","Sawan","Bhadon","Assu","Katak","Maghar","Poh","Magh","Phagun"],monthNamesShort:["Che","Vai","Jet","Har","Saw","Bha","Ass","Kat","Mgr","Poh","Mgh","Pha"],dayNames:["Somvaar","Mangalvar","Budhvaar","Veervaar","Shukarvaar","Sanicharvaar","Etvaar"],dayNamesShort:["Som","Mangal","Budh","Veer","Shukar","Sanichar","Et"],dayNamesMin:["So","Ma","Bu","Ve","Sh","Sa","Et"],digits:null,dateFormat:"dd-mm-yyyy",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[""].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidMonth);(t=a.year())<0&&t++;for(var i=a.day(),s=1;s<a.month();s++)i+=this.daysPerMonth[s-1];return i+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=i},{"../main":569,"object-assign":455}],564:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Nepali",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{"":{name:"Nepali",epochs:["BBS","ABS"],monthNames:["Baisakh","Jestha","Ashadh","Shrawan","Bhadra","Ashwin","Kartik","Mangsir","Paush","Mangh","Falgun","Chaitra"],monthNamesShort:["Bai","Je","As","Shra","Bha","Ash","Kar","Mang","Pau","Ma","Fal","Chai"],dayNames:["Aaitabaar","Sombaar","Manglbaar","Budhabaar","Bihibaar","Shukrabaar","Shanibaar"],dayNamesShort:["Aaita","Som","Mangl","Budha","Bihi","Shukra","Shani"],dayNamesMin:["Aai","So","Man","Bu","Bi","Shu","Sha"],digits:null,dateFormat:"dd/mm/yyyy",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),"undefined"==typeof this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),"undefined"==typeof this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);t=a.year(),e=a.month(),r=a.day();var i=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=i.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],i.newDate(c,1,1).add(o,"d").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),a=e.dayOfYear(),i=r+56;this._createMissingCalendarData(i);for(var o=9,s=this.NEPALI_CALENDAR_DATA[i][0],l=this.NEPALI_CALENDAR_DATA[i][o]-s+1;a>l;)++o>12&&(o=1,i++),l+=this.NEPALI_CALENDAR_DATA[i][o];var c=this.NEPALI_CALENDAR_DATA[i][o]-(l-a);return this.newDate(i,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)"undefined"==typeof this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2000:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=i},{"../main":569,"object-assign":455}],565:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}function o(t,e){return t-e*Math.floor(t/e)}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Persian",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Persian",epochs:["BP","AP"],monthNames:["Farvardin","Ordibehesht","Khordad","Tir","Mordad","Shahrivar","Mehr","Aban","Azar","Day","Bahman","Esfand"],monthNamesShort:["Far","Ord","Kho","Tir","Mor","Sha","Meh","Aba","Aza","Day","Bah","Esf"],dayNames:["Yekshambe","Doshambe","Seshambe","Ch\xe6harshambe","Panjshambe","Jom'e","Shambe"],dayNamesShort:["Yek","Do","Se","Ch\xe6","Panj","Jom","Sha"],dayNamesMin:["Ye","Do","Se","Ch","Pa","Jo","Sh"],digits:null,dateFormat:"yyyy/mm/dd",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);t=a.year(),e=a.month(),r=a.day();var i=t-(t>=0?474:473),s=474+o(i,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(i/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),a=2820;if(1029982!==n){var i=Math.floor(n/366),s=o(n,366);a=Math.floor((2134*i+2816*s+2815)/1028522)+i+1}var l=a+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),h=t-this.toJD(l,u,1)+1;return this.newDate(l,u,h)}}),n.calendars.persian=i,n.calendars.jalali=i},{"../main":569,"object-assign":455}],566:[function(t,e,r){var n=t("../main"),a=t("object-assign"),i=n.instance();function o(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}o.prototype=new n.baseCalendar,a(o.prototype,{name:"Taiwan",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Taiwan",epochs:["BROC","ROC"],monthNames:["January","February","March","April","May","June","July","August","September","October","November","December"],monthNamesShort:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayNames:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayNamesShort:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],dayNamesMin:["Su","Mo","Tu","We","Th","Fr","Sa"],digits:null,dateFormat:"yyyy/mm/dd",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return i.leapYear(t)},weekOfYear:function(t,e,r){var a=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(a.year());return i.weekOfYear(t,a.month(),a.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(a.year());return i.toJD(t,a.month(),a.day())},fromJD:function(t){var e=i.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{"../main":569,"object-assign":455}],567:[function(t,e,r){var n=t("../main"),a=t("object-assign"),i=n.instance();function o(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}o.prototype=new n.baseCalendar,a(o.prototype,{name:"Thai",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Thai",epochs:["BBE","BE"],monthNames:["January","February","March","April","May","June","July","August","September","October","November","December"],monthNamesShort:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayNames:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayNamesShort:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],dayNamesMin:["Su","Mo","Tu","We","Th","Fr","Sa"],digits:null,dateFormat:"dd/mm/yyyy",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return i.leapYear(t)},weekOfYear:function(t,e,r){var a=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(a.year());return i.weekOfYear(t,a.month(),a.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(a.year());return i.toJD(t,a.month(),a.day())},fromJD:function(t){var e=i.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{"../main":569,"object-assign":455}],568:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}i.prototype=new n.baseCalendar,a(i.prototype,{name:"UmmAlQura",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Umm al-Qura",epochs:["BH","AH"],monthNames:["Al-Muharram","Safar","Rabi' al-awwal","Rabi' Al-Thani","Jumada Al-Awwal","Jumada Al-Thani","Rajab","Sha'aban","Ramadan","Shawwal","Dhu al-Qi'dah","Dhu al-Hijjah"],monthNamesShort:["Muh","Saf","Rab1","Rab2","Jum1","Jum2","Raj","Sha'","Ram","Shaw","DhuQ","DhuH"],dayNames:["Yawm al-Ahad","Yawm al-Ithnain","Yawm al-Thal\u0101th\u0101\u2019","Yawm al-Arba\u2018\u0101\u2019","Yawm al-Kham\u012bs","Yawm al-Jum\u2018a","Yawm al-Sabt"],dayNamesMin:["Ah","Ith","Th","Ar","Kh","Ju","Sa"],digits:null,dateFormat:"yyyy/mm/dd",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,a=0,i=0;i<o.length;i++){if(o[i]>r)return o[a]-o[a-1];a++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate),i=12*(a.year()-1)+a.month()-15292;return a.day()+o[i-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var a=r+15292,i=Math.floor((a-1)/12),s=i+1,l=a-12*i,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var a=n.baseCalendar.prototype.isValid.apply(this,arguments);return a&&(a=(t=null!=t.year?t.year:t)>=1276&&t<=1500),a},_validate:function(t,e,r,a){var i=n.baseCalendar.prototype._validate.apply(this,arguments);if(i.year<1276||i.year>1500)throw a.replace(/\{0\}/,this.local.name);return i}}),n.calendars.ummalqura=i;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{"../main":569,"object-assign":455}],569:[function(t,e,r){var n=t("object-assign");function a(){this.regionalOptions=[],this.regionalOptions[""]={invalidCalendar:"Calendar {0} not found",invalidDate:"Invalid {0} date",invalidMonth:"Invalid {0} month",invalidYear:"Invalid {0} year",differentCalendars:"Cannot mix {0} and {1} dates"},this.local=this.regionalOptions[""],this.calendars={},this._localCals={}}function i(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[""].invalidDate).replace(/\{0\}/,this._calendar.local.name)}function o(t,e){return"000000".substring(0,e-(t=""+t).length)+t}function s(){this.shortYearCutoff="+10"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[""]}n(a.prototype,{instance:function(t,e){t=(t||"gregorian").toLowerCase(),e=e||"";var r=this._localCals[t+"-"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+"-"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[""].invalidCalendar).replace(/\{0\}/,t);return r},newDate:function(t,e,r,n,a){return(n=(null!=t&&t.year?t.calendar():"string"==typeof n?this.instance(n,a):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+"").replace(/[0-9]/g,function(e){return t[e]})}},substituteChineseDigits:function(t,e){return function(r){for(var n="",a=0;r>0;){var i=r%10;n=(0===i?"":t[i]+e[a])+n,a++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(i.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,"y")},month:function(t){return 0===arguments.length?this._month:this.set(t,"m")},day:function(t){return 0===arguments.length?this._day:this.set(t,"d")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[""].invalidDate).replace(/\{0\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[""].differentCalendars).replace(/\{0\}/,this._calendar.local.name).replace(/\{1\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?"-":"")+o(Math.abs(this.year()),4)+"-"+o(this.month(),2)+"-"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[""].invalidDate),r=t.day(),e=t.month(),t=t.year()),new i(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[""].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[""].invalidYear);return(e.year()<0?"-":"")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[""].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[""].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[""].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[""].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[""].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[""].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[""].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[""].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,"d"===r||"w"===r){var n=t.toJD()+e*("w"===r?this.daysInWeek():1),a=t.calendar().fromJD(n);return this._validateLevel--,[a.year(),a.month(),a.day()]}try{var i=t.year()+("y"===r?e:0),o=t.monthOfYear()+("m"===r?e:0);a=t.day();"y"===r?(t.month()!==this.fromMonthOfYear(i,o)&&(o=this.newDate(i,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(i)),a=Math.min(a,this.daysInMonth(i,this.fromMonthOfYear(i,o)))):"m"===r&&(!function(t){for(;o<t.minMonth;)i--,o+=t.monthsInYear(i);for(var e=t.monthsInYear(i);o>e-1+t.minMonth;)i++,o-=e,e=t.monthsInYear(i)}(this),a=Math.min(a,this.daysInMonth(i,this.fromMonthOfYear(i,o))));var s=[i,this.fromMonthOfYear(i,o),a];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||"y"!==n&&"m"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var a={y:[1,1,"y"],m:[1,this.monthsInYear(-1),"m"],w:[this.daysInWeek(),this.daysInYear(-1),"d"],d:[1,this.daysInYear(-1),"d"]}[n],i=r<0?-1:1;e=this._add(t,r*a[0]+i*a[1],a[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[""].invalidDate);var n="y"===r?e:t.year(),a="m"===r?e:t.month(),i="d"===r?e:t.day();return"y"!==r&&"m"!==r||(i=Math.min(i,this.daysInMonth(n,a))),t.date(n,a,i)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var a=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(a)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(a)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[""].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[""].differentCalendars).replace(/\{0\}/,this.local.name).replace(/\{1\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\{0\}/,this.local.name);var a=this.newDate(t,e,r);return this._validateLevel--,a}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:"Gregorian",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Gregorian",epochs:["BCE","CE"],monthNames:["January","February","March","April","May","June","July","August","September","October","November","December"],monthNamesShort:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayNames:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayNamesShort:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],dayNamesMin:["Su","Mo","Tu","We","Th","Fr","Sa"],digits:null,dateFormat:"mm/dd/yyyy",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[""].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[""].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[""].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var a=Math.floor(t/100),i=2-a+Math.floor(a/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+i-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,a=Math.floor((n-122.1)/365.25),i=Math.floor(365.25*a),o=Math.floor((n-i)/30.6001),s=n-i-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=a-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[""].invalidDate),a=new Date(n.year(),n.month()-1,n.day());return a.setHours(0),a.setMinutes(0),a.setSeconds(0),a.setMilliseconds(0),a.setHours(a.getHours()>12?a.getHours()+2:0),a},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new a;c.cdate=i,c.baseCalendar=s,c.calendars.gregorian=l},{"object-assign":455}],570:[function(t,e,r){var n=t("object-assign"),a=t("./main");n(a.regionalOptions[""],{invalidArguments:"Invalid arguments",invalidFormat:"Cannot format a date from another calendar",missingNumberAt:"Missing number at position {0}",unknownNameAt:"Unknown name at position {0}",unexpectedLiteralAt:"Unexpected literal at position {0}",unexpectedText:"Additional text found at end"}),a.local=a.regionalOptions[""],n(a.cdate.prototype,{formatDate:function(t,e){return"string"!=typeof t&&(e=t,t=""),this._calendar.formatDate(t||"",this,e)}}),n(a.baseCalendar.prototype,{UNIX_EPOCH:a.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:a.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:"yyyy-mm-dd",COOKIE:"D, dd M yyyy",FULL:"DD, MM d, yyyy",ISO_8601:"yyyy-mm-dd",JULIAN:"J",RFC_822:"D, d M yy",RFC_850:"DD, dd-M-yy",RFC_1036:"D, d M yy",RFC_1123:"D, d M yyyy",RFC_2822:"D, d M yyyy",RSS:"D, d M yy",TICKS:"!",TIMESTAMP:"@",W3C:"yyyy-mm-dd",formatDate:function(t,e,r){if("string"!=typeof t&&(r=e,e=t,t=""),!e)return"";if(e.calendar()!==this)throw a.local.invalidFormat||a.regionalOptions[""].invalidFormat;t=t||this.local.dateFormat;for(var n,i,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,h=r.monthNamesShort||this.local.monthNamesShort,f=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var a=""+e;if(p(t,n))for(;a.length<r;)a="0"+a;return a},g=this,v=function(t){return"function"==typeof u?u.call(g,t,p("m")):x(d("m",t.month(),2))},m=function(t,e){return e?"function"==typeof f?f.call(g,t):f[t.month()-g.minMonth]:"function"==typeof h?h.call(g,t):h[t.month()-g.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b="",_=!1,w=0;w<t.length;w++)if(_)"'"!==t.charAt(w)||p("'")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case"d":b+=x(d("d",e.day(),2));break;case"D":b+=(n="D",i=e.dayOfWeek(),o=l,s=c,p(n)?s[i]:o[i]);break;case"o":b+=d("o",e.dayOfYear(),3);break;case"w":b+=d("w",e.weekOfYear(),2);break;case"m":b+=v(e);break;case"M":b+=m(e,p("M"));break;case"y":b+=p("y",2)?e.year():(e.year()%100<10?"0":"")+e.year()%100;break;case"Y":p("Y",2),b+=e.formatYear();break;case"J":b+=e.toJD();break;case"@":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case"!":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case"'":p("'")?b+="'":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw a.local.invalidArguments||a.regionalOptions[""].invalidArguments;if(""===(e="object"==typeof e?e.toString():e+""))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n="string"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var i=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,h=-1,f=-1,p=-1,d=-1,g=-1,v=!1,m=!1,y=function(e,r){for(var n=1;A+n<t.length&&t.charAt(A+n)===e;)n++;return A+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),i=[2,3,n?4:2,n?4:2,10,11,20]["oyYJ@!".indexOf(t)+1],o=new RegExp("^-?\\d{1,"+i+"}"),s=e.substring(M).match(o);if(!s)throw(a.local.missingNumberAt||a.regionalOptions[""].missingNumberAt).replace(/\{0\}/,M);return M+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if("function"==typeof l){y("m");var t=l.call(b,e.substring(M));return M+=t.length,t}return x("m")},w=function(t,r,n,i){for(var o=y(t,i)?n:r,s=0;s<o.length;s++)if(e.substr(M,o[s].length).toLowerCase()===o[s].toLowerCase())return M+=o[s].length,s+b.minMonth;throw(a.local.unknownNameAt||a.regionalOptions[""].unknownNameAt).replace(/\{0\}/,M)},k=function(){if("function"==typeof u){var t=y("M")?u.call(b,e.substring(M)):c.call(b,e.substring(M));return M+=t.length,t}return w("M",c,u)},T=function(){if(e.charAt(M)!==t.charAt(A))throw(a.local.unexpectedLiteralAt||a.regionalOptions[""].unexpectedLiteralAt).replace(/\{0\}/,M);M++},M=0,A=0;A<t.length;A++)if(m)"'"!==t.charAt(A)||y("'")?T():m=!1;else switch(t.charAt(A)){case"d":d=x("d");break;case"D":w("D",i,o);break;case"o":g=x("o");break;case"w":x("w");break;case"m":p=_();break;case"M":p=k();break;case"y":var S=A;v=!y("y",2),A=S,f=x("y",2);break;case"Y":f=x("Y",2);break;case"J":h=x("J")+.5,"."===e.charAt(M)&&(M++,x("J"));break;case"@":h=x("@")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case"!":h=x("!")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case"*":M=e.length;break;case"'":y("'")?T():m=!0;break;default:T()}if(M<e.length)throw a.local.unexpectedText||a.regionalOptions[""].unexpectedText;if(-1===f?f=this.today().year():f<100&&v&&(f+=-1===n?1900:this.today().year()-this.today().year()%100-(f<=n?0:100)),"string"==typeof p&&(p=s.call(this,f,p)),g>-1){p=1,d=g;for(var E=this.daysInMonth(f,p);d>E;E=this.daysInMonth(f,p))p++,d-=E}return h>-1?this.fromJD(h):this.newDate(f,p,d)},determineDate:function(t,e,r,n,a){r&&"object"!=typeof r&&(a=n,n=r,r=null),"string"!=typeof n&&(a=n,n="");var i=this;return e=e?e.newDate():null,t=null==t?e:"string"==typeof t?function(t){try{return i.parseDate(n,t,a)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||i.today(),o=/([+-]?[0-9]+)\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||"d"),s=o.exec(t);return e}(t):"number"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:i.today().add(t,"d"):i.newDate(t)}})},{"./main":569,"object-assign":455}],571:[function(t,e,r){e.exports=t("cwise-compiler")({args:["array",{offset:[1],array:0},"scalar","scalar","index"],pre:{body:"{}",args:[],thisVars:[],localVars:[]},post:{body:"{}",args:[],thisVars:[],localVars:[]},body:{body:"{\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\n        }\n      }",args:[{name:"_inline_1_arg0_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_1_arg1_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_1_arg2_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_1_arg3_",lvalue:!1,rvalue:!0,count:2},{name:"_inline_1_arg4_",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:["_inline_1_da","_inline_1_db"]},funcName:"zeroCrossings"})},{"cwise-compiler":148}],572:[function(t,e,r){"use strict";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t("./lib/zc-core")},{"./lib/zc-core":571}],573:[function(t,e,r){"use strict";e.exports=[{path:"",backoff:0},{path:"M-2.4,-3V3L0.6,0Z",backoff:.6},{path:"M-3.7,-2.5V2.5L1.3,0Z",backoff:1.3},{path:"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z",backoff:1.55},{path:"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z",backoff:1.6},{path:"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z",backoff:2},{path:"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z",backoff:0,noRotate:!0},{path:"M2,2V-2H-2V2Z",backoff:0,noRotate:!0}]},{}],574:[function(t,e,r){"use strict";var n=t("./arrow_paths"),a=t("../../plots/font_attributes"),i=t("../../plots/cartesian/constants"),o=t("../../plot_api/plot_template").templatedArray;e.exports=o("annotation",{visible:{valType:"boolean",dflt:!0,editType:"calc+arraydraw"},text:{valType:"string",editType:"calc+arraydraw"},textangle:{valType:"angle",dflt:0,editType:"calc+arraydraw"},font:a({editType:"calc+arraydraw",colorEditType:"arraydraw"}),width:{valType:"number",min:1,dflt:null,editType:"calc+arraydraw"},height:{valType:"number",min:1,dflt:null,editType:"calc+arraydraw"},opacity:{valType:"number",min:0,max:1,dflt:1,editType:"arraydraw"},align:{valType:"enumerated",values:["left","center","right"],dflt:"center",editType:"arraydraw"},valign:{valType:"enumerated",values:["top","middle","bottom"],dflt:"middle",editType:"arraydraw"},bgcolor:{valType:"color",dflt:"rgba(0,0,0,0)",editType:"arraydraw"},bordercolor:{valType:"color",dflt:"rgba(0,0,0,0)",editType:"arraydraw"},borderpad:{valType:"number",min:0,dflt:1,editType:"calc+arraydraw"},borderwidth:{valType:"number",min:0,dflt:1,editType:"calc+arraydraw"},showarrow:{valType:"boolean",dflt:!0,editType:"calc+arraydraw"},arrowcolor:{valType:"color",editType:"arraydraw"},arrowhead:{valType:"integer",min:0,max:n.length,dflt:1,editType:"arraydraw"},startarrowhead:{valType:"integer",min:0,max:n.length,dflt:1,editType:"arraydraw"},arrowside:{valType:"flaglist",flags:["end","start"],extras:["none"],dflt:"end",editType:"arraydraw"},arrowsize:{valType:"number",min:.3,dflt:1,editType:"calc+arraydraw"},startarrowsize:{valType:"number",min:.3,dflt:1,editType:"calc+arraydraw"},arrowwidth:{valType:"number",min:.1,editType:"calc+arraydraw"},standoff:{valType:"number",min:0,dflt:0,editType:"calc+arraydraw"},startstandoff:{valType:"number",min:0,dflt:0,editType:"calc+arraydraw"},ax:{valType:"any",editType:"calc+arraydraw"},ay:{valType:"any",editType:"calc+arraydraw"},axref:{valType:"enumerated",dflt:"pixel",values:["pixel",i.idRegex.x.toString()],editType:"calc"},ayref:{valType:"enumerated",dflt:"pixel",values:["pixel",i.idRegex.y.toString()],editType:"calc"},xref:{valType:"enumerated",values:["paper",i.idRegex.x.toString()],editType:"calc"},x:{valType:"any",editType:"calc+arraydraw"},xanchor:{valType:"enumerated",values:["auto","left","center","right"],dflt:"auto",editType:"calc+arraydraw"},xshift:{valType:"number",dflt:0,editType:"calc+arraydraw"},yref:{valType:"enumerated",values:["paper",i.idRegex.y.toString()],editType:"calc"},y:{valType:"any",editType:"calc+arraydraw"},yanchor:{valType:"enumerated",values:["auto","top","middle","bottom"],dflt:"auto",editType:"calc+arraydraw"},yshift:{valType:"number",dflt:0,editType:"calc+arraydraw"},clicktoshow:{valType:"enumerated",values:[!1,"onoff","onout"],dflt:!1,editType:"arraydraw"},xclick:{valType:"any",editType:"arraydraw"},yclick:{valType:"any",editType:"arraydraw"},hovertext:{valType:"string",editType:"arraydraw"},hoverlabel:{bgcolor:{valType:"color",editType:"arraydraw"},bordercolor:{valType:"color",editType:"arraydraw"},font:a({editType:"arraydraw"}),editType:"arraydraw"},captureevents:{valType:"boolean",editType:"arraydraw"},editType:"calc",_deprecated:{ref:{valType:"string",editType:"calc"}}})},{"../../plot_api/plot_template":755,"../../plots/cartesian/constants":771,"../../plots/font_attributes":791,"./arrow_paths":573}],575:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("./draw").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach(function(e){var r=a.getFromId(t,e.xref),n=a.getFromId(t,e.yref);e._extremes={},r&&s(e,r),n&&s(e,n)})}function s(t,e){var r,n=e._id,i=n.charAt(0),o=t[i],s=t["a"+i],l=t[i+"ref"],c=t["a"+i+"ref"],u=t["_"+i+"padplus"],h=t["_"+i+"padminus"],f={x:1,y:-1}[i]*t[i+"shift"],p=3*t.arrowsize*t.arrowwidth||0,d=p+f,g=p-f,v=3*t.startarrowsize*t.arrowwidth||0,m=v+f,y=v-f;if(c===l){var x=a.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:g}),b=a.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,m),ppadminus:Math.max(h,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else m=s?m+s:m,y=s?y-s:y,r=a.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,m),ppadminus:Math.max(h,g,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([i,o],t)}},{"../../lib":717,"../../plots/cartesian/axes":765,"./draw":580}],576:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../registry"),i=t("../../plot_api/plot_template").arrayEditor;function o(t,e){var r,n,a,i,o,l,c,u=t._fullLayout.annotations,h=[],f=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(i=(a=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===a.xref&&c._id===a.yref&&l.d2r(o.x)===s(a._xclick,l)&&c.d2r(o.y)===s(a._yclick,c)){(a.visible?"onout"===i?f:p:h).push(r);break}n===d&&a.visible&&"onout"===i&&f.push(r)}return{on:h,off:f,explicitOff:p}}function s(t,e){return"log"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),h={},f=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=i(t.layout,"annotations",f[c[r]])).modifyItem("visible",!0),n.extendFlat(h,s.getUpdateObj());for(r=0;r<u.length;r++)(s=i(t.layout,"annotations",f[u[r]])).modifyItem("visible",!1),n.extendFlat(h,s.getUpdateObj());return a.call("update",t,{},h)}}},{"../../lib":717,"../../plot_api/plot_template":755,"../../registry":846}],577:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../color");e.exports=function(t,e,r,i){i("opacity");var o=i("bgcolor"),s=i("bordercolor"),l=a.opacity(s);i("borderpad");var c=i("borderwidth"),u=i("showarrow");if(i("text",u?" ":r._dfltTitle.annotation),i("textangle"),n.coerceFont(i,"font",r.font),i("width"),i("align"),i("height")&&i("valign"),u){var h,f,p=i("arrowside");-1!==p.indexOf("end")&&(h=i("arrowhead"),f=i("arrowsize")),-1!==p.indexOf("start")&&(i("startarrowhead",h),i("startarrowsize",f)),i("arrowcolor",l?e.bordercolor:a.defaultLine),i("arrowwidth",2*(l&&c||1)),i("standoff"),i("startstandoff")}var d=i("hovertext"),g=r.hoverlabel||{};if(d){var v=i("hoverlabel.bgcolor",g.bgcolor||(a.opacity(o)?a.rgb(o):a.defaultLine)),m=i("hoverlabel.bordercolor",g.bordercolor||a.contrast(v));n.coerceFont(i,"hoverlabel.font",{family:g.font.family,size:g.font.size,color:g.font.color||m})}i("captureevents",!!d)}},{"../../lib":717,"../color":591}],578:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib/to_log_range");e.exports=function(t,e,r,i){e=e||{};var o="log"===r&&"linear"===e.type,s="linear"===r&&"log"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,h=e._id.charAt(0),f=0;f<u.length;f++)l=u[f],c="annotations["+f+"].",l[h+"ref"]===e._id&&p(h),l["a"+h+"ref"]===e._id&&p("a"+h);function p(t){var r=l[t],s=null;s=o?a(r,e.range):Math.pow(10,r),n(s)||(s=null),i(c+t,s)}}},{"../../lib/to_log_range":743,"fast-isnumeric":228}],579:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../../plots/array_container_defaults"),o=t("./common_defaults"),s=t("./attributes");function l(t,e,r){function i(r,a){return n.coerce(t,e,s,r,a)}var l=i("visible"),c=i("clicktoshow");if(l||c){o(t,e,r,i);for(var u=e.showarrow,h=["x","y"],f=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var g=h[d],v=a.coerceRef(t,e,p,g,"","paper");if("paper"!==v)a.getFromId(p,v)._annIndices.push(e._index);if(a.coercePosition(e,p,i,v,g,.5),u){var m="a"+g,y=a.coerceRef(t,e,p,m,"pixel");"pixel"!==y&&y!==v&&(y=e[m]="pixel");var x="pixel"===y?f[d]:.4;a.coercePosition(e,p,i,y,m,x)}i(g+"anchor"),i(g+"shift")}if(n.noneOrAll(t,e,["x","y"]),u&&n.noneOrAll(t,e,["ax","ay"]),c){var b=i("xclick"),_=i("yclick");e._xclick=void 0===b?e.x:a.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:a.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){i(t,e,{name:"annotations",handleItemDefaults:l})}},{"../../lib":717,"../../plots/array_container_defaults":761,"../../plots/cartesian/axes":765,"./attributes":574,"./common_defaults":577}],580:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../plots/plots"),o=t("../../lib"),s=t("../../plots/cartesian/axes"),l=t("../color"),c=t("../drawing"),u=t("../fx"),h=t("../../lib/svg_text_utils"),f=t("../../lib/setcursor"),p=t("../dragelement"),d=t("../../plot_api/plot_template").arrayEditor,g=t("./draw_arrow_head");function v(t,e){var r=t._fullLayout.annotations[e]||{},n=s.getFromId(t,r.xref),a=s.getFromId(t,r.yref);n&&n.setScale(),a&&a.setScale(),m(t,r,e,!1,n,a)}function m(t,e,r,i,s,v){var m,y,x=t._fullLayout,b=t._fullLayout._size,_=t._context.edits;i?(m="annotation-"+i,y=i+".annotations"):(m="annotation",y="annotations");var w=d(t.layout,y,e),k=w.modifyBase,T=w.modifyItem,M=w.getUpdateObj;x._infolayer.selectAll("."+m+'[data-index="'+r+'"]').remove();var A="clip"+x._uid+"_ann"+r;if(e._input&&!1!==e.visible){var S={x:{},y:{}},E=+e.textangle||0,L=x._infolayer.append("g").classed(m,!0).attr("data-index",String(r)).style("opacity",e.opacity),C=L.append("g").classed("annotation-text-g",!0),P=_[e.showarrow?"annotationTail":"annotationPosition"],O=e.captureevents||_.annotationText||P,z=C.append("g").style("pointer-events",O?"all":null).call(f,"pointer").on("click",function(){t._dragging=!1,t.emit("plotly_clickannotation",q(n.event))});e.hovertext&&z.on("mouseover",function(){var r=e.hoverlabel,n=r.font,a=this.getBoundingClientRect(),i=t.getBoundingClientRect();u.loneHover({x0:a.left-i.left,x1:a.right-i.left,y:(a.top+a.bottom)/2-i.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:x._hoverlayer.node(),outerContainer:x._paper.node(),gd:t})}).on("mouseout",function(){u.loneUnhover(x._hoverlayer.node())});var I=e.borderwidth,D=e.borderpad,R=I+D,F=z.append("rect").attr("class","bg").style("stroke-width",I+"px").call(l.stroke,e.bordercolor).call(l.fill,e.bgcolor),B=e.width||e.height,N=x._topclips.selectAll("#"+A).data(B?[0]:[]);N.enter().append("clipPath").classed("annclip",!0).attr("id",A).append("rect"),N.exit().remove();var j=e.font,V=x._meta?o.templateString(e.text,x._meta):e.text,U=z.append("text").classed("annotation-text",!0).text(V);_.annotationText?U.call(h.makeEditable,{delegate:z,gd:t}).call(H).on("edit",function(r){e.text=r,this.call(H),T("text",r),s&&s.autorange&&k(s._name+".autorange",!0),v&&v.autorange&&k(v._name+".autorange",!0),a.call("_guiRelayout",t,M())}):U.call(H)}else n.selectAll("#"+A).remove();function q(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return i&&(n.subplotId=i),n}function H(r){return r.call(c.font,j).attr({"text-anchor":{left:"start",right:"end"}[e.align]||"middle"}),h.convertToTspans(r,t,G),r}function G(){var r=U.selectAll("a");1===r.size()&&r.text()===U.text()&&z.insert("a",":first-child").attr({"xlink:xlink:href":r.attr("xlink:href"),"xlink:xlink:show":r.attr("xlink:show")}).style({cursor:"pointer"}).node().appendChild(F.node());var n=z.select(".annotation-text-math-group"),u=!n.empty(),d=c.bBox((u?n:U).node()),m=d.width,y=d.height,w=e.width||m,O=e.height||y,D=Math.round(w+2*R),j=Math.round(O+2*R);function V(t,e){return"auto"===e&&(e=t<1/3?"left":t>2/3?"right":"center"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var H=!1,G=["x","y"],Y=0;Y<G.length;Y++){var W,X,Z,J,K,Q=G[Y],$=e[Q+"ref"]||Q,tt=e["a"+Q+"ref"],et={x:s,y:v}[Q],rt=(E+("x"===Q?0:-90))*Math.PI/180,nt=D*Math.cos(rt),at=j*Math.sin(rt),it=Math.abs(nt)+Math.abs(at),ot=e[Q+"anchor"],st=e[Q+"shift"]*("x"===Q?1:-1),lt=S[Q];if(et){var ct=et.r2fraction(e[Q]);(ct<0||ct>1)&&(tt===$?((ct=et.r2fraction(e["a"+Q]))<0||ct>1)&&(H=!0):H=!0),W=et._offset+et.r2p(e[Q]),J=.5}else"x"===Q?(Z=e[Q],W=b.l+b.w*Z):(Z=1-e[Q],W=b.t+b.h*Z),J=e.showarrow?.5:Z;if(e.showarrow){lt.head=W;var ut=e["a"+Q];K=nt*V(.5,e.xanchor)-at*V(.5,e.yanchor),tt===$?(lt.tail=et._offset+et.r2p(ut),X=K):(lt.tail=W+ut,X=K+ut),lt.text=lt.tail+K;var ht=x["x"===Q?"width":"height"];if("paper"===$&&(lt.head=o.constrain(lt.head,1,ht-1)),"pixel"===tt){var ft=-Math.max(lt.tail-3,lt.text),pt=Math.min(lt.tail+3,lt.text)-ht;ft>0?(lt.tail+=ft,lt.text+=ft):pt>0&&(lt.tail-=pt,lt.text-=pt)}lt.tail+=st,lt.head+=st}else X=K=it*V(J,ot),lt.text=W+K;lt.text+=st,K+=st,X+=st,e["_"+Q+"padplus"]=it/2+X,e["_"+Q+"padminus"]=it/2-X,e["_"+Q+"size"]=it,e["_"+Q+"shift"]=K}if(H)z.remove();else{var dt=0,gt=0;if("left"!==e.align&&(dt=(w-m)*("center"===e.align?.5:1)),"top"!==e.valign&&(gt=(O-y)*("middle"===e.valign?.5:1)),u)n.select("svg").attr({x:R+dt-1,y:R+gt}).call(c.setClipUrl,B?A:null,t);else{var vt=R+gt-d.top,mt=R+dt-d.left;U.call(h.positionText,mt,vt).call(c.setClipUrl,B?A:null,t)}N.select("rect").call(c.setRect,R,R,w,O),F.call(c.setRect,I/2,I/2,D-I,j-I),z.call(c.setTranslate,Math.round(S.x.text-D/2),Math.round(S.y.text-j/2)),C.attr({transform:"rotate("+E+","+S.x.text+","+S.y.text+")"});var yt,xt=function(r,n){L.selectAll(".annotation-arrow-g").remove();var u=S.x.head,h=S.y.head,f=S.x.tail+r,d=S.y.tail+n,m=S.x.text+r,y=S.y.text+n,x=o.rotationXYMatrix(E,m,y),w=o.apply2DTransform(x),A=o.apply2DTransform2(x),P=+F.attr("width"),O=+F.attr("height"),I=m-.5*P,D=I+P,R=y-.5*O,B=R+O,N=[[I,R,I,B],[I,B,D,B],[D,B,D,R],[D,R,I,R]].map(A);if(!N.reduce(function(t,e){return t^!!o.segmentsIntersect(u,h,u+1e6,h+1e6,e[0],e[1],e[2],e[3])},!1)){N.forEach(function(t){var e=o.segmentsIntersect(f,d,u,h,t[0],t[1],t[2],t[3]);e&&(f=e.x,d=e.y)});var j=e.arrowwidth,V=e.arrowcolor,U=e.arrowside,q=L.append("g").style({opacity:l.opacity(V)}).classed("annotation-arrow-g",!0),H=q.append("path").attr("d","M"+f+","+d+"L"+u+","+h).style("stroke-width",j+"px").call(l.stroke,l.rgb(V));if(g(H,U,e),_.annotationPosition&&H.node().parentNode&&!i){var G=u,Y=h;if(e.standoff){var W=Math.sqrt(Math.pow(u-f,2)+Math.pow(h-d,2));G+=e.standoff*(f-u)/W,Y+=e.standoff*(d-h)/W}var X,Z,J=q.append("path").classed("annotation-arrow",!0).classed("anndrag",!0).classed("cursor-move",!0).attr({d:"M3,3H-3V-3H3ZM0,0L"+(f-G)+","+(d-Y),transform:"translate("+G+","+Y+")"}).style("stroke-width",j+6+"px").call(l.stroke,"rgba(0,0,0,0)").call(l.fill,"rgba(0,0,0,0)");p.init({element:J.node(),gd:t,prepFn:function(){var t=c.getTranslate(z);X=t.x,Z=t.y,s&&s.autorange&&k(s._name+".autorange",!0),v&&v.autorange&&k(v._name+".autorange",!0)},moveFn:function(t,r){var n=w(X,Z),a=n[0]+t,i=n[1]+r;z.call(c.setTranslate,a,i),T("x",s?s.p2r(s.r2p(e.x)+t):e.x+t/b.w),T("y",v?v.p2r(v.r2p(e.y)+r):e.y-r/b.h),e.axref===e.xref&&T("ax",s.p2r(s.r2p(e.ax)+t)),e.ayref===e.yref&&T("ay",v.p2r(v.r2p(e.ay)+r)),q.attr("transform","translate("+t+","+r+")"),C.attr({transform:"rotate("+E+","+a+","+i+")"})},doneFn:function(){a.call("_guiRelayout",t,M());var e=document.querySelector(".js-notes-box-panel");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&xt(0,0),P)p.init({element:z.node(),gd:t,prepFn:function(){yt=C.attr("transform")},moveFn:function(t,r){var n="pointer";if(e.showarrow)e.axref===e.xref?T("ax",s.p2r(s.r2p(e.ax)+t)):T("ax",e.ax+t),e.ayref===e.yref?T("ay",v.p2r(v.r2p(e.ay)+r)):T("ay",e.ay+r),xt(t,r);else{if(i)return;var a,o;if(s)a=s.p2r(s.r2p(e.x)+t);else{var l=e._xsize/b.w,c=e.x+(e._xshift-e.xshift)/b.w-l/2;a=p.align(c+t/b.w,l,0,1,e.xanchor)}if(v)o=v.p2r(v.r2p(e.y)+r);else{var u=e._ysize/b.h,h=e.y-(e._yshift+e.yshift)/b.h-u/2;o=p.align(h-r/b.h,u,0,1,e.yanchor)}T("x",a),T("y",o),s&&v||(n=p.getCursor(s?.5:a,v?.5:o,e.xanchor,e.yanchor))}C.attr({transform:"translate("+t+","+r+")"+yt}),f(z,n)},clickFn:function(r,n){e.captureevents&&t.emit("plotly_clickannotation",q(n))},doneFn:function(){f(z),a.call("_guiRelayout",t,M());var e=document.querySelector(".js-notes-box-panel");e&&e.redraw(e.selectedObj)}})}}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(".annotation").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&v(t,r);return i.previousPromises(t)},drawOne:v,drawRaw:m}},{"../../lib":717,"../../lib/setcursor":737,"../../lib/svg_text_utils":741,"../../plot_api/plot_template":755,"../../plots/cartesian/axes":765,"../../plots/plots":826,"../../registry":846,"../color":591,"../dragelement":609,"../drawing":612,"../fx":630,"./draw_arrow_head":581,d3:165}],581:[function(t,e,r){"use strict";var n=t("d3"),a=t("../color"),i=t("./arrow_paths");e.exports=function(t,e,r){var o,s,l,c,u=t.node(),h=i[r.arrowhead||0],f=i[r.startarrowhead||0],p=(r.arrowwidth||1)*(r.arrowsize||1),d=(r.arrowwidth||1)*(r.startarrowsize||1),g=e.indexOf("start")>=0,v=e.indexOf("end")>=0,m=h.backoff*p+r.standoff,y=f.backoff*d+r.startstandoff;if("line"===u.nodeName){o={x:+t.attr("x1"),y:+t.attr("y1")},s={x:+t.attr("x2"),y:+t.attr("y2")};var x=o.x-s.x,b=o.y-s.y;if(c=(l=Math.atan2(b,x))+Math.PI,m&&y&&m+y>Math.sqrt(x*x+b*b))return void P();if(m){if(m*m>x*x+b*b)return void P();var _=m*Math.cos(l),w=m*Math.sin(l);s.x+=_,s.y+=w,t.attr({x2:s.x,y2:s.y})}if(y){if(y*y>x*x+b*b)return void P();var k=y*Math.cos(l),T=y*Math.sin(l);o.x-=k,o.y-=T,t.attr({x1:o.x,y1:o.y})}}else if("path"===u.nodeName){var M=u.getTotalLength(),A="";if(M<m+y)return void P();var S=u.getPointAtLength(0),E=u.getPointAtLength(.1);l=Math.atan2(S.y-E.y,S.x-E.x),o=u.getPointAtLength(Math.min(y,M)),A="0px,"+y+"px,";var L=u.getPointAtLength(M),C=u.getPointAtLength(M-.1);c=Math.atan2(L.y-C.y,L.x-C.x),s=u.getPointAtLength(Math.max(0,M-m)),A+=M-(A?y+m:m)+"px,"+M+"px",t.style("stroke-dasharray",A)}function P(){t.style("stroke-dasharray","0px,100px")}function O(e,i,o,s){e.path&&(e.noRotate&&(o=0),n.select(u.parentNode).append("path").attr({class:t.attr("class"),d:e.path,transform:"translate("+i.x+","+i.y+")"+(o?"rotate("+180*o/Math.PI+")":"")+"scale("+s+")"}).style({fill:a.rgb(r.arrowcolor),"stroke-width":0}))}g&&O(f,o,l,d),v&&O(h,s,c,p)}},{"../color":591,"./arrow_paths":573,d3:165}],582:[function(t,e,r){"use strict";var n=t("./draw"),a=t("./click");e.exports={moduleType:"component",name:"annotations",layoutAttributes:t("./attributes"),supplyLayoutDefaults:t("./defaults"),includeBasePlot:t("../../plots/cartesian/include_components")("annotations"),calcAutorange:t("./calc_autorange"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:a.hasClickToShow,onClick:a.onClick,convertCoords:t("./convert_coords")}},{"../../plots/cartesian/include_components":775,"./attributes":574,"./calc_autorange":575,"./click":576,"./convert_coords":578,"./defaults":579,"./draw":580}],583:[function(t,e,r){"use strict";var n=t("../annotations/attributes"),a=t("../../plot_api/edit_types").overrideAll,i=t("../../plot_api/plot_template").templatedArray;e.exports=a(i("annotation",{visible:n.visible,x:{valType:"any"},y:{valType:"any"},z:{valType:"any"},ax:{valType:"number"},ay:{valType:"number"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),"calc","from-root")},{"../../plot_api/edit_types":748,"../../plot_api/plot_template":755,"../annotations/attributes":574}],584:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes");function i(t,e){var r=e.fullSceneLayout.domain,i=e.fullLayout._size,o={pdata:null,type:"linear",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),a.setConvert(t._xa),t._xa._offset=i.l+r.x[0]*i.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*i.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),a.setConvert(t._ya),t._ya._offset=i.t+(1-r.y[1])*i.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*i.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)i(e[r],t);t.fullLayout._infolayer.selectAll(".annotation-"+t.id).remove()}},{"../../lib":717,"../../plots/cartesian/axes":765}],585:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../../plots/array_container_defaults"),o=t("../annotations/common_defaults"),s=t("./attributes");function l(t,e,r,i){function l(r,a){return n.coerce(t,e,s,r,a)}function c(t){var n=t+"axis",i={_fullLayout:{}};return i._fullLayout[n]=r[n],a.coercePosition(e,i,l,t,t,.5)}l("visible")&&(o(t,e,i.fullLayout,l),c("x"),c("y"),c("z"),n.noneOrAll(t,e,["x","y","z"]),e.xref="x",e.yref="y",e.zref="z",l("xanchor"),l("yanchor"),l("xshift"),l("yshift"),e.showarrow&&(e.axref="pixel",e.ayref="pixel",l("ax",-10),l("ay",-30),n.noneOrAll(t,e,["ax","ay"])))}e.exports=function(t,e,r){i(t,e,{name:"annotations",handleItemDefaults:l,fullLayout:r.fullLayout})}},{"../../lib":717,"../../plots/array_container_defaults":761,"../../plots/cartesian/axes":765,"../annotations/common_defaults":577,"./attributes":583}],586:[function(t,e,r){"use strict";var n=t("../annotations/draw").drawRaw,a=t("../../plots/gl3d/project"),i=["x","y","z"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var h=i[u],f=l[h],p=e[h+"axis"].r2fraction(f);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(".annotation-"+t.id+'[data-index="'+s+'"]').remove():(l._pdata=a(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{"../../plots/gl3d/project":814,"../annotations/draw":580}],587:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib");e.exports={moduleType:"component",name:"annotations3d",schema:{subplots:{scene:{annotations:t("./attributes")}}},layoutAttributes:t("./attributes"),handleDefaults:t("./defaults"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var i=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];i.test(l)&&(t[l].annotations||[]).length&&(a.pushUnique(e._basePlotModules,r),a.pushUnique(e._subplots.gl3d,l))}},convert:t("./convert"),draw:t("./draw")}},{"../../lib":717,"../../registry":846,"./attributes":583,"./convert":584,"./defaults":585,"./draw":586}],588:[function(t,e,r){"use strict";e.exports=t("world-calendars/dist/main"),t("world-calendars/dist/plus"),t("world-calendars/dist/calendars/chinese"),t("world-calendars/dist/calendars/coptic"),t("world-calendars/dist/calendars/discworld"),t("world-calendars/dist/calendars/ethiopian"),t("world-calendars/dist/calendars/hebrew"),t("world-calendars/dist/calendars/islamic"),t("world-calendars/dist/calendars/julian"),t("world-calendars/dist/calendars/mayan"),t("world-calendars/dist/calendars/nanakshahi"),t("world-calendars/dist/calendars/nepali"),t("world-calendars/dist/calendars/persian"),t("world-calendars/dist/calendars/taiwan"),t("world-calendars/dist/calendars/thai"),t("world-calendars/dist/calendars/ummalqura")},{"world-calendars/dist/calendars/chinese":555,"world-calendars/dist/calendars/coptic":556,"world-calendars/dist/calendars/discworld":557,"world-calendars/dist/calendars/ethiopian":558,"world-calendars/dist/calendars/hebrew":559,"world-calendars/dist/calendars/islamic":560,"world-calendars/dist/calendars/julian":561,"world-calendars/dist/calendars/mayan":562,"world-calendars/dist/calendars/nanakshahi":563,"world-calendars/dist/calendars/nepali":564,"world-calendars/dist/calendars/persian":565,"world-calendars/dist/calendars/taiwan":566,"world-calendars/dist/calendars/thai":567,"world-calendars/dist/calendars/ummalqura":568,"world-calendars/dist/main":569,"world-calendars/dist/plus":570}],589:[function(t,e,r){"use strict";var n=t("./calendars"),a=t("../../lib"),i=t("../../constants/numerical"),o=i.EPOCHJD,s=i.ONEDAY,l={valType:"enumerated",values:Object.keys(n.calendars),editType:"calc",dflt:"gregorian"},c=function(t,e,r,n){var i={};return i[r]=l,a.coerce(t,e,i,r,n)},u="##",h={d:{0:"dd","-":"d"},e:{0:"d","-":"d"},a:{0:"D","-":"D"},A:{0:"DD","-":"DD"},j:{0:"oo","-":"o"},W:{0:"ww","-":"w"},m:{0:"mm","-":"m"},b:{0:"M","-":"M"},B:{0:"MM","-":"MM"},y:{0:"yy","-":"yy"},Y:{0:"yyyy","-":"yyyy"},U:u,w:u,c:{0:"D M d %X yyyy","-":"D M d %X yyyy"},x:{0:"mm/dd/yyyy","-":"mm/dd/yyyy"}};var f={};function p(t){var e=f[t];return e||(e=f[t]=n.instance(t))}function d(t){return a.extendFlat({},l,{description:t})}function g(t){return"Sets the calendar system to use with `"+t+"` date data."}var v={xcalendar:d(g("x"))},m=a.extendFlat({},v,{ycalendar:d(g("y"))}),y=a.extendFlat({},m,{zcalendar:d(g("z"))}),x=d(["Sets the calendar system to use for `range` and `tick0`","if this is a date axis. This does not set the calendar for","interpreting data on this axis, that's specified in the trace","or via the global `layout.calendar`"].join(" "));e.exports={moduleType:"component",name:"calendars",schema:{traces:{scatter:m,bar:m,box:m,heatmap:m,contour:m,histogram:m,histogram2d:m,histogram2dcontour:m,scatter3d:y,surface:y,mesh3d:y,scattergl:m,ohlc:v,candlestick:v},layout:{calendar:d(["Sets the default calendar system to use for interpreting and","displaying dates throughout the plot."].join(" "))},subplots:{xaxis:{calendar:x},yaxis:{calendar:x},scene:{xaxis:{calendar:x},yaxis:{calendar:x},zaxis:{calendar:x}},polar:{radialaxis:{calendar:x}}},transforms:{filter:{valuecalendar:d(["Sets the calendar system to use for `value`, if it is a date."].join(" ")),targetcalendar:d(["Sets the calendar system to use for `target`, if it is an","array of dates. If `target` is a string (eg *x*) we use the","corresponding trace attribute (eg `xcalendar`) if it exists,","even if `targetcalendar` is provided."].join(" "))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var a=0;a<r.length;a++)c(t,e,r[a]+"calendar",n.calendar)},CANONICAL_SUNDAY:{chinese:"2000-01-02",coptic:"2000-01-03",discworld:"2000-01-03",ethiopian:"2000-01-05",hebrew:"5000-01-01",islamic:"1000-01-02",julian:"2000-01-03",mayan:"5000-01-01",nanakshahi:"1000-01-05",nepali:"2000-01-05",persian:"1000-01-01",jalali:"1000-01-01",taiwan:"1000-01-04",thai:"2000-01-04",ummalqura:"1400-01-06"},CANONICAL_TICK:{chinese:"2000-01-01",coptic:"2000-01-01",discworld:"2000-01-01",ethiopian:"2000-01-01",hebrew:"5000-01-01",islamic:"1000-01-01",julian:"2000-01-01",mayan:"5000-01-01",nanakshahi:"1000-01-01",nepali:"2000-01-01",persian:"1000-01-01",jalali:"1000-01-01",taiwan:"1000-01-01",thai:"2000-01-01",ummalqura:"1400-01-01"},DFLTRANGE:{chinese:["2000-01-01","2001-01-01"],coptic:["1700-01-01","1701-01-01"],discworld:["1800-01-01","1801-01-01"],ethiopian:["2000-01-01","2001-01-01"],hebrew:["5700-01-01","5701-01-01"],islamic:["1400-01-01","1401-01-01"],julian:["2000-01-01","2001-01-01"],mayan:["5200-01-01","5201-01-01"],nanakshahi:["0500-01-01","0501-01-01"],nepali:["2000-01-01","2001-01-01"],persian:["1400-01-01","1401-01-01"],jalali:["1400-01-01","1401-01-01"],taiwan:["0100-01-01","0101-01-01"],thai:["2500-01-01","2501-01-01"],ummalqura:["1400-01-01","1401-01-01"]},getCal:p,worldCalFmt:function(t,e,r){for(var n,a,i,l,c,f=Math.floor((e+.05)/s)+o,d=p(r).fromJD(f),g=0;-1!==(g=t.indexOf("%",g));)"0"===(n=t.charAt(g+1))||"-"===n||"_"===n?(i=3,a=t.charAt(g+2),"_"===n&&(n="-")):(a=n,n="0",i=2),(l=h[a])?(c=l===u?u:d.formatDate(l[n]),t=t.substr(0,g)+c+t.substr(g+i),g+=c.length):g+=i;return t}}},{"../../constants/numerical":693,"../../lib":717,"./calendars":588}],590:[function(t,e,r){"use strict";r.defaults=["#1f77b4","#ff7f0e","#2ca02c","#d62728","#9467bd","#8c564b","#e377c2","#7f7f7f","#bcbd22","#17becf"],r.defaultLine="#444",r.lightLine="#eee",r.background="#fff",r.borderLine="#BEC8D9",r.lightFraction=1e3/11},{}],591:[function(t,e,r){"use strict";var n=t("tinycolor2"),a=t("fast-isnumeric"),i=e.exports={},o=t("./attributes");i.defaults=o.defaults;var s=i.defaultLine=o.defaultLine;i.lightLine=o.lightLine;var l=i.background=o.background;function c(t){if(a(t)||"string"!=typeof t)return t;var e=t.trim();if("rgb"!==e.substr(0,3))return t;var r=e.match(/^rgba?\s*\(([^()]*)\)$/);if(!r)return t;var n=r[1].trim().split(/\s*[\s,]\s*/),i="a"===e.charAt(3)&&4===n.length;if(!i&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+", "+Math.round(255*n[1])+", "+Math.round(255*n[2]);return i?"rgba("+s+", "+n[3]+")":"rgb("+s+")"}i.tinyRGB=function(t){var e=t.toRgb();return"rgb("+Math.round(e.r)+", "+Math.round(e.g)+", "+Math.round(e.b)+")"},i.rgb=function(t){return i.tinyRGB(n(t))},i.opacity=function(t){return t?n(t).getAlpha():0},i.addOpacity=function(t,e){var r=n(t).toRgb();return"rgba("+Math.round(r.r)+", "+Math.round(r.g)+", "+Math.round(r.b)+", "+e+")"},i.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var a=n(e||l).toRgb(),i=1===a.a?a:{r:255*(1-a.a)+a.r*a.a,g:255*(1-a.a)+a.g*a.a,b:255*(1-a.a)+a.b*a.a},o={r:i.r*(1-r.a)+r.r*r.a,g:i.g*(1-r.a)+r.g*r.a,b:i.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},i.contrast=function(t,e,r){var a=n(t);return 1!==a.getAlpha()&&(a=n(i.combine(t,l))),(a.isDark()?e?a.lighten(e):l:r?a.darken(r):s).toString()},i.stroke=function(t,e){var r=n(e);t.style({stroke:i.tinyRGB(r),"stroke-opacity":r.getAlpha()})},i.fill=function(t,e){var r=n(e);t.style({fill:i.tinyRGB(r),"fill-opacity":r.getAlpha()})},i.clean=function(t){if(t&&"object"==typeof t){var e,r,n,a,o=Object.keys(t);for(e=0;e<o.length;e++)if(a=t[n=o[e]],"color"===n.substr(n.length-5))if(Array.isArray(a))for(r=0;r<a.length;r++)a[r]=c(a[r]);else t[n]=c(a);else if("colorscale"===n.substr(n.length-10)&&Array.isArray(a))for(r=0;r<a.length;r++)Array.isArray(a[r])&&(a[r][1]=c(a[r][1]));else if(Array.isArray(a)){var s=a[0];if(!Array.isArray(s)&&s&&"object"==typeof s)for(r=0;r<a.length;r++)i.clean(a[r])}else a&&"object"==typeof a&&i.clean(a)}}},{"./attributes":590,"fast-isnumeric":228,tinycolor2:535}],592:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/layout_attributes"),a=t("../../plots/font_attributes"),i=t("../../lib/extend").extendFlat,o=t("../../plot_api/edit_types").overrideAll;e.exports=o({thicknessmode:{valType:"enumerated",values:["fraction","pixels"],dflt:"pixels"},thickness:{valType:"number",min:0,dflt:30},lenmode:{valType:"enumerated",values:["fraction","pixels"],dflt:"fraction"},len:{valType:"number",min:0,dflt:1},x:{valType:"number",dflt:1.02,min:-2,max:3},xanchor:{valType:"enumerated",values:["left","center","right"],dflt:"left"},xpad:{valType:"number",min:0,dflt:10},y:{valType:"number",dflt:.5,min:-2,max:3},yanchor:{valType:"enumerated",values:["top","middle","bottom"],dflt:"middle"},ypad:{valType:"number",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:"number",min:0,dflt:0},bgcolor:{valType:"color",dflt:"rgba(0,0,0,0)"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:i({},n.ticks,{dflt:""}),ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:a({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,showexponent:n.showexponent,title:{text:{valType:"string"},font:a({}),side:{valType:"enumerated",values:["right","top","bottom"],dflt:"top"}},_deprecated:{title:{valType:"string"},titlefont:a({}),titleside:{valType:"enumerated",values:["right","top","bottom"],dflt:"top"}}},"colorbars","from-root")},{"../../lib/extend":708,"../../plot_api/edit_types":748,"../../plots/cartesian/layout_attributes":777,"../../plots/font_attributes":791}],593:[function(t,e,r){"use strict";e.exports={cn:{colorbar:"colorbar",cbbg:"cbbg",cbfill:"cbfill",cbfills:"cbfills",cbline:"cbline",cblines:"cblines",cbaxis:"cbaxis",cbtitleunshift:"cbtitleunshift",cbtitle:"cbtitle",cboutline:"cboutline",crisp:"crisp",jsPlaceholder:"js-placeholder"}}},{}],594:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plot_api/plot_template"),i=t("../../plots/cartesian/tick_value_defaults"),o=t("../../plots/cartesian/tick_mark_defaults"),s=t("../../plots/cartesian/tick_label_defaults"),l=t("./attributes");e.exports=function(t,e,r){var c=a.newContainer(e,"colorbar"),u=t.colorbar||{};function h(t,e){return n.coerce(u,c,l,t,e)}var f=h("thicknessmode");h("thickness","fraction"===f?30/(r.width-r.margin.l-r.margin.r):30);var p=h("lenmode");h("len","fraction"===p?1:r.height-r.margin.t-r.margin.b),h("x"),h("xanchor"),h("xpad"),h("y"),h("yanchor"),h("ypad"),n.noneOrAll(u,c,["x","y"]),h("outlinecolor"),h("outlinewidth"),h("bordercolor"),h("borderwidth"),h("bgcolor"),i(u,c,h,"linear");var d={outerTicks:!1,font:r.font};s(u,c,h,"linear",d),o(u,c,h,"linear",d),h("title.text",r._dfltTitle.colorbar),n.coerceFont(h,"title.font",r.font),h("title.side")}},{"../../lib":717,"../../plot_api/plot_template":755,"../../plots/cartesian/tick_label_defaults":784,"../../plots/cartesian/tick_mark_defaults":785,"../../plots/cartesian/tick_value_defaults":786,"./attributes":592}],595:[function(t,e,r){"use strict";var n=t("d3"),a=t("tinycolor2"),i=t("../../plots/plots"),o=t("../../registry"),s=t("../../plots/cartesian/axes"),l=t("../dragelement"),c=t("../../lib"),u=t("../../lib/extend").extendFlat,h=t("../../lib/setcursor"),f=t("../drawing"),p=t("../color"),d=t("../titles"),g=t("../../lib/svg_text_utils"),v=t("../colorscale/helpers").flipScale,m=t("../../plots/cartesian/axis_defaults"),y=t("../../plots/cartesian/position_defaults"),x=t("../../plots/cartesian/layout_attributes"),b=t("../../constants/alignment"),_=b.LINE_SPACING,w=b.FROM_TL,k=b.FROM_BR,T=t("./constants").cn;e.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll("g."+T.colorbar).data(function(t){var e,r,n,a,i=t._fullLayout,o=t.calcdata,s=[];function l(t){return u(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){"function"==typeof a.calc?a.calc(t,n,e):(e._fillgradient=r.reversescale?v(r.colorscale):r.colorscale,e._zrange=[r[a.min],r[a.max]])}for(var h=0;h<o.length;h++){var f=o[h],p=(n=f[0].trace)._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),g=d?p:[p],m=0;m<g.length;m++){var y=(a=g[m]).container;(r=y?n[y]:n)&&r.showscale&&((e=l(r.colorbar))._id="cb"+n.uid+(d&&y?"-"+y:""),e._traceIndex=n.index,e._propPrefix=(y?y+".":"")+"colorbar.",e._meta=n._meta,c(),s.push(e))}}for(var x in i._colorAxes)if((r=i[x]).showscale){var b=i._colorAxes[x];(e=l(r.colorbar))._id="cb"+x,e._propPrefix=x+".colorbar.",e._meta=i._meta,a={min:"cmin",max:"cmax"},"heatmap"!==b[0]&&(n=b[1],a.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),function(t){return t._id});e.enter().append("g").attr("class",function(t){return t._id}).classed(T.colorbar,!0),e.each(function(e){var r=n.select(this);c.ensureSingle(r,"rect",T.cbbg),c.ensureSingle(r,"g",T.cbfills),c.ensureSingle(r,"g",T.cblines),c.ensureSingle(r,"g",T.cbaxis,function(t){t.classed(T.crisp,!0)}),c.ensureSingle(r,"g",T.cbtitleunshift,function(t){t.append("g").classed(T.cbtitle,!0)}),c.ensureSingle(r,"rect",T.cboutline);var v=function(t,e,r){var o=r._fullLayout,l=o._size,h=e._fillcolor,v=e._line,b=e.title,M=b.side,A=e._zrange||n.extent(("function"==typeof h?h:v.color).domain()),S="function"==typeof v.color?v.color:function(){return v.color},E="function"==typeof h?h:function(){return h},L=e._levels,C=function(t,e,r){var n,a,i=e._levels,o=[],s=[],l=i.end+i.size/100,c=i.size,u=1.001*r[0]-.001*r[1],h=1.001*r[1]-.001*r[0];for(a=0;a<1e5&&(n=i.start+a*c,!(c>0?n>=l:n<=l));a++)n>u&&n<h&&o.push(n);if(e._fillgradient)s=[0];else if("function"==typeof e._fillcolor){var f=e._filllevels;if(f)for(l=f.end+f.size/100,c=f.size,a=0;a<1e5&&(n=f.start+a*c,!(c>0?n>=l:n<=l));a++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map(function(t){return t-i.size/2})).push(s[s.length-1]+i.size)}else e._fillcolor&&"string"==typeof e._fillcolor&&(s=[0]);return i.size<0&&(o.reverse(),s.reverse()),{line:o,fill:s}}(0,e,A),P=C.fill,O=C.line,z=Math.round(e.thickness*("fraction"===e.thicknessmode?l.w:1)),I=z/l.w,D=Math.round(e.len*("fraction"===e.lenmode?l.h:1)),R=D/l.h,F=e.xpad/l.w,B=(e.borderwidth+e.outlinewidth)/2,N=e.ypad/l.h,j=Math.round(e.x*l.w+e.xpad),V=e.x-I*({middle:.5,right:1}[e.xanchor]||0),U=e.y+R*(({top:-.5,bottom:.5}[e.yanchor]||0)-.5),q=Math.round(l.h*(1-U)),H=q-D;e._lenFrac=R,e._thickFrac=I,e._xLeftFrac=V,e._yBottomFrac=U;var G=e._axis=function(t,e,r){var n=t._fullLayout,a={type:"linear",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:"free",side:"right",position:1},i={type:"linear",_id:"y"+e._id},o={letter:"y",font:n.font,noHover:!0,noTickson:!0,calendar:n.calendar};function s(t,e){return c.coerce(a,i,x,t,e)}return m(a,i,s,o,n),y(a,i,s,o),i}(r,e,A);if(G.position=e.x+F+I,-1!==["top","bottom"].indexOf(M)&&(G.title.side=M,G.titlex=e.x+F,G.titley=U+("top"===b.side?R-N:N)),v.color&&"auto"===e.tickmode){G.tickmode="linear",G.tick0=L.start;var Y=L.size,W=c.constrain((q-H)/50,4,15)+1,X=(A[1]-A[0])/((e.nticks||W)*Y);if(X>1){var Z=Math.pow(10,Math.floor(Math.log(X)/Math.LN10));Y*=Z*c.roundUp(X/Z,[2,5,10]),(Math.abs(L.start)/L.size+1e-6)%1<2e-6&&(G.tick0=0)}G.dtick=Y}G.domain=[U+N,U+R-N],G.setScale(),t.attr("transform","translate("+Math.round(l.l)+","+Math.round(l.t)+")");var J,K=t.select("."+T.cbtitleunshift).attr("transform","translate(-"+Math.round(l.l)+",-"+Math.round(l.t)+")"),Q=t.select("."+T.cbaxis),$=0;function tt(n,a){var i={propContainer:G,propName:e._propPrefix+"title",traceIndex:e._traceIndex,_meta:e._meta,placeholder:o._dfltTitle.colorbar,containerGroup:t.select("."+T.cbtitle)},s="h"===n.charAt(0)?n.substr(1):"h"+n;t.selectAll("."+s+",."+s+"-math-group").remove(),d.draw(r,n,u(i,a||{}))}return c.syncOrAsync([i.previousPromises,function(){if(-1!==["top","bottom"].indexOf(M)){var t,r=l.l+(e.x+F)*l.w,n=G.title.font.size;t="top"===M?(1-(U+R-N))*l.h+l.t+3+.75*n:(1-(U+N))*l.h+l.t-3-.25*n,tt(G._id+"title",{attributes:{x:r,y:t,"text-anchor":"start"}})}},function(){if(-1!==["top","bottom"].indexOf(M)){var i=t.select("."+T.cbtitle),o=i.select("text"),u=[-e.outlinewidth/2,e.outlinewidth/2],h=i.select(".h"+G._id+"title-math-group").node(),p=15.6;if(o.node()&&(p=parseInt(o.node().style.fontSize,10)*_),h?($=f.bBox(h).height)>p&&(u[1]-=($-p)/2):o.node()&&!o.classed(T.jsPlaceholder)&&($=f.bBox(o.node()).height),$){if($+=5,"top"===M)G.domain[1]-=$/l.h,u[1]*=-1;else{G.domain[0]+=$/l.h;var d=g.lineCount(o);u[1]+=(1-d)*p}i.attr("transform","translate("+u+")"),G.setScale()}}t.selectAll("."+T.cbfills+",."+T.cblines).attr("transform","translate(0,"+Math.round(l.h*(1-G.domain[1]))+")"),Q.attr("transform","translate(0,"+Math.round(-l.t)+")");var m=t.select("."+T.cbfills).selectAll("rect."+T.cbfill).data(P);m.enter().append("rect").classed(T.cbfill,!0).style("stroke","none"),m.exit().remove();var y=A.map(G.c2p).map(Math.round).sort(function(t,e){return t-e});m.each(function(t,i){var o=[0===i?A[0]:(P[i]+P[i-1])/2,i===P.length-1?A[1]:(P[i]+P[i+1])/2].map(G.c2p).map(Math.round);o[1]=c.constrain(o[1]+(o[1]>o[0])?1:-1,y[0],y[1]);var s=n.select(this).attr({x:j,width:Math.max(z,2),y:n.min(o),height:Math.max(n.max(o)-n.min(o),2)});if(e._fillgradient)f.gradient(s,r,e._id,"vertical",e._fillgradient,"fill");else{var l=E(t).replace("e-","");s.attr("fill",a(l).toHexString())}});var x=t.select("."+T.cblines).selectAll("path."+T.cbline).data(v.color&&v.width?O:[]);x.enter().append("path").classed(T.cbline,!0),x.exit().remove(),x.each(function(t){n.select(this).attr("d","M"+j+","+(Math.round(G.c2p(t))+v.width/2%1)+"h"+z).call(f.lineGroupStyle,v.width,S(t),v.dash)}),Q.selectAll("g."+G._id+"tick,path").remove();var b=j+z+(e.outlinewidth||0)/2-("outside"===e.ticks?1:0),w=s.calcTicks(G),k=s.makeTransFn(G),L=s.getTickSigns(G)[2];return s.drawTicks(r,G,{vals:"inside"===G.ticks?s.clipEnds(G,w):w,layer:Q,path:s.makeTickPath(G,b,L),transFn:k}),s.drawLabels(r,G,{vals:w,layer:Q,transFn:k,labelFns:s.makeLabelFns(G,b)})},function(){if(-1===["top","bottom"].indexOf(M)){var t=G.title.font.size,e=G._offset+G._length/2,a=l.l+(G.position||0)*l.w+("right"===G.side?10+t*(G.showticklabels?1:.5):-10-t*(G.showticklabels?.5:0));tt("h"+G._id+"title",{avoid:{selection:n.select(r).selectAll("g."+G._id+"tick"),side:M,offsetLeft:l.l,offsetTop:0,maxShift:o.width},attributes:{x:a,y:e,"text-anchor":"middle"},transform:{rotate:"-90",offset:0}})}},i.previousPromises,function(){var n=z+e.outlinewidth/2+f.bBox(Q.node()).width;if((J=K.select("text")).node()&&!J.classed(T.jsPlaceholder)){var a,o=K.select(".h"+G._id+"title-math-group").node();a=o&&-1!==["top","bottom"].indexOf(M)?f.bBox(o).width:f.bBox(K.node()).right-j-l.l,n=Math.max(n,a)}var s=2*e.xpad+n+e.borderwidth+e.outlinewidth/2,c=q-H;t.select("."+T.cbbg).attr({x:j-e.xpad-(e.borderwidth+e.outlinewidth)/2,y:H-B,width:Math.max(s,2),height:Math.max(c+2*B,2)}).call(p.fill,e.bgcolor).call(p.stroke,e.bordercolor).style("stroke-width",e.borderwidth),t.selectAll("."+T.cboutline).attr({x:j,y:H+e.ypad+("top"===M?$:0),width:Math.max(z,2),height:Math.max(c-2*e.ypad-$,2)}).call(p.stroke,e.outlinecolor).style({fill:"none","stroke-width":e.outlinewidth});var u=({center:.5,right:1}[e.xanchor]||0)*s;t.attr("transform","translate("+(l.l-u)+","+l.t+")");var h={},d=w[e.yanchor],g=k[e.yanchor];"pixels"===e.lenmode?(h.y=e.y,h.t=c*d,h.b=c*g):(h.t=h.b=0,h.yt=e.y+e.len*d,h.yb=e.y-e.len*g);var v=w[e.xanchor],m=k[e.xanchor];if("pixels"===e.thicknessmode)h.x=e.x,h.l=s*v,h.r=s*m;else{var y=s-z;h.l=y*v,h.r=y*m,h.xl=e.x-e.thickness*v,h.xr=e.x+e.thickness*m}i.autoMargin(r,e._id,h)}],r)}(r,e,t);v&&v.then&&(t._promises||[]).push(v),t._context.edits.colorbarPosition&&function(t,e,r){var n,a,i,s=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr("transform"),h(t)},moveFn:function(r,o){t.attr("transform",n+" translate("+r+","+o+")"),a=l.align(e._xLeftFrac+r/s.w,e._thickFrac,0,1,e.xanchor),i=l.align(e._yBottomFrac-o/s.h,e._lenFrac,0,1,e.yanchor);var c=l.getCursor(a,i,e.xanchor,e.yanchor);h(t,c)},doneFn:function(){if(h(t),void 0!==a&&void 0!==i){var n={};n[e._propPrefix+"x"]=a,n[e._propPrefix+"y"]=i,void 0!==e._traceIndex?o.call("_guiRestyle",r,n,e._traceIndex):o.call("_guiRelayout",r,n)}}})}(r,e,t)}),e.exit().each(function(e){i.autoMargin(t,e._id)}).remove(),e.order()}}},{"../../constants/alignment":686,"../../lib":717,"../../lib/extend":708,"../../lib/setcursor":737,"../../lib/svg_text_utils":741,"../../plots/cartesian/axes":765,"../../plots/cartesian/axis_defaults":767,"../../plots/cartesian/layout_attributes":777,"../../plots/cartesian/position_defaults":780,"../../plots/plots":826,"../../registry":846,"../color":591,"../colorscale/helpers":602,"../dragelement":609,"../drawing":612,"../titles":679,"./constants":593,d3:165,tinycolor2:535}],596:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{"../../lib":717}],597:[function(t,e,r){"use strict";e.exports={moduleType:"component",name:"colorbar",attributes:t("./attributes"),supplyDefaults:t("./defaults"),draw:t("./draw").draw,hasColorbar:t("./has_colorbar")}},{"./attributes":592,"./defaults":594,"./draw":595,"./has_colorbar":596}],598:[function(t,e,r){"use strict";var n=t("../colorbar/attributes"),a=t("../../lib/regex").counter,i=t("./scales.js").scales;Object.keys(i);function o(t){return"`"+t+"`"}e.exports=function(t,e){t=t||"";var r,s=(e=e||{}).cLetter||"c",l=("onlyIfNumerical"in e?e.onlyIfNumerical:Boolean(t),"noScale"in e?e.noScale:"marker.line"===t),c="showScaleDflt"in e?e.showScaleDflt:"z"===s,u="string"==typeof e.colorscaleDflt?i[e.colorscaleDflt]:null,h=e.editTypeOverride||"",f=t?t+".":"";"colorAttr"in e?(r=e.colorAttr,e.colorAttr):o(f+(r={z:"z",c:"color"}[s]));var p=s+"auto",d=s+"min",g=s+"max",v=s+"mid",m=(o(f+p),o(f+d),o(f+g),{});m[d]=m[g]=void 0;var y={};y[p]=!1;var x={};return"color"===r&&(x.color={valType:"color",arrayOk:!0,editType:h||"style"},e.anim&&(x.color.anim=!0)),x[p]={valType:"boolean",dflt:!0,editType:"calc",impliedEdits:m},x[d]={valType:"number",dflt:null,editType:h||"plot",impliedEdits:y},x[g]={valType:"number",dflt:null,editType:h||"plot",impliedEdits:y},x[v]={valType:"number",dflt:null,editType:"calc",impliedEdits:m},x.colorscale={valType:"colorscale",editType:"calc",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:"boolean",dflt:!1!==e.autoColorDflt,editType:"calc",impliedEdits:{colorscale:void 0}},x.reversescale={valType:"boolean",dflt:!1,editType:"plot"},l||(x.showscale={valType:"boolean",dflt:c,editType:"calc"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:"subplotid",regex:a("coloraxis"),dflt:null,editType:"calc"}),x}},{"../../lib/regex":733,"../colorbar/attributes":592,"./scales.js":606}],599:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("./helpers").extractOpts;e.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?a.nestedProperty(e,c).get():e,h=i(u),f=!1!==h.auto,p=h.min,d=h.max,g=h.mid,v=function(){return a.aggNums(Math.min,null,l)},m=function(){return a.aggNums(Math.max,null,l)};(void 0===p?p=v():f&&(p=u._colorAx&&n(p)?Math.min(p,v()):v()),void 0===d?d=m():f&&(d=u._colorAx&&n(d)?Math.max(d,m()):m()),f&&void 0!==g&&(d-g>g-p?p=g-(d-g):d-g<g-p&&(d=g+(g-p))),p===d&&(p-=.5,d+=.5),h._sync("min",p),h._sync("max",d),h.autocolorscale)&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,h._sync("colorscale",o))}},{"../../lib":717,"./helpers":602,"fast-isnumeric":228}],600:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./helpers").hasColorscale,i=t("./helpers").extractOpts;e.exports=function(t,e){function r(t,e){var r=t["_"+e];void 0!==r&&(t[e]=r)}function o(t,a){var o=a.container?n.nestedProperty(t,a.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=i(o),l=s.auto;(l||void 0===s.min)&&r(o,a.min),(l||void 0===s.max)&&r(o,a.max),s.autocolorscale&&r(o,"colorscale")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);a(l,"marker.line")&&o(l,{container:"marker.line",min:"cmin",max:"cmax"})}for(var h in e._colorAxes)o(e[h],{min:"cmin",max:"cmax"})}},{"../../lib":717,"./helpers":602}],601:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../colorbar/has_colorbar"),o=t("../colorbar/defaults"),s=t("./scales").isValid,l=t("../../registry").traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?a.nestedProperty(t,r).get()||{}:t}e.exports=function t(e,r,u,h,f){var p=f.prefix,d=f.cLetter,g="_module"in r,v=c(e,p),m=c(r,p),y=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,h,f)};if(g){var b=u._colorAxes||{},_=h(p+"coloraxis");if(_){var w=l(r,"contour")&&a.nestedProperty(r,"contours.coloring").get()||"heatmap",k=b[_];return void(k?(k[2].push(x),k[0]!==w&&(k[0]=!1,a.warn(["Ignoring coloraxis:",_,"setting","as it is linked to incompatible colorscales."].join(" ")))):b[_]=[w,r,[x]])}}var T=v[d+"min"],M=v[d+"max"],A=n(T)&&n(M)&&T<M;h(p+d+"auto",!A)?h(p+d+"mid"):(h(p+d+"min"),h(p+d+"max"));var S,E,L=v.colorscale,C=y.colorscale;(void 0!==L&&(S=!s(L)),void 0!==C&&(S=!s(C)),h(p+"autocolorscale",S),h(p+"colorscale"),h(p+"reversescale"),"marker.line."!==p)&&(p&&g&&(E=i(v)),h(p+"showscale",E)&&(p&&y&&(m._template=y),o(v,m,u)))}},{"../../lib":717,"../../registry":846,"../colorbar/defaults":594,"../colorbar/has_colorbar":596,"./scales":606,"fast-isnumeric":228}],602:[function(t,e,r){"use strict";var n=t("d3"),a=t("tinycolor2"),i=t("fast-isnumeric"),o=t("../../lib"),s=t("../color"),l=t("./scales").isValid;var c=["showscale","autocolorscale","colorscale","reversescale","colorbar"],u=["min","max","mid","auto"];function h(t){var e,r,n,a=t._colorAx,i=a||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=i[n];if(a)for(e="c",r=0;r<u.length;r++)o[n=u[r]]=i["c"+n];else{var s;for(r=0;r<u.length;r++)(s="c"+(n=u[r]))in i?o[n]=i[s]:(s="z"+n)in i&&(o[n]=i[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;i[n]=i["_"+n]=r},o}function f(t){for(var e=h(t),r=e.min,n=e.max,a=e.reversescale?p(e.colorscale):e.colorscale,i=a.length,o=new Array(i),s=new Array(i),l=0;l<i;l++){var c=a[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,a=0;n>=0;n--,a++){var i=t[n];r[a]=[1-i[0],i[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var h=a(o[u]).toRgb();c[u]=[h.r,h.g,h.b,h.a]}var f,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,v=e.returnArray;return(f=d&&v?p:d?function(t){return g(p(t))}:v?function(t){return i(t)?p(t):a(t).isValid()?t:s.defaultLine}:function(t){return i(t)?g(p(t)):a(t).isValid()?t:s.defaultLine}).domain=p.domain,f.range=function(){return o},f}function g(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return a(e).toRgbString()}e.exports={hasColorscale:function(t,e,r){var n=e?o.nestedProperty(t,e).get()||{}:t,a=n[r||"color"],s=!1;if(o.isArrayOrTypedArray(a))for(var c=0;c<a.length;c++)if(i(a[c])){s=!0;break}return o.isPlainObject(n)&&(s||!0===n.showscale||i(n.cmin)&&i(n.cmax)||l(n.colorscale)||o.isPlainObject(n.colorbar))},extractOpts:h,extractScale:f,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(f(t),e)}}},{"../../lib":717,"../color":591,"./scales":606,d3:165,"fast-isnumeric":228,tinycolor2:535}],603:[function(t,e,r){"use strict";var n=t("./scales"),a=t("./helpers");e.exports={moduleType:"component",name:"colorscale",attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyLayoutDefaults:t("./layout_defaults"),handleDefaults:t("./defaults"),crossTraceDefaults:t("./cross_trace_defaults"),calc:t("./calc"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:a.hasColorscale,extractOpts:a.extractOpts,extractScale:a.extractScale,flipScale:a.flipScale,makeColorScaleFunc:a.makeColorScaleFunc,makeColorScaleFuncFromTrace:a.makeColorScaleFuncFromTrace}},{"./attributes":598,"./calc":599,"./cross_trace_defaults":600,"./defaults":601,"./helpers":602,"./layout_attributes":604,"./layout_defaults":605,"./scales":606}],604:[function(t,e,r){"use strict";var n=t("../../lib/extend").extendFlat,a=t("./attributes"),i=t("./scales").scales;e.exports={editType:"calc",colorscale:{editType:"calc",sequential:{valType:"colorscale",dflt:i.Reds,editType:"calc"},sequentialminus:{valType:"colorscale",dflt:i.Blues,editType:"calc"},diverging:{valType:"colorscale",dflt:i.RdBu,editType:"calc"}},coloraxis:n({_isSubplotObj:!0,editType:"calc"},a("",{colorAttr:"corresponding trace color array(s)",noColorAxis:!0,showScaleDflt:!0}))}},{"../../lib/extend":708,"./attributes":598,"./scales":606}],605:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plot_api/plot_template"),i=t("./layout_attributes"),o=t("./defaults");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r("colorscale.sequential"),r("colorscale.sequentialminus"),r("colorscale.diverging");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,i.coloraxis,t,e)}for(var h in c){var f=c[h];if(f[0])s=t[h]||{},(l=a.newContainer(e,h,"coloraxis"))._name=h,o(s,l,e,u,{prefix:"",cLetter:"c"});else{for(var p=0;p<f[2].length;p++)f[2][p]();delete e._colorAxes[h]}}}},{"../../lib":717,"../../plot_api/plot_template":755,"./defaults":601,"./layout_attributes":604}],606:[function(t,e,r){"use strict";var n=t("tinycolor2"),a={Greys:[[0,"rgb(0,0,0)"],[1,"rgb(255,255,255)"]],YlGnBu:[[0,"rgb(8,29,88)"],[.125,"rgb(37,52,148)"],[.25,"rgb(34,94,168)"],[.375,"rgb(29,145,192)"],[.5,"rgb(65,182,196)"],[.625,"rgb(127,205,187)"],[.75,"rgb(199,233,180)"],[.875,"rgb(237,248,217)"],[1,"rgb(255,255,217)"]],Greens:[[0,"rgb(0,68,27)"],[.125,"rgb(0,109,44)"],[.25,"rgb(35,139,69)"],[.375,"rgb(65,171,93)"],[.5,"rgb(116,196,118)"],[.625,"rgb(161,217,155)"],[.75,"rgb(199,233,192)"],[.875,"rgb(229,245,224)"],[1,"rgb(247,252,245)"]],YlOrRd:[[0,"rgb(128,0,38)"],[.125,"rgb(189,0,38)"],[.25,"rgb(227,26,28)"],[.375,"rgb(252,78,42)"],[.5,"rgb(253,141,60)"],[.625,"rgb(254,178,76)"],[.75,"rgb(254,217,118)"],[.875,"rgb(255,237,160)"],[1,"rgb(255,255,204)"]],Bluered:[[0,"rgb(0,0,255)"],[1,"rgb(255,0,0)"]],RdBu:[[0,"rgb(5,10,172)"],[.35,"rgb(106,137,247)"],[.5,"rgb(190,190,190)"],[.6,"rgb(220,170,132)"],[.7,"rgb(230,145,90)"],[1,"rgb(178,10,28)"]],Reds:[[0,"rgb(220,220,220)"],[.2,"rgb(245,195,157)"],[.4,"rgb(245,160,105)"],[1,"rgb(178,10,28)"]],Blues:[[0,"rgb(5,10,172)"],[.35,"rgb(40,60,190)"],[.5,"rgb(70,100,245)"],[.6,"rgb(90,120,245)"],[.7,"rgb(106,137,247)"],[1,"rgb(220,220,220)"]],Picnic:[[0,"rgb(0,0,255)"],[.1,"rgb(51,153,255)"],[.2,"rgb(102,204,255)"],[.3,"rgb(153,204,255)"],[.4,"rgb(204,204,255)"],[.5,"rgb(255,255,255)"],[.6,"rgb(255,204,255)"],[.7,"rgb(255,153,255)"],[.8,"rgb(255,102,204)"],[.9,"rgb(255,102,102)"],[1,"rgb(255,0,0)"]],Rainbow:[[0,"rgb(150,0,90)"],[.125,"rgb(0,0,200)"],[.25,"rgb(0,25,255)"],[.375,"rgb(0,152,255)"],[.5,"rgb(44,255,150)"],[.625,"rgb(151,255,0)"],[.75,"rgb(255,234,0)"],[.875,"rgb(255,111,0)"],[1,"rgb(255,0,0)"]],Portland:[[0,"rgb(12,51,131)"],[.25,"rgb(10,136,186)"],[.5,"rgb(242,211,56)"],[.75,"rgb(242,143,56)"],[1,"rgb(217,30,30)"]],Jet:[[0,"rgb(0,0,131)"],[.125,"rgb(0,60,170)"],[.375,"rgb(5,255,255)"],[.625,"rgb(255,255,0)"],[.875,"rgb(250,0,0)"],[1,"rgb(128,0,0)"]],Hot:[[0,"rgb(0,0,0)"],[.3,"rgb(230,0,0)"],[.6,"rgb(255,210,0)"],[1,"rgb(255,255,255)"]],Blackbody:[[0,"rgb(0,0,0)"],[.2,"rgb(230,0,0)"],[.4,"rgb(230,210,0)"],[.7,"rgb(255,255,255)"],[1,"rgb(160,200,255)"]],Earth:[[0,"rgb(0,0,130)"],[.1,"rgb(0,180,180)"],[.2,"rgb(40,210,40)"],[.4,"rgb(230,230,50)"],[.6,"rgb(120,70,20)"],[1,"rgb(255,255,255)"]],Electric:[[0,"rgb(0,0,0)"],[.15,"rgb(30,0,100)"],[.4,"rgb(120,0,100)"],[.6,"rgb(160,90,0)"],[.8,"rgb(230,200,0)"],[1,"rgb(255,250,220)"]],Viridis:[[0,"#440154"],[.06274509803921569,"#48186a"],[.12549019607843137,"#472d7b"],[.18823529411764706,"#424086"],[.25098039215686274,"#3b528b"],[.3137254901960784,"#33638d"],[.3764705882352941,"#2c728e"],[.4392156862745098,"#26828e"],[.5019607843137255,"#21918c"],[.5647058823529412,"#1fa088"],[.6274509803921569,"#28ae80"],[.6901960784313725,"#3fbc73"],[.7529411764705882,"#5ec962"],[.8156862745098039,"#84d44b"],[.8784313725490196,"#addc30"],[.9411764705882353,"#d8e219"],[1,"#fde725"]],Cividis:[[0,"rgb(0,32,76)"],[.058824,"rgb(0,42,102)"],[.117647,"rgb(0,52,110)"],[.176471,"rgb(39,63,108)"],[.235294,"rgb(60,74,107)"],[.294118,"rgb(76,85,107)"],[.352941,"rgb(91,95,109)"],[.411765,"rgb(104,106,112)"],[.470588,"rgb(117,117,117)"],[.529412,"rgb(131,129,120)"],[.588235,"rgb(146,140,120)"],[.647059,"rgb(161,152,118)"],[.705882,"rgb(176,165,114)"],[.764706,"rgb(192,177,109)"],[.823529,"rgb(209,191,102)"],[.882353,"rgb(225,204,92)"],[.941176,"rgb(243,219,79)"],[1,"rgb(255,233,69)"]]},i=a.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var a=t[r];if(2!==a.length||+a[0]<e||!n(a[1]).isValid())return!1;e=+a[0]}return!0}e.exports={scales:a,defaultScale:i,get:function(t,e){if(e||(e=i),!t)return e;function r(){try{t=a[t]||JSON.parse(t)}catch(r){t=e}}return"string"==typeof t&&(r(),"string"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==a[t]||o(t)}}},{tinycolor2:535}],607:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a){var i=(t-r)/(n-r),o=i+e/(n-r),s=(i+o)/2;return"left"===a||"bottom"===a?i:"center"===a||"middle"===a?s:"right"===a||"top"===a?o:i<2/3-s?i:o>4/3-s?o:s}},{}],608:[function(t,e,r){"use strict";var n=t("../../lib"),a=[["sw-resize","s-resize","se-resize"],["w-resize","move","e-resize"],["nw-resize","n-resize","ne-resize"]];e.exports=function(t,e,r,i){return t="left"===r?0:"center"===r?1:"right"===r?2:n.constrain(Math.floor(3*t),0,2),e="bottom"===i?0:"middle"===i?1:"top"===i?2:n.constrain(Math.floor(3*e),0,2),a[e][t]}},{"../../lib":717}],609:[function(t,e,r){"use strict";var n=t("mouse-event-offset"),a=t("has-hover"),i=t("has-passive-events"),o=t("../../lib").removeElement,s=t("../../plots/cartesian/constants"),l=e.exports={};l.align=t("./align"),l.getCursor=t("./cursor");var c=t("./unhover");function u(){var t=document.createElement("div");t.className="dragcover";var e=t.style;return e.position="fixed",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background="none",document.body.appendChild(t),t}function h(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,f,p,d,g,v=t.gd,m=1,y=v._context.doubleClickDelay,x=t.element;v._mouseDownTime||(v._mouseDownTime=0),x.style.pointerEvents="all",x.onmousedown=_,i?(x._ontouchstart&&x.removeEventListener("touchstart",x._ontouchstart),x._ontouchstart=_,x.addEventListener("touchstart",_,{passive:!1})):x.ontouchstart=_;var b=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function _(i){v._dragged=!1,v._dragging=!0;var o=h(i);e=o[0],r=o[1],d=i.target,p=i,g=2===i.buttons||i.ctrlKey,"undefined"==typeof i.clientX&&"undefined"==typeof i.clientY&&(i.clientX=e,i.clientY=r),(n=(new Date).getTime())-v._mouseDownTime<y?m+=1:(m=1,v._mouseDownTime=n),t.prepFn&&t.prepFn(i,e,r),a&&!g?(f=u()).style.cursor=window.getComputedStyle(x).cursor:a||(f=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener("mouseup",k),document.addEventListener("touchend",k),!1!==t.dragmode&&(i.preventDefault(),document.addEventListener("mousemove",w),document.addEventListener("touchmove",w,{passive:!1}))}function w(n){n.preventDefault();var a=h(n),i=t.minDrag||s.MINDRAG,o=b(a[0]-e,a[1]-r,i),c=o[0],u=o[1];(c||u)&&(v._dragged=!0,l.unhover(v)),v._dragged&&t.moveFn&&!g&&(v._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function k(e){if(delete v._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener("mousemove",w),document.removeEventListener("touchmove",w)),document.removeEventListener("mouseup",k),document.removeEventListener("touchend",k),a?o(f):c&&(f.documentElement.style.cursor=c,c=null),v._dragging){if(v._dragging=!1,(new Date).getTime()-v._mouseDownTime>y&&(m=Math.max(m-1,1)),v._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(m,p),!g){var r;try{r=new MouseEvent("click",e)}catch(t){var n=h(e);(r=document.createEvent("MouseEvents")).initMouseEvent("click",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}v._dragging=!1,v._dragged=!1}else v._dragged=!1}},l.coverSlip=u},{"../../lib":717,"../../plots/cartesian/constants":771,"./align":607,"./cursor":608,"./unhover":610,"has-hover":411,"has-passive-events":412,"mouse-event-offset":437}],610:[function(t,e,r){"use strict";var n=t("../../lib/events"),a=t("../../lib/throttle"),i=t("../../lib/dom").getGraphDiv,o=t("../fx/constants"),s=e.exports={};s.wrapped=function(t,e,r){(t=i(t))._fullLayout&&a.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,a=t._hoverdata;e||(e={}),e.target&&!1===n.triggerHandler(t,"plotly_beforehover",e)||(r._hoverlayer.selectAll("g").remove(),r._hoverlayer.selectAll("line").remove(),r._hoverlayer.selectAll("circle").remove(),t._hoverdata=void 0,e.target&&a&&t.emit("plotly_unhover",{event:e,points:a}))}},{"../../lib/dom":706,"../../lib/events":707,"../../lib/throttle":742,"../fx/constants":624}],611:[function(t,e,r){"use strict";r.dash={valType:"string",values:["solid","dot","dash","longdash","dashdot","longdashdot"],dflt:"solid",editType:"style"}},{}],612:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("tinycolor2"),o=t("../../registry"),s=t("../color"),l=t("../colorscale"),c=t("../../lib"),u=t("../../lib/svg_text_utils"),h=t("../../constants/xmlns_namespaces"),f=t("../../constants/alignment").LINE_SPACING,p=t("../../constants/interactions").DESELECTDIM,d=t("../../traces/scatter/subtypes"),g=t("../../traces/scatter/make_bubble_size_func"),v=t("../../components/fx/helpers").appendArrayPointValue,m=e.exports={};m.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style("font-family",e),r+1&&t.style("font-size",r+"px"),n&&t.call(s.fill,n)},m.setPosition=function(t,e,r){t.attr("x",e).attr("y",r)},m.setSize=function(t,e,r){t.attr("width",e).attr("height",r)},m.setRect=function(t,e,r,n,a){t.call(m.setPosition,e,r).call(m.setSize,n,a)},m.translatePoint=function(t,e,r,n){var i=r.c2p(t.x),o=n.c2p(t.y);return!!(a(i)&&a(o)&&e.node())&&("text"===e.node().nodeName?e.attr("x",i).attr("y",o):e.attr("transform","translate("+i+","+o+")"),!0)},m.translatePoints=function(t,e,r){t.each(function(t){var a=n.select(this);m.translatePoint(t,a,e,r)})},m.hideOutsideRangePoint=function(t,e,r,n,a,i){e.attr("display",r.isPtWithinRange(t,a)&&n.isPtWithinRange(t,i)?null:"none")},m.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,a=e.yaxis;t.each(function(e){var i=e[0].trace,s=i.xcalendar,l=i.ycalendar,c=o.traceIs(i,"bar-like")?".bartext":".point,.textpoint";t.selectAll(c).each(function(t){m.hideOutsideRangePoint(t,n.select(this),r,a,s,l)})})}},m.crispRound=function(t,e,r){return e&&a(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},m.singleLineStyle=function(t,e,r,n,a){e.style("fill","none");var i=(((t||[])[0]||{}).trace||{}).line||{},o=r||i.width||0,l=a||i.dash||"";s.stroke(e,n||i.color),m.dashLine(e,l,o)},m.lineGroupStyle=function(t,e,r,a){t.style("fill","none").each(function(t){var i=(((t||[])[0]||{}).trace||{}).line||{},o=e||i.width||0,l=a||i.dash||"";n.select(this).call(s.stroke,r||i.color).call(m.dashLine,l,o)})},m.dashLine=function(t,e,r){r=+r||0,e=m.dashStyle(e,r),t.style({"stroke-dasharray":e,"stroke-width":r+"px"})},m.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return"solid"===t?t="":"dot"===t?t=r+"px,"+r+"px":"dash"===t?t=3*r+"px,"+3*r+"px":"longdash"===t?t=5*r+"px,"+5*r+"px":"dashdot"===t?t=3*r+"px,"+r+"px,"+r+"px,"+r+"px":"longdashdot"===t&&(t=5*r+"px,"+2*r+"px,"+r+"px,"+2*r+"px"),t},m.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},m.fillGroupStyle=function(t){t.style("stroke-width",0).each(function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)})};var y=t("./symbol_defs");m.symbolNames=[],m.symbolFuncs=[],m.symbolNeedLines={},m.symbolNoDot={},m.symbolNoFill={},m.symbolList=[],Object.keys(y).forEach(function(t){var e=y[t],r=e.n;m.symbolList.push(r,t,r+100,t+"-open"),m.symbolNames[r]=t,m.symbolFuncs[r]=e.f,e.needLine&&(m.symbolNeedLines[r]=!0),e.noDot?m.symbolNoDot[r]=!0:m.symbolList.push(r+200,t+"-dot",r+300,t+"-open-dot"),e.noFill&&(m.symbolNoFill[r]=!0)});var x=m.symbolNames.length,b="M0,0.5L0.5,0L0,-0.5L-0.5,0Z";function _(t,e){var r=t%100;return m.symbolFuncs[r](e)+(t>=200?b:"")}m.symbolNumber=function(t){if("string"==typeof t){var e=0;t.indexOf("-open")>0&&(e=100,t=t.replace("-open","")),t.indexOf("-dot")>0&&(e+=200,t=t.replace("-dot","")),(t=m.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=x||t>=400?0:Math.floor(Math.max(t,0))};var w={x1:1,x2:0,y1:0,y2:0},k={x1:0,x2:0,y1:1,y2:0},T=n.format("~.1f"),M={radial:{node:"radialGradient"},radialreversed:{node:"radialGradient",reversed:!0},horizontal:{node:"linearGradient",attrs:w},horizontalreversed:{node:"linearGradient",attrs:w,reversed:!0},vertical:{node:"linearGradient",attrs:k},verticalreversed:{node:"linearGradient",attrs:k,reversed:!0}};m.gradient=function(t,e,r,a,o,l){for(var u=o.length,h=M[a],f=new Array(u),p=0;p<u;p++)h.reversed?f[u-1-p]=[T(100*(1-o[p][0])),o[p][1]]:f[p]=[T(100*o[p][0]),o[p][1]];var d=e._fullLayout,g="g"+d._uid+"-"+r,v=d._defs.select(".gradients").selectAll("#"+g).data([a+f.join(";")],c.identity);v.exit().remove(),v.enter().append(h.node).each(function(){var t=n.select(this);h.attrs&&t.attr(h.attrs),t.attr("id",g);var e=t.selectAll("stop").data(f);e.exit().remove(),e.enter().append("stop"),e.each(function(t){var e=i(t[1]);n.select(this).attr({offset:t[0]+"%","stop-color":s.tinyRGB(e),"stop-opacity":e.getAlpha()})})}),t.style(l,D(g,e)).style(l+"-opacity",null);var m=function(t){return"."+t.attr("class").replace(/\s/g,".")},y=m(n.select(t.node().parentNode))+">"+m(t);d._gradientUrlQueryParts[y]=1},m.initGradients=function(t){var e=t._fullLayout;c.ensureSingle(e._defs,"g","gradients").selectAll("linearGradient,radialGradient").remove(),e._gradientUrlQueryParts={}},m.pointStyle=function(t,e,r){if(t.size()){var a=m.makePointStyleFns(e);t.each(function(t){m.singlePointStyle(t,n.select(this),e,a,r)})}},m.singlePointStyle=function(t,e,r,n,a){var i=r.marker,o=i.line;if(e.style("opacity",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?i.opacity:t.mo),n.ms2mrc){var l;l="various"===t.ms||"various"===i.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=m.symbolNumber(t.mx||i.symbol)||0;t.om=u%200>=100,e.attr("d",_(u,l))}var h,f,p,d=!1;if(t.so)p=o.outlierwidth,f=o.outliercolor,h=i.outliercolor;else{var g=(o||{}).width;p=(t.mlw+1||g+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,f="mlc"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(i.color)&&(h=s.defaultLine,d=!0),h="mc"in t?t.mcc=n.markerScale(t.mc):i.color||"rgba(0,0,0,0)",n.selectedColorFn&&(h=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,h).style({"stroke-width":(p||1)+"px",fill:"none"});else{e.style("stroke-width",(t.isBlank?0:p)+"px");var v=i.gradient,y=t.mgt;if(y?d=!0:y=v&&v.type,Array.isArray(y)&&(y=y[0],M[y]||(y=0)),y&&"none"!==y){var x=t.mgc;x?d=!0:x=v.color;var b=r.uid;d&&(b+="-"+t.i),m.gradient(e,a,b,y,[[0,x],[1,h]],"fill")}else s.fill(e,h);p&&s.stroke(e,f)}},m.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=m.tryColorscale(r,""),e.lineScale=m.tryColorscale(r,"line"),o.traceIs(t,"symbols")&&(e.ms2mrc=d.isBubble(t)?g(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,m.makeSelectedPointStyleFns(t)),e},m.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},a=t.marker||{},i=r.marker||{},s=n.marker||{},l=a.opacity,u=i.opacity,h=s.opacity,f=void 0!==u,d=void 0!==h;(c.isArrayOrTypedArray(l)||f||d)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?a.opacity:t.mo;return t.selected?f?u:e:d?h:p*e});var g=a.color,v=i.color,m=s.color;(v||m)&&(e.selectedColorFn=function(t){var e=t.mcc||g;return t.selected?v||e:m||e});var y=a.size,x=i.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,"symbols")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},m.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},a=t.textfont||{},i=r.textfont||{},o=n.textfont||{},l=a.color,c=i.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,p))},e},m.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=m.makeSelectedPointStyleFns(e),a=e.marker||{},i=[];r.selectedOpacityFn&&i.push(function(t,e){t.style("opacity",r.selectedOpacityFn(e))}),r.selectedColorFn&&i.push(function(t,e){s.fill(t,r.selectedColorFn(e))}),r.selectedSizeFn&&i.push(function(t,e){var n=e.mx||a.symbol||0,i=r.selectedSizeFn(e);t.attr("d",_(m.symbolNumber(n),i)),e.mrc2=i}),i.length&&t.each(function(t){for(var e=n.select(this),r=0;r<i.length;r++)i[r](e,t)})}},m.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&c.isArrayOrTypedArray(n))return l.makeColorScaleFuncFromTrace(r)}return c.identity};var A={start:1,end:-1,middle:0,bottom:1,top:-1};function S(t,e,r,a){var i=n.select(t.node().parentNode),o=-1!==e.indexOf("top")?"top":-1!==e.indexOf("bottom")?"bottom":"middle",s=-1!==e.indexOf("left")?"end":-1!==e.indexOf("right")?"start":"middle",l=a?a/.8+1:0,c=(u.lineCount(t)-1)*f+1,h=A[s]*l,p=.75*r+A[o]*l+(A[o]-1)*c*r/2;t.attr("text-anchor",s),i.attr("transform","translate("+h+","+p+")")}function E(t,e){var r=t.ts||e.textfont.size;return a(r)&&r>0?r:0}m.textPointStyle=function(t,e,r){if(t.size()){var a;if(e.selectedpoints){var i=m.makeSelectedTextStyleFns(e);a=i.selectedTextColorFn}var o=e.texttemplate,s=r._fullLayout;t.each(function(t){var i=n.select(this),l=o?c.extractOption(t,e,"txt","texttemplate"):c.extractOption(t,e,"tx","text");if(l||0===l){if(o){var h=e._module.formatLabels?e._module.formatLabels(t,e,s):{},f={};v(f,e,t.i);var p=e._meta||{};l=c.texttemplateString(l,h,s._d3locale,f,t,p)}var d=t.tp||e.textposition,g=E(t,e),y=a?a(t):t.tc||e.textfont.color;i.call(m.font,t.tf||e.textfont.family,g,y).text(l).call(u.convertToTspans,r).call(S,d,g,t.mrc)}else i.remove()})}},m.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=m.makeSelectedTextStyleFns(e);t.each(function(t){var a=n.select(this),i=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=E(t,e);s.fill(a,i),S(a,o,l,t.mrc2||t.mrc)})}};var L=.5;function C(t,e,r,a){var i=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(i*i+o*o,L/2),u=Math.pow(s*s+l*l,L/2),h=(u*u*i-c*c*s)*a,f=(u*u*o-c*c*l)*a,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&h/p),2),n.round(e[1]+(p&&f/p),2)],[n.round(e[0]-(d&&h/d),2),n.round(e[1]-(d&&f/d),2)]]}m.smoothopen=function(t,e){if(t.length<3)return"M"+t.join("L");var r,n="M"+t[0],a=[];for(r=1;r<t.length-1;r++)a.push(C(t[r-1],t[r],t[r+1],e));for(n+="Q"+a[0][0]+" "+t[1],r=2;r<t.length-1;r++)n+="C"+a[r-2][1]+" "+a[r-1][0]+" "+t[r];return n+="Q"+a[t.length-3][1]+" "+t[t.length-1]},m.smoothclosed=function(t,e){if(t.length<3)return"M"+t.join("L")+"Z";var r,n="M"+t[0],a=t.length-1,i=[C(t[a],t[0],t[1],e)];for(r=1;r<a;r++)i.push(C(t[r-1],t[r],t[r+1],e));for(i.push(C(t[a-1],t[a],t[0],e)),r=1;r<=a;r++)n+="C"+i[r-1][1]+" "+i[r][0]+" "+t[r];return n+="C"+i[a][1]+" "+i[0][0]+" "+t[0]+"Z"};var P={hv:function(t,e){return"H"+n.round(e[0],2)+"V"+n.round(e[1],2)},vh:function(t,e){return"V"+n.round(e[1],2)+"H"+n.round(e[0],2)},hvh:function(t,e){return"H"+n.round((t[0]+e[0])/2,2)+"V"+n.round(e[1],2)+"H"+n.round(e[0],2)},vhv:function(t,e){return"V"+n.round((t[1]+e[1])/2,2)+"H"+n.round(e[0],2)+"V"+n.round(e[1],2)}},O=function(t,e){return"L"+n.round(e[0],2)+","+n.round(e[1],2)};m.steps=function(t){var e=P[t]||O;return function(t){for(var r="M"+n.round(t[0][0],2)+","+n.round(t[0][1],2),a=1;a<t.length;a++)r+=e(t[a-1],t[a]);return r}},m.makeTester=function(){var t=c.ensureSingleById(n.select("body"),"svg","js-plotly-tester",function(t){t.attr(h.svgAttrs).style({position:"absolute",left:"-10000px",top:"-10000px",width:"9000px",height:"9000px","z-index":"1"})}),e=c.ensureSingle(t,"path","js-reference-point",function(t){t.attr("d","M0,0H1V1H0Z").style({"stroke-width":0,fill:"black"})});m.tester=t,m.testref=e},m.savedBBoxes={};var z=0;function I(t){var e=t.getAttribute("data-unformatted");if(null!==e)return e+t.getAttribute("data-math")+t.getAttribute("text-anchor")+t.getAttribute("style")}function D(t,e){if(!t)return null;var r=e._context;return"url('"+(r._exportedPlot?"":r._baseUrl||"")+"#"+t+"')"}m.bBox=function(t,e,r){var a,i,o;if(r||(r=I(t)),r){if(a=m.savedBBoxes[r])return c.extendFlat({},a)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=I(s)){var l=+s.getAttribute("x")||0,h=+s.getAttribute("y")||0,f=s.getAttribute("transform");if(!f){var p=m.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),h&&(p.top+=h,p.bottom+=h),p}if(r+="~"+l+"~"+h+"~"+f,a=m.savedBBoxes[r])return c.extendFlat({},a)}}e?i=t:(o=m.tester.node(),i=t.cloneNode(!0),o.appendChild(i)),n.select(i).attr("transform",null).call(u.positionText,0,0);var d=i.getBoundingClientRect(),g=m.testref.node().getBoundingClientRect();e||o.removeChild(i);var v={height:d.height,width:d.width,left:d.left-g.left,top:d.top-g.top,right:d.right-g.left,bottom:d.bottom-g.top};return z>=1e4&&(m.savedBBoxes={},z=0),r&&(m.savedBBoxes[r]=v),z++,c.extendFlat({},v)},m.setClipUrl=function(t,e,r){t.attr("clip-path",D(e,r))},m.getTranslate=function(t){var e=(t[t.attr?"attr":"getAttribute"]("transform")||"").replace(/.*\btranslate\((-?\d*\.?\d*)[^-\d]*(-?\d*\.?\d*)[^\d].*/,function(t,e,r){return[e,r].join(" ")}).split(" ");return{x:+e[0]||0,y:+e[1]||0}},m.setTranslate=function(t,e,r){var n=t.attr?"attr":"getAttribute",a=t.attr?"attr":"setAttribute",i=t[n]("transform")||"";return e=e||0,r=r||0,i=i.replace(/(\btranslate\(.*?\);?)/,"").trim(),i=(i+=" translate("+e+", "+r+")").trim(),t[a]("transform",i),i},m.getScale=function(t){var e=(t[t.attr?"attr":"getAttribute"]("transform")||"").replace(/.*\bscale\((\d*\.?\d*)[^\d]*(\d*\.?\d*)[^\d].*/,function(t,e,r){return[e,r].join(" ")}).split(" ");return{x:+e[0]||1,y:+e[1]||1}},m.setScale=function(t,e,r){var n=t.attr?"attr":"getAttribute",a=t.attr?"attr":"setAttribute",i=t[n]("transform")||"";return e=e||1,r=r||1,i=i.replace(/(\bscale\(.*?\);?)/,"").trim(),i=(i+=" scale("+e+", "+r+")").trim(),t[a]("transform",i),i};var R=/\s*sc.*/;m.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?"":" scale("+e+","+r+")";t.each(function(){var t=(this.getAttribute("transform")||"").replace(R,"");t=(t+=n).trim(),this.setAttribute("transform",t)})}};var F=/translate\([^)]*\)\s*$/;m.setTextPointsScale=function(t,e,r){t&&t.each(function(){var t,a=n.select(this),i=a.select("text");if(i.node()){var o=parseFloat(i.attr("x")||0),s=parseFloat(i.attr("y")||0),l=(a.attr("transform")||"").match(F);t=1===e&&1===r?[]:["translate("+o+","+s+")","scale("+e+","+r+")","translate("+-o+","+-s+")"],l&&t.push(l),a.attr("transform",t.join(" "))}})}},{"../../components/fx/helpers":626,"../../constants/alignment":686,"../../constants/interactions":692,"../../constants/xmlns_namespaces":694,"../../lib":717,"../../lib/svg_text_utils":741,"../../registry":846,"../../traces/scatter/make_bubble_size_func":1137,"../../traces/scatter/subtypes":1144,"../color":591,"../colorscale":603,"./symbol_defs":613,d3:165,"fast-isnumeric":228,tinycolor2:535}],613:[function(t,e,r){"use strict";var n=t("d3");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return"M"+e+",0A"+e+","+e+" 0 1,1 0,-"+e+"A"+e+","+e+" 0 0,1 "+e+",0Z"}},square:{n:1,f:function(t){var e=n.round(t,2);return"M"+e+","+e+"H-"+e+"V-"+e+"H"+e+"Z"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return"M"+e+",0L0,"+e+"L-"+e+",0L0,-"+e+"Z"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return"M"+r+","+e+"H"+e+"V"+r+"H-"+e+"V"+e+"H-"+r+"V-"+e+"H-"+e+"V-"+r+"H"+e+"V-"+e+"H"+r+"Z"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r="l"+e+","+e,a="l"+e+",-"+e,i="l-"+e+",-"+e,o="l-"+e+","+e;return"M0,"+e+r+a+i+a+i+o+i+o+r+o+r+"Z"}},"triangle-up":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return"M-"+e+","+n.round(t/2,2)+"H"+e+"L0,-"+n.round(t,2)+"Z"}},"triangle-down":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return"M-"+e+",-"+n.round(t/2,2)+"H"+e+"L0,"+n.round(t,2)+"Z"}},"triangle-left":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return"M"+n.round(t/2,2)+",-"+e+"V"+e+"L-"+n.round(t,2)+",0Z"}},"triangle-right":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return"M-"+n.round(t/2,2)+",-"+e+"V"+e+"L"+n.round(t,2)+",0Z"}},"triangle-ne":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return"M-"+r+",-"+e+"H"+e+"V"+r+"Z"}},"triangle-se":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return"M"+e+",-"+r+"V"+e+"H-"+r+"Z"}},"triangle-sw":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return"M"+r+","+e+"H-"+e+"V-"+r+"Z"}},"triangle-nw":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return"M-"+e+","+r+"V-"+e+"H"+r+"Z"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),a=n.round(-t,2),i=n.round(-.309*t,2);return"M"+e+","+i+"L"+r+","+n.round(.809*t,2)+"H-"+r+"L-"+e+","+i+"L0,"+a+"Z"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),a=n.round(t*Math.sqrt(3)/2,2);return"M"+a+",-"+r+"V"+r+"L0,"+e+"L-"+a+","+r+"V-"+r+"L0,-"+e+"Z"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),a=n.round(t*Math.sqrt(3)/2,2);return"M-"+r+","+a+"H"+r+"L"+e+",0L"+r+",-"+a+"H-"+r+"L-"+e+",0Z"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return"M-"+r+",-"+e+"H"+r+"L"+e+",-"+r+"V"+r+"L"+r+","+e+"H-"+r+"L-"+e+","+r+"V-"+r+"Z"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),a=n.round(.951*e,2),i=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return"M"+r+","+l+"H"+a+"L"+i+","+c+"L"+o+","+u+"L0,"+n.round(.382*e,2)+"L-"+o+","+u+"L-"+i+","+c+"L-"+a+","+l+"H-"+r+"L0,"+s+"Z"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),a=n.round(.76*t,2);return"M-"+a+",0l-"+r+",-"+e+"h"+a+"l"+r+",-"+e+"l"+r+","+e+"h"+a+"l-"+r+","+e+"l"+r+","+e+"h-"+a+"l-"+r+","+e+"l-"+r+",-"+e+"h-"+a+"Z"}},"star-triangle-up":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),a=n.round(1.6*t,2),i=n.round(4*t,2),o="A "+i+","+i+" 0 0 1 ";return"M-"+e+","+r+o+e+","+r+o+"0,-"+a+o+"-"+e+","+r+"Z"}},"star-triangle-down":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),a=n.round(1.6*t,2),i=n.round(4*t,2),o="A "+i+","+i+" 0 0 1 ";return"M"+e+",-"+r+o+"-"+e+",-"+r+o+"0,"+a+o+e+",-"+r+"Z"}},"star-square":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),a="A "+r+","+r+" 0 0 1 ";return"M-"+e+",-"+e+a+"-"+e+","+e+a+e+","+e+a+e+",-"+e+a+"-"+e+",-"+e+"Z"}},"star-diamond":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),a="A "+r+","+r+" 0 0 1 ";return"M-"+e+",0"+a+"0,"+e+a+e+",0"+a+"0,-"+e+a+"-"+e+",0Z"}},"diamond-tall":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return"M0,"+r+"L"+e+",0L0,-"+r+"L-"+e+",0Z"}},"diamond-wide":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return"M0,"+r+"L"+e+",0L0,-"+r+"L-"+e+",0Z"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return"M"+e+","+e+"H-"+e+"L"+e+",-"+e+"H-"+e+"Z"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return"M"+e+","+e+"V-"+e+"L-"+e+","+e+"V-"+e+"Z"},noDot:!0},"circle-cross":{n:27,f:function(t){var e=n.round(t,2);return"M0,"+e+"V-"+e+"M"+e+",0H-"+e+"M"+e+",0A"+e+","+e+" 0 1,1 0,-"+e+"A"+e+","+e+" 0 0,1 "+e+",0Z"},needLine:!0,noDot:!0},"circle-x":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return"M"+r+","+r+"L-"+r+",-"+r+"M"+r+",-"+r+"L-"+r+","+r+"M"+e+",0A"+e+","+e+" 0 1,1 0,-"+e+"A"+e+","+e+" 0 0,1 "+e+",0Z"},needLine:!0,noDot:!0},"square-cross":{n:29,f:function(t){var e=n.round(t,2);return"M0,"+e+"V-"+e+"M"+e+",0H-"+e+"M"+e+","+e+"H-"+e+"V-"+e+"H"+e+"Z"},needLine:!0,noDot:!0},"square-x":{n:30,f:function(t){var e=n.round(t,2);return"M"+e+","+e+"L-"+e+",-"+e+"M"+e+",-"+e+"L-"+e+","+e+"M"+e+","+e+"H-"+e+"V-"+e+"H"+e+"Z"},needLine:!0,noDot:!0},"diamond-cross":{n:31,f:function(t){var e=n.round(1.3*t,2);return"M"+e+",0L0,"+e+"L-"+e+",0L0,-"+e+"ZM0,-"+e+"V"+e+"M-"+e+",0H"+e},needLine:!0,noDot:!0},"diamond-x":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return"M"+e+",0L0,"+e+"L-"+e+",0L0,-"+e+"ZM-"+r+",-"+r+"L"+r+","+r+"M-"+r+","+r+"L"+r+",-"+r},needLine:!0,noDot:!0},"cross-thin":{n:33,f:function(t){var e=n.round(1.4*t,2);return"M0,"+e+"V-"+e+"M"+e+",0H-"+e},needLine:!0,noDot:!0,noFill:!0},"x-thin":{n:34,f:function(t){var e=n.round(t,2);return"M"+e+","+e+"L-"+e+",-"+e+"M"+e+",-"+e+"L-"+e+","+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return"M0,"+e+"V-"+e+"M"+e+",0H-"+e+"M"+r+","+r+"L-"+r+",-"+r+"M"+r+",-"+r+"L-"+r+","+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return"M"+e+","+r+"V-"+r+"m-"+r+",0V"+r+"M"+r+","+e+"H-"+r+"m0,-"+r+"H"+r},needLine:!0,noFill:!0},"y-up":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),a=n.round(.8*t,2);return"M-"+e+","+a+"L0,0M"+e+","+a+"L0,0M0,-"+r+"L0,0"},needLine:!0,noDot:!0,noFill:!0},"y-down":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),a=n.round(.8*t,2);return"M-"+e+",-"+a+"L0,0M"+e+",-"+a+"L0,0M0,"+r+"L0,0"},needLine:!0,noDot:!0,noFill:!0},"y-left":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),a=n.round(.8*t,2);return"M"+a+","+e+"L0,0M"+a+",-"+e+"L0,0M-"+r+",0L0,0"},needLine:!0,noDot:!0,noFill:!0},"y-right":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),a=n.round(.8*t,2);return"M-"+a+","+e+"L0,0M-"+a+",-"+e+"L0,0M"+r+",0L0,0"},needLine:!0,noDot:!0,noFill:!0},"line-ew":{n:41,f:function(t){var e=n.round(1.4*t,2);return"M"+e+",0H-"+e},needLine:!0,noDot:!0,noFill:!0},"line-ns":{n:42,f:function(t){var e=n.round(1.4*t,2);return"M0,"+e+"V-"+e},needLine:!0,noDot:!0,noFill:!0},"line-ne":{n:43,f:function(t){var e=n.round(t,2);return"M"+e+",-"+e+"L-"+e+","+e},needLine:!0,noDot:!0,noFill:!0},"line-nw":{n:44,f:function(t){var e=n.round(t,2);return"M"+e+","+e+"L-"+e+",-"+e},needLine:!0,noDot:!0,noFill:!0}}},{d3:165}],614:[function(t,e,r){"use strict";e.exports={visible:{valType:"boolean",editType:"calc"},type:{valType:"enumerated",values:["percent","constant","sqrt","data"],editType:"calc"},symmetric:{valType:"boolean",editType:"calc"},array:{valType:"data_array",editType:"calc"},arrayminus:{valType:"data_array",editType:"calc"},value:{valType:"number",min:0,dflt:10,editType:"calc"},valueminus:{valType:"number",min:0,dflt:10,editType:"calc"},traceref:{valType:"integer",min:0,dflt:0,editType:"style"},tracerefminus:{valType:"integer",min:0,dflt:0,editType:"style"},copy_ystyle:{valType:"boolean",editType:"plot"},copy_zstyle:{valType:"boolean",editType:"style"},color:{valType:"color",editType:"style"},thickness:{valType:"number",min:0,dflt:2,editType:"style"},width:{valType:"number",min:0,editType:"plot"},editType:"calc",_deprecated:{opacity:{valType:"number",editType:"style"}}}},{}],615:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../registry"),i=t("../../plots/cartesian/axes"),o=t("../../lib"),s=t("./compute_error");function l(t,e,r,a){var l=e["error_"+a]||{},c=[];if(l.visible&&-1!==["linear","log"].indexOf(r.type)){for(var u=s(l),h=0;h<t.length;h++){var f=t[h],p=f.i;if(void 0===p)p=h;else if(null===p)continue;var d=f[a];if(n(r.c2l(d))){var g=u(d,p);if(n(g[0])&&n(g[1])){var v=f[a+"s"]=d-g[0],m=f[a+"h"]=d+g[1];c.push(v,m)}}}var y=r._id,x=e._extremes[y],b=i.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&a.traceIs(o,"errorBarsOK")){var s=i.getFromId(t,o.xaxis),c=i.getFromId(t,o.yaxis);l(n,o,s,"x"),l(n,o,c,"y")}}}},{"../../lib":717,"../../plots/cartesian/axes":765,"../../registry":846,"./compute_error":616,"fast-isnumeric":228}],616:[function(t,e,r){"use strict";function n(t,e){return"percent"===t?function(t){return Math.abs(t*e/100)}:"constant"===t?function(){return Math.abs(e)}:"sqrt"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if("data"===e){var a=t.array||[];if(r)return function(t,e){var r=+a[e];return[r,r]};var i=t.arrayminus||[];return function(t,e){var r=+a[e],n=+i[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],617:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../registry"),i=t("../../lib"),o=t("../../plot_api/plot_template"),s=t("./attributes");e.exports=function(t,e,r,l){var c="error_"+l.axis,u=o.newContainer(e,c),h=t[c]||{};function f(t,e){return i.coerce(h,u,s,t,e)}if(!1!==f("visible",void 0!==h.array||void 0!==h.value||"sqrt"===h.type)){var p=f("type","array"in h?"data":"percent"),d=!0;"sqrt"!==p&&(d=f("symmetric",!(("data"===p?"arrayminus":"valueminus")in h))),"data"===p?(f("array"),f("traceref"),d||(f("arrayminus"),f("tracerefminus"))):"percent"!==p&&"constant"!==p||(f("value"),d||f("valueminus"));var g="copy_"+l.inherit+"style";if(l.inherit)(e["error_"+l.inherit]||{}).visible&&f(g,!(h.color||n(h.thickness)||n(h.width)));l.inherit&&u[g]||(f("color",r),f("thickness"),f("width",a.traceIs(e,"gl3d")?0:4))}}},{"../../lib":717,"../../plot_api/plot_template":755,"../../registry":846,"./attributes":614,"fast-isnumeric":228}],618:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plot_api/edit_types").overrideAll,i=t("./attributes"),o={error_x:n.extendFlat({},i),error_y:n.extendFlat({},i)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},i),error_y:n.extendFlat({},i),error_z:n.extendFlat({},i)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:"component",name:"errorbars",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:a(s,"calc","nested"),scattergl:a(o,"calc","nested")}},supplyDefaults:t("./defaults"),calc:t("./calc"),makeComputeError:t("./compute_error"),plot:t("./plot"),style:t("./style"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{"../../lib":717,"../../plot_api/edit_types":748,"./attributes":614,"./calc":615,"./compute_error":616,"./defaults":617,"./plot":619,"./style":620}],619:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../drawing"),o=t("../../traces/scatter/subtypes");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each(function(e){var h,f=e[0].trace,p=f.error_x||{},d=f.error_y||{};f.ids&&(h=function(t){return t.id});var g=o.hasMarkers(f)&&f.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var v=n.select(this).selectAll("g.errorbar").data(e,h);if(v.exit().remove(),e.length){p.visible||v.selectAll("path.xerror").remove(),d.visible||v.selectAll("path.yerror").remove(),v.style("opacity",1);var m=v.enter().append("g").classed("errorbar",!0);u&&m.style("opacity",0).transition().duration(s.duration).style("opacity",1),i.setClipUrl(v,r.layerClipId,t),v.each(function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),a(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),a(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!g||t.vis){var i,o=e.select("path.yerror");if(d.visible&&a(r.x)&&a(r.yh)&&a(r.ys)){var h=d.width;i="M"+(r.x-h)+","+r.yh+"h"+2*h+"m-"+h+",0V"+r.ys,r.noYS||(i+="m-"+h+",0h"+2*h),!o.size()?o=e.append("path").style("vector-effect","non-scaling-stroke").classed("yerror",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr("d",i)}else o.remove();var f=e.select("path.xerror");if(p.visible&&a(r.y)&&a(r.xh)&&a(r.xs)){var v=(p.copy_ystyle?d:p).width;i="M"+r.xh+","+(r.y-v)+"v"+2*v+"m0,-"+v+"H"+r.xs,r.noXS||(i+="m0,-"+v+"v"+2*v),!f.size()?f=e.append("path").style("vector-effect","non-scaling-stroke").classed("xerror",!0):u&&(f=f.transition().duration(s.duration).ease(s.easing)),f.attr("d",i)}else f.remove()}})}})}},{"../../traces/scatter/subtypes":1144,"../drawing":612,d3:165,"fast-isnumeric":228}],620:[function(t,e,r){"use strict";var n=t("d3"),a=t("../color");e.exports=function(t){t.each(function(t){var e=t[0].trace,r=e.error_y||{},i=e.error_x||{},o=n.select(this);o.selectAll("path.yerror").style("stroke-width",r.thickness+"px").call(a.stroke,r.color),i.copy_ystyle&&(i=r),o.selectAll("path.xerror").style("stroke-width",i.thickness+"px").call(a.stroke,i.color)})}},{"../color":591,d3:165}],621:[function(t,e,r){"use strict";var n=t("../../plots/font_attributes"),a=t("./layout_attributes").hoverlabel,i=t("../../lib/extend").extendFlat;e.exports={hoverlabel:{bgcolor:i({},a.bgcolor,{arrayOk:!0}),bordercolor:i({},a.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:"none"}),align:i({},a.align,{arrayOk:!0}),namelength:i({},a.namelength,{arrayOk:!0}),editType:"none"}}},{"../../lib/extend":708,"../../plots/font_attributes":791,"./layout_attributes":631}],622:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../registry");function i(t,e,r,a){a=a||n.identity,Array.isArray(t)&&(e[0][r]=a(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!a.traceIs(c,"pie-like")){var u=a.traceIs(c,"2dMap")?i:n.fillArray;u(c.hoverinfo,l,"hi",o(c)),c.hovertemplate&&u(c.hovertemplate,l,"ht"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,"hbg"),u(c.hoverlabel.bordercolor,l,"hbc"),u(c.hoverlabel.font.size,l,"hts"),u(c.hoverlabel.font.color,l,"htc"),u(c.hoverlabel.font.family,l,"htf"),u(c.hoverlabel.namelength,l,"hnl"),u(c.hoverlabel.align,l,"hta"))}}}},{"../../lib":717,"../../registry":846}],623:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("./hover").hover;e.exports=function(t,e,r){var i=n.getComponentMethod("annotations","onClick")(t,t._hoverdata);function o(){t.emit("plotly_click",{points:t._hoverdata,event:e})}void 0!==r&&a(t,e,r,!0),t._hoverdata&&e&&e.target&&(i&&i.then?i.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{"../../registry":846,"./hover":627}],624:[function(t,e,r){"use strict";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:"Arial, sans-serif",HOVERMINTIME:50,HOVERID:"-hover"}},{}],625:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("./hoverlabel_defaults");e.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),i(t,e,function(r,i){return n.coerce(t,e,a,r,i)},s)}},{"../../lib":717,"./attributes":621,"./hoverlabel_defaults":628}],626:[function(t,e,r){"use strict";var n=t("../../lib");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if("splom"===t.type){for(var n=t.xaxes||[],a=t.yaxes||[],i=0;i<n.length;i++)for(var o=0;o<a.length;o++)if(-1!==e.indexOf(n[i]+a[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,a){return"closest"===t?a||r.quadrature(e,n):"x"===t.charAt(0)?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var a=e(t[n]);a<=r.distance&&(r.index=n,r.distance=a)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),a=e(r);return Math.sqrt(n*n+a*a)}},r.makeEventData=function(t,e,n){var a="index"in t?t.index:t.pointNumber,i={data:e._input,fullData:e,curveNumber:e.index,pointNumber:a};if(e._indexToPoints){var o=e._indexToPoints[a];1===o.length?i.pointIndex=o[0]:i.pointIndices=o}else i.pointIndex=a;return e._module.eventData?i=e._module.eventData(i,t,e,n,a):("xVal"in t?i.x=t.xVal:"x"in t&&(i.x=t.x),"yVal"in t?i.y=t.yVal:"y"in t&&(i.y=t.y),t.xa&&(i.xaxis=t.xa),t.ya&&(i.yaxis=t.ya),void 0!==t.zLabelVal&&(i.z=t.zLabelVal)),r.appendArrayPointValue(i,e,a),i},r.appendArrayPointValue=function(t,e,r){var a=e._arrayAttrs;if(a)for(var s=0;s<a.length;s++){var l=a[s],c=i(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var a=e._arrayAttrs;if(a)for(var s=0;s<a.length;s++){var l=a[s],c=i(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),h=new Array(r.length),f=0;f<r.length;f++)h[f]=o(u,r[f]);t[c]=h}}};var a={ids:"id",locations:"location",labels:"label",values:"value","marker.colors":"color",parents:"parent"};function i(t){return a[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}var s={x:!0,y:!0},l={"x unified":!0,"y unified":!0};r.isUnifiedHover=function(t){return"string"==typeof t&&!!l[t]},r.isXYhover=function(t){return"string"==typeof t&&!!s[t]}},{"../../lib":717}],627:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("tinycolor2"),o=t("../../lib"),s=t("../../lib/events"),l=t("../../lib/svg_text_utils"),c=t("../../lib/override_cursor"),u=t("../drawing"),h=t("../color"),f=t("../dragelement"),p=t("../../plots/cartesian/axes"),d=t("../../registry"),g=t("./helpers"),v=t("./constants"),m=t("../legend/defaults"),y=t("../legend/draw"),x=v.YANGLE,b=Math.PI*x/180,_=1/Math.sin(b),w=Math.cos(b),k=Math.sin(b),T=v.HOVERARROWSIZE,M=v.HOVERTEXTPAD;function A(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||""].join(",")}r.hover=function(t,e,r,i){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+v.HOVERID,v.HOVERMINTIME,function(){!function(t,e,r,i){r||(r="xy");var l=Array.isArray(r)?r:[r],u=t._fullLayout,p=u._plots||[],v=p[r],m=u._has("cartesian");if(v){var y=v.overlays.map(function(t){return t.id});l=l.concat(y)}for(var x=l.length,b=new Array(x),w=new Array(x),k=!1,T=0;T<x;T++){var M=l[T];if(p[M])k=!0,b[T]=p[M].xaxis,w[T]=p[M].yaxis;else{if(!u[M]||!u[M]._subplot)return void o.warn("Unrecognized subplot: "+M);var S=u[M]._subplot;b[T]=S.xaxis,w[T]=S.yaxis}}var L=e.hovermode||u.hovermode;L&&!k&&(L="closest");if(-1===["x","y","closest","x unified","y unified"].indexOf(L)||!t.calcdata||t.querySelector(".zoombox")||t._dragging)return f.unhoverRaw(t,e);var I,D,R,F,B,N,j,V,U,q,H,G,Y,W=-1===u.hoverdistance?1/0:u.hoverdistance,X=-1===u.spikedistance?1/0:u.spikedistance,Z=[],J=[],K={hLinePoint:null,vLinePoint:null},Q=!1;if(Array.isArray(e))for(L="array",R=0;R<e.length;R++)(B=t.calcdata[e[R].curveNumber||0])&&(N=B[0].trace,"skip"!==B[0].trace.hoverinfo&&(J.push(B),"h"===N.orientation&&(Q=!0)));else{for(F=0;F<t.calcdata.length;F++)B=t.calcdata[F],"skip"!==(N=B[0].trace).hoverinfo&&g.isTraceInSubplots(N,l)&&(J.push(B),"h"===N.orientation&&(Q=!0));var $,tt,et=!e.target;if(et)$="xpx"in e?e.xpx:b[0]._length/2,tt="ypx"in e?e.ypx:w[0]._length/2;else{if(!1===s.triggerHandler(t,"plotly_beforehover",e))return;var rt=e.target.getBoundingClientRect();if($=e.clientX-rt.left,tt=e.clientY-rt.top,$<0||$>b[0]._length||tt<0||tt>w[0]._length)return f.unhoverRaw(t,e)}if(e.pointerX=$+b[0]._offset,e.pointerY=tt+w[0]._offset,I="xval"in e?g.flat(l,e.xval):g.p2c(b,$),D="yval"in e?g.flat(l,e.yval):g.p2c(w,tt),!a(I[0])||!a(D[0]))return o.warn("Fx.hover failed",e,t),f.unhoverRaw(t,e)}var nt=1/0;function at(t,r){for(F=0;F<J.length;F++)if((B=J[F])&&B[0]&&B[0].trace&&!0===(N=B[0].trace).visible&&0!==N._length&&-1===["carpet","contourcarpet"].indexOf(N._module.name)){if("splom"===N.type?j=l[V=0]:(j=g.getSubplot(N),V=l.indexOf(j)),U=L,g.isUnifiedHover(U)&&(U=U.charAt(0)),G={cd:B,trace:N,xa:b[V],ya:w[V],maxHoverDistance:W,maxSpikeDistance:X,index:!1,distance:Math.min(nt,W),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:h.defaultLine,name:N.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},u[j]&&(G.subplot=u[j]._subplot),u._splomScenes&&u._splomScenes[N.uid]&&(G.scene=u._splomScenes[N.uid]),Y=Z.length,"array"===U){var n=e[F];"pointNumber"in n?(G.index=n.pointNumber,U="closest"):(U="","xval"in n&&(q=n.xval,U="x"),"yval"in n&&(H=n.yval,U=U?"closest":"y"))}else void 0!==t&&void 0!==r?(q=t,H=r):(q=I[V],H=D[V]);if(0!==W)if(N._module&&N._module.hoverPoints){var i=N._module.hoverPoints(G,q,H,U,u._hoverlayer);if(i)for(var s,c=0;c<i.length;c++)s=i[c],a(s.x0)&&a(s.y0)&&Z.push(P(s,L))}else o.log("Unrecognized trace type in hover:",N);if("closest"===L&&Z.length>Y&&(Z.splice(0,Y),nt=Z[0].distance),m&&0!==X&&0===Z.length){G.distance=X,G.index=!1;var f=N._module.hoverPoints(G,q,H,"closest",u._hoverlayer);if(f&&(f=f.filter(function(t){return t.spikeDistance<=X})),f&&f.length){var p,d=f.filter(function(t){return t.xa.showspikes&&"hovered data"!==t.xa.spikesnap});if(d.length){var v=d[0];a(v.x0)&&a(v.y0)&&(p=ot(v),(!K.vLinePoint||K.vLinePoint.spikeDistance>p.spikeDistance)&&(K.vLinePoint=p))}var y=f.filter(function(t){return t.ya.showspikes&&"hovered data"!==t.ya.spikesnap});if(y.length){var x=y[0];a(x.x0)&&a(x.y0)&&(p=ot(x),(!K.hLinePoint||K.hLinePoint.spikeDistance>p.spikeDistance)&&(K.hLinePoint=p))}}}}}function it(t,e){for(var r,n=null,a=1/0,i=0;i<t.length;i++)(r=t[i].spikeDistance)<=a&&r<=e&&(n=t[i],a=r);return n}function ot(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}at();var st={fullLayout:u,container:u._hoverlayer,outerContainer:u._paperdiv,event:e},lt=t._spikepoints,ct={vLinePoint:K.vLinePoint,hLinePoint:K.hLinePoint};if(t._spikepoints=ct,m&&0!==X&&0!==Z.length){var ut=Z.filter(function(t){return t.ya.showspikes}),ht=it(ut,X);K.hLinePoint=ot(ht);var ft=Z.filter(function(t){return t.xa.showspikes}),pt=it(ft,X);K.vLinePoint=ot(pt)}if(0===Z.length){var dt=f.unhoverRaw(t,e);return!m||null===K.hLinePoint&&null===K.vLinePoint||z(lt)&&O(t,K,st),dt}m&&z(lt)&&O(t,K,st);if(Z.sort(function(t,e){return t.distance-e.distance}),g.isXYhover(U)&&0!==Z[0].length&&"splom"!==Z[0].trace.type){var gt=Z[0],vt=gt.cd[gt.index],mt="group"===u.boxmode||"group"===u.violinmode,yt=gt.xVal,xt=gt.xa;"category"===xt.type&&(yt=xt._categoriesMap[yt]),"date"===xt.type&&(yt=xt.d2c(yt)),vt&&vt.t&&vt.t.posLetter===xt._id&&mt&&(yt+=vt.t.dPos);var bt=gt.yVal;"category"===(xt=gt.ya).type&&(bt=xt._categoriesMap[bt]),"date"===xt.type&&(bt=xt.d2c(bt)),vt&&vt.t&&vt.t.posLetter===xt._id&&mt&&(bt+=vt.t.dPos),at(yt,bt);var _t={};Z=Z.filter(function(t){var e=A(t);if(!_t[e])return _t[e]=!0,_t[e]})}var wt=t._hoverdata,kt=[];for(R=0;R<Z.length;R++){var Tt=Z[R],Mt=g.makeEventData(Tt,Tt.trace,Tt.cd);if(!1!==Tt.hovertemplate){var At=!1;Tt.cd[Tt.index]&&Tt.cd[Tt.index].ht&&(At=Tt.cd[Tt.index].ht),Tt.hovertemplate=At||Tt.trace.hovertemplate||!1}Tt.eventData=[Mt],kt.push(Mt)}t._hoverdata=kt;var St="y"===L&&(J.length>1||Z.length>1)||"closest"===L&&Q&&Z.length>1,Et=h.combine(u.plot_bgcolor||h.background,u.paper_bgcolor),Lt={hovermode:L,rotateLabels:St,bgColor:Et,container:u._hoverlayer,outerContainer:u._paperdiv,commonLabelOpts:u.hoverlabel,hoverdistance:u.hoverdistance},Ct=E(Z,Lt,t);g.isUnifiedHover(L)||(!function(t,e,r){var n,a,i,o,s,l,c,u=0,h=1,f=t.size(),p=new Array(f),d=0;function g(t){var e=t[0],r=t[t.length-1];if(a=e.pmin-e.pos-e.dp+e.size,i=r.pos+r.dp+r.size-e.pmax,a>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=a;n=!1}if(!(i<.01)){if(a<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=i;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,i=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=i;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}t.each(function(t){var n=t[e],a="x"===n._id.charAt(0),i=n.range;0===d&&i&&i[0]>i[1]!==a&&(h=-1),p[d++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(a?_:1)/2,pmin:0,pmax:a?r.width:r.height}]}),p.sort(function(t,e){return t[0].posref-e[0].posref||h*(e[0].traceIndex-t[0].traceIndex)});for(;!n&&u<=f;){for(u++,n=!0,o=0;o<p.length-1;){var v=p[o],m=p[o+1],y=v[v.length-1],x=m[0];if((a=y.pos+y.dp+y.size-x.pos-x.dp+x.size)>.01&&y.pmin===x.pmin&&y.pmax===x.pmax){for(s=m.length-1;s>=0;s--)m[s].dp+=a;for(v.push.apply(v,m),p.splice(o+1,1),c=0,s=v.length-1;s>=0;s--)c+=v[s].dp;for(i=c/v.length,s=v.length-1;s>=0;s--)v[s].dp-=i;n=!1}else o++}p.forEach(g)}for(o=p.length-1;o>=0;o--){var b=p[o];for(s=b.length-1;s>=0;s--){var w=b[s],k=w.datum;k.offset=w.dp,k.del=w.del}}}(Ct,St?"xa":"ya",u),C(Ct,St));if(e.target&&e.target.tagName){var Pt=d.getComponentMethod("annotations","hasClickToShow")(t,kt);c(n.select(e.target),Pt?"pointer":"")}if(!e.target||i||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var a=r[n],i=t._hoverdata[n];if(a.curveNumber!==i.curveNumber||String(a.pointNumber)!==String(i.pointNumber)||String(a.pointNumbers)!==String(i.pointNumbers))return!0}return!1}(t,0,wt))return;wt&&t.emit("plotly_unhover",{event:e,points:wt});t.emit("plotly_hover",{event:e,points:t._hoverdata,xaxes:b,yaxes:w,xvals:I,yvals:D})}(t,e,r,i)})},r.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var a=t.map(function(t){return{color:t.color||h.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:""},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}}),i=n.select(e.container),o=e.outerContainer?n.select(e.outerContainer):i,s={hovermode:"closest",rotateLabels:!1,bgColor:e.bgColor||h.background,container:i,outerContainer:o},l=E(a,s,e.gd),c=0,u=0;return l.sort(function(t,e){return t.y0-e.y0}).each(function(t,r){var n=t.y0-t.by/2;t.offset=n-5<c?c-n+5:0,c=n+t.by+t.offset,r===e.anchorIndex&&(u=t.offset)}).each(function(t){t.offset-=u}),C(l,s.rotateLabels),r?l:l.node()};var S=/<extra>([\s\S]*)<\/extra>/;function E(t,e,r){var a=r._fullLayout,i=e.hovermode,s=e.rotateLabels,c=e.bgColor,f=e.container,p=e.outerContainer,d=e.commonLabelOpts||{},b=e.fontFamily||v.HOVERFONT,_=e.fontSize||v.HOVERFONTSIZE,w=t[0],k=w.xa,S=w.ya,E="y"===i.charAt(0)?"yLabel":"xLabel",C=w[E],P=(String(C)||"").split(" ")[0],O=p.node().getBoundingClientRect(),z=O.top,I=O.width,D=O.height,R=void 0!==C&&w.distance<=e.hoverdistance&&("x"===i||"y"===i);if(R){var F,B,N=!0;for(F=0;F<t.length;F++)if(N&&void 0===t[F].zLabel&&(N=!1),B=t[F].hoverinfo||t[F].trace.hoverinfo){var j=Array.isArray(B)?B:B.split("+");if(-1===j.indexOf("all")&&-1===j.indexOf(i)){R=!1;break}}N&&(R=!1)}var V=f.selectAll("g.axistext").data(R?[0]:[]);function U(t){return t.filter(function(t){return void 0!==t.zLabelVal||(t[E]||"").split(" ")[0]===P})}if(V.enter().append("g").classed("axistext",!0),V.exit().remove(),V.each(function(){var e=n.select(this),s=o.ensureSingle(e,"path","",function(t){t.style({"stroke-width":"1px"})}),c=o.ensureSingle(e,"text","",function(t){t.attr("data-notex",1)}),f=d.bgcolor||h.defaultLine,p=d.bordercolor||h.contrast(f),g=h.contrast(f),v={family:d.font.family||b,size:d.font.size||_,color:d.font.color||g};s.style({fill:f,stroke:p}),c.text(C).call(u.font,v).call(l.positionText,0,0).call(l.convertToTspans,r),e.attr("transform","");var m,y,x=c.node().getBoundingClientRect();if("x"===i){var A="top"===k.side?"-":"";c.attr("text-anchor","middle").call(l.positionText,0,"top"===k.side?z-x.bottom-T-M:z-x.top+T+M),m=k._offset+(w.x0+w.x1)/2,y=S._offset+("top"===k.side?0:S._length);var E=x.width/2+M;m<E?(m=E,s.attr("d","M-"+(E-T)+",0L-"+(E-2*T)+","+A+T+"H"+(M+x.width/2)+"v"+A+(2*M+x.height)+"H-"+E+"V"+A+T+"Z")):m>a.width-E?(m=a.width-E,s.attr("d","M"+(E-T)+",0L"+E+","+A+T+"v"+A+(2*M+x.height)+"H-"+E+"V"+A+T+"H"+(E-2*T)+"Z")):s.attr("d","M0,0L"+T+","+A+T+"H"+(M+x.width/2)+"v"+A+(2*M+x.height)+"H-"+(M+x.width/2)+"V"+A+T+"H-"+T+"Z")}else{var L,P,O;"right"===S.side?(L="start",P=1,O="",m=k._offset+k._length):(L="end",P=-1,O="-",m=k._offset),y=S._offset+(w.y0+w.y1)/2,c.attr("text-anchor",L),s.attr("d","M0,0L"+O+T+","+T+"V"+(M+x.height/2)+"h"+O+(2*M+x.width)+"V-"+(M+x.height/2)+"H"+O+T+"V-"+T+"Z");var I,D=x.height/2,R=z-x.top-D,F="clip"+a._uid+"commonlabel"+S._id;if(m<x.width+2*M+T){I="M-"+(T+M)+"-"+D+"h-"+(x.width-M)+"V"+D+"h"+(x.width-M)+"Z";var B=x.width-m+M;l.positionText(c,B,R),"end"===L&&c.selectAll("tspan").each(function(){var t=n.select(this),e=u.tester.append("text").text(t.text()).call(u.font,v),r=e.node().getBoundingClientRect();Math.round(r.width)<Math.round(x.width)&&t.attr("x",B-r.width),e.remove()})}else l.positionText(c,P*(M+T),R),I=null;var N=a._topclips.selectAll("#"+F).data(I?[0]:[]);N.enter().append("clipPath").attr("id",F).append("path"),N.exit().remove(),N.select("path").attr("d",I),u.setClipUrl(c,I?F:null,r)}e.attr("transform","translate("+m+","+y+")"),t=U(t)}),g.isUnifiedHover(i)){if(f.selectAll("g.hovertext").remove(),void 0!==C&&w.distance<=e.hoverdistance&&(t=U(t)),0===t.length)return;var q={showlegend:!0,legend:{title:{text:C,font:a.hoverlabel.font},font:a.hoverlabel.font,bgcolor:a.hoverlabel.bgcolor,bordercolor:a.hoverlabel.bordercolor,borderwidth:1,tracegroupgap:7,traceorder:a.legend?a.legend.traceorder:void 0,orientation:"v"}},H={};m(q,H,r._fullData);var G=H.legend;G.entries=[];for(var Y=0;Y<t.length;Y++){var W=L(t[Y],!0,i,a,C),X=W[0],Z=W[1],J=t[Y];J.name=Z,J.text=""!==Z?Z+" : "+X:X;var K=J.cd[J.index];K&&(K.mc&&(J.mc=K.mc),K.mcc&&(J.mc=K.mcc),K.mlc&&(J.mlc=K.mlc),K.mlcc&&(J.mlc=K.mlcc),K.mlw&&(J.mlw=K.mlw),K.mrc&&(J.mrc=K.mrc),K.dir&&(J.dir=K.dir)),J._distinct=!0,G.entries.push([J])}G.entries.sort(function(t,e){return t[0].trace.index-e[0].trace.index}),G.layer=f,y(r,G);var Q=o.mean(t.map(function(t){return(t.y0+t.y1)/2})),$=o.mean(t.map(function(t){return(t.x0+t.x1)/2})),tt=f.select("g.legend"),et=tt.node().getBoundingClientRect();$+=k._offset,Q+=S._offset-et.height/2;var rt=et.width+2*M;!($+rt<=I)&&$-rt>=0?$-=rt:$+=2*M;var nt=et.height+2*M,at=Q+nt>=D;return nt<=D&&(Q<=z?Q=S._offset+2*M:at&&(Q=D-nt)),tt.attr("transform","translate("+$+","+Q+")"),tt}var it=f.selectAll("g.hovertext").data(t,function(t){return A(t)});return it.enter().append("g").classed("hovertext",!0).each(function(){var t=n.select(this);t.append("rect").call(h.fill,h.addOpacity(c,.8)),t.append("text").classed("name",!0),t.append("path").style("stroke-width","1px"),t.append("text").classed("nums",!0).call(u.font,b,_)}),it.exit().remove(),it.each(function(t){var e=n.select(this).attr("transform",""),o=t.bgcolor||t.color,f=h.combine(h.opacity(o)?o:h.defaultLine,c),p=h.combine(h.opacity(t.color)?t.color:h.defaultLine,c),d=t.borderColor||h.contrast(f),g=L(t,R,i,a,C,e),v=g[0],m=g[1],y=e.select("text.nums").call(u.font,t.fontFamily||b,t.fontSize||_,t.fontColor||d).text(v).attr("data-notex",1).call(l.positionText,0,0).call(l.convertToTspans,r),w=e.select("text.name"),k=0,A=0;if(m&&m!==v){w.call(u.font,t.fontFamily||b,t.fontSize||_,p).text(m).attr("data-notex",1).call(l.positionText,0,0).call(l.convertToTspans,r);var S=w.node().getBoundingClientRect();k=S.width+2*M,A=S.height+2*M}else w.remove(),e.select("rect").remove();e.select("path").style({fill:f,stroke:d});var E,P,O=y.node().getBoundingClientRect(),F=t.xa._offset+(t.x0+t.x1)/2,B=t.ya._offset+(t.y0+t.y1)/2,N=Math.abs(t.x1-t.x0),j=Math.abs(t.y1-t.y0),V=O.width+T+M+k;if(t.ty0=z-O.top,t.bx=O.width+2*M,t.by=Math.max(O.height+2*M,A),t.anchor="start",t.txwidth=O.width,t.tx2width=k,t.offset=0,s)t.pos=F,E=B+j/2+V<=D,P=B-j/2-V>=0,"top"!==t.idealAlign&&E||!P?E?(B+=j/2,t.anchor="start"):t.anchor="middle":(B-=j/2,t.anchor="end");else if(t.pos=B,E=F+N/2+V<=I,P=F-N/2-V>=0,"left"!==t.idealAlign&&E||!P)if(E)F+=N/2,t.anchor="start";else{t.anchor="middle";var U=V/2,q=F+U-I,H=F-U;q>0&&(F-=q),H<0&&(F+=-H)}else F-=N/2,t.anchor="end";y.attr("text-anchor",t.anchor),k&&w.attr("text-anchor",t.anchor),e.attr("transform","translate("+F+","+B+")"+(s?"rotate("+x+")":""))}),it}function L(t,e,r,n,a,i){var s="",l="";void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),s=I(t.name,t.nameLength)),void 0!==t.zLabel?(void 0!==t.xLabel&&(l+="x: "+t.xLabel+"<br>"),void 0!==t.yLabel&&(l+="y: "+t.yLabel+"<br>"),"choropleth"!==t.trace.type&&"choroplethmapbox"!==t.trace.type&&(l+=(l?"z: ":"")+t.zLabel)):e&&t[r.charAt(0)+"Label"]===a?l=t[("x"===r.charAt(0)?"y":"x")+"Label"]||"":void 0===t.xLabel?void 0!==t.yLabel&&"scattercarpet"!==t.trace.type&&(l=t.yLabel):l=void 0===t.yLabel?t.xLabel:"("+t.xLabel+", "+t.yLabel+")",!t.text&&0!==t.text||Array.isArray(t.text)||(l+=(l?"<br>":"")+t.text),void 0!==t.extraText&&(l+=(l?"<br>":"")+t.extraText),i&&""===l&&!t.hovertemplate&&(""===s&&i.remove(),l=s);var c=n._d3locale,u=t.hovertemplate||!1,h=t.hovertemplateLabels||t,f=t.eventData[0]||{};return u&&(l=(l=o.hovertemplateString(u,h,c,f,t.trace._meta)).replace(S,function(e,r){return s=I(r,t.nameLength),""})),[l,s]}function C(t,e){t.each(function(t){var r=n.select(this);if(t.del)return r.remove();var a=r.select("text.nums"),i=t.anchor,o="end"===i?-1:1,s={start:1,end:-1,middle:0}[i],c=s*(T+M),h=c+s*(t.txwidth+M),f=0,p=t.offset;"middle"===i&&(c-=t.tx2width/2,h+=t.txwidth/2+M),e&&(p*=-k,f=t.offset*w),r.select("path").attr("d","middle"===i?"M-"+(t.bx/2+t.tx2width/2)+","+(p-t.by/2)+"h"+t.bx+"v"+t.by+"h-"+t.bx+"Z":"M0,0L"+(o*T+f)+","+(T+p)+"v"+(t.by/2-T)+"h"+o*t.bx+"v-"+t.by+"H"+(o*T+f)+"V"+(p-T)+"Z");var d=c+f,g=p+t.ty0-t.by/2+M,v=t.textAlign||"auto";"auto"!==v&&("left"===v&&"start"!==i?(a.attr("text-anchor","start"),d="middle"===i?-t.bx/2-t.tx2width/2+M:-t.bx-M):"right"===v&&"end"!==i&&(a.attr("text-anchor","end"),d="middle"===i?t.bx/2-t.tx2width/2-M:t.bx+M)),a.call(l.positionText,d,g),t.tx2width&&(r.select("text.name").call(l.positionText,h+s*M+f,p+t.ty0-t.by/2+M),r.select("rect").call(u.setRect,h+(s-1)*t.tx2width/2+f,p-t.by/2-1,t.tx2width,t.by+2))})}function P(t,e){var r=t.index,n=t.trace||{},i=t.cd[0],s=t.cd[r]||{};function l(t){return t||a(t)&&0===t}var c=Array.isArray(r)?function(t,e){var a=o.castOption(i,r,t);return l(a)?a:o.extractOption({},n,"",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var a=c(r,n);l(a)&&(t[e]=a)}if(u("hoverinfo","hi","hoverinfo"),u("bgcolor","hbg","hoverlabel.bgcolor"),u("borderColor","hbc","hoverlabel.bordercolor"),u("fontFamily","htf","hoverlabel.font.family"),u("fontSize","hts","hoverlabel.font.size"),u("fontColor","htc","hoverlabel.font.color"),u("nameLength","hnl","hoverlabel.namelength"),u("textAlign","hta","hoverlabel.align"),t.posref="y"===e||"closest"===e&&"h"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel="xLabel"in t?t.xLabel:p.hoverLabelText(t.xa,t.xLabelVal),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel="yLabel"in t?t.yLabel:p.hoverLabelText(t.ya,t.yLabelVal),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||"log"===t.xa.type&&t.xerr<=0)){var h=p.tickText(t.xa,t.xa.c2l(t.xerr),"hover").text;void 0!==t.xerrneg?t.xLabel+=" +"+h+" / -"+p.tickText(t.xa,t.xa.c2l(t.xerrneg),"hover").text:t.xLabel+=" \xb1 "+h,"x"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||"log"===t.ya.type&&t.yerr<=0)){var f=p.tickText(t.ya,t.ya.c2l(t.yerr),"hover").text;void 0!==t.yerrneg?t.yLabel+=" +"+f+" / -"+p.tickText(t.ya,t.ya.c2l(t.yerrneg),"hover").text:t.yLabel+=" \xb1 "+f,"y"===e&&(t.distance+=1)}var d=t.hoverinfo||t.trace.hoverinfo;return d&&"all"!==d&&(-1===(d=Array.isArray(d)?d:d.split("+")).indexOf("x")&&(t.xLabel=void 0),-1===d.indexOf("y")&&(t.yLabel=void 0),-1===d.indexOf("z")&&(t.zLabel=void 0),-1===d.indexOf("text")&&(t.text=void 0),-1===d.indexOf("name")&&(t.name=void 0)),t}function O(t,e,r){var n,a,o=r.container,s=r.fullLayout,l=s._size,c=r.event,f=!!e.hLinePoint,d=!!e.vLinePoint;if(o.selectAll(".spikeline").remove(),d||f){var g=h.combine(s.plot_bgcolor,s.paper_bgcolor);if(f){var v,m,y=e.hLinePoint;n=y&&y.xa,"cursor"===(a=y&&y.ya).spikesnap?(v=c.pointerX,m=c.pointerY):(v=n._offset+y.x,m=a._offset+y.y);var x,b,_=i.readability(y.color,g)<1.5?h.contrast(g):y.color,w=a.spikemode,k=a.spikethickness,T=a.spikecolor||_,M=p.getPxPosition(t,a);if(-1!==w.indexOf("toaxis")||-1!==w.indexOf("across")){if(-1!==w.indexOf("toaxis")&&(x=M,b=v),-1!==w.indexOf("across")){var A=a._counterDomainMin,S=a._counterDomainMax;"free"===a.anchor&&(A=Math.min(A,a.position),S=Math.max(S,a.position)),x=l.l+A*l.w,b=l.l+S*l.w}o.insert("line",":first-child").attr({x1:x,x2:b,y1:m,y2:m,"stroke-width":k,stroke:T,"stroke-dasharray":u.dashStyle(a.spikedash,k)}).classed("spikeline",!0).classed("crisp",!0),o.insert("line",":first-child").attr({x1:x,x2:b,y1:m,y2:m,"stroke-width":k+2,stroke:g}).classed("spikeline",!0).classed("crisp",!0)}-1!==w.indexOf("marker")&&o.insert("circle",":first-child").attr({cx:M+("right"!==a.side?k:-k),cy:m,r:k,fill:T}).classed("spikeline",!0)}if(d){var E,L,C=e.vLinePoint;n=C&&C.xa,a=C&&C.ya,"cursor"===n.spikesnap?(E=c.pointerX,L=c.pointerY):(E=n._offset+C.x,L=a._offset+C.y);var P,O,z=i.readability(C.color,g)<1.5?h.contrast(g):C.color,I=n.spikemode,D=n.spikethickness,R=n.spikecolor||z,F=p.getPxPosition(t,n);if(-1!==I.indexOf("toaxis")||-1!==I.indexOf("across")){if(-1!==I.indexOf("toaxis")&&(P=F,O=L),-1!==I.indexOf("across")){var B=n._counterDomainMin,N=n._counterDomainMax;"free"===n.anchor&&(B=Math.min(B,n.position),N=Math.max(N,n.position)),P=l.t+(1-N)*l.h,O=l.t+(1-B)*l.h}o.insert("line",":first-child").attr({x1:E,x2:E,y1:P,y2:O,"stroke-width":D,stroke:R,"stroke-dasharray":u.dashStyle(n.spikedash,D)}).classed("spikeline",!0).classed("crisp",!0),o.insert("line",":first-child").attr({x1:E,x2:E,y1:P,y2:O,"stroke-width":D+2,stroke:g}).classed("spikeline",!0).classed("crisp",!0)}-1!==I.indexOf("marker")&&o.insert("circle",":first-child").attr({cx:E,cy:F-("top"!==n.side?D:-D),r:D,fill:R}).classed("spikeline",!0)}}}function z(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}function I(t,e){return l.plainText(t||"",{len:e,allowedTags:["br","sub","sup","b","i","em"]})}},{"../../lib":717,"../../lib/events":707,"../../lib/override_cursor":728,"../../lib/svg_text_utils":741,"../../plots/cartesian/axes":765,"../../registry":846,"../color":591,"../dragelement":609,"../drawing":612,"../legend/defaults":642,"../legend/draw":643,"./constants":624,"./helpers":626,d3:165,"fast-isnumeric":228,tinycolor2:535}],628:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../color"),i=t("./helpers").isUnifiedHover;e.exports=function(t,e,r,o){function s(t){o.font[t]||(o.font[t]=e.legend?e.legend.font[t]:e.font[t])}o=o||{},e&&i(e.hovermode)&&(o.font||(o.font={}),s("size"),s("family"),s("color"),e.legend?(o.bgcolor||(o.bgcolor=a.combine(e.legend.bgcolor,e.paper_bgcolor)),o.bordercolor||(o.bordercolor=e.legend.bordercolor)):o.bgcolor||(o.bgcolor=e.paper_bgcolor)),r("hoverlabel.bgcolor",o.bgcolor),r("hoverlabel.bordercolor",o.bordercolor),r("hoverlabel.namelength",o.namelength),n.coerceFont(r,"hoverlabel.font",o.font),r("hoverlabel.align",o.align)}},{"../../lib":717,"../color":591,"./helpers":626}],629:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e,r){function i(r,i){return void 0!==e[r]?e[r]:n.coerce(t,e,a,r,i)}var o,s=i("clickmode");return e._has("cartesian")?s.indexOf("select")>-1?o="closest":(e._isHoriz=function(t,e){for(var r=e._scatterStackOpts||{},n=0;n<t.length;n++){var a=t[n],i=a.xaxis+a.yaxis,o=r[i]||{},s=o[a.stackgroup]||{};if("h"!==a.orientation&&"h"!==s.orientation)return!1}return!0}(r,e),o=e._isHoriz?"y":"x"):o="closest",i("hovermode",o)}},{"../../lib":717,"./layout_attributes":631}],630:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../dragelement"),o=t("./helpers"),s=t("./layout_attributes"),l=t("./hover");e.exports={moduleType:"component",name:"fx",constants:t("./constants"),schema:{layout:s},attributes:t("./attributes"),layoutAttributes:s,supplyLayoutGlobalDefaults:t("./layout_global_defaults"),supplyDefaults:t("./defaults"),supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return a.castOption(t,e,"hoverlabel."+r)},castHoverinfo:function(t,e,r){return a.castOption(t,r,"hoverinfo",function(r){return a.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)})},hover:l.hover,unhover:i.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=a.isD3Selection(t)?t:n.select(t);e.selectAll("g.hovertext").remove(),e.selectAll(".spikeline").remove()},click:t("./click")}},{"../../lib":717,"../dragelement":609,"./attributes":621,"./calc":622,"./click":623,"./constants":624,"./defaults":625,"./helpers":626,"./hover":627,"./layout_attributes":631,"./layout_defaults":632,"./layout_global_defaults":633,d3:165}],631:[function(t,e,r){"use strict";var n=t("./constants"),a=t("../../plots/font_attributes")({editType:"none"});a.family.dflt=n.HOVERFONT,a.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:"flaglist",flags:["event","select"],dflt:"event",editType:"plot",extras:["none"]},dragmode:{valType:"enumerated",values:["zoom","pan","select","lasso","orbit","turntable",!1],dflt:"zoom",editType:"modebar"},hovermode:{valType:"enumerated",values:["x","y","closest",!1,"x unified","y unified"],editType:"modebar"},hoverdistance:{valType:"integer",min:-1,dflt:20,editType:"none"},spikedistance:{valType:"integer",min:-1,dflt:20,editType:"none"},hoverlabel:{bgcolor:{valType:"color",editType:"none"},bordercolor:{valType:"color",editType:"none"},font:a,align:{valType:"enumerated",values:["left","right","auto"],dflt:"auto",editType:"none"},namelength:{valType:"integer",min:-1,dflt:15,editType:"none"},editType:"none"},selectdirection:{valType:"enumerated",values:["h","v","d","any"],dflt:"any",editType:"none"}}},{"../../plots/font_attributes":791,"./constants":624}],632:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./helpers").isUnifiedHover,i=t("./layout_attributes"),o=t("./hovermode_defaults"),s=t("./hoverlabel_defaults");e.exports=function(t,e,r){function l(r,a){return n.coerce(t,e,i,r,a)}var c=o(t,e,r);c&&(l("hoverdistance"),l("spikedistance",a(c)?-1:void 0)),"select"===l("dragmode")&&l("selectdirection");var u=e._has("mapbox"),h=e._has("geo"),f=e._basePlotModules.length;"zoom"===e.dragmode&&((u||h)&&1===f||u&&h&&2===f)&&(e.dragmode="pan"),s(t,e,l)}},{"../../lib":717,"./helpers":626,"./hoverlabel_defaults":628,"./hovermode_defaults":629,"./layout_attributes":631}],633:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./hoverlabel_defaults"),i=t("./layout_attributes");e.exports=function(t,e){a(t,e,function(r,a){return n.coerce(t,e,i,r,a)})}},{"../../lib":717,"./hoverlabel_defaults":628,"./layout_attributes":631}],634:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../lib/regex").counter,i=t("../../plots/domain").attributes,o=t("../../plots/cartesian/constants").idRegex,s=t("../../plot_api/plot_template"),l={rows:{valType:"integer",min:1,editType:"plot"},roworder:{valType:"enumerated",values:["top to bottom","bottom to top"],dflt:"top to bottom",editType:"plot"},columns:{valType:"integer",min:1,editType:"plot"},subplots:{valType:"info_array",freeLength:!0,dimensions:2,items:{valType:"enumerated",values:[a("xy").toString(),""],editType:"plot"},editType:"plot"},xaxes:{valType:"info_array",freeLength:!0,items:{valType:"enumerated",values:[o.x.toString(),""],editType:"plot"},editType:"plot"},yaxes:{valType:"info_array",freeLength:!0,items:{valType:"enumerated",values:[o.y.toString(),""],editType:"plot"},editType:"plot"},pattern:{valType:"enumerated",values:["independent","coupled"],dflt:"coupled",editType:"plot"},xgap:{valType:"number",min:0,max:1,editType:"plot"},ygap:{valType:"number",min:0,max:1,editType:"plot"},domain:i({name:"grid",editType:"plot",noGridCell:!0},{}),xside:{valType:"enumerated",values:["bottom","bottom plot","top plot","top"],dflt:"bottom plot",editType:"plot"},yside:{valType:"enumerated",values:["left","left plot","right plot","right"],dflt:"left plot",editType:"plot"},editType:"plot"};function c(t,e,r){var n=e[r+"axes"],a=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:a.length?a:void 0}function u(t,e,r,n,a,i){var o=e(t+"gap",r),s=e("domain."+t);e(t+"side",n);for(var l=new Array(a),c=s[0],u=(s[1]-c)/(a-o),h=u*(1-o),f=0;f<a;f++){var p=c+u*f;l[i?a-1-f:f]=[p,p+h]}return l}function h(t,e,r,n,a){var i,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=""}if(Array.isArray(t))for(i=0;i<r;i++)s(i,t[i]);else for(s(0,a),i=1;i<r;i++)s(i,a+(i+1));return o}e.exports={moduleType:"component",name:"grid",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},a=c(e,r,"x"),i=c(e,r,"y");if(t.grid||a||i){var o,h,f=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(a),d=Array.isArray(i),g=p&&a!==r.xaxes&&d&&i!==r.yaxes;f?(o=r.subplots.length,h=r.subplots[0].length):(d&&(o=i.length),p&&(h=a.length));var v=s.newContainer(e,"grid"),m=T("rows",o),y=T("columns",h);if(m*y>1){f||p||d||"independent"===T("pattern")&&(f=!0),v._hasSubplotGrid=f;var x,b,_="top to bottom"===T("roworder"),w=f?.2:.1,k=f?.3:.1;g&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),v._domains={x:u("x",T,w,x,y),y:u("y",T,k,b,m,_)}}else delete e.grid}function T(t,e){return n.coerce(r,v,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,a,i,o,s,l,u,f=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,g=r.rows,v=r.columns,m="independent"===r.pattern,y=r._axisMap={};if(d){var x=f.subplots||[];l=r.subplots=new Array(g);var b=1;for(n=0;n<g;n++){var _=l[n]=new Array(v),w=x[n]||[];for(a=0;a<v;a++)if(m?(s=1===b?"xy":"x"+b+"y"+b,b++):s=w[a],_[a]="",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf("y"),i=s.slice(0,u),o=s.slice(u),void 0!==y[i]&&y[i]!==a||void 0!==y[o]&&y[o]!==n)continue;_[a]=s,y[i]=a,y[o]=n}}}else{var k=c(e,f,"x"),T=c(e,f,"y");r.xaxes=h(k,p.xaxis,v,y,"x"),r.yaxes=h(T,p.yaxis,g,y,"y")}var M=r._anchors={},A="top to bottom"===r.roworder;for(var S in y){var E,L,C,P=S.charAt(0),O=r[P+"side"];if(O.length<8)M[S]="free";else if("x"===P){if("t"===O.charAt(0)===A?(E=0,L=1,C=g):(E=g-1,L=-1,C=-1),d){var z=y[S];for(n=E;n!==C;n+=L)if((s=l[n][z])&&(u=s.indexOf("y"),s.slice(0,u)===S)){M[S]=s.slice(u);break}}else for(n=E;n!==C;n+=L)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){M[S]=o;break}}else if("l"===O.charAt(0)?(E=0,L=1,C=v):(E=v-1,L=-1,C=-1),d){var I=y[S];for(n=E;n!==C;n+=L)if((s=l[I][n])&&(u=s.indexOf("y"),s.slice(u)===S)){M[S]=s.slice(0,u);break}}else for(n=E;n!==C;n+=L)if(i=r.xaxes[n],-1!==p.cartesian.indexOf(i+S)){M[S]=i;break}}}}}},{"../../lib":717,"../../lib/regex":733,"../../plot_api/plot_template":755,"../../plots/cartesian/constants":771,"../../plots/domain":790}],635:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/constants"),a=t("../../plot_api/plot_template").templatedArray;e.exports=a("image",{visible:{valType:"boolean",dflt:!0,editType:"arraydraw"},source:{valType:"string",editType:"arraydraw"},layer:{valType:"enumerated",values:["below","above"],dflt:"above",editType:"arraydraw"},sizex:{valType:"number",dflt:0,editType:"arraydraw"},sizey:{valType:"number",dflt:0,editType:"arraydraw"},sizing:{valType:"enumerated",values:["fill","contain","stretch"],dflt:"contain",editType:"arraydraw"},opacity:{valType:"number",min:0,max:1,dflt:1,editType:"arraydraw"},x:{valType:"any",dflt:0,editType:"arraydraw"},y:{valType:"any",dflt:0,editType:"arraydraw"},xanchor:{valType:"enumerated",values:["left","center","right"],dflt:"left",editType:"arraydraw"},yanchor:{valType:"enumerated",values:["top","middle","bottom"],dflt:"top",editType:"arraydraw"},xref:{valType:"enumerated",values:["paper",n.idRegex.x.toString()],dflt:"paper",editType:"arraydraw"},yref:{valType:"enumerated",values:["paper",n.idRegex.y.toString()],dflt:"paper",editType:"arraydraw"},editType:"arraydraw"})},{"../../plot_api/plot_template":755,"../../plots/cartesian/constants":771}],636:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib/to_log_range");e.exports=function(t,e,r,i){e=e||{};var o="log"===r&&"linear"===e.type,s="linear"===r&&"log"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,h=e._id.charAt(0),f=0;f<u.length;f++)if(c="images["+f+"].",(l=u[f])[h+"ref"]===e._id){var p=l[h],d=l["size"+h],g=null,v=null;if(o){g=a(p,e.range);var m=d/Math.pow(10,g)/2;v=2*Math.log(m+Math.sqrt(1+m*m))/Math.LN10}else v=(g=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(g)?n(v)||(v=null):(g=null,v=null),i(c+h,g),i(c+"size"+h,v)}}},{"../../lib/to_log_range":743,"fast-isnumeric":228}],637:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../../plots/array_container_defaults"),o=t("./attributes");function s(t,e,r){function i(r,a){return n.coerce(t,e,o,r,a)}var s=i("source");if(!i("visible",!!s))return e;i("layer"),i("xanchor"),i("yanchor"),i("sizex"),i("sizey"),i("sizing"),i("opacity");for(var l={_fullLayout:r},c=["x","y"],u=0;u<2;u++){var h=c[u],f=a.coerceRef(t,e,l,h,"paper");if("paper"!==f)a.getFromId(l,f)._imgIndices.push(e._index);a.coercePosition(e,l,i,f,h,0)}return e}e.exports=function(t,e){i(t,e,{name:"images",handleItemDefaults:s})}},{"../../lib":717,"../../plots/array_container_defaults":761,"../../plots/cartesian/axes":765,"./attributes":635}],638:[function(t,e,r){"use strict";var n=t("d3"),a=t("../drawing"),i=t("../../plots/cartesian/axes"),o=t("../../constants/xmlns_namespaces");e.exports=function(t){var e,r,s=t._fullLayout,l=[],c={},u=[];for(r=0;r<s.images.length;r++){var h=s.images[r];if(h.visible)if("below"===h.layer&&"paper"!==h.xref&&"paper"!==h.yref){e=h.xref+h.yref;var f=s._plots[e];if(!f){u.push(h);continue}f.mainplot&&(e=f.mainplot.id),c[e]||(c[e]=[]),c[e].push(h)}else"above"===h.layer?l.push(h):u.push(h)}var p={x:{left:{sizing:"xMin",offset:0},center:{sizing:"xMid",offset:-.5},right:{sizing:"xMax",offset:-1}},y:{top:{sizing:"YMin",offset:0},middle:{sizing:"YMid",offset:-.5},bottom:{sizing:"YMax",offset:-1}}};function d(e){var r=n.select(this);if(this._imgSrc!==e.source)if(r.attr("xmlns",o.svg),e.source&&"data:"===e.source.slice(0,5))r.attr("xlink:href",e.source),this._imgSrc=e.source;else{var a=new Promise(function(t){var n=new Image;function a(){r.remove(),t()}this.img=n,n.setAttribute("crossOrigin","anonymous"),n.onerror=a,n.onload=function(){var e=document.createElement("canvas");e.width=this.width,e.height=this.height,e.getContext("2d").drawImage(this,0,0);var n=e.toDataURL("image/png");r.attr("xlink:href",n),t()},r.on("error",a),n.src=e.source,this._imgSrc=e.source}.bind(this));t._promises.push(a)}}function g(e){var r=n.select(this),o=i.getFromId(t,e.xref),l=i.getFromId(t,e.yref),c=s._size,u=o?Math.abs(o.l2p(e.sizex)-o.l2p(0)):e.sizex*c.w,h=l?Math.abs(l.l2p(e.sizey)-l.l2p(0)):e.sizey*c.h,f=u*p.x[e.xanchor].offset,d=h*p.y[e.yanchor].offset,g=p.x[e.xanchor].sizing+p.y[e.yanchor].sizing,v=(o?o.r2p(e.x)+o._offset:e.x*c.w+c.l)+f,m=(l?l.r2p(e.y)+l._offset:c.h-e.y*c.h+c.t)+d;switch(e.sizing){case"fill":g+=" slice";break;case"stretch":g="none"}r.attr({x:v,y:m,width:u,height:h,preserveAspectRatio:g,opacity:e.opacity});var y=(o?o._id:"")+(l?l._id:"");a.setClipUrl(r,y?"clip"+s._uid+y:null,t)}var v=s._imageLowerLayer.selectAll("image").data(u),m=s._imageUpperLayer.selectAll("image").data(l);v.enter().append("image"),m.enter().append("image"),v.exit().remove(),m.exit().remove(),v.each(function(t){d.bind(this)(t),g.bind(this)(t)}),m.each(function(t){d.bind(this)(t),g.bind(this)(t)});var y=Object.keys(s._plots);for(r=0;r<y.length;r++){e=y[r];var x=s._plots[e];if(x.imagelayer){var b=x.imagelayer.selectAll("image").data(c[e]||[]);b.enter().append("image"),b.exit().remove(),b.each(function(t){d.bind(this)(t),g.bind(this)(t)})}}}},{"../../constants/xmlns_namespaces":694,"../../plots/cartesian/axes":765,"../drawing":612,d3:165}],639:[function(t,e,r){"use strict";e.exports={moduleType:"component",name:"images",layoutAttributes:t("./attributes"),supplyLayoutDefaults:t("./defaults"),includeBasePlot:t("../../plots/cartesian/include_components")("images"),draw:t("./draw"),convertCoords:t("./convert_coords")}},{"../../plots/cartesian/include_components":775,"./attributes":635,"./convert_coords":636,"./defaults":637,"./draw":638}],640:[function(t,e,r){"use strict";var n=t("../../plots/font_attributes"),a=t("../color/attributes");e.exports={bgcolor:{valType:"color",editType:"legend"},bordercolor:{valType:"color",dflt:a.defaultLine,editType:"legend"},borderwidth:{valType:"number",min:0,dflt:0,editType:"legend"},font:n({editType:"legend"}),orientation:{valType:"enumerated",values:["v","h"],dflt:"v",editType:"legend"},traceorder:{valType:"flaglist",flags:["reversed","grouped"],extras:["normal"],editType:"legend"},tracegroupgap:{valType:"number",min:0,dflt:10,editType:"legend"},itemsizing:{valType:"enumerated",values:["trace","constant"],dflt:"trace",editType:"legend"},itemclick:{valType:"enumerated",values:["toggle","toggleothers",!1],dflt:"toggle",editType:"legend"},itemdoubleclick:{valType:"enumerated",values:["toggle","toggleothers",!1],dflt:"toggleothers",editType:"legend"},x:{valType:"number",min:-2,max:3,editType:"legend"},xanchor:{valType:"enumerated",values:["auto","left","center","right"],dflt:"left",editType:"legend"},y:{valType:"number",min:-2,max:3,editType:"legend"},yanchor:{valType:"enumerated",values:["auto","top","middle","bottom"],editType:"legend"},uirevision:{valType:"any",editType:"none"},valign:{valType:"enumerated",values:["top","middle","bottom"],dflt:"middle",editType:"legend"},title:{text:{valType:"string",dflt:"",editType:"legend"},font:n({editType:"legend"}),side:{valType:"enumerated",values:["top","left","top left"],editType:"legend"},editType:"legend"},editType:"legend"}},{"../../plots/font_attributes":791,"../color/attributes":590}],641:[function(t,e,r){"use strict";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:"#808BA4",scrollBarMargin:4,scrollBarEnterAttrs:{rx:20,ry:3,width:0,height:0},titlePad:2,textGap:40,itemGap:5}},{}],642:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("../../plot_api/plot_template"),o=t("./attributes"),s=t("../../plots/layout_attributes"),l=t("./helpers");e.exports=function(t,e,r){for(var c=t.legend||{},u=0,h=!1,f="normal",p=0;p<r.length;p++){var d=r[p];d.visible&&((d.showlegend||d._dfltShowLegend&&!(d._module&&d._module.attributes&&d._module.attributes.showlegend&&!1===d._module.attributes.showlegend.dflt))&&(u++,d.showlegend&&(h=!0,(n.traceIs(d,"pie-like")||!0===d._input.showlegend)&&u++)),(n.traceIs(d,"bar")&&"stack"===e.barmode||-1!==["tonextx","tonexty"].indexOf(d.fill))&&(f=l.isGrouped({traceorder:f})?"grouped+reversed":"reversed"),void 0!==d.legendgroup&&""!==d.legendgroup&&(f=l.isReversed({traceorder:f})?"reversed+grouped":"grouped"))}var g=a.coerce(t,e,s,"showlegend",h&&u>1);if(!1!==g||c.uirevision){var v=i.newContainer(e,"legend");if(_("uirevision",e.uirevision),!1!==g){_("bgcolor",e.paper_bgcolor),_("bordercolor"),_("borderwidth"),a.coerceFont(_,"font",e.font);var m,y,x,b=_("orientation");"h"===b?(m=0,n.getComponentMethod("rangeslider","isVisible")(t.xaxis)?(y=1.1,x="bottom"):(y=-.1,x="top")):(m=1.02,y=1,x="auto"),_("traceorder",f),l.isGrouped(e.legend)&&_("tracegroupgap"),_("itemsizing"),_("itemclick"),_("itemdoubleclick"),_("x",m),_("xanchor"),_("y",y),_("yanchor",x),_("valign"),a.noneOrAll(c,v,["x","y"]),_("title.text")&&(_("title.side","h"===b?"left":"top"),a.coerceFont(_,"title.font",e.font))}}function _(t,e){return a.coerce(c,v,o,t,e)}}},{"../../lib":717,"../../plot_api/plot_template":755,"../../plots/layout_attributes":817,"../../registry":846,"./attributes":640,"./helpers":646}],643:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../plots/plots"),o=t("../../registry"),s=t("../../lib/events"),l=t("../dragelement"),c=t("../drawing"),u=t("../color"),h=t("../../lib/svg_text_utils"),f=t("./handle_click"),p=t("./constants"),d=t("../../constants/alignment"),g=d.LINE_SPACING,v=d.FROM_TL,m=d.FROM_BR,y=t("./get_legend_data"),x=t("./style"),b=t("./helpers");function _(t,e,r,n,a){var i=r.data()[0][0].trace,l={event:a,node:r.node(),curveNumber:i.index,expandedIndex:i._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(i._group&&(l.group=i._group),o.traceIs(i,"pie-like")&&(l.label=r.datum()[0].label),!1!==s.triggerHandler(t,"plotly_legendclick",l))if(1===n)e._clickTimeout=setTimeout(function(){f(r,t,n)},t._context.doubleClickDelay);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,"plotly_legenddoubleclick",l)&&f(r,t,n)}}function w(t,e,r){var n,i=t.data()[0][0],s=i.trace,l=o.traceIs(s,"pie-like"),u=s.index,f=r._main&&e._context.edits.legendText&&!l,d=r._maxNameLength;r.entries?n=i.text:(n=l?i.label:s.name,s._meta&&(n=a.templateString(n,s._meta)));var g=a.ensureSingle(t,"text","legendtext");g.attr("text-anchor","start").classed("user-select-none",!0).call(c.font,r.font).text(f?k(n,d):n),h.positionText(g,p.textGap,0),f?g.call(h.makeEditable,{gd:e,text:n}).call(M,t,e,r).on("edit",function(n){this.text(k(n,d)).call(M,t,e,r);var s=i.trace._fullInput||{},l={};if(o.hasTransform(s,"groupby")){var c=o.getTransformIndices(s,"groupby"),h=c[c.length-1],f=a.keyedContainer(s,"transforms["+h+"].styles","target","value.name");f.set(i.trace._group,n),l=f.constructUpdate()}else l.name=n;return o.call("_guiRestyle",e,l,u)}):M(g,t,e,r)}function k(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||"").length;n>0;n--)t+=" ";return t}function T(t,e){var r,i=e._context.doubleClickDelay,o=1,s=a.ensureSingle(t,"rect","legendtoggle",function(t){t.style("cursor","pointer").attr("pointer-events","all").call(u.fill,"rgba(0,0,0,0)")});s.on("mousedown",function(){(r=(new Date).getTime())-e._legendMouseDownTime<i?o+=1:(o=1,e._legendMouseDownTime=r)}),s.on("mouseup",function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>i&&(o=Math.max(o-1,1)),_(e,r,t,o,n.event)}})}function M(t,e,r,n){n._main||t.attr("data-notex",!0),h.convertToTspans(t,r,function(){!function(t,e,r){var n=t.data()[0][0];if(r._main&&n&&!n.trace.showlegend)return void t.remove();var a=t.select("g[class*=math-group]"),i=a.node();r||(r=e._fullLayout.legend);var o,s,l=r.borderwidth,u=(n?r:r.title).font.size*g;if(i){var f=c.bBox(i);o=f.height,s=f.width,n?c.setTranslate(a,0,.25*o):c.setTranslate(a,l,.75*o+l)}else{var d=t.select(n?".legendtext":".legendtitletext"),v=h.lineCount(d),m=d.node();o=u*v,s=m?c.bBox(m).width:0;var y=u*((v-1)/2-.3);n?h.positionText(d,p.textGap,-y):h.positionText(d,p.titlePad+l,u+l)}n?(n.lineHeight=u,n.height=Math.max(o,16)+3,n.width=s):(r._titleWidth=s,r._titleHeight=o)}(e,r,n)})}function A(t){return a.isRightAnchor(t)?"right":a.isCenterAnchor(t)?"center":"left"}function S(t){return a.isBottomAnchor(t)?"bottom":a.isMiddleAnchor(t)?"middle":"top"}e.exports=function(t,e){var r,s=t._fullLayout,h="legend"+s._uid;if(e?(r=e.layer,h+="-hover"):((e=s.legend||{})._main=!0,r=s._infolayer),r){var f;if(t._legendMouseDownTime||(t._legendMouseDownTime=0),e._main){if(!t.calcdata)return;f=s.showlegend&&y(t.calcdata,e)}else{if(!e.entries)return;f=y(e.entries,e)}var d=s.hiddenlabels||[];if(e._main&&(!s.showlegend||!f.length))return r.selectAll(".legend").remove(),s._topdefs.select("#"+h).remove(),i.autoMargin(t,"legend");var g=a.ensureSingle(r,"g","legend",function(t){e._main&&t.attr("pointer-events","all")}),k=a.ensureSingleById(s._topdefs,"clipPath",h,function(t){t.append("rect")}),E=a.ensureSingle(g,"rect","bg",function(t){t.attr("shape-rendering","crispEdges")});E.call(u.stroke,e.bordercolor).call(u.fill,e.bgcolor).style("stroke-width",e.borderwidth+"px");var L=a.ensureSingle(g,"g","scrollbox"),C=e.title;if(e._titleWidth=0,e._titleHeight=0,C.text){var P=a.ensureSingle(L,"text","legendtitletext");P.attr("text-anchor","start").classed("user-select-none",!0).call(c.font,C.font).text(C.text),M(P,L,t,e)}var O=a.ensureSingle(g,"rect","scrollbar",function(t){t.attr(p.scrollBarEnterAttrs).call(u.fill,p.scrollBarColor)}),z=L.selectAll("g.groups").data(f);z.enter().append("g").attr("class","groups"),z.exit().remove();var I=z.selectAll("g.traces").data(a.identity);I.enter().append("g").attr("class","traces"),I.exit().remove(),I.style("opacity",function(t){var e=t[0].trace;return o.traceIs(e,"pie-like")?-1!==d.indexOf(t[0].label)?.5:1:"legendonly"===e.visible?.5:1}).each(function(){n.select(this).call(w,t,e)}).call(x,t,e).each(function(){e._main&&n.select(this).call(T,t)}),a.syncOrAsync([i.previousPromises,function(){return function(t,e,r,a){var i=t._fullLayout;a||(a=i.legend);var o=i._size,s=b.isVertical(a),l=b.isGrouped(a),u=a.borderwidth,h=2*u,f=p.textGap,d=p.itemGap,g=2*(u+d),v=S(a),m=a.y<0||0===a.y&&"top"===v,y=a.y>1||1===a.y&&"bottom"===v;a._maxHeight=Math.max(m||y?i.height/2:o.h,30);var x=0;a._width=0,a._height=0;var _=function(t){var e=0,r=0,n=t.title.side;n&&(-1!==n.indexOf("left")&&(e=t._titleWidth),-1!==n.indexOf("top")&&(r=t._titleHeight));return[e,r]}(a);if(s)r.each(function(t){var e=t[0].height;c.setTranslate(this,u+_[0],u+_[1]+a._height+e/2+d),a._height+=e,a._width=Math.max(a._width,t[0].width)}),x=f+a._width,a._width+=d+f+h,a._height+=g,l&&(e.each(function(t,e){c.setTranslate(this,0,e*a.tracegroupgap)}),a._height+=(a._lgroupsLength-1)*a.tracegroupgap);else{var w=A(a),k=a.x<0||0===a.x&&"right"===w,T=a.x>1||1===a.x&&"left"===w,M=y||m,E=i.width/2;a._maxWidth=Math.max(k?M&&"left"===w?o.l+o.w:E:T?M&&"right"===w?o.r+o.w:E:o.w,2*f);var L=0,C=0;r.each(function(t){var e=t[0].width+f;L=Math.max(L,e),C+=e}),x=null;var P=0;if(l){var O=0,z=0,I=0;e.each(function(){var t=0,e=0;n.select(this).selectAll("g.traces").each(function(r){var n=r[0].height;c.setTranslate(this,_[0],_[1]+u+d+n/2+e),e+=n,t=Math.max(t,f+r[0].width)}),O=Math.max(O,e);var r=t+d;r+u+z>a._maxWidth&&(P=Math.max(P,z),z=0,I+=O+a.tracegroupgap,O=e),c.setTranslate(this,z,I),z+=r}),a._width=Math.max(P,z)+u,a._height=I+O+g}else{var D=r.size(),R=C+h+(D-1)*d<a._maxWidth,F=0,B=0,N=0,j=0;r.each(function(t){var e=t[0].height,r=f+t[0].width,n=(R?r:L)+d;n+u+B>a._maxWidth&&(P=Math.max(P,j),B=0,N+=F,a._height+=F,F=0),c.setTranslate(this,_[0]+u+B,_[1]+u+N+e/2+d),j=B+r+d,B+=n,F=Math.max(F,e)}),R?(a._width=B+h,a._height=F+g):(a._width=Math.max(P,j)+h,a._height+=F+g)}}a._width=Math.ceil(Math.max(a._width+_[0],a._titleWidth+2*(u+p.titlePad))),a._height=Math.ceil(Math.max(a._height+_[1],a._titleHeight+2*(u+p.itemGap))),a._effHeight=Math.min(a._height,a._maxHeight);var V=t._context.edits,U=V.legendText||V.legendPosition;r.each(function(t){var e=n.select(this).select(".legendtoggle"),r=t[0].height,a=U?f:x||f+t[0].width;s||(a+=d/2),c.setRect(e,0,-r/2,a,r)})}(t,z,I,e)},function(){if(!e._main||!function(t){var e=t._fullLayout.legend,r=A(e),n=S(e);return i.autoMargin(t,"legend",{x:e.x,y:e.y,l:e._width*v[r],r:e._width*m[r],b:e._effHeight*m[n],t:e._effHeight*v[n]})}(t)){var u,f,d,y,x=s._size,b=e.borderwidth,w=x.l+x.w*e.x-v[A(e)]*e._width,T=x.t+x.h*(1-e.y)-v[S(e)]*e._effHeight;if(e._main&&s.margin.autoexpand){var M=w,C=T;w=a.constrain(w,0,s.width-e._width),T=a.constrain(T,0,s.height-e._effHeight),w!==M&&a.log("Constrain legend.x to make legend fit inside graph"),T!==C&&a.log("Constrain legend.y to make legend fit inside graph")}if(e._main&&c.setTranslate(g,w,T),O.on(".drag",null),g.on("wheel",null),!e._main||e._height<=e._maxHeight||t._context.staticPlot){var P=e._effHeight;e._main||(P=e._height),E.attr({width:e._width-b,height:P-b,x:b/2,y:b/2}),c.setTranslate(L,0,0),k.select("rect").attr({width:e._width-2*b,height:P-2*b,x:b,y:b}),c.setClipUrl(L,h,t),c.setRect(O,0,0,0,0),delete e._scrollY}else{var z,I,D,R=Math.max(p.scrollBarMinHeight,e._effHeight*e._effHeight/e._height),F=e._effHeight-R-2*p.scrollBarMargin,B=e._height-e._effHeight,N=F/B,j=Math.min(e._scrollY||0,B);E.attr({width:e._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:e._effHeight-b,x:b/2,y:b/2}),k.select("rect").attr({width:e._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:e._effHeight-2*b,x:b,y:b+j}),c.setClipUrl(L,h,t),q(j,R,N),g.on("wheel",function(){q(j=a.constrain(e._scrollY+n.event.deltaY/F*B,0,B),R,N),0!==j&&j!==B&&n.event.preventDefault()});var V=n.behavior.drag().on("dragstart",function(){var t=n.event.sourceEvent;z="touchstart"===t.type?t.changedTouches[0].clientY:t.clientY,D=j}).on("drag",function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||(I="touchmove"===t.type?t.changedTouches[0].clientY:t.clientY,q(j=function(t,e,r){var n=(r-e)/N+t;return a.constrain(n,0,B)}(D,z,I),R,N))});O.call(V);var U=n.behavior.drag().on("dragstart",function(){var t=n.event.sourceEvent;"touchstart"===t.type&&(z=t.changedTouches[0].clientY,D=j)}).on("drag",function(){var t=n.event.sourceEvent;"touchmove"===t.type&&(I=t.changedTouches[0].clientY,q(j=function(t,e,r){var n=(e-r)/N+t;return a.constrain(n,0,B)}(D,z,I),R,N))});L.call(U)}if(t._context.edits.legendPosition)g.classed("cursor-move",!0),l.init({element:g.node(),gd:t,prepFn:function(){var t=c.getTranslate(g);d=t.x,y=t.y},moveFn:function(t,r){var n=d+t,a=y+r;c.setTranslate(g,n,a),u=l.align(n,0,x.l,x.l+x.w,e.xanchor),f=l.align(a,0,x.t+x.h,x.t,e.yanchor)},doneFn:function(){void 0!==u&&void 0!==f&&o.call("_guiRelayout",t,{"legend.x":u,"legend.y":f})},clickFn:function(e,n){var a=r.selectAll("g.traces").filter(function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom});a.size()>0&&_(t,g,a,e,n)}})}function q(r,n,a){e._scrollY=t._fullLayout.legend._scrollY=r,c.setTranslate(L,0,-r),c.setRect(O,e._width,p.scrollBarMargin+r*a,p.scrollBarWidth,n),k.select("rect").attr("y",b+r)}}],t)}}},{"../../constants/alignment":686,"../../lib":717,"../../lib/events":707,"../../lib/svg_text_utils":741,"../../plots/plots":826,"../../registry":846,"../color":591,"../dragelement":609,"../drawing":612,"./constants":641,"./get_legend_data":644,"./handle_click":645,"./helpers":646,"./style":648,d3:165}],644:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("./helpers");e.exports=function(t,e){var r,i,o={},s=[],l=!1,c={},u=0,h=0,f=e._main;function p(t,r){if(""!==t&&a.isGrouped(e))-1===s.indexOf(t)?(s.push(t),l=!0,o[t]=[[r]]):o[t].push([r]);else{var n="~~i"+u;s.push(n),o[n]=[[r]],u++}}for(r=0;r<t.length;r++){var d=t[r],g=d[0],v=g.trace,m=v.legendgroup;if(!f||v.visible&&v.showlegend)if(n.traceIs(v,"pie-like"))for(c[m]||(c[m]={}),i=0;i<d.length;i++){var y=d[i].label;c[m][y]||(p(m,{label:y,color:d[i].color,i:d[i].i,trace:v,pts:d[i].pts}),c[m][y]=!0,h=Math.max(h,(y||"").length))}else p(m,g),h=Math.max(h,(v.name||"").length)}if(!s.length)return[];var x,b,_=s.length;if(l&&a.isGrouped(e))for(b=new Array(_),r=0;r<_;r++)x=o[s[r]],b[r]=a.isReversed(e)?x.reverse():x;else{for(b=[new Array(_)],r=0;r<_;r++)x=o[s[r]][0],b[0][a.isReversed(e)?_-r-1:r]=x;_=1}return e._lgroupsLength=_,e._maxNameLength=h,b}},{"../../registry":846,"./helpers":646}],645:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../registry"),i=!0;e.exports=function(t,e,r){var o=e._fullLayout;if(!e._dragged&&!e._editing){var s,l=o.legend.itemclick,c=o.legend.itemdoubleclick;if(1===r&&"toggle"===l&&"toggleothers"===c&&i&&e.data&&e._context.showTips?(n.notifier(n._(e,"Double-click on legend to isolate one trace"),"long"),i=!1):i=!1,1===r?s=l:2===r&&(s=c),s){var u,h,f,p,d,g=o.hiddenlabels?o.hiddenlabels.slice():[],v=t.data()[0][0],m=e._fullData,y=v.trace,x=y.legendgroup,b={},_=[],w=[],k=[];if(a.traceIs(y,"pie-like")){var T=v.label,M=g.indexOf(T);"toggle"===s?-1===M?g.push(T):g.splice(M,1):"toggleothers"===s&&(g=[],e.calcdata[0].forEach(function(t){T!==t.label&&g.push(t.label)}),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===g.length&&-1===M&&(g=[])),a.call("_guiRelayout",e,"hiddenlabels",g)}else{var A,S=x&&x.length,E=[];if(S)for(u=0;u<m.length;u++)(A=m[u]).visible&&A.legendgroup===x&&E.push(u);if("toggle"===s){var L;switch(y.visible){case!0:L="legendonly";break;case!1:L=!1;break;case"legendonly":L=!0}if(S)for(u=0;u<m.length;u++)!1!==m[u].visible&&m[u].legendgroup===x&&B(m[u],L);else B(y,L)}else if("toggleothers"===s){var C,P,O,z,I=!0;for(u=0;u<m.length;u++)if(C=m[u]===y,O=!0!==m[u].showlegend,!(C||O||(P=S&&m[u].legendgroup===x)||!0!==m[u].visible||a.traceIs(m[u],"notLegendIsolatable"))){I=!1;break}for(u=0;u<m.length;u++)if(!1!==m[u].visible&&!a.traceIs(m[u],"notLegendIsolatable"))switch(y.visible){case"legendonly":B(m[u],!0);break;case!0:z=!!I||"legendonly",C=m[u]===y,O=!0!==m[u].showlegend&&!m[u].legendgroup,P=C||S&&m[u].legendgroup===x,B(m[u],!(!P&&!O)||z)}}for(u=0;u<w.length;u++)if(f=w[u]){var D=f.constructUpdate(),R=Object.keys(D);for(h=0;h<R.length;h++)p=R[h],(b[p]=b[p]||[])[k[u]]=D[p]}for(d=Object.keys(b),u=0;u<d.length;u++)for(p=d[u],h=0;h<_.length;h++)b[p].hasOwnProperty(h)||(b[p][h]=void 0);a.call("_guiRestyle",e,b,_)}}}function F(t,e,r){var n=_.indexOf(t),a=b[e];return a||(a=b[e]=[]),-1===_.indexOf(t)&&(_.push(t),n=_.length-1),a[n]=r,n}function B(t,e){var r=t._fullInput;if(a.hasTransform(r,"groupby")){var i=w[r.index];if(!i){var o=a.getTransformIndices(r,"groupby"),s=o[o.length-1];i=n.keyedContainer(r,"transforms["+s+"].styles","target","value.visible"),w[r.index]=i}var l=i.get(t._group);void 0===l&&(l=!0),!1!==l&&i.set(t._group,e),k[r.index]=F(r.index,"visible",!1!==r.visible)}else{var c=!1!==r.visible&&e;F(r.index,"visible",c)}}}},{"../../lib":717,"../../registry":846}],646:[function(t,e,r){"use strict";r.isGrouped=function(t){return-1!==(t.traceorder||"").indexOf("grouped")},r.isVertical=function(t){return"h"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||"").indexOf("reversed")}},{}],647:[function(t,e,r){"use strict";e.exports={moduleType:"component",name:"legend",layoutAttributes:t("./attributes"),supplyLayoutDefaults:t("./defaults"),draw:t("./draw"),style:t("./style")}},{"./attributes":640,"./defaults":642,"./draw":643,"./style":648}],648:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../lib"),o=t("../drawing"),s=t("../color"),l=t("../colorscale/helpers").extractOpts,c=t("../../traces/scatter/subtypes"),u=t("../../traces/pie/style_one"),h=t("../../traces/pie/helpers").castOption,f=12,p=5,d=2,g=10,v=5;function m(t,e){return(e?"radial":"horizontal")+(t?"":"reversed")}e.exports=function(t,e,r){var y=e._fullLayout;r||(r=y.legend);var x="constant"===r.itemsizing,b=function(t,e,r,n){var a;if(t+1)a=t;else{if(!(e&&e.width>0))return 0;a=e.width}return x?n:Math.min(a,r)};function _(t,e,r){var i=t[0].trace,o=i.marker||{},l=o.line||{},c=r?i.visible&&i.type===r:a.traceIs(i,"bar"),u=n.select(e).select("g.legendpoints").selectAll("path.legend"+r).data(c?[t]:[]);u.enter().append("path").classed("legend"+r,!0).attr("d","M6,6H-6V-6H6Z").attr("transform","translate(20,0)"),u.exit().remove(),u.each(function(t){var e=n.select(this),r=t[0],a=b(r.mlw,o.line,v,d);e.style("stroke-width",a+"px").call(s.fill,r.mc||o.color),a&&s.stroke(e,r.mlc||l.color)})}function w(t,e,r){var o=t[0],s=o.trace,l=r?s.visible&&s.type===r:a.traceIs(s,r),c=n.select(e).select("g.legendpoints").selectAll("path.legend"+r).data(l?[t]:[]);if(c.enter().append("path").classed("legend"+r,!0).attr("d","M6,6H-6V-6H6Z").attr("transform","translate(20,0)"),c.exit().remove(),c.size()){var f=(s.marker||{}).line,p=b(h(f.width,o.pts),f,v,d),g=i.minExtend(s,{marker:{line:{width:p}}});g.marker.line.color=f.color;var m=i.minExtend(o,{trace:g});u(c,m,g)}}t.each(function(t){var e=n.select(this),a=i.ensureSingle(e,"g","layers");a.style("opacity",t[0].trace.opacity);var o=r.valign,s=t[0].lineHeight,l=t[0].height;if("middle"!==o&&s&&l){var c={top:1,bottom:-1}[o]*(.5*(s-l+3));a.attr("transform","translate(0,"+c+")")}else a.attr("transform",null);a.selectAll("g.legendfill").data([t]).enter().append("g").classed("legendfill",!0),a.selectAll("g.legendlines").data([t]).enter().append("g").classed("legendlines",!0);var u=a.selectAll("g.legendsymbols").data([t]);u.enter().append("g").classed("legendsymbols",!0),u.selectAll("g.legendpoints").data([t]).enter().append("g").classed("legendpoints",!0)}).each(function(t){var r,a=t[0].trace,c=[];if(a.visible)switch(a.type){case"histogram2d":case"heatmap":c=[["M-15,-2V4H15V-2Z"]],r=!0;break;case"choropleth":case"choroplethmapbox":c=[["M-6,-6V6H6V-6Z"]],r=!0;break;case"densitymapbox":c=[["M-6,0 a6,6 0 1,0 12,0 a 6,6 0 1,0 -12,0"]],r="radial";break;case"cone":c=[["M-6,2 A2,2 0 0,0 -6,6 V6L6,4Z"],["M-6,-6 A2,2 0 0,0 -6,-2 L6,-4Z"],["M-6,-2 A2,2 0 0,0 -6,2 L6,0Z"]],r=!1;break;case"streamtube":c=[["M-6,2 A2,2 0 0,0 -6,6 H6 A2,2 0 0,1 6,2 Z"],["M-6,-6 A2,2 0 0,0 -6,-2 H6 A2,2 0 0,1 6,-6 Z"],["M-6,-2 A2,2 0 0,0 -6,2 H6 A2,2 0 0,1 6,-2 Z"]],r=!1;break;case"surface":c=[["M-6,-6 A2,3 0 0,0 -6,0 H6 A2,3 0 0,1 6,-6 Z"],["M-6,1 A2,3 0 0,1 -6,6 H6 A2,3 0 0,0 6,0 Z"]],r=!0;break;case"mesh3d":c=[["M-6,6H0L-6,-6Z"],["M6,6H0L6,-6Z"],["M-6,-6H6L0,6Z"]],r=!1;break;case"volume":c=[["M-6,6H0L-6,-6Z"],["M6,6H0L6,-6Z"],["M-6,-6H6L0,6Z"]],r=!0;break;case"isosurface":c=[["M-6,6H0L-6,-6Z"],["M6,6H0L6,-6Z"],["M-6,-6 A12,24 0 0,0 6,-6 L0,6Z"]],r=!1}var u=n.select(this).select("g.legendpoints").selectAll("path.legend3dandfriends").data(c);u.enter().append("path").classed("legend3dandfriends",!0).attr("transform","translate(20,0)").style("stroke-miterlimit",1),u.exit().remove(),u.each(function(t,c){var u,h=n.select(this),f=l(a),p=f.colorscale,d=f.reversescale;if(p){if(!r){var g=p.length;u=0===c?p[d?g-1:0][1]:1===c?p[d?0:g-1][1]:p[Math.floor((g-1)/2)][1]}}else{var v=a.vertexcolor||a.facecolor||a.color;u=i.isArrayOrTypedArray(v)?v[c]||v[0]:v}h.attr("d",t[0]),u?h.call(s.fill,u):h.call(function(t){if(t.size()){var n="legendfill-"+a.uid;o.gradient(t,e,n,m(d,"radial"===r),p,"fill")}})})}).each(function(t){var e=t[0].trace,r="waterfall"===e.type;if(t[0]._distinct&&r){var a=t[0].trace[t[0].dir].marker;return t[0].mc=a.color,t[0].mlw=a.line.width,t[0].mlc=a.line.color,_(t,this,"waterfall")}var i=[];e.visible&&r&&(i=t[0].hasTotals?[["increasing","M-6,-6V6H0Z"],["totals","M6,6H0L-6,-6H-0Z"],["decreasing","M6,6V-6H0Z"]]:[["increasing","M-6,-6V6H6Z"],["decreasing","M6,6V-6H-6Z"]]);var o=n.select(this).select("g.legendpoints").selectAll("path.legendwaterfall").data(i);o.enter().append("path").classed("legendwaterfall",!0).attr("transform","translate(20,0)").style("stroke-miterlimit",1),o.exit().remove(),o.each(function(t){var r=n.select(this),a=e[t[0]].marker,i=b(void 0,a.line,v,d);r.attr("d",t[1]).style("stroke-width",i+"px").call(s.fill,a.color),i&&r.call(s.stroke,a.line.color)})}).each(function(t){_(t,this,"funnel")}).each(function(t){_(t,this)}).each(function(t){var r=t[0].trace,l=n.select(this).select("g.legendpoints").selectAll("path.legendbox").data(r.visible&&a.traceIs(r,"box-violin")?[t]:[]);l.enter().append("path").classed("legendbox",!0).attr("d","M6,6H-6V-6H6Z").attr("transform","translate(20,0)"),l.exit().remove(),l.each(function(){var t=n.select(this);if("all"!==r.boxpoints&&"all"!==r.points||0!==s.opacity(r.fillcolor)||0!==s.opacity((r.line||{}).color)){var a=b(void 0,r.line,v,d);t.style("stroke-width",a+"px").call(s.fill,r.fillcolor),a&&s.stroke(t,r.line.color)}else{var c=i.minExtend(r,{marker:{size:x?f:i.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:"diameter"}});l.call(o.pointStyle,c,e)}})}).each(function(t){w(t,this,"funnelarea")}).each(function(t){w(t,this,"pie")}).each(function(t){var r,a,s=t[0],u=s.trace,h=u.visible&&u.fill&&"none"!==u.fill,f=c.hasLines(u),d=u.contours,v=!1,y=!1,x=l(u),_=x.colorscale,w=x.reversescale;if(d){var k=d.coloring;"lines"===k?v=!0:f="none"===k||"heatmap"===k||d.showlines,"constraint"===d.type?h="="!==d._operation:"fill"!==k&&"heatmap"!==k||(y=!0)}var T=c.hasMarkers(u)||c.hasText(u),M=h||y,A=f||v,S=T||!M?"M5,0":A?"M5,-2":"M5,-3",E=n.select(this),L=E.select(".legendfill").selectAll("path").data(h||y?[t]:[]);if(L.enter().append("path").classed("js-fill",!0),L.exit().remove(),L.attr("d",S+"h30v6h-30z").call(h?o.fillGroupStyle:function(t){if(t.size()){var r="legendfill-"+u.uid;o.gradient(t,e,r,m(w),_,"fill")}}),f||v){var C=b(void 0,u.line,g,p);a=i.minExtend(u,{line:{width:C}}),r=[i.minExtend(s,{trace:a})]}var P=E.select(".legendlines").selectAll("path").data(f||v?[r]:[]);P.enter().append("path").classed("js-line",!0),P.exit().remove(),P.attr("d",S+(v?"l30,0.0001":"h30")).call(f?o.lineGroupStyle:function(t){if(t.size()){var r="legendline-"+u.uid;o.lineGroupStyle(t),o.gradient(t,e,r,m(w),_,"stroke")}})}).each(function(t){var r,a,s=t[0],l=s.trace,u=c.hasMarkers(l),h=c.hasText(l),g=c.hasLines(l);function v(t,e,r,n){var a=i.nestedProperty(l,t).get(),o=i.isArrayOrTypedArray(a)&&e?e(a):a;if(x&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function m(t){return s._distinct&&s.index&&t[s.index]?t[s.index]:t[0]}if(u||h||g){var y={},b={};if(u){y.mc=v("marker.color",m),y.mx=v("marker.symbol",m),y.mo=v("marker.opacity",i.mean,[.2,1]),y.mlc=v("marker.line.color",m),y.mlw=v("marker.line.width",i.mean,[0,5],d),b.marker={sizeref:1,sizemin:1,sizemode:"diameter"};var _=v("marker.size",i.mean,[2,16],f);y.ms=_,b.marker.size=_}g&&(b.line={width:v("line.width",m,[0,10],p)}),h&&(y.tx="Aa",y.tp=v("textposition",m),y.ts=10,y.tc=v("textfont.color",m),y.tf=v("textfont.family",m)),r=[i.minExtend(s,y)],(a=i.minExtend(l,b)).selectedpoints=null,a.texttemplate=null}var w=n.select(this).select("g.legendpoints"),k=w.selectAll("path.scatterpts").data(u?r:[]);k.enter().insert("path",":first-child").classed("scatterpts",!0).attr("transform","translate(20,0)"),k.exit().remove(),k.call(o.pointStyle,a,e),u&&(r[0].mrc=3);var T=w.selectAll("g.pointtext").data(h?r:[]);T.enter().append("g").classed("pointtext",!0).append("text").attr("transform","translate(20,0)"),T.exit().remove(),T.selectAll("text").call(o.textPointStyle,a,e)}).each(function(t){var e=t[0].trace,r=n.select(this).select("g.legendpoints").selectAll("path.legendcandle").data(e.visible&&"candlestick"===e.type?[t,t]:[]);r.enter().append("path").classed("legendcandle",!0).attr("d",function(t,e){return e?"M-15,0H-8M-8,6V-6H8Z":"M15,0H8M8,-6V6H-8Z"}).attr("transform","translate(20,0)").style("stroke-miterlimit",1),r.exit().remove(),r.each(function(t,r){var a=n.select(this),i=e[r?"increasing":"decreasing"],o=b(void 0,i.line,v,d);a.style("stroke-width",o+"px").call(s.fill,i.fillcolor),o&&s.stroke(a,i.line.color)})}).each(function(t){var e=t[0].trace,r=n.select(this).select("g.legendpoints").selectAll("path.legendohlc").data(e.visible&&"ohlc"===e.type?[t,t]:[]);r.enter().append("path").classed("legendohlc",!0).attr("d",function(t,e){return e?"M-15,0H0M-8,-6V0":"M15,0H0M8,6V0"}).attr("transform","translate(20,0)").style("stroke-miterlimit",1),r.exit().remove(),r.each(function(t,r){var a=n.select(this),i=e[r?"increasing":"decreasing"],l=b(void 0,i.line,v,d);a.style("fill","none").call(o.dashLine,i.line.dash,l),l&&s.stroke(a,i.line.color)})})}},{"../../lib":717,"../../registry":846,"../../traces/pie/helpers":1099,"../../traces/pie/style_one":1105,"../../traces/scatter/subtypes":1144,"../color":591,"../colorscale/helpers":602,"../drawing":612,d3:165}],649:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../plots/plots"),i=t("../../plots/cartesian/axis_ids"),o=t("../../lib"),s=t("../../fonts/ploticon"),l=o._,c=e.exports={};function u(t,e){var r,a,o=e.currentTarget,s=o.getAttribute("data-attr"),l=o.getAttribute("data-val")||!0,c=t._fullLayout,u={},h=i.list(t,null,!0),f=c._cartesianSpikesEnabled;if("zoom"===s){var p,d="in"===l?.5:2,g=(1+d)/2,v=(1-d)/2;for(a=0;a<h.length;a++)if(!(r=h[a]).fixedrange)if(p=r._name,"auto"===l)u[p+".autorange"]=!0;else if("reset"===l){if(void 0===r._rangeInitial)u[p+".autorange"]=!0;else{var m=r._rangeInitial.slice();u[p+".range[0]"]=m[0],u[p+".range[1]"]=m[1]}void 0!==r._showSpikeInitial&&(u[p+".showspikes"]=r._showSpikeInitial,"on"!==f||r._showSpikeInitial||(f="off"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[g*y[0]+v*y[1],g*y[1]+v*y[0]];u[p+".range[0]"]=r.l2r(x[0]),u[p+".range[1]"]=r.l2r(x[1])}}else"hovermode"!==s||"x"!==l&&"y"!==l||(l=c._isHoriz?"y":"x",o.setAttribute("data-val",l)),u[s]=l;c._cartesianSpikesEnabled=f,n.call("_guiRelayout",t,u)}function h(t,e){for(var r=e.currentTarget,a=r.getAttribute("data-attr"),i=r.getAttribute("data-val")||!0,o=t._fullLayout._subplots.gl3d||[],s={},l=a.split("."),c=0;c<o.length;c++)s[o[c]+"."+l[1]]=i;var u="pan"===i?i:"zoom";s.dragmode=u,n.call("_guiRelayout",t,s)}function f(t,e){for(var r=e.currentTarget.getAttribute("data-attr"),a=t._fullLayout,i=a._subplots.gl3d||[],o={},s=0;s<i.length;s++){var l,c=i[s],u=c+".camera",h=c+".aspectratio",f=c+".aspectmode",p=a[c]._scene;"resetLastSave"===r?(o[u+".up"]=p.viewInitial.up,o[u+".eye"]=p.viewInitial.eye,o[u+".center"]=p.viewInitial.center,l=!0):"resetDefault"===r&&(o[u+".up"]=null,o[u+".eye"]=null,o[u+".center"]=null,l=!0),l&&(o[h+".x"]=p.viewInitial.aspectratio.x,o[h+".y"]=p.viewInitial.aspectratio.y,o[h+".z"]=p.viewInitial.aspectratio.z,o[f]=p.viewInitial.aspectmode)}n.call("_guiRelayout",t,o)}function p(t,e){var r=e.currentTarget,n=r._previousVal,a=t._fullLayout,i=a._subplots.gl3d||[],o=["xaxis","yaxis","zaxis"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<i.length;c++){var u=i[c],h=a[u],f=u+".hovermode";s[f]=h.hovermode,l[f]=!1;for(var p=0;p<3;p++){var d=o[p],g=u+"."+d+".showspikes";l[g]=!1,s[g]=h[d].showspikes}}r._previousVal=s}return l}function d(t,e){for(var r=e.currentTarget,a=r.getAttribute("data-attr"),i=r.getAttribute("data-val")||!0,o=t._fullLayout,s=o._subplots.geo||[],l=0;l<s.length;l++){var c=s[l],u=o[c];if("zoom"===a){var h=u.projection.scale,f="in"===i?2*h:.5*h;n.call("_guiRelayout",t,c+".projection.scale",f)}}"reset"===a&&y(t,"geo")}function g(t){var e=t._fullLayout;return!e.hovermode&&(e._has("cartesian")?e._isHoriz?"y":"x":"closest")}function v(t){var e=g(t);n.call("_guiRelayout",t,"hovermode",e)}function m(t,e){for(var r=e.currentTarget.getAttribute("data-val"),a=t._fullLayout,i=a._subplots.mapbox||[],o={},s=0;s<i.length;s++){var l=i[s],c=a[l].zoom,u="in"===r?1.05*c:c/1.05;o[l+".zoom"]=u}n.call("_guiRelayout",t,o)}function y(t,e){for(var r=t._fullLayout,a=r._subplots[e]||[],i={},o=0;o<a.length;o++)for(var s=a[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var h=c[u];i[s+"."+h]=l[h]}n.call("_guiRelayout",t,i)}c.toImage={name:"toImage",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||"png";return l(t,"png"===e?"Download plot as a png":"Download plot")},icon:s.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||"png"};o.notifier(l(t,"Taking snapshot - this may take a few seconds"),"long"),"svg"!==r.format&&o.isIE()&&(o.notifier(l(t,"IE only supports svg.  Changing format to svg."),"long"),r.format="svg"),["filename","width","height","scale"].forEach(function(t){t in e&&(r[t]=e[t])}),n.call("downloadImage",t,r).then(function(e){o.notifier(l(t,"Snapshot succeeded")+" - "+e,"long")}).catch(function(){o.notifier(l(t,"Sorry, there was a problem downloading your snapshot!"),"long")})}},c.sendDataToCloud={name:"sendDataToCloud",title:function(t){return l(t,"Edit in Chart Studio")},icon:s.disk,click:function(t){a.sendDataToCloud(t)}},c.editInChartStudio={name:"editInChartStudio",title:function(t){return l(t,"Edit in Chart Studio")},icon:s.pencil,click:function(t){a.sendDataToCloud(t)}},c.zoom2d={name:"zoom2d",title:function(t){return l(t,"Zoom")},attr:"dragmode",val:"zoom",icon:s.zoombox,click:u},c.pan2d={name:"pan2d",title:function(t){return l(t,"Pan")},attr:"dragmode",val:"pan",icon:s.pan,click:u},c.select2d={name:"select2d",title:function(t){return l(t,"Box Select")},attr:"dragmode",val:"select",icon:s.selectbox,click:u},c.lasso2d={name:"lasso2d",title:function(t){return l(t,"Lasso Select")},attr:"dragmode",val:"lasso",icon:s.lasso,click:u},c.zoomIn2d={name:"zoomIn2d",title:function(t){return l(t,"Zoom in")},attr:"zoom",val:"in",icon:s.zoom_plus,click:u},c.zoomOut2d={name:"zoomOut2d",title:function(t){return l(t,"Zoom out")},attr:"zoom",val:"out",icon:s.zoom_minus,click:u},c.autoScale2d={name:"autoScale2d",title:function(t){return l(t,"Autoscale")},attr:"zoom",val:"auto",icon:s.autoscale,click:u},c.resetScale2d={name:"resetScale2d",title:function(t){return l(t,"Reset axes")},attr:"zoom",val:"reset",icon:s.home,click:u},c.hoverClosestCartesian={name:"hoverClosestCartesian",title:function(t){return l(t,"Show closest data on hover")},attr:"hovermode",val:"closest",icon:s.tooltip_basic,gravity:"ne",click:u},c.hoverCompareCartesian={name:"hoverCompareCartesian",title:function(t){return l(t,"Compare data on hover")},attr:"hovermode",val:function(t){return t._fullLayout._isHoriz?"y":"x"},icon:s.tooltip_compare,gravity:"ne",click:u},c.zoom3d={name:"zoom3d",title:function(t){return l(t,"Zoom")},attr:"scene.dragmode",val:"zoom",icon:s.zoombox,click:h},c.pan3d={name:"pan3d",title:function(t){return l(t,"Pan")},attr:"scene.dragmode",val:"pan",icon:s.pan,click:h},c.orbitRotation={name:"orbitRotation",title:function(t){return l(t,"Orbital rotation")},attr:"scene.dragmode",val:"orbit",icon:s["3d_rotate"],click:h},c.tableRotation={name:"tableRotation",title:function(t){return l(t,"Turntable rotation")},attr:"scene.dragmode",val:"turntable",icon:s["z-axis"],click:h},c.resetCameraDefault3d={name:"resetCameraDefault3d",title:function(t){return l(t,"Reset camera to default")},attr:"resetDefault",icon:s.home,click:f},c.resetCameraLastSave3d={name:"resetCameraLastSave3d",title:function(t){return l(t,"Reset camera to last save")},attr:"resetLastSave",icon:s.movie,click:f},c.hoverClosest3d={name:"hoverClosest3d",title:function(t){return l(t,"Toggle show closest data on hover")},attr:"hovermode",val:null,toggle:!0,icon:s.tooltip_basic,gravity:"ne",click:function(t,e){var r=p(t,e);n.call("_guiRelayout",t,r)}},c.zoomInGeo={name:"zoomInGeo",title:function(t){return l(t,"Zoom in")},attr:"zoom",val:"in",icon:s.zoom_plus,click:d},c.zoomOutGeo={name:"zoomOutGeo",title:function(t){return l(t,"Zoom out")},attr:"zoom",val:"out",icon:s.zoom_minus,click:d},c.resetGeo={name:"resetGeo",title:function(t){return l(t,"Reset")},attr:"reset",val:null,icon:s.autoscale,click:d},c.hoverClosestGeo={name:"hoverClosestGeo",title:function(t){return l(t,"Toggle show closest data on hover")},attr:"hovermode",val:null,toggle:!0,icon:s.tooltip_basic,gravity:"ne",click:v},c.hoverClosestGl2d={name:"hoverClosestGl2d",title:function(t){return l(t,"Toggle show closest data on hover")},attr:"hovermode",val:null,toggle:!0,icon:s.tooltip_basic,gravity:"ne",click:v},c.hoverClosestPie={name:"hoverClosestPie",title:function(t){return l(t,"Toggle show closest data on hover")},attr:"hovermode",val:"closest",icon:s.tooltip_basic,gravity:"ne",click:v},c.resetViewSankey={name:"resetSankeyGroup",title:function(t){return l(t,"Reset view")},icon:s.home,click:function(t){for(var e={"node.groups":[],"node.x":[],"node.y":[]},r=0;r<t._fullData.length;r++){var a=t._fullData[r]._viewInitial;e["node.groups"].push(a.node.groups.slice()),e["node.x"].push(a.node.x.slice()),e["node.y"].push(a.node.y.slice())}n.call("restyle",t,e)}},c.toggleHover={name:"toggleHover",title:function(t){return l(t,"Toggle show closest data on hover")},attr:"hovermode",val:null,toggle:!0,icon:s.tooltip_basic,gravity:"ne",click:function(t,e){var r=p(t,e);r.hovermode=g(t),n.call("_guiRelayout",t,r)}},c.resetViews={name:"resetViews",title:function(t){return l(t,"Reset views")},icon:s.home,click:function(t,e){var r=e.currentTarget;r.setAttribute("data-attr","zoom"),r.setAttribute("data-val","reset"),u(t,e),r.setAttribute("data-attr","resetLastSave"),f(t,e),y(t,"geo"),y(t,"mapbox")}},c.toggleSpikelines={name:"toggleSpikelines",title:function(t){return l(t,"Toggle Spike Lines")},icon:s.spikeline,attr:"_cartesianSpikesEnabled",val:"on",click:function(t){var e=t._fullLayout,r=e._cartesianSpikesEnabled;e._cartesianSpikesEnabled="on"===r?"off":"on",n.call("_guiRelayout",t,function(t){for(var e="on"===t._fullLayout._cartesianSpikesEnabled,r=i.list(t,null,!0),n={},a=0;a<r.length;a++){var o=r[a];n[o._name+".showspikes"]=!!e||o._showSpikeInitial}return n}(t))}},c.resetViewMapbox={name:"resetViewMapbox",title:function(t){return l(t,"Reset view")},attr:"reset",icon:s.home,click:function(t){y(t,"mapbox")}},c.zoomInMapbox={name:"zoomInMapbox",title:function(t){return l(t,"Zoom in")},attr:"zoom",val:"in",icon:s.zoom_plus,click:m},c.zoomOutMapbox={name:"zoomOutMapbox",title:function(t){return l(t,"Zoom out")},attr:"zoom",val:"out",icon:s.zoom_minus,click:m}},{"../../fonts/ploticon":697,"../../lib":717,"../../plots/cartesian/axis_ids":768,"../../plots/plots":826,"../../registry":846}],650:[function(t,e,r){"use strict";r.manage=t("./manage")},{"./manage":651}],651:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axis_ids"),a=t("../../traces/scatter/subtypes"),i=t("../../registry"),o=t("../fx/helpers").isUnifiedHover,s=t("./modebar"),l=t("./buttons");e.exports=function(t){var e=t._fullLayout,r=t._context,c=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error(["*modeBarButtonsToRemove* configuration options","must be an array."].join(" "));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error(["*modeBarButtonsToAdd* configuration options","must be an array."].join(" "));var u,h=r.modeBarButtons;u=Array.isArray(h)&&h.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var a=r[n];if("string"==typeof a){if(void 0===l[a])throw new Error(["*modeBarButtons* configuration options","invalid button name"].join(" "));t[e][n]=l[a]}}return t}(h):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,s=t._context,c=s.modeBarButtonsToRemove,u=s.modeBarButtonsToAdd,h=e._has("cartesian"),f=e._has("gl3d"),p=e._has("geo"),d=e._has("pie"),g=e._has("funnelarea"),v=e._has("gl2d"),m=e._has("ternary"),y=e._has("mapbox"),x=e._has("polar"),b=e._has("sankey"),_=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),w=o(e.hovermode),k=[];function T(t){if(t.length){for(var e=[],r=0;r<t.length;r++){var n=t[r];-1===c.indexOf(n)&&e.push(l[n])}k.push(e)}}var M=["toImage"];s.showEditInChartStudio?M.push("editInChartStudio"):s.showSendToCloud&&M.push("sendDataToCloud");T(M);var A=[],S=[],E=[],L=[];(h||v||d||g||m)+p+f+y+x>1?(S=["toggleHover"],E=["resetViews"]):p?(A=["zoomInGeo","zoomOutGeo"],S=["hoverClosestGeo"],E=["resetGeo"]):f?(S=["hoverClosest3d"],E=["resetCameraDefault3d","resetCameraLastSave3d"]):y?(A=["zoomInMapbox","zoomOutMapbox"],S=["toggleHover"],E=["resetViewMapbox"]):v?S=["hoverClosestGl2d"]:d?S=["hoverClosestPie"]:b?(S=["hoverClosestCartesian","hoverCompareCartesian"],E=["resetViewSankey"]):S=["toggleHover"];h&&(S=["toggleSpikelines","hoverClosestCartesian","hoverCompareCartesian"]);(function(t){for(var e=0;e<t.length;e++)if(!i.traceIs(t[e],"noHover"))return!1;return!0}(r)||w)&&(S=[]);!h&&!v||_||(A=["zoomIn2d","zoomOut2d","autoScale2d"],"resetViews"!==E[0]&&(E=["resetScale2d"]));f?L=["zoom3d","pan3d","orbitRotation","tableRotation"]:(h||v)&&!_||m?L=["zoom2d","pan2d"]:y||p?L=["pan2d"]:x&&(L=["zoom2d"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(i.traceIs(n,"scatter-like")?(a.hasMarkers(n)||a.hasText(n))&&(e=!0):i.traceIs(n,"box-violin")&&"all"!==n.boxpoints&&"all"!==n.points||(e=!0))}return e})(r)&&L.push("select2d","lasso2d");return T(L),T(A.concat(E)),T(S),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(k,u)}(t),c?c.update(t,u):e._modeBar=s(t,u)}else c&&(c.destroy(),delete e._modeBar)}},{"../../plots/cartesian/axis_ids":768,"../../registry":846,"../../traces/scatter/subtypes":1144,"../fx/helpers":626,"./buttons":649,"./modebar":652}],652:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../../lib"),o=t("../../fonts/ploticon"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement("div"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,a="modebar-"+n._uid;this.element.setAttribute("id",a),this._uid=a,this.element.className="modebar","hover"===r.displayModeBar&&(this.element.className+=" modebar--hover ease-bg"),"v"===n.modebar.orientation&&(this.element.className+=" vertical",e=e.reverse());var o=n.modebar,s="hover"===r.displayModeBar?".js-plotly-plot .plotly:hover ":"";i.deleteRelatedStyleRule(a),i.addRelatedStyleRule(a,s+"#"+a+" .modebar-group","background-color: "+o.bgcolor),i.addRelatedStyleRule(a,"#"+a+" .modebar-btn .icon path","fill: "+o.color),i.addRelatedStyleRule(a,"#"+a+" .modebar-btn:hover .icon path","fill: "+o.activecolor),i.addRelatedStyleRule(a,"#"+a+" .modebar-btn.active .icon path","fill: "+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var h=this.getLogo();r.watermark&&(h.className=h.className+" watermark"),"v"===n.modebar.orientation?this.element.insertBefore(h,this.element.childNodes[0]):this.element.appendChild(h),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach(function(t){var r=e.createGroup();t.forEach(function(t){var n=t.name;if(!n)throw new Error("must provide button 'name' in button config");if(-1!==e.buttonsNames.indexOf(n))throw new Error("button name '"+n+"' is taken");e.buttonsNames.push(n);var a=e.createButton(t);e.buttonElements.push(a),r.appendChild(a)}),e.element.appendChild(r)})},c.createGroup=function(){var t=document.createElement("div");return t.className="modebar-group",t},c.createButton=function(t){var e=this,r=document.createElement("a");r.setAttribute("rel","tooltip"),r.className="modebar-btn";var a=t.title;void 0===a?a=t.name:"function"==typeof a&&(a=a(this.graphInfo)),(a||0===a)&&r.setAttribute("data-title",a),void 0!==t.attr&&r.setAttribute("data-attr",t.attr);var i=t.val;if(void 0!==i&&("function"==typeof i&&(i=i(this.graphInfo)),r.setAttribute("data-val",i)),"function"!=typeof t.click)throw new Error("must provide button 'click' function in button config");r.addEventListener("click",function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)}),r.setAttribute("data-toggle",t.toggle||!1),t.toggle&&n.select(r).classed("active",!0);var s=t.icon;return"function"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute("data-gravity",t.gravity||"n"),r},c.createIcon=function(t){var e,r=a(t.height)?Number(t.height):t.ascent-t.descent,n="http://www.w3.org/2000/svg";if(t.path){(e=document.createElementNS(n,"svg")).setAttribute("viewBox",[0,0,t.width,r].join(" ")),e.setAttribute("class","icon");var i=document.createElementNS(n,"path");i.setAttribute("d",t.path),t.transform?i.setAttribute("transform",t.transform):void 0!==t.ascent&&i.setAttribute("transform","matrix(1 0 0 -1 0 "+t.ascent+")"),e.appendChild(i)}t.svg&&(e=s.parseFromString(t.svg,"application/xml").childNodes[0]);return e.setAttribute("height","1em"),e.setAttribute("width","1em"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute("data-attr"):null;this.buttonElements.forEach(function(t){var a=t.getAttribute("data-val")||!0,o=t.getAttribute("data-attr"),s="true"===t.getAttribute("data-toggle"),l=n.select(t);if(s)o===r&&l.classed("active",!l.classed("active"));else{var c=null===o?o:i.nestedProperty(e,o).get();l.classed("active",c===a)}})},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement("a");return e.href="https://plotly.com/",e.target="_blank",e.setAttribute("data-title",i._(this.graphInfo,"Produced with Plotly")),e.className="modebar-btn plotlyjsicon modebar-btn--logo",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){i.removeElement(this.container.querySelector(".modebar")),i.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,a=new l({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(a.element).append("span").classed("badge-private float--left",!0).text("PRIVATE"),a}},{"../../fonts/ploticon":697,"../../lib":717,d3:165,"fast-isnumeric":228}],653:[function(t,e,r){"use strict";var n=t("../../plots/font_attributes"),a=t("../color/attributes"),i=(0,t("../../plot_api/plot_template").templatedArray)("button",{visible:{valType:"boolean",dflt:!0,editType:"plot"},step:{valType:"enumerated",values:["month","year","day","hour","minute","second","all"],dflt:"month",editType:"plot"},stepmode:{valType:"enumerated",values:["backward","todate"],dflt:"backward",editType:"plot"},count:{valType:"number",min:0,dflt:1,editType:"plot"},label:{valType:"string",editType:"plot"},editType:"plot"});e.exports={visible:{valType:"boolean",editType:"plot"},buttons:i,x:{valType:"number",min:-2,max:3,editType:"plot"},xanchor:{valType:"enumerated",values:["auto","left","center","right"],dflt:"left",editType:"plot"},y:{valType:"number",min:-2,max:3,editType:"plot"},yanchor:{valType:"enumerated",values:["auto","top","middle","bottom"],dflt:"bottom",editType:"plot"},font:n({editType:"plot"}),bgcolor:{valType:"color",dflt:a.lightLine,editType:"plot"},activecolor:{valType:"color",editType:"plot"},bordercolor:{valType:"color",dflt:a.defaultLine,editType:"plot"},borderwidth:{valType:"number",min:0,dflt:0,editType:"plot"},editType:"plot"}},{"../../plot_api/plot_template":755,"../../plots/font_attributes":791,"../color/attributes":590}],654:[function(t,e,r){"use strict";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],655:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../color"),i=t("../../plot_api/plot_template"),o=t("../../plots/array_container_defaults"),s=t("./attributes"),l=t("./constants");function c(t,e,r,a){var i=a.calendar;function o(r,a){return n.coerce(t,e,s.buttons,r,a)}if(o("visible")){var l=o("step");"all"!==l&&(!i||"gregorian"===i||"month"!==l&&"year"!==l?o("stepmode"):e.stepmode="backward",o("count")),o("label")}}e.exports=function(t,e,r,u,h){var f=t.rangeselector||{},p=i.newContainer(e,"rangeselector");function d(t,e){return n.coerce(f,p,s,t,e)}if(d("visible",o(f,p,{name:"buttons",handleItemDefaults:c,calendar:h}).length>0)){var g=function(t,e,r){for(var n=r.filter(function(r){return e[r].anchor===t._id}),a=0,i=0;i<n.length;i++){var o=e[n[i]].domain;o&&(a=Math.max(o[1],a))}return[t.domain[0],a+l.yPad]}(e,r,u);d("x",g[0]),d("y",g[1]),n.noneOrAll(t,e,["x","y"]),d("xanchor"),d("yanchor"),n.coerceFont(d,"font",r.font);var v=d("bgcolor");d("activecolor",a.contrast(v,l.lightAmount,l.darkAmount)),d("bordercolor"),d("borderwidth")}}},{"../../lib":717,"../../plot_api/plot_template":755,"../../plots/array_container_defaults":761,"../color":591,"./attributes":653,"./constants":654}],656:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../plots/plots"),o=t("../color"),s=t("../drawing"),l=t("../../lib"),c=t("../../lib/svg_text_utils"),u=t("../../plots/cartesian/axis_ids"),h=t("../../constants/alignment"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR,g=t("./constants"),v=t("./get_update_object");function m(t){return t._id}function y(t,e,r){var n=l.ensureSingle(t,"rect","selector-rect",function(t){t.attr("shape-rendering","crispEdges")});n.attr({rx:g.rx,ry:g.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style("stroke-width",e.borderwidth+"px")}function x(t,e,r,n){l.ensureSingle(t,"text","selector-text",function(t){t.classed("user-select-none",!0).attr("text-anchor","middle")}).call(s.font,e.font).text(function(t,e){if(t.label)return e?l.templateString(t.label,e):t.label;return"all"===t.step?"all":t.count+t.step.charAt(0)}(r,n._fullLayout._meta)).call(function(t){c.convertToTspans(t,n)})}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(".rangeselector").data(function(t){for(var e=u.list(t,"x",!0),r=[],n=0;n<e.length;n++){var a=e[n];a.rangeselector&&a.rangeselector.visible&&r.push(a)}return r}(t),m);e.enter().append("g").classed("rangeselector",!0),e.exit().remove(),e.style({cursor:"pointer","pointer-events":"all"}),e.each(function(e){var r=n.select(this),o=e,u=o.rangeselector,h=r.selectAll("g.button").data(l.filterVisible(u.buttons));h.enter().append("g").classed("button",!0),h.exit().remove(),h.each(function(e){var r=n.select(this),i=v(o,e);e._isActive=function(t,e,r){if("all"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,i),r.call(y,u,e),r.call(x,u,e,t),r.on("click",function(){t._dragged||a.call("_guiRelayout",t,i)}),r.on("mouseover",function(){e._isHovered=!0,r.call(y,u,e)}),r.on("mouseout",function(){e._isHovered=!1,r.call(y,u,e)})}),function(t,e,r,a,o){var u=0,h=0,v=r.borderwidth;e.each(function(){var t=n.select(this),e=t.select(".selector-text"),a=r.font.size*f,i=Math.max(a*c.lineCount(e),16)+3;h=Math.max(h,i)}),e.each(function(){var t=n.select(this),e=t.select(".selector-rect"),a=t.select(".selector-text"),i=a.node()&&s.bBox(a.node()).width,o=r.font.size*f,l=c.lineCount(a),p=Math.max(i+10,g.minButtonWidth);t.attr("transform","translate("+(v+u)+","+v+")"),e.attr({x:0,y:0,width:p,height:h}),c.positionText(a,p/2,h/2-(l-1)*o/2+3),u+=p+5});var m=t._fullLayout._size,y=m.l+m.w*r.x,x=m.t+m.h*(1-r.y),b="left";l.isRightAnchor(r)&&(y-=u,b="right");l.isCenterAnchor(r)&&(y-=u/2,b="center");var _="top";l.isBottomAnchor(r)&&(x-=h,_="bottom");l.isMiddleAnchor(r)&&(x-=h/2,_="middle");u=Math.ceil(u),h=Math.ceil(h),y=Math.round(y),x=Math.round(x),i.autoMargin(t,a+"-range-selector",{x:r.x,y:r.y,l:u*p[b],r:u*d[b],b:h*d[_],t:h*p[_]}),o.attr("transform","translate("+y+","+x+")")}(t,h,u,o._name,r)})}},{"../../constants/alignment":686,"../../lib":717,"../../lib/svg_text_utils":741,"../../plots/cartesian/axis_ids":768,"../../plots/plots":826,"../../registry":846,"../color":591,"../drawing":612,"./constants":654,"./get_update_object":657,d3:165}],657:[function(t,e,r){"use strict";var n=t("d3");e.exports=function(t,e){var r=t._name,a={};if("all"===e.step)a[r+".autorange"]=!0;else{var i=function(t,e){var r,a=t.range,i=new Date(t.r2l(a[1])),o=e.step,s=e.count;switch(e.stepmode){case"backward":r=t.l2r(+n.time[o].utc.offset(i,-s));break;case"todate":var l=n.time[o].utc.offset(i,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=a[1];return[r,c]}(t,e);a[r+".range[0]"]=i[0],a[r+".range[1]"]=i[1]}return a}},{d3:165}],658:[function(t,e,r){"use strict";e.exports={moduleType:"component",name:"rangeselector",schema:{subplots:{xaxis:{rangeselector:t("./attributes")}}},layoutAttributes:t("./attributes"),handleDefaults:t("./defaults"),draw:t("./draw")}},{"./attributes":653,"./defaults":655,"./draw":656}],659:[function(t,e,r){"use strict";var n=t("../color/attributes");e.exports={bgcolor:{valType:"color",dflt:n.background,editType:"plot"},bordercolor:{valType:"color",dflt:n.defaultLine,editType:"plot"},borderwidth:{valType:"integer",dflt:0,min:0,editType:"plot"},autorange:{valType:"boolean",dflt:!0,editType:"calc",impliedEdits:{"range[0]":void 0,"range[1]":void 0}},range:{valType:"info_array",items:[{valType:"any",editType:"calc",impliedEdits:{"^autorange":!1}},{valType:"any",editType:"calc",impliedEdits:{"^autorange":!1}}],editType:"calc",impliedEdits:{autorange:!1}},thickness:{valType:"number",dflt:.15,min:0,max:1,editType:"plot"},visible:{valType:"boolean",dflt:!0,editType:"calc"},editType:"calc"}},{"../color/attributes":590}],660:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axis_ids").list,a=t("../../plots/cartesian/autorange").getAutoRange,i=t("./constants");e.exports=function(t){for(var e=n(t,"x",!0),r=0;r<e.length;r++){var o=e[r],s=o[i.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=a(t,o))}}},{"../../plots/cartesian/autorange":764,"../../plots/cartesian/axis_ids":768,"./constants":661}],661:[function(t,e,r){"use strict";e.exports={name:"rangeslider",containerClassName:"rangeslider-container",bgClassName:"rangeslider-bg",rangePlotClassName:"rangeslider-rangeplot",maskMinClassName:"rangeslider-mask-min",maskMaxClassName:"rangeslider-mask-max",slideBoxClassName:"rangeslider-slidebox",grabberMinClassName:"rangeslider-grabber-min",grabAreaMinClassName:"rangeslider-grabarea-min",handleMinClassName:"rangeslider-handle-min",grabberMaxClassName:"rangeslider-grabber-max",grabAreaMaxClassName:"rangeslider-grabarea-max",handleMaxClassName:"rangeslider-handle-max",maskMinOppAxisClassName:"rangeslider-mask-min-opp-axis",maskMaxOppAxisClassName:"rangeslider-mask-max-opp-axis",maskColor:"rgba(0,0,0,0.4)",maskOppAxisColor:"rgba(0,0,0,0.2)",slideBoxFill:"transparent",slideBoxCursor:"ew-resize",grabAreaFill:"transparent",grabAreaCursor:"col-resize",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],662:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plot_api/plot_template"),i=t("../../plots/cartesian/axis_ids"),o=t("./attributes"),s=t("./oppaxis_attributes");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,h,f=l.rangeslider,p=a.newContainer(c,"rangeslider");if(_("visible")){_("bgcolor",e.plot_bgcolor),_("bordercolor"),_("borderwidth"),_("thickness"),_("autorange",!c.isValidRange(f.range)),_("range");var d=e._subplots;if(d)for(var g=d.cartesian.filter(function(t){return t.substr(0,t.indexOf("y"))===i.name2id(r)}).map(function(t){return t.substr(t.indexOf("y"),t.length)}),v=n.simpleMap(g,i.id2name),m=0;m<v.length;m++){var y=v[m];u=f[y]||{},h=a.newContainer(p,y,"yaxis");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x="fixed"),"match"!==w("rangemode",x)&&w("range",b.range.slice())}p._input=f}}function _(t,e){return n.coerce(f,p,o,t,e)}function w(t,e){return n.coerce(u,h,s,t,e)}}},{"../../lib":717,"../../plot_api/plot_template":755,"../../plots/cartesian/axis_ids":768,"./attributes":659,"./oppaxis_attributes":666}],663:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../plots/plots"),o=t("../../lib"),s=t("../drawing"),l=t("../color"),c=t("../titles"),u=t("../../plots/cartesian"),h=t("../../plots/cartesian/axis_ids"),f=t("../dragelement"),p=t("../../lib/setcursor"),d=t("./constants");function g(t,e,r,n){var a=o.ensureSingle(t,"rect",d.bgClassName,function(t){t.attr({x:0,y:0,"shape-rendering":"crispEdges"})}),i=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,l=-n._offsetShift,c=s.crispRound(e,n.borderwidth);a.attr({width:n._width+i,height:n._height+i,transform:"translate("+l+","+l+")",fill:n.bgcolor,stroke:n.bordercolor,"stroke-width":c})}function v(t,e,r,n){var a=e._fullLayout;o.ensureSingleById(a._topdefs,"clipPath",n._clipId,function(t){t.append("rect").attr({x:0,y:0})}).select("rect").attr({width:n._width,height:n._height})}function m(t,e,r,a){var l,c=e.calcdata,f=t.selectAll("g."+d.rangePlotClassName).data(r._subplotsWith,o.identity);f.enter().append("g").attr("class",function(t){return d.rangePlotClassName+" "+t}).call(s.setClipUrl,a._clipId,e),f.order(),f.exit().remove(),f.each(function(t,o){var s=n.select(this),f=0===o,p=h.getFromId(e,t,"y"),d=p._name,g=a[d],v={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:a.range.slice(),calendar:r.calendar},width:a._width,height:a._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};r.rangebreaks&&(v.layout.xaxis.rangebreaks=r.rangebreaks),v.layout[d]={type:p.type,domain:[0,1],range:"match"!==g.rangemode?g.range.slice():p.range.slice(),calendar:p.calendar},p.rangebreaks&&(v.layout[d].rangebreaks=p.rangebreaks),i.supplyDefaults(v);var m=v._fullLayout.xaxis,y=v._fullLayout[d];m.clearCalc(),m.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:s,xaxis:m,yaxis:y,isRangePlot:!0};f?l=x:(x.mainplot="xy",x.mainplotinfo=l),u.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var a=t[n],i=a[0].trace;i.xaxis+i.yaxis===e&&r.push(a)}return r}(c,t))})}function y(t,e,r,n,a){(o.ensureSingle(t,"rect",d.maskMinClassName,function(t){t.attr({x:0,y:0,"shape-rendering":"crispEdges"})}).attr("height",n._height).call(l.fill,d.maskColor),o.ensureSingle(t,"rect",d.maskMaxClassName,function(t){t.attr({y:0,"shape-rendering":"crispEdges"})}).attr("height",n._height).call(l.fill,d.maskColor),"match"!==a.rangemode)&&(o.ensureSingle(t,"rect",d.maskMinOppAxisClassName,function(t){t.attr({y:0,"shape-rendering":"crispEdges"})}).attr("width",n._width).call(l.fill,d.maskOppAxisColor),o.ensureSingle(t,"rect",d.maskMaxOppAxisClassName,function(t){t.attr({y:0,"shape-rendering":"crispEdges"})}).attr("width",n._width).style("border-top",d.maskOppBorder).call(l.fill,d.maskOppAxisColor))}function x(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,"rect",d.slideBoxClassName,function(t){t.attr({y:0,cursor:d.slideBoxCursor,"shape-rendering":"crispEdges"})}).attr({height:n._height,fill:d.slideBoxFill})}function b(t,e,r,n){var a=o.ensureSingle(t,"g",d.grabberMinClassName),i=o.ensureSingle(t,"g",d.grabberMaxClassName),s={x:0,width:d.handleWidth,rx:d.handleRadius,fill:l.background,stroke:l.defaultLine,"stroke-width":d.handleStrokeWidth,"shape-rendering":"crispEdges"},c={y:Math.round(n._height/4),height:Math.round(n._height/2)};if(o.ensureSingle(a,"rect",d.handleMinClassName,function(t){t.attr(s)}).attr(c),o.ensureSingle(i,"rect",d.handleMaxClassName,function(t){t.attr(s)}).attr(c),!e._context.staticPlot){var u={width:d.grabAreaWidth,x:0,y:0,fill:d.grabAreaFill,cursor:d.grabAreaCursor};o.ensureSingle(a,"rect",d.grabAreaMinClassName,function(t){t.attr(u)}).attr("height",n._height),o.ensureSingle(i,"rect",d.grabAreaMaxClassName,function(t){t.attr(u)}).attr("height",n._height)}}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,i=0;i<r.length;i++){var s=r[i][d.name];s._clipId=s._id+"-"+e._uid}var l=e._infolayer.selectAll("g."+d.containerClassName).data(r,function(t){return t._name});l.exit().each(function(t){var r=t[d.name];e._topdefs.select("#"+r._clipId).remove()}).remove(),0!==r.length&&(l.enter().append("g").classed(d.containerClassName,!0).attr("pointer-events","all"),l.each(function(r){var i=n.select(this),s=r[d.name],l=e[h.id2name(r.anchor)],u=s[h.id2name(r.anchor)];if(s.range){var _,w=o.simpleMap(s.range,r.r2l),k=o.simpleMap(r.range,r.r2l);_=k[0]<k[1]?[Math.min(w[0],k[0]),Math.max(w[1],k[1])]:[Math.max(w[0],k[0]),Math.min(w[1],k[1])],s.range=s._input.range=o.simpleMap(_,r.l2r)}r.cleanRange("rangeslider.range");var T=e._size,M=r.domain;s._width=T.w*(M[1]-M[0]);var A=Math.round(T.l+T.w*M[0]),S=Math.round(T.t+T.h*(1-r._counterDomainMin)+("bottom"===r.side?r._depth:0)+s._offsetShift+d.extraPad);i.attr("transform","translate("+A+","+S+")"),s._rl=o.simpleMap(s.range,r.r2l);var E=s._rl[0],L=s._rl[1],C=L-E;if(s.p2d=function(t){return t/s._width*C+E},s.d2p=function(t){return(t-E)/C*s._width},r.rangebreaks){var P=r.locateBreaks(E,L);if(P.length){var O,z,I=0;for(O=0;O<P.length;O++)I+=(z=P[O]).max-z.min;var D=s._width/(L-E-I),R=[-D*E];for(O=0;O<P.length;O++)z=P[O],R.push(R[R.length-1]-D*(z.max-z.min));for(s.d2p=function(t){for(var e=R[0],r=0;r<P.length;r++){var n=P[r];if(t>=n.max)e=R[r+1];else if(t<n.min)break}return e+D*t},O=0;O<P.length;O++)(z=P[O]).pmin=s.d2p(z.min),z.pmax=s.d2p(z.max);s.p2d=function(t){for(var e=R[0],r=0;r<P.length;r++){var n=P[r];if(t>=n.pmax)e=R[r+1];else if(t<n.pmin)break}return(t-e)/D}}}if("match"!==u.rangemode){var F=l.r2l(u.range[0]),B=l.r2l(u.range[1])-F;s.d2pOppAxis=function(t){return(t-F)/B*s._height}}i.call(g,t,r,s).call(v,t,r,s).call(m,t,r,s).call(y,t,r,s,u).call(x,t,r,s).call(b,t,r,s),function(t,e,r,i){var s=t.select("rect."+d.slideBoxClassName).node(),l=t.select("rect."+d.grabAreaMinClassName).node(),c=t.select("rect."+d.grabAreaMaxClassName).node();t.on("mousedown",function(){var u=n.event,h=u.target,d=u.clientX,g=d-t.node().getBoundingClientRect().left,v=i.d2p(r._rl[0]),m=i.d2p(r._rl[1]),y=f.coverSlip();function x(t){var u,f,x,b=+t.clientX-d;switch(h){case s:x="ew-resize",u=v+b,f=m+b;break;case l:x="col-resize",u=v+b,f=m;break;case c:x="col-resize",u=v,f=m+b;break;default:x="ew-resize",u=g,f=g+b}if(f<u){var _=f;f=u,u=_}i._pixelMin=u,i._pixelMax=f,p(n.select(y),x),function(t,e,r,n){function i(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=i(n.p2d(n._pixelMin)),l=i(n.p2d(n._pixelMax));window.requestAnimationFrame(function(){a.call("_guiRelayout",e,r._name+".range",[s,l])})}(0,e,r,i)}y.addEventListener("mousemove",x),y.addEventListener("mouseup",function t(){y.removeEventListener("mousemove",x);y.removeEventListener("mouseup",t);o.removeElement(y)})})}(i,t,r,s),function(t,e,r,n,a,i){var s=d.handleWidth/2;function l(t){return o.constrain(t,0,n._width)}function c(t){return o.constrain(t,0,n._height)}function u(t){return o.constrain(t,-s,n._width+s)}var h=l(n.d2p(r._rl[0])),f=l(n.d2p(r._rl[1]));if(t.select("rect."+d.slideBoxClassName).attr("x",h).attr("width",f-h),t.select("rect."+d.maskMinClassName).attr("width",h),t.select("rect."+d.maskMaxClassName).attr("x",f).attr("width",n._width-f),"match"!==i.rangemode){var p=n._height-c(n.d2pOppAxis(a._rl[1])),g=n._height-c(n.d2pOppAxis(a._rl[0]));t.select("rect."+d.maskMinOppAxisClassName).attr("x",h).attr("height",p).attr("width",f-h),t.select("rect."+d.maskMaxOppAxisClassName).attr("x",h).attr("y",g).attr("height",n._height-g).attr("width",f-h),t.select("rect."+d.slideBoxClassName).attr("y",p).attr("height",g-p)}var v=Math.round(u(h-s))-.5,m=Math.round(u(f-s))+.5;t.select("g."+d.grabberMinClassName).attr("transform","translate("+v+",0.5)"),t.select("g."+d.grabberMaxClassName).attr("transform","translate("+m+",0.5)")}(i,0,r,s,l,u),"bottom"===r.side&&c.draw(t,r._id+"title",{propContainer:r,propName:r._name+".title",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:S+s._height+s._offsetShift+10+1.5*r.title.font.size,"text-anchor":"middle"}})}))}},{"../../lib":717,"../../lib/setcursor":737,"../../plots/cartesian":776,"../../plots/cartesian/axis_ids":768,"../../plots/plots":826,"../../registry":846,"../color":591,"../dragelement":609,"../drawing":612,"../titles":679,"./constants":661,d3:165}],664:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axis_ids"),a=t("../../lib/svg_text_utils"),i=t("./constants"),o=t("../../constants/alignment").LINE_SPACING,s=i.name;function l(t){var e=t&&t[s];return e&&e.visible}r.isVisible=l,r.makeData=function(t){var e=n.list({_fullLayout:t},"x",!0),r=t.margin,a=[];if(!t._has("gl2d"))for(var i=0;i<e.length;i++){var o=e[i];if(l(o)){a.push(o);var c=o[s];c._id=s+o._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=a},r.autoMarginOpts=function(t,e){var r=t._fullLayout,n=e[s],l=e._id.charAt(0),c=0,u=0;"bottom"===e.side&&(c=e._depth,e.title.text!==r._dfltTitle[l]&&(u=1.5*e.title.font.size+10+n._offsetShift,u+=(e.title.text.match(a.BR_TAG_ALL)||[]).length*e.title.font.size*o));return{x:0,y:e._counterDomainMin,l:0,r:0,t:0,b:n._height+c+Math.max(r.margin.b,u),pad:i.extraPad+2*n._offsetShift}}},{"../../constants/alignment":686,"../../lib/svg_text_utils":741,"../../plots/cartesian/axis_ids":768,"./constants":661}],665:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("./oppaxis_attributes"),o=t("./helpers");e.exports={moduleType:"component",name:"rangeslider",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},a,{yaxis:i})}}},layoutAttributes:t("./attributes"),handleDefaults:t("./defaults"),calcAutorange:t("./calc_autorange"),draw:t("./draw"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{"../../lib":717,"./attributes":659,"./calc_autorange":660,"./defaults":662,"./draw":663,"./helpers":664,"./oppaxis_attributes":666}],666:[function(t,e,r){"use strict";e.exports={_isSubplotObj:!0,rangemode:{valType:"enumerated",values:["auto","fixed","match"],dflt:"match",editType:"calc"},range:{valType:"info_array",items:[{valType:"any",editType:"plot"},{valType:"any",editType:"plot"}],editType:"plot"},editType:"calc"}},{}],667:[function(t,e,r){"use strict";var n=t("../annotations/attributes"),a=t("../../traces/scatter/attributes").line,i=t("../drawing/attributes").dash,o=t("../../lib/extend").extendFlat,s=t("../../plot_api/plot_template").templatedArray;e.exports=s("shape",{visible:{valType:"boolean",dflt:!0,editType:"calc+arraydraw"},type:{valType:"enumerated",values:["circle","rect","path","line"],editType:"calc+arraydraw"},layer:{valType:"enumerated",values:["below","above"],dflt:"above",editType:"arraydraw"},xref:o({},n.xref,{}),xsizemode:{valType:"enumerated",values:["scaled","pixel"],dflt:"scaled",editType:"calc+arraydraw"},xanchor:{valType:"any",editType:"calc+arraydraw"},x0:{valType:"any",editType:"calc+arraydraw"},x1:{valType:"any",editType:"calc+arraydraw"},yref:o({},n.yref,{}),ysizemode:{valType:"enumerated",values:["scaled","pixel"],dflt:"scaled",editType:"calc+arraydraw"},yanchor:{valType:"any",editType:"calc+arraydraw"},y0:{valType:"any",editType:"calc+arraydraw"},y1:{valType:"any",editType:"calc+arraydraw"},path:{valType:"string",editType:"calc+arraydraw"},opacity:{valType:"number",min:0,max:1,dflt:1,editType:"arraydraw"},line:{color:o({},a.color,{editType:"arraydraw"}),width:o({},a.width,{editType:"calc+arraydraw"}),dash:o({},i,{editType:"arraydraw"}),editType:"calc+arraydraw"},fillcolor:{valType:"color",dflt:"rgba(0,0,0,0)",editType:"arraydraw"},editType:"arraydraw"})},{"../../lib/extend":708,"../../plot_api/plot_template":755,"../../traces/scatter/attributes":1120,"../annotations/attributes":574,"../drawing/attributes":611}],668:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("./constants"),o=t("./helpers");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,a,s,l){var c=t/2,u=l;if("pixel"===e){var h=s?o.extractPathCoords(s,l?i.paramIsY:i.paramIsX):[r,a],f=n.aggNums(Math.max,null,h),p=n.aggNums(Math.min,null,h),d=p<0?Math.abs(p)+c:c,g=f>0?f+c:c;return{ppad:c,ppadplus:u?d:g,ppadminus:u?g:d}}return{ppad:c}}function u(t,e,r,n,a){var s="category"===t.type||"multicategory"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,h,f=1/0,p=-1/0,d=n.match(i.segmentRE);for("date"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=a[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(i.paramRE))||u.length<c||((h=s(u[c]))<f&&(f=h),h>p&&(p=h)));return p>=f?[f,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,h,f=r[o];if(f._extremes={},"paper"!==f.xref){var p="pixel"===f.xsizemode?f.xanchor:f.x0,d="pixel"===f.xsizemode?f.xanchor:f.x1;(h=u(c=a.getFromId(t,f.xref),p,d,f.path,i.paramIsX))&&(f._extremes[c._id]=a.findExtremes(c,h,s(f)))}if("paper"!==f.yref){var g="pixel"===f.ysizemode?f.yanchor:f.y0,v="pixel"===f.ysizemode?f.yanchor:f.y1;(h=u(c=a.getFromId(t,f.yref),g,v,f.path,i.paramIsY))&&(f._extremes[c._id]=a.findExtremes(c,h,l(f)))}}}},{"../../lib":717,"../../plots/cartesian/axes":765,"./constants":669,"./helpers":672}],669:[function(t,e,r){"use strict";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],670:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../../plots/array_container_defaults"),o=t("./attributes"),s=t("./helpers");function l(t,e,r){function i(r,a){return n.coerce(t,e,o,r,a)}if(i("visible")){i("layer"),i("opacity"),i("fillcolor"),i("line.color"),i("line.width"),i("line.dash");for(var l=i("type",t.path?"path":"rect"),c=i("xsizemode"),u=i("ysizemode"),h=["x","y"],f=0;f<2;f++){var p,d,g,v=h[f],m=v+"anchor",y="x"===v?c:u,x={_fullLayout:r},b=a.coerceRef(t,e,x,v,"","paper");if("paper"!==b?((p=a.getFromId(x,b))._shapeIndices.push(e._index),g=s.rangeToShapePosition(p),d=s.shapePositionToRange(p)):d=g=n.identity,"path"!==l){var _=v+"0",w=v+"1",k=t[_],T=t[w];t[_]=d(t[_],!0),t[w]=d(t[w],!0),"pixel"===y?(i(_,0),i(w,10)):(a.coercePosition(e,x,i,b,_,.25),a.coercePosition(e,x,i,b,w,.75)),e[_]=g(e[_]),e[w]=g(e[w]),t[_]=k,t[w]=T}if("pixel"===y){var M=t[m];t[m]=d(t[m],!0),a.coercePosition(e,x,i,b,m,.25),e[m]=g(e[m]),t[m]=M}}"path"===l?i("path"):n.noneOrAll(t,e,["x0","x1","y0","y1"])}}e.exports=function(t,e){i(t,e,{name:"shapes",handleItemDefaults:l})}},{"../../lib":717,"../../plots/array_container_defaults":761,"../../plots/cartesian/axes":765,"./attributes":667,"./helpers":672}],671:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("../../plots/cartesian/axes"),o=t("../color"),s=t("../drawing"),l=t("../../plot_api/plot_template").arrayEditor,c=t("../dragelement"),u=t("../../lib/setcursor"),h=t("./constants"),f=t("./helpers");function p(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index="'+e+'"]').remove();var r=t._fullLayout.shapes[e]||{};if(r._input&&!1!==r.visible)if("below"!==r.layer)m(t._fullLayout._shapeUpperLayer);else if("paper"===r.xref||"paper"===r.yref)m(t._fullLayout._shapeLowerLayer);else{var p=t._fullLayout._plots[r.xref+r.yref];if(p)m((p.mainplotinfo||p).shapelayer);else m(t._fullLayout._shapeLowerLayer)}function m(p){var m={"data-index":e,"fill-rule":"evenodd",d:g(t,r)},y=r.line.width?r.line.color:"rgba(0,0,0,0)",x=p.append("path").attr(m).style("opacity",r.opacity).call(o.stroke,y).call(o.fill,r.fillcolor).call(s.dashLine,r.line.dash,r.line.width);d(x,t,r),t._context.edits.shapePosition&&function(t,e,r,o,p){var m,y,x,b,_,w,k,T,M,A,S,E,L,C,P,O,z=10,I=10,D="pixel"===r.xsizemode,R="pixel"===r.ysizemode,F="line"===r.type,B="path"===r.type,N=l(t.layout,"shapes",r),j=N.modifyItem,V=i.getFromId(t,r.xref),U=i.getFromId(t,r.yref),q=f.getDataToPixel(t,V),H=f.getDataToPixel(t,U,!0),G=f.getPixelToData(t,V),Y=f.getPixelToData(t,U,!0),W=F?function(){var t=Math.max(r.line.width,10),n=p.append("g").attr("data-index",o);n.append("path").attr("d",e.attr("d")).style({cursor:"move","stroke-width":t,"stroke-opacity":"0"});var a={"fill-opacity":"0"},i=t/2>10?t/2:10;return n.append("circle").attr({"data-line-point":"start-point",cx:D?q(r.xanchor)+r.x0:q(r.x0),cy:R?H(r.yanchor)-r.y0:H(r.y0),r:i}).style(a).classed("cursor-grab",!0),n.append("circle").attr({"data-line-point":"end-point",cx:D?q(r.xanchor)+r.x1:q(r.x1),cy:R?H(r.yanchor)-r.y1:H(r.y1),r:i}).style(a).classed("cursor-grab",!0),n}():e,X={element:W.node(),gd:t,prepFn:function(n){D&&(_=q(r.xanchor));R&&(w=H(r.yanchor));"path"===r.type?P=r.path:(m=D?r.x0:q(r.x0),y=R?r.y0:H(r.y0),x=D?r.x1:q(r.x1),b=R?r.y1:H(r.y1));m<x?(M=m,L="x0",A=x,C="x1"):(M=x,L="x1",A=m,C="x0");!R&&y<b||R&&y>b?(k=y,S="y0",T=b,E="y1"):(k=b,S="y1",T=y,E="y0");Z(n),Q(p,r),function(t,e,r){var n=e.xref,a=e.yref,o=i.getFromId(r,n),l=i.getFromId(r,a),c="";"paper"===n||o.autorange||(c+=n);"paper"===a||l.autorange||(c+=a);s.setClipUrl(t,c?"clip"+r._fullLayout._uid+c:null,r)}(e,r,t),X.moveFn="move"===O?J:K},doneFn:function(){u(e),$(p),d(e,t,r),n.call("_guiRelayout",t,N.getUpdateObj())},clickFn:function(){$(p)}};function Z(t){if(F)O="path"===t.target.tagName?"move":"start-point"===t.target.attributes["data-line-point"].value?"resize-over-start-point":"resize-over-end-point";else{var r=X.element.getBoundingClientRect(),n=r.right-r.left,a=r.bottom-r.top,i=t.clientX-r.left,o=t.clientY-r.top,s=!B&&n>z&&a>I&&!t.shiftKey?c.getCursor(i/n,1-o/a):"move";u(e,s),O=s.split("-")[0]}}function J(n,a){if("path"===r.type){var i=function(t){return t},o=i,s=i;D?j("xanchor",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},V&&"date"===V.type&&(o=f.encodeDate(o))),R?j("yanchor",r.yanchor=Y(w+a)):(s=function(t){return Y(H(t)+a)},U&&"date"===U.type&&(s=f.encodeDate(s))),j("path",r.path=v(P,o,s))}else D?j("xanchor",r.xanchor=G(_+n)):(j("x0",r.x0=G(m+n)),j("x1",r.x1=G(x+n))),R?j("yanchor",r.yanchor=Y(w+a)):(j("y0",r.y0=Y(y+a)),j("y1",r.y1=Y(b+a)));e.attr("d",g(t,r)),Q(p,r)}function K(n,a){if(B){var i=function(t){return t},o=i,s=i;D?j("xanchor",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},V&&"date"===V.type&&(o=f.encodeDate(o))),R?j("yanchor",r.yanchor=Y(w+a)):(s=function(t){return Y(H(t)+a)},U&&"date"===U.type&&(s=f.encodeDate(s))),j("path",r.path=v(P,o,s))}else if(F){if("resize-over-start-point"===O){var l=m+n,c=R?y-a:y+a;j("x0",r.x0=D?l:G(l)),j("y0",r.y0=R?c:Y(c))}else if("resize-over-end-point"===O){var u=x+n,h=R?b-a:b+a;j("x1",r.x1=D?u:G(u)),j("y1",r.y1=R?h:Y(h))}}else{var d=~O.indexOf("n")?k+a:k,N=~O.indexOf("s")?T+a:T,W=~O.indexOf("w")?M+n:M,X=~O.indexOf("e")?A+n:A;~O.indexOf("n")&&R&&(d=k-a),~O.indexOf("s")&&R&&(N=T-a),(!R&&N-d>I||R&&d-N>I)&&(j(S,r[S]=R?d:Y(d)),j(E,r[E]=R?N:Y(N))),X-W>z&&(j(L,r[L]=D?W:G(W)),j(C,r[C]=D?X:G(X)))}e.attr("d",g(t,r)),Q(p,r)}function Q(t,e){(D||R)&&function(){var r="path"!==e.type,n=t.selectAll(".visual-cue").data([0]);n.enter().append("path").attr({fill:"#fff","fill-rule":"evenodd",stroke:"#000","stroke-width":1}).classed("visual-cue",!0);var i=q(D?e.xanchor:a.midRange(r?[e.x0,e.x1]:f.extractPathCoords(e.path,h.paramIsX))),o=H(R?e.yanchor:a.midRange(r?[e.y0,e.y1]:f.extractPathCoords(e.path,h.paramIsY)));if(i=f.roundPositionForSharpStrokeRendering(i,1),o=f.roundPositionForSharpStrokeRendering(o,1),D&&R){var s="M"+(i-1-1)+","+(o-1-1)+"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z";n.attr("d",s)}else if(D){var l="M"+(i-1-1)+","+(o-9-1)+"v18 h2 v-18 Z";n.attr("d",l)}else{var c="M"+(i-9-1)+","+(o-1-1)+"h18 v2 h-18 Z";n.attr("d",c)}}()}function $(t){t.selectAll(".visual-cue").remove()}c.init(X),W.node().onmousemove=Z}(t,x,r,e,p)}}function d(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,"");s.setClipUrl(t,n?"clip"+e._fullLayout._uid+n:null,e)}function g(t,e){var r,n,o,s,l,c,u,p,d=e.type,g=i.getFromId(t,e.xref),v=i.getFromId(t,e.yref),m=t._fullLayout._size;if(g?(r=f.shapePositionToRange(g),n=function(t){return g._offset+g.r2p(r(t,!0))}):n=function(t){return m.l+m.w*t},v?(o=f.shapePositionToRange(v),s=function(t){return v._offset+v.r2p(o(t,!0))}):s=function(t){return m.t+m.h*(1-t)},"path"===d)return g&&"date"===g.type&&(n=f.decodeDate(n)),v&&"date"===v.type&&(s=f.decodeDate(s)),function(t,e,r){var n=t.path,i=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(h.segmentRE,function(t){var n=0,c=t.charAt(0),u=h.paramIsX[c],f=h.paramIsY[c],p=h.numParams[c],d=t.substr(1).replace(h.paramRE,function(t){return u[n]?t="pixel"===i?e(s)+Number(t):e(t):f[n]&&(t="pixel"===o?r(l)-Number(t):r(t)),++n>p&&(t="X"),t});return n>p&&(d=d.replace(/[\s,]*X.*/,""),a.log("Ignoring extra params in segment "+t)),c+d})}(e,n,s);if("pixel"===e.xsizemode){var y=n(e.xanchor);l=y+e.x0,c=y+e.x1}else l=n(e.x0),c=n(e.x1);if("pixel"===e.ysizemode){var x=s(e.yanchor);u=x-e.y0,p=x-e.y1}else u=s(e.y0),p=s(e.y1);if("line"===d)return"M"+l+","+u+"L"+c+","+p;if("rect"===d)return"M"+l+","+u+"H"+c+"V"+p+"H"+l+"Z";var b=(l+c)/2,_=(u+p)/2,w=Math.abs(b-l),k=Math.abs(_-u),T="A"+w+","+k,M=b+w+","+_;return"M"+M+T+" 0 1,1 "+(b+","+(_-k))+T+" 0 0,1 "+M+"Z"}function v(t,e,r){return t.replace(h.segmentRE,function(t){var n=0,a=t.charAt(0),i=h.paramIsX[a],o=h.paramIsY[a],s=h.numParams[a];return a+t.substr(1).replace(h.paramRE,function(t){return n>=s?t:(i[n]?t=e(t):o[n]&&(t=r(t)),n++,t)})})}e.exports={draw:function(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll("path").remove(),e._shapeLowerLayer.selectAll("path").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll("path").remove()}for(var a=0;a<e.shapes.length;a++)e.shapes[a].visible&&p(t,a)},drawOne:p}},{"../../lib":717,"../../lib/setcursor":737,"../../plot_api/plot_template":755,"../../plots/cartesian/axes":765,"../../registry":846,"../color":591,"../dragelement":609,"../drawing":612,"./constants":669,"./helpers":672}],672:[function(t,e,r){"use strict";var n=t("./constants"),a=t("../../lib");r.rangeToShapePosition=function(t){return"log"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return"log"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace("_"," ")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(" ","_")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach(function(t){var i=e[t.charAt(0)].drawn;if(void 0!==i){var o=t.substr(1).match(n.paramRE);!o||o.length<i||r.push(a.cleanNumber(o[i]))}}),r},r.getDataToPixel=function(t,e,n){var a,i=t._fullLayout._size;if(e){var o=r.shapePositionToRange(e);a=function(t){return e._offset+e.r2p(o(t,!0))},"date"===e.type&&(a=r.decodeDate(a))}else a=n?function(t){return i.t+i.h*(1-t)}:function(t){return i.l+i.w*t};return a},r.getPixelToData=function(t,e,n){var a,i=t._fullLayout._size;if(e){var o=r.rangeToShapePosition(e);a=function(t){return o(e.p2r(t-e._offset))}}else a=n?function(t){return 1-(t-i.t)/i.h}:function(t){return(t-i.l)/i.w};return a},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n}},{"../../lib":717,"./constants":669}],673:[function(t,e,r){"use strict";var n=t("./draw");e.exports={moduleType:"component",name:"shapes",layoutAttributes:t("./attributes"),supplyLayoutDefaults:t("./defaults"),includeBasePlot:t("../../plots/cartesian/include_components")("shapes"),calcAutorange:t("./calc_autorange"),draw:n.draw,drawOne:n.drawOne}},{"../../plots/cartesian/include_components":775,"./attributes":667,"./calc_autorange":668,"./defaults":670,"./draw":671}],674:[function(t,e,r){"use strict";var n=t("../../plots/font_attributes"),a=t("../../plots/pad_attributes"),i=t("../../lib/extend").extendDeepAll,o=t("../../plot_api/edit_types").overrideAll,s=t("../../plots/animation_attributes"),l=t("../../plot_api/plot_template").templatedArray,c=t("./constants"),u=l("step",{visible:{valType:"boolean",dflt:!0},method:{valType:"enumerated",values:["restyle","relayout","animate","update","skip"],dflt:"restyle"},args:{valType:"info_array",freeLength:!0,items:[{valType:"any"},{valType:"any"},{valType:"any"}]},label:{valType:"string"},value:{valType:"string"},execute:{valType:"boolean",dflt:!0}});e.exports=o(l("slider",{visible:{valType:"boolean",dflt:!0},active:{valType:"number",min:0,dflt:0},steps:u,lenmode:{valType:"enumerated",values:["fraction","pixels"],dflt:"fraction"},len:{valType:"number",min:0,dflt:1},x:{valType:"number",min:-2,max:3,dflt:0},pad:i(a({editType:"arraydraw"}),{},{t:{dflt:20}}),xanchor:{valType:"enumerated",values:["auto","left","center","right"],dflt:"left"},y:{valType:"number",min:-2,max:3,dflt:0},yanchor:{valType:"enumerated",values:["auto","top","middle","bottom"],dflt:"top"},transition:{duration:{valType:"number",min:0,dflt:150},easing:{valType:"enumerated",values:s.transition.easing.values,dflt:"cubic-in-out"}},currentvalue:{visible:{valType:"boolean",dflt:!0},xanchor:{valType:"enumerated",values:["left","center","right"],dflt:"left"},offset:{valType:"number",dflt:10},prefix:{valType:"string"},suffix:{valType:"string"},font:n({})},font:n({}),activebgcolor:{valType:"color",dflt:c.gripBgActiveColor},bgcolor:{valType:"color",dflt:c.railBgColor},bordercolor:{valType:"color",dflt:c.railBorderColor},borderwidth:{valType:"number",min:0,dflt:c.railBorderWidth},ticklen:{valType:"number",min:0,dflt:c.tickLength},tickcolor:{valType:"color",dflt:c.tickColor},tickwidth:{valType:"number",min:0,dflt:1},minorticklen:{valType:"number",min:0,dflt:c.minorTickLength}}),"arraydraw","from-root")},{"../../lib/extend":708,"../../plot_api/edit_types":748,"../../plot_api/plot_template":755,"../../plots/animation_attributes":760,"../../plots/font_attributes":791,"../../plots/pad_attributes":825,"./constants":675}],675:[function(t,e,r){"use strict";e.exports={name:"sliders",containerClassName:"slider-container",groupClassName:"slider-group",inputAreaClass:"slider-input-area",railRectClass:"slider-rail-rect",railTouchRectClass:"slider-rail-touch-rect",gripRectClass:"slider-grip-rect",tickRectClass:"slider-tick-rect",inputProxyClass:"slider-input-proxy",labelsClass:"slider-labels",labelGroupClass:"slider-label-group",labelClass:"slider-label",currentValueClass:"slider-current-value",railHeight:5,menuIndexAttrName:"slider-active-index",autoMarginIdRoot:"slider-",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:"#bec8d9",railBgColor:"#f8fafc",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:"#bec8d9",gripBgColor:"#f6f8fa",gripBgActiveColor:"#dbdde0",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:"#333",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:"#333",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],676:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/array_container_defaults"),i=t("./attributes"),o=t("./constants").name,s=i.steps;function l(t,e,r){function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=a(t,e,{name:"steps",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o("visible")){e._stepCount=l;var h=e._visibleSteps=n.filterVisible(s);(s[o("active")]||{}).visible||(e.active=h[0]._index),o("x"),o("y"),n.noneOrAll(t,e,["x","y"]),o("xanchor"),o("yanchor"),o("len"),o("lenmode"),o("pad.t"),o("pad.r"),o("pad.b"),o("pad.l"),n.coerceFont(o,"font",r.font),o("currentvalue.visible")&&(o("currentvalue.xanchor"),o("currentvalue.prefix"),o("currentvalue.suffix"),o("currentvalue.offset"),n.coerceFont(o,"currentvalue.font",e.font)),o("transition.duration"),o("transition.easing"),o("bgcolor"),o("activebgcolor"),o("bordercolor"),o("borderwidth"),o("ticklen"),o("tickwidth"),o("tickcolor"),o("minorticklen")}}function c(t,e){function r(r,a){return n.coerce(t,e,s,r,a)}if("skip"===t.method||Array.isArray(t.args)?r("visible"):e.visible=!1){r("method"),r("args");var a=r("label","step-"+e._index);r("value",a),r("execute")}}e.exports=function(t,e){a(t,e,{name:o,handleItemDefaults:l})}},{"../../lib":717,"../../plots/array_container_defaults":761,"./attributes":674,"./constants":675}],677:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../plots/plots"),i=t("../color"),o=t("../drawing"),s=t("../../lib"),l=t("../../lib/svg_text_utils"),c=t("../../plot_api/plot_template").arrayEditor,u=t("./constants"),h=t("../../constants/alignment"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR;function g(t){return u.autoMarginIdRoot+t._index}function v(t){return t._index}function m(t,e){var r=o.tester.selectAll("g."+u.labelGroupClass).data(e._visibleSteps);r.enter().append("g").classed(u.labelGroupClass,!0);var i=0,c=0;r.each(function(t){var r=b(n.select(this),{step:t},e).node();if(r){var a=o.bBox(r);c=Math.max(c,a.height),i=Math.max(i,a.width)}}),r.remove();var h=e._dims={};h.inputAreaWidth=Math.max(u.railWidth,u.gripHeight);var f=t._fullLayout._size;h.lx=f.l+f.w*e.x,h.ly=f.t+f.h*(1-e.y),"fraction"===e.lenmode?h.outerLength=Math.round(f.w*e.len):h.outerLength=e.len,h.inputAreaStart=0,h.inputAreaLength=Math.round(h.outerLength-e.pad.l-e.pad.r);var v=(h.inputAreaLength-2*u.stepInset)/(e._stepCount-1),m=i+u.labelPadding;if(h.labelStride=Math.max(1,Math.ceil(m/v)),h.labelHeight=c,h.currentValueMaxWidth=0,h.currentValueHeight=0,h.currentValueTotalHeight=0,h.currentValueMaxLines=1,e.currentvalue.visible){var x=o.tester.append("g");r.each(function(t){var r=y(x,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},a=l.lineCount(r);h.currentValueMaxWidth=Math.max(h.currentValueMaxWidth,Math.ceil(n.width)),h.currentValueHeight=Math.max(h.currentValueHeight,Math.ceil(n.height)),h.currentValueMaxLines=Math.max(h.currentValueMaxLines,a)}),h.currentValueTotalHeight=h.currentValueHeight+e.currentvalue.offset,x.remove()}h.height=h.currentValueTotalHeight+u.tickOffset+e.ticklen+u.labelOffset+h.labelHeight+e.pad.t+e.pad.b;var _="left";s.isRightAnchor(e)&&(h.lx-=h.outerLength,_="right"),s.isCenterAnchor(e)&&(h.lx-=h.outerLength/2,_="center");var w="top";s.isBottomAnchor(e)&&(h.ly-=h.height,w="bottom"),s.isMiddleAnchor(e)&&(h.ly-=h.height/2,w="middle"),h.outerLength=Math.ceil(h.outerLength),h.height=Math.ceil(h.height),h.lx=Math.round(h.lx),h.ly=Math.round(h.ly);var k={y:e.y,b:h.height*d[w],t:h.height*p[w]};"fraction"===e.lenmode?(k.l=0,k.xl=e.x-e.len*p[_],k.r=0,k.xr=e.x+e.len*d[_]):(k.x=e.x,k.l=h.outerLength*p[_],k.r=h.outerLength*d[_]),a.autoMargin(t,g(e),k)}function y(t,e,r){if(e.currentvalue.visible){var n,a,i=e._dims;switch(e.currentvalue.xanchor){case"right":n=i.inputAreaLength-u.currentValueInset-i.currentValueMaxWidth,a="left";break;case"center":n=.5*i.inputAreaLength,a="middle";break;default:n=u.currentValueInset,a="left"}var c=s.ensureSingle(t,"text",u.labelClass,function(t){t.classed("user-select-none",!0).attr({"text-anchor":a,"data-notex":1})}),h=e.currentvalue.prefix?e.currentvalue.prefix:"";if("string"==typeof r)h+=r;else{var p=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(p=s.templateString(p,d)),h+=p}e.currentvalue.suffix&&(h+=e.currentvalue.suffix),c.call(o.font,e.currentvalue.font).text(h).call(l.convertToTspans,e._gd);var g=l.lineCount(c),v=(i.currentValueMaxLines+1-g)*e.currentvalue.font.size*f;return l.positionText(c,n,v),c}}function x(t,e,r){s.ensureSingle(t,"rect",u.gripRectClass,function(n){n.call(T,e,t,r).style("pointer-events","all")}).attr({width:u.gripWidth,height:u.gripHeight,rx:u.gripRadius,ry:u.gripRadius}).call(i.stroke,r.bordercolor).call(i.fill,r.bgcolor).style("stroke-width",r.borderwidth+"px")}function b(t,e,r){var n=s.ensureSingle(t,"text",u.labelClass,function(t){t.classed("user-select-none",!0).attr({"text-anchor":"middle","data-notex":1})}),a=e.step.label,i=r._gd._fullLayout._meta;return i&&(a=s.templateString(a,i)),n.call(o.font,r.font).text(a).call(l.convertToTspans,r._gd),n}function _(t,e){var r=s.ensureSingle(t,"g",u.labelsClass),a=e._dims,i=r.selectAll("g."+u.labelGroupClass).data(a.labelSteps);i.enter().append("g").classed(u.labelGroupClass,!0),i.exit().remove(),i.each(function(t){var r=n.select(this);r.call(b,t,e),o.setTranslate(r,S(e,t.fraction),u.tickOffset+e.ticklen+e.font.size*f+u.labelOffset+a.currentValueTotalHeight)})}function w(t,e,r,n,a){var i=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[i]._index;o!==r.active&&k(t,e,r,o,!0,a)}function k(t,e,r,n,i,o){var s=r.active;r.active=n,c(t.layout,u.name,r).applyUpdate("active",n);var l=r.steps[r.active];e.call(A,r,o),e.call(y,r),t.emit("plotly_sliderchange",{slider:r,step:r.steps[r.active],interaction:i,previousActive:s}),l&&l.method&&i&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=i,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:i,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame(function(){var r=e._nextMethod.step;r.method&&(r.execute&&a.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)})))}function T(t,e,r){var a=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on("mousedown",function(){var t=s();e.emit("plotly_sliderstart",{slider:t});var l=r.select("."+u.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(i.fill,t.activebgcolor);var c=E(t,n.mouse(a)[0]);w(e,r,t,c,!0),t._dragging=!0,o.on("mousemove",function(){var t=s(),i=E(t,n.mouse(a)[0]);w(e,r,t,i,!1)}),o.on("mouseup",function(){var t=s();t._dragging=!1,l.call(i.fill,t.bgcolor),o.on("mouseup",null),o.on("mousemove",null),e.emit("plotly_sliderend",{slider:t,step:t.steps[t.active]})})})}function M(t,e){var r=t.selectAll("rect."+u.tickRectClass).data(e._visibleSteps),a=e._dims;r.enter().append("rect").classed(u.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+"px","shape-rendering":"crispEdges"}),r.each(function(t,r){var s=r%a.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(i.fill,e.tickcolor),o.setTranslate(l,S(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?u.tickOffset:u.minorTickOffset)+a.currentValueTotalHeight)})}function A(t,e,r){for(var n=t.select("rect."+u.gripRectClass),a=0,i=0;i<e._stepCount;i++)if(e._visibleSteps[i]._index===e.active){a=i;break}var o=S(e,a/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr("transform","translate("+(o-.5*u.gripWidth)+","+e._dims.currentValueTotalHeight+")")}}function S(t,e){var r=t._dims;return r.inputAreaStart+u.stepInset+(r.inputAreaLength-2*u.stepInset)*Math.min(1,Math.max(0,e))}function E(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-u.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*u.stepInset-2*r.inputAreaStart)))}function L(t,e,r){var n=r._dims,a=s.ensureSingle(t,"rect",u.railTouchRectClass,function(n){n.call(T,e,t,r).style("pointer-events","all")});a.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,u.tickOffset+r.ticklen+n.labelHeight)}).call(i.fill,r.bgcolor).attr("opacity",0),o.setTranslate(a,0,n.currentValueTotalHeight)}function C(t,e){var r=e._dims,n=r.inputAreaLength-2*u.railInset,a=s.ensureSingle(t,"rect",u.railRectClass);a.attr({width:n,height:u.railWidth,rx:u.railRadius,ry:u.railRadius,"shape-rendering":"crispEdges"}).call(i.stroke,e.bordercolor).call(i.fill,e.bgcolor).style("stroke-width",e.borderwidth+"px"),o.setTranslate(a,u.railInset,.5*(r.inputAreaWidth-u.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[u.name],n=[],a=0;a<r.length;a++){var i=r[a];i.visible&&(i._gd=e,n.push(i))}return n}(e,t),i=e._infolayer.selectAll("g."+u.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),a.autoMargin(t,g(e))}if(i.enter().append("g").classed(u.containerClassName,!0).style("cursor","ew-resize"),i.exit().each(function(){n.select(this).selectAll("g."+u.groupClassName).each(s)}).remove(),0!==r.length){var l=i.selectAll("g."+u.groupClassName).data(r,v);l.enter().append("g").classed(u.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var h=r[c];m(t,h)}l.each(function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),a.manageCommandObserver(t,e,e._visibleSteps,function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))}),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(y,r).call(C,r).call(_,r).call(M,r).call(L,t,r).call(x,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(A,r,!1),e.call(y,r)}(t,n.select(this),e)})}}},{"../../constants/alignment":686,"../../lib":717,"../../lib/svg_text_utils":741,"../../plot_api/plot_template":755,"../../plots/plots":826,"../color":591,"../drawing":612,"./constants":675,d3:165}],678:[function(t,e,r){"use strict";var n=t("./constants");e.exports={moduleType:"component",name:n.name,layoutAttributes:t("./attributes"),supplyLayoutDefaults:t("./defaults"),draw:t("./draw")}},{"./attributes":674,"./constants":675,"./defaults":676,"./draw":677}],679:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../../plots/plots"),o=t("../../registry"),s=t("../../lib"),l=t("../drawing"),c=t("../color"),u=t("../../lib/svg_text_utils"),h=t("../../constants/interactions"),f=t("../../constants/alignment").OPPOSITE_SIDE,p=/ [XY][0-9]* /;e.exports={draw:function(t,e,r){var d,g=r.propContainer,v=r.propName,m=r.placeholder,y=r.traceIndex,x=r.avoid||{},b=r.attributes,_=r.transform,w=r.containerGroup,k=t._fullLayout,T=1,M=!1,A=g.title,S=(A&&A.text?A.text:"").trim(),E=A&&A.font?A.font:{},L=E.family,C=E.size,P=E.color;"title.text"===v?d="titleText":-1!==v.indexOf("axis")?d="axisTitleText":v.indexOf(!0)&&(d="colorbarTitleText");var O=t._context.edits[d];""===S?T=0:S.replace(p," % ")===m.replace(p," % ")&&(T=.2,M=!0,O||(S="")),r._meta?S=s.templateString(S,r._meta):k._meta&&(S=s.templateString(S,k._meta));var z=S||O;w||(w=s.ensureSingle(k._infolayer,"g","g-"+e));var I=w.selectAll("text").data(z?[0]:[]);if(I.enter().append("text"),I.text(S).attr("class",e),I.exit().remove(),!z)return w;function D(t){s.syncOrAsync([R,F],t)}function R(e){var r;return _?(r="",_.rotate&&(r+="rotate("+[_.rotate,b.x,b.y]+")"),_.offset&&(r+="translate(0, "+_.offset+")")):r=null,e.attr("transform",r),e.style({"font-family":L,"font-size":n.round(C,2)+"px",fill:c.rgb(P),opacity:T*c.opacity(P),"font-weight":i.fontWeight}).attr(b).call(u.convertToTspans,t),i.previousPromises(t)}function F(t){var e=n.select(t.node().parentNode);if(x&&x.selection&&x.side&&S){e.attr("transform",null);var r=f[x.side],i="left"===x.side||"top"===x.side?-1:1,o=a(x.pad)?x.pad:2,c=l.bBox(e.node()),u={left:0,top:0,right:k.width,bottom:k.height},h=x.maxShift||i*(u[x.side]-c[x.side]),p=0;if(h<0)p=h;else{var d=x.offsetLeft||0,g=x.offsetTop||0;c.left-=d,c.right-=d,c.top-=g,c.bottom-=g,x.selection.each(function(){var t=l.bBox(this);s.bBoxIntersect(c,t,o)&&(p=Math.max(p,i*(t[x.side]-c[r])+o))}),p=Math.min(h,p)}if(p>0||h<0){var v={left:[-p,0],right:[p,0],top:[0,-p],bottom:[0,p]}[x.side];e.attr("transform","translate("+v+")")}}}return I.call(D),O&&(S?I.on(".opacity",null):(T=0,M=!0,I.text(m).on("mouseover.opacity",function(){n.select(this).transition().duration(h.SHOW_PLACEHOLDER).style("opacity",1)}).on("mouseout.opacity",function(){n.select(this).transition().duration(h.HIDE_PLACEHOLDER).style("opacity",0)})),I.call(u.makeEditable,{gd:t}).on("edit",function(e){void 0!==y?o.call("_guiRestyle",t,v,e,y):o.call("_guiRelayout",t,v,e)}).on("cancel",function(){this.text(this.attr("data-unformatted")).call(D)}).on("input",function(t){this.text(t||" ").call(u.positionText,b.x,b.y)})),I.classed("js-placeholder",M),w}}},{"../../constants/alignment":686,"../../constants/interactions":692,"../../lib":717,"../../lib/svg_text_utils":741,"../../plots/plots":826,"../../registry":846,"../color":591,"../drawing":612,d3:165,"fast-isnumeric":228}],680:[function(t,e,r){"use strict";var n=t("../../plots/font_attributes"),a=t("../color/attributes"),i=t("../../lib/extend").extendFlat,o=t("../../plot_api/edit_types").overrideAll,s=t("../../plots/pad_attributes"),l=t("../../plot_api/plot_template").templatedArray,c=l("button",{visible:{valType:"boolean"},method:{valType:"enumerated",values:["restyle","relayout","animate","update","skip"],dflt:"restyle"},args:{valType:"info_array",freeLength:!0,items:[{valType:"any"},{valType:"any"},{valType:"any"}]},args2:{valType:"info_array",freeLength:!0,items:[{valType:"any"},{valType:"any"},{valType:"any"}]},label:{valType:"string",dflt:""},execute:{valType:"boolean",dflt:!0}});e.exports=o(l("updatemenu",{_arrayAttrRegexps:[/^updatemenus\[(0|[1-9][0-9]+)\]\.buttons/],visible:{valType:"boolean"},type:{valType:"enumerated",values:["dropdown","buttons"],dflt:"dropdown"},direction:{valType:"enumerated",values:["left","right","up","down"],dflt:"down"},active:{valType:"integer",min:-1,dflt:0},showactive:{valType:"boolean",dflt:!0},buttons:c,x:{valType:"number",min:-2,max:3,dflt:-.05},xanchor:{valType:"enumerated",values:["auto","left","center","right"],dflt:"right"},y:{valType:"number",min:-2,max:3,dflt:1},yanchor:{valType:"enumerated",values:["auto","top","middle","bottom"],dflt:"top"},pad:i(s({editType:"arraydraw"}),{}),font:n({}),bgcolor:{valType:"color"},bordercolor:{valType:"color",dflt:a.borderLine},borderwidth:{valType:"number",min:0,dflt:1,editType:"arraydraw"}}),"arraydraw","from-root")},{"../../lib/extend":708,"../../plot_api/edit_types":748,"../../plot_api/plot_template":755,"../../plots/font_attributes":791,"../../plots/pad_attributes":825,"../color/attributes":590}],681:[function(t,e,r){"use strict";e.exports={name:"updatemenus",containerClassName:"updatemenu-container",headerGroupClassName:"updatemenu-header-group",headerClassName:"updatemenu-header",headerArrowClassName:"updatemenu-header-arrow",dropdownButtonGroupClassName:"updatemenu-dropdown-button-group",dropdownButtonClassName:"updatemenu-dropdown-button",buttonClassName:"updatemenu-button",itemRectClassName:"updatemenu-item-rect",itemTextClassName:"updatemenu-item-text",menuIndexAttrName:"updatemenu-active-index",autoMarginIdRoot:"updatemenu-",blankHeaderOpts:{label:"  "},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:"#F4FAFF",hoverColor:"#F4FAFF",arrowSymbol:{left:"\u25c4",right:"\u25ba",up:"\u25b2",down:"\u25bc"}}},{}],682:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/array_container_defaults"),i=t("./attributes"),o=t("./constants").name,s=i.buttons;function l(t,e,r){function o(r,a){return n.coerce(t,e,i,r,a)}o("visible",a(t,e,{name:"buttons",handleItemDefaults:c}).length>0)&&(o("active"),o("direction"),o("type"),o("showactive"),o("x"),o("y"),n.noneOrAll(t,e,["x","y"]),o("xanchor"),o("yanchor"),o("pad.t"),o("pad.r"),o("pad.b"),o("pad.l"),n.coerceFont(o,"font",r.font),o("bgcolor",r.paper_bgcolor),o("bordercolor"),o("borderwidth"))}function c(t,e){function r(r,a){return n.coerce(t,e,s,r,a)}r("visible","skip"===t.method||Array.isArray(t.args))&&(r("method"),r("args"),r("args2"),r("label"),r("execute"))}e.exports=function(t,e){a(t,e,{name:o,handleItemDefaults:l})}},{"../../lib":717,"../../plots/array_container_defaults":761,"./attributes":680,"./constants":681}],683:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../plots/plots"),i=t("../color"),o=t("../drawing"),s=t("../../lib"),l=t("../../lib/svg_text_utils"),c=t("../../plot_api/plot_template").arrayEditor,u=t("../../constants/alignment").LINE_SPACING,h=t("./constants"),f=t("./scrollbox");function p(t){return t._index}function d(t,e){return+t.attr(h.menuIndexAttrName)===e._index}function g(t,e,r,n,a,i,o,s){e.active=o,c(t.layout,h.name,e).applyUpdate("active",o),"buttons"===e.type?m(t,n,null,null,e):"dropdown"===e.type&&(a.attr(h.menuIndexAttrName,"-1"),v(t,n,a,i,e),s||m(t,n,a,i,e))}function v(t,e,r,n,a){var i=s.ensureSingle(e,"g",h.headerClassName,function(t){t.style("pointer-events","all")}),l=a._dims,c=a.active,u=a.buttons[c]||h.blankHeaderOpts,f={y:a.pad.t,yPad:0,x:a.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};i.call(y,a,u,t).call(A,a,f,p),s.ensureSingle(e,"text",h.headerArrowClassName,function(t){t.classed("user-select-none",!0).attr("text-anchor","end").call(o.font,a.font).text(h.arrowSymbol[a.direction])}).attr({x:l.headerWidth-h.arrowOffsetX+a.pad.l,y:l.headerHeight/2+h.textOffsetY+a.pad.t}),i.on("click",function(){r.call(S,String(d(r,a)?-1:a._index)),m(t,e,r,n,a)}),i.on("mouseover",function(){i.call(w)}),i.on("mouseout",function(){i.call(k,a)}),o.setTranslate(e,l.lx,l.ly)}function m(t,e,r,i,o){r||(r=e).attr("pointer-events","all");var l=function(t){return-1==+t.attr(h.menuIndexAttrName)}(r)&&"buttons"!==o.type?[]:o.buttons,c="dropdown"===o.type?h.dropdownButtonClassName:h.buttonClassName,u=r.selectAll("g."+c).data(s.filterVisible(l)),f=u.enter().append("g").classed(c,!0),p=u.exit();"dropdown"===o.type?(f.attr("opacity","0").transition().attr("opacity","1"),p.transition().attr("opacity","0").remove()):p.remove();var d=0,v=0,m=o._dims,x=-1!==["up","down"].indexOf(o.direction);"dropdown"===o.type&&(x?v=m.headerHeight+h.gapButtonHeader:d=m.headerWidth+h.gapButtonHeader),"dropdown"===o.type&&"up"===o.direction&&(v=-h.gapButtonHeader+h.gapButton-m.openHeight),"dropdown"===o.type&&"left"===o.direction&&(d=-h.gapButtonHeader+h.gapButton-m.openWidth);var b={x:m.lx+d+o.pad.l,y:m.ly+v+o.pad.t,yPad:h.gapButton,xPad:h.gapButton,index:0},T={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each(function(s,l){var c=n.select(this);c.call(y,o,s,t).call(A,o,b),c.on("click",function(){n.event.defaultPrevented||(s.execute&&(s.args2&&o.active===l?(g(t,o,0,e,r,i,-1),a.executeAPICommand(t,s.method,s.args2)):(g(t,o,0,e,r,i,l),a.executeAPICommand(t,s.method,s.args))),t.emit("plotly_buttonclicked",{menu:o,button:s,active:o.active}))}),c.on("mouseover",function(){c.call(w)}),c.on("mouseout",function(){c.call(k,o),u.call(_,o)})}),u.call(_,o),x?(T.w=Math.max(m.openWidth,m.headerWidth),T.h=b.y-T.t):(T.w=b.x-T.l,T.h=Math.max(m.openHeight,m.headerHeight)),T.direction=o.direction,i&&(u.size()?function(t,e,r,n,a,i){var o,s,l,c=a.direction,u="up"===c||"down"===c,f=a._dims,p=a.active;if(u)for(s=0,l=0;l<p;l++)s+=f.heights[l]+h.gapButton;else for(o=0,l=0;l<p;l++)o+=f.widths[l]+h.gapButton;n.enable(i,o,s),n.hbar&&n.hbar.attr("opacity","0").transition().attr("opacity","1");n.vbar&&n.vbar.attr("opacity","0").transition().attr("opacity","1")}(0,0,0,i,o,T):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr("opacity","0").each("end",function(){e=!1,r||t.disable()});r&&t.vbar.transition().attr("opacity","0").each("end",function(){r=!1,e||t.disable()})}(i))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,"rect",h.itemRectClassName,function(t){t.attr({rx:h.rx,ry:h.ry,"shape-rendering":"crispEdges"})}).call(i.stroke,e.bordercolor).call(i.fill,e.bgcolor).style("stroke-width",e.borderwidth+"px")}function b(t,e,r,n){var a=s.ensureSingle(t,"text",h.itemTextClassName,function(t){t.classed("user-select-none",!0).attr({"text-anchor":"start","data-notex":1})}),i=r.label,c=n._fullLayout._meta;c&&(i=s.templateString(i,c)),a.call(o.font,e.font).text(i).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each(function(t,a){var o=n.select(this);a===r&&e.showactive&&o.select("rect."+h.itemRectClassName).call(i.fill,h.activeColor)})}function w(t){t.select("rect."+h.itemRectClassName).call(i.fill,h.hoverColor)}function k(t,e){t.select("rect."+h.itemRectClassName).call(i.fill,e.bgcolor)}function T(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},i=o.tester.selectAll("g."+h.dropdownButtonClassName).data(s.filterVisible(e.buttons));i.enter().append("g").classed(h.dropdownButtonClassName,!0);var c=-1!==["up","down"].indexOf(e.direction);i.each(function(a,i){var s=n.select(this);s.call(y,e,a,t);var f=s.select("."+h.itemTextClassName),p=f.node()&&o.bBox(f.node()).width,d=Math.max(p+h.textPadX,h.minWidth),g=e.font.size*u,v=l.lineCount(f),m=Math.max(g*v,h.minHeight)+h.textOffsetY;m=Math.ceil(m),d=Math.ceil(d),r.widths[i]=d,r.heights[i]=m,r.height1=Math.max(r.height1,m),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=m+h.gapButton,r.openHeight+=m+h.gapButton):(r.totalWidth+=d+h.gapButton,r.openWidth+=d+h.gapButton,r.totalHeight=Math.max(r.totalHeight,m),r.openHeight=r.totalHeight)}),c?r.totalHeight-=h.gapButton:r.totalWidth-=h.gapButton,r.headerWidth=r.width1+h.arrowPadX,r.headerHeight=r.height1,"dropdown"===e.type&&(c?(r.width1+=h.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=h.arrowPadX),i.remove();var f=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var g="left";s.isRightAnchor(e)&&(r.lx-=f,g="right"),s.isCenterAnchor(e)&&(r.lx-=f/2,g="center");var v="top";s.isBottomAnchor(e)&&(r.ly-=p,v="bottom"),s.isMiddleAnchor(e)&&(r.ly-=p/2,v="middle"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),a.autoMargin(t,M(e),{x:e.x,y:e.y,l:f*({right:1,center:.5}[g]||0),r:f*({left:1,center:.5}[g]||0),b:p*({top:1,middle:.5}[v]||0),t:p*({bottom:1,middle:.5}[v]||0)})}function M(t){return h.autoMarginIdRoot+t._index}function A(t,e,r,n){n=n||{};var a=t.select("."+h.itemRectClassName),i=t.select("."+h.itemTextClassName),s=e.borderwidth,c=r.index,f=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==["up","down"].indexOf(e.direction),d=n.height||(p?f.heights[c]:f.height1);a.attr({x:0,y:0,width:n.width||(p?f.width1:f.widths[c]),height:d});var g=e.font.size*u,v=(l.lineCount(i)-1)*g/2;l.positionText(i,h.textOffsetX,d/2-v+h.textOffsetY),p?r.y+=f.heights[c]+r.yPad:r.x+=f.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(h.menuIndexAttrName,e||"-1").selectAll("g."+h.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[h.name]);function i(e){a.autoMargin(t,M(e))}var o=e._menulayer.selectAll("g."+h.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append("g").classed(h.containerClassName,!0).style("cursor","pointer"),o.exit().each(function(){n.select(this).selectAll("g."+h.headerGroupClassName).each(i)}).remove(),0!==r.length){var l=o.selectAll("g."+h.headerGroupClassName).data(r,p);l.enter().append("g").classed(h.headerGroupClassName,!0);for(var c=s.ensureSingle(o,"g",h.dropdownButtonGroupClassName,function(t){t.style("pointer-events","all")}),u=0;u<r.length;u++){var y=r[u];T(t,y)}var x="updatemenus"+e._uid,b=new f(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each(function(t){c.call(S),i(t)}).remove(),l.each(function(e){var r=n.select(this),i="dropdown"===e.type?c:null;a.manageCommandObserver(t,e,e.buttons,function(n){g(t,e,e.buttons[n.index],r,i,b,n.index,!0)}),"dropdown"===e.type?(v(t,r,c,b,e),d(c,e)&&m(t,r,c,b,e)):m(t,r,null,null,e)})}}},{"../../constants/alignment":686,"../../lib":717,"../../lib/svg_text_utils":741,"../../plot_api/plot_template":755,"../../plots/plots":826,"../color":591,"../drawing":612,"./constants":681,"./scrollbox":685,d3:165}],684:[function(t,e,r){arguments[4][678][0].apply(r,arguments)},{"./attributes":680,"./constants":681,"./defaults":682,"./draw":683,dup:678}],685:[function(t,e,r){"use strict";e.exports=s;var n=t("d3"),a=t("../color"),i=t("../drawing"),o=t("../../lib");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll("rect.scrollbox-bg").data([0]),this.bg.exit().on(".drag",null).on("wheel",null).remove(),this.bg.enter().append("rect").classed("scrollbox-bg",!0).style("pointer-events","all").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor="#808BA4",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,h,f,p,d=this.position.l,g=this.position.w,v=this.position.t,m=this.position.h,y=this.position.direction,x="down"===y,b="left"===y,_="up"===y,w=g,k=m;x||b||"right"===y||_||(this.position.direction="down",x=!0),x||_?(h=(u=d)+w,x?(f=v,k=(p=Math.min(f+k,c))-f):k=(p=v+k)-(f=Math.max(p-k,0))):(p=(f=v)+k,b?w=(h=d+w)-(u=Math.max(h-w,0)):(u=d,w=(h=Math.min(u+w,l))-u)),this._box={l:u,t:f,w:w,h:k};var T=g>w,M=s.barLength+2*s.barPad,A=s.barWidth+2*s.barPad,S=d,E=v+m;E+A>c&&(E=c-A);var L=this.container.selectAll("rect.scrollbar-horizontal").data(T?[0]:[]);L.exit().on(".drag",null).remove(),L.enter().append("rect").classed("scrollbar-horizontal",!0).call(a.fill,s.barColor),T?(this.hbar=L.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:M,height:A}),this._hbarXMin=S+M/2,this._hbarTranslateMax=w-M):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var C=m>k,P=s.barWidth+2*s.barPad,O=s.barLength+2*s.barPad,z=d+g,I=v;z+P>l&&(z=l-P);var D=this.container.selectAll("rect.scrollbar-vertical").data(C?[0]:[]);D.exit().on(".drag",null).remove(),D.enter().append("rect").classed("scrollbar-vertical",!0).call(a.fill,s.barColor),C?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:z,y:I,width:P,height:O}),this._vbarYMin=I+O/2,this._vbarTranslateMax=k-O):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=C?h+P+.5:h+.5,N=f-.5,j=T?p+A+.5:p+.5,V=o._topdefs.selectAll("#"+R).data(T||C?[0]:[]);if(V.exit().remove(),V.enter().append("clipPath").attr("id",R).append("rect"),T||C?(this._clipRect=V.select("rect").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(i.setClipUrl,R,this.gd),this.bg.attr({x:d,y:v,width:g,height:m})):(this.bg.attr({width:0,height:0}),this.container.on("wheel",null).on(".drag",null).call(i.setClipUrl,null),delete this._clipRect),T||C){var U=n.behavior.drag().on("dragstart",function(){n.event.sourceEvent.preventDefault()}).on("drag",this._onBoxDrag.bind(this));this.container.on("wheel",null).on("wheel",this._onBoxWheel.bind(this)).on(".drag",null).call(U);var q=n.behavior.drag().on("dragstart",function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()}).on("drag",this._onBarDrag.bind(this));T&&this.hbar.on(".drag",null).call(q),C&&this.vbar.on(".drag",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on("wheel",null).on(".drag",null).call(i.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(".drag",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(".drag",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,a=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,a)-r)/(a-r)*(this.position.w-this._box.w)}if(this.vbar){var i=e+this._vbarYMin,s=i+this._vbarTranslateMax;e=(o.constrain(n.event.y,i,s)-i)/(s-i)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(i.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var a=t/r;this.hbar.call(i.setTranslate,t+a*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(i.setTranslate,t,e+s*this._vbarTranslateMax)}}},{"../../lib":717,"../color":591,"../drawing":612,d3:165}],686:[function(t,e,r){"use strict";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:"right",right:"left",top:"bottom",bottom:"top"}}},{}],687:[function(t,e,r){"use strict";e.exports={INCREASING:{COLOR:"#3D9970",SYMBOL:"\u25b2"},DECREASING:{COLOR:"#FF4136",SYMBOL:"\u25bc"}}},{}],688:[function(t,e,r){"use strict";e.exports={FORMAT_LINK:"https://github.com/d3/d3-3.x-api-reference/blob/master/Formatting.md#d3_format",DATE_FORMAT_LINK:"https://github.com/d3/d3-3.x-api-reference/blob/master/Time-Formatting.md#format"}},{}],689:[function(t,e,r){"use strict";e.exports={COMPARISON_OPS:["=","!=","<",">=",">","<="],COMPARISON_OPS2:["=","<",">=",">","<="],INTERVAL_OPS:["[]","()","[)","(]","][",")(","](",")["],SET_OPS:["{}","}{"],CONSTRAINT_REDUCTION:{"=":"=","<":"<","<=":"<",">":">",">=":">","[]":"[]","()":"[]","[)":"[]","(]":"[]","][":"][",")(":"][","](":"][",")[":"]["}}},{}],690:[function(t,e,r){"use strict";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],691:[function(t,e,r){"use strict";e.exports={circle:"\u25cf","circle-open":"\u25cb",square:"\u25a0","square-open":"\u25a1",diamond:"\u25c6","diamond-open":"\u25c7",cross:"+",x:"\u274c"}},{}],692:[function(t,e,r){"use strict";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},{}],693:[function(t,e,r){"use strict";e.exports={BADNUM:void 0,FP_SAFE:Number.MAX_VALUE/1e4,ONEAVGYEAR:315576e5,ONEAVGMONTH:26298e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:1-1e-6,LOG_CLIP:10,MINUS_SIGN:"\u2212"}},{}],694:[function(t,e,r){"use strict";r.xmlns="http://www.w3.org/2000/xmlns/",r.svg="http://www.w3.org/2000/svg",r.xlink="http://www.w3.org/1999/xlink",r.svgAttrs={xmlns:r.svg,"xmlns:xlink":r.xlink}},{}],695:[function(t,e,r){"use strict";r.version=t("./version").version,t("es6-promise").polyfill(),t("../build/plotcss"),t("./fonts/mathjax_config")();for(var n=t("./registry"),a=r.register=n.register,i=t("./plot_api"),o=Object.keys(i),s=0;s<o.length;s++){var l=o[s];"_"!==l.charAt(0)&&(r[l]=i[l]),a({moduleType:"apiMethod",name:l,fn:i[l]})}a(t("./traces/scatter")),a([t("./components/legend"),t("./components/fx"),t("./components/annotations"),t("./components/annotations3d"),t("./components/shapes"),t("./components/images"),t("./components/updatemenus"),t("./components/sliders"),t("./components/rangeslider"),t("./components/rangeselector"),t("./components/grid"),t("./components/errorbars"),t("./components/colorscale"),t("./components/colorbar")]),a([t("./locale-en"),t("./locale-en-us")]),window.PlotlyLocales&&Array.isArray(window.PlotlyLocales)&&(a(window.PlotlyLocales),delete window.PlotlyLocales),r.Icons=t("./fonts/ploticon"),r.Plots=t("./plots/plots"),r.Fx=t("./components/fx"),r.Snapshot=t("./snapshot"),r.PlotSchema=t("./plot_api/plot_schema"),r.Queue=t("./lib/queue"),r.d3=t("d3")},{"../build/plotcss":1,"./components/annotations":582,"./components/annotations3d":587,"./components/colorbar":597,"./components/colorscale":603,"./components/errorbars":618,"./components/fx":630,"./components/grid":634,"./components/images":639,"./components/legend":647,"./components/rangeselector":658,"./components/rangeslider":665,"./components/shapes":673,"./components/sliders":678,"./components/updatemenus":684,"./fonts/mathjax_config":696,"./fonts/ploticon":697,"./lib/queue":732,"./locale-en":746,"./locale-en-us":745,"./plot_api":750,"./plot_api/plot_schema":754,"./plots/plots":826,"./registry":846,"./snapshot":851,"./traces/scatter":1132,"./version":1302,d3:165,"es6-promise":221}],696:[function(t,e,r){"use strict";e.exports=function(){"undefined"!=typeof MathJax&&("local"!==(window.PlotlyConfig||{}).MathJaxConfig&&(MathJax.Hub.Config({messageStyle:"none",skipStartupTypeset:!0,displayAlign:"left",tex2jax:{inlineMath:[["$","$"],["\\(","\\)"]]}}),MathJax.Hub.Configured()))}},{}],697:[function(t,e,r){"use strict";e.exports={undo:{width:857.1,height:1e3,path:"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z",transform:"matrix(1 0 0 -1 0 850)"},home:{width:928.6,height:1e3,path:"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z",transform:"matrix(1 0 0 -1 0 850)"},"camera-retro":{width:1e3,height:1e3,path:"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z",transform:"matrix(1 0 0 -1 0 850)"},zoombox:{width:1e3,height:1e3,path:"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z",transform:"matrix(1 0 0 -1 0 850)"},pan:{width:1e3,height:1e3,path:"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z",transform:"matrix(1 0 0 -1 0 850)"},zoom_plus:{width:875,height:1e3,path:"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z",transform:"matrix(1 0 0 -1 0 850)"},zoom_minus:{width:875,height:1e3,path:"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z",transform:"matrix(1 0 0 -1 0 850)"},autoscale:{width:1e3,height:1e3,path:"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z",transform:"matrix(1 0 0 -1 0 850)"},tooltip_basic:{width:1500,height:1e3,path:"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z",transform:"matrix(1 0 0 -1 0 850)"},tooltip_compare:{width:1125,height:1e3,path:"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z",transform:"matrix(1 0 0 -1 0 850)"},plotlylogo:{width:1542,height:1e3,path:"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z",transform:"matrix(1 0 0 -1 0 850)"},"z-axis":{width:1e3,height:1e3,path:"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z",transform:"matrix(1 0 0 -1 0 850)"},"3d_rotate":{width:1e3,height:1e3,path:"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z",transform:"matrix(1 0 0 -1 0 850)"},camera:{width:1e3,height:1e3,path:"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z",transform:"matrix(1 0 0 -1 0 850)"},movie:{width:1e3,height:1e3,path:"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z",transform:"matrix(1 0 0 -1 0 850)"},question:{width:857.1,height:1e3,path:"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z",transform:"matrix(1 0 0 -1 0 850)"},disk:{width:857.1,height:1e3,path:"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z",transform:"matrix(1 0 0 -1 0 850)"},lasso:{width:1031,height:1e3,path:"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z",transform:"matrix(1 0 0 -1 0 850)"},selectbox:{width:1e3,height:1e3,path:"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z",transform:"matrix(1 0 0 -1 0 850)"},spikeline:{width:1e3,height:1e3,path:"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z",transform:"matrix(1.5 0 0 -1.5 0 850)"},pencil:{width:1792,height:1792,path:"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z",transform:"matrix(1 0 0 1 0 1)"},newplotlylogo:{name:"newplotlylogo",svg:"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #3f4f75;} .cls-2 {fill: #80cfbe;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>"}}},{}],698:[function(t,e,r){"use strict";r.isLeftAnchor=function(t){return"left"===t.xanchor||"auto"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return"center"===t.xanchor||"auto"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return"right"===t.xanchor||"auto"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return"top"===t.yanchor||"auto"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return"middle"===t.yanchor||"auto"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return"bottom"===t.yanchor||"auto"===t.yanchor&&t.y<=1/3}},{}],699:[function(t,e,r){"use strict";var n=t("./mod"),a=n.mod,i=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return i(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=a(r,s))>(n=a(n,s))&&(n+=s);var i=a(t,s),o=i+s;return i>=r&&i<=n||o>=r&&o<=n}function h(t,e,r,n,a,i,c){a=a||0,i=i||0;var u,h,f,p,d,g=l([r,n]);function v(t,e){return[t*Math.cos(e)+a,i-t*Math.sin(e)]}g?(u=0,h=o,f=s):r<n?(u=r,f=n):(u=n,f=r),t<e?(p=t,d=e):(p=e,d=t);var m,y=Math.abs(f-u)<=o?0:1;function x(t,e,r){return"A"+[t,t]+" "+[0,y,r]+" "+v(t,e)}return g?m=null===p?"M"+v(d,u)+x(d,h,0)+x(d,f,0)+"Z":"M"+v(p,u)+x(p,h,0)+x(p,f,0)+"ZM"+v(d,u)+x(d,h,1)+x(d,f,1)+"Z":null===p?(m="M"+v(d,u)+x(d,f,0),c&&(m+="L0,0Z")):m="M"+v(p,u)+"L"+v(d,u)+x(d,f,0)+"L"+v(p,f)+x(p,u,1)+"Z",m}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(a=r[0],i=r[1]):(a=r[1],i=r[0]),t>=a&&t<=i);var a,i},pathArc:function(t,e,r,n,a){return h(null,t,e,r,n,a,0)},pathSector:function(t,e,r,n,a){return h(null,t,e,r,n,a,1)},pathAnnulus:function(t,e,r,n,a,i){return h(t,e,r,n,a,i,1)}}},{"./mod":724}],700:[function(t,e,r){"use strict";var n=Array.isArray,a="undefined"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer:{isView:function(){return!1}},i="undefined"==typeof DataView?function(){}:DataView;function o(t){return a.isView(t)&&!(t instanceof i)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,a=0;a<t.length;a++)n=e(n,t[a].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,a,i,o,s,l,c=[],u=!0,h=0;for(r=0;r<arguments.length;r++)(o=(a=arguments[r]).length)&&(e?c.push(a):(e=a,i=o),n(a)?t=!1:(u=!1,h?t!==a.constructor&&(t=!1):t=a.constructor),h+=o);if(!h)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(h)).set(e),r=0;r<c.length;r++)a=c[r],s.set(a,i),i+=a.length;return s}for(s=new Array(h),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(a=c[r],l=0;l<a.length;l++)s[i+l]=a[l];i+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],701:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../constants/numerical").BADNUM,i=/^['"%,$#\s']+|[, ]|['"%,$#\s']+$/g;e.exports=function(t){return"string"==typeof t&&(t=t.replace(i,"")),n(t)?Number(t):a}},{"../constants/numerical":693,"fast-isnumeric":228}],702:[function(t,e,r){"use strict";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each(function(t){t.regl&&t.regl.clear({color:!0,depth:!0})})}},{}],703:[function(t,e,r){"use strict";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener("resize",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],704:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("tinycolor2"),i=t("../plots/attributes"),o=t("../components/colorscale/scales"),s=t("../constants/interactions").DESELECTDIM,l=t("./nested_property"),c=t("./regex").counter,u=t("./mod").modHalf,h=t("./array").isArrayOrTypedArray;function f(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&h(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var a={},i=a,o={set:function(t){i=t}};return n.coerceFunction(t,o,a,e),i!==a}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){h(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var a=String(r[n]);if("/"===a.charAt(0)&&"/"===a.charAt(a.length-1)){if(new RegExp(a.substr(1,a.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,a){!n(t)||void 0!==a.min&&t<a.min||void 0!==a.max&&t>a.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,a){t%1||!n(t)||void 0!==a.min&&t<a.min||void 0!==a.max&&t>a.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if("string"!=typeof t){var a="number"==typeof t;!0!==n.strict&&a?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){a(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every(function(t){return a(t).isValid()})?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){"auto"===t?e.set("auto"):n(t)?e.set(u(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var a=n.regex||c(r);"string"==typeof t&&a.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||"string"==typeof t&&!!c(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if("string"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var a=t.split("+"),i=0;i<a.length;){var o=a[i];-1===n.flags.indexOf(o)||a.indexOf(o)<i?a.splice(i,1):i++}a.length?e.set(a.join("+")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,a){function i(t,e,n){var a,i={set:function(t){a=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,i,n,e),a}var o=2===a.dimensions||"1-2"===a.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,h,f,p=a.items,d=[],g=Array.isArray(p),v=g&&o&&Array.isArray(p[0]),m=o&&g&&!v,y=g&&!m?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],h=m?p.length:g?p[s].length:c.length,l=0;l<h;l++)u=m?p[l]:g?p[s][l]:p,void 0!==(f=i(c[l],u,(n[s]||[])[l]))&&(d[s][l]=f);else for(s=0;s<y;s++)void 0!==(f=i(t[s],g?p[s]:p,n[s]))&&(d[s]=f);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),a=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var i=0;i<t.length;i++)if(a){if(!Array.isArray(t[i])||!e.freeLength&&t[i].length!==r[i].length)return!1;for(var o=0;o<t[i].length;o++)if(!f(t[i][o],n?r[i][o]:r))return!1}else if(!f(t[i],n?r[i]:r))return!1;return!0}}},r.coerce=function(t,e,n,a,i){var o=l(n,a).get(),s=l(t,a),c=l(e,a),u=s.get(),p=e._template;if(void 0===u&&p&&(u=l(p,a).get(),p=0),void 0===i&&(i=o.dflt),o.arrayOk&&h(u))return c.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,c,i,o);var g=c.get();return p&&g===i&&!f(u,o)&&(d(u=l(p,a).get(),c,i,o),g=c.get()),g},r.coerce2=function(t,e,n,a,i){var o=l(t,a),s=r.coerce(t,e,n,a,i),c=o.get();return null!=c&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+".family",r.family),n.size=t(e+".size",r.size),n.color=t(e+".color",r.color),n},r.coerceHoverinfo=function(t,e,n){var a,o=e._module.attributes,s=o.hoverinfo?o:i,l=s.hoverinfo;if(1===n._dataLength){var c="all"===l.dflt?l.flags.slice():l.dflt.split("+");c.splice(c.indexOf("name"),1),a=c.join("+")}return r.coerce(t,e,s,"hoverinfo",a)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,a=t.marker.opacity;if(void 0!==a)h(a)||t.selected||t.unselected||(r=a,n=s*a),e("selected.marker.opacity",r),e("unselected.marker.opacity",n)}},r.validate=f},{"../components/colorscale/scales":606,"../constants/interactions":692,"../plots/attributes":762,"./array":700,"./mod":724,"./nested_property":725,"./regex":733,"fast-isnumeric":228,tinycolor2:535}],705:[function(t,e,r){"use strict";var n,a,i=t("d3"),o=t("fast-isnumeric"),s=t("./loggers"),l=t("./mod").mod,c=t("../constants/numerical"),u=c.BADNUM,h=c.ONEDAY,f=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,g=c.EPOCHJD,v=t("../registry"),m=i.time.format.utc,y=/^\s*(-?\d\d\d\d|\d\d)(-(\d?\d)(-(\d?\d)([ Tt]([01]?\d|2[0-3])(:([0-5]\d)(:([0-5]\d(\.\d+)?))?(Z|z|[+\-]\d\d:?\d\d)?)?)?)?)?\s*$/m,x=/^\s*(-?\d\d\d\d|\d\d)(-(\d?\di?)(-(\d?\d)([ Tt]([01]?\d|2[0-3])(:([0-5]\d)(:([0-5]\d(\.\d+)?))?(Z|z|[+\-]\d\d:?\d\d)?)?)?)?)?\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&v.componentsRegistry.calendars&&"string"==typeof t&&"gregorian"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){return _(t)?e?v.getComponentMethod("calendars","CANONICAL_SUNDAY")[t]:v.getComponentMethod("calendars","CANONICAL_TICK")[t]:e?"2000-01-02":"2000-01-01"},r.dfltRange=function(t){return _(t)?v.getComponentMethod("calendars","DFLTRANGE")[t]:["2000-01-01","2001-01-01"]},r.isJSDate=function(t){return"object"==typeof t&&null!==t&&"function"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var i=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;i=i-s/2+l(o-i+s/2,s)}return(t=Number(t)-i)>=n&&t<=a?t:u}if("string"!=typeof t&&"number"!=typeof t)return u;t=String(t);var c=_(e),m=t.charAt(0);!c||"G"!==m&&"g"!==m||(t=t.substr(1),e="");var w=c&&"chinese"===e.substr(0,7),k=t.match(w?x:y);if(!k)return u;var T=k[1],M=k[3]||"1",A=Number(k[5]||1),S=Number(k[7]||0),E=Number(k[9]||0),L=Number(k[11]||0);if(c){if(2===T.length)return u;var C;T=Number(T);try{var P=v.getComponentMethod("calendars","getCal")(e);if(w){var O="i"===M.charAt(M.length-1);M=parseInt(M,10),C=P.newDate(T,P.toMonthIndex(T,M,O),A)}else C=P.newDate(T,Number(M),A)}catch(t){return u}return C?(C.toJD()-g)*h+S*f+E*p+L*d:u}T=2===T.length?(Number(T)+2e3-b)%100+b:Number(T),M-=1;var z=new Date(Date.UTC(2e3,M,A,S,E));return z.setUTCFullYear(T),z.getUTCMonth()!==M?u:z.getUTCDate()!==A?u:z.getTime()+L*d},n=r.MIN_MS=r.dateTime2ms("-9999"),a=r.MAX_MS=r.dateTime2ms("9999-12-31 23:59:59.9999"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var k=90*h,T=3*f,M=5*p;function A(t,e,r,n,a){if((e||r||n||a)&&(t+=" "+w(e,2)+":"+w(r,2),(n||a)&&(t+=":"+w(n,2),a))){for(var i=4;a%10==0;)i-=1,a/=10;t+="."+w(a,i)}return t}r.ms2DateTime=function(t,e,r){if("number"!=typeof t||!(t>=n&&t<=a))return u;e||(e=0);var i,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/h)+g,E=Math.floor(l(t,h));try{i=v.getComponentMethod("calendars","getCal")(r).fromJD(S).formatDate("yyyy-mm-dd")}catch(t){i=m("G%Y-%m-%d")(new Date(w))}if("-"===i.charAt(0))for(;i.length<11;)i="-0"+i.substr(1);else for(;i.length<10;)i="0"+i;o=e<k?Math.floor(E/f):0,s=e<k?Math.floor(E%f/p):0,c=e<T?Math.floor(E%p/d):0,y=e<M?E%d*10+b:0}else x=new Date(w),i=m("%Y-%m-%d")(x),o=e<k?x.getUTCHours():0,s=e<k?x.getUTCMinutes():0,c=e<T?x.getUTCSeconds():0,y=e<M?10*x.getUTCMilliseconds()+b:0;return A(i,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+h&&t<=a-h))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return A(i.time.format("%Y-%m-%d")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||"number"==typeof t&&isFinite(t)){if(_(n))return s.error("JS Dates and milliseconds are incompatible with world calendars",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error("unrecognized date",t),e;return t};var S=/%\d?f/g;function E(t,e,r,n){t=t.replace(S,function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,"")||"0"});var a=new Date(Math.floor(e+.05));if(_(n))try{t=v.getComponentMethod("calendars","worldCalFmt")(t,e,n)}catch(t){return"Invalid"}return r(t)(a)}var L=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,a,i){if(a=_(a)&&a,!e)if("y"===r)e=i.year;else if("m"===r)e=i.month;else{if("d"!==r)return function(t,e){var r=l(t+.05,h),n=w(Math.floor(r/f),2)+":"+w(l(Math.floor(r/p),60),2);if("M"!==e){o(e)||(e=0);var a=(100+Math.min(l(t/d,60),L[e])).toFixed(e).substr(1);e>0&&(a=a.replace(/0+$/,"").replace(/[\.]$/,"")),n+=":"+a}return n}(t,r)+"\n"+E(i.dayMonthYear,t,n,a);e=i.dayMonth+"\n"+i.year}return E(e,t,n,a)};var C=3*h;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,h);if(t=Math.round(t-n),r)try{var a=Math.round(t/h)+g,i=v.getComponentMethod("calendars","getCal")(r),o=i.fromJD(a);return e%12?i.add(o,e,"m"):i.add(o,e/12,"y"),(o.toJD()-g)*h+n}catch(e){s.error("invalid ms "+t+" in calendar "+r)}var c=new Date(t+C);return c.setUTCMonth(c.getUTCMonth()+e)+n-C},r.findExactDates=function(t,e){for(var r,n,a=0,i=0,s=0,l=0,c=_(e)&&v.getComponentMethod("calendars","getCal")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%h))if(c)try{1===(r=c.fromJD(n/h+g)).day()?1===r.month()?a++:i++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?a++:i++:s++}else l++;s+=i+=a;var f=t.length-l;return{exactYears:a/f,exactMonths:i/f,exactDays:s/f}}},{"../constants/numerical":693,"../registry":846,"./loggers":721,"./mod":724,d3:165,"fast-isnumeric":228}],706:[function(t,e,r){"use strict";var n=t("d3"),a=t("./loggers");function i(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function o(t,e,r){var n="plotly.js-style-"+t,i=document.getElementById(n);i||((i=document.createElement("style")).setAttribute("id",n),i.appendChild(document.createTextNode("")),document.head.appendChild(i));var o=i.sheet;o.insertRule?o.insertRule(e+"{"+r+"}",0):o.addRule?o.addRule(e,r,0):a.warn("addStyleRule failed")}e.exports={getGraphDiv:function(t){var e;if("string"==typeof t){if(null===(e=document.getElementById(t)))throw new Error("No DOM element with id '"+t+"' exists on the page.");return e}if(null==t)throw new Error("DOM element provided is null or undefined");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed("js-plotly-plot")},removeElement:i,addStyleRule:function(t,e){o("global",t,e)},addRelatedStyleRule:o,deleteRelatedStyleRule:function(t){var e="plotly.js-style-"+t,r=document.getElementById(e);r&&i(r)}}},{"./loggers":721,d3:165}],707:[function(t,e,r){"use strict";var n=t("events").EventEmitter,a={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,a){"undefined"!=typeof jQuery&&jQuery(t).trigger(n,a),e.emit(n,a),r.emit(n,a)},t},triggerHandler:function(t,e,r){var n,a;"undefined"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var i=t._ev;if(!i)return n;var o,s=i._events[e];if(!s)return n;function l(t){return t.listener?(i.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(i,[r]))):t.apply(i,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return a=l(s[o]),void 0!==n?n:a},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=a},{events:106}],708:[function(t,e,r){"use strict";var n=t("./is_plain_object.js"),a=Array.isArray;function i(t,e,r,o){var s,l,c,u,h,f,p=t[0],d=t.length;if(2===d&&a(p)&&a(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&"object"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var g=1;g<d;g++)for(l in s=t[g])c=p[l],u=s[l],o&&a(u)?p[l]=u:e&&u&&(n(u)||(h=a(u)))?(h?(h=!1,f=c&&a(c)?c:[]):f=c&&n(c)?c:{},p[l]=i([f,u],e,r,o)):("undefined"!=typeof u||r)&&(p[l]=u);return p}r.extendFlat=function(){return i(arguments,!1,!1,!1)},r.extendDeep=function(){return i(arguments,!0,!1,!1)},r.extendDeepAll=function(){return i(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return i(arguments,!0,!1,!0)}},{"./is_plain_object.js":718}],709:[function(t,e,r){"use strict";e.exports=function(t){for(var e={},r=[],n=0,a=0;a<t.length;a++){var i=t[a];1!==e[i]&&(e[i]=1,r[n++]=i)}return r}},{}],710:[function(t,e,r){"use strict";function n(t){return!0===t.visible}function a(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?a:n),i=[],o=0;o<t.length;o++){var s=t[o];r(s)&&i.push(s)}return i}},{}],711:[function(t,e,r){"use strict";var n=t("d3"),a=t("country-regex"),i=t("@turf/area"),o=t("@turf/centroid"),s=t("@turf/bbox"),l=t("./identity"),c=t("./loggers"),u=t("./is_plain_object"),h=t("./nested_property"),f=t("./polygon"),p=Object.keys(a),d={"ISO-3":l,"USA-states":l,"country names":function(t){for(var e=0;e<p.length;e++){var r=p[e],n=new RegExp(a[r]);if(n.test(t.trim().toLowerCase()))return r}return c.log("Unrecognized country name: "+t+"."),!1}};function g(t){var e=t.geojson,r=window.PlotlyGeoAssets||{},n="string"==typeof e?r[e]:e;return u(n)?n:(c.error("Oops ... something went wrong when fetching "+e),!1)}e.exports={locationToFeature:function(t,e,r){if(!e||"string"!=typeof e)return!1;var n,a,i,o=d[t](e);if(o){if("USA-states"===t)for(n=[],i=0;i<r.length;i++)(a=r[i]).properties&&a.properties.gu&&"USA"===a.properties.gu&&n.push(a);else n=r;for(i=0;i<n.length;i++)if((a=n[i]).id===o)return a;c.log(["Location with id",o,"does not have a matching topojson feature at this resolution."].join(" "))}return!1},feature2polygons:function(t){var e,r,n,a,i=t.geometry,o=i.coordinates,s=t.id,l=[];function c(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e="RUS"===s||"FJI"===s?function(t){var e;if(null===c(t))e=t;else for(e=new Array(t.length),a=0;a<t.length;a++)e[a]=[t[a][0]<0?t[a][0]+360:t[a][0],t[a][1]];l.push(f.tester(e))}:"ATA"===s?function(t){var e=c(t);if(null===e)return l.push(f.tester(t));var r=new Array(t.length+1),n=0;for(a=0;a<t.length;a++)a>e?r[n++]=[t[a][0]+360,t[a][1]]:a===e?(r[n++]=t[a],r[n++]=[t[a][0],-90]):r[n++]=t[a];var i=f.tester(r);i.pts.pop(),l.push(i)}:function(t){l.push(f.tester(t))},i.type){case"MultiPolygon":for(r=0;r<o.length;r++)for(n=0;n<o[r].length;n++)e(o[r][n]);break;case"Polygon":for(r=0;r<o.length;r++)e(o[r])}return l},getTraceGeojson:g,extractTraceFeature:function(t){var e=t[0].trace,r=g(e);if(!r)return!1;var n,a={},s=[];for(n=0;n<e._length;n++){var l=t[n];(l.loc||0===l.loc)&&(a[l.loc]=l)}function u(t){var r=h(t,e.featureidkey||"id").get(),n=a[r];if(n){var l=t.geometry;if("Polygon"===l.type||"MultiPolygon"===l.type){var u={type:"Feature",id:r,geometry:l,properties:{}};u.properties.ct=function(t){var e,r=t.geometry;if("MultiPolygon"===r.type)for(var n=r.coordinates,a=0,s=0;s<n.length;s++){var l={type:"Polygon",coordinates:n[s]},c=i.default(l);c>a&&(a=c,e=l)}else e=r;return o.default(e).geometry.coordinates}(u),n.fIn=t,n.fOut=u,s.push(u)}else c.log(["Location",n.loc,"does not have a valid GeoJSON geometry.","Traces with locationmode *geojson-id* only support","*Polygon* and *MultiPolygon* geometries."].join(" "))}delete a[r]}switch(r.type){case"FeatureCollection":var f=r.features;for(n=0;n<f.length;n++)u(f[n]);break;case"Feature":u(r);break;default:return c.warn(["Invalid GeoJSON type",(r.type||"none")+".","Traces with locationmode *geojson-id* only support","*FeatureCollection* and *Feature* types."].join(" ")),!1}for(var p in a)c.log(["Location *"+p+"*","does not have a matching feature with id-key","*"+e.featureidkey+"*."].join(" "));return s},fetchTraceGeoData:function(t){var e=window.PlotlyGeoAssets||{},r=[];function a(t){return new Promise(function(r,a){n.json(t,function(n,i){if(n){delete e[t];var o=404===n.status?'GeoJSON at URL "'+t+'" does not exist.':"Unexpected error while fetching from "+t;return a(new Error(o))}return e[t]=i,r(i)})})}function i(t){return new Promise(function(r,n){var a=0,i=setInterval(function(){return e[t]&&"pending"!==e[t]?(clearInterval(i),r(e[t])):a>100?(clearInterval(i),n("Unexpected error while fetching from "+t)):void a++},50)})}for(var o=0;o<t.length;o++){var s=t[o][0].trace.geojson;"string"==typeof s&&(e[s]?"pending"===e[s]&&r.push(i(s)):(e[s]="pending",r.push(a(s))))}return r},computeBbox:function(t){return s.default(t)}}},{"./identity":716,"./is_plain_object":718,"./loggers":721,"./nested_property":725,"./polygon":729,"@turf/area":57,"@turf/bbox":58,"@turf/centroid":59,"country-regex":136,d3:165}],712:[function(t,e,r){"use strict";var n=t("../constants/numerical").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],a=[],i=0;i<t.length;i++){var o=t[i].lonlat;o[0]!==n?a.push(o):!e&&a.length>0&&(r.push(a),a=[])}return a.length>0&&r.push(a),r},r.makeLine=function(t){return 1===t.length?{type:"LineString",coordinates:t[0]}:{type:"MultiLineString",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:"Polygon",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:"MultiPolygon",coordinates:e}},r.makeBlank=function(){return{type:"Point",coordinates:[]}}},{"../constants/numerical":693}],713:[function(t,e,r){"use strict";var n,a,i,o=t("./mod").mod;function s(t,e,r,n,a,i,o,s){var l=r-t,c=a-t,u=o-a,h=n-e,f=i-e,p=s-i,d=l*p-u*h;if(0===d)return null;var g=(c*p-u*f)/d,v=(c*h-l*f)/d;return v<0||v>1||g<0||g>1?null:{x:t+l*g,y:e+h*g}}function l(t,e,r,n,a){var i=n*t+a*e;if(i<0)return n*n+a*a;if(i>r){var o=n-t,s=a-e;return o*o+s*s}var l=n*e-a*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,a,i,o,c){if(s(t,e,r,n,a,i,o,c))return 0;var u=r-t,h=n-e,f=o-a,p=c-i,d=u*u+h*h,g=f*f+p*p,v=Math.min(l(u,h,d,a-t,i-e),l(u,h,d,o-t,c-e),l(f,p,g,t-a,e-i),l(f,p,g,r-a,n-i));return Math.sqrt(v)},r.getTextLocation=function(t,e,r,s){if(t===a&&s===i||(n={},a=t,i=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),h=t.getPointAtLength(o(r,e)),f={x:(4*h.x+l.x+c.x)/6,y:(4*h.y+l.y+c.y)/6,theta:u};return n[r]=f,f},r.clearLocationCache=function(){a=null},r.getVisibleSegment=function(t,e,r){var n,a,i=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),h=u;function f(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(a=r);var c=r.x<i?i-r.x:r.x>o?r.x-o:0,h=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+h*h)}for(var p=f(c);p;){if((c+=p+r)>h)return;p=f(c)}for(p=f(h);p;){if(c>(h-=p+r))return;p=f(h)}return{min:c,max:h,len:h-c,total:u,isClosed:0===c&&h===u&&Math.abs(n.x-a.x)<.1&&Math.abs(n.y-a.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var a,i,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,h=0,f=0,p=s;h<c;){if(a=(f+p)/2,o=(i=t.getPointAtLength(a))[r]-e,Math.abs(o)<l)return i;u*o>0?p=a:f=a,h++}return i}},{"./mod":724}],714:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("tinycolor2"),i=t("color-normalize"),o=t("../components/colorscale"),s=t("../components/color/attributes").defaultLine,l=t("./array").isArrayOrTypedArray,c=i(s),u=1;function h(t,e){var r=t;return r[3]*=e,r}function f(t){if(n(t))return c;var e=i(t);return e.length?e:c}function p(t){return n(t)?t:u}e.exports={formatColor:function(t,e,r){var n,a,s,d,g,v=t.color,m=l(v),y=l(e),x=o.extractOpts(t),b=[];if(n=void 0!==x.colorscale?o.makeColorScaleFuncFromTrace(t):f,a=m?function(t,e){return void 0===t[e]?c:i(n(t[e]))}:f,s=y?function(t,e){return void 0===t[e]?u:p(t[e])}:p,m||y)for(var _=0;_<r;_++)d=a(v,_),g=s(e,_),b[_]=h(d,g);else b=h(i(v),e);return b},parseColorScale:function(t,e){void 0===e&&(e=1);var r=o.extractOpts(t);return(r.reversescale?o.flipScale(r.colorscale):r.colorscale).map(function(t){var r=t[0],n=a(t[1]).toRgb();return{index:r,rgb:[n.r,n.g,n.b,e]}})}}},{"../components/color/attributes":590,"../components/colorscale":603,"./array":700,"color-normalize":122,"fast-isnumeric":228,tinycolor2:535}],715:[function(t,e,r){"use strict";var n=t("./identity");function a(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:a,descend:n,wrap:a,unwrap:function(t){return t[0]}}},{"./identity":716}],716:[function(t,e,r){"use strict";e.exports=function(t){return t}},{}],717:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../constants/numerical"),o=i.FP_SAFE,s=i.BADNUM,l=e.exports={};l.nestedProperty=t("./nested_property"),l.keyedContainer=t("./keyed_container"),l.relativeAttr=t("./relative_attr"),l.isPlainObject=t("./is_plain_object"),l.toLogRange=t("./to_log_range"),l.relinkPrivateKeys=t("./relink_private");var c=t("./array");l.isTypedArray=c.isTypedArray,l.isArrayOrTypedArray=c.isArrayOrTypedArray,l.isArray1D=c.isArray1D,l.ensureArray=c.ensureArray,l.concat=c.concat,l.maxRowLength=c.maxRowLength,l.minRowLength=c.minRowLength;var u=t("./mod");l.mod=u.mod,l.modHalf=u.modHalf;var h=t("./coerce");l.valObjectMeta=h.valObjectMeta,l.coerce=h.coerce,l.coerce2=h.coerce2,l.coerceFont=h.coerceFont,l.coerceHoverinfo=h.coerceHoverinfo,l.coerceSelectionMarkerOpacity=h.coerceSelectionMarkerOpacity,l.validate=h.validate;var f=t("./dates");l.dateTime2ms=f.dateTime2ms,l.isDateTime=f.isDateTime,l.ms2DateTime=f.ms2DateTime,l.ms2DateTimeLocal=f.ms2DateTimeLocal,l.cleanDate=f.cleanDate,l.isJSDate=f.isJSDate,l.formatDate=f.formatDate,l.incrementMonth=f.incrementMonth,l.dateTick0=f.dateTick0,l.dfltRange=f.dfltRange,l.findExactDates=f.findExactDates,l.MIN_MS=f.MIN_MS,l.MAX_MS=f.MAX_MS;var p=t("./search");l.findBin=p.findBin,l.sorterAsc=p.sorterAsc,l.sorterDes=p.sorterDes,l.distinctVals=p.distinctVals,l.roundUp=p.roundUp,l.sort=p.sort,l.findIndexOfMin=p.findIndexOfMin;var d=t("./stats");l.aggNums=d.aggNums,l.len=d.len,l.mean=d.mean,l.median=d.median,l.midRange=d.midRange,l.variance=d.variance,l.stdev=d.stdev,l.interp=d.interp;var g=t("./matrix");l.init2dArray=g.init2dArray,l.transposeRagged=g.transposeRagged,l.dot=g.dot,l.translationMatrix=g.translationMatrix,l.rotationMatrix=g.rotationMatrix,l.rotationXYMatrix=g.rotationXYMatrix,l.apply2DTransform=g.apply2DTransform,l.apply2DTransform2=g.apply2DTransform2;var v=t("./angles");l.deg2rad=v.deg2rad,l.rad2deg=v.rad2deg,l.angleDelta=v.angleDelta,l.angleDist=v.angleDist,l.isFullCircle=v.isFullCircle,l.isAngleInsideSector=v.isAngleInsideSector,l.isPtInsideSector=v.isPtInsideSector,l.pathArc=v.pathArc,l.pathSector=v.pathSector,l.pathAnnulus=v.pathAnnulus;var m=t("./anchor_utils");l.isLeftAnchor=m.isLeftAnchor,l.isCenterAnchor=m.isCenterAnchor,l.isRightAnchor=m.isRightAnchor,l.isTopAnchor=m.isTopAnchor,l.isMiddleAnchor=m.isMiddleAnchor,l.isBottomAnchor=m.isBottomAnchor;var y=t("./geometry2d");l.segmentsIntersect=y.segmentsIntersect,l.segmentDistance=y.segmentDistance,l.getTextLocation=y.getTextLocation,l.clearLocationCache=y.clearLocationCache,l.getVisibleSegment=y.getVisibleSegment,l.findPointOnPath=y.findPointOnPath;var x=t("./extend");l.extendFlat=x.extendFlat,l.extendDeep=x.extendDeep,l.extendDeepAll=x.extendDeepAll,l.extendDeepNoArrays=x.extendDeepNoArrays;var b=t("./loggers");l.log=b.log,l.warn=b.warn,l.error=b.error;var _=t("./regex");l.counterRegex=_.counter;var w=t("./throttle");l.throttle=w.throttle,l.throttleDone=w.done,l.clearThrottle=w.clear;var k=t("./dom");function T(t){var e={};for(var r in t)for(var n=t[r],a=0;a<n.length;a++)e[n[a]]=+r;return e}l.getGraphDiv=k.getGraphDiv,l.isPlotDiv=k.isPlotDiv,l.removeElement=k.removeElement,l.addStyleRule=k.addStyleRule,l.addRelatedStyleRule=k.addRelatedStyleRule,l.deleteRelatedStyleRule=k.deleteRelatedStyleRule,l.clearResponsive=t("./clear_responsive"),l.makeTraceGroups=t("./make_trace_groups"),l._=t("./localize"),l.notifier=t("./notifier"),l.filterUnique=t("./filter_unique"),l.filterVisible=t("./filter_visible"),l.pushUnique=t("./push_unique"),l.cleanNumber=t("./clean_number"),l.ensureNumber=function(t){return a(t)?(t=Number(t))<-o||t>o?s:a(t)?Number(t):s:s},l.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(a(t)&&t>=0&&t%1==0)},l.noop=t("./noop"),l.identity=t("./identity"),l.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},l.swapAttrs=function(t,e,r,n){r||(r="x"),n||(n="y");for(var a=0;a<e.length;a++){var i=e[a],o=l.nestedProperty(t,i.replace("?",r)),s=l.nestedProperty(t,i.replace("?",n)),c=o.get();o.set(s.get()),s.set(c)}},l.raiseToTop=function(t){t.parentNode.appendChild(t)},l.cancelTransition=function(t){return t.transition().duration(0)},l.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},l.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},l.simpleMap=function(t,e,r,n){for(var a=t.length,i=new Array(a),o=0;o<a;o++)i[o]=e(t[o],r,n);return i},l.randstr=function t(e,r,n,a){if(n||(n=16),void 0===r&&(r=24),r<=0)return"0";var i,o,s=Math.log(Math.pow(2,r))/Math.log(n),c="";for(i=2;s===1/0;i*=2)s=Math.log(Math.pow(2,r/i))/Math.log(n)*i;var u=s-Math.floor(s);for(i=0;i<Math.floor(s);i++)c=Math.floor(Math.random()*n).toString(n)+c;u&&(o=Math.pow(n,u),c=Math.floor(Math.random()*o).toString(n)+c);var h=parseInt(c,n);return e&&e[c]||h!==1/0&&h>=Math.pow(2,r)?a>10?(l.warn("randstr failed uniqueness"),c):t(e,r,n,(a||0)+1):c},l.OptionControl=function(t,e){t||(t={}),e||(e="opt");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r["_"+e]=t,r},l.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,a,i,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(i=0,n=0;n<l;n++)(a=r+n+1-e)<-o?a-=s*Math.round(a/s):a>=s&&(a-=s*Math.floor(a/s)),a<0?a=-1-a:a>=o&&(a=s-1-a),i+=t[a]*c[n];u[r]=i}return u},l.syncOrAsync=function(t,e,r){var n;function a(){return l.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(a).then(void 0,l.promiseError);return r&&r(e)},l.stripTrailingSlash=function(t){return"/"===t.substr(-1)?t.substr(0,t.length-1):t},l.noneOrAll=function(t,e,r){if(t){var n,a=!1,i=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?a=!0:i=!1;if(a&&!i)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},l.mergeArray=function(t,e,r,n){var a="function"==typeof n;if(l.isArrayOrTypedArray(t))for(var i=Math.min(t.length,e.length),o=0;o<i;o++){var s=t[o];e[o][r]=a?n(s):s}},l.mergeArrayCastPositive=function(t,e,r){return l.mergeArray(t,e,r,function(t){var e=+t;return isFinite(e)&&e>0?e:0})},l.fillArray=function(t,e,r,n){if(n=n||l.identity,l.isArrayOrTypedArray(t))for(var a=0;a<e.length;a++)e[a][r]=n(t[a])},l.castOption=function(t,e,r,n){n=n||l.identity;var a=l.nestedProperty(t,r).get();return l.isArrayOrTypedArray(a)?Array.isArray(e)&&l.isArrayOrTypedArray(a[e[0]])?n(a[e[0]][e[1]]):n(a[e]):a},l.extractOption=function(t,e,r,n){if(r in t)return t[r];var a=l.nestedProperty(e,n).get();return Array.isArray(a)?void 0:a},l.tagSelected=function(t,e,r){var n,a,i=e.selectedpoints,o=e._indexToPoints;o&&(n=T(o));for(var s=0;s<i.length;s++){var c=i[s];if(l.isIndex(c)||l.isArrayOrTypedArray(c)&&l.isIndex(c[0])&&l.isIndex(c[1])){var u=n?n[c]:c,h=r?r[u]:u;void 0!==(a=h)&&a<t.length&&(t[h].selected=1)}}},l.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=T(r),a=[],i=0;i<e.length;i++){var o=e[i];if(l.isIndex(o)){var s=n[o];l.isIndex(s)&&a.push(s)}}return a}return e},l.getTargetArray=function(t,e){var r=e.target;if("string"==typeof r&&r){var n=l.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},l.minExtend=function(t,e){var r={};"object"!=typeof e&&(e={});var n,a,i,o=Object.keys(t);for(n=0;n<o.length;n++)i=t[a=o[n]],"_"!==a.charAt(0)&&"function"!=typeof i&&("module"===a?r[a]=i:Array.isArray(i)?r[a]="colorscale"===a?i.slice():i.slice(0,3):l.isTypedArray(i)?r[a]=i.subarray(0,3):r[a]=i&&"object"==typeof i?l.minExtend(t[a],e[a]):i);for(o=Object.keys(e),n=0;n<o.length;n++)"object"==typeof(i=e[a=o[n]])&&a in r&&"object"==typeof r[a]||(r[a]=i);return r},l.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},l.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},l.isIE=function(){return"undefined"!=typeof window.navigator.msSaveBlob};var M=/MSIE [1-9]\./;l.isIE9orBelow=function(){return l.isIE()&&M.test(window.navigator.userAgent)};var A=/Version\/[\d\.]+.*Safari/;l.isSafari=function(){return A.test(window.navigator.userAgent)},l.isD3Selection=function(t){return t&&"function"==typeof t.classed},l.ensureSingle=function(t,e,r,n){var a=t.select(e+(r?"."+r:""));if(a.size())return a;var i=t.append(e);return r&&i.classed(r,!0),n&&i.call(n),i},l.ensureSingleById=function(t,e,r,n){var a=t.select(e+"#"+r);if(a.size())return a;var i=t.append(e).attr("id",r);return n&&i.call(n),i},l.objectFromPath=function(t,e){for(var r,n=t.split("."),a=r={},i=0;i<n.length;i++){var o=n[i],s=null,l=n[i].match(/(.*)\[([0-9]+)\]/);l?(o=l[1],s=l[2],r=r[o]=[],i===n.length-1?r[s]=e:r[s]={},r=r[s]):(i===n.length-1?r[o]=e:r[o]={},r=r[o])}return a};var S=/^([^\[\.]+)\.(.+)?/,E=/^([^\.]+)\[([0-9]+)\](\.)?(.+)?/;l.expandObjectPaths=function(t){var e,r,n,a,i,o,s;if("object"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(S))?(a=t[r],n=e[1],delete t[r],t[n]=l.extendDeepNoArrays(t[n]||{},l.objectFromPath(r,l.expandObjectPaths(a))[n])):(e=r.match(E))?(a=t[r],n=e[1],i=parseInt(e[2]),delete t[r],t[n]=t[n]||[],"."===e[3]?(s=e[4],o=t[n][i]=t[n][i]||{},l.extendDeepNoArrays(o,l.objectFromPath(s,l.expandObjectPaths(a)))):t[n][i]=l.expandObjectPaths(a)):t[r]=l.expandObjectPaths(t[r]));return t},l.numSeparate=function(t,e,r){if(r||(r=!1),"string"!=typeof e||0===e.length)throw new Error("Separator string required for formatting!");"number"==typeof t&&(t=String(t));var n=/(\d+)(\d{3})/,a=e.charAt(0),i=e.charAt(1),o=t.split("."),s=o[0],l=o.length>1?a+o[1]:"";if(i&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,"$1"+i+"$2");return s+l},l.TEMPLATE_STRING_REGEX=/%{([^\s%{}:]*)([:|\|][^}]*)?}/g;var L=/^\w*$/;l.templateString=function(t,e){var r={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,n){var a;return L.test(n)?a=e[n]:(r[n]=r[n]||l.nestedProperty(e,n).get,a=r[n]()),l.isValidTextValue(a)?a:""})};var C={max:10,count:0,name:"hovertemplate"};l.hovertemplateString=function(){return z.apply(C,arguments)};var P={max:10,count:0,name:"texttemplate"};l.texttemplateString=function(){return z.apply(P,arguments)};var O=/^[:|\|]/;function z(t,e,r){var a=this,i=arguments;e||(e={});var o={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,s,c){var u,h,f,p;for(f=3;f<i.length;f++)if(u=i[f]){if(u.hasOwnProperty(s)){h=u[s];break}if(L.test(s)||(h=o[s]||l.nestedProperty(u,s).get())&&(o[s]=h),void 0!==h)break}if(void 0===h&&a)return a.count<a.max&&(l.warn("Variable '"+s+"' in "+a.name+" could not be found!"),h=t),a.count===a.max&&l.warn("Too many "+a.name+" warnings - additional warnings will be suppressed"),a.count++,t;if(c){if(":"===c[0]&&(h=(p=r?r.numberFormat:n.format)(c.replace(O,""))(h)),"|"===c[0]){p=r?r.timeFormat.utc:n.time.format.utc;var d=l.dateTime2ms(h);h=l.formatDate(d,c.replace(O,""),!1,p)}}else e.hasOwnProperty(s+"Label")&&(h=e[s+"Label"]);return h})}l.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,a=0,i=0;i<r;i++){var o=t.charCodeAt(i)||0,s=e.charCodeAt(i)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(a=10*a+s-48),!l||!c){if(n!==a)return n-a;if(o!==s)return o-s}}return a-n};var I=2e9;l.seedPseudoRandom=function(){I=2e9},l.pseudoRandom=function(){var t=I;return I=(69069*I+1)%4294967296,Math.abs(I-t)<429496729?l.pseudoRandom():I/4294967296},l.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},a=l.extractOption(t,e,"htx","hovertext");if(l.isValidTextValue(a))return n(a);var i=l.extractOption(t,e,"tx","text");return l.isValidTextValue(i)?n(i):void 0},l.isValidTextValue=function(t){return t||0===t},l.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+"%",n=0;n<e;n++)-1!==r.indexOf(".")&&(r=(r=r.replace("0%","%")).replace(".%","%"));return r},l.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||"none"===e},l.getTextTransform=function(t){var e=t.noCenter,r=t.textX,n=t.textY,a=t.targetX,i=t.targetY,o=t.anchorX||0,s=t.anchorY||0,l=t.rotate,c=t.scale;return c?c>1&&(c=1):c=0,"translate("+(a-c*(r+o))+","+(i-c*(n+s))+")"+(c<1?"scale("+c+")":"")+(l?"rotate("+l+(e?"":" "+r+" "+n)+")":"")},l.ensureUniformFontSize=function(t,e){var r=l.extendFlat({},e);return r.size=Math.max(e.size,t._fullLayout.uniformtext.minsize||0),r}},{"../constants/numerical":693,"./anchor_utils":698,"./angles":699,"./array":700,"./clean_number":701,"./clear_responsive":703,"./coerce":704,"./dates":705,"./dom":706,"./extend":708,"./filter_unique":709,"./filter_visible":710,"./geometry2d":713,"./identity":716,"./is_plain_object":718,"./keyed_container":719,"./localize":720,"./loggers":721,"./make_trace_groups":722,"./matrix":723,"./mod":724,"./nested_property":725,"./noop":726,"./notifier":727,"./push_unique":731,"./regex":733,"./relative_attr":734,"./relink_private":735,"./search":736,"./stats":739,"./throttle":742,"./to_log_range":743,d3:165,"fast-isnumeric":228}],718:[function(t,e,r){"use strict";e.exports=function(t){return window&&window.process&&window.process.versions?"[object Object]"===Object.prototype.toString.call(t):"[object Object]"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t)===Object.prototype}},{}],719:[function(t,e,r){"use strict";var n=t("./nested_property"),a=/^\w*$/;e.exports=function(t,e,r,i){var o,s,l;r=r||"name",i=i||"value";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||"";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var h=a.test(i),f={set:function(t,e){var a=null===e?4:0;if(!s){if(!l||4===a)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===a)return;a|=3,o=s.length,u[t]=o}else e!==(h?s[o][i]:n(s[o],i).get())&&(a|=2);var p=s[o]=s[o]||{};return p[r]=t,h?p[i]=e:n(p,i).set(e),null!==e&&(a&=-5),c[o]=c[o]|a,f},get:function(t){if(s){var e=u[t];return void 0===e?void 0:h?s[e][i]:n(s[e],i).get()}},rename:function(t,e){var n=u[t];return void 0===n?f:(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e,f)},remove:function(t){var e=u[t];if(void 0===e)return f;var a=s[e];if(Object.keys(a).length>2)return c[e]=2|c[e],f.set(t,null);if(h){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(a,i).set(null),c[e]=6|c[e];return f},constructUpdate:function(){for(var t,a,o={},l=Object.keys(c),u=0;u<l.length;u++)a=l[u],t=e+"["+a+"]",s[a]?(1&c[a]&&(o[t+"."+r]=s[a][r]),2&c[a]&&(o[t+"."+i]=h?4&c[a]?null:s[a][i]:4&c[a]?null:n(s[a],i).get())):o[t]=null;return o}};return f}},{"./nested_property":725}],720:[function(t,e,r){"use strict";var n=t("../registry");e.exports=function(t,e){for(var r=t._context.locale,a=0;a<2;a++){for(var i=t._context.locales,o=0;o<2;o++){var s=(i[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}i=n.localeRegistry}var c=r.split("-")[0];if(c===r)break;r=c}return e}},{"../registry":846}],721:[function(t,e,r){"use strict";var n=t("../plot_api/plot_config").dfltConfig,a=t("./notifier"),i=e.exports={};function o(t,e){if(t&&t.apply)try{return void t.apply(console,e)}catch(t){}for(var r=0;r<e.length;r++)try{t(e[r])}catch(t){console.log(e[r])}}i.log=function(){var t;if(n.logging>1){var e=["LOG:"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.trace||console.log,e)}if(n.notifyOnLogging>1){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);a(r.join("<br>"),"long")}},i.warn=function(){var t;if(n.logging>0){var e=["WARN:"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.trace||console.log,e)}if(n.notifyOnLogging>0){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);a(r.join("<br>"),"stick")}},i.error=function(){var t;if(n.logging>0){var e=["ERROR:"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.error,e)}if(n.notifyOnLogging>0){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);a(r.join("<br>"),"stick")}}},{"../plot_api/plot_config":753,"./notifier":727}],722:[function(t,e,r){"use strict";var n=t("d3");e.exports=function(t,e,r){var a=t.selectAll("g."+r.replace(/\s/g,".")).data(e,function(t){return t[0].trace.uid});a.exit().remove(),a.enter().append("g").attr("class",r),a.order();var i=t.classed("rangeplot")?"nodeRangePlot3":"node3";return a.each(function(t){t[0][i]=n.select(this)}),a}},{d3:165}],723:[function(t,e,r){"use strict";r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,a=t.length;for(e=0;e<a;e++)n=Math.max(n,t[e].length);var i=new Array(n);for(e=0;e<n;e++)for(i[e]=new Array(a),r=0;r<a;r++)i[e][r]=t[r][e];return i},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,a,i=t.length;if(t[0].length)for(n=new Array(i),a=0;a<i;a++)n[a]=r.dot(t[a],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),a=0;a<o.length;a++)n[a]=r.dot(t,o[a])}else for(n=0,a=0;a<i;a++)n+=t[a]*e[a];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}}},{}],724:[function(t,e,r){"use strict";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],725:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("./array").isArrayOrTypedArray;function i(t,e){return function(){var r,n,o,s,l,c=t;for(s=0;s<e.length-1;s++){if(-1===(r=e[s])){for(n=!0,o=[],l=0;l<c.length;l++)o[l]=i(c[l],e.slice(s+1))(),o[l]!==o[0]&&(n=!1);return n?o[0]:o}if("number"==typeof r&&!a(c))return;if("object"!=typeof(c=c[r])||null===c)return}if("object"==typeof c&&null!==c&&null!==(o=c[e[s]]))return o}}e.exports=function(t,e){if(n(e))e=String(e);else if("string"!=typeof e||"[-1]"===e.substr(e.length-4))throw"bad property string";for(var r,a,o,s=0,c=e.split(".");s<c.length;){if(r=String(c[s]).match(/^([^\[\]]*)((\[\-?[0-9]*\])+)$/)){if(r[1])c[s]=r[1];else{if(0!==s)throw"bad property string";c.splice(0,1)}for(a=r[2].substr(1,r[2].length-2).split("]["),o=0;o<a.length;o++)s++,c.splice(s,0,Number(a[o]))}s++}return"object"!=typeof t?function(t,e,r){return{set:function(){throw"bad container"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:l(t,c,e),get:i(t,c),astr:e,parts:c,obj:t}};var o=/(^|\.)args\[/;function s(t,e){return void 0===t||null===t&&!e.match(o)}function l(t,e,r){return function(n){var i,o,l=t,f="",p=[[t,f]],d=s(n,r);for(o=0;o<e.length-1;o++){if("number"==typeof(i=e[o])&&!a(l))throw"array index but container is not an array";if(-1===i){if(d=!u(l,e.slice(o+1),n,r))break;return}if(!h(l,i,e[o+1],d))break;if("object"!=typeof(l=l[i])||null===l)throw"container is not an object";f=c(f,i),p.push([l,f])}if(d){if(o===e.length-1&&(delete l[e[o]],Array.isArray(l)&&+e[o]==l.length-1))for(;l.length&&void 0===l[l.length-1];)l.pop()}else l[e[o]]=n}}function c(t,e){var r=e;return n(e)?r="["+e+"]":t&&(r="."+e),t+r}function u(t,e,r,n){var i,o=a(r),c=!0,u=r,f=n.replace("-1",0),p=!o&&s(r,f),d=e[0];for(i=0;i<t.length;i++)f=n.replace("-1",i),o&&(p=s(u=r[i%r.length],f)),p&&(c=!1),h(t,i,d,p)&&l(t[i],e,n.replace("-1",i))(u);return c}function h(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]="number"==typeof r?[]:{}}return!0}},{"./array":700,"fast-isnumeric":228}],726:[function(t,e,r){"use strict";e.exports=function(){}},{}],727:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=[];e.exports=function(t,e){if(-1===i.indexOf(t)){i.push(t);var r=1e3;a(e)?r=e:"long"===e&&(r=3e3);var o=n.select("body").selectAll(".plotly-notifier").data([0]);o.enter().append("div").classed("plotly-notifier",!0),o.selectAll(".notifier-note").data(i).enter().append("div").classed("notifier-note",!0).style("opacity",0).each(function(t){var a=n.select(this);a.append("button").classed("notifier-close",!0).html("&times;").on("click",function(){a.transition().call(s)});for(var i=a.append("p"),o=t.split(/<br\s*\/?>/g),l=0;l<o.length;l++)l&&i.append("br"),i.append("span").text(o[l]);"stick"===e?a.transition().duration(350).style("opacity",1):a.transition().duration(700).style("opacity",1).transition().delay(r).call(s)})}function s(t){t.duration(700).style("opacity",0).each("end",function(t){var e=i.indexOf(t);-1!==e&&i.splice(e,1),n.select(this).remove()})}}},{d3:165,"fast-isnumeric":228}],728:[function(t,e,r){"use strict";var n=t("./setcursor"),a="data-savedcursor";e.exports=function(t,e){var r=t.attr(a);if(e){if(!r){for(var i=(t.attr("class")||"").split(" "),o=0;o<i.length;o++){var s=i[o];0===s.indexOf("cursor-")&&t.attr(a,s.substr(7)).classed(s,!1)}t.attr(a)||t.attr(a,"!!")}n(t,e)}else r&&(t.attr(a,null),"!!"===r?n(t):n(t,r))}},{"./setcursor":737}],729:[function(t,e,r){"use strict";var n=t("./matrix").dot,a=t("../constants/numerical").BADNUM,i=e.exports={};i.tester=function(t){var e,r=t.slice(),n=r[0][0],i=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),i=Math.max(i,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,h=r[0];for(e=1;e<r.length;e++)if(h[0]!==r[e][0]||h[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:i,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===a||r<n||r>i||c===a||c<o||c>s||e&&l(t))}:function(t,e){var l=t[0],c=t[1];if(l===a||l<n||l>i||c===a||c<o||c>s)return!1;var u,h,f,p,d,g=r.length,v=r[0][0],m=r[0][1],y=0;for(u=1;u<g;u++)if(h=v,f=m,v=r[u][0],m=r[u][1],!(l<(p=Math.min(h,v))||l>Math.max(h,v)||c>Math.max(f,m)))if(c<Math.min(f,m))l!==p&&y++;else{if(c===(d=v===h?c:f+(l-h)*(m-f)/(v-h)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}},i.isSegmentBent=function(t,e,r,a){var i,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),h=Math.sqrt(u),f=[-c[1]/h,c[0]/h];for(i=e+1;i<r;i++)if(o=[t[i][0]-l[0],t[i][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,f))>a)return!0;return!1},i.filter=function(t,e){var r=[t[0]],n=0,a=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(a+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||i.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,a=r.length-1),l=c)}t.length>1&&o(t.pop());return{addPt:o,raw:t,filtered:r}}},{"../constants/numerical":693,"./matrix":723}],730:[function(t,e,r){(function(r){"use strict";var n=t("./show_no_webgl_msg"),a=t("regl");e.exports=function(t,e){var i=t._fullLayout,o=!0;return i._glcanvas.each(function(n){if(!n.regl&&(!n.pick||i._has("parcoords"))){try{n.regl=a({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}o&&this.addEventListener("webglcontextlost",function(e){t&&t.emit&&t.emit("plotly_webglcontextlost",{event:e,layer:n.key})},!1)}}),o||n({container:i._glcontainer.node()}),o}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./show_no_webgl_msg":738,regl:500}],731:[function(t,e,r){"use strict";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],732:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../plot_api/plot_config").dfltConfig;var i={add:function(t,e,r,n,i){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(i)),t.undoQueue.queue.length>a.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.undo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)i.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.redo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)i.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};i.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,a=[],i=0;i<e.length;i++)r=e[i],a[i]=r===t?r:"object"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return a}(t,r),e.apply(null,r)},e.exports=i},{"../lib":717,"../plot_api/plot_config":753}],733:[function(t,e,r){"use strict";r.counter=function(t,e,r,n){var a=(e||"")+(r?"":"$"),i=!1===n?"":"^";return"xy"===t?new RegExp(i+"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?"+a):new RegExp(i+t+"([2-9]|[1-9][0-9]+)?"+a)}},{}],734:[function(t,e,r){"use strict";var n=/^(.*)(\.[^\.\[\]]+|\[\d\])$/,a=/^[^\.\[\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(a))throw new Error("bad relativeAttr call:"+[t,e]);t=""}if("^"!==e.charAt(0))break;e=e.slice(1)}return t&&"["!==e.charAt(0)?t+"."+e:t+e}},{}],735:[function(t,e,r){"use strict";var n=t("./array").isArrayOrTypedArray,a=t("./is_plain_object");e.exports=function t(e,r){for(var i in r){var o=r[i],s=e[i];if(s!==o)if("_"===i.charAt(0)||"function"==typeof o){if(i in e)continue;e[i]=o}else if(n(o)&&n(s)&&a(o[0])){if("customdata"===i||"ids"===i)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&a(o[c])&&a(s[c])&&t(s[c],o[c])}else a(o)&&a(s)&&(t(s,o),Object.keys(s).length||delete e[i])}}},{"./array":700,"./is_plain_object":718}],736:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("./loggers"),i=t("./identity");function o(t,e){return t<e}function s(t,e){return t<=e}function l(t,e){return t>e}function c(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var i,u,h=0,f=e.length,p=0,d=f>1?(e[f-1]-e[0])/(f-1):1;for(u=d>=0?r?o:s:r?c:l,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);h<f&&p++<100;)u(e[i=Math.floor((h+f)/2)],t)?h=i+1:f=i;return p>90&&a.log("Long binary search..."),h-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t){var e=t.slice();e.sort(r.sorterAsc);for(var n=e.length-1,a=e[n]-e[0]||1,i=a/(n||1)/1e4,o=[e[0]],s=0;s<n;s++)e[s+1]>e[s]+i&&(a=Math.min(a,e[s+1]-e[s]),o.push(e[s+1]));return{vals:o,minDiff:a}},r.roundUp=function(t,e,r){for(var n,a=0,i=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;a<i&&o++<100;)e[n=c((a+i)/2)]<=t?a=n+s:i=n-l;return e[a]},r.sort=function(t,e){for(var r=0,n=0,a=1;a<t.length;a++){var i=e(t[a],t[a-1]);if(i<0?r=1:i>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||i;for(var r,n=1/0,a=0;a<t.length;a++){var o=e(t[a]);o<n&&(n=o,r=a)}return r}},{"./identity":716,"./loggers":721,"fast-isnumeric":228}],737:[function(t,e,r){"use strict";e.exports=function(t,e){(t.attr("class")||"").split(" ").forEach(function(e){0===e.indexOf("cursor-")&&t.classed(e,!1)}),e&&t.classed("cursor-"+e,!0)}},{}],738:[function(t,e,r){"use strict";var n=t("../components/color"),a=function(){};e.exports=function(t){for(var e in t)"function"==typeof t[e]&&(t[e]=a);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement("div");r.className="no-webgl",r.style.cursor="pointer",r.style.fontSize="24px",r.style.color=n.defaults[0],r.style.position="absolute",r.style.left=r.style.top="0px",r.style.width=r.style.height="100%",r.style["background-color"]=n.lightLine,r.style["z-index"]=30;var i=document.createElement("p");return i.textContent="WebGL is not supported by your browser - visit https://get.webgl.org for more info",i.style.position="relative",i.style.top="50%",i.style.left="50%",i.style.height="30%",i.style.width="50%",i.style.margin="-15% 0 0 -25%",r.appendChild(i),t.container.appendChild(r),t.container.style.background="#FFFFFF",t.container.onclick=function(){window.open("https://get.webgl.org")},!1}},{"../components/color":591}],739:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("./array").isArrayOrTypedArray;r.aggNums=function(t,e,i,o){var s,l;if((!o||o>i.length)&&(o=i.length),n(e)||(e=!1),a(i[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,i[s]);i=l}for(s=0;s<o;s++)n(e)?n(i[s])&&(e=t(+e,+i[s])):e=i[s];return e},r.len=function(t){return r.aggNums(function(t){return t+1},0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums(function(t,e){return t+e},0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,a){return e||(e=r.len(t)),n(a)||(a=r.mean(t,e)),r.aggNums(function(t,e){return t+Math.pow(e-a,2)},0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.median=function(t){var e=t.slice().sort();return r.interp(e,.5)},r.interp=function(t,e){if(!n(e))throw"n should be a finite number";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{"./array":700,"fast-isnumeric":228}],740:[function(t,e,r){"use strict";var n=t("color-normalize");e.exports=function(t){return t?n(t):[0,0,0,1]}},{"color-normalize":122}],741:[function(t,e,r){"use strict";var n=t("d3"),a=t("../lib"),i=t("../constants/xmlns_namespaces"),o=t("../constants/alignment").LINE_SPACING;function s(t,e){return t.node().getBoundingClientRect()[e]}var l=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,A){var S=t.text(),L=!t.attr("data-notex")&&"undefined"!=typeof MathJax&&S.match(l),C=n.select(t.node().parentNode);if(!C.empty()){var P=t.attr("class")?t.attr("class").split(" ")[0]:"text";return P+="-math",C.selectAll("svg."+P).remove(),C.selectAll("g."+P+"-group").remove(),t.style("display",null).attr({"data-unformatted":S,"data-math":"N"}),L?(e&&e._promises||[]).push(new Promise(function(e){t.style("display","none");var r=parseInt(t.node().style.fontSize,10),i={fontSize:r};!function(t,e,r){var i,o,s,l;MathJax.Hub.Queue(function(){return o=a.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:"none",tex2jax:{inlineMath:[["$","$"],["\\(","\\)"]]},displayAlign:"left"})},function(){if("SVG"!==(i=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer("SVG")},function(){var r="math-output-"+a.randstr({},64);return l=n.select("body").append("div").attr({id:r}).style({visibility:"hidden",position:"absolute"}).style({"font-size":e.fontSize+"px"}).text(t.replace(c,"\\lt ").replace(u,"\\gt ")),MathJax.Hub.Typeset(l.node())},function(){var e=n.select("body").select("#MathJax_SVG_glyphs");if(l.select(".MathJax_SVG").empty()||!l.select("svg").node())a.log("There was an error in the tex syntax.",t),r();else{var o=l.select("svg").node().getBoundingClientRect();r(l.select(".MathJax_SVG"),e,o)}if(l.remove(),"SVG"!==i)return MathJax.Hub.setRenderer(i)},function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)})}(L[2],i,function(n,a,i){C.selectAll("svg."+P).remove(),C.selectAll("g."+P+"-group").remove();var o=n&&n.select("svg");if(!o||!o.node())return O(),void e();var l=C.append("g").classed(P+"-group",!0).attr({"pointer-events":"none","data-unformatted":S,"data-math":"Y"});l.node().appendChild(o.node()),a&&a.node()&&o.node().insertBefore(a.node().cloneNode(!0),o.node().firstChild),o.attr({class:P,height:i.height,preserveAspectRatio:"xMinYMin meet"}).style({overflow:"visible","pointer-events":"none"});var c=t.node().style.fill||"black",u=o.select("g");u.attr({fill:c,stroke:c});var h=s(u,"width"),f=s(u,"height"),p=+t.attr("x")-h*{start:0,middle:.5,end:1}[t.attr("text-anchor")||"start"],d=-(r||s(t,"height"))/4;"y"===P[0]?(l.attr({transform:"rotate("+[-90,+t.attr("x"),+t.attr("y")]+") translate("+[-h/2,d-f/2]+")"}),o.attr({x:+t.attr("x"),y:+t.attr("y")})):"l"===P[0]?o.attr({x:t.attr("x"),y:d-f/2}):"a"===P[0]&&0!==P.indexOf("atitle")?o.attr({x:0,y:d}):o.attr({x:p,y:+t.attr("y")+d-f/2}),A&&A.call(t,l),e(l)})})):O(),t}function O(){C.empty()||(P=t.attr("class")+"-math",C.select("svg."+P).remove()),t.text("").style("white-space","pre"),function(t,e){e=e.replace(v," ");var r,s=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(i.svg,"tspan");n.select(e).attr({class:"line",dy:c*o+"em"}),t.appendChild(e),r=e;var a=l;if(l=[{node:e}],a.length>1)for(var s=1;s<a.length;s++)A(a[s])}function A(t){var e,a=t.type,o={};if("a"===a){e="a";var s=t.target,c=t.href,u=t.popup;c&&(o={"xlink:xlink:show":"_blank"===s||"_"!==s.charAt(0)?"new":"replace",target:s,"xlink:xlink:href":c},u&&(o.onclick='window.open(this.href.baseVal,this.target.baseVal,"'+u+'");return false;'))}else e="tspan";t.style&&(o.style=t.style);var h=document.createElementNS(i.svg,e);if("sup"===a||"sub"===a){S(r,d),r.appendChild(h);var g=document.createElementNS(i.svg,"tspan");S(g,d),n.select(g).attr("dy",p[a]),o.dy=f[a],r.appendChild(h),r.appendChild(g)}else r.appendChild(h);n.select(h).attr(o),r=t.node=h,l.push(t)}function S(t,e){t.appendChild(document.createTextNode(e))}function L(t){if(1!==l.length){var n=l.pop();t!==n.type&&a.log("Start tag <"+n.type+"> doesnt match end tag <"+t+">. Pretending it did match.",e),r=l[l.length-1].node}else a.log("Ignoring unexpected end tag </"+t+">.",e)}x.test(e)?u():(r=t,l=[{node:t}]);for(var C=e.split(m),P=0;P<C.length;P++){var O=C[P],z=O.match(y),I=z&&z[2].toLowerCase(),D=h[I];if("br"===I)u();else if(void 0===D)S(r,E(O));else if(z[1])L(I);else{var R=z[4],F={type:I},B=T(R,b);if(B?(B=B.replace(M,"$1 fill:"),D&&(B+=";"+D)):D&&(B=D),B&&(F.style=B),"a"===I){s=!0;var N=T(R,_);if(N){var j=document.createElement("a");j.href=N,-1!==g.indexOf(j.protocol)&&(F.href=encodeURI(decodeURI(N)),F.target=T(R,w)||"_blank",F.popup=T(R,k))}}A(F)}}return s}(t.node(),S)&&t.style("pointer-events","all"),r.positionText(t),A&&A.call(t)}};var c=/(<|&lt;|&#60;)/g,u=/(>|&gt;|&#62;)/g;var h={sup:"font-size:70%",sub:"font-size:70%",b:"font-weight:bold",i:"font-style:italic",a:"cursor:pointer",span:"",em:"font-style:italic;font-weight:bold"},f={sub:"0.3em",sup:"-0.6em"},p={sub:"-0.21em",sup:"0.42em"},d="\u200b",g=["http:","https:","mailto:","",void 0,":"],v=r.NEWLINES=/(\r\n?|\n)/g,m=/(<[^<>]*>)/,y=/<(\/?)([^ >]*)(\s+(.*))?>/i,x=/<br(\s+.*)?>/i;r.BR_TAG_ALL=/<br(\s+.*)?>/gi;var b=/(^|[\s"'])style\s*=\s*("([^"]*);?"|'([^']*);?')/i,_=/(^|[\s"'])href\s*=\s*("([^"]*)"|'([^']*)')/i,w=/(^|[\s"'])target\s*=\s*("([^"\s]*)"|'([^'\s]*)')/i,k=/(^|[\s"'])popup\s*=\s*("([\w=,]*)"|'([\w=,]*)')/i;function T(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&E(n)}var M=/(^|;)\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:["br"],a="...".length,i=t.split(m),o=[],s="",l=0,c=0;c<i.length;c++){var u=i[c],h=u.match(y),f=h&&h[2].toLowerCase();if(f)-1!==n.indexOf(f)&&(o.push(u),s=f);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&("br"!==s||d<=a||p<=a)&&o.pop(),r>a?o.push(u.substr(0,d-a)+"..."):o.push(u.substr(0,d));break}s=""}}return o.join("")};var A={mu:"\u03bc",amp:"&",lt:"<",gt:">",nbsp:"\xa0",times:"\xd7",plusmn:"\xb1",deg:"\xb0"},S=/&(#\d+|#x[\da-fA-F]+|[a-z]+);/g;function E(t){return t.replace(S,function(t,e){return("#"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}("x"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):A[e])||t})}function L(t,e,r){var n,a,i,o=r.horizontalAlign,s=r.verticalAlign||"top",l=t.node().getBoundingClientRect(),c=e.node().getBoundingClientRect();return a="bottom"===s?function(){return l.bottom-n.height}:"middle"===s?function(){return l.top+(l.height-n.height)/2}:function(){return l.top},i="right"===o?function(){return l.right-n.width}:"center"===o?function(){return l.left+(l.width-n.width)/2}:function(){return l.left},function(){return n=this.node().getBoundingClientRect(),this.style({top:a()-c.top+"px",left:i()-c.left+"px","z-index":1e3}),this}}r.convertEntities=E,r.lineCount=function(t){return t.selectAll("tspan.line").size()||1},r.positionText=function(t,e,r){return t.each(function(){var t=n.select(this);function a(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var i=a("x",e),o=a("y",r);"text"===this.nodeName&&t.selectAll("tspan.line").attr({x:i,y:o})})},r.makeEditable=function(t,e){var r=e.gd,a=e.delegate,i=n.dispatch("edit","input","cancel"),o=a||t;if(t.style({"pointer-events":a?"none":"all"}),1!==t.size())throw new Error("boo");function s(){!function(){var a=n.select(r).select(".svg-container"),o=a.append("div"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr("data-unformatted"));o.classed("plugin-editable editable",!0).style({position:"absolute","font-family":s.fontFamily||"Arial","font-size":c,color:e.fill||s.fill||"black",opacity:1,"background-color":e.background||"transparent",outline:"#ffffff33 1px solid",margin:[-c/8+1,0,0,-1].join("px ")+"px",padding:"0","box-sizing":"border-box"}).attr({contenteditable:!0}).text(u).call(L(t,a,e)).on("blur",function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,a=n.select(this).attr("class");(e=a?"."+a.split(" ")[0]+"-math-group":"[class*=-math-group]")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on("mouseup",null),i.edit.call(t,o)}).on("focus",function(){var t=this;r._editing=!0,n.select(document).on("mouseup",function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()})}).on("keyup",function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on("blur",function(){return!1}).transition().remove(),i.cancel.call(t,this.textContent)):(i.input.call(t,this.textContent),n.select(this).call(L(t,a,e)))}).on("keydown",function(){13===n.event.which&&this.blur()}).call(l)}(),t.style({opacity:0});var a,s=o.attr("class");(a=s?"."+s.split(" ")[0]+"-math-group":"[class*=-math-group]")&&n.select(t.node().parentNode).select(a).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on("click",s),n.rebind(t,i,"on")}},{"../constants/alignment":686,"../constants/xmlns_namespaces":694,"../lib":717,d3:165}],742:[function(t,e,r){"use strict";var n={};function a(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var i=n[t],o=Date.now();if(!i){for(var s in n)n[s].ts<o-6e4&&delete n[s];i=n[t]={ts:0,timer:null}}function l(){r(),i.ts=Date.now(),i.onDone&&(i.onDone(),i.onDone=null)}a(i),o>i.ts+e?l():i.timer=setTimeout(function(){l(),i.timer=null},e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise(function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}}):Promise.resolve()},r.clear=function(t){if(t)a(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],743:[function(t,e,r){"use strict";var n=t("fast-isnumeric");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{"fast-isnumeric":228}],744:[function(t,e,r){"use strict";var n=e.exports={},a=t("../plots/geo/constants").locationmodeToLayer,i=t("topojson-client").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,"-"),"_",t.resolution.toString(),"m"].join("")},n.getTopojsonPath=function(t,e){return t+e+".json"},n.getTopojsonFeatures=function(t,e){var r=a[t.locationmode],n=e.objects[r];return i(e,n).features}},{"../plots/geo/constants":793,"topojson-client":538}],745:[function(t,e,r){"use strict";e.exports={moduleType:"locale",name:"en-US",dictionary:{"Click to enter Colorscale title":"Click to enter Colorscale title"},format:{date:"%m/%d/%Y"}}},{}],746:[function(t,e,r){"use strict";e.exports={moduleType:"locale",name:"en",dictionary:{"Click to enter Colorscale title":"Click to enter Colourscale title"},format:{days:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],shortDays:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],months:["January","February","March","April","May","June","July","August","September","October","November","December"],shortMonths:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],periods:["AM","PM"],dateTime:"%a %b %e %X %Y",date:"%d/%m/%Y",time:"%H:%M:%S",decimal:".",thousands:",",grouping:[3],currency:["$",""],year:"%Y",month:"%b %Y",dayMonth:"%b %-d",dayMonthYear:"%b %-d, %Y"}}},{}],747:[function(t,e,r){"use strict";var n=t("../registry");e.exports=function(t){for(var e,r,a=n.layoutArrayContainers,i=n.layoutArrayRegexes,o=t.split("[")[0],s=0;s<i.length;s++)if((r=t.match(i[s]))&&0===r.index){e=r[0];break}if(e||(e=a[a.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\[(0|[1-9][0-9]*)\](\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||""}:{array:e,index:"",property:""}}},{"../registry":846}],748:[function(t,e,r){"use strict";var n=t("../lib"),a=n.extendFlat,i=n.isPlainObject,o={valType:"flaglist",extras:["none"],flags:["calc","clearAxisTypes","plot","style","markerSize","colorbars"]},s={valType:"flaglist",extras:["none"],flags:["calc","plot","legend","ticks","axrange","layoutstyle","modebar","camera","arraydraw","colorbars"]},l=o.flags.slice().concat(["fullReplot"]),c=s.flags.slice().concat("layoutReplot");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function h(t,e,r){var n=a({},t);for(var o in n){var s=n[o];i(s)&&(n[o]=f(s,e,r,o))}return"from-root"===r&&(n.editType=e),n}function f(t,e,r,n){if(t.valType){var i=a({},t);if(i.editType=e,Array.isArray(t.items)){i.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)i.items[o]=f(t.items[o],e,"from-root")}return i}return h(t,e,"_"===n.charAt(0)?"nested":"from-root")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&"none"!==r)for(var n=r.split("+"),a=0;a<n.length;a++)t[n[a]]=!0},overrideAll:h}},{"../lib":717}],749:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("gl-mat4/fromQuat"),i=t("../registry"),o=t("../lib"),s=t("../plots/plots"),l=t("../plots/cartesian/axis_ids"),c=t("../components/color"),u=l.cleanId,h=l.getFromTrace,f=i.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&"paper"!==r&&(t[e]=u(r,n))}function d(t){function e(e,r){var n=t[e],a=t.title&&t.title[r];n&&!a&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&("string"!=typeof t.title&&"number"!=typeof t.title||(t.title={text:t.title}),e("titlefont","font"),e("titleposition","position"),e("titleside","side"),e("titleoffset","offset"))}function g(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,("string"==typeof e||"number"==typeof e)&&String(e)}function v(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var a,i=Math.min(t.length,e.length);for(a=0;a<i&&t.charAt(a)===e.charAt(a);a++);return t.substr(0,a).trim()}function m(t){var e="middle",r="center";return"string"==typeof t&&(-1!==t.indexOf("top")?e="top":-1!==t.indexOf("bottom")&&(e="bottom"),-1!==t.indexOf("left")?r="left":-1!==t.indexOf("right")&&(r="right")),e+" "+r}function y(t,e){return e in t&&"object"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log("Clearing previous rejected promises from queue."),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var i=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,h=(s.subplotsRegistry.ternary||{}).attrRegex,f=(s.subplotsRegistry.gl3d||{}).attrRegex,g=Object.keys(t);for(e=0;e<g.length;e++){var v=g[e];if(i&&i.test(v)){var m=t[v];m.anchor&&"free"!==m.anchor&&(m.anchor=u(m.anchor)),m.overlaying&&(m.overlaying=u(m.overlaying)),m.type||(m.isdate?m.type="date":m.islog?m.type="log":!1===m.isdate&&!1===m.islog&&(m.type="linear")),"withzero"!==m.autorange&&"tozero"!==m.autorange||(m.autorange=!0,m.rangemode="tozero"),delete m.islog,delete m.isdate,delete m.categories,y(m,"domain")&&delete m.domain,void 0!==m.autotick&&(void 0===m.tickmode&&(m.tickmode=m.autotick?"auto":"linear"),delete m.autotick),d(m)}else if(l&&l.test(v)){d(t[v].radialaxis)}else if(h&&h.test(v)){var x=t[v];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(f&&f.test(v)){var b=t[v],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],k=_[1],T=_[2],M=a([],w),A=[];for(n=0;n<3;++n)A[n]=k[n]+T*M[2+4*n];b.camera={eye:{x:A[0],y:A[1],z:A[2]},center:{x:k[0],y:k[1],z:k[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}d(b.xaxis),d(b.yaxis),d(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var E=t.annotations[e];o.isPlainObject(E)&&(E.ref&&("paper"===E.ref?(E.xref="paper",E.yref="paper"):"data"===E.ref&&(E.xref="x",E.yref="y"),delete E.ref),p(E,"xref"),p(E,"yref"))}var L=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<L;e++){var C=t.shapes[e];o.isPlainObject(C)&&(p(C,"xref"),p(C,"yref"))}var P=t.legend;return P&&(P.x>3?(P.x=1.02,P.xanchor="left"):P.x<-2&&(P.x=-.02,P.xanchor="right"),P.y>3?(P.y=1.02,P.yanchor="bottom"):P.y<-2&&(P.y=-.02,P.yanchor="top")),d(t),"rotate"===t.dragmode&&(t.dragmode="orbit"),c.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,a=t[e];if("histogramy"===a.type&&"xbins"in a&&!("ybins"in a)&&(a.ybins=a.xbins,delete a.xbins),a.error_y&&"opacity"in a.error_y){var l=c.defaults,h=a.error_y.color||(f(a,"bar")?c.defaultLine:l[e%l.length]);a.error_y.color=c.addOpacity(c.rgb(h),c.opacity(h)*a.error_y.opacity),delete a.error_y.opacity}if("bardir"in a&&("h"!==a.bardir||!f(a,"bar")&&"histogram"!==a.type.substr(0,9)||(a.orientation="h",r.swapXYData(a)),delete a.bardir),"histogramy"===a.type&&r.swapXYData(a),"histogramx"!==a.type&&"histogramy"!==a.type||(a.type="histogram"),"scl"in a&&!("colorscale"in a)&&(a.colorscale=a.scl,delete a.scl),"reversescl"in a&&!("reversescale"in a)&&(a.reversescale=a.reversescl,delete a.reversescl),a.xaxis&&(a.xaxis=u(a.xaxis,"x")),a.yaxis&&(a.yaxis=u(a.yaxis,"y")),f(a,"gl3d")&&a.scene&&(a.scene=s.subplotsRegistry.gl3d.cleanId(a.scene)),!f(a,"pie-like")&&!f(a,"bar-like"))if(Array.isArray(a.textposition))for(n=0;n<a.textposition.length;n++)a.textposition[n]=m(a.textposition[n]);else a.textposition&&(a.textposition=m(a.textposition));var p=i.getModule(a);if(p&&p.colorbar){var x=p.colorbar.container,b=x?a[x]:a;b&&b.colorscale&&("YIGnBu"===b.colorscale&&(b.colorscale="YlGnBu"),"YIOrRd"===b.colorscale&&(b.colorscale="YlOrRd"))}if("surface"===a.type&&o.isPlainObject(a.contours)){var _=["x","y","z"];for(n=0;n<_.length;n++){var w=a.contours[_[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if("candlestick"===a.type||"ohlc"===a.type){var k=!1!==(a.increasing||{}).showlegend,T=!1!==(a.decreasing||{}).showlegend,M=g(a.increasing),A=g(a.decreasing);if(!1!==M&&!1!==A){var S=v(M,A,k,T);S&&(a.name=S)}else!M&&!A||a.name||(a.name=M||A)}if(Array.isArray(a.transforms)){var E=a.transforms;for(n=0;n<E.length;n++){var L=E[n];if(o.isPlainObject(L))switch(L.type){case"filter":L.filtersrc&&(L.target=L.filtersrc,delete L.filtersrc),L.calendar&&(L.valuecalendar||(L.valuecalendar=L.calendar),delete L.calendar);break;case"groupby":if(L.styles=L.styles||L.style,L.styles&&!Array.isArray(L.styles)){var C=L.styles,P=Object.keys(C);L.styles=[];for(var O=0;O<P.length;O++)L.styles.push({target:P[O],value:C[P[O]]})}}}}y(a,"line")&&delete a.line,"marker"in a&&(y(a.marker,"line")&&delete a.marker.line,y(a,"marker")&&delete a.marker),c.clean(a),a.autobinx&&(delete a.autobinx,delete a.xbins),a.autobiny&&(delete a.autobiny,delete a.ybins),d(a),a.colorbar&&d(a.colorbar),a.marker&&a.marker.colorbar&&d(a.marker.colorbar),a.line&&a.line.colorbar&&d(a.line.colorbar),a.aaxis&&d(a.aaxis),a.baxis&&d(a.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,["?","?0","d?","?bins","nbins?","autobin?","?src","error_?"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n="copy_ystyle"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,["error_?.copy_ystyle"]),n&&o.swapAttrs(t,["error_?.color","error_?.thickness","error_?.width"])}if("string"==typeof t.hoverinfo){var a=t.hoverinfo.split("+");for(e=0;e<a.length;e++)"x"===a[e]?a[e]="y":"y"===a[e]&&(a[e]="x");t.hoverinfo=a.join("+")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map(function(t,e){return e});if(Array.isArray(e)){for(var r=[],a=0;a<e.length;a++)o.isIndex(e[a],t.data.length)?r.push(e[a]):o.warn("trace index (",e[a],") is not a number or is out of bounds");return r}return e},r.manageArrayContainers=function(t,e,r){var a=t.obj,i=t.parts,s=i.length,l=i[s-1],c=n(l);if(c&&null===e){var u=i.slice(0,s-1).join(".");o.nestedProperty(a,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\.[^\[\]\.]+|\[[^\[\]\.]+\])$/;function b(t){var e=t.search(x);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=b(e);r;){if(r in t)return!0;r=b(r)}return!1};var _=["x","y","z"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var a=t._fullData[n],i=0;i<3;i++){var s=h(t,a,_[i]);if(s&&"log"!==s.type){var l=s._name,c=s._id.substr(1);if("scene"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+"."+l}var u=l+".type";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},{"../components/color":591,"../lib":717,"../plots/cartesian/axis_ids":768,"../plots/plots":826,"../registry":846,"fast-isnumeric":228,"gl-mat4/fromQuat":265}],750:[function(t,e,r){"use strict";var n=t("./plot_api");r.plot=n.plot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t("./to_image"),r.validate=t("./validate"),r.downloadImage=t("../snapshot/download");var a=t("./template_api");r.makeTemplate=a.makeTemplate,r.validateTemplate=a.validateTemplate},{"../snapshot/download":848,"./plot_api":752,"./template_api":757,"./to_image":758,"./validate":759}],751:[function(t,e,r){"use strict";var n=t("../lib/is_plain_object"),a=t("../lib/noop"),i=t("../lib/loggers"),o=t("../lib/search").sorterAsc,s=t("../registry");r.containerArrayMatch=t("./container_array_match");var l=r.isAddVal=function(t){return"add"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||"remove"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var h=e.astr,f=s.getComponentMethod(h,"supplyLayoutDefaults"),p=s.getComponentMethod(h,"draw"),d=s.getComponentMethod(h,"drawOne"),g=n.replot||n.recalc||f===a||p===a,v=t.layout,m=t._fullLayout;if(r[""]){Object.keys(r).length>1&&i.warn("Full array edits are incompatible with other edits",h);var y=r[""][""];if(c(y))e.set(null);else{if(!Array.isArray(y))return i.warn("Unrecognized full array edit value",h,y),!0;e.set(y)}return!g&&(f(v,m),p(t),!0)}var x,b,_,w,k,T,M,A,S=Object.keys(r).map(Number).sort(o),E=e.get(),L=E||[],C=u(m,h).get(),P=[],O=-1,z=L.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],k=Object.keys(w),T=w[""],M=l(T),_<0||_>L.length-(M?0:1))i.warn("index out of range",h,_);else if(void 0!==T)k.length>1&&i.warn("Insertion & removal are incompatible with edits to the same index.",h,_),c(T)?P.push(_):M?("add"===T&&(T={}),L.splice(_,0,T),C&&C.splice(_,0,{})):i.warn("Unrecognized full object edit value",h,_,T),-1===O&&(O=_);else for(b=0;b<k.length;b++)A=h+"["+_+"].",u(L[_],k[b],A).set(w[k[b]]);for(x=P.length-1;x>=0;x--)L.splice(P[x],1),C&&C.splice(P[x],1);if(L.length?E||e.set(L):e.set(null),g)return!1;if(f(v,m),d!==a){var I;if(-1===O)I=S;else{for(z=Math.max(L.length,z),I=[],x=0;x<S.length&&!((_=S[x])>=O);x++)I.push(_);for(x=O;x<z;x++)I.push(x)}for(x=0;x<I.length;x++)d(t,I[x])}else p(t);return!0}},{"../lib/is_plain_object":718,"../lib/loggers":721,"../lib/noop":726,"../lib/search":736,"../registry":846,"./container_array_match":747}],752:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("has-hover"),o=t("../lib"),s=o.nestedProperty,l=t("../lib/events"),c=t("../lib/queue"),u=t("../registry"),h=t("./plot_schema"),f=t("../plots/plots"),p=t("../plots/polar/legacy"),d=t("../plots/cartesian/axes"),g=t("../components/drawing"),v=t("../components/color"),m=t("../plots/cartesian/graph_interact").initInteractions,y=t("../constants/xmlns_namespaces"),x=t("../lib/svg_text_utils"),b=t("../plots/cartesian/select").clearSelect,_=t("./plot_config").dfltConfig,w=t("./manage_arrays"),k=t("./helpers"),T=t("./subroutines"),M=t("./edit_types"),A=t("../plots/cartesian/constants").AX_NAME_PATTERN,S=0,E=5;function L(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit("plotly_afterplot")}function C(t,e){try{t._fullLayout._paper.style("background",e)}catch(t){o.error(t)}}function P(t,e){C(t,v.combine(e,"white"))}function O(t,e){if(!t._context){t._context=o.extendDeep({},_);var r=n.select("base");t._context._baseUrl=r.size()&&r.attr("href")?window.location.href.split("#")[0]:""}var a,s,l,c=t._context;if(e){for(s=Object.keys(e),a=0;a<s.length;a++)"editable"!==(l=s[a])&&"edits"!==l&&l in c&&("setBackground"===l&&"opaque"===e[l]?c[l]=P:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),a=0;a<s.length;a++)c.edits[s[a]]=u;if(e.edits)for(s=Object.keys(e.edits),a=0;a<s.length;a++)(l=s[a])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),"hover"!==c.displayModeBar||i||(c.displayModeBar=!0),"transparent"!==c.setBackground&&"function"==typeof c.setBackground||(c.setBackground=C),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var h=c.scrollZoom,f=c._scrollZoom={};if(!0===h)f.cartesian=1,f.gl3d=1,f.geo=1,f.mapbox=1;else if("string"==typeof h){var p=h.split("+");for(a=0;a<p.length;a++)f[p[a]]=1}else!1!==h&&(f.gl3d=1,f.geo=1,f.mapbox=1)}function z(t,e){var r,n,a=e+1,i=[];for(r=0;r<t.length;r++)(n=t[r])<0?i.push(a+n):i.push(n);return i}function I(t,e,r){var n,a;for(n=0;n<e.length;n++){if((a=e[n])!==parseInt(a,10))throw new Error("all values in "+r+" must be integers");if(a>=t.data.length||a<-t.data.length)throw new Error(r+" must be valid indices for gd.data.");if(e.indexOf(a,n+1)>-1||a>=0&&e.indexOf(-t.data.length+a)>-1||a<0&&e.indexOf(t.data.length+a)>-1)throw new Error("each index in "+r+" must be unique.")}}function D(t,e,r){if(!Array.isArray(t.data))throw new Error("gd.data must be an array.");if("undefined"==typeof e)throw new Error("currentIndices is a required argument.");if(Array.isArray(e)||(e=[e]),I(t,e,"currentIndices"),"undefined"==typeof r||Array.isArray(r)||(r=[r]),"undefined"!=typeof r&&I(t,r,"newIndices"),"undefined"!=typeof r&&e.length!==r.length)throw new Error("current and new indices must be of equal length.")}function R(t,e,r,n,i){!function(t,e,r,n){var a=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error("gd.data must be an array");if(!o.isPlainObject(e))throw new Error("update must be a key:value object");if("undefined"==typeof r)throw new Error("indices must be an integer or array of integers");for(var i in I(t,r,"indices"),e){if(!Array.isArray(e[i])||e[i].length!==r.length)throw new Error("attribute "+i+" must be an array of length equal to indices array length");if(a&&(!(i in n)||!Array.isArray(n[i])||n[i].length!==e[i].length))throw new Error("when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object")}}(t,e,r,n);for(var l=function(t,e,r,n){var i,l,c,u,h,f=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=z(r,t.data.length-1),e)for(var g=0;g<r.length;g++){if(i=t.data[r[g]],l=(c=s(i,d)).get(),u=e[d][g],!o.isArrayOrTypedArray(u))throw new Error("attribute: "+d+" index: "+g+" must be an array");if(!o.isArrayOrTypedArray(l))throw new Error("cannot extend missing or non-array attribute: "+d);if(l.constructor!==u.constructor)throw new Error("cannot extend array with an array of a different type: "+d);h=f?n[d][g]:n,a(h)||(h=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(h)})}return p}(t,e,r,n),c={},u={},h=0;h<l.length;h++){var f=l[h].prop,p=l[h].maxp,d=i(l[h].target,l[h].insert,p);f.set(d[0]),Array.isArray(c[f.astr])||(c[f.astr]=[]),c[f.astr].push(d[1]),Array.isArray(u[f.astr])||(u[f.astr]=[]),u[f.astr].push(l[h].target.length)}return{update:c,maxPoints:u}}function F(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function B(t,e,n,a){t=o.getGraphDiv(t),k.clearPromiseQueue(t);var i={};if("string"==typeof e)i[e]=n;else{if(!o.isPlainObject(e))return o.warn("Restyle fail.",e,n,a),Promise.reject();i=o.extendFlat({},e),void 0===a&&(a=n)}Object.keys(i).length&&(t.changed=!0);var s=k.coerceTraceIndices(t,a),l=U(t,i,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&k.clearAxisTypes(t,s,{});var h=[];u.fullReplot?h.push(r.plot):(h.push(f.previousPromises),f.supplyDefaults(t),u.markerSize&&(f.doCalcdata(t),Y(h)),u.style&&h.push(T.doTraceStyle),u.colorbars&&h.push(T.doColorBars),h.push(L)),h.push(f.rehover,f.redrag),c.add(t,B,[t,l.undoit,l.traces],B,[t,l.redoit,l.traces]);var p=o.syncOrAsync(h,t);return p&&p.then||(p=Promise.resolve()),p.then(function(){return t.emit("plotly_restyle",l.eventData),t})}function N(t){return void 0===t?null:t}function j(t,e){return e?function(e,r,n){var a=s(e,r),i=a.set;return a.set=function(e){V((n||"")+r,a.get(),e,t),i(e)},a}:s}function V(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var a=Array.isArray(e)?e:[],i=Array.isArray(r)?r:[],s=Math.max(a.length,i.length),l=0;l<s;l++)V(t+"["+l+"]",a[l],i[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},h=o.extendFlat({},c,u);for(var f in h)V(t+"."+f,c[f],u[f],n)}else void 0===n[t]&&(n[t]=N(e))}function U(t,e,r){var n,a=t._fullLayout,i=t._fullData,l=t.data,c=a._guiEditing,p=j(a._preGUI,c),g=o.extendDeepAll({},e);q(e);var v,m=M.traceFlags(),y={},x={};function b(){return r.map(function(){})}function _(t){var e=d.id2name(t);-1===v.indexOf(e)&&v.push(e)}function w(t){return"LAYOUT"+t+".autorange"}function T(t){return"LAYOUT"+t+".range"}function A(t){for(var e=t;e<i.length;e++)if(i[e]._input===l[t])return i[e]}function S(n,i,o){if(Array.isArray(n))n.forEach(function(t){S(t,i,o)});else if(!(n in e||k.hasParent(e,n))){var s;if("LAYOUT"===n.substr(0,6))s=p(t.layout,n.replace("LAYOUT",""));else{var u=r[o];s=j(a._tracePreGUI[A(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=N(s.get())),void 0!==i&&s.set(i)}}function E(t){return function(e){return i[e][t]}}function L(t){return function(e,n){return!1===e?i[r[n]][t]:null}}for(var C in e){if(k.hasParent(e,C))throw new Error("cannot set "+C+" and a parent attribute simultaneously");var P,O,z,I,D,R,F=e[C];if("autobinx"!==C&&"autobiny"!==C||(C=C.charAt(C.length-1)+"bins",F=Array.isArray(F)?F.map(L(C)):!1===F?r.map(E(C)):null),y[C]=F,"LAYOUT"!==C.substr(0,6)){for(x[C]=b(),n=0;n<r.length;n++){if(P=l[r[n]],O=A(r[n]),I=(z=j(a._tracePreGUI[O._fullInput.uid],c)(P,C)).get(),void 0!==(D=Array.isArray(F)?F[n%F.length]:F)){var B=z.parts[z.parts.length-1],V=C.substr(0,C.length-B.length-1),U=V?V+".":"",H=V?s(O,V).get():O;if((R=h.getTraceValObject(O,z.parts))&&R.impliedEdits&&null!==D)for(var G in R.impliedEdits)S(o.relativeAttr(C,G),R.impliedEdits[G],n);else if("thicknessmode"!==B&&"lenmode"!==B||I===D||"fraction"!==D&&"pixels"!==D||!H){if("type"===C&&("pie"===D!=("pie"===I)||"funnelarea"===D!=("funnelarea"===I))){var Y="x",W="y";"bar"!==D&&"bar"!==I||"h"!==P.orientation||(Y="y",W="x"),o.swapAttrs(P,["?","?src"],"labels",Y),o.swapAttrs(P,["d?","?0"],"label",Y),o.swapAttrs(P,["?","?src"],"values",W),"pie"===I||"funnelarea"===I?(s(P,"marker.color").set(s(P,"marker.colors").get()),a._pielayer.selectAll("g.trace").remove()):u.traceIs(P,"cartesian")&&s(P,"marker.colors").set(s(P,"marker.color").get())}}else{var X=a._size,Z=H.orient,J="top"===Z||"bottom"===Z;if("thicknessmode"===B){var K=J?X.h:X.w;S(U+"thickness",H.thickness*("fraction"===D?1/K:K),n)}else{var Q=J?X.w:X.h;S(U+"len",H.len*("fraction"===D?1/Q:Q),n)}}x[C][n]=N(I);if(-1!==["swapxy","swapxyaxes","orientation","orientationaxes"].indexOf(C)){if("orientation"===C){z.set(D);var $=P.x&&!P.y?"h":"v";if((z.get()||$)===O.orientation)continue}else"orientationaxes"===C&&(P.orientation={v:"h",h:"v"}[O.orientation]);k.swapXYData(P),m.calc=m.clearAxisTypes=!0}else-1!==f.dataArrayContainers.indexOf(z.parts[0])?(k.manageArrayContainers(z,D,x),m.calc=!0):(R?R.arrayOk&&!u.traceIs(O,"regl")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(I))?m.calc=!0:M.update(m,R):m.calc=!0,z.set(D))}}if(-1!==["swapxyaxes","orientationaxes"].indexOf(C)&&d.swap(t,r),"orientationaxes"===C){var tt=s(t.layout,"hovermode");"x"===tt.get()?tt.set("y"):"y"===tt.get()?tt.set("x"):"x unified"===tt.get()?tt.set("y unified"):"y unified"===tt.get()&&tt.set("x unified")}if(-1!==["orientation","type"].indexOf(C)){for(v=[],n=0;n<r.length;n++){var et=l[r[n]];u.traceIs(et,"cartesian")&&(_(et.xaxis||"x"),_(et.yaxis||"y"))}S(v.map(w),!0,0),S(v.map(T),[0,1],0)}}else z=p(t.layout,C.replace("LAYOUT","")),x[C]=[N(z.get())],z.set(Array.isArray(F)?F[0]:F),m.calc=!0}return(m.calc||m.plot)&&(m.fullReplot=!0),{flags:m,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[g,r])}}function q(t){var e,r,n,a=o.counterRegex("axis",".title",!1,!1),i=/colorbar\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],"title"!==r&&!a.test(r)&&!i.test(r)||"string"!=typeof n&&"number"!=typeof n?r.indexOf("titlefont")>-1?l(r,r.replace("titlefont","title.font")):r.indexOf("titleposition")>-1?l(r,r.replace("titleposition","title.position")):r.indexOf("titleside")>-1?l(r,r.replace("titleside","title.side")):r.indexOf("titleoffset")>-1&&l(r,r.replace("titleoffset","title.offset")):l(r,r.replace("title","title.text"));function l(e,r){t[r]=t[e],delete t[e]}}function H(t,e,r){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);var n={};if("string"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn("Relayout fail.",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var a=J(t,n),i=a.flags;i.calc&&(t.calcdata=void 0);var s=[f.previousPromises];i.layoutReplot?s.push(T.layoutReplot):Object.keys(n).length&&(G(t,i,a)||f.supplyDefaults(t),i.legend&&s.push(T.doLegend),i.layoutstyle&&s.push(T.layoutStyles),i.axrange&&Y(s,a.rangesAltered),i.ticks&&s.push(T.doTicksRelayout),i.modebar&&s.push(T.doModeBar),i.camera&&s.push(T.doCamera),i.colorbars&&s.push(T.doColorBars),s.push(L)),s.push(f.rehover,f.redrag),c.add(t,H,[t,a.undoit],H,[t,a.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then(function(){return t.emit("plotly_relayout",a.eventData),t})}function G(t,e,r){var n=t._fullLayout;if(!e.axrange)return!1;for(var a in e)if("axrange"!==a&&e[a])return!1;for(var i in r.rangesAltered){var o=d.id2name(i),s=t.layout[o],l=n[o];if(l.autorange=s.autorange,l.range=s.range.slice(),l.cleanRange(),l._matchGroup)for(var c in l._matchGroup)if(c!==i){var u=n[d.id2name(c)];u.autorange=l.autorange,u.range=l.range.slice(),u._input.range=l.range.slice()}}return!0}function Y(t,e){var r=e?function(t){var r=[],n=!0;for(var a in e){var i=d.getFromId(t,a);if(r.push(a),i._matchGroup)for(var o in i._matchGroup)e[o]||r.push(o);i.automargin&&(n=!1)}return d.draw(t,r,{skipTitle:n})}:function(t){return d.draw(t,"redraw")};t.push(b,T.doAutoRangeAndConstraints,r,T.drawData,T.finalDraw)}var W=/^[xyz]axis[0-9]*\.range(\[[0|1]\])?$/,X=/^[xyz]axis[0-9]*\.autorange$/,Z=/^[xyz]axis[0-9]*\.domain(\[[0|1]\])?$/;function J(t,e){var r,n,a,i=t.layout,l=t._fullLayout,c=l._guiEditing,f=j(l._preGUI,c),p=Object.keys(e),g=d.list(t),v=o.extendDeepAll({},e),m={};for(q(e),p=Object.keys(e),n=0;n<p.length;n++)if(0===p[n].indexOf("allaxes")){for(a=0;a<g.length;a++){var y=g[a]._id.substr(1),x=-1!==y.indexOf("scene")?y+".":"",b=p[n].replace("allaxes",x+g[a]._name);e[b]||(e[b]=e[p[n]])}delete e[p[n]]}var _=M.layoutFlags(),T={},S={};function E(t,r){if(Array.isArray(t))t.forEach(function(t){E(t,r)});else if(!(t in e||k.hasParent(e,t))){var n=f(i,t);t in S||(S[t]=N(n.get())),void 0!==r&&n.set(r)}}var L,C={};function P(t){var e=d.name2id(t.split(".")[0]);return C[e]=1,e}for(var O in e){if(k.hasParent(e,O))throw new Error("cannot set "+O+" and a parent attribute simultaneously");for(var z=f(i,O),I=e[O],D=z.parts.length-1;D>0&&"string"!=typeof z.parts[D];)D--;var R=z.parts[D],F=z.parts[D-1]+"."+R,B=z.parts.slice(0,D).join("."),V=s(t.layout,B).get(),U=s(l,B).get(),H=z.get();if(void 0!==I){T[O]=I,S[O]="reverse"===R?I:N(H);var G=h.getLayoutValObject(l,z.parts);if(G&&G.impliedEdits&&null!==I)for(var Y in G.impliedEdits)E(o.relativeAttr(O,Y),G.impliedEdits[Y]);if(-1!==["width","height"].indexOf(O))if(I){E("autosize",null);var J="height"===O?"width":"height";E(J,l[J])}else l[O]=t._initialAutoSize[O];else if("autosize"===O)E("width",I?null:l.width),E("height",I?null:l.height);else if(F.match(W))P(F),s(l,B+"._inputRange").set(null);else if(F.match(X)){P(F),s(l,B+"._inputRange").set(null);var Q=s(l,B).get();Q._inputDomain&&(Q._input.domain=Q._inputDomain.slice())}else F.match(Z)&&s(l,B+"._inputDomain").set(null);if("type"===R){var $=V,tt="linear"===U.type&&"log"===I,et="log"===U.type&&"linear"===I;if(tt||et){if($&&$.range)if(U.autorange)tt&&($.range=$.range[1]>$.range[0]?[1,2]:[2,1]);else{var rt=$.range[0],nt=$.range[1];tt?(rt<=0&&nt<=0&&E(B+".autorange",!0),rt<=0?rt=nt/1e6:nt<=0&&(nt=rt/1e6),E(B+".range[0]",Math.log(rt)/Math.LN10),E(B+".range[1]",Math.log(nt)/Math.LN10)):(E(B+".range[0]",Math.pow(10,rt)),E(B+".range[1]",Math.pow(10,nt)))}else E(B+".autorange",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[z.parts[0]]&&"radialaxis"===z.parts[1]&&delete l[z.parts[0]]._subplot.viewInitial["radialaxis.range"],u.getComponentMethod("annotations","convertCoords")(t,U,I,E),u.getComponentMethod("images","convertCoords")(t,U,I,E)}else E(B+".autorange",!0),E(B+".range",null);s(l,B+"._inputRange").set(null)}else if(R.match(A)){var at=s(l,O).get(),it=(I||{}).type;it&&"-"!==it||(it="linear"),u.getComponentMethod("annotations","convertCoords")(t,at,it,E),u.getComponentMethod("images","convertCoords")(t,at,it,E)}var ot=w.containerArrayMatch(O);if(ot){r=ot.array,n=ot.index;var st=ot.property,lt=G||{editType:"calc"};""!==n&&""===st&&(w.isAddVal(I)?S[O]=null:w.isRemoveVal(I)?S[O]=(s(i,r).get()||[])[n]:o.warn("unrecognized full object value",e)),M.update(_,lt),m[r]||(m[r]={});var ct=m[r][n];ct||(ct=m[r][n]={}),ct[st]=I,delete e[O]}else"reverse"===R?(V.range?V.range.reverse():(E(B+".autorange",!0),V.range=[1,0]),U.autorange?_.calc=!0:_.plot=!0):(l._has("scatter-like")&&l._has("regl")&&"dragmode"===O&&("lasso"===I||"select"===I)&&"lasso"!==H&&"select"!==H?_.plot=!0:l._has("gl2d")?_.plot=!0:G?M.update(_,G):_.calc=!0,z.set(I))}}for(r in m){w.applyContainerArrayChanges(t,f(i,r),m[r],_,f)||(_.plot=!0)}var ut=l._axisConstraintGroups||[];for(L in C)for(n=0;n<ut.length;n++){var ht=ut[n];if(ht[L])for(var ft in _.calc=!0,ht)C[ft]||(d.getFromId(t,ft)._constraintShrinkable=!0)}return(K(t)||e.height||e.width)&&(_.plot=!0),(_.plot||_.calc)&&(_.layoutReplot=!0),{flags:_,rangesAltered:C,undoit:S,redoit:T,eventData:v}}function K(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&f.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function Q(t,e,n,a){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var i=k.coerceTraceIndices(t,a),s=U(t,o.extendFlat({},e),i),l=s.flags,u=J(t,o.extendFlat({},n)),h=u.flags;(l.calc||h.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&k.clearAxisTypes(t,i,n);var p=[];h.layoutReplot?p.push(T.layoutReplot):l.fullReplot?p.push(r.plot):(p.push(f.previousPromises),G(t,h,u)||f.supplyDefaults(t),l.style&&p.push(T.doTraceStyle),(l.colorbars||h.colorbars)&&p.push(T.doColorBars),h.legend&&p.push(T.doLegend),h.layoutstyle&&p.push(T.layoutStyles),h.axrange&&Y(p,u.rangesAltered),h.ticks&&p.push(T.doTicksRelayout),h.modebar&&p.push(T.doModeBar),h.camera&&p.push(T.doCamera),p.push(L)),p.push(f.rehover,f.redrag),c.add(t,Q,[t,s.undoit,u.undoit,s.traces],Q,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then(function(){return t.emit("plotly_update",{data:s.eventData,layout:u.eventData}),t})}function $(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var tt=[{pattern:/^hiddenlabels/,attr:"legend.uirevision"},{pattern:/^((x|y)axis\d*)\.((auto)?range|title\.text)/},{pattern:/axis\d*\.showspikes$/,attr:"modebar.uirevision"},{pattern:/(hover|drag)mode$/,attr:"modebar.uirevision"},{pattern:/^(scene\d*)\.camera/},{pattern:/^(geo\d*)\.(projection|center|fitbounds)/},{pattern:/^(ternary\d*\.[abc]axis)\.(min|title\.text)$/},{pattern:/^(polar\d*\.radialaxis)\.((auto)?range|angle|title\.text)/},{pattern:/^(polar\d*\.angularaxis)\.rotation/},{pattern:/^(mapbox\d*)\.(center|zoom|bearing|pitch)/},{pattern:/^legend\.(x|y)$/,attr:"editrevision"},{pattern:/^(shapes|annotations)/,attr:"editrevision"},{pattern:/^title\.text$/,attr:"editrevision"}],et=[{pattern:/^selectedpoints$/,attr:"selectionrevision"},{pattern:/(^|value\.)visible$/,attr:"legend.uirevision"},{pattern:/^dimensions\[\d+\]\.constraintrange/},{pattern:/^node\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\.)name$/},{pattern:/colorbar\.title\.text$/},{pattern:/colorbar\.(x|y)$/,attr:"editrevision"}];function rt(t,e){for(var r=0;r<e.length;r++){var n=e[r],a=t.match(n.pattern);if(a)return{head:a[1],attr:n.attr}}}function nt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(".");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(".")+".uirevision").get()))return r;return e.uirevision}function at(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function it(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function ot(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function st(t,e,r,n){var a,i,l,c=n.getValObject,u=n.flags,h=n.immutable,f=n.inArray,p=n.arrayIndex;function d(){var t=a.editType;f&&-1!==t.indexOf("arraydraw")?o.pushUnique(u.arrays[f],p):(M.update(u,a),"none"!==t&&u.nChanges++,n.transition&&a.anim&&u.nChangesAnim++,(W.test(l)||X.test(l))&&(u.rangesAltered[r[0]]=1),Z.test(l)&&s(e,"_inputDomain").set(null),"datarevision"===i&&(u.newDataRevision=1))}function g(t){return"data_array"===t.valType||t.arrayOk}for(i in t){if(u.calc&&!n.transition)return;var v=t[i],m=e[i],y=r.concat(i);if(l=y.join("."),"_"!==i.charAt(0)&&"function"!=typeof v&&v!==m){if(("tick0"===i||"dtick"===i)&&"geo"!==r[0]){var x=e.tickmode;if("auto"===x||"array"===x||!x)continue}if(("range"!==i||!e.autorange)&&("zmin"!==i&&"zmax"!==i||"contourcarpet"!==e.type)&&(a=c(y))&&(!a._compareAsJSON||JSON.stringify(v)!==JSON.stringify(m))){var b,_=a.valType,w=g(a),k=Array.isArray(v),T=Array.isArray(m);if(k&&T){var A="_input_"+i,S=t[A],E=e[A];if(Array.isArray(S)&&S===E)continue}if(void 0===m)w&&k?u.calc=!0:d();else if(a._isLinkedToArray){var L=[],C=!1;f||(u.arrays[i]=L);var P=Math.min(v.length,m.length),O=Math.max(v.length,m.length);if(P!==O){if("arraydraw"!==a.editType){d();continue}C=!0}for(b=0;b<P;b++)st(v[b],m[b],y.concat(b),o.extendFlat({inArray:i,arrayIndex:b},n));if(C)for(b=P;b<O;b++)L.push(b)}else!_&&o.isPlainObject(v)?st(v,m,y,n):w?k&&T?(h&&(u.calc=!0),(h||n.newDataRevision)&&d()):k!==T?u.calc=!0:d():k&&T&&v.length===m.length&&String(v)===String(m)||d()}}}for(i in e)if(!(i in t||"_"===i.charAt(0)||"function"==typeof e[i])){if(g(a=c(r.concat(i)))&&Array.isArray(e[i]))return void(u.calc=!0);d()}}function lt(t){var e=n.select(t),r=t._fullLayout;if(r._container=e.selectAll(".plot-container").data([0]),r._container.enter().insert("div",":first-child").classed("plot-container",!0).classed("plotly",!0),r._paperdiv=r._container.selectAll(".svg-container").data([0]),r._paperdiv.enter().append("div").classed("svg-container",!0).style("position","relative"),r._glcontainer=r._paperdiv.selectAll(".gl-container").data([{}]),r._glcontainer.enter().append("div").classed("gl-container",!0),r._paperdiv.selectAll(".main-svg").remove(),r._paperdiv.select(".modebar-container").remove(),r._paper=r._paperdiv.insert("svg",":first-child").classed("main-svg",!0),r._toppaper=r._paperdiv.append("svg").classed("main-svg",!0),r._modebardiv=r._paperdiv.append("div"),r._hoverpaper=r._paperdiv.append("svg").classed("main-svg",!0),!r._uid){var a={};n.selectAll("defs").each(function(){this.id&&(a[this.id.split("-")[1]]=1)}),r._uid=o.randstr(a)}r._paperdiv.selectAll(".main-svg").attr(y.svgAttrs),r._defs=r._paper.append("defs").attr("id","defs-"+r._uid),r._clips=r._defs.append("g").classed("clips",!0),r._topdefs=r._toppaper.append("defs").attr("id","topdefs-"+r._uid),r._topclips=r._topdefs.append("g").classed("clips",!0),r._bgLayer=r._paper.append("g").classed("bglayer",!0),r._draggers=r._paper.append("g").classed("draglayer",!0);var i=r._paper.append("g").classed("layer-below",!0);r._imageLowerLayer=i.append("g").classed("imagelayer",!0),r._shapeLowerLayer=i.append("g").classed("shapelayer",!0),r._cartesianlayer=r._paper.append("g").classed("cartesianlayer",!0),r._polarlayer=r._paper.append("g").classed("polarlayer",!0),r._ternarylayer=r._paper.append("g").classed("ternarylayer",!0),r._geolayer=r._paper.append("g").classed("geolayer",!0),r._funnelarealayer=r._paper.append("g").classed("funnelarealayer",!0),r._pielayer=r._paper.append("g").classed("pielayer",!0),r._treemaplayer=r._paper.append("g").classed("treemaplayer",!0),r._sunburstlayer=r._paper.append("g").classed("sunburstlayer",!0),r._indicatorlayer=r._toppaper.append("g").classed("indicatorlayer",!0),r._glimages=r._paper.append("g").classed("glimages",!0);var s=r._toppaper.append("g").classed("layer-above",!0);r._imageUpperLayer=s.append("g").classed("imagelayer",!0),r._shapeUpperLayer=s.append("g").classed("shapelayer",!0),r._infolayer=r._toppaper.append("g").classed("infolayer",!0),r._menulayer=r._toppaper.append("g").classed("menulayer",!0),r._zoomlayer=r._toppaper.append("g").classed("zoomlayer",!0),r._hoverlayer=r._hoverpaper.append("g").classed("hoverlayer",!0),r._modebardiv.classed("modebar-container",!0).style("position","absolute").style("top","0px").style("right","0px"),t.emit("plotly_framework")}r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error("This element is not a Plotly plot: "+t+". It's likely that you've failed to create a plot before animating it. For more details, see https://plotly.com/javascript/animations/");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var a=(r=f.supplyAnimationDefaults(r)).transition,i=r.frame;function s(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function l(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise(function(i,u){function h(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,f.transition(t,e.frame.data,e.frame.layout,k.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then(function(){e.onComplete&&e.onComplete()}),t.emit("plotly_animatingframe",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit("plotly_animated"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit("plotly_animating"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&h()};e()}var d,g,v=0;function m(t){return Array.isArray(a)?v>=a.length?t.transitionOpts=a[v]:t.transitionOpts=a[0]:t.transitionOpts=a,v++,t}var y=[],x=null==e,b=Array.isArray(e);if(x||b||!o.isPlainObject(e)){if(x||-1!==["string","number"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(g=n._frames[d])&&(x||String(g.group)===String(e))&&y.push({type:"byname",name:String(g.name),data:m({name:g.name})});else if(b)for(d=0;d<e.length;d++){var _=e[d];-1!==["number","string"].indexOf(typeof _)?(_=String(_),y.push({type:"byname",name:_,data:m({name:_})})):o.isPlainObject(_)&&y.push({type:"object",data:m(o.extendFlat({},_))})}}else y.push({type:"object",data:m(o.extendFlat({},e))});for(d=0;d<y.length;d++)if("byname"===(g=y[d]).type&&!n._frameHash[g.data.name])return o.warn('animate failure: frame not found: "'+g.data.name+'"'),void u();-1!==["next","immediate"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit("plotly_animationinterrupted",[])}}(),"reverse"===r.direction&&y.reverse();var w=t._fullLayout._currentFrame;if(w&&r.fromcurrent){var T=-1;for(d=0;d<y.length;d++)if("byname"===(g=y[d]).type&&g.name===w){T=d;break}if(T>0&&T<y.length-1){var M=[];for(d=0;d<y.length;d++)g=y[d],("byname"!==y[d].type||d>T)&&M.push(g);y=M}}y.length>0?function(e){if(0!==e.length){for(var a=0;a<e.length;a++){var o;o="byname"===e[a].type?f.computeFrame(t,e[a].name):e[a].data;var h=l(a),d=s(a);d.duration=Math.min(d.duration,h.duration);var g={frame:o,name:e[a].name,frameOpts:h,transitionOpts:d};a===e.length-1&&(g.onComplete=c(i,2),g.onInterrupt=u),n._frameQueue.push(g)}"immediate"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit("plotly_animated"),i())})},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error("This element is not a Plotly plot: "+t+". It's likely that you've failed to create a plot before adding frames. For more details, see https://plotly.com/javascript/animations/");var n,a,i,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error("addFrames failure: frameList must be an Array of frame definitions"+e);var h=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var g=e[n].name,v=(u[g]||d[g]||{}).name,m=e[n].name,y=u[v]||d[v];v&&m&&"number"==typeof m&&y&&S<E&&(S++,o.warn('addFrames: overwriting frame "'+(u[v]||d[v]).name+'" with a frame whose name of type "number" also equates to "'+v+'". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),S===E&&o.warn("addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.")),d[g]={name:g},p.push({frame:f.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:h+n})}p.sort(function(t,e){return t.index>e.index?-1:t.index<e.index?1:0});var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if("number"==typeof(a=p[n].frame).name&&o.warn("Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings"),!a.name)for(;u[a.name="frame "+t._transitionData._counter++];);if(u[a.name]){for(i=0;i<l.length&&(l[i]||{}).name!==a.name;i++);x.push({type:"replace",index:i,value:a}),b.unshift({type:"replace",index:i,value:l[i]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:"insert",index:s,value:a}),b.unshift({type:"delete",index:s}),_++}var w=f.modifyFrames,k=f.modifyFrames,T=[t,b],M=[t,x];return c&&c.add(t,w,T,k,M),f.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error("This element is not a Plotly plot: "+t);var r,n,a=t._transitionData._frames,i=[],s=[];if(!e)for(e=[],r=0;r<a.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],i.push({type:"delete",index:n}),s.unshift({type:"insert",index:n,value:a[n]});var l=f.modifyFrames,u=f.modifyFrames,h=[t,s],p=[t,i];return c&&c.add(t,l,h,u,p),f.modifyFrames(t,i)},r.addTraces=function t(e,n,a){e=o.getGraphDiv(e);var i,s,l=[],u=r.deleteTraces,h=t,f=[e,l],p=[e,n];for(function(t,e,r){var n,a;if(!Array.isArray(t.data))throw new Error("gd.data must be an array.");if("undefined"==typeof e)throw new Error("traces must be defined.");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if("object"!=typeof(a=e[n])||Array.isArray(a)||null===a)throw new Error("all values in traces array must be non-array objects");if("undefined"==typeof r||Array.isArray(r)||(r=[r]),"undefined"!=typeof r&&r.length!==e.length)throw new Error("if indices is specified, traces.length must equal indices.length")}(e,n,a),Array.isArray(n)||(n=[n]),n=n.map(function(t){return o.extendFlat({},t)}),k.cleanData(n),i=0;i<n.length;i++)e.data.push(n[i]);for(i=0;i<n.length;i++)l.push(-n.length+i);if("undefined"==typeof a)return s=r.redraw(e),c.add(e,u,f,h,p),s;Array.isArray(a)||(a=[a]);try{D(e,l,a)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,f,h,p),s=r.moveTraces(e,l,a),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var a,i,s=[],l=r.addTraces,u=t,h=[e,s,n],f=[e,n];if("undefined"==typeof n)throw new Error("indices must be an integer or array of integers.");for(Array.isArray(n)||(n=[n]),I(e,n,"indices"),(n=z(n,e.data.length-1)).sort(o.sorterDes),a=0;a<n.length;a+=1)i=e.data.splice(n[a],1)[0],s.push(i);var p=r.redraw(e);return c.add(e,l,h,u,f),p},r.extendTraces=function t(e,n,a,i){var s=R(e=o.getGraphDiv(e),n,a,i,function(t,e,r){var n,a;if(o.isTypedArray(t))if(r<0){var i=new t.constructor(0),s=F(t,e);r<0?(n=s,a=i):(n=i,a=s)}else if(n=new t.constructor(r),a=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),a.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),a.set(t),a.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),a.set(t.subarray(0,u))}else n=t.concat(e),a=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,a]}),l=r.redraw(e),u=[e,s.update,a,s.maxPoints];return c.add(e,r.prependTraces,u,t,arguments),l},r.moveTraces=function t(e,n,a){var i,s=[],l=[],u=t,h=t,f=[e=o.getGraphDiv(e),a,n],p=[e,n,a];if(D(e,n,a),n=Array.isArray(n)?n:[n],"undefined"==typeof a)for(a=[],i=0;i<n.length;i++)a.push(-n.length+i);for(a=Array.isArray(a)?a:[a],n=z(n,e.data.length-1),a=z(a,e.data.length-1),i=0;i<e.data.length;i++)-1===n.indexOf(i)&&s.push(e.data[i]);for(i=0;i<n.length;i++)l.push({newIndex:a[i],trace:e.data[n[i]]});for(l.sort(function(t,e){return t.newIndex-e.newIndex}),i=0;i<l.length;i+=1)s.splice(l[i].newIndex,0,l[i].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,f,h,p),d},r.prependTraces=function t(e,n,a,i){var s=R(e=o.getGraphDiv(e),n,a,i,function(t,e,r){var n,a;if(o.isTypedArray(t))if(r<=0){var i=new t.constructor(0),s=F(e,t);r<0?(n=s,a=i):(n=i,a=s)}else if(n=new t.constructor(r),a=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),a.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),a.set(e.subarray(l)),a.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),a.set(t.subarray(c))}else n=e.concat(t),a=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,a]}),l=r.redraw(e),u=[e,s.update,a,s.maxPoints];return c.add(e,r.extendTraces,u,t,arguments),l},r.newPlot=function(t,e,n,a){return t=o.getGraphDiv(t),f.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),f.purge(t),r.plot(t,e,n,a)},r.plot=function(t,e,a,i){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,a=c.layout,i=c.config,s=c.frames}if(!1===l.triggerHandler(t,"plotly_beforeplot",[e,a,i]))return Promise.reject();e||a||o.isPlotDiv(t)||o.warn("Calling Plotly.plot as if redrawing but this container doesn't yet have a plot.",t),O(t,i),a||(a={}),n.select(t).classed("js-plotly-plot",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var h=0===(t.data||[]).length&&Array.isArray(e);Array.isArray(e)&&(k.cleanData(e),h?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!h||(t.layout=k.cleanLayout(a)),f.supplyDefaults(t);var v=t._fullLayout,y=v._has("cartesian");if(!v._has("polar")&&e&&e[0]&&e[0].r)return o.log("Legacy polar charts are deprecated!"),function(t,e,r){var a=n.select(t).selectAll(".plot-container").data([0]);a.enter().insert("div",":first-child").classed("plot-container plotly",!0);var i=a.selectAll(".svg-container").data([0]);i.enter().append("div").classed("svg-container",!0).style("position","relative"),i.html(""),e&&(t.data=e),r&&(t.layout=r),p.manager.fillLayout(t),i.style({width:t._fullLayout.width+"px",height:t._fullLayout.height+"px"}),t.framework=p.manager.framework(t),t.framework({data:t.data,layout:t.layout},i.node()),t.framework.setUndoPoint();var s=t.framework.svg(),l=1,c=t._fullLayout.title?t._fullLayout.title.text:"";""!==c&&c||(l=0);var u=function(){this.call(x.convertToTspans,t)},h=s.select(".title-group text").call(u);if(t._context.edits.titleText){var d=o._(t,"Click to enter Plot title");c&&c!==d||(l=.2,h.attr({"data-unformatted":d}).text(d).style({opacity:l}).on("mouseover.opacity",function(){n.select(this).transition().duration(100).style("opacity",1)}).on("mouseout.opacity",function(){n.select(this).transition().duration(1e3).style("opacity",0)}));var g=function(){this.call(x.makeEditable,{gd:t}).on("edit",function(e){t.framework({layout:{title:{text:e}}}),this.text(e).call(u),this.call(g)}).on("cancel",function(){var t=this.attr("data-unformatted");this.text(t).call(u)})};h.call(g)}return t._context.setBackground(t,t._fullLayout.paper_bgcolor),f.addLinks(t),Promise.resolve()}(t,e,a);v._replotting=!0,h&&lt(t),t.framework!==lt&&(t.framework=lt,lt(t)),g.initGradients(t),h&&d.saveShowSpikeInitial(t);var b=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;b&&f.doCalcdata(t);for(var _=0;_<t.calcdata.length;_++)t.calcdata[_][0].trace=t._fullData[_];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||f.resize(t)},window.addEventListener("resize",t._responsiveChartHandler)):o.clearResponsive(t);var w=o.extendFlat({},v._size),M=0;function A(){if(f.clearAutoMarginIds(t),T.drawMarginPushers(t),d.allowAutoMargin(t),v._has("pie"))for(var e=t._fullData,r=0;r<e.length;r++){var n=e[r];"pie"===n.type&&n.automargin&&f.allowAutoMargin(t,"pie."+n.uid+".automargin")}return f.doAutoMargin(t),f.previousPromises(t)}function S(){t._transitioning||(T.doAutoRangeAndConstraints(t),h&&d.saveRangeInitial(t),u.getComponentMethod("rangeslider","calcAutorange")(t))}var E=[f.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=v._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!v._glcanvas&&v._has("gl")&&(v._glcanvas=v._glcontainer.selectAll(".gl-canvas").data([{key:"contextLayer",context:!0,pick:!1},{key:"focusLayer",context:!1,pick:!1},{key:"pickLayer",context:!1,pick:!0}],function(t){return t.key}),v._glcanvas.enter().append("canvas").attr("class",function(t){return"gl-canvas gl-canvas-"+t.key.replace("Layer","")}).style({position:"absolute",top:0,left:0,overflow:"visible","pointer-events":"none"})),v._glcanvas){v._glcanvas.attr("width",v.width).attr("height",v.height);var a=v._glcanvas.data()[0].regl;if(a&&(Math.floor(v.width)!==a._gl.drawingBufferWidth||Math.floor(v.height)!==a._gl.drawingBufferHeight)){var i="WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.";if(!M)return o.log(i+" Clearing graph and plotting again."),f.cleanPlot([],{},t._fullData,v),f.supplyDefaults(t),v=t._fullLayout,f.doCalcdata(t),M++,e();o.error(i)}}return"h"===v.modebar.orientation?v._modebardiv.style("height",null).style("width","100%"):v._modebardiv.style("width",null).style("height",v.height+"px"),f.previousPromises(t)},A,function(){if(f.didMarginChange(w,v._size))return o.syncOrAsync([A,T.layoutStyles],t)}];y&&E.push(function(){if(b)return o.syncOrAsync([u.getComponentMethod("shapes","calcAutorange"),u.getComponentMethod("annotations","calcAutorange"),S],t);S()}),E.push(T.layoutStyles),y&&E.push(function(){return d.draw(t,h?"":"redraw")}),E.push(T.drawData,T.finalDraw,m,f.addLinks,f.rehover,f.redrag,f.doAutoMargin,f.previousPromises);var C=o.syncOrAsync(E,t);return C&&C.then||(C=Promise.resolve()),C.then(function(){return L(t),t})},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return f.cleanPlot([],{},r,e),f.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},r.react=function(t,e,n,a){var i,l;t=o.getGraphDiv(t),k.clearPromiseQueue(t);var c=t._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,a=d.config,i=d.frames}var g=!1;if(a){var v=o.extendDeep({},t._context);t._context=void 0,O(t,a),g=function t(e,r){var n;for(n in e)if("_"!==n.charAt(0)){var a=e[n],i=r[n];if(a!==i)if(o.isPlainObject(a)&&o.isPlainObject(i)){if(t(a,i))return!0}else{if(!Array.isArray(a)||!Array.isArray(i))return!0;if(a.length!==i.length)return!0;for(var s=0;s<a.length;s++)if(a[s]!==i[s]){if(!o.isPlainObject(a[s])||!o.isPlainObject(i[s]))return!0;if(t(a[s],i[s]))return!0}}}}(v,t._context)}t.data=e||[],k.cleanData(t.data),t.layout=n||{},k.cleanLayout(t.layout),function(t,e,r,n){var a,i,l,c,u,h,f,p,d=n._preGUI,g=[],v={};for(a in d){if(u=rt(a,tt)){if(i=u.attr||u.head+".uirevision",(c=(l=s(n,i).get())&&nt(i,e))&&c===l&&(null===(h=d[a])&&(h=void 0),ot(p=(f=s(e,a)).get(),h))){void 0===p&&"autorange"===a.substr(a.length-9)&&g.push(a.substr(0,a.length-10)),f.set(N(s(n,a).get()));continue}}else o.warn("unrecognized GUI edit: "+a);delete d[a],"range["===a.substr(a.length-8,6)&&(v[a.substr(0,a.length-9)]=1)}for(var m=0;m<g.length;m++){var y=g[m];if(v[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,k=b[_],T=null;for(a in k){if(!T){var M=at(_,r);if(M<0){delete b[_];break}var A=it(_,t,(w=r[M]._fullInput).index);if(A<0){delete b[_];break}T=t[A]}if(u=rt(a,et)){if(u.attr?c=(l=s(n,u.attr).get())&&nt(u.attr,e):(l=w.uirevision,void 0===(c=T.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(h=k[a])&&(h=void 0),ot(p=(f=s(T,a)).get(),h))){f.set(N(s(w,a).get()));continue}}else o.warn("unrecognized GUI edit: "+a+" in trace uid "+_);delete k[a]}}}(t.data,t.layout,c,p),f.supplyDefaults(t,{skipUpdateCalc:!0});var m=t._fullData,y=t._fullLayout,x=void 0===y.datarevision,b=y.transition,_=function(t,e,r,n,a){var i=M.layoutFlags();return i.arrays={},i.rangesAltered={},i.nChanges=0,i.nChangesAnim=0,st(e,r,[],{getValObject:function(t){return h.getLayoutValObject(r,t)},flags:i,immutable:n,transition:a,gd:t}),(i.plot||i.calc)&&(i.layoutReplot=!0),a&&i.nChanges&&i.nChangesAnim&&(i.anim=i.nChanges===i.nChangesAnim?"all":"some"),i}(t,p,y,x,b),w=_.newDataRevision,A=function(t,e,r,n,a,i){var o=e.length===r.length;if(!a&&!o)return{fullReplot:!0,calc:!0};var s,l,c=M.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=h.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:a,newDataRevision:i,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,f.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,st(e[s]._fullInput,l,[],u)}return(c.calc||c.plot)&&(c.fullReplot=!0),a&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?"all":"some"),c}(t,c,m,x,b,w);K(t)&&(_.layoutReplot=!0),A.calc||_.calc?t.calcdata=void 0:f.supplyDefaultsUpdateCalc(t.calcdata,m);var S=[];if(i&&(t._transitionData={},f.createTransitionData(t),S.push(function(){return r.addFrames(t,i)})),y.transition&&!g&&(A.anim||_.anim))f.doCalcdata(t),T.doAutoRangeAndConstraints(t),S.push(function(){return f.transitionFromReact(t,A,_,p)});else if(A.fullReplot||_.layoutReplot||g)t._fullLayout._skipDefaults=!0,S.push(r.plot);else{for(var E in _.arrays){var C=_.arrays[E];if(C.length){var P=u.getComponentMethod(E,"drawOne");if(P!==o.noop)for(var z=0;z<C.length;z++)P(t,C[z]);else{var I=u.getComponentMethod(E,"draw");if(I===o.noop)throw new Error("cannot draw components: "+E);I(t)}}}S.push(f.previousPromises),A.style&&S.push(T.doTraceStyle),(A.colorbars||_.colorbars)&&S.push(T.doColorBars),_.legend&&S.push(T.doLegend),_.layoutstyle&&S.push(T.layoutStyles),_.axrange&&Y(S),_.ticks&&S.push(T.doTicksRelayout),_.modebar&&S.push(T.doModeBar),_.camera&&S.push(T.doCamera),S.push(L)}S.push(f.rehover,f.redrag),(l=o.syncOrAsync(S,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,a);return l.then(function(){return t.emit("plotly_react",{data:e,layout:n}),t})},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error("This element is not a Plotly plot: "+t);return k.cleanData(t.data),k.cleanLayout(t.layout),t.calcdata=void 0,r.plot(t).then(function(){return t.emit("plotly_redraw"),t})},r.relayout=H,r.restyle=B,r.setPlotConfig=function(t){return o.extendFlat(_,t)},r.update=Q,r._guiRelayout=$(H),r._guiRestyle=$(B),r._guiUpdate=$(Q),r._storeDirectGUIEdit=function(t,e,r){for(var n in r)V(n,s(t,n).get(),r[n],e)}},{"../components/color":591,"../components/drawing":612,"../constants/xmlns_namespaces":694,"../lib":717,"../lib/events":707,"../lib/queue":732,"../lib/svg_text_utils":741,"../plots/cartesian/axes":765,"../plots/cartesian/constants":771,"../plots/cartesian/graph_interact":774,"../plots/cartesian/select":782,"../plots/plots":826,"../plots/polar/legacy":834,"../registry":846,"./edit_types":748,"./helpers":749,"./manage_arrays":751,"./plot_config":753,"./plot_schema":754,"./subroutines":756,d3:165,"fast-isnumeric":228,"has-hover":411}],753:[function(t,e,r){"use strict";var n={staticPlot:{valType:"boolean",dflt:!1},plotlyServerURL:{valType:"string",dflt:""},editable:{valType:"boolean",dflt:!1},edits:{annotationPosition:{valType:"boolean",dflt:!1},annotationTail:{valType:"boolean",dflt:!1},annotationText:{valType:"boolean",dflt:!1},axisTitleText:{valType:"boolean",dflt:!1},colorbarPosition:{valType:"boolean",dflt:!1},colorbarTitleText:{valType:"boolean",dflt:!1},legendPosition:{valType:"boolean",dflt:!1},legendText:{valType:"boolean",dflt:!1},shapePosition:{valType:"boolean",dflt:!1},titleText:{valType:"boolean",dflt:!1}},autosizable:{valType:"boolean",dflt:!1},responsive:{valType:"boolean",dflt:!1},fillFrame:{valType:"boolean",dflt:!1},frameMargins:{valType:"number",dflt:0,min:0,max:.5},scrollZoom:{valType:"flaglist",flags:["cartesian","gl3d","geo","mapbox"],extras:[!0,!1],dflt:"gl3d+geo+mapbox"},doubleClick:{valType:"enumerated",values:[!1,"reset","autosize","reset+autosize"],dflt:"reset+autosize"},doubleClickDelay:{valType:"number",dflt:300,min:0},showAxisDragHandles:{valType:"boolean",dflt:!0},showAxisRangeEntryBoxes:{valType:"boolean",dflt:!0},showTips:{valType:"boolean",dflt:!0},showLink:{valType:"boolean",dflt:!1},linkText:{valType:"string",dflt:"Edit chart",noBlank:!0},sendData:{valType:"boolean",dflt:!0},showSources:{valType:"any",dflt:!1},displayModeBar:{valType:"enumerated",values:["hover",!0,!1],dflt:"hover"},showSendToCloud:{valType:"boolean",dflt:!1},showEditInChartStudio:{valType:"boolean",dflt:!1},modeBarButtonsToRemove:{valType:"any",dflt:[]},modeBarButtonsToAdd:{valType:"any",dflt:[]},modeBarButtons:{valType:"any",dflt:!1},toImageButtonOptions:{valType:"any",dflt:{}},displaylogo:{valType:"boolean",dflt:!0},watermark:{valType:"boolean",dflt:!1},plotGlPixelRatio:{valType:"number",dflt:2,min:1,max:4},setBackground:{valType:"any",dflt:"transparent"},topojsonURL:{valType:"string",noBlank:!0,dflt:"https://cdn.plot.ly/"},mapboxAccessToken:{valType:"string",dflt:null},logging:{valType:"integer",min:0,max:2,dflt:1},notifyOnLogging:{valType:"integer",min:0,max:2,dflt:0},queueLength:{valType:"integer",min:0,dflt:0},globalTransforms:{valType:"any",dflt:[]},locale:{valType:"string",dflt:"en-US"},locales:{valType:"any",dflt:{}}},a={};!function t(e,r){for(var n in e){var a=e[n];a.valType?r[n]=a.dflt:(r[n]||(r[n]={}),t(a,r[n]))}}(n,a),e.exports={configAttributes:n,dfltConfig:a}},{}],754:[function(t,e,r){"use strict";var n=t("../registry"),a=t("../lib"),i=t("../plots/attributes"),o=t("../plots/layout_attributes"),s=t("../plots/frame_attributes"),l=t("../plots/animation_attributes"),c=t("./plot_config").configAttributes,u=t("../plots/polar/legacy/area_attributes"),h=t("../plots/polar/legacy/axis_attributes"),f=t("./edit_types"),p=a.extendFlat,d=a.extendDeepAll,g=a.isPlainObject,v=a.isArrayOrTypedArray,m=a.nestedProperty,y=a.valObjectMeta,x="_isSubplotObj",b="_isLinkedToArray",_=[x,b,"_arrayAttrRegexps","_deprecated"];function w(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(k(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!g(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!k(e[++r]))return!1}else if("info_array"===t.valType){var a=e[++r];if(!k(a))return!1;var i=t.items;if(Array.isArray(i)){if(a>=i.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!k(o))return!1;t=i[a][o]}else t=i[a]}else t=i}}return t}function k(t){return t===Math.round(t)&&t>=0}function T(){var t,e,r={};for(t in d(r,o),n.subplotsRegistry){if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var a=0;a<e.attr.length;a++)S(r,e,e.attr[a]);else S(r,e,"subplot"===e.attr?e.name:e.attr)}for(t in r=function(t){return p(t,{radialaxis:h.radialaxis,angularaxis:h.angularaxis}),p(t,h.layout),t}(r),n.componentsRegistry){var i=(e=n.componentsRegistry[t]).schema;if(i&&(i.subplots||i.layout)){var s=i.subplots;if(s&&s.xaxis&&!s.yaxis)for(var l in s.xaxis)delete r.yaxis[l]}else"colorscale"===e.name?d(r,e.layoutAttributes):e.layoutAttributes&&E(r,e.layoutAttributes,e.name)}return{layoutAttributes:A(r)}}function M(){var t={frames:d({},s)};return A(t),t.frames}function A(t){return function(t){r.crawl(t,function(t,e,n){r.isValObject(t)?"data_array"===t.valType?(t.role="data",n[e+"src"]={valType:"string",editType:"none"}):!0===t.arrayOk&&(n[e+"src"]={valType:"string",editType:"none"}):g(t)&&(t.role="object")})}(t),function(t){r.crawl(t,function(t,e,r){if(!t)return;var n=t[b];if(!n)return;delete t[b],r[e]={items:{}},r[e].items[n]=t,r[e].role="object"})}(t),function(t){!function t(e){for(var r in e)if(g(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function S(t,e,r){var n=m(t,r),a=d({},e.layoutAttributes);a[x]=!0,n.set(a)}function E(t,e,r){var n=m(t,r);n.set(d(n.get()||{},e))}r.IS_SUBPLOT_OBJ=x,r.IS_LINKED_TO_ARRAY=b,r.DEPRECATED="_deprecated",r.UNDERSCORE_ATTRS=_,r.get=function(){var t={};n.allTypes.concat("area").forEach(function(e){t[e]=function(t){var e,a;"area"===t?(e={attributes:u},a={}):(e=n.modules[t]._module,a=e.basePlotModule);var o={type:null},s=d({},i),l=d({},e.attributes);r.crawl(l,function(t,e,r,n,a){m(s,a).set(void 0),void 0===t&&m(l,a).set(void 0)}),d(o,s),n.traceIs(t,"noOpacity")&&delete o.opacity;n.traceIs(t,"showLegend")||(delete o.showlegend,delete o.legendgroup);n.traceIs(t,"noHover")&&(delete o.hoverinfo,delete o.hoverlabel);e.selectPoints||delete o.selectedpoints;d(o,l),a.attributes&&d(o,a.attributes);o.type=t;var c={meta:e.meta||{},categories:e.categories||{},animatable:Boolean(e.animatable),type:t,attributes:A(o)};if(e.layoutAttributes){var h={};d(h,e.layoutAttributes),c.layoutAttributes=A(h)}e.animatable||r.crawl(c,function(t){r.isValObject(t)&&"anim"in t&&delete t.anim});return c}(e)});var e={};return Object.keys(n.transformsRegistry).forEach(function(t){e[t]=function(t){var e=n.transformsRegistry[t],r=d({},e.attributes);return Object.keys(n.componentsRegistry).forEach(function(e){var a=n.componentsRegistry[e];a.schema&&a.schema.transforms&&a.schema.transforms[t]&&Object.keys(a.schema.transforms[t]).forEach(function(e){E(r,a.schema.transforms[t][e],e)})}),{attributes:A(r)}}(t)}),{defs:{valObjects:y,metaKeys:_.concat(["description","role","editType","impliedEdits"]),editType:{traces:f.traces,layout:f.layout},impliedEdits:{}},traces:t,layout:T(),transforms:e,frames:M(),animation:A(l),config:A(c)}},r.crawl=function(t,e,n,a){var i=n||0;a=a||"",Object.keys(t).forEach(function(n){var o=t[n];if(-1===_.indexOf(n)){var s=(a?a+".":"")+n;e(o,n,t,i,s),r.isValObject(o)||g(o)&&"impliedEdits"!==n&&r.crawl(o,e,i+1,s)}})},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,a=[],o=[],s=[];function l(t,r,i,l){o=o.slice(0,l).concat([r]),s=s.slice(0,l).concat([t&&t._isLinkedToArray]),t&&("data_array"===t.valType||!0===t.arrayOk)&&!("colorbar"===o[l-1]&&("ticktext"===r||"tickvals"===r))&&function t(e,r,i){var l=e[o[r]];var c=i+o[r];if(r===o.length-1)v(l)&&a.push(n+c);else if(s[r]){if(Array.isArray(l))for(var u=0;u<l.length;u++)g(l[u])&&t(l[u],r+1,c+"["+u+"].")}else g(l)&&t(l,r+1,c+".")}(e,0,"")}e=t,n="",r.crawl(i,l),t._module&&t._module.attributes&&r.crawl(t._module.attributes,l);var c=t.transforms;if(c)for(var u=0;u<c.length;u++){var h=c[u],f=h._module;f&&(n="transforms["+u+"].",e=h,r.crawl(f.attributes,l))}return a},r.getTraceValObject=function(t,e){var r,a,o=e[0],s=1;if("transforms"===o){if(1===e.length)return i.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!k(c)||c>=l.length)return!1;a=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else if("area"===t.type)a=u[o];else{var h=t._module;if(h||(h=(n.modules[t.type||i.type.dflt]||{})._module),!h)return!1;if(!(a=(r=h.attributes)&&r[o])){var f=h.basePlotModule;f&&f.attributes&&(a=f.attributes[o])}a||(a=i[o])}return w(a,e,s)},r.getLayoutValObject=function(t,e){return w(function(t,e){var r,a,i,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((i=l[r]).attrRegex&&i.attrRegex.test(e)){if(i.layoutAttrOverrides)return i.layoutAttrOverrides;!c&&i.layoutAttributes&&(c=i.layoutAttributes)}var u=i.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var f=t._modules;if(f)for(r=0;r<f.length;r++)if((s=f[r].layoutAttributes)&&e in s)return s[e];for(a in n.componentsRegistry){if("colorscale"===(i=n.componentsRegistry[a]).name&&0===e.indexOf("coloraxis"))return i.layoutAttributes[e];if(!i.schema&&e===i.name)return i.layoutAttributes}if(e in o)return o[e];if("radialaxis"===e||"angularaxis"===e)return h[e];return h.layout[e]||!1}(t,e[0]),e,1)}},{"../lib":717,"../plots/animation_attributes":760,"../plots/attributes":762,"../plots/frame_attributes":792,"../plots/layout_attributes":817,"../plots/polar/legacy/area_attributes":832,"../plots/polar/legacy/axis_attributes":833,"../registry":846,"./edit_types":748,"./plot_config":753}],755:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../plots/attributes"),i="templateitemname",o={name:{valType:"string",editType:"none"}};function s(t){return t&&"string"==typeof t}function l(t){var e=t.length-1;return"s"!==t.charAt(e)&&n.warn("bad argument to arrayDefaultKey: "+t),t.substr(0,t.length-1)+"defaults"}o[i]={valType:"string",editType:"calc"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=o.name,e[i]=o[i],e},r.traceTemplater=function(t){var e,r,i={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(i[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},a,"type"),_template:null};if(e in i){r=t[e];var l=i[e]%r.length;i[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var a=t._template,i=a&&(a[e]||r&&a[r]);return n.isPlainObject(i)||(i=null),t[e]={_template:i}},r.arrayTemplater=function(t,e,r){var n=t._template,a=n&&n[l(e)],o=n&&n[e];Array.isArray(o)&&o.length||(o=[]);var c={};return{newItem:function(t){var e={name:t.name,_input:t},n=e[i]=t[i];if(!s(n))return e._template=a,e;for(var l=0;l<o.length;l++){var u=o[l];if(u.name===n)return c[n]=1,e._template=u,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<o.length;e++){var r=o[e],n=r.name;if(s(n)&&!c[n]){var a={_template:r,name:n,_input:{_templateitemname:n}};a[i]=r[i],t.push(a),c[n]=1}}return t}}},r.arrayDefaultKey=l,r.arrayEditor=function(t,e,r){var a=(n.nestedProperty(t,e).get()||[]).length,o=r._index,s=o>=a&&(r._input||{})._templateitemname;s&&(o=a);var l,c=e+"["+o+"]";function u(){l={},s&&(l[c]={},l[c][i]=s)}function h(t,e){s?n.nestedProperty(l[c],t).set(e):l[c+"."+t]=e}function f(){var t=l;return u(),t}return u(),{modifyBase:function(t,e){l[t]=e},modifyItem:h,getUpdateObj:f,applyUpdate:function(e,r){e&&h(e,r);var a=f();for(var i in a)n.nestedProperty(t,i).set(a[i])}}}},{"../lib":717,"../plots/attributes":762}],756:[function(t,e,r){"use strict";var n=t("d3"),a=t("../registry"),i=t("../plots/plots"),o=t("../lib"),s=t("../lib/clear_gl_canvases"),l=t("../components/color"),c=t("../components/drawing"),u=t("../components/titles"),h=t("../components/modebar"),f=t("../plots/cartesian/axes"),p=t("../constants/alignment"),d=t("../plots/cartesian/constraints"),g=d.enforce,v=d.clean,m=t("../plots/cartesian/autorange").doAutoRange,y="start",x="middle",b="end";function _(t,e,r){for(var n=0;n<r.length;n++){var a=r[n][0],i=r[n][1];if(!(a[0]>=t[1]||a[1]<=t[0])&&(i[0]<e[1]&&i[1]>e[0]))return!0}return!1}function w(t){var e,a,s,u,d,g,v=t._fullLayout,m=v._size,y=m.p,x=f.list(t,"",!0);if(v._paperdiv.style({width:t._context.responsive&&v.autosize&&!t._context._hasZeroWidth&&!t.layout.width?"100%":v.width+"px",height:t._context.responsive&&v.autosize&&!t._context._hasZeroHeight&&!t.layout.height?"100%":v.height+"px"}).selectAll(".main-svg").call(c.setSize,v.width,v.height),t._context.setBackground(t,v.paper_bgcolor),r.drawMainTitle(t),h.manage(t),!v._has("cartesian"))return i.previousPromises(t);function b(t,e,r){var n=t._lw/2;return"x"===t._id.charAt(0)?e?"top"===r?e._offset-y-n:e._offset+e._length+y+n:m.t+m.h*(1-(t.position||0))+n%1:e?"right"===r?e._offset+e._length+y+n:e._offset-y-n:m.l+m.w*(t.position||0)+n%1}for(e=0;e<x.length;e++){var w=(u=x[e])._anchorAxis;u._linepositions={},u._lw=c.crispRound(t,u.linewidth,1),u._mainLinePosition=b(u,w,u.side),u._mainMirrorPosition=u.mirror&&w?b(u,w,p.OPPOSITE_SIDE[u.side]):null}var T=[],A=[],S=[],E=1===l.opacity(v.paper_bgcolor)&&1===l.opacity(v.plot_bgcolor)&&v.paper_bgcolor===v.plot_bgcolor;for(a in v._plots)if((s=v._plots[a]).mainplot)s.bg&&s.bg.remove(),s.bg=void 0;else{var L=s.xaxis.domain,C=s.yaxis.domain,P=s.plotgroup;if(_(L,C,S)){var O=P.node(),z=s.bg=o.ensureSingle(P,"rect","bg");O.insertBefore(z.node(),O.childNodes[0]),A.push(a)}else P.select("rect.bg").remove(),S.push([L,C]),E||(T.push(a),A.push(a))}var I,D,R,F,B,N,j,V,U,q,H,G,Y,W=v._bgLayer.selectAll(".bg").data(T);for(W.enter().append("rect").classed("bg",!0),W.exit().remove(),W.each(function(t){v._plots[t].bg=n.select(this)}),e=0;e<A.length;e++)s=v._plots[A[e]],d=s.xaxis,g=s.yaxis,s.bg&&s.bg.call(c.setRect,d._offset-y,g._offset-y,d._length+2*y,g._length+2*y).call(l.fill,v.plot_bgcolor).style("stroke-width",0);if(!v._hasOnlyLargeSploms)for(a in v._plots){s=v._plots[a],d=s.xaxis,g=s.yaxis;var X,Z,J=s.clipId="clip"+v._uid+a+"plot",K=o.ensureSingleById(v._clips,"clipPath",J,function(t){t.classed("plotclip",!0).append("rect")});s.clipRect=K.select("rect").attr({width:d._length,height:g._length}),c.setTranslate(s.plot,d._offset,g._offset),s._hasClipOnAxisFalse?(X=null,Z=J):(X=J,Z=null),c.setClipUrl(s.plot,X,t),s.layerClipId=Z}function Q(t){return"M"+I+","+t+"H"+D}function $(t){return"M"+d._offset+","+t+"h"+d._length}function tt(t){return"M"+t+","+V+"V"+j}function et(t){return"M"+t+","+g._offset+"v"+g._length}function rt(t,e,r){if(!t.showline||a!==t._mainSubplot)return"";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(a in v._plots){s=v._plots[a],d=s.xaxis,g=s.yaxis;var nt="M0,0";k(d,a)&&(B=M(d,"left",g,x),I=d._offset-(B?y+B:0),N=M(d,"right",g,x),D=d._offset+d._length+(N?y+N:0),R=b(d,g,"bottom"),F=b(d,g,"top"),!(Y=!d._anchorAxis||a!==d._mainSubplot)||"allticks"!==d.mirror&&"all"!==d.mirror||(d._linepositions[a]=[R,F]),nt=rt(d,Q,$),Y&&d.showline&&("all"===d.mirror||"allticks"===d.mirror)&&(nt+=Q(R)+Q(F)),s.xlines.style("stroke-width",d._lw+"px").call(l.stroke,d.showline?d.linecolor:"rgba(0,0,0,0)")),s.xlines.attr("d",nt);var at="M0,0";k(g,a)&&(H=M(g,"bottom",d,x),j=g._offset+g._length+(H?y:0),G=M(g,"top",d,x),V=g._offset-(G?y:0),U=b(g,d,"left"),q=b(g,d,"right"),!(Y=!g._anchorAxis||a!==g._mainSubplot)||"allticks"!==g.mirror&&"all"!==g.mirror||(g._linepositions[a]=[U,q]),at=rt(g,tt,et),Y&&g.showline&&("all"===g.mirror||"allticks"===g.mirror)&&(at+=tt(U)+tt(q)),s.ylines.style("stroke-width",g._lw+"px").call(l.stroke,g.showline?g.linecolor:"rgba(0,0,0,0)")),s.ylines.attr("d",at)}return f.makeClipPaths(t),i.previousPromises(t)}function k(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||"all"===t.mirror||"allticks"===t.mirror)}function T(t,e,r){if(!r.showline||!r._lw)return!1;if("all"===r.mirror||"allticks"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var a=p.FROM_BL[e];return r.side===e?n.domain[a]===t.domain[a]:r.mirror&&n.domain[1-a]===t.domain[1-a]}function M(t,e,r,n){if(T(t,e,r))return r._lw;for(var a=0;a<n.length;a++){var i=n[a];if(i._mainAxis===r._mainAxis&&T(t,e,i))return i._lw}return 0}function A(t,e){var r=t.title,n=t._size,a=0;switch(e===y?a=r.pad.l:e===b&&(a=-r.pad.r),r.xref){case"paper":return n.l+n.w*r.x+a;case"container":default:return t.width*r.x+a}}function S(t,e){var r=t.title,n=t._size,a=0;if("0em"!==e&&e?e===p.CAP_SHIFT+"em"&&(a=r.pad.t):a=-r.pad.b,"auto"===r.y)return n.t/2;switch(r.yref){case"paper":return n.t+n.h-n.h*r.y+a;case"container":default:return t.height-t.height*r.y+a}}r.layoutStyles=function(t){return o.syncOrAsync([i.doAutoMargin,w],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=x;o.isRightAnchor(e)?r=b:o.isLeftAnchor(e)&&(r=y);return r}(e),n=function(t){var e=t.title,r="0em";o.isTopAnchor(e)?r=p.CAP_SHIFT+"em":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+"em");return r}(e);u.draw(t,"gtitle",{propContainer:e,propName:"title.text",placeholder:e._dfltTitle.plot,attributes:{x:A(e,r),y:S(e,n),"text-anchor":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},h=u._module||{},f=h.arraysToCalcdata;f&&f(l,u);var p=h.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return i.style(t),a.getComponentMethod("legend","draw")(t),i.previousPromises(t)},r.doColorBars=function(t){return a.getComponentMethod("colorbar","draw")(t),i.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,a.call("plot",t,"",e)},r.doLegend=function(t){return a.getComponentMethod("legend","draw")(t),i.previousPromises(t)},r.doTicksRelayout=function(t){return f.draw(t,"redraw"),t._fullLayout._hasOnlyLargeSploms&&(a.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),i.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;h.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return i.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var a=e[r[n]];a._scene.setViewport(a)}},r.drawData=function(t){var e=t._fullLayout;s(t);for(var n=e._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return r.redrawReglTraces(t),i.style(t),a.getComponentMethod("shapes","draw")(t),a.getComponentMethod("annotations","draw")(t),a.getComponentMethod("images","draw")(t),e._replotting=!1,i.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has("regl")){var r,n,a=t._fullData,i=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<a.length;r++){var l=a[r];!0===l.visible&&0!==l._length&&("splom"===l.type?e._splomScenes[l.uid].draw():"scattergl"===l.type?o.pushUnique(i,l.xaxis+l.yaxis):"scatterpolargl"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<i.length;r++)(n=e._plots[i[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e,r,n=t._fullLayout,a=f.list(t,"",!0),i=n._axisMatchGroups||[],s={},l=0;l<a.length;l++)e=a[l],v(t,e),m(t,e),s[e._id]=1;g(t);t:for(var c=0;c<i.length;c++){var u,h=i[c],p=null;for(u in h)if(s[(e=f.getFromId(t,u))._id]){if(!1===e.autorange)continue t;r=o.simpleMap(e.range,e.r2l),p?p[0]<p[1]?(p[0]=Math.min(p[0],r[0]),p[1]=Math.max(p[1],r[1])):(p[0]=Math.max(p[0],r[0]),p[1]=Math.min(p[1],r[1])):p=r}for(u in h)(e=f.getFromId(t,u)).range=o.simpleMap(p,e.l2r),e._input.range=e.range.slice(),e.setScale()}},r.finalDraw=function(t){a.getComponentMethod("rangeslider","draw")(t),a.getComponentMethod("rangeselector","draw")(t)},r.drawMarginPushers=function(t){a.getComponentMethod("legend","draw")(t),a.getComponentMethod("rangeselector","draw")(t),a.getComponentMethod("sliders","draw")(t),a.getComponentMethod("updatemenus","draw")(t),a.getComponentMethod("colorbar","draw")(t)}},{"../components/color":591,"../components/drawing":612,"../components/modebar":650,"../components/titles":679,"../constants/alignment":686,"../lib":717,"../lib/clear_gl_canvases":702,"../plots/cartesian/autorange":764,"../plots/cartesian/axes":765,"../plots/cartesian/constraints":772,"../plots/plots":826,"../registry":846,d3:165}],757:[function(t,e,r){"use strict";var n=t("../lib"),a=n.isPlainObject,i=t("./plot_schema"),o=t("../plots/plots"),s=t("../plots/attributes"),l=t("./plot_template"),c=t("./plot_config").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,i,o=Object.keys(t).sort();function s(e,r,n){if(a(r)&&a(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(i=0;i<r.length;i++){var s=r[i],c=o.newItem(s)._template;c&&u(c,s)}var h=o.defaultItems();for(i=0;i<h.length;i++)r.push(h[i]._template);for(i=0;i<r.length;i++)delete r[i].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],f=t[c];if(c in e?s(f,e[c],c):e[c]=f,h(c)===c)for(var p in e){var d=h(p);p===d||d!==c||p in t||s(f,e[p],c)}}}function h(t){return t.replace(/[0-9]+$/,"")}function f(t,e,r,i,o){var s=o&&r(o);for(var c in t){var u=t[c],d=p(t,c,i),g=p(t,c,o),v=r(g);if(!v){var m=h(c);m!==c&&(v=r(g=p(t,m,o)))}if((!s||s!==v)&&!(!v||v._noTemplating||"data_array"===v.valType||v.arrayOk&&Array.isArray(u)))if(!v.valType&&a(u))f(u,e,r,d,g);else if(v._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(a(w)){var k=w.name;if(k)b[k]||(f(w,e,r,p(u,x,d),p(u,x,g)),x++,b[k]=1);else if(!y){var T=p(t,l.arrayDefaultKey(c),i),M=p(u,x,d);f(w,e,r,M,p(u,x,g));var A=n.nestedProperty(e,M);n.nestedProperty(e,T).set(A.get()),A.set(null),y=!0}}}else{n.nestedProperty(e,d).set(u)}}}function p(t,e,r){return r?Array.isArray(t)?r+"["+e+"]":r+"."+e:e}function d(t){for(var e=0;e<t.length;e++)if(a(t[e]))return!0}function g(t){var e;switch(t.code){case"data":e="The template has no key data.";break;case"layout":e="The template has no key layout.";break;case"missing":e=t.path?"There are no templates for item "+t.path+" with name "+t.templateitemname:"There are no templates for trace "+t.index+", of type "+t.traceType+".";break;case"unused":e=t.path?"The template item at "+t.path+" was not used in constructing the plot.":t.dataCount?"Some of the templates of type "+t.traceType+" were not used. The template has "+t.templateCount+" traces, the data only has "+t.dataCount+" of this type.":"The template has "+t.templateCount+" traces of type "+t.traceType+" but there are none in the data.";break;case"reused":e="Some of the templates of type "+t.traceType+" were used more than once. The template has "+t.templateCount+" traces, the data has "+t.dataCount+" of this type."}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var l={data:{},layout:{}};e.forEach(function(t){var e={};f(t,e,function(t,e){return i.getTraceValObject(t,n.nestedProperty({},e).parts)}.bind(null,t));var r=n.coerce(t,{},s,"type"),a=l.data[r];a||(a=l.data[r]=[]),a.push(e)}),f(r,l.layout,function(t,e){return i.getLayoutValObject(t,n.nestedProperty({},e).parts)}.bind(null,r)),delete l.layout.template;var h=r.template;if(a(h)){var p,d,g,v,m,y,x=h.layout;a(x)&&u(x,l.layout);var b=h.data;if(a(b)){for(d in l.data)if(g=b[d],Array.isArray(g)){for(y=(m=l.data[d]).length,v=g.length,p=0;p<y;p++)u(g[p%v],m[p]);for(p=y;p<v;p++)m.push(n.extendDeep({},g[p]))}for(d in b)d in l.data||(l.data[d]=n.extendDeep([],b[d]))}}return l},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),i=r.layout||{};a(e)||(e=i.template||{});var s=e.layout,l=e.data,u=[];r.layout=i,r.layout.template=e,o.supplyDefaults(r);var f=r._fullLayout,v=r._fullData,m={};if(a(s)?(!function t(e,r){for(var n in e)if("_"!==n.charAt(0)&&a(e[n])){var i,o=h(n),s=[];for(i=0;i<r.length;i++)s.push(p(e,n,r[i])),o!==n&&s.push(p(e,o,r[i]));for(i=0;i<s.length;i++)m[s[i]]=1;t(e[n],s)}}(f,["layout"]),function t(e,r){for(var n in e)if(-1===n.indexOf("defaults")&&a(e[n])){var i=p(e,n,r);m[i]?t(e[n],i):u.push({code:"unused",path:i})}}(s,"layout")):u.push({code:"layout"}),a(l)){for(var y,x={},b=0;b<v.length;b++){var _=v[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:"missing",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,k=x[y]||0;w>k?u.push({code:"unused",traceType:y,templateCount:w,dataCount:k}):k>w&&u.push({code:"reused",traceType:y,templateCount:w,dataCount:k})}}else u.push({code:"data"});if(function t(e,r){for(var n in e)if("_"!==n.charAt(0)){var i=e[n],o=p(e,n,r);a(i)?(Array.isArray(e)&&!1===i._template&&i.templateitemname&&u.push({code:"missing",path:o,templateitemname:i.templateitemname}),t(i,o)):Array.isArray(i)&&d(i)&&t(i,o)}}({data:v,layout:f},""),u.length)return u.map(g)}},{"../lib":717,"../plots/attributes":762,"../plots/plots":826,"./plot_config":753,"./plot_schema":754,"./plot_template":755}],758:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("./plot_api"),i=t("../plots/plots"),o=t("../lib"),s=t("../snapshot/helpers"),l=t("../snapshot/tosvg"),c=t("../snapshot/svgtoimg"),u=t("../version").version,h={format:{valType:"enumerated",values:["png","jpeg","webp","svg","full-json"],dflt:"png"},width:{valType:"number",min:1},height:{valType:"number",min:1},scale:{valType:"number",min:0,dflt:1},setBackground:{valType:"any",dflt:!1},imageDataOnly:{valType:"boolean",dflt:!1}};e.exports=function(t,e){var r,f,p,d;function g(t){return!(t in e)||o.validate(e[t],h[t])}if(e=e||{},o.isPlainObject(t)?(r=t.data||[],f=t.layout||{},p=t.config||{},d={}):(t=o.getGraphDiv(t),r=o.extendDeep([],t.data),f=o.extendDeep({},t.layout),p=t._context,d=t._fullLayout||{}),!g("width")&&null!==e.width||!g("height")&&null!==e.height)throw new Error("Height and width should be pixel values.");if(!g("format"))throw new Error("Image format is not jpeg, png, svg or webp.");var v={};function m(t,r){return o.coerce(e,v,h,t,r)}var y=m("format"),x=m("width"),b=m("height"),_=m("scale"),w=m("setBackground"),k=m("imageDataOnly"),T=document.createElement("div");T.style.position="absolute",T.style.left="-5000px",document.body.appendChild(T);var M=o.extendFlat({},f);x?M.width=x:null===e.width&&n(d.width)&&(M.width=d.width),b?M.height=b:null===e.height&&n(d.height)&&(M.height=d.height);var A=o.extendFlat({},p,{_exportedPlot:!0,staticPlot:!0,setBackground:w}),S=s.getRedrawFunc(T);function E(){return new Promise(function(t){setTimeout(t,s.getDelay(T._fullLayout))})}function L(){return new Promise(function(t,e){var r=l(T,y,_),n=T._fullLayout.width,h=T._fullLayout.height;function f(){a.purge(T),document.body.removeChild(T)}if("full-json"===y){var p=i.graphJson(T,!1,"keepdata","object",!0,!0);return p.version=u,p=JSON.stringify(p),f(),t(k?p:s.encodeJSON(p))}if(f(),"svg"===y)return t(k?r:s.encodeSVG(r));var d=document.createElement("canvas");d.id=o.randstr(),c({format:y,width:n,height:h,scale:_,canvas:d,svg:r,promise:!0}).then(t).catch(e)})}return new Promise(function(t,e){a.plot(T,r,M,A).then(S).then(E).then(L).then(function(e){t(function(t){return k?t.replace(s.IMAGE_URL_PREFIX,""):t}(e))}).catch(function(t){e(t)})})}},{"../lib":717,"../plots/plots":826,"../snapshot/helpers":850,"../snapshot/svgtoimg":852,"../snapshot/tosvg":854,"../version":1302,"./plot_api":752,"fast-isnumeric":228}],759:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../plots/plots"),i=t("./plot_schema"),o=t("./plot_config").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,a,i,o){o=o||[];for(var h=Object.keys(t),f=0;f<h.length;f++){var v=h[f];if("transforms"!==v){var m=o.slice();m.push(v);var y=t[v],x=e[v],b=g(r,v),_=(b||{}).valType,w="info_array"===_,k="colorscale"===_,T=(b||{}).items;if(d(r,v))if(s(y)&&s(x)&&"any"!==_)u(y,x,b,a,i,m);else if(w&&l(y)){y.length>x.length&&a.push(p("unused",i,m.concat(x.length)));var M,A,S,E,L,C=x.length,P=Array.isArray(T);if(P&&(C=Math.min(C,T.length)),2===b.dimensions)for(A=0;A<C;A++)if(l(y[A])){y[A].length>x[A].length&&a.push(p("unused",i,m.concat(A,x[A].length)));var O=x[A].length;for(M=0;M<(P?Math.min(O,T[A].length):O);M++)S=P?T[A][M]:T,E=y[A][M],L=x[A][M],n.validate(E,S)?L!==E&&L!==+E&&a.push(p("dynamic",i,m.concat(A,M),E,L)):a.push(p("value",i,m.concat(A,M),E))}else a.push(p("array",i,m.concat(A),y[A]));else for(A=0;A<C;A++)S=P?T[A]:T,E=y[A],L=x[A],n.validate(E,S)?L!==E&&L!==+E&&a.push(p("dynamic",i,m.concat(A),E,L)):a.push(p("value",i,m.concat(A),E))}else if(b.items&&!w&&l(y)){var z,I,D=T[Object.keys(T)[0]],R=[];for(z=0;z<x.length;z++){var F=x[z]._index||z;if((I=m.slice()).push(F),s(y[F])&&s(x[z])){R.push(F);var B=y[F],N=x[z];s(B)&&!1!==B.visible&&!1===N.visible?a.push(p("invisible",i,I)):u(B,N,D,a,i,I)}}for(z=0;z<y.length;z++)(I=m.slice()).push(z),s(y[z])?-1===R.indexOf(z)&&a.push(p("unused",i,I)):a.push(p("object",i,I,y[z]))}else!s(y)&&s(x)?a.push(p("object",i,m,y)):c(y)||!c(x)||w||k?v in e?n.validate(y,b)?"enumerated"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&a.push(p("dynamic",i,m,y,x)):a.push(p("value",i,m,y)):a.push(p("unused",i,m,y)):a.push(p("array",i,m,y));else a.push(p("schema",i,m))}}return a}e.exports=function(t,e){var r,c,h=i.get(),f=[],d={_context:n.extendFlat({},o)};l(t)?(d.data=n.extendDeep([],t),r=t):(d.data=[],r=[],f.push(p("array","data"))),s(e)?(d.layout=n.extendDeep({},e),c=e):(d.layout={},c={},arguments.length>1&&f.push(p("object","layout"))),a.supplyDefaults(d);for(var g=d._fullData,v=r.length,m=0;m<v;m++){var y=r[m],x=["data",m];if(s(y)){var b=g[m],_=b.type,w=h.traces[_].attributes;w.type={valType:"enumerated",values:[_]},!1===b.visible&&!1!==y.visible&&f.push(p("invisible",x)),u(y,b,w,f,x);var k=y.transforms,T=b.transforms;if(k){l(k)||f.push(p("array",x,["transforms"])),x.push("transforms");for(var M=0;M<k.length;M++){var A=["transforms",M],S=k[M].type;if(s(k[M])){var E=h.transforms[S]?h.transforms[S].attributes:{};E.type={valType:"enumerated",values:Object.keys(h.transforms)},u(k[M],T[M],E,f,x,A)}else f.push(p("object",x,A))}}}else f.push(p("object",x))}return u(c,d._fullLayout,function(t,e){for(var r=t.layout.layoutAttributes,a=0;a<e.length;a++){var i=e[a],o=t.traces[i.type],s=o.layoutAttributes;s&&(i.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}(h,g),f,"layout"),0===f.length?void 0:f};var h={object:function(t,e){return("layout"===t&&""===e?"The layout argument":"data"===t[0]&&""===e?"Trace "+t[1]+" in the data argument":f(t)+"key "+e)+" must be linked to an object container"},array:function(t,e){return("data"===t?"The data argument":f(t)+"key "+e)+" must be linked to an array container"},schema:function(t,e){return f(t)+"key "+e+" is not part of the schema"},unused:function(t,e,r){var n=s(r)?"container":"key";return f(t)+n+" "+e+" did not get coerced"},dynamic:function(t,e,r,n){return[f(t)+"key",e,"(set to '"+r+"')","got reset to","'"+n+"'","during defaults."].join(" ")},invisible:function(t,e){return(e?f(t)+"item "+e:"Trace "+t[1])+" got defaulted to be not visible"},value:function(t,e,r){return[f(t)+"key "+e,"is set to an invalid value ("+r+")"].join(" ")}};function f(t){return l(t)?"In data trace "+t[1]+", ":"In "+t+", "}function p(t,e,r,a,i){var o,s;r=r||"",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e="",r=0;r<t.length;r++){var n=t[r];"number"==typeof n?e=e.substr(0,e.length-1)+"["+n+"]":e+=n,r<t.length-1&&(e+=".")}return e}(r),u=h[t](e,c,a,i);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function d(t,e){var r=m(e),n=r.keyMinusId,a=r.id;return!!(n in t&&t[n]._isSubplotObj&&a)||e in t}function g(t,e){return e in t?t[e]:t[m(e).keyMinusId]}var v=n.counterRegex("([a-z]+)");function m(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{"../lib":717,"../plots/plots":826,"./plot_config":753,"./plot_schema":754}],760:[function(t,e,r){"use strict";e.exports={mode:{valType:"enumerated",dflt:"afterall",values:["immediate","next","afterall"]},direction:{valType:"enumerated",values:["forward","reverse"],dflt:"forward"},fromcurrent:{valType:"boolean",dflt:!1},frame:{duration:{valType:"number",min:0,dflt:500},redraw:{valType:"boolean",dflt:!0}},transition:{duration:{valType:"number",min:0,dflt:500,editType:"none"},easing:{valType:"enumerated",dflt:"cubic-in-out",values:["linear","quad","cubic","sin","exp","circle","elastic","back","bounce","linear-in","quad-in","cubic-in","sin-in","exp-in","circle-in","elastic-in","back-in","bounce-in","linear-out","quad-out","cubic-out","sin-out","exp-out","circle-out","elastic-out","back-out","bounce-out","linear-in-out","quad-in-out","cubic-in-out","sin-in-out","exp-in-out","circle-in-out","elastic-in-out","back-in-out","bounce-in-out"],editType:"none"},ordering:{valType:"enumerated",values:["layout first","traces first"],dflt:"layout first",editType:"none"}}}},{}],761:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../plot_api/plot_template");e.exports=function(t,e,r){var i,o,s=r.name,l=r.inclusionAttr||"visible",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],h=e[s]=[],f=a.arrayTemplater(e,s,l);for(i=0;i<u.length;i++){var p=u[i];n.isPlainObject(p)?o=f.newItem(p):(o=f.newItem({}))[l]=!1,o._index=i,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),h.push(o)}var d=f.defaultItems();for(i=0;i<d.length;i++)(o=d[i])._index=h.length,r.handleItemDefaults({},o,e,r,{}),h.push(o);if(n.isArrayOrTypedArray(c)){var g=Math.min(c.length,h.length);for(i=0;i<g;i++)n.relinkPrivateKeys(h[i],c[i])}return h}},{"../lib":717,"../plot_api/plot_template":755}],762:[function(t,e,r){"use strict";var n=t("../components/fx/attributes");e.exports={type:{valType:"enumerated",values:[],dflt:"scatter",editType:"calc+clearAxisTypes",_noTemplating:!0},visible:{valType:"enumerated",values:[!0,!1,"legendonly"],dflt:!0,editType:"calc"},showlegend:{valType:"boolean",dflt:!0,editType:"style"},legendgroup:{valType:"string",dflt:"",editType:"style"},opacity:{valType:"number",min:0,max:1,dflt:1,editType:"style"},name:{valType:"string",editType:"style"},uid:{valType:"string",editType:"plot",anim:!0},ids:{valType:"data_array",editType:"calc",anim:!0},customdata:{valType:"data_array",editType:"calc"},meta:{valType:"any",arrayOk:!0,editType:"plot"},selectedpoints:{valType:"any",editType:"calc"},hoverinfo:{valType:"flaglist",flags:["x","y","z","text","name"],extras:["all","none","skip"],arrayOk:!0,dflt:"all",editType:"none"},hoverlabel:n.hoverlabel,stream:{token:{valType:"string",noBlank:!0,strict:!0,editType:"calc"},maxpoints:{valType:"number",min:0,max:1e4,dflt:500,editType:"calc"},editType:"calc"},transforms:{_isLinkedToArray:"transform",editType:"calc"},uirevision:{valType:"any",editType:"none"}}},{"../components/fx/attributes":621}],763:[function(t,e,r){"use strict";e.exports={xaxis:{valType:"subplotid",dflt:"x",editType:"calc+clearAxisTypes"},yaxis:{valType:"subplotid",dflt:"y",editType:"calc+clearAxisTypes"}}},{}],764:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../constants/numerical").FP_SAFE,o=t("../../registry");function s(t,e){var r,n,i=[],o=l(e),s=c(t,e),u=s.min,h=s.max;if(0===u.length||0===h.length)return a.simpleMap(e.range,e.r2l);var f=u[0].val,p=h[0].val;for(r=1;r<u.length&&f===p;r++)f=Math.min(f,u[r].val);for(r=1;r<h.length&&f===p;r++)p=Math.max(p,h[r].val);var d=!1;if(e.range){var g=a.simpleMap(e.range,e.r2l);d=g[1]<g[0]}"reversed"===e.autorange&&(d=!0,e.autorange=!0);var v,m,y,x,b,_,w=e.rangemode,k="tozero"===w,T="nonnegative"===w,M=e._length,A=M/10,S=function(t,r){var n=0;if(e.rangebreaks)for(var a=e.locateBreaks(t,r),i=0;i<a.length;i++){var o=a[i];n+=o.max-o.min}return n},E=0;for(r=0;r<u.length;r++)for(v=u[r],n=0;n<h.length;n++)(_=(m=h[n]).val-v.val-S(v.val,m.val))>0&&((b=M-o(v)-o(m))>A?_/b>E&&(y=v,x=m,E=_/b):_/M>E&&(y={val:v.val,pad:0},x={val:m.val,pad:0},E=_/M));if(f===p){var L=f-1,C=f+1;if(k)if(0===f)i=[0,1];else{var P=(f>0?h:u).reduce(function(t,e){return Math.max(t,o(e))},0),O=f/(1-Math.min(.5,P/M));i=f>0?[0,O]:[O,0]}else i=T?[Math.max(0,L),Math.max(1,C)]:[L,C]}else k?(y.val>=0&&(y={val:0,pad:0}),x.val<=0&&(x={val:0,pad:0})):T&&(y.val-E*o(y)<0&&(y={val:0,pad:0}),x.val<=0&&(x={val:1,pad:0})),E=(x.val-y.val-S(v.val,m.val))/(M-o(y)-o(x)),i=[y.val-E*o(y),x.val+E*o(x)];return d&&i.reverse(),a.simpleMap(i,e.l2r||Number)}function l(t){var e=t._length/20;return"domain"===t.constrain&&t._inputDomain&&(e*=(t._inputDomain[1]-t._inputDomain[0])/(t.domain[1]-t.domain[0])),function(t){return t.pad+(t.extrapad?e:0)}}function c(t,e){var r,n,a,i=e._id,o=t._fullData,s=t._fullLayout,l=[],c=[];function f(t,e){for(r=0;r<e.length;r++){var o=t[e[r]],s=(o._extremes||{})[i];if(!0===o.visible&&s){for(n=0;n<s.min.length;n++)a=s.min[n],u(l,a.val,a.pad,{extrapad:a.extrapad});for(n=0;n<s.max.length;n++)a=s.max[n],h(c,a.val,a.pad,{extrapad:a.extrapad})}}}return f(o,e._traceIndices),f(s.annotations||[],e._annIndices||[]),f(s.shapes||[],e._shapeIndices||[]),{min:l,max:c}}function u(t,e,r,n){f(t,e,r,n,d)}function h(t,e,r,n){f(t,e,r,n,g)}function f(t,e,r,n,a){for(var i=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(a(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}a(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=i&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function p(t){return n(t)&&Math.abs(t)<i}function d(t,e){return t<=e}function g(t,e){return t>=e}e.exports={getAutoRange:s,makePadFn:l,doAutoRange:function(t,e){if(e.setScale(),e.autorange){e.range=s(t,e),e._r=e.range.slice(),e._rl=a.simpleMap(e._r,e.r2l);var r=e._input,n={};n[e._attr+".range"]=e.range,n[e._attr+".autorange"]=e.autorange,o.call("_storeDirectGUIEdit",t.layout,t._fullLayout._preGUI,n),r.range=e.range.slice(),r.autorange=e.autorange}var i=e._anchorAxis;if(i&&i.rangeslider){var l=i.rangeslider[e._name];l&&"auto"===l.rangemode&&(l.range=s(t,e)),i._input.rangeslider[e._name]=a.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var a,o,s,l,c,f,d,g,v,m=[],y=[],x=e.length,b=r.padded||!1,_=r.tozero&&("linear"===t.type||"-"===t.type),w="log"===t.type,k=!1,T=r.vpadLinearized||!1;function M(t){if(Array.isArray(t))return k=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var A=M((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),S=M((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),E=M(r.vpadplus||r.vpad),L=M(r.vpadminus||r.vpad);if(!k){if(g=1/0,v=-1/0,w)for(a=0;a<x;a++)(o=e[a])<g&&o>0&&(g=o),o>v&&o<i&&(v=o);else for(a=0;a<x;a++)(o=e[a])<g&&o>-i&&(g=o),o>v&&o<i&&(v=o);e=[g,v],x=2}var C={tozero:_,extrapad:b};function P(r){s=e[r],n(s)&&(f=A(r),d=S(r),T?(l=t.c2l(s)-L(r),c=t.c2l(s)+E(r)):(g=s-L(r),v=s+E(r),w&&g<v/10&&(g=v/10),l=t.c2l(g),c=t.c2l(v)),_&&(l=Math.min(0,l),c=Math.max(0,c)),p(l)&&u(m,l,d,C),p(c)&&h(y,c,f,C))}var O=Math.min(6,x);for(a=0;a<O;a++)P(a);for(a=x-1;a>=O;a--)P(a);return{min:m,max:y,opts:r}},concatExtremes:c}},{"../../constants/numerical":693,"../../lib":717,"../../registry":846,"fast-isnumeric":228}],765:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../../plots/plots"),o=t("../../registry"),s=t("../../lib"),l=t("../../lib/svg_text_utils"),c=t("../../components/titles"),u=t("../../components/color"),h=t("../../components/drawing"),f=t("./layout_attributes"),p=t("./clean_ticks"),d=t("../../constants/numerical"),g=d.ONEAVGYEAR,v=d.ONEAVGMONTH,m=d.ONEDAY,y=d.ONEHOUR,x=d.ONEMIN,b=d.ONESEC,_=d.MINUS_SIGN,w=d.BADNUM,k=t("../../constants/alignment"),T=k.MID_SHIFT,M=k.CAP_SHIFT,A=k.LINE_SPACING,S=k.OPPOSITE_SIDE,E=e.exports={};E.setConvert=t("./set_convert");var L=t("./axis_autotype"),C=t("./axis_ids");E.id2name=C.id2name,E.name2id=C.name2id,E.cleanId=C.cleanId,E.list=C.list,E.listIds=C.listIds,E.getFromId=C.getFromId,E.getFromTrace=C.getFromTrace;var P=t("./autorange");E.getAutoRange=P.getAutoRange,E.findExtremes=P.findExtremes,E.coerceRef=function(t,e,r,n,a,i){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+"axis"],c=n+"ref",u={};return a||(a=l[0]||i),i||(i=a),u[c]={valType:"enumerated",values:l.concat(i?[i]:[]),dflt:a},s.coerce(t,e,u,c)},E.coercePosition=function(t,e,r,n,a,i){var o,l;if("paper"===n||"pixel"===n)o=s.ensureNumber,l=r(a,i);else{var c=E.getFromId(e,n);l=r(a,i=c.fraction2r(i)),o=c.cleanPos}t[a]=o(l)},E.cleanPosition=function(t,e,r){return("paper"===r||"pixel"===r?s.ensureNumber:E.getFromId(e,r).cleanPos)(t)},E.redrawComponents=function(t,e){e=e||E.listIds(t);var r=t._fullLayout;function n(n,a,i,s){for(var l=o.getComponentMethod(n,a),c={},u=0;u<e.length;u++)for(var h=r[E.id2name(e[u])][i],f=0;f<h.length;f++){var p=h[f];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n("annotations","drawOne","_annIndices"),n("shapes","drawOne","_shapeIndices"),n("images","draw","_imgIndices",!0)};var O=E.getDataConversions=function(t,e,r,n){var a,i="x"===r||"y"===r||"z"===r?r:n;if(Array.isArray(i)){if(a={type:L(n),_categories:[]},E.setConvert(a),"category"===a.type)for(var o=0;o<n.length;o++)a.d2c(n[o])}else a=E.getFromTrace(t,e,i);return a?{d2c:a.d2c,c2d:a.c2d}:"ids"===i?{d2c:I,c2d:I}:{d2c:z,c2d:z}};function z(t){return+t}function I(t){return String(t)}E.getDataToCoordFunc=function(t,e,r,n){return O(t,e,r,n).d2c},E.counterLetter=function(t){var e=t.charAt(0);return"x"===e?"y":"y"===e?"x":void 0},E.minDtick=function(t,e,r,n){-1===["log","category","multicategory"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},E.saveRangeInitial=function(t,e){for(var r=E.list(t,"",!0),n=!1,a=0;a<r.length;a++){var i=r[a],o=void 0===i._rangeInitial,s=o||!(i.range[0]===i._rangeInitial[0]&&i.range[1]===i._rangeInitial[1]);(o&&!1===i.autorange||e&&s)&&(i._rangeInitial=i.range.slice(),n=!0)}return n},E.saveShowSpikeInitial=function(t,e){for(var r=E.list(t,"",!0),n=!1,a="on",i=0;i<r.length;i++){var o=r[i],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),"on"!==a||o.showspikes||(a="off")}return t._fullLayout._cartesianSpikesEnabled=a,n},E.autoBin=function(t,e,r,n,i,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if("category"===e.type||"multicategory"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(i||(i=e.calendar),l="log"===e.type?{type:"linear",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,i),calendar:i},E.setConvert(l),o=o&&p.dtick(o,l.type))l.dtick=o,l.tick0=p.tick0(void 0,l.type,i);else{var h;if(r)h=(u-c)/r;else{var f=s.distinctVals(t),d=Math.pow(10,Math.floor(Math.log(f.minDiff)/Math.LN10)),g=d*s.roundUp(f.minDiff/d,[.9,1.9,4.9,9.9],!0);h=Math.max(g,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),a(h)||(h=1)}E.autoTicks(l,h)}var v,y=l.dtick,x=E.tickIncrement(E.tickFirst(l),y,"reverse",i);if("number"==typeof y)v=(x=function(t,e,r,n,i){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var h=0;h<e.length;h++)e[h]%1==0?l++:a(e[h])||c++,u(e[h])&&o++,u(e[h]+r.dtick/2)&&s++;var f=e.length-c;if(l===f&&"date"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*f&&(o>.3*f||u(n)||u(i))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(x,t,l,c,u))+(1+Math.floor((u-x)/y))*y;else for("M"===l.dtick.charAt(0)&&(x=function(t,e,r,n,a){var i=s.findExactDates(e,a);if(i.exactDays>.8){var o=Number(r.substr(1));i.exactYears>.8&&o%12==0?t=E.tickIncrement(t,"M6","reverse")+1.5*m:i.exactMonths>.8?t=E.tickIncrement(t,"M1","reverse")+15.5*m:t-=m/2;var l=E.tickIncrement(t,r);if(l<=n)return l}return t}(x,t,y,c,i)),v=x,0;v<=u;)v=E.tickIncrement(v,y,!1,i),0;return{start:e.c2r(x,0,i),end:e.c2r(v,0,i),size:y,_dataSpan:u-c}},E.prepTicks=function(t){var e=s.simpleMap(t.range,t.r2l);if("auto"===t.tickmode||!t.dtick){var r,n=t.nticks;n||("category"===t.type||"multicategory"===t.type?(r=t.tickfont?1.2*(t.tickfont.size||12):15,n=t._length/r):(r="y"===t._id.charAt(0)?40:80,n=s.constrain(t._length/r,4,9)+1),"radialaxis"===t._name&&(n*=2)),"array"===t.tickmode&&(n*=100),t._roughDTick=(Math.abs(e[1]-e[0])-(t._lBreaks||0))/n,E.autoTicks(t,t._roughDTick),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}t.tick0||(t.tick0="date"===t.type?"2000-01-01":0),"date"===t.type&&t.dtick<.1&&(t.dtick=.1),q(t)},E.calcTicks=function(t){E.prepTicks(t);var e=s.simpleMap(t.range,t.r2l);if("array"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),a=s.simpleMap(t.range,t.r2l),i=1.0001*a[0]-1e-4*a[1],o=1.0001*a[1]-1e-4*a[0],l=Math.min(i,o),c=Math.max(i,o),u=0;Array.isArray(r)||(r=[]);var h="category"===t.type?t.d2l_noadd:t.d2l;"log"===t.type&&"L"!==String(t.dtick).charAt(0)&&(t.dtick="L"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var f=0;f<e.length;f++){var p=h(e[f]);p>l&&p<c&&(void 0===r[f]?n[u]=E.tickText(t,p):n[u]=H(t,p,String(r[f])),u++)}u<e.length&&n.splice(u,e.length-u);t.rangebreaks&&(n=n.filter(function(e){return t.maskBreaks(e.x)!==w}));return n}(t);t._tmin=E.tickFirst(t);var r=1.0001*e[0]-1e-4*e[1],n=1.0001*e[1]-1e-4*e[0],i=e[1]<e[0];if(t._tmin<r!==i)return[];"category"!==t.type&&"multicategory"!==t.type||(n=i?Math.max(-.5,n):Math.min(t._categories.length-.5,n));var o,l="log"===t.type&&!(a(t.dtick)||"L"===t.dtick.charAt(0));if(function(){var e=null,r=Math.max(1e3,t._length||0);o=[];for(var a=t._tmin;(i?a>=n:a<=n)&&!(o.length>r||a===e);a=E.tickIncrement(a,t.dtick,i,t.calendar)){e=a;var s=!1;l&&a!==(0|a)&&(s=!0),o.push({minor:s,value:a})}}(),t.rangebreaks){if("auto"===t.tickmode)for(var c=0;c<o.length;c++){var u=o[c].value;if(t.maskBreaks(u)===w)for(var h=0;h<t._rangebreaks.length;h++){var f=t._rangebreaks[h];if(u>=f.min&&u<f.max){o[c].value=f.max;break}}}var p=o.length;if(p>2){for(var d,g=2*(t.tickfont?t.tickfont.size:12),v=[],m=i?1:-1,y=i?p-1:0,x=i?0:p-1;m*x<=m*y;x+=m){var b=t.c2p(o[x].value);(void 0===d||Math.abs(b-d)>g)&&(d=b,v.push(o[x]))}o=v.reverse()}}ot(t)&&360===Math.abs(e[1]-e[0])&&o.pop(),t._tmax=(o[o.length-1]||{}).value,t._prevDateHead="",t._inCalcTicks=!0;for(var _=new Array(o.length),k=0;k<o.length;k++){var T=o[k].minor,M=o[k].value;_[k]=E.tickText(t,M,!1,T)}return t._inCalcTicks=!1,_};var D=[2,5,10],R=[1,2,3,6,12],F=[1,2,5,10,15,30],B=[1,2,3,7,14],N=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],j=[-.301,0,.301,.699,1],V=[15,30,45,90,180];function U(t,e,r){return e*s.roundUp(t/e,r)}function q(t){var e=t.dtick;if(t._tickexponent=0,a(e)||"string"==typeof e||(e=1),"category"!==t.type&&"multicategory"!==t.type||(t._tickround=null),"date"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,""),i=n.length;if("M"===String(e).charAt(0))i>10||"01-01"!==n.substr(5)?t._tickround="d":t._tickround=+e.substr(1)%12==0?"y":"m";else if(e>=m&&i<=10||e>=15*m)t._tickround="d";else if(e>=x&&i<=16||e>=y)t._tickround="M";else if(e>=b&&i<=19||e>=x)t._tickround="S";else{var o=t.l2r(r+e).replace(/^-/,"").length;t._tickround=Math.max(i,o)-20,t._tickround<0&&(t._tickround=4)}}else if(a(e)||"L"===e.charAt(0)){var s=t.range.map(t.r2d||Number);a(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01);Math.abs(c)>3&&(Y(t.exponentformat)&&!W(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function H(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||"",fontSize:n.size,font:n.family,fontColor:n.color}}E.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if("date"===t.type){t.tick0=s.dateTick0(t.calendar);var i=2*e;i>g?(e/=g,r=n(10),t.dtick="M"+12*U(e,r,D)):i>v?(e/=v,t.dtick="M"+U(e,1,R)):i>m?(t.dtick=U(e,m,t._hasDayOfWeekBreaks?[1,7,14]:B),t.tick0=s.dateTick0(t.calendar,!0)):i>y?t.dtick=U(e,y,R):i>x?t.dtick=U(e,x,F):i>b?t.dtick=U(e,b,F):(r=n(10),t.dtick=U(e,r,D))}else if("log"===t.type){t.tick0=0;var o=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(o[1]-o[0])<1){var l=1.5*Math.abs((o[1]-o[0])/e);e=Math.abs(Math.pow(10,o[1])-Math.pow(10,o[0]))/l,r=n(10),t.dtick="L"+U(e,r,D)}else t.dtick=e>.3?"D2":"D1"}else"category"===t.type||"multicategory"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):ot(t)?(t.tick0=0,r=1,t.dtick=U(e,r,V)):(t.tick0=0,r=n(10),t.dtick=U(e,r,D));if(0===t.dtick&&(t.dtick=1),!a(t.dtick)&&"string"!=typeof t.dtick){var c=t.dtick;throw t.dtick=1,"ax.dtick error: "+String(c)}},E.tickIncrement=function(t,e,r,i){var o=r?-1:1;if(a(e))return t+o*e;var l=e.charAt(0),c=o*Number(e.substr(1));if("M"===l)return s.incrementMonth(t,c,i);if("L"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if("D"===l){var u="D2"===e?j:N,h=t+.01*o,f=s.roundUp(s.mod(h,1),u,r);return Math.floor(h)+Math.log(n.round(Math.pow(10,f),1))/Math.LN10}throw"unrecognized dtick "+String(e)},E.tickFirst=function(t){var e=t.r2l||Number,r=s.simpleMap(t.range,e),i=r[1]<r[0],o=i?Math.floor:Math.ceil,l=1.0001*r[0]-1e-4*r[1],c=t.dtick,u=e(t.tick0);if(a(c)){var h=o((l-u)/c)*c+u;return"category"!==t.type&&"multicategory"!==t.type||(h=s.constrain(h,0,t._categories.length-1)),h}var f=c.charAt(0),p=Number(c.substr(1));if("M"===f){for(var d,g,v,m=0,y=u;m<10;){if(((d=E.tickIncrement(y,c,i,t.calendar))-l)*(y-l)<=0)return i?Math.min(y,d):Math.max(y,d);g=(l-(y+d)/2)/(d-y),v=f+(Math.abs(Math.round(g))||1)*p,y=E.tickIncrement(y,v,g<0?!i:i,t.calendar),m++}return s.error("tickFirst did not converge",t),y}if("L"===f)return Math.log(o((Math.pow(10,l)-u)/p)*p+u)/Math.LN10;if("D"===f){var x="D2"===c?j:N,b=s.roundUp(s.mod(l,1),x,i);return Math.floor(l)+Math.log(n.round(Math.pow(10,b),1))/Math.LN10}throw"unrecognized dtick "+String(c)},E.tickText=function(t,e,r,n){var i,o=H(t,e),l="array"===t.tickmode,c=r||l,u=t.type,h="category"===u?t.d2l_noadd:t.d2l;if(l&&Array.isArray(t.ticktext)){var f=s.simpleMap(t.range,t.r2l),p=(Math.abs(f[1]-f[0])-(t._lBreaks||0))/1e4;for(i=0;i<t.ticktext.length&&!(Math.abs(e-h(t.tickvals[i]))<p);i++);if(i<t.ticktext.length)return o.text=String(t.ticktext[i]),o}function d(n){if(void 0===n)return!0;if(r)return"none"===n;var a={first:t._tmin,last:t._tmax}[n];return"all"!==n&&e!==a}var g=r?"never":"none"!==t.exponentformat&&d(t.showexponent)?"hide":"";if("date"===u?function(t,e,r,n){var i=t._tickround,o=r&&t.hoverformat||E.getTickFormat(t);n&&(i=a(i)?4:{y:"m",m:"d",d:"M",M:"S",S:4}[i]);var l,c=s.formatDate(e.x,o,i,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf("\n");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&("00:00:00"===c||"00:00"===c?(c=l,l=""):8===c.length&&(c=c.replace(/:00$/,"")));l&&(r?"d"===i?c+=", "+l:c=l+(c?", "+c:""):t._inCalcTicks&&l===t._prevDateHead||(c+="<br>"+l,t._prevDateHead=l));e.text=c}(t,o,r,c):"log"===u?function(t,e,r,n,i){var o=t.dtick,l=e.x,c=t.tickformat,u="string"==typeof o&&o.charAt(0);"never"===i&&(i="");n&&"L"!==u&&(o="L3",u="L");if(c||"L"===u)e.text=X(Math.pow(10,l),t,i,n);else if(a(o)||"D"===u&&s.mod(l+.01,1)<.1){var h=Math.round(l),f=Math.abs(h),p=t.exponentformat;"power"===p||Y(p)&&W(h)?(e.text=0===h?1:1===h?"10":"10<sup>"+(h>1?"":_)+f+"</sup>",e.fontSize*=1.25):("e"===p||"E"===p)&&f>2?e.text="1"+p+(h>0?"+":_)+f:(e.text=X(Math.pow(10,l),t,"","fakehover"),"D1"===o&&"y"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if("D"!==u)throw"unrecognized dtick "+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if("D1"===t.dtick){var d=String(e.text).charAt(0);"0"!==d&&"1"!==d||("y"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,g):"category"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r="");e.text=String(r)}(t,o):"multicategory"===u?function(t,e,r){var n=Math.round(e.x),a=t._categories[n]||[],i=void 0===a[1]?"":String(a[1]),o=void 0===a[0]?"":String(a[0]);r?e.text=o+" - "+i:(e.text=i,e.text2=o)}(t,o,r):ot(t)?function(t,e,r,n,a){if("radians"!==t.thetaunit||r)e.text=X(e.x,t,a,n);else{var i=e.x/180;if(0===i)e.text="0";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){var r=1;for(;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,a=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/a),Math.round(r/a)]}(i);if(o[1]>=100)e.text=X(s.deg2rad(e.x),t,a,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text="\u03c0":e.text=o[0]+"\u03c0":e.text=["<sup>",o[0],"</sup>","\u2044","<sub>",o[1],"</sub>","\u03c0"].join(""),l&&(e.text=_+e.text)}}}}(t,o,r,c,g):function(t,e,r,n,a){"never"===a?a="":"all"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(a="hide");e.text=X(e.x,t,a,n)}(t,o,0,c,g),n||(t.tickprefix&&!d(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!d(t.showticksuffix)&&(o.text+=t.ticksuffix)),"boundaries"===t.tickson||t.showdividers){var v=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};o.xbnd=[v(o.x-.5),v(o.x+t.dtick-.5)]}return o},E.hoverLabelText=function(t,e,r){if(r!==w&&r!==e)return E.hoverLabelText(t,e)+" - "+E.hoverLabelText(t,r);var n="log"===t.type&&e<=0,a=E.tickText(t,t.c2l(n?-e:e),"hover").text;return n?0===e?"0":_+a:a};var G=["f","p","n","\u03bc","m","","k","M","G","T"];function Y(t){return"SI"===t||"B"===t}function W(t){return t>14||t<-15}function X(t,e,r,n){var i=t<0,o=e._tickround,l=r||e.exponentformat||"B",c=e._tickexponent,u=E.getTickFormat(e),h=e.separatethousands;if(n){var f={exponentformat:l,dtick:"none"===e.showexponent?e.dtick:a(t)&&Math.abs(t)||1,range:"none"===e.showexponent?e.range.map(e.r2d):[0,t||1]};q(f),o=(Number(f._tickround)||0)+4,c=f._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,_);var p,d=Math.pow(10,-o)/2;if("none"===l&&(c=0),(t=Math.abs(t))<d)t="0",i=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var g=o;g<0;g++)t+="0"}else{var v=(t=String(t)).indexOf(".")+1;v&&(t=t.substr(0,v+o).replace(/\.?0+$/,""))}t=s.numSeparate(t,e._separators,h)}c&&"hide"!==l&&(Y(l)&&W(c)&&(l="power"),p=c<0?_+-c:"power"!==l?"+"+c:String(c),"e"===l||"E"===l?t+=l+p:"power"===l?t+="\xd710<sup>"+p+"</sup>":"B"===l&&9===c?t+="B":Y(l)&&(t+=G[c/3+5]));return i?_+t:t}function Z(t,e){for(var r=[],n={},a=0;a<e.length;a++){var i=e[a];n[i.text2]?n[i.text2].push(i.x):n[i.text2]=[i.x]}for(var o in n)r.push(H(t,s.interp(n[o],.5),o));return r}function J(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join("_")}function K(t){var e=t.title.font.size,r=(t.title.text.match(l.BR_TAG_ALL)||[]).length;return t.title.hasOwnProperty("standoff")?r?e*(M+r*A):e*M:r?e*(r+1)*A:e}function Q(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function $(t){var e=n.select(t),r=e.select(".text-math-group");return r.empty()?e.select("text"):r}function tt(t){return t._id+".automargin"}function et(t){return tt(t)+".mirror"}function rt(t){return t._id+".rangeslider"}function nt(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function at(t,e,r){var n,a,i=[],o=[],l=t.layout;for(n=0;n<e.length;n++)i.push(E.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(E.getFromId(t,r[n]));var c=Object.keys(f),u=["anchor","domain","overlaying","position","side","tickangle","editType"],h=["linear","log"];for(n=0;n<c.length;n++){var p=c[n],d=i[0][p],g=o[0][p],v=!0,m=!1,y=!1;if("_"!==p.charAt(0)&&"function"!=typeof d&&-1===u.indexOf(p)){for(a=1;a<i.length&&v;a++){var x=i[a][p];"type"===p&&-1!==h.indexOf(d)&&-1!==h.indexOf(x)&&d!==x?m=!0:x!==d&&(v=!1)}for(a=1;a<o.length&&v;a++){var b=o[a][p];"type"===p&&-1!==h.indexOf(g)&&-1!==h.indexOf(b)&&g!==b?y=!0:o[a][p]!==g&&(v=!1)}v&&(m&&(l[i[0]._name].type="linear"),y&&(l[o[0]._name].type="linear"),it(l,p,i,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],["?"])}}function it(t,e,r,n,a){var i,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for("title"===e&&(l&&l.text===a.x&&(l.text=a.y),c&&c.text===a.y&&(c.text=a.x)),i=0;i<r.length;i++)o(t,r[i]._name+"."+e).set(c);for(i=0;i<n.length;i++)o(t,n[i]._name+"."+e).set(l)}function ot(t){return"angularaxis"===t._id}E.getTickFormat=function(t){var e,r,n,a,i,o,s,l;function c(t){return"string"!=typeof t?t:Number(t.replace("M",""))*v}function u(t,e){var r=["L","D"];if(typeof t==typeof e){if("number"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),a=r.indexOf(e.charAt(0));return n===a?Number(t.replace(/(L|D)/g,""))-Number(e.replace(/(L|D)/g,"")):n-a}return"number"==typeof t?1:-1}function h(t,e){var r=null===e[0],n=null===e[1],a=u(t,e[0])>=0,i=u(t,e[1])<=0;return(r||a)&&(n||i)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case"date":case"linear":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(a=t.dtick,i=n.dtickrange,o=void 0,s=void 0,l=void 0,o=c||function(t){return t},s=i[0],l=i[1],(!s&&"number"!=typeof s||o(s)<=o(a))&&(!l&&"number"!=typeof l||o(l)>=o(a)))){r=n;break}break;case"log":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&h(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},E.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),a=e?E.findSubplotsWithAxis(n,e):n;return a.sort(function(t,e){var r=t.substr(1).split("y"),n=e.substr(1).split("y");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]}),a},E.findSubplotsWithAxis=function(t,e){for(var r=new RegExp("x"===e._id.charAt(0)?"^"+e._id+"y":e._id+"$"),n=[],a=0;a<t.length;a++){var i=t[a];r.test(i)&&n.push(i)}return n},E.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,a,i={_offset:0,_length:e.width,_id:""},o={_offset:0,_length:e.height,_id:""},s=E.list(t,"x",!0),l=E.list(t,"y",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),a=0;a<l.length;a++)0===r&&c.push({x:i,y:l[a]}),c.push({x:s[r],y:l[a]});var u=e._clips.selectAll(".axesclip").data(c,function(t){return t.x._id+t.y._id});u.enter().append("clipPath").classed("axesclip",!0).attr("id",function(t){return"clip"+e._uid+t.x._id+t.y._id}).append("rect"),u.exit().remove(),u.each(function(t){n.select(this).select("rect").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})})}},E.draw=function(t,e,r){var n=t._fullLayout;"redraw"===e&&n._paper.selectAll("g.subplot").each(function(t){var e=t[0],r=n._plots[e],a=r.xaxis,i=r.yaxis;r.xaxislayer.selectAll("."+a._id+"tick").remove(),r.yaxislayer.selectAll("."+i._id+"tick").remove(),r.xaxislayer.selectAll("."+a._id+"tick2").remove(),r.yaxislayer.selectAll("."+i._id+"tick2").remove(),r.xaxislayer.selectAll("."+a._id+"divider").remove(),r.yaxislayer.selectAll("."+i._id+"divider").remove(),r.gridlayer&&r.gridlayer.selectAll("path").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll("path").remove(),n._infolayer.select(".g-"+a._id+"title").remove(),n._infolayer.select(".g-"+i._id+"title").remove()});var a=e&&"redraw"!==e?e:E.listIds(t);return s.syncOrAsync(a.map(function(e){return function(){if(e){var n=E.getFromId(t,e),a=E.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),a}}}))},E.drawOne=function(t,e,r){var n,a,l;r=r||{},e.setScale();var f=t._fullLayout,p=e._id,d=p.charAt(0),g=E.counterLetter(p),v=f._plots[e._mainSubplot];if(v){var m=v[d+"axislayer"],y=e._mainLinePosition,x=e._mainMirrorPosition,b=e._vals=E.calcTicks(e),_=[e.mirror,y,x].join("_");for(n=0;n<b.length;n++)b[n].axInfo=_;e._selections={},e._tickAngles&&(e._prevTickAngles=e._tickAngles),e._tickAngles={},e._depth=null;var w={};if(e.visible){var k,T,M=E.makeTransFn(e);if("boundaries"===e.tickson){var L=function(t,e){var r,n=[],a=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)a(e[r],0);a(e[r-1],1)}return n}(0,b);T=E.clipEnds(e,L),k="inside"===e.ticks?T:L}else T=E.clipEnds(e,b),k="inside"===e.ticks?T:b;var C=e._gridVals=T,P=function(t,e){var r,n,a=[],i=function(t,e){var r=t.xbnd[e];null!==r&&a.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var o=e[r];o.text2!==n&&i(o,0),n=o.text2}i(e[r-1],1)}return a}(e,b);if(!f._hasOnlyLargeSploms){var O=e._subplotsWith,z={};for(n=0;n<O.length;n++){a=O[n];var I=(l=f._plots[a])[g+"axis"],D=I._mainAxis._id;if(!z[D]){z[D]=1;var R="x"===d?"M0,"+I._offset+"v"+I._length:"M"+I._offset+",0h"+I._length;E.drawGrid(t,e,{vals:C,counterAxis:I,layer:l.gridlayer.select("."+p),path:R,transFn:M}),E.drawZeroLine(t,e,{counterAxis:I,layer:l.zerolinelayer,path:R,transFn:M})}}}var F=E.getTickSigns(e),B=[];if(e.ticks){var N,j,V,U=E.makeTickPath(e,y,F[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(N=E.makeTickPath(e,x,F[3]),j=U+N):(N="",j=U),e.showdividers&&"outside"===e.ticks&&"boundaries"===e.tickson){var q={};for(n=0;n<P.length;n++)q[P[n].x]=1;V=function(t){return q[t.x]?N:j}}else V=j;E.drawTicks(t,e,{vals:k,layer:m,path:V,transFn:M}),"allticks"===e.mirror&&(B=Object.keys(e._linepositions||{}))}for(n=0;n<B.length;n++){a=B[n],l=f._plots[a];var H=e._linepositions[a]||[],G=E.makeTickPath(e,H[0],F[0])+E.makeTickPath(e,H[1],F[1]);E.drawTicks(t,e,{vals:k,layer:l[d+"axislayer"],path:G,transFn:M})}var Y=[];if(Y.push(function(){return E.drawLabels(t,e,{vals:b,layer:m,transFn:M,labelFns:E.makeLabelFns(e,y)})}),"multicategory"===e.type){var W={x:2,y:10}[d];Y.push(function(){var r={x:"height",y:"width"}[d],n=Q()[r]+W+(e._tickAngles[p+"tick"]?e.tickfont.size*A:0);return E.drawLabels(t,e,{vals:Z(e,b),layer:m,cls:p+"tick2",repositionOnUpdate:!0,secondary:!0,transFn:M,labelFns:E.makeLabelFns(e,y+n*F[4])})}),Y.push(function(){return e._depth=F[4]*(Q("tick2")[e.side]-y),function(t,e,r){var n=e._id+"divider",a=r.vals,i=r.layer.selectAll("path."+n).data(a,J);i.exit().remove(),i.enter().insert("path",":first-child").classed(n,1).classed("crisp",1).call(u.stroke,e.dividercolor).style("stroke-width",h.crispRound(t,e.dividerwidth,1)+"px"),i.attr("transform",r.transFn).attr("d",r.path)}(t,e,{vals:P,layer:m,path:E.makeTickPath(e,y,F[4],e._depth),transFn:M})})}else e.title.hasOwnProperty("standoff")&&Y.push(function(){e._depth=F[4]*(Q()[e.side]-y)});var X=o.getComponentMethod("rangeslider","isVisible")(e);return Y.push(function(){var r,n,a,s,l=e.side.charAt(0),c=S[e.side].charAt(0),u=E.getPxPosition(t,e),h="outside"===e.ticks?e.ticklen:0;if((e.automargin||X)&&("multicategory"===e.type?r=Q("tick2"):(r=Q(),"x"===d&&"b"===l&&(e._depth=Math.max(r.width>0?r.bottom-u:0,h)))),e.automargin){n={x:0,y:0,r:0,l:0,t:0,b:0};var p=[0,1];if("x"===d){if("b"===l?n[l]=e._depth:(n[l]=e._depth=Math.max(r.width>0?u-r.top:0,h),p.reverse()),r.width>0){var v=r.right-(e._offset+e._length);v>0&&(n.xr=1,n.r=v);var m=e._offset-r.left;m>0&&(n.xl=0,n.l=m)}}else if("l"===l?n[l]=e._depth=Math.max(r.height>0?u-r.left:0,h):(n[l]=e._depth=Math.max(r.height>0?r.right-u:0,h),p.reverse()),r.height>0){var y=r.bottom-(e._offset+e._length);y>0&&(n.yb=0,n.b=y);var x=e._offset-r.top;x>0&&(n.yt=1,n.t=x)}n[g]="free"===e.anchor?e.position:e._anchorAxis.domain[p[0]],e.title.text!==f._dfltTitle[d]&&(n[l]+=K(e)+(e.title.standoff||0)),e.mirror&&"free"!==e.anchor&&((a={x:0,y:0,r:0,l:0,t:0,b:0})[c]=e.linewidth,e.mirror&&!0!==e.mirror&&(a[c]+=h),!0===e.mirror||"ticks"===e.mirror?a[g]=e._anchorAxis.domain[p[1]]:"all"!==e.mirror&&"allticks"!==e.mirror||(a[g]=[e._counterDomainMin,e._counterDomainMax][p[1]]))}X&&(s=o.getComponentMethod("rangeslider","autoMarginOpts")(t,e)),i.autoMargin(t,tt(e),n),i.autoMargin(t,et(e),a),i.autoMargin(t,rt(e),s)}),r.skipTitle||X&&"bottom"===e.side||Y.push(function(){return function(t,e){var r,n=t._fullLayout,a=e._id,i=a.charAt(0),o=e.title.font.size;if(e.title.hasOwnProperty("standoff"))r=e._depth+e.title.standoff+K(e);else{if("multicategory"===e.type)r=e._depth;else{r=10+1.5*o+(e.linewidth?e.linewidth-1:0)}r+="x"===i?"top"===e.side?o*(e.showticklabels?1:0):o*(e.showticklabels?1.5:.5):"right"===e.side?o*(e.showticklabels?1:.5):o*(e.showticklabels?.5:0)}var s,l,u,f,p=E.getPxPosition(t,e);"x"===i?(l=e._offset+e._length/2,u="top"===e.side?p-r:p+r):(u=e._offset+e._length/2,l="right"===e.side?p+r:p-r,s={rotate:"-90",offset:0});if("multicategory"!==e.type){var d=e._selections[e._id+"tick"];if(f={selection:d,side:e.side},d&&d.node()&&d.node().parentNode){var g=h.getTranslate(d.node().parentNode);f.offsetLeft=g.x,f.offsetTop=g.y}e.title.hasOwnProperty("standoff")&&(f.pad=0)}return c.draw(t,a+"title",{propContainer:e,propName:e._name+".title.text",placeholder:n._dfltTitle[i],avoid:f,transform:s,attributes:{x:l,y:u,"text-anchor":"middle"}})}(t,e)}),s.syncOrAsync(Y)}}function Q(t){var r=p+(t||"tick");return w[r]||(w[r]=function(t,e){var r,n,a,i;t._selections[e].size()?(r=1/0,n=-1/0,a=1/0,i=-1/0,t._selections[e].each(function(){var t=$(this),e=h.bBox(t.node().parentNode);r=Math.min(r,e.top),n=Math.max(n,e.bottom),a=Math.min(a,e.left),i=Math.max(i,e.right)})):(r=0,n=0,a=0,i=0);return{top:r,bottom:n,left:a,right:i,height:n-r,width:i-a}}(e,r)),w[r]}},E.getTickSigns=function(t){var e=t._id.charAt(0),r={x:"top",y:"right"}[e],n=t.side===r?1:-1,a=[-1,1,n,-n];return"inside"!==t.ticks==("x"===e)&&(a=a.map(function(t){return-t})),t.side&&a.push({l:-1,t:-1,r:1,b:1}[t.side.charAt(0)]),a},E.makeTransFn=function(t){var e=t._id.charAt(0),r=t._offset;return"x"===e?function(e){return"translate("+(r+t.l2p(e.x))+",0)"}:function(e){return"translate(0,"+(r+t.l2p(e.x))+")"}},E.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var a=t._id.charAt(0),i=(t.linewidth||1)/2;return"x"===a?"M0,"+(e+i*r)+"v"+n*r:"M"+(e+i*r)+",0h"+n*r},E.makeLabelFns=function(t,e,r){var n=t._id.charAt(0),i="boundaries"!==t.tickson&&"outside"===t.ticks,o=0,l=0;if(i&&(o+=t.ticklen),r&&"outside"===t.ticks){var c=s.deg2rad(r);o=t.ticklen*Math.cos(c)+1,l=t.ticklen*Math.sin(c)}t.showticklabels&&(i||t.showline)&&(o+=.2*t.tickfont.size);var u,h,f,p,d={labelStandoff:o+=(t.linewidth||1)/2,labelShift:l};return"x"===n?(p="bottom"===t.side?1:-1,u=l*p,h=e+o*p,f="bottom"===t.side?1:-.2,d.xFn=function(t){return t.dx+u},d.yFn=function(t){return t.dy+h+t.fontSize*f},d.anchorFn=function(t,e){return a(e)&&0!==e&&180!==e?e*p<0?"end":"start":"middle"},d.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:"top"===t.side?-n:0}):"y"===n&&(p="right"===t.side?1:-1,u=o,h=-l*p,f=90===Math.abs(t.tickangle)?.5:0,d.xFn=function(t){return t.dx+e+(u+t.fontSize*f)*p},d.yFn=function(t){return t.dy+h+t.fontSize*T},d.anchorFn=function(e,r){return a(r)&&90===Math.abs(r)?"middle":"right"===t.side?"start":"end"},d.heightFn=function(e,r,n){return(r*="left"===t.side?1:-1)<-30?-n:r<30?-.5*n:0}),d},E.drawTicks=function(t,e,r){r=r||{};var n=e._id+"tick",a=r.layer.selectAll("path."+n).data(e.ticks?r.vals:[],J);a.exit().remove(),a.enter().append("path").classed(n,1).classed("ticks",1).classed("crisp",!1!==r.crisp).call(u.stroke,e.tickcolor).style("stroke-width",h.crispRound(t,e.tickwidth,1)+"px").attr("d",r.path),a.attr("transform",r.transFn)},E.drawGrid=function(t,e,r){r=r||{};var n=e._id+"grid",a=r.vals,i=r.counterAxis;if(!1===e.showgrid)a=[];else if(i&&E.shouldShowZeroLine(t,e,i))for(var o="array"===e.tickmode,s=0;s<a.length;s++){var l=a[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(a=a.slice(0,s).concat(a.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll("path."+n).data(a,J);c.exit().remove(),c.enter().append("path").classed(n,1).classed("crisp",!1!==r.crisp),e._gw=h.crispRound(t,e.gridwidth,1),c.attr("transform",r.transFn).attr("d",r.path).call(u.stroke,e.gridcolor||"#ddd").style("stroke-width",e._gw+"px"),"function"==typeof r.path&&c.attr("d",r.path)},E.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+"zl",a=E.shouldShowZeroLine(t,e,r.counterAxis),i=r.layer.selectAll("path."+n).data(a?[{x:0,id:e._id}]:[]);i.exit().remove(),i.enter().append("path").classed(n,1).classed("zl",1).classed("crisp",!1!==r.crisp).each(function(){r.layer.selectAll("path").sort(function(t,e){return C.idSort(t.id,e.id)})}),i.attr("transform",r.transFn).attr("d",r.path).call(u.stroke,e.zerolinecolor||u.defaultLine).style("stroke-width",h.crispRound(t,e.zerolinewidth,e._gw||1)+"px")},E.drawLabels=function(t,e,r){r=r||{};var i=t._fullLayout,o=e._id,c=o.charAt(0),u=r.cls||o+"tick",f=r.vals,p=r.labelFns,d=r.secondary?0:e.tickangle,g=(e._prevTickAngles||{})[u],v=r.layer.selectAll("g."+u).data(e.showticklabels?f:[],J),m=[];function y(t,e){t.each(function(t){var i=n.select(this),o=i.select(".text-math-group"),s=p.anchorFn(t,e),c=r.transFn.call(i.node(),t)+(a(e)&&0!=+e?" rotate("+e+","+p.xFn(t)+","+(p.yFn(t)-t.fontSize/2)+")":""),u=l.lineCount(i),f=A*t.fontSize,d=p.heightFn(t,a(e)?+e:0,(u-1)*f);if(d&&(c+=" translate(0, "+d+")"),o.empty())i.select("text").attr({transform:c,"text-anchor":s});else{var g=h.bBox(o.node()).width*{end:-.5,start:.5}[s];o.attr("transform",c+(g?"translate("+g+",0)":""))}})}v.enter().append("g").classed(u,1).append("text").attr("text-anchor","middle").each(function(e){var r=n.select(this),a=t._promises.length;r.call(l.positionText,p.xFn(e),p.yFn(e)).call(h.font,e.font,e.fontSize,e.fontColor).text(e.text).call(l.convertToTspans,t),t._promises[a]?m.push(t._promises.pop().then(function(){y(r,d)})):y(r,d)}),v.exit().remove(),r.repositionOnUpdate&&v.each(function(t){n.select(this).select("text").call(l.positionText,p.xFn(t),p.yFn(t))}),y(v,g+1?g:d);var x=null;e._selections&&(e._selections[u]=v);var b=[function(){return m.length&&Promise.all(m)}];e.automargin&&i._redrawFromAutoMarginCount&&90===g?(x=90,b.push(function(){y(v,g)})):b.push(function(){if(y(v,d),f.length&&"x"===c&&!a(d)&&("log"!==e.type||"D"!==String(e.dtick).charAt(0))){x=0;var t,n=0,i=[];if(v.each(function(t){n=Math.max(n,t.fontSize);var r=e.l2p(t.x),a=$(this),o=h.bBox(a.node());i.push({top:0,bottom:10,height:10,left:r-o.width/2,right:r+o.width/2+2,width:o.width+2})}),"boundaries"!==e.tickson&&!e.showdividers||r.secondary){var o=f.length,l=Math.abs((f[o-1].x-f[0].x)*e._m)/(o-1)<2.5*n||"multicategory"===e.type;for(t=0;t<i.length-1;t++)if(s.bBoxIntersect(i[t],i[t+1])){x=l?90:30;break}}else{var u=2;for(e.ticks&&(u+=e.tickwidth/2),t=0;t<i.length;t++){var p=f[t].xbnd,g=i[t];if(null!==p[0]&&g.left-e.l2p(p[0])<u||null!==p[1]&&e.l2p(p[1])-g.right<u){x=90;break}}}x&&y(v,x)}}),e._tickAngles&&b.push(function(){e._tickAngles[u]=null===x?a(d)?d:0:x});var _=s.syncOrAsync(b);return _&&_.then&&t._promises.push(_),_},E.getPxPosition=function(t,e){var r,n=t._fullLayout._size,a=e._id.charAt(0),i=e.side;return"free"!==e.anchor?r=e._anchorAxis:"x"===a?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:"y"===a&&(r={_offset:n.l+(e.position||0)*n.w,_length:0}),"top"===i||"left"===i?r._offset:"bottom"===i||"right"===i?r._offset+r._length:void 0},E.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&("linear"===e.type||"-"===e.type)&&!(e.rangebreaks&&e.maskBreaks(0)===w)&&(Q(e,0)||!function(t,e,r,n){var a=r._mainAxis;if(!a)return;var i=t._fullLayout,o=e._id.charAt(0),s=E.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==("x"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return"number"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var a=t._linepositions||{};for(var i in a)if(n(a[i][0])||n(a[i][1]))return!0}var u=i._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var h=E.list(t,s),f=0;f<h.length;f++){var p=h[f];if(p._mainAxis===a&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,a=e._id.charAt(0),i=0;i<r.length;i++){var s=r[i];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,"bar-like")&&s.orientation==={x:"h",y:"v"}[a])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===a)return!0}}return!1}(t,e))},E.clipEnds=function(t,e){return e.filter(function(e){return Q(t,e.x)})},E.allowAutoMargin=function(t){for(var e=E.list(t,"",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&(i.allowAutoMargin(t,tt(n)),n.mirror&&i.allowAutoMargin(t,et(n))),o.getComponentMethod("rangeslider","isVisible")(n)&&i.allowAutoMargin(t,rt(n))}},E.swap=function(t,e){for(var r=function(t,e){var r,n,a=[];for(r=0;r<e.length;r++){var i=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<a.length;n++)-1===a[n].x.indexOf(o)&&-1===a[n].y.indexOf(s)||i.push(n);if(i.length){var l,c=a[i[0]];if(i.length>1)for(n=1;n<i.length;n++)l=a[i[n]],nt(c.x,l.x),nt(c.y,l.y);nt(c.x,[o]),nt(c.y,[s])}else a.push({x:[o],y:[s]})}}return a}(t,e),n=0;n<r.length;n++)at(t,r[n].x,r[n].y)}},{"../../components/color":591,"../../components/drawing":612,"../../components/titles":679,"../../constants/alignment":686,"../../constants/numerical":693,"../../lib":717,"../../lib/svg_text_utils":741,"../../plots/plots":826,"../../registry":846,"./autorange":764,"./axis_autotype":766,"./axis_ids":768,"./clean_ticks":770,"./layout_attributes":777,"./set_convert":783,d3:165,"fast-isnumeric":228}],766:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../constants/numerical").BADNUM;e.exports=function(t,e,r){return!(r=r||{}).noMultiCategory&&(o=t,a.isArrayOrTypedArray(o[0])&&a.isArrayOrTypedArray(o[1]))?"multicategory":function(t,e){for(var r=Math.max(1,(t.length-1)/1e3),i=0,o=0,s={},l=0;l<t.length;l+=r){var c=t[Math.round(l)],u=String(c);s[u]||(s[u]=1,a.isDateTime(c,e)&&(i+=1),n(c)&&(o+=1))}return i>2*o}(t,e)?"date":function(t){for(var e=Math.max(1,(t.length-1)/1e3),r=0,n=0,o={},s=0;s<t.length;s+=e){var l=t[Math.round(s)],c=String(l);o[c]||(o[c]=1,"boolean"==typeof l?n++:a.cleanNumber(l)!==i?r++:"string"==typeof l&&n++)}return n>2*r}(t)?"category":function(t){if(!t)return!1;for(var e=0;e<t.length;e++)if(n(t[e]))return!0;return!1}(t)?"linear":"-";var o}},{"../../constants/numerical":693,"../../lib":717,"fast-isnumeric":228}],767:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../registry"),i=t("../../lib"),o=t("../array_container_defaults"),s=t("./layout_attributes"),l=t("./tick_value_defaults"),c=t("./tick_mark_defaults"),u=t("./tick_label_defaults"),h=t("./category_order_defaults"),f=t("./line_grid_defaults"),p=t("./set_convert"),d=t("./constants").WEEKDAY_PATTERN,g=t("./constants").HOUR_PATTERN;function v(t,e,r){function a(r,n){return i.coerce(t,e,s.rangebreaks,r,n)}if(a("enabled")){var o=a("bounds");if(o&&o.length>=2){var l,c,u="";if(2===o.length)for(l=0;l<2;l++)if(c=y(o[l])){u=d;break}var h=a("pattern",u);if(h===d)for(l=0;l<2;l++)(c=y(o[l]))&&(e.bounds[l]=o[l]=c-1);if(h)for(l=0;l<2;l++)switch(c=o[l],h){case d:if(!n(c))return void(e.enabled=!1);if((c=+c)!==Math.floor(c)||c<0||c>=7)return void(e.enabled=!1);e.bounds[l]=o[l]=c;break;case g:if(!n(c))return void(e.enabled=!1);if((c=+c)<0||c>24)return void(e.enabled=!1);e.bounds[l]=o[l]=c}if(!1===r.autorange){var f=r.range;if(f[0]<f[1]){if(o[0]<f[0]&&o[1]>f[1])return void(e.enabled=!1)}else if(o[0]>f[0]&&o[1]<f[1])return void(e.enabled=!1)}}else{var p=a("values");if(!p||!p.length)return void(e.enabled=!1);a("dvalue")}}}e.exports=function(t,e,r,n,g){var m=n.letter,y=n.font||{},x=n.splomStash||{},b=r("visible",!n.visibleDflt),_=e._template||{},w=e.type||_.type||"-";"date"===w&&a.getComponentMethod("calendars","handleDefaults")(t,e,"calendar",n.calendar);p(e,g);var k=!e.isValidRange(t.range);k&&n.reverseDflt&&(k="reversed"),!r("autorange",k)||"linear"!==w&&"-"!==w||r("rangemode"),r("range"),e.cleanRange(),h(t,e,r,n),"category"===w||n.noHover||r("hoverformat");var T=r("color"),M=T!==s.color.dflt?T:y.color,A=x.label||g._dfltTitle[m];if(u(t,e,r,w,n,{pass:1}),!b)return e;r("title.text",A),i.coerceFont(r,"title.font",{family:y.family,size:Math.round(1.2*y.size),color:M}),l(t,e,r,w),u(t,e,r,w,n,{pass:2}),c(t,e,r,n),f(t,e,r,{dfltColor:T,bgColor:n.bgColor,showGrid:n.showGrid,attributes:s}),(e.showline||e.ticks)&&r("mirror"),n.automargin&&r("automargin");var S,E="multicategory"===w;n.noTickson||"category"!==w&&!E||!e.ticks&&!e.showgrid||(E&&(S="boundaries"),r("tickson",S));E&&(r("showdividers")&&(r("dividercolor"),r("dividerwidth")));if("date"===w)if(o(t,e,{name:"rangebreaks",inclusionAttr:"enabled",handleItemDefaults:v}),e.rangebreaks.length){for(var L=0;L<e.rangebreaks.length;L++)if(e.rangebreaks[L].pattern===d){e._hasDayOfWeekBreaks=!0;break}if(p(e,g),g._has("scattergl")||g._has("splom"))for(var C=0;C<n.data.length;C++){var P=n.data[C];"scattergl"!==P.type&&"splom"!==P.type||(P.visible=!1,i.warn(P.type+" traces do not work on axes with rangebreaks. Setting trace "+P.index+" to `visible: false`."))}}else delete e.rangebreaks;return e};var m={sun:1,mon:2,tue:3,wed:4,thu:5,fri:6,sat:7};function y(t){if("string"==typeof t)return m[t.substr(0,3).toLowerCase()]}},{"../../lib":717,"../../registry":846,"../array_container_defaults":761,"./category_order_defaults":769,"./constants":771,"./layout_attributes":777,"./line_grid_defaults":779,"./set_convert":783,"./tick_label_defaults":784,"./tick_mark_defaults":785,"./tick_value_defaults":786,"fast-isnumeric":228}],768:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("./constants");r.id2name=function(t){if("string"==typeof t&&t.match(a.AX_ID_PATTERN)){var e=t.substr(1);return"1"===e&&(e=""),t.charAt(0)+"axis"+e}},r.name2id=function(t){if(t.match(a.AX_NAME_PATTERN)){var e=t.substr(5);return"1"===e&&(e=""),t.charAt(0)+e}},r.cleanId=function(t,e){if(t.match(a.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)){var r=t.substr(1).replace(/^0+/,"");return"1"===r&&(r=""),t.charAt(0)+r}},r.list=function(t,e,n){var a=t._fullLayout;if(!a)return[];var i,o=r.listIds(t,e),s=new Array(o.length);for(i=0;i<o.length;i++){var l=o[i];s[i]=a[l.charAt(0)+"axis"+l.substr(1)]}if(!n){var c=a._subplots.gl3d||[];for(i=0;i<c.length;i++){var u=a[c[i]];e?s.push(u[e+"axis"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+"axis"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var a=t._fullLayout;return"x"===n?e=e.replace(/y[0-9]*/,""):"y"===n&&(e=e.replace(/x[0-9]*/,"")),a[r.id2name(e)]},r.getFromTrace=function(t,e,a){var i=t._fullLayout,o=null;if(n.traceIs(e,"gl3d")){var s=e.scene;"scene"===s.substr(0,5)&&(o=i[s][a+"axis"])}else o=r.getFromId(t,e[a+"axis"]||a);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},r.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++){if(r[n][e])return"g"+n}return e}},{"../../registry":846,"./constants":771}],769:[function(t,e,r){"use strict";e.exports=function(t,e,r,n){if("category"===e.type){var a,i=t.categoryarray,o=Array.isArray(i)&&i.length>0;o&&(a="array");var s,l=r("categoryorder",a);"array"===l&&(s=r("categoryarray")),o||"array"!==l||(l=e.categoryorder="trace"),"trace"===l?e._initialCategories=[]:"array"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,a,i=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[i+"axis"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][i];for(a=0;a<l.length;a++){var c=l[a];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),"category ascending"===l?e._initialCategories=s:"category descending"===l&&(e._initialCategories=s.reverse()))}}},{}],770:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../constants/numerical").ONEDAY;r.dtick=function(t,e){var r="log"===e,a="date"===e,o="category"===e,s=a?i:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:o?Math.max(1,Math.round(t)):a?Math.max(.1,t):t;if("string"!=typeof t||!a&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(a&&"M"===l&&c===Math.round(c)||r&&"L"===l||r&&"D"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,i){return"date"===e?a.cleanDate(t,a.dateTick0(r)):"D1"!==i&&"D2"!==i?n(t)?Number(t):0:void 0}},{"../../constants/numerical":693,"../../lib":717,"fast-isnumeric":228}],771:[function(t,e,r){"use strict";var n=t("../../lib/regex").counter;e.exports={idRegex:{x:n("x"),y:n("y")},attrRegex:n("[xy]axis"),xAxisMatch:n("xaxis"),yAxisMatch:n("yaxis"),AX_ID_PATTERN:/^[xyz][0-9]*$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,HOUR_PATTERN:"hour",WEEKDAY_PATTERN:"day of week",MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:"-select",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:["imagelayer","heatmaplayer","contourcarpetlayer","contourlayer","funnellayer","waterfalllayer","barlayer","carpetlayer","violinlayer","boxlayer","ohlclayer","scattercarpetlayer","scatterlayer"],clipOnAxisFalseQuery:[".scatterlayer",".barlayer",".funnellayer",".waterfalllayer"],layerValue2layerClass:{"above traces":"above","below traces":"below"}}},{"../../lib/regex":733}],772:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./axis_ids").id2name,i=t("./scale_zoom"),o=t("./autorange").makePadFn,s=t("./autorange").concatExtremes,l=t("../../constants/numerical").ALMOST_EQUAL,c=t("../../constants/alignment").FROM_BL;function u(t,e,r,n,i){var o,s,l,c,u="range"!==i,h=n[a(e)].type,f=[];for(s=0;s<r.length;s++)if((l=r[s])!==e&&(c=n[a(l)]).type===h)if(c.fixedrange){if(u&&c.anchor){n[a(c.anchor)].fixedrange&&f.push(l)}}else f.push(l);for(o=0;o<t.length;o++)if(t[o][e]){var p=t[o],d=[];for(s=0;s<f.length;s++)p[l=f[s]]||d.push(l);return{linkableAxes:d,thisGroup:p}}return{linkableAxes:f,thisGroup:null}}function h(t,e,r,n,a){var i,o,s,l,c;null===e?((e={})[r]=1,c=t.length,t.push(e)):c=t.indexOf(e);var u=Object.keys(e);for(i=0;i<t.length;i++)if(s=t[i],i!==c&&s[n]){var h=s[n];for(o=0;o<u.length;o++)s[l=u[o]]=h*a*e[l];return void t.splice(c,1)}if(1!==a)for(o=0;o<u.length;o++)e[u[o]]*=a;e[n]=1}function f(t,e){var r=t._inputDomain,n=c[t.constraintoward],a=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[a+(r[0]-a)/e,a+(r[1]-a)/e],t.setScale()}r.handleConstraintDefaults=function(t,e,r,a){var i,o,s,l,c=a.allAxisIds,f=a.layoutOut,p=a.scaleanchorDflt,d=a.constrainDflt,g=f._axisConstraintGroups,v=f._axisMatchGroups,m=e._id,y=m.charAt(0),x=((f._splomAxes||{})[y]||{})[m]||{},b=e._id,_=b.charAt(0),w=r("constrain",d);if(n.coerce(t,e,{constraintoward:{valType:"enumerated",values:"x"===_?["left","center","right"]:["bottom","middle","top"],dflt:"x"===_?"center":"middle"}},"constraintoward"),!t.matches&&!x.matches||e.fixedrange||(o=u(v,b,c,f),i=n.coerce(t,e,{matches:{valType:"enumerated",values:o.linkableAxes||[],dflt:x.matches}},"matches")),i||e.fixedrange&&"domain"!==w||!t.scaleanchor&&!p||(l=u(g,b,c,f,w),s=n.coerce(t,e,{scaleanchor:{valType:"enumerated",values:l.linkableAxes||[]}},"scaleanchor",p)),i?(delete e.constrain,h(v,o.thisGroup,b,i,1)):-1!==c.indexOf(t.matches)&&n.warn("ignored "+e._name+'.matches: "'+t.matches+'" to avoid either an infinite loop or because the target axis has fixed range.'),s){var k=r("scaleratio");k||(k=e.scaleratio=1),h(g,l.thisGroup,b,s,k)}else-1!==c.indexOf(t.scaleanchor)&&n.warn("ignored "+e._name+'.scaleanchor: "'+t.scaleanchor+'" to avoid either an infinite loop and possibly inconsistent scaleratios, or because the target axis has fixed range or this axis declares a *matches* constraint.')},r.enforce=function(t){var e,r,n,c,u,h,p,d=t._fullLayout,g=d._axisConstraintGroups||[];for(e=0;e<g.length;e++){var v=g[e],m=Object.keys(v),y=1/0,x=0,b=1/0,_={},w={},k=!1;for(r=0;r<m.length;r++)w[n=m[r]]=c=d[a(n)],c._inputDomain?c.domain=c._inputDomain.slice():c._inputDomain=c.domain.slice(),c._inputRange||(c._inputRange=c.range.slice()),c.setScale(),_[n]=u=Math.abs(c._m)/v[n],y=Math.min(y,u),"domain"!==c.constrain&&c._constraintShrinkable||(b=Math.min(b,u)),delete c._constraintShrinkable,x=Math.max(x,u),"domain"===c.constrain&&(k=!0);if(!(y>l*x)||k)for(r=0;r<m.length;r++)if(u=_[n=m[r]],h=(c=w[n]).constrain,u!==b||"domain"===h)if(p=u/b,"range"===h)i(c,p);else{var T=c._inputDomain,M=(c.domain[1]-c.domain[0])/(T[1]-T[0]),A=(c.r2l(c.range[1])-c.r2l(c.range[0]))/(c.r2l(c._inputRange[1])-c.r2l(c._inputRange[0]));if((p/=M)*A<1){c.domain=c._input.domain=T.slice(),i(c,p);continue}if(A<1&&(c.range=c._input.range=c._inputRange.slice(),p*=A),c.autorange){var S=c.r2l(c.range[0]),E=c.r2l(c.range[1]),L=(S+E)/2,C=L,P=L,O=Math.abs(E-L),z=L-O*p*1.0001,I=L+O*p*1.0001,D=o(c);f(c,p);var R,F,B=Math.abs(c._m),N=s(t,c),j=N.min,V=N.max;for(F=0;F<j.length;F++)(R=j[F].val-D(j[F])/B)>z&&R<C&&(C=R);for(F=0;F<V.length;F++)(R=V[F].val+D(V[F])/B)<I&&R>P&&(P=R);p/=(P-C)/(2*O),C=c.l2r(C),P=c.l2r(P),c.range=c._input.range=S<E?[C,P]:[P,C]}f(c,p)}}},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,a=t._fullLayout._axisConstraintGroups,i=0;i<a.length;i++)if(a[i][n]){r=!0;break}r&&"domain"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{"../../constants/alignment":686,"../../constants/numerical":693,"../../lib":717,"./autorange":764,"./axis_ids":768,"./scale_zoom":781}],773:[function(t,e,r){"use strict";var n=t("d3"),a=t("tinycolor2"),i=t("has-passive-events"),o=t("../../registry"),s=t("../../lib"),l=t("../../lib/svg_text_utils"),c=t("../../components/color"),u=t("../../components/drawing"),h=t("../../components/fx"),f=t("./axes"),p=t("../../lib/setcursor"),d=t("../../components/dragelement"),g=t("../../constants/alignment").FROM_TL,v=t("../../lib/clear_gl_canvases"),m=t("../../plot_api/subroutines").redrawReglTraces,y=t("../plots"),x=t("./axis_ids").getFromId,b=t("./select").prepSelect,_=t("./select").clearSelect,w=t("./select").selectOnClick,k=t("./scale_zoom"),T=t("./constants"),M=T.MINDRAG,A=T.MINZOOM,S=!0;function E(t,e,r,n){var a=s.ensureSingle(t.draglayer,e,r,function(e){e.classed("drag",!0).style({fill:"transparent","stroke-width":0}).attr("data-subplot",t.id)});return a.call(p,n),a.node()}function L(t,e,r,a,i,o,s){var l=E(t,"rect",e,r);return n.select(l).call(u.setRect,a,i,o,s),l}function C(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return""}function P(t,e,r,n,a){for(var i=0;i<t.length;i++){var o=t[i];if(!o.fixedrange)if(o.rangebreaks){var s="y"===o._id.charAt(0),l=s?1-e:e,c=s?1-r:r;n[o._name+".range[0]"]=o.l2r(o.p2l(l*o._length)),n[o._name+".range[1]"]=o.l2r(o.p2l(c*o._length))}else{var u=o._rl[0],h=o._rl[1]-u;n[o._name+".range[0]"]=o.l2r(u+h*e),n[o._name+".range[1]"]=o.l2r(u+h*r)}}if(a&&a.length){var f=(e+(1-r))/2;P(a,f,1-f,n,[])}}function O(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(!n.fixedrange)if(n.rangebreaks){var a=n._length,i=(n.p2l(0+e)-n.p2l(0)+(n.p2l(a+e)-n.p2l(a)))/2;n.range=[n.l2r(n._rl[0]-i),n.l2r(n._rl[1]-i)]}else n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)]}}function z(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function I(t,e,r,n,a){return t.append("path").attr("class","zoombox").style({fill:e>.2?"rgba(0,0,0,0)":"rgba(255,255,255,0)","stroke-width":0}).attr("transform","translate("+r+", "+n+")").attr("d",a+"Z")}function D(t,e,r){return t.append("path").attr("class","zoombox-corners").style({fill:c.background,stroke:c.defaultLine,"stroke-width":1,opacity:0}).attr("transform","translate("+e+", "+r+")").attr("d","M0,0Z")}function R(t,e,r,n,a,i){t.attr("d",n+"M"+r.l+","+r.t+"v"+r.h+"h"+r.w+"v-"+r.h+"h-"+r.w+"Z"),F(t,e,a,i)}function F(t,e,r,n){r||(t.transition().style("fill",n>.2?"rgba(0,0,0,0.4)":"rgba(255,255,255,0.3)").duration(200),e.transition().style("opacity",1).duration(200))}function B(t){n.select(t).selectAll(".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners").remove()}function N(t){S&&t.data&&t._context.showTips&&(s.notifier(s._(t,"Double-click to zoom back out"),"long"),S=!1)}function j(t){return"lasso"===t||"select"===t}function V(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,A)/2);return"M"+(t.l-3.5)+","+(t.t-.5+e)+"h3v"+-e+"h"+e+"v-3h-"+(e+3)+"ZM"+(t.r+3.5)+","+(t.t-.5+e)+"h-3v"+-e+"h"+-e+"v-3h"+(e+3)+"ZM"+(t.r+3.5)+","+(t.b+.5-e)+"h-3v"+e+"h"+-e+"v3h"+(e+3)+"ZM"+(t.l-3.5)+","+(t.b+.5-e)+"h3v"+e+"h"+e+"v3h-"+(e+3)+"Z"}function U(t,e,r,n){for(var a,i,o,l,c=!1,u={},h={},f=0;f<e.length;f++){var p=e[f];for(a in r)if(p[a]){for(o in p)("x"===o.charAt(0)?r:n)[o]||(u[o]=a);for(i in n)p[i]&&(c=!0)}for(i in n)if(p[i])for(l in p)("x"===l.charAt(0)?r:n)[l]||(h[l]=i)}c&&(s.extendFlat(u,h),h={});var d={},g=[];for(o in u){var v=x(t,o);g.push(v),d[v._id]=v}var m={},y=[];for(l in h){var b=x(t,l);y.push(b),m[b._id]=b}return{xaHash:d,yaHash:m,xaxes:g,yaxes:y,xLinks:u,yLinks:h,isSubplotConstrained:c}}function q(t,e){if(i){var r=void 0!==t.onwheel?"wheel":"mousewheel";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel&&(t.onmousewheel=e)}function H(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,i,c,p,S,E){var F,G,Y,W,X,Z,J,K,Q,$,tt,et,rt,nt,at,it,ot,st,lt,ct,ut,ht=t._fullLayout._zoomlayer,ft=S+E==="nsew",pt=1===(S+E).length;function dt(){if(F=e.xaxis,G=e.yaxis,Q=F._length,$=G._length,J=F._offset,K=G._offset,(Y={})[F._id]=F,(W={})[G._id]=G,S&&E)for(var r=e.overlays,n=0;n<r.length;n++){var a=r[n].xaxis;Y[a._id]=a;var i=r[n].yaxis;W[i._id]=i}X=H(Y),Z=H(W),rt=C(X,E),nt=C(Z,S),at=!nt&&!rt,tt=U(t,t._fullLayout._axisConstraintGroups,Y,W),et=U(t,t._fullLayout._axisMatchGroups,Y,W),it=E||tt.isSubplotConstrained||et.isSubplotConstrained,ot=S||tt.isSubplotConstrained||et.isSubplotConstrained;var o=t._fullLayout;st=o._has("scattergl"),lt=o._has("splom"),ct=o._has("svg")}dt();var gt=function(t,e,r){return t?"nsew"===t?r?"":"pan"===e?"move":"crosshair":t.toLowerCase()+"-resize":"pointer"}(nt+rt,t._fullLayout.dragmode,ft),vt=L(e,S+E+"drag",gt,r,i,c,p);if(at&&!ft)return vt.onmousedown=null,vt.style.pointerEvents="none",vt;var mt,yt,xt,bt,_t,wt,kt,Tt,Mt,At,St={element:vt,gd:t,plotinfo:e};function Et(){St.plotinfo.selection=!1,_(t)}function Lt(r,a){var i=t._fullLayout.clickmode;if(B(t),2!==r||pt||function(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];rt&&(r=r.concat(X)),nt&&(r=r.concat(Z)),et.xaxes&&(r=r.concat(et.xaxes)),et.yaxes&&(r=r.concat(et.yaxes));var n,a,i,s={};if("reset+autosize"===e)for(e="autosize",a=0;a<r.length;a++)if((n=r[a])._rangeInitial&&(n.range[0]!==n._rangeInitial[0]||n.range[1]!==n._rangeInitial[1])||!n._rangeInitial&&!n.autorange){e="reset";break}if("autosize"===e)for(a=0;a<r.length;a++)(n=r[a]).fixedrange||(s[n._name+".autorange"]=!0);else if("reset"===e)for((rt||tt.isSubplotConstrained)&&(r=r.concat(tt.xaxes)),nt&&!tt.isSubplotConstrained&&(r=r.concat(tt.yaxes)),tt.isSubplotConstrained&&(rt?nt||(r=r.concat(Z)):r=r.concat(X)),a=0;a<r.length;a++)(n=r[a]).fixedrange||(n._rangeInitial?(i=n._rangeInitial,s[n._name+".range[0]"]=i[0],s[n._name+".range[1]"]=i[1]):s[n._name+".autorange"]=!0);t.emit("plotly_doubleclick",null),o.call("_guiRelayout",t,s)}}(),ft)i.indexOf("select")>-1&&w(a,t,X,Z,e.id,St),i.indexOf("event")>-1&&h.click(t,a,e.id);else if(1===r&&pt){var s=S?G:F,c="s"===S||"w"===E?0:1,u=s._name+".range["+c+"]",f=function(t,e){var r,a=t.range[e],i=Math.abs(a-t.range[1-e]);return"date"===t.type?a:"log"===t.type?(r=Math.ceil(Math.max(0,-Math.log(i)/Math.LN10))+3,n.format("."+r+"g")(Math.pow(10,a))):(r=Math.floor(Math.log(Math.abs(a))/Math.LN10)-Math.floor(Math.log(i)/Math.LN10)+4,n.format("."+String(r)+"g")(a))}(s,c),p="left",d="middle";if(s.fixedrange)return;S?(d="n"===S?"top":"bottom","right"===s.side&&(p="right")):"e"===E&&(p="right"),t._context.showAxisRangeEntryBoxes&&n.select(vt).call(l.makeEditable,{gd:t,immediate:!0,background:t._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:"#444",horizontalAlign:p,verticalAlign:d}).on("edit",function(e){var r=s.d2r(e);void 0!==r&&o.call("_guiRelayout",t,u,r)})}}function Ct(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min(Q,e+mt)),a=Math.max(0,Math.min($,r+yt)),i=Math.abs(n-mt),o=Math.abs(a-yt);function s(){kt="",xt.r=xt.l,xt.t=xt.b,Mt.attr("d","M0,0Z")}if(xt.l=Math.min(mt,n),xt.r=Math.max(mt,n),xt.t=Math.min(yt,a),xt.b=Math.max(yt,a),tt.isSubplotConstrained)i>A||o>A?(kt="xy",i/Q>o/$?(o=i*$/Q,yt>a?xt.t=yt-o:xt.b=yt+o):(i=o*Q/$,mt>n?xt.l=mt-i:xt.r=mt+i),Mt.attr("d",V(xt))):s();else if(et.isSubplotConstrained)if(i>A||o>A){kt="xy";var l=Math.min(xt.l/Q,($-xt.b)/$),c=Math.max(xt.r/Q,($-xt.t)/$);xt.l=l*Q,xt.r=c*Q,xt.b=(1-l)*$,xt.t=(1-c)*$,Mt.attr("d",V(xt))}else s();else!nt||o<Math.min(Math.max(.6*i,M),A)?i<M||!rt?s():(xt.t=0,xt.b=$,kt="x",Mt.attr("d",function(t,e){return"M"+(t.l-.5)+","+(e-A-.5)+"h-3v"+(2*A+1)+"h3ZM"+(t.r+.5)+","+(e-A-.5)+"h3v"+(2*A+1)+"h-3Z"}(xt,yt))):!rt||i<Math.min(.6*o,A)?(xt.l=0,xt.r=Q,kt="y",Mt.attr("d",function(t,e){return"M"+(e-A-.5)+","+(t.t-.5)+"v-3h"+(2*A+1)+"v3ZM"+(e-A-.5)+","+(t.b+.5)+"v3h"+(2*A+1)+"v-3Z"}(xt,mt))):(kt="xy",Mt.attr("d",V(xt)));xt.w=xt.r-xt.l,xt.h=xt.b-xt.t,kt&&(At=!0),t._dragged=At,R(Tt,Mt,xt,_t,wt,bt),Pt(),t.emit("plotly_relayouting",ut),wt=!0}function Pt(){ut={},"xy"!==kt&&"x"!==kt||(P(X,xt.l/Q,xt.r/Q,ut,tt.xaxes),Bt("x",ut)),"xy"!==kt&&"y"!==kt||(P(Z,($-xt.b)/$,($-xt.t)/$,ut,tt.yaxes),Bt("y",ut))}function Ot(){Pt(),B(t),jt(),N(t)}St.prepFn=function(e,r,n){var i=St.dragmode,o=t._fullLayout.dragmode;o!==i&&(St.dragmode=o),dt(),at||(ft?e.shiftKey?"pan"===o?o="zoom":j(o)||(o="pan"):e.ctrlKey&&(o="pan"):o="pan"),St.minDrag="lasso"===o?1:void 0,j(o)?(St.xaxes=X,St.yaxes=Z,b(e,r,n,St,o)):(St.clickFn=Lt,j(i)&&Et(),at||("zoom"===o?(St.moveFn=Ct,St.doneFn=Ot,St.minDrag=1,function(e,r,n){var i=vt.getBoundingClientRect();mt=r-i.left,yt=n-i.top,xt={l:mt,r:mt,w:0,t:yt,b:yt,h:0},bt=t._hmpixcount?t._hmlumcount/t._hmpixcount:a(t._fullLayout.plot_bgcolor).getLuminance(),wt=!1,kt="xy",At=!1,Tt=I(ht,bt,J,K,_t="M0,0H"+Q+"V"+$+"H0V0"),Mt=D(ht,J,K)}(0,r,n)):"pan"===o&&(St.moveFn=Ft,St.doneFn=jt))),t._fullLayout._redrag=function(){var e=t._dragdata;e&&e.element===vt&&(j(t._fullLayout.dragmode)||(dt(),Vt([0,0,Q,$]),St.moveFn(e.dx,e.dy)))}},d.init(St);var zt=[0,0,Q,$],It=null,Dt=T.REDRAWDELAY,Rt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function Ft(e,r){if(!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,"ew"===rt||"ns"===nt)return rt&&(O(X,e),Bt("x")),nt&&(O(Z,r),Bt("y")),Vt([rt?-e:0,nt?-r:0,Q,$]),Nt(),void t.emit("plotly_relayouting",ut);if(tt.isSubplotConstrained&&rt&&nt){var n="w"===rt==("n"===nt)?1:-1,a=(e/Q+n*r/$)/2;e=a*Q,r=n*a*$}"w"===rt?e=l(X,0,e):"e"===rt?e=l(X,1,-e):rt||(e=0),"n"===nt?r=l(Z,1,r):"s"===nt?r=l(Z,0,-r):nt||(r=0);var i="w"===rt?e:0,o="n"===nt?r:0;if(tt.isSubplotConstrained){var s;if(!rt&&1===nt.length){for(s=0;s<X.length;s++)X[s].range=X[s]._r.slice(),k(X[s],1-r/$);i=(e=r*Q/$)/2}if(!nt&&1===rt.length){for(s=0;s<Z.length;s++)Z[s].range=Z[s]._r.slice(),k(Z[s],1-e/Q);o=(r=e*$/Q)/2}}Bt("x"),Bt("y"),Vt([i,o,Q-e,$-r]),Nt(),t.emit("plotly_relayouting",ut)}function l(t,e,r){for(var n,a,i=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,a=s._rl[i]+(s._rl[e]-s._rl[i])/z(r/s._length);var l=s.l2r(a);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-a)/(n._rl[e]-n._rl[i])}}function Bt(t,e){for(var r=et.isSubplotConstrained?{x:Z,y:X}[t]:et[t+"axes"],n=et.isSubplotConstrained?{x:X,y:Z}[t]:[],a=0;a<r.length;a++){var i=r[a],o=i._id,s=et.xLinks[o]||et.yLinks[o],l=n[0]||Y[s]||W[s];l&&(e?(e[i._name+".range[0]"]=e[l._name+".range[0]"],e[i._name+".range[1]"]=e[l._name+".range[1]"]):i.range=l.range.slice())}}function Nt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(it&&(n(X),n(tt.xaxes),n(et.xaxes)),ot&&(n(Z),n(tt.yaxes),n(et.yaxes)),ut={},e=0;e<r.length;e++){var a=r[e],i=x(t,a);f.drawOne(t,i,{skipTitle:!0}),ut[i._name+".range[0]"]=i.range[0],ut[i._name+".range[1]"]=i.range[1]}f.redrawComponents(t,r)}function jt(){Vt([0,0,Q,$]),s.syncOrAsync([y.previousPromises,function(){t._fullLayout._replotting=!1,o.call("_guiRelayout",t,ut)}],t)}function Vt(e){var r,n,a,i,l=t._fullLayout,c=l._plots,h=l._subplots.cartesian;if(lt&&o.subplotsRegistry.splom.drag(t),st)for(r=0;r<h.length;r++)if(a=(n=c[h[r]]).xaxis,i=n.yaxis,n._scene){var f=s.simpleMap(a.range,a.r2l),p=s.simpleMap(i.range,i.r2l);n._scene.update({range:[f[0],p[0],f[1],p[1]]})}if((lt||st)&&(v(t),m(t)),ct){var d=e[2]/F._length,g=e[3]/G._length;for(r=0;r<h.length;r++){a=(n=c[h[r]]).xaxis,i=n.yaxis;var y,x,b,_,w=it&&!a.fixedrange&&Y[a._id],k=ot&&!i.fixedrange&&W[i._id];if(w?(y=d,b=E?e[0]:Ht(a,y)):et.xaHash[a._id]?(y=d,b=e[0]*a._length/F._length):et.yaHash[a._id]?(y=g,b="ns"===nt?-e[1]*a._length/G._length:Ht(a,y,{n:"top",s:"bottom"}[nt])):b=qt(a,y=Ut(a,d,g)),k?(x=g,_=S?e[1]:Ht(i,x)):et.yaHash[i._id]?(x=g,_=e[1]*i._length/G._length):et.xaHash[i._id]?(x=d,_="ew"===rt?-e[0]*i._length/F._length:Ht(i,x,{e:"right",w:"left"}[rt])):_=qt(i,x=Ut(i,d,g)),y||x){y||(y=1),x||(x=1);var T=a._offset-b/y,M=i._offset-_/x;n.clipRect.call(u.setTranslate,b,_).call(u.setScale,y,x),n.plot.call(u.setTranslate,T,M).call(u.setScale,1/y,1/x),y===n.xScaleFactor&&x===n.yScaleFactor||(u.setPointGroupScale(n.zoomScalePts,y,x),u.setTextPointsScale(n.zoomScaleTxt,y,x)),u.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=y,n.yScaleFactor=x}}}}function Ut(t,e,r){return t.fixedrange?0:it&&tt.xaHash[t._id]?e:ot&&(tt.isSubplotConstrained?tt.xaHash:tt.yaHash)[t._id]?r:0}function qt(t,e){return e?(t.range=t._r.slice(),k(t,e),Ht(t,e)):0}function Ht(t,e,r){return t._length*(1-e)*g[r||t.constraintoward||"middle"]}return S.length*E.length!=1&&q(vt,function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(Et(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();dt(),clearTimeout(It);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,a=Math.exp(-Math.min(Math.max(r,-20),20)/200),i=Rt.draglayer.select(".nsewdrag").node().getBoundingClientRect(),o=(e.clientX-i.left)/i.width,l=(i.bottom-e.clientY)/i.height;if(it){for(E||(o=.5),n=0;n<X.length;n++)c(X[n],o,a);Bt("x"),zt[2]*=a,zt[0]+=zt[2]*o*(1/a-1)}if(ot){for(S||(l=.5),n=0;n<Z.length;n++)c(Z[n],l,a);Bt("y"),zt[3]*=a,zt[1]+=zt[3]*(1-l)*(1/a-1)}Vt(zt),Nt(),t.emit("plotly_relayouting",ut),It=setTimeout(function(){zt=[0,0,Q,$],jt()},Dt),e.preventDefault()}else s.log("Did not find wheel motion attributes: ",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),a=n[0]+(n[1]-n[0])*e;t.range=n.map(function(e){return t.l2r(a+(e-a)*r)})}}}),vt},makeDragger:E,makeRectDragger:L,makeZoombox:I,makeCorners:D,updateZoombox:R,xyCorners:V,transitionZoombox:F,removeZoombox:B,showDoubleClickNotifier:N,attachWheelEventHandler:q}},{"../../components/color":591,"../../components/dragelement":609,"../../components/drawing":612,"../../components/fx":630,"../../constants/alignment":686,"../../lib":717,"../../lib/clear_gl_canvases":702,"../../lib/setcursor":737,"../../lib/svg_text_utils":741,"../../plot_api/subroutines":756,"../../registry":846,"../plots":826,"./axes":765,"./axis_ids":768,"./constants":771,"./scale_zoom":781,"./select":782,d3:165,"has-passive-events":412,tinycolor2:535}],774:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/fx"),i=t("../../components/dragelement"),o=t("../../lib/setcursor"),s=t("./dragbox").makeDragBox,l=t("./constants").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(".drag").remove();else if(e._has("cartesian")||e._has("splom")){Object.keys(e._plots||{}).sort(function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split("y"),a=r.split("y");return n[0]===a[0]?Number(n[1]||1)-Number(a[1]||1):Number(n[0]||1)-Number(a[0]||1)}return e._plots[t].mainplot?1:-1}).forEach(function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,"ns","ew");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&t._fullLayout._plots[r]&&a.hover(t,e,r)},a.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,i.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,"n","w"),s(t,n,o._offset+o._length,c._offset-l,l,l,"n","e"),s(t,n,o._offset-l,c._offset+c._length,l,l,"s","w"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,"s","e"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var h=o._mainLinePosition;"top"===o.side&&(h-=l),s(t,n,o._offset+.1*o._length,h,.8*o._length,l,"","ew"),s(t,n,o._offset,h,.1*o._length,l,"","w"),s(t,n,o._offset+.9*o._length,h,.1*o._length,l,"","e")}if(r===c._mainSubplot){var f=c._mainLinePosition;"right"!==c.side&&(f-=l),s(t,n,f,c._offset+.1*c._length,l,.8*c._length,"ns",""),s(t,n,f,c._offset+.9*c._length,l,.1*c._length,"s",""),s(t,n,f,c._offset,l,.1*c._length,"n","")}}});var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,a.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,a.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r="pan"===e.dragmode?"move":"crosshair";o(e._draggers,r)}},{"../../components/dragelement":609,"../../components/fx":630,"../../lib/setcursor":737,"./constants":771,"./dragbox":773,d3:165}],775:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib");e.exports=function(t){return function(e,r){var i=e[t];if(Array.isArray(i))for(var o=n.subplotsRegistry.cartesian,s=o.idRegex,l=r._subplots,c=l.xaxis,u=l.yaxis,h=l.cartesian,f=r._has("cartesian")||r._has("gl2d"),p=0;p<i.length;p++){var d=i[p];if(a.isPlainObject(d)){var g=d.xref,v=d.yref,m=s.x.test(g),y=s.y.test(v);if(m||y){f||a.pushUnique(r._basePlotModules,o);var x=!1;m&&-1===c.indexOf(g)&&(c.push(g),x=!0),y&&-1===u.indexOf(v)&&(u.push(v),x=!0),x&&m&&y&&h.push(g+v)}}}}}},{"../../lib":717,"../../registry":846}],776:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../lib"),o=t("../plots"),s=t("../../components/drawing"),l=t("../get_data").getModuleCalcData,c=t("./axis_ids"),u=t("./constants"),h=t("../../constants/xmlns_namespaces"),f=i.ensureSingle;function p(t,e,r){return i.ensureSingle(t,e,r,function(t){t.datum(r)})}function d(t,e,r,i,o){for(var c,h,f,p=u.traceLayerClasses,d=t._fullLayout,g=d._modules,v=[],m=[],y=0;y<g.length;y++){var x=(c=g[y]).name,b=a.modules[x].categories;if(b.svg){var _=c.layerName||x+"layer",w=c.plot;f=(h=l(r,w))[0],r=h[1],f.length&&v.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:f}),b.zoomScale&&m.push("."+_)}}v.sort(function(t,e){return t.i-e.i});var k=e.plot.selectAll("g.mlayer").data(v,function(t){return t.className});if(k.enter().append("g").attr("class",function(t){return t.className}).classed("mlayer",!0).classed("rangeplot",e.isRangePlot),k.exit().remove(),k.order(),k.each(function(r){var a=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,a,i,o),-1===u.clipOnAxisFalseQuery.indexOf("."+l)&&s.setClipUrl(a,e.layerClipId,t)}),d._has("scattergl")&&(c=a.getModule("scattergl"),f=l(r,c)[0],c.plot(t,e,f)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(",")).selectAll(".trace")),m.length)){var T=e.plot.selectAll(m.join(",")).selectAll(".trace");e.zoomScalePts=T.selectAll("path.point"),e.zoomScaleTxt=T.selectAll(".textpoint")}}function g(t,e){var r=e.plotgroup,n=e.id,a=u.layerValue2layerClass[e.xaxis.layer],i=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,h=n+"-x",d=n+"-y";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,f(s.overlinesBelow,"path",h),f(s.overlinesBelow,"path",d),f(s.overaxesBelow,"g",h),f(s.overaxesBelow,"g",d),e.plot=f(s.overplot,"g",n),f(s.overlinesAbove,"path",h),f(s.overlinesAbove,"path",d),f(s.overaxesAbove,"g",h),f(s.overaxesAbove,"g",d),e.xlines=l.select(".overlines-"+a).select("."+h),e.ylines=l.select(".overlines-"+i).select("."+d),e.xaxislayer=l.select(".overaxes-"+a).select("."+h),e.yaxislayer=l.select(".overaxes-"+i).select("."+d)}else if(o)e.xlines=f(r,"path","xlines-above"),e.ylines=f(r,"path","ylines-above"),e.xaxislayer=f(r,"g","xaxislayer-above"),e.yaxislayer=f(r,"g","yaxislayer-above");else{var g=f(r,"g","layer-subplot");e.shapelayer=f(g,"g","shapelayer"),e.imagelayer=f(g,"g","imagelayer"),e.gridlayer=f(r,"g","gridlayer"),e.zerolinelayer=f(r,"g","zerolinelayer"),f(r,"path","xlines-below"),f(r,"path","ylines-below"),e.overlinesBelow=f(r,"g","overlines-below"),f(r,"g","xaxislayer-below"),f(r,"g","yaxislayer-below"),e.overaxesBelow=f(r,"g","overaxes-below"),e.plot=f(r,"g","plot"),e.overplot=f(r,"g","overplot"),e.xlines=f(r,"path","xlines-above"),e.ylines=f(r,"path","ylines-above"),e.overlinesAbove=f(r,"g","overlines-above"),f(r,"g","xaxislayer-above"),f(r,"g","yaxislayer-above"),e.overaxesAbove=f(r,"g","overaxes-above"),e.xlines=r.select(".xlines-"+a),e.ylines=r.select(".ylines-"+i),e.xaxislayer=r.select(".xaxislayer-"+a),e.yaxislayer=r.select(".yaxislayer-"+i)}o||(p(e.gridlayer,"g",e.xaxis._id),p(e.gridlayer,"g",e.yaxis._id),e.gridlayer.selectAll("g").map(function(t){return t[0]}).sort(c.idSort)),e.xlines.style("fill","none").classed("crisp",!0),e.ylines.style("fill","none").classed("crisp",!0)}function v(t,e){if(t){var r={};for(var a in t.each(function(t){var a=t[0];n.select(this).remove(),m(a,e),r[a]=!0}),e._plots)for(var i=e._plots[a].overlays||[],o=0;o<i.length;o++){var s=i[o];r[s.id]&&s.plot.selectAll(".trace").remove()}}}function m(t,e){e._draggers.selectAll("g."+t).remove(),e._defs.select("#clip"+e._uid+t+"plot").remove()}r.name="cartesian",r.attr=["xaxis","yaxis"],r.idRoot=["x","y"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t("./attributes"),r.layoutAttributes=t("./layout_attributes"),r.supplyLayoutDefaults=t("./layout_defaults"),r.transitionAxes=t("./transition_axes"),r.finalizeSubplots=function(t,e){var r,n,a,o=e._subplots,s=o.xaxis,l=o.yaxis,h=o.cartesian,f=h.concat(o.gl2d||[]),p={},d={};for(r=0;r<f.length;r++){var g=f[r].split("y");p[g[0]]=1,d["y"+g[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(a=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(a)||(a="y"),h.push(n+a),f.push(n+a),d[a]||(d[a]=1,i.pushUnique(l,a)));for(r=0;r<l.length;r++)d[a=l[r]]||(n=(t[c.id2name(a)]||{}).anchor,u.idRegex.x.test(n)||(n="x"),h.push(n+a),f.push(n+a),p[n]||(p[n]=1,i.pushUnique(s,n)));if(!f.length){for(var v in n="",a="",t){if(u.attrRegex.test(v))"x"===v.charAt(0)?(!n||+v.substr(5)<+n.substr(5))&&(n=v):(!a||+v.substr(5)<+a.substr(5))&&(a=v)}n=n?c.name2id(n):"x",a=a?c.name2id(a):"y",s.push(n),l.push(a),h.push(n+a)}},r.plot=function(t,e,r,n){var a,i=t._fullLayout,o=i._subplots.cartesian,s=t.calcdata;if(!Array.isArray(e))for(e=[],a=0;a<s.length;a++)e.push(a);for(a=0;a<o.length;a++){for(var l,c=o[a],u=i._plots[c],h=[],f=0;f<s.length;f++){var p=s[f],g=p[0].trace;g.xaxis+g.yaxis===c&&((-1!==e.indexOf(g.index)||g.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==["tonextx","tonexty","tonext"].indexOf(g.fill)&&-1===h.indexOf(l)&&h.push(l),h.push(p)),l=p)}d(t,u,h,r,n)}},r.clean=function(t,e,r,n){var a,i,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(a=s[o]).plotgroup&&a.plotgroup.remove();var h=n._has&&n._has("gl"),f=e._has&&e._has("gl");if(h&&!f)for(o in s)(a=s[o])._scene&&a._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(i=0;i<p.length;i++){var d=p[i];e[c.id2name(d)]||n._infolayer.selectAll(".g-"+d+"title").remove()}}var g=n._has&&n._has("cartesian"),y=e._has&&e._has("cartesian");if(g&&!y)v(n._cartesianlayer.selectAll(".subplot"),n),n._defs.selectAll(".axesclip").remove(),delete n._axisConstraintGroups;else if(u.cartesian)for(i=0;i<u.cartesian.length;i++){var x=u.cartesian[i];if(!l[x]){var b="."+x+",."+x+"-x,."+x+"-y";n._cartesianlayer.selectAll(b).remove(),m(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,a,i,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],h=[];for(e=0;e<c;e++){n=l[e],a=s._plots[n],i=a.xaxis,o=a.yaxis;var f=i._mainAxis,p=o._mainAxis,d=f._id+p._id,g=s._plots[d];a.overlays=[],d!==n&&g?(a.mainplot=d,a.mainplotinfo=g,h.push(n)):(a.mainplot=void 0,a.mainPlotinfo=void 0,u.push(n))}for(e=0;e<h.length;e++)n=h[e],(a=s._plots[n]).mainplotinfo.overlays.push(a);var v=u.concat(h),m=new Array(c);for(e=0;e<c;e++){n=v[e],a=s._plots[n],i=a.xaxis,o=a.yaxis;var y=[n,i.layer,o.layer,i.overlaying||"",o.overlaying||""];for(r=0;r<a.overlays.length;r++)y.push(a.overlays[r].id);m[e]=y}return m}(t),a=e._cartesianlayer.selectAll(".subplot").data(r,String);a.enter().append("g").attr("class",function(t){return"subplot "+t[0]}),a.order(),a.exit().call(v,e),a.each(function(r){var a=r[0],i=e._plots[a];i.plotgroup=n.select(this),g(t,i),i.draglayer=f(e._draggers,"g",a)})},r.rangePlot=function(t,e,r){g(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(".svg-container");r.filter(function(t,e){return e===r.size()-1}).selectAll(".gl-canvas-context, .gl-canvas-focus").each(function(){var t=this.toDataURL("image/png");e.append("svg:image").attr({xmlns:h.svg,"xlink:href":t,preserveAspectRatio:"none",x:0,y:0,width:this.width,height:this.height})})},r.updateFx=t("./graph_interact").updateFx},{"../../components/drawing":612,"../../constants/xmlns_namespaces":694,"../../lib":717,"../../registry":846,"../get_data":800,"../plots":826,"./attributes":763,"./axis_ids":768,"./constants":771,"./graph_interact":774,"./layout_attributes":777,"./layout_defaults":778,"./transition_axes":787,d3:165}],777:[function(t,e,r){"use strict";var n=t("../font_attributes"),a=t("../../components/color/attributes"),i=t("../../components/drawing/attributes").dash,o=t("../../lib/extend").extendFlat,s=t("../../plot_api/plot_template").templatedArray,l=(t("../../constants/docs").FORMAT_LINK,t("../../constants/docs").DATE_FORMAT_LINK,t("../../constants/numerical").ONEDAY),c=t("./constants"),u=c.HOUR_PATTERN,h=c.WEEKDAY_PATTERN;e.exports={visible:{valType:"boolean",editType:"plot"},color:{valType:"color",dflt:a.defaultLine,editType:"ticks"},title:{text:{valType:"string",editType:"ticks"},font:n({editType:"ticks"}),standoff:{valType:"number",min:0,editType:"ticks"},editType:"ticks"},type:{valType:"enumerated",values:["-","linear","log","date","category","multicategory"],dflt:"-",editType:"calc",_noTemplating:!0},autorange:{valType:"enumerated",values:[!0,!1,"reversed"],dflt:!0,editType:"axrange",impliedEdits:{"range[0]":void 0,"range[1]":void 0}},rangemode:{valType:"enumerated",values:["normal","tozero","nonnegative"],dflt:"normal",editType:"plot"},range:{valType:"info_array",items:[{valType:"any",editType:"axrange",impliedEdits:{"^autorange":!1},anim:!0},{valType:"any",editType:"axrange",impliedEdits:{"^autorange":!1},anim:!0}],editType:"axrange",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:"boolean",dflt:!1,editType:"calc"},scaleanchor:{valType:"enumerated",values:[c.idRegex.x.toString(),c.idRegex.y.toString()],editType:"plot"},scaleratio:{valType:"number",min:0,dflt:1,editType:"plot"},constrain:{valType:"enumerated",values:["range","domain"],dflt:"range",editType:"plot"},constraintoward:{valType:"enumerated",values:["left","center","right","top","middle","bottom"],editType:"plot"},matches:{valType:"enumerated",values:[c.idRegex.x.toString(),c.idRegex.y.toString()],editType:"calc"},rangebreaks:s("rangebreak",{enabled:{valType:"boolean",dflt:!0,editType:"calc"},bounds:{valType:"info_array",items:[{valType:"any",editType:"calc"},{valType:"any",editType:"calc"}],editType:"calc"},pattern:{valType:"enumerated",values:[h,u,""],editType:"calc"},values:{valType:"info_array",freeLength:!0,editType:"calc",items:{valType:"any",editType:"calc"}},dvalue:{valType:"number",editType:"calc",min:0,dflt:l},editType:"calc"}),tickmode:{valType:"enumerated",values:["auto","linear","array"],editType:"ticks",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:"integer",min:0,dflt:0,editType:"ticks"},tick0:{valType:"any",editType:"ticks",impliedEdits:{tickmode:"linear"}},dtick:{valType:"any",editType:"ticks",impliedEdits:{tickmode:"linear"}},tickvals:{valType:"data_array",editType:"ticks"},ticktext:{valType:"data_array",editType:"ticks"},ticks:{valType:"enumerated",values:["outside","inside",""],editType:"ticks"},tickson:{valType:"enumerated",values:["labels","boundaries"],dflt:"labels",editType:"ticks"},mirror:{valType:"enumerated",values:[!0,"ticks",!1,"all","allticks"],dflt:!1,editType:"ticks+layoutstyle"},ticklen:{valType:"number",min:0,dflt:5,editType:"ticks"},tickwidth:{valType:"number",min:0,dflt:1,editType:"ticks"},tickcolor:{valType:"color",dflt:a.defaultLine,editType:"ticks"},showticklabels:{valType:"boolean",dflt:!0,editType:"ticks"},automargin:{valType:"boolean",dflt:!1,editType:"ticks"},showspikes:{valType:"boolean",dflt:!1,editType:"modebar"},spikecolor:{valType:"color",dflt:null,editType:"none"},spikethickness:{valType:"number",dflt:3,editType:"none"},spikedash:o({},i,{dflt:"dash",editType:"none"}),spikemode:{valType:"flaglist",flags:["toaxis","across","marker"],dflt:"toaxis",editType:"none"},spikesnap:{valType:"enumerated",values:["data","cursor","hovered data"],dflt:"data",editType:"none"},tickfont:n({editType:"ticks"}),tickangle:{valType:"angle",dflt:"auto",editType:"ticks"},tickprefix:{valType:"string",dflt:"",editType:"ticks"},showtickprefix:{valType:"enumerated",values:["all","first","last","none"],dflt:"all",editType:"ticks"},ticksuffix:{valType:"string",dflt:"",editType:"ticks"},showticksuffix:{valType:"enumerated",values:["all","first","last","none"],dflt:"all",editType:"ticks"},showexponent:{valType:"enumerated",values:["all","first","last","none"],dflt:"all",editType:"ticks"},exponentformat:{valType:"enumerated",values:["none","e","E","power","SI","B"],dflt:"B",editType:"ticks"},separatethousands:{valType:"boolean",dflt:!1,editType:"ticks"},tickformat:{valType:"string",dflt:"",editType:"ticks"},tickformatstops:s("tickformatstop",{enabled:{valType:"boolean",dflt:!0,editType:"ticks"},dtickrange:{valType:"info_array",items:[{valType:"any",editType:"ticks"},{valType:"any",editType:"ticks"}],editType:"ticks"},value:{valType:"string",dflt:"",editType:"ticks"},editType:"ticks"}),hoverformat:{valType:"string",dflt:"",editType:"none"},showline:{valType:"boolean",dflt:!1,editType:"ticks+layoutstyle"},linecolor:{valType:"color",dflt:a.defaultLine,editType:"layoutstyle"},linewidth:{valType:"number",min:0,dflt:1,editType:"ticks+layoutstyle"},showgrid:{valType:"boolean",editType:"ticks"},gridcolor:{valType:"color",dflt:a.lightLine,editType:"ticks"},gridwidth:{valType:"number",min:0,dflt:1,editType:"ticks"},zeroline:{valType:"boolean",editType:"ticks"},zerolinecolor:{valType:"color",dflt:a.defaultLine,editType:"ticks"},zerolinewidth:{valType:"number",dflt:1,editType:"ticks"},showdividers:{valType:"boolean",dflt:!0,editType:"ticks"},dividercolor:{valType:"color",dflt:a.defaultLine,editType:"ticks"},dividerwidth:{valType:"number",dflt:1,editType:"ticks"},anchor:{valType:"enumerated",values:["free",c.idRegex.x.toString(),c.idRegex.y.toString()],editType:"plot"},side:{valType:"enumerated",values:["top","bottom","left","right"],editType:"plot"},overlaying:{valType:"enumerated",values:["free",c.idRegex.x.toString(),c.idRegex.y.toString()],editType:"plot"},layer:{valType:"enumerated",values:["above traces","below traces"],dflt:"above traces",editType:"plot"},domain:{valType:"info_array",items:[{valType:"number",min:0,max:1,editType:"plot"},{valType:"number",min:0,max:1,editType:"plot"}],dflt:[0,1],editType:"plot"},position:{valType:"number",min:0,max:1,dflt:0,editType:"plot"},categoryorder:{valType:"enumerated",values:["trace","category ascending","category descending","array","total ascending","total descending","min ascending","min descending","max ascending","max descending","sum ascending","sum descending","mean ascending","mean descending","median ascending","median descending"],dflt:"trace",editType:"calc"},categoryarray:{valType:"data_array",editType:"calc"},uirevision:{valType:"any",editType:"none"},editType:"calc",_deprecated:{autotick:{valType:"boolean",editType:"ticks"},title:{valType:"string",editType:"ticks"},titlefont:n({editType:"ticks"})}}},{"../../components/color/attributes":590,"../../components/drawing/attributes":611,"../../constants/docs":688,"../../constants/numerical":693,"../../lib/extend":708,"../../plot_api/plot_template":755,"../font_attributes":791,"./constants":771}],778:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/color"),i=t("../../components/fx/helpers").isUnifiedHover,o=t("../../components/fx/hovermode_defaults"),s=t("../../plot_api/plot_template"),l=t("../layout_attributes"),c=t("./layout_attributes"),u=t("./type_defaults"),h=t("./axis_defaults"),f=t("./constraints").handleConstraintDefaults,p=t("./position_defaults"),d=t("./axis_ids"),g=d.id2name,v=d.name2id,m=t("./constants").AX_ID_PATTERN,y=t("../../registry"),x=y.traceIs,b=y.getComponentMethod;function _(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var d,y,w={},k={},T={},M={},A={},S={},E={},L={},C={},P={};for(d=0;d<r.length;d++){var O=r[d];if(x(O,"cartesian")||x(O,"gl2d")){var z,I;if(O.xaxis)z=g(O.xaxis),_(w,z,O);else if(O.xaxes)for(y=0;y<O.xaxes.length;y++)_(w,g(O.xaxes[y]),O);if(O.yaxis)I=g(O.yaxis),_(w,I,O);else if(O.yaxes)for(y=0;y<O.yaxes.length;y++)_(w,g(O.yaxes[y]),O);if("funnel"===O.type?"h"===O.orientation?(z&&(k[z]=!0),I&&(E[I]=!0)):I&&(T[I]=!0):"image"===O.type?(I&&(L[I]=!0),z&&(L[z]=!0)):(I&&(A[I]=!0,S[I]=!0),x(O,"carpet")&&("carpet"!==O.type||O._cheater)||z&&(M[z]=!0)),"carpet"===O.type&&O._cheater&&z&&(k[z]=!0),x(O,"2dMap")&&(C[z]=!0,C[I]=!0),x(O,"oriented"))P["h"===O.orientation?I:z]=!0}}var D=e._subplots,R=D.xaxis,F=D.yaxis,B=n.simpleMap(R,g),N=n.simpleMap(F,g),j=B.concat(N),V=a.background;R.length&&F.length&&(V=n.coerce(t,e,l,"plot_bgcolor"));var U,q,H,G,Y,W=a.combine(V,e.paper_bgcolor);function X(){var t=w[U]||[];Y._traceIndices=t.map(function(t){return t._expandedIndex}),Y._annIndices=[],Y._shapeIndices=[],Y._imgIndices=[],Y._subplotsWith=[],Y._counterAxes=[],Y._name=Y._attr=U,Y._id=q}function Z(t,e){return n.coerce(G,Y,c,t,e)}function J(t,e){return n.coerce2(G,Y,c,t,e)}function K(t){return"x"===t?F:R}function Q(e,r){for(var n="x"===e?B:N,a=[],i=0;i<n.length;i++){var o=n[i];o===r||(t[o]||{}).overlaying||a.push(v(o))}return a}var $={x:K("x"),y:K("y")},tt=$.x.concat($.y),et={},rt=[];function nt(){var t=G.matches;m.test(t)&&-1===tt.indexOf(t)&&(et[t]=G.type,rt=Object.keys(et))}var at=o(t,e,r),it=i(at);for(d=0;d<j.length;d++){U=j[d],q=v(U),H=U.charAt(0),n.isPlainObject(t[U])||(t[U]={}),G=t[U],Y=s.newContainer(e,U,H+"axis"),X();var ot="x"===H&&!M[U]&&k[U]||"y"===H&&!A[U]&&T[U],st="y"===H&&(!S[U]&&E[U]||L[U]),lt={letter:H,font:e.font,outerTicks:C[U],showGrid:!P[U],data:w[U]||[],bgColor:W,calendar:e.calendar,automargin:!0,visibleDflt:ot,reverseDflt:st,splomStash:((e._splomAxes||{})[H]||{})[q]};Z("uirevision",e.uirevision),u(G,Y,Z,lt),h(G,Y,Z,lt,e);var ct=it&&H===at.charAt(0),ut=J("spikecolor",it?Y.color:void 0),ht=J("spikethickness",it?1.5:void 0),ft=J("spikedash",it?"dot":void 0),pt=J("spikemode",it?"across":void 0),dt=J("spikesnap",it?"hovered data":void 0);Z("showspikes",!!(ct||ut||ht||ft||pt||dt))||(delete Y.spikecolor,delete Y.spikethickness,delete Y.spikedash,delete Y.spikemode,delete Y.spikesnap),p(G,Y,Z,{letter:H,counterAxes:$[H],overlayableAxes:Q(H,U),grid:e.grid}),Z("title.standoff"),nt(),Y._input=G}for(d=0;d<rt.length;){q=rt[d++],H=(U=g(q)).charAt(0),n.isPlainObject(t[U])||(t[U]={}),G=t[U],Y=s.newContainer(e,U,H+"axis"),X();var gt={letter:H,font:e.font,outerTicks:C[U],showGrid:!P[U],data:[],bgColor:W,calendar:e.calendar,automargin:!0,visibleDflt:!1,reverseDflt:!1,splomStash:((e._splomAxes||{})[H]||{})[q]};Z("uirevision",e.uirevision),Y.type=et[q]||"linear",h(G,Y,Z,gt,e),p(G,Y,Z,{letter:H,counterAxes:$[H],overlayableAxes:Q(H,U),grid:e.grid}),Z("fixedrange"),nt(),Y._input=G}var vt=b("rangeslider","handleDefaults"),mt=b("rangeselector","handleDefaults");for(d=0;d<B.length;d++)U=B[d],G=t[U],Y=e[U],vt(t,e,U),"date"===Y.type&&mt(G,Y,e,N,Y.calendar),Z("fixedrange");for(d=0;d<N.length;d++){U=N[d],G=t[U],Y=e[U];var yt=e[g(Y.anchor)];Z("fixedrange",b("rangeslider","isVisible")(yt))}var xt=e._axisConstraintGroups=[],bt=e._axisMatchGroups=[],_t=tt.concat(rt),wt=j.concat(n.simpleMap(rt,g));for(d=0;d<wt.length;d++){var kt,Tt;H=(U=wt[d]).charAt(0),G=t[U],Y=e[U],kt="y"===H&&!G.hasOwnProperty("scaleanchor")&&L[U]?Y.anchor:void 0,Tt=!G.hasOwnProperty("constrain")&&L[U]?"domain":void 0,f(G,Y,Z,{allAxisIds:_t,layoutOut:e,scaleanchorDflt:kt,constrainDflt:Tt})}for(d=0;d<bt.length;d++){var Mt=bt[d],At=null,St=null;for(q in Mt)(Y=e[g(q)]).matches||(At=Y.range,St=Y.autorange);if(null===At||null===St)for(q in Mt){At=(Y=e[g(q)]).range,St=Y.autorange;break}for(q in Mt)(Y=e[g(q)]).matches&&(Y.range=At.slice(),Y.autorange=St),Y._matchGroup=Mt;if(xt.length)for(q in Mt)for(y=0;y<xt.length;y++){var Et=xt[y];for(var Lt in Et)q===Lt&&(n.warn("Axis "+Lt+" is set with both a *scaleanchor* and *matches* constraint; ignoring the scale constraint."),delete Et[Lt],Object.keys(Et).length<2&&xt.splice(y,1))}}}},{"../../components/color":591,"../../components/fx/helpers":626,"../../components/fx/hovermode_defaults":629,"../../lib":717,"../../plot_api/plot_template":755,"../../registry":846,"../layout_attributes":817,"./axis_defaults":767,"./axis_ids":768,"./constants":771,"./constraints":772,"./layout_attributes":777,"./position_defaults":780,"./type_defaults":788}],779:[function(t,e,r){"use strict";var n=t("tinycolor2").mix,a=t("../../components/color/attributes").lightFraction,i=t("../../lib");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return i.coerce2(t,e,o.attributes,r,n)}var c=l("linecolor",s),u=l("linewidth");r("showline",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var h=l("gridcolor",n(s,o.bgColor,o.blend||a).toRgbString()),f=l("gridwidth");if(r("showgrid",o.showGrid||!!h||!!f)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l("zerolinecolor",s),d=l("zerolinewidth");r("zeroline",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{"../../components/color/attributes":590,"../../lib":717,tinycolor2:535}],780:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib");e.exports=function(t,e,r,i){var o,s,l,c,u=i.counterAxes||[],h=i.overlayableAxes||[],f=i.letter,p=i.grid;p&&(s=p._domains[f][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[f+"side"].split(" ")[0],c=p.domain[f]["right"===l||"top"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?"free":u[0]||"free"),l=l||("x"===f?"bottom":"left"),c=c||0,"free"===a.coerce(t,e,{anchor:{valType:"enumerated",values:["free"].concat(u),dflt:o}},"anchor")&&r("position",c),a.coerce(t,e,{side:{valType:"enumerated",values:"x"===f?["bottom","top"]:["left","right"],dflt:l}},"side");var d=!1;if(h.length&&(d=a.coerce(t,e,{overlaying:{valType:"enumerated",values:[!1].concat(h),dflt:!1}},"overlaying")),!d){var g=r("domain",s);g[0]>g[1]-1/4096&&(e.domain=s),a.noneOrAll(t.domain,e.domain,s)}return r("layer"),e}},{"../../lib":717,"fast-isnumeric":228}],781:[function(t,e,r){"use strict";var n=t("../../constants/alignment").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||"center"]);var a=[t.r2l(t.range[0]),t.r2l(t.range[1])],i=a[0]+(a[1]-a[0])*r;t.range=t._input.range=[t.l2r(i+(a[0]-i)*e),t.l2r(i+(a[1]-i)*e)]}},{"../../constants/alignment":686}],782:[function(t,e,r){"use strict";var n=t("polybooljs"),a=t("../../registry"),i=t("../../components/color"),o=t("../../components/fx"),s=t("../../lib"),l=t("../../lib/polygon"),c=t("../../lib/throttle"),u=t("../../components/fx/helpers").makeEventData,h=t("./axis_ids").getFromId,f=t("../../lib/clear_gl_canvases"),p=t("../../plot_api/subroutines").redrawReglTraces,d=t("./constants"),g=d.MINSELECT,v=l.filter,m=l.tester;function y(t){return t._id}function x(t,e,r,n,a,i,o){var s,l,c,u,h,f,p,d,g,v=e._hoverdata,m=e._fullLayout.clickmode.indexOf("event")>-1,y=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(v)){k(t,e,i);var x=function(t,e){var r,n,a=t[0],i=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],a.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===a.hoverOnBox)break;void 0!==a.pointNumber?i=a.pointNumber:void 0!==a.binNumber&&(i=a.binNumber,o=a.pointNumbers);break}return{pointNumber:i,pointNumbers:o,searchInfo:r}}(v,s=M(e,r,n,a));if(x.pointNumbers.length>0?function(t,e){var r,n,a,i=[];for(a=0;a<t.length;a++)(r=t[a]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&i.push(r);if(1===i.length&&i[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(a=0;a<e.pointNumbers.length;a++)if(n.selectedpoints.indexOf(e.pointNumbers[a])<0)return!1;return!0}return!1}(s,x):function(t){var e,r,n,a=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((a+=r.selectedpoints.length)>1)return!1}return 1===a}(s)&&(f=S(x))){for(o&&o.remove(),g=0;g<s.length;g++)(l=s[g])._module.selectPoints(l,!1);E(e,s),T(i),m&&e.emit("plotly_deselect",null)}else{for(p=t.shiftKey&&(void 0!==f?f:S(x)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(x.pointNumber,x.searchInfo,p),u=w(i.selectionDefs.concat([c])),g=0;g<s.length;g++)if(h=L(s[g]._module.selectPoints(s[g],u),s[g]),y.length)for(var b=0;b<h.length;b++)y.push(h[b]);else y=h;E(e,s,d={points:y}),c&&i&&i.selectionDefs.push(c),o&&A(i.mergedPolygons,o),m&&e.emit("plotly_selected",d)}}}function b(t){return"pointNumber"in t&&"searchInfo"in t}function _(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,a){var i=t.searchInfo.cd[0].trace._expandedIndex;return a.cd[0].trace._expandedIndex===i&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function w(t){for(var e=[],r=b(t[0])?0:t[0][0][0],n=r,a=b(t[0])?0:t[0][0][1],i=a,o=0;o<t.length;o++)if(b(t[o]))e.push(_(t[o]));else{var s=l.tester(t[o]);s.subtract=t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),a=Math.min(a,s.ymin),i=Math.max(i,s.ymax)}return{xmin:r,xmax:n,ymin:a,ymax:i,pts:[],contains:function(t,r,n,a){for(var i=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,a)&&(i=!1===e[o].subtract);return i},isRect:!1,degenerate:!1}}function k(t,e,r){var n=e._fullLayout,a=r.plotinfo,i=n._lastSelectedSubplot&&n._lastSelectedSubplot===a.id,o=t.shiftKey||t.altKey;i&&o&&a.selection&&a.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=a.selection.selectionDefs,r.mergedPolygons=a.selection.mergedPolygons):o&&a.selection||T(r),i||(C(e),n._lastSelectedSubplot=a.id)}function T(t){var e=t.plotinfo;e.selection={},e.selection.selectionDefs=t.selectionDefs=[],e.selection.mergedPolygons=t.mergedPolygons=[]}function M(t,e,r,n){var a,i,o,s=[],l=e.map(y),c=r.map(y);for(o=0;o<t.calcdata.length;o++)if(!0===(i=(a=t.calcdata[o])[0].trace).visible&&i._module&&i._module.selectPoints)if(!n||i.subplot!==n&&i.geo!==n)if("splom"===i.type&&i._xaxes[l[0]]&&i._yaxes[c[0]]){var u=p(i._module,a,e[0],r[0]);u.scene=t._fullLayout._splomScenes[i.uid],s.push(u)}else if("sankey"===i.type){var f=p(i._module,a,e[0],r[0]);s.push(f)}else{if(-1===l.indexOf(i.xaxis))continue;if(-1===c.indexOf(i.yaxis))continue;s.push(p(i._module,a,h(t,i.xaxis),h(t,i.yaxis)))}else s.push(p(i._module,a,e[0],r[0]));return s;function p(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function A(t,e){var r,n,a=[];for(r=0;r<t.length;r++){var i=t[r];a.push(i.join("L")+"L"+i[0])}n=t.length>0?"M"+a.join("M")+"Z":"M0,0Z",e.attr("d",n)}function S(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,a=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(a)>-1}function E(t,e,r){var n,i,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid]||{};void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var h=u[n],d=h.data,g=h.fullData;h.pointIndices?([].push.apply(d.selectedpoints,h.pointIndices),s._fullInput!==s&&[].push.apply(g.selectedpoints,h.pointIndices)):(d.selectedpoints.push(h.pointIndex),s._fullInput!==s&&g.selectedpoints.push(h.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var v=!1;for(n=0;n<e.length;n++){s=(o=(i=e[n]).cd)[0].trace,a.traceIs(s,"regl")&&(v=!0);var m=i._module,y=m.styleOnSelect||m.style;y&&(y(t,o,o[0].node3),o[0].nodeRangePlot3&&y(t,o,o[0].nodeRangePlot3))}v&&(f(t),p(t))}function L(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,a=0;a<t.length;a++)t[a]=u(t[a],n,r);return t}function C(t){var e=(t._fullLayout||{})._zoomlayer;e&&e.selectAll(".select-outline").remove()}e.exports={prepSelect:function(t,e,r,a,l){var u,h,f,p,y,b,_,S=a.gd,C=S._fullLayout,P=C._zoomlayer,O=a.element.getBoundingClientRect(),z=a.plotinfo,I=z.xaxis._offset,D=z.yaxis._offset,R=e-O.left,F=r-O.top,B=R,N=F,j="M"+R+","+F,V=a.xaxes[0]._length,U=a.yaxes[0]._length,q=a.xaxes.concat(a.yaxes),H=t.altKey;k(t,S,a),"lasso"===l&&(u=v([[R,F]],d.BENDPX));var G=P.selectAll("path.select-outline-"+z.id).data([1,2]);G.enter().append("path").attr("class",function(t){return"select-outline select-outline-"+t+" select-outline-"+z.id}).attr("transform","translate("+I+", "+D+")").attr("d",j+"Z");var Y,W=P.append("path").attr("class","zoombox-corners").style({fill:i.background,stroke:i.defaultLine,"stroke-width":1}).attr("transform","translate("+I+", "+D+")").attr("d","M0,0Z"),X=C._uid+d.SELECTID,Z=[],J=M(S,a.xaxes,a.yaxes,a.subplot);function K(t,e){return"log"===t.type?t.p2d(e):t.p2r(e)}function Q(t){var e="y"===t._id.charAt(0)?1:0;return function(r){return K(t,r[e])}}function $(t,e){return t-e}Y=z.fillRangeItems?z.fillRangeItems:"select"===l?function(t,e){var r=t.range={};for(y=0;y<q.length;y++){var n=q[y],a=n._id.charAt(0);r[n._id]=[K(n,e[a+"min"]),K(n,e[a+"max"])].sort($)}}:function(t,e,r){var n=t.lassoPoints={};for(y=0;y<q.length;y++){var a=q[y];n[a._id]=r.filtered.map(Q(a))}},a.moveFn=function(t,e){B=Math.max(0,Math.min(V,t+R)),N=Math.max(0,Math.min(U,e+F));var r=Math.abs(B-R),i=Math.abs(N-F);if("select"===l){var o=C.selectdirection;"h"===(o="any"===C.selectdirection?i<Math.min(.6*r,g)?"h":r<Math.min(.6*i,g)?"v":"d":C.selectdirection)?((p=[[R,0],[R,U],[B,U],[B,0]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(0,U),p.ymax=Math.max(0,U),W.attr("d","M"+p.xmin+","+(F-g)+"h-4v"+2*g+"h4ZM"+(p.xmax-1)+","+(F-g)+"h4v"+2*g+"h-4Z")):"v"===o?((p=[[0,F],[0,N],[V,N],[V,F]]).xmin=Math.min(0,V),p.xmax=Math.max(0,V),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr("d","M"+(R-g)+","+p.ymin+"v-4h"+2*g+"v4ZM"+(R-g)+","+(p.ymax-1)+"v4h"+2*g+"v-4Z")):"d"===o&&((p=[[R,F],[R,N],[B,N],[B,F]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr("d","M0,0Z"))}else"lasso"===l&&(u.addPt([B,N]),p=u.filtered);a.selectionDefs&&a.selectionDefs.length?(f=function(t,e,r){return r?n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions:n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(a.mergedPolygons,p,H),p.subtract=H,h=w(a.selectionDefs.concat([p]))):(f=[p],h=m(p)),A(f,G),c.throttle(X,d.SELECTDELAY,function(){var t;Z=[];var e,r=[];for(y=0;y<J.length;y++)if(e=(b=J[y])._module.selectPoints(b,h),r.push(e),t=L(e,b),Z.length)for(var n=0;n<t.length;n++)Z.push(t[n]);else Z=t;E(S,J,_={points:Z}),Y(_,p,u),a.gd.emit("plotly_selecting",_)})},a.clickFn=function(t,e){var r=C.clickmode;W.remove(),c.done(X).then(function(){if(c.clear(X),2===t){for(G.remove(),y=0;y<J.length;y++)(b=J[y])._module.selectPoints(b,!1);E(S,J),T(a),S.emit("plotly_deselect",null)}else r.indexOf("select")>-1&&x(e,S,a.xaxes,a.yaxes,a.subplot,a,G),"event"===r&&S.emit("plotly_selected",void 0);o.click(S,e)}).catch(s.error)},a.doneFn=function(){W.remove(),c.done(X).then(function(){c.clear(X),a.gd.emit("plotly_selected",_),p&&a.selectionDefs&&(p.subtract=H,a.selectionDefs.push(p),a.mergedPolygons.length=0,[].push.apply(a.mergedPolygons,f)),a.doneFnCompleted&&a.doneFnCompleted(Z)}).catch(s.error)}},clearSelect:C,selectOnClick:x}},{"../../components/color":591,"../../components/fx":630,"../../components/fx/helpers":626,"../../lib":717,"../../lib/clear_gl_canvases":702,"../../lib/polygon":729,"../../lib/throttle":742,"../../plot_api/subroutines":756,"../../registry":846,"./axis_ids":768,"./constants":771,polybooljs:474}],783:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../../lib"),o=i.cleanNumber,s=i.ms2DateTime,l=i.dateTime2ms,c=i.ensureNumber,u=i.isArrayOrTypedArray,h=t("../../constants/numerical"),f=h.FP_SAFE,p=h.BADNUM,d=h.LOG_CLIP,g=h.ONEDAY,v=h.ONEHOUR,m=h.ONEMIN,y=h.ONESEC,x=t("./axis_ids"),b=t("./constants"),_=b.HOUR_PATTERN,w=b.WEEKDAY_PATTERN;function k(t){return Math.pow(10,t)}function T(t){return null!=t}e.exports=function(t,e){e=e||{};var r=t._id||"x",h=r.charAt(0);function M(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],a=t.range[1];return.5*(n+a-2*d*Math.abs(n-a))}return p}function A(e,r,n){var o=l(e,n||t.calendar);if(o===p){if(!a(e))return p;e=+e;var s=Math.floor(10*i.mod(e+.05,1)),c=Math.round(e-s/10);o=l(new Date(c))+s/10}return o}function S(e,r,n){return s(e,r,n||t.calendar)}function E(e){return t._categories[Math.round(e)]}function L(e){if(T(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push("number"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return p}function C(e){if(t._categoriesMap)return t._categoriesMap[e]}function P(t){var e=C(t);return void 0!==e?e:a(t)?+t:void 0}function O(t,e,r){return n.round(r+e*t,2)}function z(t,e,r){return(t-r)/e}var I=function(e){return a(e)?O(e,t._m,t._b):p},D=function(e){return z(e,t._m,t._b)};if(t.rangebreaks){var R="y"===h;I=function(e){if(!a(e))return p;var r=t._rangebreaks.length;if(!r)return O(e,t._m,t._b);var n=R;t.range[0]>t.range[1]&&(n=!n);for(var i=n?-1:1,o=i*e,s=0,l=0;l<r;l++){var c=i*t._rangebreaks[l].min,u=i*t._rangebreaks[l].max;if(o<c)break;if(!(o>u)){s=o<(c+u)/2?l:l+1;break}s=l+1}var h=t._B[s]||0;return isFinite(h)?O(e,t._m2,h):0},D=function(e){var r=t._rangebreaks.length;if(!r)return z(e,t._m,t._b);for(var n=0,a=0;a<r&&!(e<t._rangebreaks[a].pmin);a++)e>t._rangebreaks[a].pmax&&(n=a+1);return z(e,t._m2,t._B[n])}}t.c2l="log"===t.type?M:c,t.l2c="log"===t.type?k:c,t.l2p=I,t.p2l=D,t.c2p="log"===t.type?function(t,e){return I(M(t,e))}:I,t.p2c="log"===t.type?function(t){return k(D(t))}:D,-1!==["linear","-"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=o,t.c2d=t.c2r=t.l2d=t.l2r=c,t.d2p=t.r2p=function(e){return t.l2p(o(e))},t.p2d=t.p2r=D,t.cleanPos=c):"log"===t.type?(t.d2r=t.d2l=function(t,e){return M(o(t),e)},t.r2d=t.r2c=function(t){return k(o(t))},t.d2c=t.r2l=o,t.c2d=t.l2r=c,t.c2r=M,t.l2d=k,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return k(D(t))},t.r2p=function(e){return t.l2p(o(e))},t.p2r=D,t.cleanPos=c):"date"===t.type?(t.d2r=t.r2d=i.identity,t.d2c=t.r2c=t.d2l=t.r2l=A,t.c2d=t.c2r=t.l2d=t.l2r=S,t.d2p=t.r2p=function(e,r,n){return t.l2p(A(e,0,n))},t.p2d=t.p2r=function(t,e,r){return S(D(t),e,r)},t.cleanPos=function(e){return i.cleanDate(e,p,t.calendar)}):"category"===t.type?(t.d2c=t.d2l=L,t.r2d=t.c2d=t.l2d=E,t.d2r=t.d2l_noadd=P,t.r2c=function(e){var r=P(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=c,t.r2l=P,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return E(D(t))},t.r2p=t.d2p,t.p2r=D,t.cleanPos=function(t){return"string"==typeof t&&""!==t?t:c(t)}):"multicategory"===t.type&&(t.r2d=t.c2d=t.l2d=E,t.d2r=t.d2l_noadd=P,t.r2c=function(e){var r=P(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=C,t.l2r=t.c2r=c,t.r2l=P,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return E(D(t))},t.r2p=t.d2p,t.p2r=D,t.cleanPos=function(t){return Array.isArray(t)||"string"==typeof t&&""!==t?t:c(t)},t.setupMultiCategory=function(n){var a,o,s=t._traceIndices,l=e._axisMatchGroups;if(l&&l.length&&0===t._categories.length)for(a=0;a<l.length;a++){var c=l[a];if(c[r])for(var f in c)if(f!==r){var p=e[x.id2name(f)];s=s.concat(p._traceIndices)}}var d=[[0,{}],[0,{}]],g=[];for(a=0;a<s.length;a++){var v=n[s[a]];if(h in v){var m=v[h],y=v._length||i.minRowLength(m);if(u(m[0])&&u(m[1]))for(o=0;o<y;o++){var b=m[0][o],_=m[1][o];T(b)&&T(_)&&(g.push([b,_]),b in d[0][1]||(d[0][1][b]=d[0][0]++),_ in d[1][1]||(d[1][1][_]=d[1][0]++))}}}for(g.sort(function(t,e){var r=d[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var a=d[1][1];return a[t[1]]-a[e[1]]}),a=0;a<g.length;a++)L(g[a])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,r){r||(r={}),e||(e="range");var n,o,s=i.nestedProperty(t,e).get();if(o=(o="date"===t.type?i.dfltRange(t.calendar):"y"===h?b.DFLTRANGEY:r.dfltRange||b.DFLTRANGEX).slice(),"tozero"!==t.rangemode&&"nonnegative"!==t.rangemode||(o[0]=0),s&&2===s.length)for("date"!==t.type||t.autorange||(s[0]=i.cleanDate(s[0],p,t.calendar),s[1]=i.cleanDate(s[1],p,t.calendar)),n=0;n<2;n++)if("date"===t.type){if(!i.isDateTime(s[n],t.calendar)){t[e]=o;break}if(t.r2l(s[0])===t.r2l(s[1])){var l=i.constrain(t.r2l(s[0]),i.MIN_MS+1e3,i.MAX_MS-1e3);s[0]=t.l2r(l-1e3),s[1]=t.l2r(l+1e3);break}}else{if(!a(s[n])){if(!a(s[1-n])){t[e]=o;break}s[n]=s[1-n]*(n?10:.1)}if(s[n]<-f?s[n]=-f:s[n]>f&&(s[n]=f),s[0]===s[1]){var c=Math.max(1,Math.abs(1e-6*s[0]));s[0]-=c,s[1]+=c}}else i.nestedProperty(t,e).set(o)},t.setScale=function(r){var n=e._size;if(t.overlaying){var a=x.getFromId({_fullLayout:e},t.overlaying);t.domain=a.domain}var i=r&&t._r?"_r":"range",o=t.calendar;t.cleanRange(i);var s,l,c=t.r2l(t[i][0],o),u=t.r2l(t[i][1],o),f="y"===h;if((f?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(c-u),t._b=-t._m*u):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(u-c),t._b=-t._m*c),t._rangebreaks=[],t._lBreaks=0,t._m2=0,t._B=[],t.rangebreaks)&&(t._rangebreaks=t.locateBreaks(Math.min(c,u),Math.max(c,u)),t._rangebreaks.length)){for(s=0;s<t._rangebreaks.length;s++)l=t._rangebreaks[s],t._lBreaks+=Math.abs(l.max-l.min);var p=f;c>u&&(p=!p),p&&t._rangebreaks.reverse();var d=p?-1:1;for(t._m2=d*t._length/(Math.abs(u-c)-t._lBreaks),t._B.push(-t._m2*(f?u:c)),s=0;s<t._rangebreaks.length;s++)l=t._rangebreaks[s],t._B.push(t._B[t._B.length-1]-d*t._m2*(l.max-l.min));for(s=0;s<t._rangebreaks.length;s++)(l=t._rangebreaks[s]).pmin=I(l.min),l.pmax=I(l.max)}if(!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error("Something went wrong with axis scaling")},t.maskBreaks=function(e){for(var r,n,a,s,l,c=t.rangebreaks||[],u=0;u<c.length;u++){var h=c[u];if(h.enabled)if(h.bounds){var f=h.pattern;switch(n=(r=i.simpleMap(h.bounds,f?o:t.d2c))[0],a=r[1],f){case w:s=(l=new Date(e)).getUTCDay(),n>a&&(a+=7,s<n&&(s+=7));break;case _:s=(l=new Date(e)).getUTCHours()+(l.getUTCMinutes()/60+l.getUTCSeconds()/3600+l.getUTCMilliseconds()/36e5),n>a&&(a+=24,s<n&&(s+=24));break;case"":s=e}if(s>=n&&s<a)return p}else for(var d=i.simpleMap(h.values,t.d2c).sort(i.sorterAsc),g=0;g<d.length;g++)if(a=(n=d[g])+h.dvalue,e>=n&&e<a)return p}return e},t.locateBreaks=function(e,r){var n,a,s,l,c=[];if(!t.rangebreaks)return c;var u=t.rangebreaks.slice().sort(function(t,e){return t.pattern===w&&e.pattern===_?-1:e.pattern===w&&t.pattern===_?1:0}),h=function(t,n){if((t=i.constrain(t,e,r))!==(n=i.constrain(n,e,r))){for(var a=!0,o=0;o<c.length;o++){var s=c[o];t>s.max||n<s.min||(t<s.min&&(s.min=t),n>s.max&&(s.max=n),a=!1)}a&&c.push({min:t,max:n})}};for(n=0;n<u.length;n++){var f=u[n];if(f.enabled)if(f.bounds){var p=e,d=r;f.pattern&&(p=Math.floor(p)),s=(a=i.simpleMap(f.bounds,f.pattern?o:t.r2l))[0],l=a[1];var x,b,k=new Date(p);switch(f.pattern){case w:b=7*g,x=(l-s+(l<s?7:0))*g,p+=s*g-(k.getUTCDay()*g+k.getUTCHours()*v+k.getUTCMinutes()*m+k.getUTCSeconds()*y+k.getUTCMilliseconds());break;case _:b=g,x=(l-s+(l<s?24:0))*v,p+=s*v-(k.getUTCHours()*v+k.getUTCMinutes()*m+k.getUTCSeconds()*y+k.getUTCMilliseconds());break;default:p=Math.min(a[0],a[1]),x=b=(d=Math.max(a[0],a[1]))-p}for(var T=p;T<d;T+=b)h(T,T+x)}else for(var M=i.simpleMap(f.values,t.d2c),A=0;A<M.length;A++)h(s=M[A],l=s+f.dvalue)}return c.sort(function(t,e){return t.min-e.min}),c},t.makeCalcdata=function(e,r){var n,a,o,s,l=t.type,c="date"===l&&e[r+"calendar"];if(r in e){if(n=e[r],s=e._length||i.minRowLength(n),i.isTypedArray(n)&&("linear"===l||"log"===l)){if(s===n.length)return n;if(n.subarray)return n.subarray(0,s)}if("multicategory"===l)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var a=(t[0]||[])[n],i=(t[1]||[])[n];r[n]=C([a,i])}return r}(n,s);for(a=new Array(s),o=0;o<s;o++)a[o]=t.d2c(n[o],0,c)}else{var u=r+"0"in e?t.d2c(e[r+"0"],0,c):0,h=e["d"+r]?Number(e["d"+r]):1;for(n=e[{x:"y",y:"x"}[r]],s=e._length||n.length,a=new Array(s),o=0;o<s;o++)a[o]=u+o*h}if(t.rangebreaks)for(o=0;o<s;o++)a[o]=t.maskBreaks(a[o]);return a},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&a(t.r2l(e[0]))&&a(t.r2l(e[1]))},t.isPtWithinRange=function(e,r){var n=t.c2l(e[h],null,r),a=t.r2l(t.range[0]),i=t.r2l(t.range[1]);return a<i?a<=n&&n<=i:i<=n&&n<=a},t.clearCalc=function(){var n=function(){t._categories=[],t._categoriesMap={}},a=e._axisMatchGroups;if(a&&a.length){for(var i=!1,o=0;o<a.length;o++){var s=a[o];if(s[r]){i=!0;var l=null,c=null;for(var u in s){var h=e[x.id2name(u)];if(h._categories){l=h._categories,c=h._categoriesMap;break}}l&&c?(t._categories=l,t._categoriesMap=c):n();break}}i||n()}else n();if(t._initialCategories)for(var f=0;f<t._initialCategories.length;f++)L(t._initialCategories[f])},t.sortByInitialCategories=function(){var n=[];if(t._categories=[],t._categoriesMap={},t._initialCategories)for(var a=0;a<t._initialCategories.length;a++)L(t._initialCategories[a]);n=n.concat(t._traceIndices);var i=t._matchGroup;for(var o in i)if(r!==o){var s=e[x.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var F=e._d3locale;"date"===t.type&&(t._dateFormat=F?F.timeFormat.utc:n.time.format.utc,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=F?F.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{"../../constants/numerical":693,"../../lib":717,"./axis_ids":768,"./constants":771,d3:165,"fast-isnumeric":228}],784:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes"),i=t("../array_container_defaults");function o(t){var e=["showexponent","showtickprefix","showticksuffix"].filter(function(e){return void 0!==t[e]});if(e.every(function(r){return t[r]===t[e[0]]})||1===e.length)return t[e[0]]}function s(t,e){function r(r,i){return n.coerce(t,e,a.tickformatstops,r,i)}r("enabled")&&(r("dtickrange"),r("value"))}e.exports=function(t,e,r,l,c,u){u&&1!==u.pass||function(t,e,r,n,a){var i=o(t);r("tickprefix")&&r("showtickprefix",i);r("ticksuffix",a.tickSuffixDflt)&&r("showticksuffix",i)}(t,0,r,0,c),u&&2!==u.pass||function(t,e,r,l,c){var u=o(t);r("tickprefix")&&r("showtickprefix",u);r("ticksuffix",c.tickSuffixDflt)&&r("showticksuffix",u);if(r("showticklabels")){var h=c.font||{},f=e.color,p=f&&f!==a.color.dflt?f:h.color;if(n.coerceFont(r,"tickfont",{family:h.family,size:h.size,color:p}),r("tickangle"),"category"!==l){var d=r("tickformat");i(t,e,{name:"tickformatstops",inclusionAttr:"enabled",handleItemDefaults:s}),e.tickformatstops.length||delete e.tickformatstops,d||"date"===l||(r("showexponent",u),r("exponentformat"),r("separatethousands"))}}}(t,e,r,l,c)}},{"../../lib":717,"../array_container_defaults":761,"./layout_attributes":777}],785:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e,r,i){var o=n.coerce2(t,e,a,"ticklen"),s=n.coerce2(t,e,a,"tickwidth"),l=n.coerce2(t,e,a,"tickcolor",e.color);r("ticks",i.outerTicks||o||s||l?"outside":"")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{"../../lib":717,"./layout_attributes":777}],786:[function(t,e,r){"use strict";var n=t("./clean_ticks");e.exports=function(t,e,r,a){function i(r){var n=t[r];return void 0!==n?n:(e._template||{})[r]}var o,s=i("tick0"),l=i("dtick"),c=i("tickvals");"array"!==i("tickmode")||"log"!==a&&"date"!==a?o=r("tickmode",Array.isArray(c)?"array":l?"linear":"auto"):o=e.tickmode="auto";if("auto"===o)r("nticks");else if("linear"===o){var u=e.dtick=n.dtick(l,a);e.tick0=n.tick0(s,a,e.calendar,u)}else if("multicategory"!==a){void 0===r("tickvals")?e.tickmode="auto":r("ticktext")}}},{"./clean_ticks":770}],787:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../lib"),o=t("../../components/drawing"),s=t("./axes");e.exports=function(t,e,r,l){var c=t._fullLayout;if(0!==e.length){var u,h,f,p;l&&(u=l());var d=n.ease(r.easing);return t._transitionData._interruptCallbacks.push(function(){return window.cancelAnimationFrame(p),p=null,function(){for(var r={},n=0;n<e.length;n++){var i=e[n],o=i.plotinfo.xaxis,s=i.plotinfo.yaxis;i.xr0&&(r[o._name+".range"]=i.xr0.slice()),i.yr0&&(r[s._name+".range"]=i.yr0.slice())}return a.call("relayout",t,r).then(function(){for(var t=0;t<e.length;t++)g(e[t].plotinfo)})}()}),h=Date.now(),p=window.requestAnimationFrame(function n(){f=Date.now();for(var i=Math.min(1,(f-h)/r.duration),o=d(i),s=0;s<e.length;s++)v(e[s],o);f-h>r.duration?(function(){for(var r={},n=0;n<e.length;n++){var i=e[n],o=i.plotinfo.xaxis,s=i.plotinfo.yaxis;i.xr1&&(r[o._name+".range"]=i.xr1.slice()),i.yr1&&(r[s._name+".range"]=i.yr1.slice())}u&&u(),a.call("relayout",t,r).then(function(){for(var t=0;t<e.length;t++)g(e[t].plotinfo)})}(),p=window.cancelAnimationFrame(n)):p=window.requestAnimationFrame(n)}),Promise.resolve()}function g(t){var e=t.xaxis,r=t.yaxis;c._defs.select("#"+t.clipId+"> rect").call(o.setTranslate,0,0).call(o.setScale,1,1),t.plot.call(o.setTranslate,e._offset,r._offset).call(o.setScale,1,1);var n=t.plot.selectAll(".scatterlayer .trace");n.selectAll(".point").call(o.setPointGroupScale,1,1),n.selectAll(".textpoint").call(o.setTextPointsScale,1,1),n.call(o.hideOutsideRangePoints,t)}function v(e,r){var n=e.plotinfo,a=n.xaxis,l=n.yaxis,c=a._length,u=l._length,h=!!e.xr1,f=!!e.yr1,p=[];if(h){var d=i.simpleMap(e.xr0,a.r2l),g=i.simpleMap(e.xr1,a.r2l),v=d[1]-d[0],m=g[1]-g[0];p[0]=(d[0]*(1-r)+r*g[0]-d[0])/(d[1]-d[0])*c,p[2]=c*(1-r+r*m/v),a.range[0]=a.l2r(d[0]*(1-r)+r*g[0]),a.range[1]=a.l2r(d[1]*(1-r)+r*g[1])}else p[0]=0,p[2]=c;if(f){var y=i.simpleMap(e.yr0,l.r2l),x=i.simpleMap(e.yr1,l.r2l),b=y[1]-y[0],_=x[1]-x[0];p[1]=(y[1]*(1-r)+r*x[1]-y[1])/(y[0]-y[1])*u,p[3]=u*(1-r+r*_/b),l.range[0]=a.l2r(y[0]*(1-r)+r*x[0]),l.range[1]=l.l2r(y[1]*(1-r)+r*x[1])}else p[1]=0,p[3]=u;s.drawOne(t,a,{skipTitle:!0}),s.drawOne(t,l,{skipTitle:!0}),s.redrawComponents(t,[a._id,l._id]);var w=h?c/p[2]:1,k=f?u/p[3]:1,T=h?p[0]:0,M=f?p[1]:0,A=h?p[0]/p[2]*c:0,S=f?p[1]/p[3]*u:0,E=a._offset-A,L=l._offset-S;n.clipRect.call(o.setTranslate,T,M).call(o.setScale,1/w,1/k),n.plot.call(o.setTranslate,E,L).call(o.setScale,w,k),o.setPointGroupScale(n.zoomScalePts,1/w,1/k),o.setTextPointsScale(n.zoomScaleTxt,1/w,1/k)}s.redrawComponents(t)}},{"../../components/drawing":612,"../../lib":717,"../../registry":846,"./axes":765,d3:165}],788:[function(t,e,r){"use strict";var n=t("../../registry").traceIs,a=t("./axis_autotype");function i(t){return{v:"x",h:"y"}[t.orientation||"v"]}function o(t,e){var r=i(t),a=n(t,"box-violin"),o=n(t._fullInput||{},"candlestick");return a&&!o&&e===r&&void 0===t[r]&&void 0===t[r+"0"]}e.exports=function(t,e,r,s){"-"===r("type",(s.splomStash||{}).type)&&(!function(t,e){if("-"!==t.type)return;var r,s=t._id,l=s.charAt(0);-1!==s.indexOf("scene")&&(s=l);var c=function(t,e,r){for(var n=0;n<t.length;n++){var a=t[n];if("splom"===a.type&&a._length>0&&(a["_"+r+"axes"]||{})[e])return a;if((a[r+"axis"]||r)===e){if(o(a,r))return a;if((a[r]||[]).length||a[r+"0"])return a}}}(e,s,l);if(!c)return;if("histogram"===c.type&&l==={v:"y",h:"x"}[c.orientation||"v"])return void(t.type="linear");var u=l+"calendar",h=c[u],f={noMultiCategory:!n(c,"cartesian")||n(c,"noMultiCategory")};"box"===c.type&&c._hasPreCompStats&&l==={h:"x",v:"y"}[c.orientation||"v"]&&(f.noMultiCategory=!0);if(o(c,l)){var p=i(c),d=[];for(r=0;r<e.length;r++){var g=e[r];n(g,"box-violin")&&(g[l+"axis"]||l)===s&&(void 0!==g[p]?d.push(g[p][0]):void 0!==g.name?d.push(g.name):d.push("text"),g[u]!==h&&(h=void 0))}t.type=a(d,h,f)}else if("splom"===c.type){var v=c.dimensions,m=v[c._axesDim[s]];m.visible&&(t.type=a(m.values,h,f))}else t.type=a(c[l]||[c[l+"0"]],h,f)}(e,s.data),"-"===e.type?e.type="linear":t.type=e.type)}},{"../../registry":846,"./axis_autotype":766}],789:[function(t,e,r){"use strict";var n=t("../registry"),a=t("../lib");function i(t,e,r){var n,i,o,s=!1;if("data"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if("layout"!==e.type)return!1;n=t._fullLayout}return i=a.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==i&&(s=!0),o[e.prop]=i,{changed:s,value:i}}function o(t,e){var r=[],n=e[0],i={};if("string"==typeof n)i[n]=e[1];else{if(!a.isPlainObject(n))return r;i=n}return l(i,function(t,e,n){r.push({type:"layout",prop:t,value:n})},"",0),r}function s(t,e){var r,n,i,o,s=[];if(n=e[0],i=e[1],r=e[2],o={},"string"==typeof n)o[n]=i;else{if(!a.isPlainObject(n))return s;o=n,void 0===r&&(r=i)}return void 0===r&&(r=null),l(o,function(e,n,a){var i,o;if(Array.isArray(a)){o=a.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),i=[];for(var c=0;c<l;c++)i[c]=r?r[c]:c}else o=a,i=r?r.slice():null;if(null===i)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(i)){if(!Array.isArray(o)){var u=o;o=[];for(var h=0;h<i.length;h++)o[h]=u}o.length=Math.min(i.length,o.length)}s.push({type:"data",prop:e,traces:i,value:o})},"",0),s}function l(t,e,r,n){Object.keys(t).forEach(function(i){var o=t[i];if("_"!==i[0]){var s=r+(n>0?".":"")+i;a.isPlainObject(o)?l(o,e,s,n+1):e(s,i,o)}})}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){i(t,c,s.cache),s.check=function(){if(l){var e=i(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=["plotly_relayout","plotly_redraw","plotly_restyle","plotly_update","plotly_animatingframe","plotly_afterplot"],h=0;h<u.length;h++)t._internalOn(u[h],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else a.log("Unable to automatically bind plot updates to API command"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var a,i,o=e.length;for(a=0;a<o;a++){var s,l=e[a],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var h=r.computeAPICommandBindings(t,c,u);if(1!==h.length)return!1;if(i){if((s=h[0]).type!==i.type)return!1;if(s.prop!==i.prop)return!1;if(Array.isArray(i.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var f=0;f<i.traces.length;f++)if(i.traces[f]!==s.traces[f])return!1}else if(s.prop!==i.prop)return!1}else i=h[0],Array.isArray(i.traces)&&i.traces.sort();var p=(s=h[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=a)}return i},r.executeAPICommand=function(t,e,r){if("skip"===e)return Promise.resolve();var i=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return i.apply(null,o).catch(function(t){return a.warn("API call to Plotly."+e+" rejected.",t),Promise.reject(t)})},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case"restyle":n=s(t,r);break;case"relayout":n=o(t,r);break;case"update":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case"animate":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==["string","number"].indexOf(typeof e[0][0])?[{type:"layout",prop:"_currentFrame",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{"../lib":717,"../registry":846}],790:[function(t,e,r){"use strict";var n=t("../lib/extend").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:"info_array",editType:(t=t||{}).editType,items:[{valType:"number",min:0,max:1,editType:t.editType},{valType:"number",min:0,max:1,editType:t.editType}],dflt:[0,1]},a=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(a.row={valType:"integer",min:0,dflt:0,editType:t.editType},a.column={valType:"integer",min:0,dflt:0,editType:t.editType}),a},r.defaults=function(t,e,r,n){var a=n&&n.x||[0,1],i=n&&n.y||[0,1],o=e.grid;if(o){var s=r("domain.column");void 0!==s&&(s<o.columns?a=o._domains.x[s]:delete t.domain.column);var l=r("domain.row");void 0!==l&&(l<o.rows?i=o._domains.y[l]:delete t.domain.row)}var c=r("domain.x",a),u=r("domain.y",i);c[0]<c[1]||(t.domain.x=a.slice()),u[0]<u[1]||(t.domain.y=i.slice())}},{"../lib/extend":708}],791:[function(t,e,r){"use strict";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:"string",noBlank:!0,strict:!0,editType:e},size:{valType:"number",min:1,editType:e},color:{valType:"color",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],792:[function(t,e,r){"use strict";e.exports={_isLinkedToArray:"frames_entry",group:{valType:"string"},name:{valType:"string"},traces:{valType:"any"},baseframe:{valType:"string"},data:{valType:"any"},layout:{valType:"any"}}},{}],793:[function(t,e,r){"use strict";r.projNames={equirectangular:"equirectangular",mercator:"mercator",orthographic:"orthographic","natural earth":"naturalEarth",kavrayskiy7:"kavrayskiy7",miller:"miller",robinson:"robinson",eckert4:"eckert4","azimuthal equal area":"azimuthalEqualArea","azimuthal equidistant":"azimuthalEquidistant","conic equal area":"conicEqualArea","conic conformal":"conicConformal","conic equidistant":"conicEquidistant",gnomonic:"gnomonic",stereographic:"stereographic",mollweide:"mollweide",hammer:"hammer","transverse mercator":"transverseMercator","albers usa":"albersUsa","winkel tripel":"winkel3",aitoff:"aitoff",sinusoidal:"sinusoidal"},r.axesNames=["lonaxis","lataxis"],r.lonaxisSpan={orthographic:180,"azimuthal equal area":360,"azimuthal equidistant":360,"conic conformal":180,gnomonic:160,stereographic:180,"transverse mercator":180,"*":360},r.lataxisSpan={"conic conformal":150,stereographic:179.5,"*":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:"equirectangular",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:"albers usa"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:"conic conformal",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:"mercator",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:"mercator",projRotate:[0,0,0]},"north america":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:"conic conformal",projRotate:[-100,0,0],projParallels:[29.5,45.5]},"south america":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:"mercator",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor="#F0DC82",r.waterColor="#3399FF",r.locationmodeToLayer={"ISO-3":"countries","USA-states":"subunits","country names":"countries"},r.sphereSVG={type:"Sphere"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=["bg","ocean","land","lakes","subunits","countries","coastlines","rivers","lataxis","lonaxis","frame","backplot","frontplot"],r.layersForChoropleth=["bg","ocean","land","subunits","countries","coastlines","lataxis","lonaxis","frame","backplot","rivers","lakes","frontplot"],r.layerNameToAdjective={ocean:"ocean",land:"land",lakes:"lake",subunits:"subunit",countries:"country",coastlines:"coastline",rivers:"river",frame:"frame"}},{}],794:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../lib"),o=t("../../components/color"),s=t("../../components/drawing"),l=t("../../components/fx"),c=t("../plots"),u=t("../cartesian/axes"),h=t("../cartesian/autorange").getAutoRange,f=t("../../components/dragelement"),p=t("../cartesian/select").prepSelect,d=t("../cartesian/select").selectOnClick,g=t("./zoom"),v=t("./constants"),m=t("../../lib/geo_location_utils"),y=t("../../lib/topojson_utils"),x=t("topojson-client").feature;function b(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t("./projections")(n);var _=b.prototype;function w(t,e){var r=v.clipPad,n=t[0]+r,a=t[1]-r,i=e[0]+r,o=e[1]-r;n>0&&a<0&&(a+=360);var s=(a-n)/4;return{type:"Polygon",coordinates:[[[n,i],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[a,o],[a,i],[a-s,i],[a-2*s,i],[a-3*s,i],[n,i]]]}}e.exports=function(t){return new b(t)},_.plot=function(t,e,r){var n=this,a=e[this.id],i=[],o=!1;for(var s in v.layerNameToAdjective)if("frame"!==s&&a["show"+s]){o=!0;break}for(var l=0;l<t.length;l++)if(t[0][0].trace.locationmode){o=!0;break}if(o){var c=y.getTopojsonName(a);null!==n.topojson&&c===n.topojsonName||(n.topojsonName=c,void 0===PlotlyGeoAssets.topojson[n.topojsonName]&&i.push(n.fetchTopojson()))}i=i.concat(m.fetchTraceGeoData(t)),r.push(new Promise(function(r,a){Promise.all(i).then(function(){n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e),r()}).catch(a)}))},_.fetchTopojson=function(){var t=this,e=y.getTopojsonPath(t.topojsonURL,t.topojsonName);return new Promise(function(r,a){n.json(e,function(n,i){if(n)return 404===n.status?a(new Error(["plotly.js could not find topojson file at",e,".","Make sure the *topojsonURL* plot config option","is set properly."].join(" "))):a(new Error(["unexpected error while fetching topojson file at",e].join(" ")));PlotlyGeoAssets.topojson[t.topojsonName]=i,r()})})},_.update=function(t,e){var r=e[this.id];this.hasChoropleth=!1;for(var n=0;n<t.length;n++){var a=t[n],i=a[0].trace;"choropleth"===i.type&&(this.hasChoropleth=!0),!0===i.visible&&i._length>0&&i._module.calcGeoJSON(a,e)}if(!this.updateProjection(t,e)){this.viewInitial&&this.scope===r.scope||this.saveViewInitial(r),this.scope=r.scope,this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),c.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var o=this.layers.frontplot.select(".scatterlayer");this.dataPoints.point=o.selectAll(".point"),this.dataPoints.text=o.selectAll("text"),this.dataPaths.line=o.selectAll(".js-line");var s=this.layers.backplot.select(".choroplethlayer");this.dataPaths.choropleth=s.selectAll("path"),this.render()}},_.updateProjection=function(t,e){var r=this.graphDiv,o=e[this.id],s=e._size,l=o.domain,c=o.projection,u=o.lonaxis,f=o.lataxis,p=u._ax,d=f._ax,g=this.projection=function(t){for(var e=t.projection.type,r=n.geo[v.projNames[e]](),a=t._isClipped?v.lonaxisSpan[e]/2:null,i=["center","rotate","parallels","clipExtent"],o=function(t){return t?r:[]},s=0;s<i.length;s++){var l=i[s];"function"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(a){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>a*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],a=t[1][1]-t[0][1],i=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),i&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),a/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(a-s*(o[1][1]+o[0][1]))/2;return i&&r.clipExtent(i),r.scale(150*s).translate([l,c])},r.precision(v.precision),a&&r.clipAngle(a-v.clipPad);return r}(o),m=[[s.l+s.w*l.x[0],s.t+s.h*(1-l.y[1])],[s.l+s.w*l.x[1],s.t+s.h*(1-l.y[0])]],y=o.center||{},x=c.rotation||{},b=u.range||[],_=f.range||[];if(o.fitbounds){p._length=m[1][0]-m[0][0],d._length=m[1][1]-m[0][1],p.range=h(r,p),d.range=h(r,d);var k=(p.range[0]+p.range[1])/2,T=(d.range[0]+d.range[1])/2;if(o._isScoped)y={lon:k,lat:T};else if(o._isClipped){y={lon:k,lat:T},x={lon:k,lat:T,roll:x.roll};var M=c.type,A=v.lonaxisSpan[M]/2||180,S=v.lataxisSpan[M]/2||180;b=[k-A,k+A],_=[T-S,T+S]}else y={lon:k,lat:T},x={lon:k,lat:x.lat,roll:x.roll}}g.center([y.lon-x.lon,y.lat-x.lat]).rotate([-x.lon,-x.lat,x.roll]).parallels(c.parallels);var E=w(b,_);g.fitExtent(m,E);var L=this.bounds=g.getBounds(E),C=this.fitScale=g.scale(),P=g.translate();if(!isFinite(L[0][0])||!isFinite(L[0][1])||!isFinite(L[1][0])||!isFinite(L[1][1])||isNaN(P[0])||isNaN(P[0])){for(var O=["fitbounds","projection.rotation","center","lonaxis.range","lataxis.range"],z="Invalid geo settings, relayout'ing to default view.",I={},D=0;D<O.length;D++)I[this.id+"."+O[D]]=null;return this.viewInitial=null,i.warn(z),r._promises.push(a.call("relayout",r,I)),z}if(o.fitbounds){var R=g.getBounds(w(p.range,d.range)),F=Math.min((L[1][0]-L[0][0])/(R[1][0]-R[0][0]),(L[1][1]-L[0][1])/(R[1][1]-R[0][1]));isFinite(F)?g.scale(F*C):i.warn("Something went wrong during"+this.id+"fitbounds computations.")}else g.scale(c.scale*C);var B=this.midPt=[(L[0][0]+L[1][0])/2,(L[0][1]+L[1][1])/2];if(g.translate([P[0]+(B[0]-P[0]),P[1]+(B[1]-P[1])]).clipExtent(L),o._isAlbersUsa){var N=g([y.lon,y.lat]),j=g.translate();g.translate([j[0]-(N[0]-j[0]),j[1]-(N[1]-j[1])])}},_.updateBaseLayers=function(t,e){var r=this,a=r.topojson,i=r.layers,l=r.basePaths;function c(t){return"lonaxis"===t||"lataxis"===t}function h(t){return Boolean(v.lineLayers[t])}function f(t){return Boolean(v.fillLayers[t])}var p=(this.hasChoropleth?v.layersForChoropleth:v.layers).filter(function(t){return h(t)||f(t)?e["show"+t]:!c(t)||e[t].showgrid}),d=r.framework.selectAll(".layer").data(p,String);d.exit().each(function(t){delete i[t],delete l[t],n.select(this).remove()}),d.enter().append("g").attr("class",function(t){return"layer "+t}).each(function(t){var e=i[t]=n.select(this);"bg"===t?r.bgRect=e.append("rect").style("pointer-events","all"):c(t)?l[t]=e.append("path").style("fill","none"):"backplot"===t?e.append("g").classed("choroplethlayer",!0):"frontplot"===t?e.append("g").classed("scatterlayer",!0):h(t)?l[t]=e.append("path").style("fill","none").style("stroke-miterlimit",2):f(t)&&(l[t]=e.append("path").style("stroke","none"))}),d.order(),d.each(function(r){var n=l[r],i=v.layerNameToAdjective[r];"frame"===r?n.datum(v.sphereSVG):h(r)||f(r)?n.datum(x(a,a.objects[r])):c(r)&&n.datum(function(t,e,r){var n,a,i,o=e[t],s=v.scopeDefaults[e.scope];"lonaxis"===t?(n=s.lonaxisRange,a=s.lataxisRange,i=function(t,e){return[t,e]}):"lataxis"===t&&(n=s.lataxisRange,a=s.lonaxisRange,i=function(t,e){return[e,t]});var l={type:"linear",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};u.setConvert(l,r);var c=u.calcTicks(l);e.isScoped||"lonaxis"!==t||c.pop();for(var h=c.length,f=new Array(h),p=0;p<h;p++)for(var d=c[p].x,g=f[p]=[],m=a[0];m<a[1]+2.5;m+=2.5)g.push(i(d,m));return{type:"MultiLineString",coordinates:f}}(r,e,t)).call(o.stroke,e[r].gridcolor).call(s.dashLine,"",e[r].gridwidth),h(r)?n.call(o.stroke,e[i+"color"]).call(s.dashLine,"",e[i+"width"]):f(r)&&n.call(o.fill,e[i+"color"])})},_.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,a=r[0][0]-n,i=r[0][1]-n,l=r[1][0]-a+n,c=r[1][1]-i+n;s.setRect(this.clipRect,a,i,l,c),this.bgRect.call(s.setRect,a,i,l,c).call(o.fill,e.bgcolor),this.xaxis._offset=a,this.xaxis._length=l,this.yaxis._offset=i,this.yaxis._length=c},_.updateFx=function(t,e){var r=this,i=r.graphDiv,o=r.bgRect,s=t.dragmode,c=t.clickmode;if(!r.isStatic){var u;"select"===s?u=function(t,e){(t.range={})[r.id]=[v([e.xmin,e.ymin]),v([e.xmax,e.ymax])]}:"lasso"===s&&(u=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(v)});var h={element:r.bgRect.node(),gd:i,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:u},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(e){2===e&&t._zoomlayer.selectAll(".select-outline").remove()}};"pan"===s?(o.node().onmousedown=null,o.call(g(r,e)),o.on("dblclick.zoom",function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+"."+n]=t[n];a.call("_guiRelayout",i,e),i.emit("plotly_doubleclick",null)}),i._context._scrollZoom.geo||o.on("wheel.zoom",null)):"select"!==s&&"lasso"!==s||(o.on(".zoom",null),h.prepFn=function(t,e,r){p(t,e,r,h,s)},f.init(h)),o.on("mousemove",function(){var t=r.projection.invert(n.mouse(this));if(!t||isNaN(t[0])||isNaN(t[1]))return f.unhover(i,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},l.hover(i,n.event,r.id)}),o.on("mouseout",function(){i._dragging||f.unhover(i,n.event)}),o.on("click",function(){"select"!==s&&"lasso"!==s&&(c.indexOf("select")>-1&&d(n.event,i,[r.xaxis],[r.yaxis],r.id,h),c.indexOf("event")>-1&&l.click(i,n.event))})}function v(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},_.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,a="clip"+r._uid+t.id;t.clipDef=r._clips.append("clipPath").attr("id",a),t.clipRect=t.clipDef.append("rect"),t.framework=n.select(t.container).append("g").attr("class","geo "+t.id).call(s.setClipUrl,a,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:"x",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:"y",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:"linear",showexponent:"all",exponentformat:"B"},u.setConvert(t.mockAxis,r)},_.saveViewInitial=function(t){var e,r=t.center||{},n=t.projection,a=n.rotation||{};this.viewInitial={fitbounds:t.fitbounds,"projection.scale":n.scale},e=t._isScoped?{"center.lon":r.lon,"center.lat":r.lat}:t._isClipped?{"projection.rotation.lon":a.lon,"projection.rotation.lat":a.lat}:{"center.lon":r.lon,"center.lat":r.lat,"projection.rotation.lon":a.lon},i.extendFlat(this.viewInitial,e)},_.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?"translate("+r[0]+","+r[1]+")":null}function a(t){return e.isLonLatOverEdges(t.lonlat)?"none":null}for(t in this.basePaths)this.basePaths[t].attr("d",r);for(t in this.dataPaths)this.dataPaths[t].attr("d",function(t){return r(t.geojson)});for(t in this.dataPoints)this.dataPoints[t].attr("display",a).attr("transform",n)}},{"../../components/color":591,"../../components/dragelement":609,"../../components/drawing":612,"../../components/fx":630,"../../lib":717,"../../lib/geo_location_utils":711,"../../lib/topojson_utils":744,"../../registry":846,"../cartesian/autorange":764,"../cartesian/axes":765,"../cartesian/select":782,"../plots":826,"./constants":793,"./projections":798,"./zoom":799,d3:165,"topojson-client":538}],795:[function(t,e,r){"use strict";var n=t("../../plots/get_data").getSubplotCalcData,a=t("../../lib").counterRegex,i=t("./geo"),o="geo",s=a(o),l={};l[o]={valType:"subplotid",dflt:o,editType:"calc"},e.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:t("./layout_attributes"),supplyLayoutDefaults:t("./layout_defaults"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots[o],s=0;s<a.length;s++){var l=a[s],c=n(r,o,l),u=e[l]._subplot;u||(u=i({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots[o],n=0;n<r.length;n++){var a=e[r[n]];a._subplot.updateFx(e,a)}},clean:function(t,e,r,n){for(var a=n._subplots[o]||[],i=0;i<a.length;i++){var s=a[i],l=n[s]._subplot;!e[s]&&l&&(l.framework.remove(),l.clipDef.remove())}}}},{"../../lib":717,"../../plots/get_data":800,"./geo":794,"./layout_attributes":796,"./layout_defaults":797}],796:[function(t,e,r){"use strict";var n=t("../../components/color/attributes"),a=t("../domain").attributes,i=t("./constants"),o=t("../../plot_api/edit_types").overrideAll,s={range:{valType:"info_array",items:[{valType:"number"},{valType:"number"}]},showgrid:{valType:"boolean",dflt:!1},tick0:{valType:"number",dflt:0},dtick:{valType:"number"},gridcolor:{valType:"color",dflt:n.lightLine},gridwidth:{valType:"number",min:0,dflt:1}};(e.exports=o({domain:a({name:"geo"},{}),fitbounds:{valType:"enumerated",values:[!1,"locations","geojson"],dflt:!1,editType:"plot"},resolution:{valType:"enumerated",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:"enumerated",values:Object.keys(i.scopeDefaults),dflt:"world"},projection:{type:{valType:"enumerated",values:Object.keys(i.projNames)},rotation:{lon:{valType:"number"},lat:{valType:"number"},roll:{valType:"number"}},parallels:{valType:"info_array",items:[{valType:"number"},{valType:"number"}]},scale:{valType:"number",min:0,dflt:1}},center:{lon:{valType:"number"},lat:{valType:"number"}},visible:{valType:"boolean",dflt:!0},showcoastlines:{valType:"boolean"},coastlinecolor:{valType:"color",dflt:n.defaultLine},coastlinewidth:{valType:"number",min:0,dflt:1},showland:{valType:"boolean",dflt:!1},landcolor:{valType:"color",dflt:i.landColor},showocean:{valType:"boolean",dflt:!1},oceancolor:{valType:"color",dflt:i.waterColor},showlakes:{valType:"boolean",dflt:!1},lakecolor:{valType:"color",dflt:i.waterColor},showrivers:{valType:"boolean",dflt:!1},rivercolor:{valType:"color",dflt:i.waterColor},riverwidth:{valType:"number",min:0,dflt:1},showcountries:{valType:"boolean"},countrycolor:{valType:"color",dflt:n.defaultLine},countrywidth:{valType:"number",min:0,dflt:1},showsubunits:{valType:"boolean"},subunitcolor:{valType:"color",dflt:n.defaultLine},subunitwidth:{valType:"number",min:0,dflt:1},showframe:{valType:"boolean"},framecolor:{valType:"color",dflt:n.defaultLine},framewidth:{valType:"number",min:0,dflt:1},bgcolor:{valType:"color",dflt:n.background},lonaxis:s,lataxis:s},"plot","from-root")).uirevision={valType:"any",editType:"none"}},{"../../components/color/attributes":590,"../../plot_api/edit_types":748,"../domain":790,"./constants":793}],797:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../subplot_defaults"),i=t("../get_data").getSubplotData,o=t("./constants"),s=t("./layout_attributes"),l=o.axesNames;function c(t,e,r,a){var s=i(a.fullData,"geo",a.id).map(function(t){return t._expandedIndex}),c=r("resolution"),u=r("scope"),h=o.scopeDefaults[u],f=r("projection.type",h.projType),p=e._isAlbersUsa="albers usa"===f;p&&(u=e.scope="usa");var d=e._isScoped="world"!==u,g=e._isConic=-1!==f.indexOf("conic"),v=e._isClipped=!!o.lonaxisSpan[f];if(!1===t.visible){var m=n.extendDeep({},e._template);m.showcoastlines=!1,m.showcountries=!1,m.showframe=!1,m.showlakes=!1,m.showland=!1,m.showocean=!1,m.showrivers=!1,m.showsubunits=!1,m.lonaxis&&(m.lonaxis.showgrid=!1),m.lataxis&&(m.lataxis.showgrid=!1),e._template=m}for(var y=r("visible"),x=0;x<l.length;x++){var b,_=l[x],w=[30,10][x];if(d)b=h[_+"Range"];else{var k=o[_+"Span"],T=(k[f]||k["*"])/2,M=r("projection.rotation."+_.substr(0,3),h.projRotate[x]);b=[M-T,M+T]}var A=r(_+".range",b);r(_+".tick0"),r(_+".dtick",w),r(_+".showgrid",!!y&&void 0)&&(r(_+".gridcolor"),r(_+".gridwidth")),e[_]._ax={type:"linear",_id:_.slice(0,3),_traceIndices:s,setScale:n.identity,c2l:n.identity,r2l:n.identity,autorange:!0,range:A.slice(),_m:1,_input:{}}}var S=e.lonaxis.range,E=e.lataxis.range,L=S[0],C=S[1];L>0&&C<0&&(C+=360);var P,O,z,I=(L+C)/2;if(!p){var D=d?h.projRotate:[I,0,0];P=r("projection.rotation.lon",D[0]),r("projection.rotation.lat",D[1]),r("projection.rotation.roll",D[2]),r("showcoastlines",!d&&y)&&(r("coastlinecolor"),r("coastlinewidth")),r("showocean",!!y&&void 0)&&r("oceancolor")}(p?(O=-96.6,z=38.7):(O=d?I:P,z=(E[0]+E[1])/2),r("center.lon",O),r("center.lat",z),g)&&r("projection.parallels",h.projParallels||[0,60]);r("projection.scale"),r("showland",!!y&&void 0)&&r("landcolor"),r("showlakes",!!y&&void 0)&&r("lakecolor"),r("showrivers",!!y&&void 0)&&(r("rivercolor"),r("riverwidth")),r("showcountries",d&&"usa"!==u&&y)&&(r("countrycolor"),r("countrywidth")),("usa"===u||"north america"===u&&50===c)&&(r("showsubunits",y),r("subunitcolor"),r("subunitwidth")),d||r("showframe",y)&&(r("framecolor"),r("framewidth")),r("bgcolor"),r("fitbounds")&&(delete e.projection.scale,d?(delete e.center.lon,delete e.center.lat):v?(delete e.center.lon,delete e.center.lat,delete e.projection.rotation.lon,delete e.projection.rotation.lat,delete e.lonaxis.range,delete e.lataxis.range):(delete e.center.lon,delete e.center.lat,delete e.projection.rotation.lon))}e.exports=function(t,e,r){a(t,e,r,{type:"geo",attributes:s,handleDefaults:c,fullData:r,partition:"y"})}},{"../../lib":717,"../get_data":800,"../subplot_defaults":840,"./constants":793,"./layout_attributes":796}],798:[function(t,e,r){"use strict";e.exports=function(t){function e(t,e){return{type:"Feature",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if("GeometryCollection"===e.type)return{type:"GeometryCollection",geometries:object.geometries.map(function(t){return r(t,n)})};if(!c.hasOwnProperty(e.type))return null;var a=c[e.type];return t.geo.stream(e,n(a)),a.result()}t.geo.project=function(t,e){var a=e.stream;if(!a)throw new Error("not yet supported");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,a)};var n={Feature:e,FeatureCollection:function(t,r){return{type:"FeatureCollection",features:t.features.map(function(t){return e(t,r)})}}},a=[],i=[],o={point:function(t,e){a.push([t,e])},result:function(){var t=a.length?a.length<2?{type:"Point",coordinates:a[0]}:{type:"MultiPoint",coordinates:a}:null;return a=[],t}},s={lineStart:u,point:function(t,e){a.push([t,e])},lineEnd:function(){a.length&&(i.push(a),a=[])},result:function(){var t=i.length?i.length<2?{type:"LineString",coordinates:i[0]}:{type:"MultiLineString",coordinates:i}:null;return i=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){a.push([t,e])},lineEnd:function(){var t=a.length;if(t){do{a.push(a[0].slice())}while(++t<4);i.push(a),a=[]}},polygonEnd:u,result:function(){if(!i.length)return null;var t=[],e=[];return i.forEach(function(r){!function(t){if((e=t.length)<4)return!1;for(var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])}),e.forEach(function(e){var r=e[0];t.some(function(t){if(function(t,e){for(var r=e[0],n=e[1],a=!1,i=0,o=t.length,s=o-1;i<o;s=i++){var l=t[i],c=l[0],u=l[1],h=t[s],f=h[0],p=h[1];u>n^p>n&&r<(f-c)*(n-u)/(p-u)+c&&(a=!a)}return a}(t[0],r))return t.push(e),!0})||t.push([e])}),i=[],t.length?t.length>1?{type:"MultiPolygon",coordinates:t}:{type:"Polygon",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var h=1e-6,f=h*h,p=Math.PI,d=p/2,g=(Math.sqrt(p),p/180),v=180/p;function m(t){return t>1?d:t<-1?-d:Math.asin(t)}function y(t){return t>1?0:t<-1?p:Math.acos(t)}var x=t.geo.projection,b=t.geo.projectionMutator;function _(t,e){var r=(2+d)*Math.sin(e);e/=2;for(var n=0,a=1/0;n<10&&Math.abs(a)>h;n++){var i=Math.cos(e);e-=a=(e+Math.sin(e)*(i+2)-r)/(2*i*(1+i))}return[2/Math.sqrt(p*(4+p))*t*(1+Math.cos(e)),2*Math.sqrt(p/(4+p))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-p,0],[0,d],[p,0]]],[[[-p,0],[0,-d],[p,0]]]];function a(t,r){for(var a=r<0?-1:1,i=n[+(r<0)],o=0,s=i.length-1;o<s&&t>i[o][2][0];++o);var l=e(t-i[o][1][0],r);return l[0]+=e(i[o][1][0],a*r>a*i[o][0][1]?i[o][0][1]:r)[0],l}e.invert&&(a.invert=function(t,i){for(var o=r[+(i<0)],s=n[+(i<0)],c=0,u=o.length;c<u;++c){var h=o[c];if(h[0][0]<=t&&t<h[1][0]&&h[0][1]<=i&&i<h[1][1]){var f=e.invert(t-e(s[c][1][0],0)[0],i);return f[0]+=s[c][1][0],l(a(f[0],f[1]),[t,i])?f:null}}});var i=t.geo.projection(a),o=i.stream;function s(t,e){for(var r,n,a,i=-1,o=t.length,s=t[0],l=[];++i<o;){n=((r=t[i])[0]-s[0])/e,a=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*a]);s=r}return l.push(r),l}function l(t,e){return Math.abs(t[0]-e[0])<h&&Math.abs(t[1]-e[1])<h}return i.stream=function(e){var r=i.rotate(),a=o(e),l=(i.rotate([0,0]),o(e));return i.rotate(r),a.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],a=0,i=n[0].length;a<i;++a){var o=n[0][a],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[l+e,c+e],[l+e,u-e],[h-e,u-e],[h-e,f+e]],30))}for(var a=n[1].length-1;a>=0;--a){var o=n[1][a],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[h-e,f-e],[h-e,u+e],[l+e,u+e],[l+e,c-e]],30))}return{type:"Polygon",coordinates:[t.merge(r)]}}(),l)},a},i.lobes=function(t){return arguments.length?(n=t.map(function(t){return t.map(function(t){return[[t[0][0]*p/180,t[0][1]*p/180],[t[1][0]*p/180,t[1][1]*p/180],[t[2][0]*p/180,t[2][1]*p/180]]})}),r=n.map(function(t){return t.map(function(t){var r,n=e(t[0][0],t[0][1])[0],a=e(t[2][0],t[2][1])[0],i=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return i>o&&(r=i,i=o,o=r),[[n,i],[a,o]]})}),i):n.map(function(t){return t.map(function(t){return[[180*t[0][0]/p,180*t[0][1]/p],[180*t[1][0]/p,180*t[1][1]/p],[180*t[2][0]/p,180*t[2][1]/p]]})})},i},_.invert=function(t,e){var r=.5*e*Math.sqrt((4+p)/p),n=m(r),a=Math.cos(n);return[t/(2/Math.sqrt(p*(4+p))*(1+a)),m((n+r*(a+2))/(2+d))]},(t.geo.eckert4=function(){return x(_)}).raw=_;var w=t.geo.azimuthalEqualArea.raw;function k(t,e){if(arguments.length<2&&(e=t),1===e)return w;if(e===1/0)return T;function r(r,n){var a=w(r/e,n);return a[0]*=t,a}return r.invert=function(r,n){var a=w.invert(r/t,n);return a[0]*=e,a},r}function T(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function M(t,e){return[3*t/(2*p)*Math.sqrt(p*p/3-e*e),e]}function A(t,e){return[t,1.25*Math.log(Math.tan(p/4+.4*e))]}function S(t){return function(e){var r,n=t*Math.sin(e),a=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>h&&--a>0);return e/2}}T.invert=function(t,e){var r=2*m(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=b(k),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=k,M.invert=function(t,e){return[2/3*p*t/Math.sqrt(p*p/3-e*e),e]},(t.geo.kavrayskiy7=function(){return x(M)}).raw=M,A.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*p]},(t.geo.miller=function(){return x(A)}).raw=A,S(p);var E=function(t,e,r){var n=S(r);function a(r,a){return[t*r*Math.cos(a=n(a)),e*Math.sin(a)]}return a.invert=function(n,a){var i=m(a/e);return[n/(t*Math.cos(i)),m((2*i+Math.sin(2*i))/r)]},a}(Math.SQRT2/d,Math.SQRT2,p);function L(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return x(E)}).raw=E,L.invert=function(t,e){var r,n=e,a=25;do{var i=n*n,o=i*i;n-=r=(n*(1.007226+i*(.015085+o*(.028874*i-.044475-.005916*o)))-e)/(1.007226+i*(.045255+o*(.259866*i-.311325-.005916*11*o)))}while(Math.abs(r)>h&&--a>0);return[t/(.8707+(i=n*n)*(i*(i*i*i*(.003971-.001529*i)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return x(L)}).raw=L;var C=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function P(t,e){var r,n=Math.min(18,36*Math.abs(e)/p),a=Math.floor(n),i=n-a,o=(r=C[a])[0],s=r[1],l=(r=C[++a])[0],c=r[1],u=(r=C[Math.min(19,++a)])[0],h=r[1];return[t*(l+i*(u-o)/2+i*i*(u-2*l+o)/2),(e>0?d:-d)*(c+i*(h-s)/2+i*i*(h-2*c+s)/2)]}function O(t,e){return[t*Math.cos(e),e]}function z(t,e){var r,n=Math.cos(e),a=(r=y(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*a,Math.sin(e)*a]}function I(t,e){var r=z(t,e);return[(r[0]+t/d)/2,(r[1]+e)/2]}C.forEach(function(t){t[1]*=1.0144}),P.invert=function(t,e){var r=e/d,n=90*r,a=Math.min(18,Math.abs(n/5)),i=Math.max(0,Math.floor(a));do{var o=C[i][1],s=C[i+1][1],l=C[Math.min(19,i+2)][1],c=l-o,u=l-2*s+o,h=2*(Math.abs(r)-s)/c,p=u/c,m=h*(1-p*h*(1-2*p*h));if(m>=0||1===i){n=(e>=0?5:-5)*(m+a);var y,x=50;do{m=(a=Math.min(18,Math.abs(n)/5))-(i=Math.floor(a)),o=C[i][1],s=C[i+1][1],l=C[Math.min(19,i+2)][1],n-=(y=(e>=0?d:-d)*(s+m*(l-o)/2+m*m*(l-2*s+o)/2)-e)*v}while(Math.abs(y)>f&&--x>0);break}}while(--i>=0);var b=C[i][0],_=C[i+1][0],w=C[Math.min(19,i+2)][0];return[t/(_+m*(w-b)/2+m*m*(w-2*_+b)/2),n*g]},(t.geo.robinson=function(){return x(P)}).raw=P,O.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return x(O)}).raw=O,z.invert=function(t,e){if(!(t*t+4*e*e>p*p+h)){var r=t,n=e,a=25;do{var i,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),f=Math.sin(2*n),d=c*c,g=u*u,v=s*s,m=1-g*l*l,x=m?y(u*l)*Math.sqrt(i=1/m):i=0,b=2*x*u*s-t,_=x*c-e,w=i*(g*v+x*u*l*d),k=i*(.5*o*f-2*x*c*s),T=.25*i*(f*s-x*c*g*o),M=i*(d*l+x*v*u),A=k*T-M*w;if(!A)break;var S=(_*k-b*M)/A,E=(b*T-_*w)/A;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--a>0);return[r,n]}},(t.geo.aitoff=function(){return x(z)}).raw=z,I.invert=function(t,e){var r=t,n=e,a=25;do{var i,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,f=Math.sin(r),p=Math.cos(r/2),g=Math.sin(r/2),v=g*g,m=1-u*p*p,x=m?y(o*p)*Math.sqrt(i=1/m):i=0,b=.5*(2*x*o*g+r/d)-t,_=.5*(x*s+n)-e,w=.5*i*(u*v+x*o*p*c)+.5/d,k=i*(f*l/4-x*s*g),T=.125*i*(l*g-x*s*u*f),M=.5*i*(c*p+x*v*o)+.5,A=k*T-M*w,S=(_*k-b*M)/A,E=(b*T-_*w)/A;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--a>0);return[r,n]},(t.geo.winkel3=function(){return x(I)}).raw=I}},{}],799:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../registry"),o=Math.PI/180,s=180/Math.PI,l={cursor:"pointer"},c={cursor:"auto"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function h(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],h={},f={};function p(t,e){h[n+"."+t]=a.nestedProperty(l,t).get(),i.call("_storeDirectGUIEdit",s,c._preGUI,h);var r=a.nestedProperty(u,t);r.get()!==e&&(r.set(e),a.nestedProperty(l,t).set(e),f[n+"."+t]=e)}r(p),p("projection.scale",e.scale()/t.fitScale),p("fitbounds",!1),o.emit("plotly_relayout",f)}function f(t,e){var r=u(0,e);function a(r){var n=e.invert(t.midPt);r("center.lon",n[0]),r("center.lat",n[1])}return r.on("zoomstart",function(){n.select(this).style(l)}).on("zoom",function(){e.scale(n.event.scale).translate(n.event.translate),t.render();var r=e.invert(t.midPt);t.graphDiv.emit("plotly_relayouting",{"geo.projection.scale":e.scale()/t.fitScale,"geo.center.lon":r[0],"geo.center.lat":r[1]})}).on("zoomend",function(){n.select(this).style(c),h(t,e,a)}),r}function p(t,e){var r,a,i,o,s,f,p,d,g,v=u(0,e),m=2;function y(t){return e.invert(t)}function x(r){var n=e.rotate(),a=e.invert(t.midPt);r("projection.rotation.lon",-n[0]),r("center.lon",a[0]),r("center.lat",a[1])}return v.on("zoomstart",function(){n.select(this).style(l),r=n.mouse(this),a=e.rotate(),i=e.translate(),o=a,s=y(r)}).on("zoom",function(){if(f=n.mouse(this),function(t){var r=y(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>m||Math.abs(n[1]-t[1])>m}(r))return v.scale(e.scale()),void v.translate(e.translate());e.scale(n.event.scale),e.translate([i[0],n.event.translate[1]]),s?y(f)&&(d=y(f),p=[o[0]+(d[0]-s[0]),a[1],a[2]],e.rotate(p),o=p):s=y(r=f),g=!0,t.render();var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit("plotly_relayouting",{"geo.projection.scale":e.scale()/t.fitScale,"geo.center.lon":c[0],"geo.center.lat":c[1],"geo.projection.rotation.lon":-l[0]})}).on("zoomend",function(){n.select(this).style(c),g&&h(t,e,x)}),v}function d(t,e){var r,a={r:e.rotate(),k:e.scale()},i=u(0,e),f=function(t){var e=0,r=arguments.length,a=[];for(;++e<r;)a.push(arguments[e]);var i=n.dispatch.apply(null,a);return i.of=function(e,r){return function(a){var o;try{o=a.sourceEvent=n.event,a.target=t,n.event=a,i[a.type].apply(e,r)}finally{n.event=o}}},i}(i,"zoomstart","zoom","zoomend"),p=0,d=i.on;function m(t){var r=e.rotate();t("projection.rotation.lon",-r[0]),t("projection.rotation.lat",-r[1])}return i.on("zoomstart",function(){n.select(this).style(l);var t,c,u,h,m,b,_,w,k,T,M,A=n.mouse(this),S=e.rotate(),E=S,L=e.translate(),C=(c=.5*(t=S)[0]*o,u=.5*t[1]*o,h=.5*t[2]*o,m=Math.sin(c),b=Math.cos(c),_=Math.sin(u),w=Math.cos(u),k=Math.sin(h),T=Math.cos(h),[b*w*T+m*_*k,m*w*T-b*_*k,b*_*T+m*w*k,b*w*k-m*_*T]);r=g(e,A),d.call(i,"zoom",function(){var t,i,o,l,c,u,h,p,d,m,b=n.mouse(this);if(e.scale(a.k=n.event.scale),r){if(g(e,b)){e.rotate(S).translate(L);var _=g(e,b),w=function(t,e){if(!t||!e)return;var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(x(r,r)),a=.5*Math.acos(Math.max(-1,Math.min(1,x(t,e)))),i=Math.sin(a)/n;return n&&[Math.cos(a),r[2]*i,-r[1]*i,r[0]*i]}(r,_),k=function(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}((i=w,o=(t=C)[0],l=t[1],c=t[2],u=t[3],h=i[0],p=i[1],d=i[2],m=i[3],[o*h-l*p-c*d-u*m,o*p+l*h+c*m-u*d,o*d-l*m+c*h+u*p,o*m+l*d-c*p+u*h])),T=a.r=function(t,e,r){var n=y(e,2,t[0]);n=y(n,1,t[1]),n=y(n,0,t[2]-r[2]);var a,i,o=e[0],l=e[1],c=e[2],u=n[0],h=n[1],f=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(h)>d?(i=(h>0?90:-90)-p,a=0):(i=Math.asin(h/d)*s-p,a=Math.sqrt(d*d-h*h));var g=180-i-2*p,m=(Math.atan2(f,u)-Math.atan2(c,a))*s,x=(Math.atan2(f,u)-Math.atan2(c,-a))*s,b=v(r[0],r[1],i,m),_=v(r[0],r[1],g,x);return b<=_?[i,m,r[2]]:[g,x,r[2]]}(k,r,E);isFinite(T[0])&&isFinite(T[1])&&isFinite(T[2])||(T=E),e.rotate(T),E=T}}else r=g(e,A=b);f.of(this,arguments)({type:"zoom"})}),M=f.of(this,arguments),p++||M({type:"zoomstart"})}).on("zoomend",function(){var r;n.select(this).style(c),d.call(i,"zoom",null),r=f.of(this,arguments),--p||r({type:"zoomend"}),h(t,e,m)}).on("zoom.redraw",function(){t.render();var r=e.rotate();t.graphDiv.emit("plotly_relayouting",{"geo.projection.scale":e.scale()/t.fitScale,"geo.projection.rotation.lon":-r[0],"geo.projection.rotation.lat":-r[1]})}),n.rebind(i,f,"on")}function g(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function v(t,e,r,n){var a=m(r-t),i=m(n-e);return Math.sqrt(a*a+i*i)}function m(t){return(t%360+540)%360-180}function y(t,e,r){var n=r*o,a=t.slice(),i=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return a[i]=t[i]*l-t[s]*c,a[s]=t[s]*l+t[i]*c,a}function x(t,e){for(var r=0,n=0,a=t.length;n<a;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?f:e._isClipped?d:p)(t,r)}},{"../../lib":717,"../../registry":846,d3:165}],800:[function(t,e,r){"use strict";var n=t("../registry"),a=t("./cartesian/constants").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var a=n.subplotsRegistry[e];if(!a)return[];for(var i=a.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[i]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,a=[],i=[];if(!(r="string"==typeof e?n.getModule(e).plot:"function"==typeof e?e:e.plot))return[a,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&0!==l._length&&(l._module.plot===r?a.push(s):i.push(s))}return[a,i]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var i,o,s,l=n.subplotsRegistry[e].attr,c=[];if("gl2d"===e){var u=r.match(a);o="x"+u[1],s="y"+u[2]}for(var h=0;h<t.length;h++)i=t[h],"gl2d"===e&&n.traceIs(i,"gl2d")?i[l[0]]===o&&i[l[1]]===s&&c.push(i):i[l]===r&&c.push(i);return c}},{"../registry":846,"./cartesian/constants":771}],801:[function(t,e,r){"use strict";var n=t("mouse-change"),a=t("mouse-wheel"),i=t("mouse-event-offset"),o=t("../cartesian/constants"),s=t("has-passive-events");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function h(e,n,a){var i,s,l=t.calcDataBox(),h=r.viewBox,f=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,g=o.MINZOOM*r.pixelRatio;function v(e,r,n){var a=Math.min(r,n),i=Math.max(r,n);a!==i?(l[e]=a,l[e+2]=i,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,a*=r.pixelRatio,a=h[3]-h[1]-a,t.fullLayout.dragmode){case"zoom":if(e){var m=n/(h[2]-h[0])*(l[2]-l[0])+l[0],y=a/(h[3]-h[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=m,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=a),c.boxEnd[0]=m,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<g,b=Math.abs(c.dragStart[1]-a)<g;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,a=0;a<e.length;a++)if(-1!==e[a][r]){if(-1!==e[a][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{i=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(i*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(i)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(i>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(i=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],i||s?(i&&(v(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(v(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case"pan":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=a),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-a)<d&&(a=c.dragStart[1]),i=(f-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-a)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=i,l[2]+=i,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=a}return c.mouseListener=n(e,h),e.addEventListener("touchstart",function(t){var r=i(t.changedTouches[0],e);h(0,r[0],r[1]),h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener("touchmove",function(t){t.preventDefault();var r=i(t.changedTouches[0],e);h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener("touchend",function(t){h(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()},!!s&&{passive:!1}),c.wheelListener=a(e,function(e,n){if(!t.scrollZoom)return!1;var a=t.calcDataBox(),i=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(i[3]-i[1])),h=o/(i[2]-i[0])*(a[2]-a[0])+a[0],f=s/(i[3]-i[1])*(a[3]-a[1])+a[1];return a[0]=(a[0]-h)*l+h,a[2]=(a[2]-h)*l+h,a[1]=(a[1]-f)*l+f,a[3]=(a[3]-f)*l+f,t.setRanges(a),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0},!0),c}},{"../cartesian/constants":771,"has-passive-events":412,"mouse-change":436,"mouse-event-offset":437,"mouse-wheel":439}],802:[function(t,e,r){"use strict";var n=t("../cartesian/axes"),a=t("../../lib/str2rgbarray");function i(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=["x","y"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=["sans-serif","sans-serif"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title="",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont="sans-serif",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=i.prototype,s=["xaxis","yaxis"];o.merge=function(t){var e,r,n,i,o,l,c,u,h,f,p;for(this.titleEnable=!1,this.backgroundColor=a(t.plot_bgcolor),f=0;f<2;++f){var d=(e=s[f]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?"":r.title.text,p=0;p<=2;p+=2)this.labelEnable[f+p]=!1,this.labels[f+p]=n,this.labelColor[f+p]=a(r.title.font.color),this.labelFont[f+p]=r.title.font.family,this.labelSize[f+p]=r.title.font.size,this.labelPad[f+p]=this.getLabelPad(e,r),this.tickEnable[f+p]=!1,this.tickColor[f+p]=a((r.tickfont||{}).color),this.tickAngle[f+p]="auto"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[f+p]=this.getTickPad(r),this.tickMarkLength[f+p]=0,this.tickMarkWidth[f+p]=r.tickwidth||0,this.tickMarkColor[f+p]=a(r.tickcolor),this.borderLineEnable[f+p]=!1,this.borderLineColor[f+p]=a(r.linecolor),this.borderLineWidth[f+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,i=r.mirror||!1,u=c?-1!==String(i).indexOf("all"):!!i,h=c?"allticks"===i:-1!==String(i).indexOf("ticks"),o?this.labelEnable[f]=!0:l&&(this.labelEnable[f+2]=!0),o?this.tickEnable[f]=r.showticklabels:l&&(this.tickEnable[f+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[f]=r.showline),(l||u)&&(this.borderLineEnable[f+2]=r.showline),(o||h)&&(this.tickMarkLength[f]=this.getTickMarkLength(r)),(l||h)&&(this.tickMarkLength[f+2]=this.getTickMarkLength(r)),this.gridLineEnable[f]=r.showgrid,this.gridLineColor[f]=a(r.gridcolor),this.gridLineWidth[f]=r.gridwidth,this.zeroLineEnable[f]=r.zeroline,this.zeroLineColor[f]=a(r.zerolinecolor),this.zeroLineWidth[f]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return"xaxis"===t?"bottom"===r:"yaxis"===t?"left"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return"xaxis"===t?"top"===r:"yaxis"===t?"right"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return"xaxis"===t?"top"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:"yaxis"===t?"right"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return"outside"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return"inside"===t.ticks?-e:e},e.exports=function(t){return new i(t)}},{"../../lib/str2rgbarray":740,"../cartesian/axes":765}],803:[function(t,e,r){"use strict";var n=t("../../plot_api/edit_types").overrideAll,a=t("./scene2d"),i=t("../layout_attributes"),o=t("../../constants/xmlns_namespaces"),s=t("../cartesian/constants"),l=t("../cartesian"),c=t("../../components/fx/layout_attributes"),u=t("../get_data").getSubplotData;r.name="gl2d",r.attr=["xaxis","yaxis"],r.idRoot=["x","y"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t("../cartesian/attributes"),r.supplyLayoutDefaults=function(t,e,r){e._has("cartesian")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,"plot","from-root"),r.baseLayoutAttrOverrides=n({plot_bgcolor:i.plot_bgcolor,hoverlabel:c.hoverlabel},"plot","nested"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,i=0;i<n.length;i++){var o=n[i],s=e._plots[o],l=u(r,"gl2d",o),c=s._scene2d;void 0===c&&(c=new a({id:o,graphDiv:t,container:t.querySelector(".gl-container"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var a=n._subplots.gl2d||[],i=0;i<a.length;i++){var o=a[i],s=n._plots[o];if(s._scene2d)0===u(t,"gl2d",o).length&&(s._scene2d.destroy(),delete n._plots[o])}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var a=e._plots[r[n]]._scene2d,i=a.toImage("png");e._glimages.append("svg:image").attr({xmlns:o.svg,"xlink:href":i,x:0,y:0,width:"100%",height:"100%",preserveAspectRatio:"none"}),a.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{"../../components/fx/layout_attributes":631,"../../constants/xmlns_namespaces":694,"../../plot_api/edit_types":748,"../cartesian":776,"../cartesian/attributes":763,"../cartesian/constants":771,"../get_data":800,"../layout_attributes":817,"./scene2d":804}],804:[function(t,e,r){"use strict";var n,a,i=t("../../registry"),o=t("../../plots/cartesian/axes"),s=t("../../components/fx"),l=t("gl-plot2d"),c=t("gl-spikes2d"),u=t("gl-select-box"),h=t("webgl-context"),f=t("./convert"),p=t("./camera"),d=t("../../lib/show_no_webgl_msg"),g=t("../cartesian/constraints"),v=g.enforce,m=g.clean,y=t("../cartesian/autorange").doAutoRange,x=["xaxis","yaxis"],b=t("../cartesian/constants").SUBPLOT_PATTERN;function _(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=f(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=_;var w=_.prototype;w.makeFramework=function(){if(this.staticPlot){if(!(a||(n=document.createElement("canvas"),a=h({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error("Error creating static canvas/context for image server");this.canvas=n,this.gl=a}else{var t=this.container.querySelector(".gl-canvas-focus"),e=h({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width="100%",r.style.height="100%",r.style.position="absolute",r.style.top="0px",r.style.left="0px",r.style["pointer-events"]="none",this.updateSize(r),r.className+=" user-select-none";var i=this.svgContainer=document.createElementNS("http://www.w3.org/2000/svg","svg");i.style.position="absolute",i.style.top=i.style.left="0px",i.style.width=i.style.height="100%",i.style["z-index"]=20,i.style["pointer-events"]="none";var o=this.mouseContainer=document.createElement("div");o.style.position="absolute",o.style["pointer-events"]="auto",this.pickCanvas=this.container.querySelector(".gl-canvas-pick");var s=this.container;s.appendChild(i),s.appendChild(o);var l=this;o.addEventListener("mouseout",function(){l.isMouseOver=!1,l.unhover()}),o.addEventListener("mouseover",function(){l.isMouseOver=!0})},w.toImage=function(t){t||(t="png"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,a=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var i=new Uint8Array(r*a*4);e.readPixels(0,0,r,a,e.RGBA,e.UNSIGNED_BYTE,i);for(var o=0,s=a-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=i[4*(r*o+l)+c];i[4*(r*o+l)+c]=i[4*(r*s+l)+c],i[4*(r*s+l)+c]=u}var h=document.createElement("canvas");h.width=r,h.height=a;var f,p=h.getContext("2d"),d=p.createImageData(r,a);switch(d.data.set(i),p.putImageData(d,0,0),t){case"jpeg":f=h.toDataURL("image/jpeg");break;case"webp":f=h.toDataURL("image/webp");break;default:f=h.toDataURL("image/png")}return this.staticPlot&&this.container.removeChild(n),f},w.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,a=r.height,i=0|Math.ceil(e*n),o=0|Math.ceil(e*a);return t.width===i&&t.height===o||(t.width=i,t.height=o),t},w.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+"";return t},w.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(b),r="xaxis"+e[1],n="yaxis"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},w.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,a={},o=a[e._name+".range"]=e.range.slice(),s=a[r._name+".range"]=r.range.slice();a[e._name+".autorange"]=e.autorange,a[r._name+".autorange"]=r.autorange,i.call("_storeDirectGUIEdit",t.layout,t._fullLayout._preGUI,a);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,a.lastInputTime=this.camera.lastInputTime,t.emit("plotly_relayout",a)},w.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],a=e[r];if(n.length!==a.length)return!0;for(var i=0;i<n.length;++i)if(n[i].x!==a[i].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},w.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&i.getComponentMethod("annotations","drawOne")(t,r)}},w.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map(function(e){t[e].dispose(),delete t[e]}),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener("wheel",this.camera.wheelListener),this.camera=null}},w.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var a=r.width,i=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,a,i];var s={_fullLayout:{_axisConstraintGroups:this.graphDiv._fullLayout._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis}};m(s,this.xaxis),m(s,this.yaxis);var l,c,u=r._size,h=this.xaxis.domain,f=this.yaxis.domain;for(o.viewBox=[u.l+h[0]*u.w,u.b+f[0]*u.h,a-u.r-(1-h[1])*u.w,i-u.t-(1-f[1])*u.h],this.mouseContainer.style.width=u.w*(h[1]-h[0])+"px",this.mouseContainer.style.height=u.h*(f[1]-f[0])+"px",this.mouseContainer.height=u.h*(f[1]-f[0]),this.mouseContainer.style.left=u.l+h[0]*u.w+"px",this.mouseContainer.style.top=u.t+(1-f[1])*u.h+"px",c=0;c<2;++c)(l=this[x[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();v(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},w.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,a=t.r2l,i=e.r2l;return[a(r[0]),i(n[0]),a(r[1]),i(n[1])]},w.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,a=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[a(t[1]),a(t[3])]},w.updateTraces=function(t,e){var r,n,a,i=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<i.length;r++){var o=i[r],s=this.traces[o];for(n=0;n<t.length;n++)if((a=t[n]).uid===o&&a.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){a=t[r];var l=e[r],c=this.traces[a.uid];c?c.update(a,l):(c=a._module.plot(this,a,l),this.traces[a.uid]=c)}this.glplot.objects.sort(function(t,e){return t._trace.index-e._trace.index})},w.updateFx=function(t){"lasso"===t||"select"===t?(this.pickCanvas.style["pointer-events"]="none",this.mouseContainer.style["pointer-events"]="none"):(this.pickCanvas.style["pointer-events"]="auto",this.mouseContainer.style["pointer-events"]="auto"),this.mouseContainer.style.cursor="pan"===t?"move":"zoom"===t?"crosshair":null},w.emitPointAction=function(t,e){for(var r,n=t.trace.uid,a=t.pointIndex,i=0;i<this.fullData.length;i++)this.fullData[i].uid===n&&(r=this.fullData[i]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:a,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,a),this.graphDiv.emit(e,{points:[o]})},w.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,a=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var i,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&"zoom"===a.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var h=a._size,f=this.xaxis.domain,p=this.yaxis.domain,d=(i=t.pick(o/t.pixelRatio+h.l+f[0]*h.w,l/t.pixelRatio-(h.t+(1-p[1])*h.h)))&&i.object._trace.handlePick(i);if(d&&n&&this.emitPointAction(d,"plotly_click"),i&&"skip"!==i.object._trace.hoverinfo&&a.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var g=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:i.dataCoord}),g.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(i.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(i.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,"plotly_hover");var v=this.fullData[g.trace.index]||{},m=g.pointIndex,y=s.castHoverinfo(v,a,m);if(y&&"all"!==y){var x=y.split("+");-1===x.indexOf("x")&&(g.traceCoord[0]=void 0),-1===x.indexOf("y")&&(g.traceCoord[1]=void 0),-1===x.indexOf("z")&&(g.traceCoord[2]=void 0),-1===x.indexOf("text")&&(g.textLabel=void 0),-1===x.indexOf("name")&&(g.name=void 0)}s.loneHover({x:g.screenCoord[0],y:g.screenCoord[1],xLabel:this.hoverFormatter("xaxis",g.traceCoord[0]),yLabel:this.hoverFormatter("yaxis",g.traceCoord[1]),zLabel:g.traceCoord[2],text:g.textLabel,name:g.name,color:s.castHoverOption(v,m,"bgcolor")||g.color,borderColor:s.castHoverOption(v,m,"bordercolor"),fontFamily:s.castHoverOption(v,m,"font.family"),fontSize:s.castHoverOption(v,m,"font.size"),fontColor:s.castHoverOption(v,m,"font.color"),nameLength:s.castHoverOption(v,m,"namelength"),textAlign:s.castHoverOption(v,m,"align")},{container:this.svgContainer,gd:this.graphDiv})}}i||this.unhover(),t.draw()}},w.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit("plotly_unhover"),s.loneUnhover(this.svgContainer))},w.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),"hover").text}}},{"../../components/fx":630,"../../lib/show_no_webgl_msg":738,"../../plots/cartesian/axes":765,"../../registry":846,"../cartesian/autorange":764,"../cartesian/constants":771,"../cartesian/constraints":772,"./camera":801,"./convert":802,"gl-plot2d":290,"gl-select-box":302,"gl-spikes2d":311,"webgl-context":554}],805:[function(t,e,r){"use strict";var n=t("../../plot_api/edit_types").overrideAll,a=t("../../components/fx/layout_attributes"),i=t("./scene"),o=t("../get_data").getSubplotData,s=t("../../lib"),l=t("../../constants/xmlns_namespaces");r.name="gl3d",r.attr="scene",r.idRoot="scene",r.idRegex=r.attrRegex=s.counterRegex("scene"),r.attributes=t("./layout/attributes"),r.layoutAttributes=t("./layout/layout_attributes"),r.baseLayoutAttrOverrides=n({hoverlabel:a.hoverlabel},"plot","nested"),r.supplyLayoutDefaults=t("./layout/defaults"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,a=0;a<n.length;a++){var s=n[a],l=o(r,"gl3d",s),c=e[s],u=c.camera,h=c._scene;h||(h=new i({id:s,graphDiv:t,container:t.querySelector(".gl-container"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:u},e),c._scene=h),h.viewInitial||(h.viewInitial={up:{x:u.up.x,y:u.up.y,z:u.up.z},eye:{x:u.eye.x,y:u.eye.y,z:u.eye.z},center:{x:u.center.x,y:u.center.y,z:u.center.z}}),h.plot(l,e,t.layout)}},r.clean=function(t,e,r,n){for(var a=n._subplots.gl3d||[],i=0;i<a.length;i++){var o=a[i];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(".annotation-"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,a=0;a<r.length;a++){var i=e[r[a]],o=i.domain,s=i._scene,c=s.toImage("png");e._glimages.append("svg:image").attr({xmlns:l.svg,"xlink:href":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:"none"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return"1"===e&&(e=""),"scene"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{"../../components/fx/layout_attributes":631,"../../constants/xmlns_namespaces":694,"../../lib":717,"../../plot_api/edit_types":748,"../get_data":800,"./layout/attributes":806,"./layout/defaults":810,"./layout/layout_attributes":811,"./scene":815}],806:[function(t,e,r){"use strict";e.exports={scene:{valType:"subplotid",dflt:"scene",editType:"calc+clearAxisTypes"}}},{}],807:[function(t,e,r){"use strict";var n=t("../../../components/color"),a=t("../../cartesian/layout_attributes"),i=t("../../../lib/extend").extendFlat,o=t("../../../plot_api/edit_types").overrideAll;e.exports=o({visible:a.visible,showspikes:{valType:"boolean",dflt:!0},spikesides:{valType:"boolean",dflt:!0},spikethickness:{valType:"number",min:0,dflt:2},spikecolor:{valType:"color",dflt:n.defaultLine},showbackground:{valType:"boolean",dflt:!1},backgroundcolor:{valType:"color",dflt:"rgba(204, 204, 204, 0.5)"},showaxeslabels:{valType:"boolean",dflt:!0},color:a.color,categoryorder:a.categoryorder,categoryarray:a.categoryarray,title:{text:a.title.text,font:a.title.font},type:i({},a.type,{values:["-","linear","log","date","category"]}),autorange:a.autorange,rangemode:a.rangemode,range:i({},a.range,{items:[{valType:"any",editType:"plot",impliedEdits:{"^autorange":!1}},{valType:"any",editType:"plot",impliedEdits:{"^autorange":!1}}],anim:!1}),tickmode:a.tickmode,nticks:a.nticks,tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,mirror:a.mirror,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,tickfont:a.tickfont,tickangle:a.tickangle,tickprefix:a.tickprefix,showtickprefix:a.showtickprefix,ticksuffix:a.ticksuffix,showticksuffix:a.showticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,separatethousands:a.separatethousands,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:a.showline,linecolor:a.linecolor,linewidth:a.linewidth,showgrid:a.showgrid,gridcolor:i({},a.gridcolor,{dflt:"rgb(204, 204, 204)"}),gridwidth:a.gridwidth,zeroline:a.zeroline,zerolinecolor:a.zerolinecolor,zerolinewidth:a.zerolinewidth,_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},"plot","from-root")},{"../../../components/color":591,"../../../lib/extend":708,"../../../plot_api/edit_types":748,"../../cartesian/layout_attributes":777}],808:[function(t,e,r){"use strict";var n=t("tinycolor2").mix,a=t("../../../lib"),i=t("../../../plot_api/plot_template"),o=t("./axis_attributes"),s=t("../../cartesian/type_defaults"),l=t("../../cartesian/axis_defaults"),c=["xaxis","yaxis","zaxis"];e.exports=function(t,e,r){var u,h;function f(t,e){return a.coerce(u,h,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(h=i.newContainer(e,d))._id=d[0]+r.scene,h._name=d,s(u,h,f,r),l(u,h,f,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),f("gridcolor",n(h.color,r.bgColor,13600/187).toRgbString()),f("title.text",d[0]),h.setScale=a.noop,f("showspikes")&&(f("spikesides"),f("spikethickness"),f("spikecolor",h.color)),f("showaxeslabels"),f("showbackground")&&f("backgroundcolor")}}},{"../../../lib":717,"../../../plot_api/plot_template":755,"../../cartesian/axis_defaults":767,"../../cartesian/type_defaults":788,"./axis_attributes":807,tinycolor2:535}],809:[function(t,e,r){"use strict";var n=t("../../../lib/str2rgbarray"),a=t("../../../lib"),i=["xaxis","yaxis","zaxis"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=["sans-serif","sans-serif","sans-serif"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=["x","y","z"],this.labelEnable=[!0,!0,!0],this.labelFont=["Open Sans","Open Sans","Open Sans"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[i[r]];o.visible?(this.labels[r]=t._meta?a.templateString(o.title.text,t._meta):o.title.text,"font"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),"showline"in o&&(this.lineEnable[r]=o.showline),"linecolor"in o&&(this.lineColor[r]=n(o.linecolor)),"linewidth"in o&&(this.lineWidth[r]=o.linewidth),"showgrid"in o&&(this.gridEnable[r]=o.showgrid),"gridcolor"in o&&(this.gridColor[r]=n(o.gridcolor)),"gridwidth"in o&&(this.gridWidth[r]=o.gridwidth),"log"===o.type?this.zeroEnable[r]=!1:"zeroline"in o&&(this.zeroEnable[r]=o.zeroline),"zerolinecolor"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),"zerolinewidth"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),"ticks"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,"ticklen"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),"tickcolor"in o&&(this.lineTickColor[r]=n(o.tickcolor)),"tickwidth"in o&&(this.lineTickWidth[r]=o.tickwidth),"tickangle"in o&&(this.tickAngle[r]="auto"===o.tickangle?-3600:Math.PI*-o.tickangle/180),"showticklabels"in o&&(this.tickEnable[r]=o.showticklabels),"tickfont"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),"mirror"in o?-1!==["ticks","all","allticks"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,"showbackground"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{"../../../lib":717,"../../../lib/str2rgbarray":740}],810:[function(t,e,r){"use strict";var n=t("../../../lib"),a=t("../../../components/color"),i=t("../../../registry"),o=t("../../subplot_defaults"),s=t("./axis_defaults"),l=t("./layout_attributes"),c=t("../../get_data").getSubplotData,u="gl3d";function h(t,e,r,n){for(var o=r("bgcolor"),l=a.combine(o,n.paper_bgcolor),h=["up","center","eye"],f=0;f<h.length;f++)r("camera."+h[f]+".x"),r("camera."+h[f]+".y"),r("camera."+h[f]+".z");r("camera.projection.type");var p=!!r("aspectratio.x")&&!!r("aspectratio.y")&&!!r("aspectratio.z"),d=r("aspectmode",p?"manual":"auto");p||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},"manual"===d&&(e.aspectmode="auto"),t.aspectmode=e.aspectmode);var g=c(n.fullData,u,n.id);s(t,e,{font:n.font,scene:n.id,data:g,bgColor:l,calendar:n.calendar,fullLayout:n.fullLayout}),i.getComponentMethod("annotations3d","handleDefaults")(t,e,n);var v=n.getDfltFromLayout("dragmode");if(!1!==v&&!v)if(v="orbit",t.camera&&t.camera.up){var m=t.camera.up.x,y=t.camera.up.y,x=t.camera.up.z;0!==x&&(m&&y&&x?x/Math.sqrt(m*m+y*y+x*x)>.999&&(v="turntable"):v="turntable")}else v="turntable";r("dragmode",v),r("hovermode",n.getDfltFromLayout("hovermode"))}e.exports=function(t,e,r){var a=e._basePlotModules.length>1;o(t,e,r,{type:u,attributes:l,handleDefaults:h,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!a)return n.validate(t[e],l[e])?t[e]:void 0},paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{"../../../components/color":591,"../../../lib":717,"../../../registry":846,"../../get_data":800,"../../subplot_defaults":840,"./axis_defaults":808,"./layout_attributes":811}],811:[function(t,e,r){"use strict";var n=t("./axis_attributes"),a=t("../../domain").attributes,i=t("../../../lib/extend").extendFlat,o=t("../../../lib").counterRegex;function s(t,e,r){return{x:{valType:"number",dflt:t,editType:"camera"},y:{valType:"number",dflt:e,editType:"camera"},z:{valType:"number",dflt:r,editType:"camera"},editType:"camera"}}e.exports={_arrayAttrRegexps:[o("scene",".annotations",!0)],bgcolor:{valType:"color",dflt:"rgba(0,0,0,0)",editType:"plot"},camera:{up:i(s(0,0,1),{}),center:i(s(0,0,0),{}),eye:i(s(1.25,1.25,1.25),{}),projection:{type:{valType:"enumerated",values:["perspective","orthographic"],dflt:"perspective",editType:"calc"},editType:"calc"},editType:"camera"},domain:a({name:"scene",editType:"plot"}),aspectmode:{valType:"enumerated",values:["auto","cube","data","manual"],dflt:"auto",editType:"plot",impliedEdits:{"aspectratio.x":void 0,"aspectratio.y":void 0,"aspectratio.z":void 0}},aspectratio:{x:{valType:"number",min:0,editType:"plot",impliedEdits:{"^aspectmode":"manual"}},y:{valType:"number",min:0,editType:"plot",impliedEdits:{"^aspectmode":"manual"}},z:{valType:"number",min:0,editType:"plot",impliedEdits:{"^aspectmode":"manual"}},editType:"plot",impliedEdits:{aspectmode:"manual"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:"enumerated",values:["orbit","turntable","zoom","pan",!1],editType:"plot"},hovermode:{valType:"enumerated",values:["closest",!1],dflt:"closest",editType:"modebar"},uirevision:{valType:"any",editType:"none"},editType:"plot",_deprecated:{cameraposition:{valType:"info_array",editType:"camera"}}}},{"../../../lib":717,"../../../lib/extend":708,"../../domain":790,"./axis_attributes":807}],812:[function(t,e,r){"use strict";var n=t("../../../lib/str2rgbarray"),a=["xaxis","yaxis","zaxis"];function i(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}i.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[a[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new i;return e.merge(t),e}},{"../../../lib/str2rgbarray":740}],813:[function(t,e,r){"use strict";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[i[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var h=u.tickmode;if("auto"===u.tickmode){u.tickmode="linear";var f=u.nticks||a.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/f)}for(var p=n.calcTicks(u),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],"date"===u.type&&(p[d].text=p[d].text.replace(/\<br\>/g," "));l[c]=p,u.tickmode=h}}e.ticks=l;for(var c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(var d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],a=new Array(n.length),i=0;i<n.length;++i)a[i]=n[i].x;e[r]=a}return e}(l)};var n=t("../../cartesian/axes"),a=t("../../../lib"),i=["xaxis","yaxis","zaxis"],o=[0,0,0]},{"../../../lib":717,"../../cartesian/axes":765}],814:[function(t,e,r){"use strict";function n(t,e){var r,n,a=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)a[n]+=t[4*r+n]*e[r];return a}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],815:[function(t,e,r){"use strict";var n,a,i=t("gl-plot3d"),o=i.createCamera,s=i.createScene,l=t("webgl-context"),c=t("has-passive-events"),u=t("../../registry"),h=t("../../lib"),f=t("../../plots/cartesian/axes"),p=t("../../components/fx"),d=t("../../lib/str2rgbarray"),g=t("../../lib/show_no_webgl_msg"),v=t("./project"),m=t("./layout/convert"),y=t("./layout/spikes"),x=t("./layout/tick_marks"),b=t("is-mobile")({tablet:!0,featureDetect:!0});function _(t,e){var r=document.createElement("div"),n=t.container;this.graphDiv=t.graphDiv;var a=document.createElementNS("http://www.w3.org/2000/svg","svg");a.style.position="absolute",a.style.top=a.style.left="0px",a.style.width=a.style.height="100%",a.style["z-index"]=20,a.style["pointer-events"]="none",r.appendChild(a),this.svgContainer=a,r.id=t.id,r.style.position="absolute",r.style.top=r.style.left="0px",r.style.width=r.style.height="100%",n.appendChild(r),this.fullLayout=e,this.id=t.id||"scene",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=m(e,e[this.id]),this.spikeOptions=y(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=u.getComponentMethod("annotations3d","convert"),this.drawAnnotations=u.getComponentMethod("annotations3d","draw"),this.initializeGLPlot()}var w=_.prototype;w.prepareOptions=function(){var t={canvas:this.canvas,gl:this.gl,glOptions:{preserveDrawingBuffer:b,premultipliedAlpha:!0,antialias:!0},container:this.container,axes:this.axesOptions,spikes:this.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:this.camera,pixelRatio:this.pixelRatio};if(this.staticMode){if(!(a||(n=document.createElement("canvas"),a=l({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error("error creating static canvas/context for image server");t.gl=a,t.canvas=n}return t},w.tryCreatePlot=function(){var t=this.prepareOptions(),e=!0;try{this.glplot=s(t)}catch(r){if(this.staticMode)e=!1;else try{h.warn(["webgl setup failed possibly due to",b?"disabling":"enabling","preserveDrawingBuffer config.","The device may not be supported by is-mobile module!","Inverting preserveDrawingBuffer option in second attempt to create webgl scene."].join(" ")),b=t.glOptions.preserveDrawingBuffer=!t.glOptions.preserveDrawingBuffer,this.glplot=s(t)}catch(t){e=!1}}return e},w.initializeGLCamera=function(){var t=this.fullSceneLayout.camera,e="orthographic"===t.projection.type;this.camera=o(this.container,{center:[t.center.x,t.center.y,t.center.z],eye:[t.eye.x,t.eye.y,t.eye.z],up:[t.up.x,t.up.y,t.up.z],_ortho:e,zoomMin:.01,zoomMax:100,mode:"orbit"})},w.initializeGLPlot=function(){var t=this;if(t.initializeGLCamera(),!t.tryCreatePlot())return g(t);t.traces={},t.make4thDimension();var e=t.graphDiv,r=e.layout,n=function(){var e={};return t.isCameraChanged(r)&&(e[t.id+".camera"]=t.getCamera()),t.isAspectChanged(r)&&(e[t.id+".aspectratio"]=t.glplot.getAspectratio(),"manual"!==r[t.id].aspectmode&&(t.fullSceneLayout.aspectmode=r[t.id].aspectmode=e[t.id+".aspectmode"]="manual")),e},a=function(t){if(!1!==t.fullSceneLayout.dragmode){var e=n();t.saveLayout(r),t.graphDiv.emit("plotly_relayout",e)}};return t.glplot.canvas.addEventListener("mouseup",function(){a(t)}),t.glplot.canvas.addEventListener("wheel",function(r){if(e._context._scrollZoom.gl3d){if(t.camera._ortho){var n=r.deltaX>r.deltaY?1.1:1/1.1,i=t.glplot.getAspectratio();t.glplot.setAspectratio({x:n*i.x,y:n*i.y,z:n*i.z})}a(t)}},!!c&&{passive:!1}),t.glplot.canvas.addEventListener("mousemove",function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e=n();t.graphDiv.emit("plotly_relayouting",e)}}),t.staticMode||t.glplot.canvas.addEventListener("webglcontextlost",function(r){e&&e.emit&&e.emit("plotly_webglcontextlost",{event:r,layer:t.id})},!1),t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(){t.render()},!0},w.render=function(){var t,e=this,r=e.graphDiv,n=e.svgContainer,a=e.container.getBoundingClientRect(),i=a.width,o=a.height;n.setAttributeNS(null,"viewBox","0 0 "+i+" "+o),n.setAttributeNS(null,"width",i),n.setAttributeNS(null,"height",o),x(e),e.glplot.axes.update(e.axesOptions);for(var s,l=Object.keys(e.traces),c=null,u=e.glplot.selection,d=0;d<l.length;++d)"skip"!==(t=e.traces[l[d]]).data.hoverinfo&&t.handlePick(u)&&(c=t),t.setContourLevels&&t.setContourLevels();function g(t,r){var n=e.fullSceneLayout[t];return f.tickText(n,n.d2l(r),"hover").text}if(null!==c){var m=v(e.glplot.cameraParams,u.dataCoordinate);t=c.data;var y,b=r._fullData[t.index],_=u.index,w={xLabel:g("xaxis",u.traceCoordinate[0]),yLabel:g("yaxis",u.traceCoordinate[1]),zLabel:g("zaxis",u.traceCoordinate[2])},k=p.castHoverinfo(b,e.fullLayout,_),T=(k||"").split("+"),M=k&&"all"===k;b.hovertemplate||M||(-1===T.indexOf("x")&&(w.xLabel=void 0),-1===T.indexOf("y")&&(w.yLabel=void 0),-1===T.indexOf("z")&&(w.zLabel=void 0),-1===T.indexOf("text")&&(u.textLabel=void 0),-1===T.indexOf("name")&&(c.name=void 0));var A=[];"cone"===t.type||"streamtube"===t.type?(w.uLabel=g("xaxis",u.traceCoordinate[3]),(M||-1!==T.indexOf("u"))&&A.push("u: "+w.uLabel),w.vLabel=g("yaxis",u.traceCoordinate[4]),(M||-1!==T.indexOf("v"))&&A.push("v: "+w.vLabel),w.wLabel=g("zaxis",u.traceCoordinate[5]),(M||-1!==T.indexOf("w"))&&A.push("w: "+w.wLabel),w.normLabel=u.traceCoordinate[6].toPrecision(3),(M||-1!==T.indexOf("norm"))&&A.push("norm: "+w.normLabel),"streamtube"===t.type&&(w.divergenceLabel=u.traceCoordinate[7].toPrecision(3),(M||-1!==T.indexOf("divergence"))&&A.push("divergence: "+w.divergenceLabel)),u.textLabel&&A.push(u.textLabel),y=A.join("<br>")):"isosurface"===t.type||"volume"===t.type?(w.valueLabel=f.tickText(e._mockAxis,e._mockAxis.d2l(u.traceCoordinate[3]),"hover").text,A.push("value: "+w.valueLabel),u.textLabel&&A.push(u.textLabel),y=A.join("<br>")):y=u.textLabel;var S={x:u.traceCoordinate[0],y:u.traceCoordinate[1],z:u.traceCoordinate[2],data:b._input,fullData:b,curveNumber:b.index,pointNumber:_};p.appendArrayPointValue(S,b,_),t._module.eventData&&(S=b._module.eventData(S,u,b,{},_));var E={points:[S]};e.fullSceneLayout.hovermode&&p.loneHover({trace:b,x:(.5+.5*m[0]/m[3])*i,y:(.5-.5*m[1]/m[3])*o,xLabel:w.xLabel,yLabel:w.yLabel,zLabel:w.zLabel,text:y,name:c.name,color:p.castHoverOption(b,_,"bgcolor")||c.color,borderColor:p.castHoverOption(b,_,"bordercolor"),fontFamily:p.castHoverOption(b,_,"font.family"),fontSize:p.castHoverOption(b,_,"font.size"),fontColor:p.castHoverOption(b,_,"font.color"),nameLength:p.castHoverOption(b,_,"namelength"),textAlign:p.castHoverOption(b,_,"align"),hovertemplate:h.castOption(b,_,"hovertemplate"),hovertemplateLabels:h.extendFlat({},S,w),eventData:[S]},{container:n,gd:r}),u.buttons&&u.distance<5?r.emit("plotly_click",E):r.emit("plotly_hover",E),s=E}else p.loneUnhover(n),r.emit("plotly_unhover",s);e.drawAnnotations(e)},w.recoverContext=function(){var t=this;t.glplot.dispose();var e=function(){t.glplot.gl.isContextLost()?requestAnimationFrame(e):t.initializeGLPlot()?t.plot.apply(t,t.plotArgs):h.error("Catastrophic and unrecoverable WebGL error. Context lost.")};requestAnimationFrame(e)};var k=["xaxis","yaxis","zaxis"];function T(t,e,r){for(var n=t.fullSceneLayout,a=0;a<3;a++){var i=k[a],o=i.charAt(0),s=n[i],l=e[o],c=e[o+"calendar"],u=e["_"+o+"length"];if(h.isArrayOrTypedArray(l))for(var f,p=0;p<(u||l.length);p++)if(h.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)f=s.d2l(l[p][d],0,c),!isNaN(f)&&isFinite(f)&&(r[0][a]=Math.min(r[0][a],f),r[1][a]=Math.max(r[1][a],f));else f=s.d2l(l[p],0,c),!isNaN(f)&&isFinite(f)&&(r[0][a]=Math.min(r[0][a],f),r[1][a]=Math.max(r[1][a],f));else r[0][a]=Math.min(r[0][a],0),r[1][a]=Math.max(r[1][a],u-1)}}w.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,a,i,o,s,l,c=e[this.id],u=r[this.id];this.fullLayout=e,this.fullSceneLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setViewport(c),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.setClearColor(d(c.bgcolor)),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(i=0;i<t.length;++i)!0===(n=t[i]).visible&&0!==n._length&&T(this,n,h);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],a=0;a<3;a++)for(var i=k[a],o=i.charAt(0),s=r[i],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][a]=Math.min(e[0][a],u),e[1][a]=Math.max(e[1][a],u))}}}(this,h);var f=[1,1,1];for(o=0;o<3;++o)h[1][o]===h[0][o]?f[o]=1:f[o]=1/(h[1][o]-h[0][o]);for(this.dataScale=f,this.convertAnnotations(this),i=0;i<t.length;++i)!0===(n=t[i]).visible&&0!==n._length&&((a=this.traces[n.uid])?a.data.type===n.type?a.update(n):(a.dispose(),a=n._module.plot(this,n),this.traces[n.uid]=a):(a=n._module.plot(this,n),this.traces[n.uid]=a),a.name=n.name);var p=Object.keys(this.traces);t:for(i=0;i<p.length;++i){for(o=0;o<t.length;++o)if(t[o].uid===p[i]&&!0===t[o].visible&&0!==t[o]._length)continue t;(a=this.traces[p[i]]).dispose(),delete this.traces[p[i]]}this.glplot.objects.sort(function(t,e){return t._trace.data.index-e._trace.data.index});var g,v=[[0,0,0],[0,0,0]],m=[],y={};for(i=0;i<3;++i){if((l=(s=c[k[i]]).type)in y?(y[l].acc*=f[i],y[l].count+=1):y[l]={acc:f[i],count:1},s.autorange){v[0][i]=1/0,v[1][i]=-1/0;var x=this.glplot.objects,b=this.fullSceneLayout.annotations||[],_=s._name.charAt(0);for(o=0;o<x.length;o++){var w=x[o],M=w.bounds,A=w._trace.data._pad||0;"ErrorBars"===w.constructor.name&&s._lowerLogErrorBound?v[0][i]=Math.min(v[0][i],s._lowerLogErrorBound):v[0][i]=Math.min(v[0][i],M[0][i]/f[i]-A),v[1][i]=Math.max(v[1][i],M[1][i]/f[i]+A)}for(o=0;o<b.length;o++){var S=b[o];if(S.visible){var E=s.r2l(S[_]);v[0][i]=Math.min(v[0][i],E),v[1][i]=Math.max(v[1][i],E)}}if("rangemode"in s&&"tozero"===s.rangemode&&(v[0][i]=Math.min(v[0][i],0),v[1][i]=Math.max(v[1][i],0)),v[0][i]>v[1][i])v[0][i]=-1,v[1][i]=1;else{var L=v[1][i]-v[0][i];v[0][i]-=L/32,v[1][i]+=L/32}if("reversed"===s.autorange){var C=v[0][i];v[0][i]=v[1][i],v[1][i]=C}}else{var P=s.range;v[0][i]=s.r2l(P[0]),v[1][i]=s.r2l(P[1])}v[0][i]===v[1][i]&&(v[0][i]-=1,v[1][i]+=1),m[i]=v[1][i]-v[0][i],this.glplot.setBounds(i,{min:v[0][i]*f[i],max:v[1][i]*f[i]})}var O=c.aspectmode;if("cube"===O)g=[1,1,1];else if("manual"===O){var z=c.aspectratio;g=[z.x,z.y,z.z]}else{if("auto"!==O&&"data"!==O)throw new Error("scene.js aspectRatio was not one of the enumerated types");var I=[1,1,1];for(i=0;i<3;++i){var D=y[l=(s=c[k[i]]).type];I[i]=Math.pow(D.acc,1/D.count)/f[i]}g="data"===O?I:Math.max.apply(null,I)/Math.min.apply(null,I)<=4?I:[1,1,1]}c.aspectratio.x=u.aspectratio.x=g[0],c.aspectratio.y=u.aspectratio.y=g[1],c.aspectratio.z=u.aspectratio.z=g[2],this.glplot.setAspectratio(c.aspectratio),this.viewInitial.aspectratio||(this.viewInitial.aspectratio={x:c.aspectratio.x,y:c.aspectratio.y,z:c.aspectratio.z}),this.viewInitial.aspectmode||(this.viewInitial.aspectmode=c.aspectmode);var R=c.domain||null,F=e._size||null;if(R&&F){var B=this.container.style;B.position="absolute",B.left=F.l+R.x[0]*F.w+"px",B.top=F.t+(1-R.y[1])*F.h+"px",B.width=F.w*(R.x[1]-R.x[0])+"px",B.height=F.h*(R.y[1]-R.y[0])+"px"}this.glplot.redraw()}},w.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener("wheel",this.camera.wheelListener),this.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},w.getCamera=function(){var t;return this.camera.view.recalcMatrix(this.camera.view.lastT()),{up:{x:(t=this.camera).up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?"orthographic":"perspective"}}},w.setViewport=function(t){var e,r=t.camera;this.camera.lookAt.apply(this,[[(e=r).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]),this.glplot.setAspectratio(t.aspectratio),"orthographic"===r.projection.type!==this.camera._ortho&&(this.glplot.redraw(),this.glplot.clearRGBA(),this.glplot.dispose(),this.initializeGLPlot())},w.isCameraChanged=function(t){var e=this.getCamera(),r=h.nestedProperty(t,this.id+".camera").get();function n(t,e,r,n){var a=["up","center","eye"],i=["x","y","z"];return e[a[r]]&&t[a[r]][i[n]]===e[a[r]][i[n]]}var a=!1;if(void 0===r)a=!0;else{for(var i=0;i<3;i++)for(var o=0;o<3;o++)if(!n(e,r,i,o)){a=!0;break}(!r.projection||e.projection&&e.projection.type!==r.projection.type)&&(a=!0)}return a},w.isAspectChanged=function(t){var e=this.glplot.getAspectratio(),r=h.nestedProperty(t,this.id+".aspectratio").get();return void 0===r||r.x!==e.x||r.y!==e.y||r.z!==e.z},w.saveLayout=function(t){var e,r,n,a,i,o,s=this.fullLayout,l=this.isCameraChanged(t),c=this.isAspectChanged(t),f=l||c;if(f){var p={};if(l&&(e=this.getCamera(),n=(r=h.nestedProperty(t,this.id+".camera")).get(),p[this.id+".camera"]=n),c&&(a=this.glplot.getAspectratio(),o=(i=h.nestedProperty(t,this.id+".aspectratio")).get(),p[this.id+".aspectratio"]=o),u.call("_storeDirectGUIEdit",t,s._preGUI,p),l)r.set(e),h.nestedProperty(s,this.id+".camera").set(e);if(c)i.set(a),h.nestedProperty(s,this.id+".aspectratio").set(a),this.glplot.redraw()}return f},w.updateFx=function(t,e){var r=this.camera;if(r)if("orbit"===t)r.mode="orbit",r.keyBindingMode="rotate";else if("turntable"===t){r.up=[0,0,1],r.mode="turntable",r.keyBindingMode="rotate";var n=this.graphDiv,a=n._fullLayout,i=this.fullSceneLayout.camera,o=i.up.x,s=i.up.y,l=i.up.z;if(l/Math.sqrt(o*o+s*s+l*l)<.999){var c=this.id+".camera.up",f={x:0,y:0,z:1},p={};p[c]=f;var d=n.layout;u.call("_storeDirectGUIEdit",d,a._preGUI,p),i.up=f,h.nestedProperty(d,c).set(f)}}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},w.toImage=function(t){t||(t="png"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,a=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var i=new Uint8Array(r*a*4);e.readPixels(0,0,r,a,e.RGBA,e.UNSIGNED_BYTE,i),function(t,e,r){for(var n=0,a=r-1;n<a;++n,--a)for(var i=0;i<e;++i)for(var o=0;o<4;++o){var s=4*(e*n+i)+o,l=4*(e*a+i)+o,c=t[s];t[s]=t[l],t[l]=c}}(i,r,a),function(t,e,r){for(var n=0;n<r;++n)for(var a=0;a<e;++a){var i=4*(e*n+a),o=t[i+3];if(o>0)for(var s=255/o,l=0;l<3;++l)t[i+l]=Math.min(s*t[i+l],255)}}(i,r,a);var o=document.createElement("canvas");o.width=r,o.height=a;var s,l=o.getContext("2d"),c=l.createImageData(r,a);switch(c.data.set(i),l.putImageData(c,0,0),t){case"jpeg":s=o.toDataURL("image/jpeg");break;case"webp":s=o.toDataURL("image/webp");break;default:s=o.toDataURL("image/png")}return this.staticMode&&this.container.removeChild(n),s},w.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[k[t]];f.setConvert(e,this.fullLayout),e.setScale=h.noop}},w.make4thDimension=function(){var t=this.graphDiv._fullLayout;this._mockAxis={type:"linear",showexponent:"all",exponentformat:"B"},f.setConvert(this._mockAxis,t)},e.exports=_},{"../../components/fx":630,"../../lib":717,"../../lib/show_no_webgl_msg":738,"../../lib/str2rgbarray":740,"../../plots/cartesian/axes":765,"../../registry":846,"./layout/convert":809,"./layout/spikes":812,"./layout/tick_marks":813,"./project":814,"gl-plot3d":293,"has-passive-events":412,"is-mobile":421,"webgl-context":554}],816:[function(t,e,r){"use strict";e.exports=function(t,e,r,n){n=n||t.length;for(var a=new Array(n),i=0;i<n;i++)a[i]=[t[i],e[i],r[i]];return a}},{}],817:[function(t,e,r){"use strict";var n=t("./font_attributes"),a=t("./animation_attributes"),i=t("../components/color/attributes"),o=t("./pad_attributes"),s=t("../lib/extend").extendFlat,l=n({editType:"calc"});l.family.dflt='"Open Sans", verdana, arial, sans-serif',l.size.dflt=12,l.color.dflt=i.defaultLine,e.exports={font:l,title:{text:{valType:"string",editType:"layoutstyle"},font:n({editType:"layoutstyle"}),xref:{valType:"enumerated",dflt:"container",values:["container","paper"],editType:"layoutstyle"},yref:{valType:"enumerated",dflt:"container",values:["container","paper"],editType:"layoutstyle"},x:{valType:"number",min:0,max:1,dflt:.5,editType:"layoutstyle"},y:{valType:"number",min:0,max:1,dflt:"auto",editType:"layoutstyle"},xanchor:{valType:"enumerated",dflt:"auto",values:["auto","left","center","right"],editType:"layoutstyle"},yanchor:{valType:"enumerated",dflt:"auto",values:["auto","top","middle","bottom"],editType:"layoutstyle"},pad:s(o({editType:"layoutstyle"}),{}),editType:"layoutstyle"},uniformtext:{mode:{valType:"enumerated",values:[!1,"hide","show"],dflt:!1,editType:"plot"},minsize:{valType:"number",min:0,dflt:0,editType:"plot"},editType:"plot"},autosize:{valType:"boolean",dflt:!1,editType:"none"},width:{valType:"number",min:10,dflt:700,editType:"plot"},height:{valType:"number",min:10,dflt:450,editType:"plot"},margin:{l:{valType:"number",min:0,dflt:80,editType:"plot"},r:{valType:"number",min:0,dflt:80,editType:"plot"},t:{valType:"number",min:0,dflt:100,editType:"plot"},b:{valType:"number",min:0,dflt:80,editType:"plot"},pad:{valType:"number",min:0,dflt:0,editType:"plot"},autoexpand:{valType:"boolean",dflt:!0,editType:"plot"},editType:"plot"},paper_bgcolor:{valType:"color",dflt:i.background,editType:"plot"},plot_bgcolor:{valType:"color",dflt:i.background,editType:"layoutstyle"},separators:{valType:"string",editType:"plot"},hidesources:{valType:"boolean",dflt:!1,editType:"plot"},showlegend:{valType:"boolean",editType:"legend"},colorway:{valType:"colorlist",dflt:i.defaults,editType:"calc"},datarevision:{valType:"any",editType:"calc"},uirevision:{valType:"any",editType:"none"},editrevision:{valType:"any",editType:"none"},selectionrevision:{valType:"any",editType:"none"},template:{valType:"any",editType:"calc"},modebar:{orientation:{valType:"enumerated",values:["v","h"],dflt:"h",editType:"modebar"},bgcolor:{valType:"color",editType:"modebar"},color:{valType:"color",editType:"modebar"},activecolor:{valType:"color",editType:"modebar"},uirevision:{valType:"any",editType:"none"},editType:"modebar"},meta:{valType:"any",arrayOk:!0,editType:"plot"},transition:s({},a.transition,{editType:"none"}),_deprecated:{title:{valType:"string",editType:"layoutstyle"},titlefont:n({editType:"layoutstyle"})}}},{"../components/color/attributes":590,"../lib/extend":708,"./animation_attributes":760,"./font_attributes":791,"./pad_attributes":825}],818:[function(t,e,r){"use strict";var n={"open-street-map":{id:"osm",version:8,sources:{"plotly-osm-tiles":{type:"raster",attribution:'<a href="http://www.openstreetmap.org/about/" target="_blank">\xa9 OpenStreetMap</a>',tiles:["https://a.tile.openstreetmap.org/{z}/{x}/{y}.png","https://b.tile.openstreetmap.org/{z}/{x}/{y}.png"],tileSize:256}},layers:[{id:"plotly-osm-tiles",type:"raster",source:"plotly-osm-tiles",minzoom:0,maxzoom:22}]},"white-bg":{id:"white-bg",version:8,sources:{},layers:[{id:"white-bg",type:"background",paint:{"background-color":"#FFFFFF"},minzoom:0,maxzoom:22}]},"carto-positron":{id:"carto-positron",version:8,sources:{"plotly-carto-positron":{type:"raster",attribution:'<a href="https://carto.com/" target="_blank">\xa9 CARTO</a>',tiles:["https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png"],tileSize:256}},layers:[{id:"plotly-carto-positron",type:"raster",source:"plotly-carto-positron",minzoom:0,maxzoom:22}]},"carto-darkmatter":{id:"carto-darkmatter",version:8,sources:{"plotly-carto-darkmatter":{type:"raster",attribution:'<a href="https://carto.com/" target="_blank">\xa9 CARTO</a>',tiles:["https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png"],tileSize:256}},layers:[{id:"plotly-carto-darkmatter",type:"raster",source:"plotly-carto-darkmatter",minzoom:0,maxzoom:22}]},"stamen-terrain":{id:"stamen-terrain",version:8,sources:{"plotly-stamen-terrain":{type:"raster",attribution:'Map tiles by <a href="http://stamen.com">Stamen Design</a>, under <a href="http://creativecommons.org/licenses/by/3.0">CC BY 3.0</a> | Data by <a href="http://openstreetmap.org">OpenStreetMap</a>, under <a href="http://www.openstreetmap.org/copyright">ODbL</a>.',tiles:["https://stamen-tiles.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png"],tileSize:256}},layers:[{id:"plotly-stamen-terrain",type:"raster",source:"plotly-stamen-terrain",minzoom:0,maxzoom:22}]},"stamen-toner":{id:"stamen-toner",version:8,sources:{"plotly-stamen-toner":{type:"raster",attribution:'Map tiles by <a href="http://stamen.com">Stamen Design</a>, under <a href="http://creativecommons.org/licenses/by/3.0">CC BY 3.0</a> | Data by <a href="http://openstreetmap.org">OpenStreetMap</a>, under <a href="http://www.openstreetmap.org/copyright">ODbL</a>.',tiles:["https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png"],tileSize:256}},layers:[{id:"plotly-stamen-toner",type:"raster",source:"plotly-stamen-toner",minzoom:0,maxzoom:22}]},"stamen-watercolor":{id:"stamen-watercolor",version:8,sources:{"plotly-stamen-watercolor":{type:"raster",attribution:'Map tiles by <a href="http://stamen.com">Stamen Design</a>, under <a href="http://creativecommons.org/licenses/by/3.0">CC BY 3.0</a> | Data by <a href="http://openstreetmap.org">OpenStreetMap</a>, under <a href="http://creativecommons.org/licenses/by-sa/3.0">CC BY SA</a>.',tiles:["https://stamen-tiles.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png"],tileSize:256}},layers:[{id:"plotly-stamen-watercolor",type:"raster",source:"plotly-stamen-watercolor",minzoom:0,maxzoom:22}]}},a=Object.keys(n);e.exports={requiredVersion:"1.3.2",styleUrlPrefix:"mapbox://styles/mapbox/",styleUrlSuffix:"v9",styleValuesMapbox:["basic","streets","outdoors","light","dark","satellite","satellite-streets"],styleValueDflt:"basic",stylesNonMapbox:n,styleValuesNonMapbox:a,traceLayerPrefix:"plotly-trace-layer-",layoutLayerPrefix:"plotly-layout-layer-",wrongVersionErrorMsg:["Your custom plotly.js bundle is not using the correct mapbox-gl version","Please install mapbox-gl@1.3.2."].join("\n"),noAccessTokenErrorMsg:["Missing Mapbox access token.","Mapbox trace type require a Mapbox access token to be registered.","For example:","  Plotly.plot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });","More info here: https://www.mapbox.com/help/define-access-token/"].join("\n"),missingStyleErrorMsg:["No valid mapbox style found, please set `mapbox.style` to one of:",a.join(", "),"or register a Mapbox access token to use a Mapbox-served style."].join("\n"),multipleTokensErrorMsg:["Set multiple mapbox access token across different mapbox subplot,","using first token found as mapbox-gl does not allow multipleaccess tokens on the same page."].join("\n"),mapOnErrorMsg:"Mapbox error.",mapboxLogo:{path0:"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z",path1:"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z",path2:"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z",polygon:"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34"},styleRules:{map:"overflow:hidden;position:relative;","missing-css":"display:none;",canary:"background-color:salmon;","ctrl-bottom-left":"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;","ctrl-bottom-right":"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;",ctrl:"clear: both; pointer-events: auto; transform: translate(0, 0);","ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner":"display: none;","ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner":"display: block; margin-top:2px","ctrl-attrib.mapboxgl-compact:hover":"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;","ctrl-attrib.mapboxgl-compact::after":'content: ""; cursor: pointer; position: absolute; background-image: url(\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"%3E %3Cpath fill="%23333333" fill-rule="evenodd" d="M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0"/%3E %3C/svg%3E\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',"ctrl-attrib.mapboxgl-compact":"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;","ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after":"bottom: 0; right: 0","ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after":"bottom: 0; left: 0","ctrl-bottom-left .mapboxgl-ctrl":"margin: 0 0 10px 10px; float: left;","ctrl-bottom-right .mapboxgl-ctrl":"margin: 0 10px 10px 0; float: right;","ctrl-attrib":"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px","ctrl-attrib a":"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px","ctrl-attrib a:hover":"color: inherit; text-decoration: underline;","ctrl-attrib .mapbox-improve-map":"font-weight: bold; margin-left: 2px;","attrib-empty":"display: none;","ctrl-logo":'display:block; width: 21px; height: 21px; background-image: url(\'data:image/svg+xml;charset=utf-8,%3C?xml version="1.0" encoding="utf-8"?%3E %3Csvg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 21 21" style="enable-background:new 0 0 21 21;" xml:space="preserve"%3E%3Cg transform="translate(0,0.01)"%3E%3Cpath d="m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z" style="opacity:0.9;fill:%23ffffff;enable-background:new" class="st0"/%3E%3Cpath d="M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z" style="opacity:0.35;enable-background:new" class="st1"/%3E%3Cpath d="M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z" style="opacity:0.35;enable-background:new" class="st1"/%3E%3Cpolygon points="11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 " style="opacity:0.9;fill:%23ffffff;enable-background:new" class="st0"/%3E%3C/g%3E%3C/svg%3E\')'}}},{}],819:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e){var r=t.split(" "),a=r[0],i=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=["",""],u=[0,0];switch(a){case"top":c[0]="top",u[1]=-l;break;case"bottom":c[0]="bottom",u[1]=l}switch(i){case"left":c[1]="right",u[0]=-s;break;case"right":c[1]="left",u[0]=s}return{anchor:c[0]&&c[1]?c.join("-"):c[0]?c[0]:c[1]?c[1]:"center",offset:u}}},{"../../lib":717}],820:[function(t,e,r){"use strict";var n=t("mapbox-gl"),a=t("../../lib"),i=t("../../plots/get_data").getSubplotCalcData,o=t("../../constants/xmlns_namespaces"),s=t("d3"),l=t("../../components/drawing"),c=t("../../lib/svg_text_utils"),u=t("./mapbox"),h=r.constants=t("./constants");function f(t){return"string"==typeof t&&(-1!==h.styleValuesMapbox.indexOf(t)||0===t.indexOf("mapbox://"))}r.name="mapbox",r.attr="subplot",r.idRoot="mapbox",r.idRegex=r.attrRegex=a.counterRegex("mapbox"),r.attributes={subplot:{valType:"subplotid",dflt:"mapbox",editType:"calc"}},r.layoutAttributes=t("./layout_attributes"),r.supplyLayoutDefaults=t("./layout_defaults"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,o=e._subplots.mapbox;if(n.version!==h.requiredVersion)throw new Error(h.wrongVersionErrorMsg);var s=function(t,e){var r=t._fullLayout;if(""===t._context.mapboxAccessToken)return"";for(var n=[],i=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;f(c.style)&&(u?a.pushUnique(n,u):(f(c._input.style)&&(a.error("Uses Mapbox map style, but did not set an access token."),o=!0),s=!0)),u&&a.pushUnique(i,u)}if(s){var p=o?h.noAccessTokenErrorMsg:h.missingStyleErrorMsg;throw a.error(p),new Error(p)}return n.length?(n.length>1&&a.warn(h.multipleTokensErrorMsg),n[0]):(i.length&&a.log(["Listed mapbox access token(s)",i.join(","),"but did not use a Mapbox map style, ignoring token(s)."].join(" ")),"")}(t,o);n.accessToken=s;for(var l=0;l<o.length;l++){var c=o[l],p=i(r,"mapbox",c),d=e[c],g=d._subplot;g||(g=new u(t,c),e[c]._subplot=g),g.viewInitial||(g.viewInitial={center:a.extendFlat({},d.center),zoom:d.zoom,bearing:d.bearing,pitch:d.pitch}),g.plot(p,e,t._promises)}},r.clean=function(t,e,r,n){for(var a=n._subplots.mapbox||[],i=0;i<a.length;i++){var o=a[i];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,a=0;a<r.length;a++){var i=e[r[a]],u=i.domain,f=i._subplot.toImage("png");e._glimages.append("svg:image").attr({xmlns:o.svg,"xlink:href":f,x:n.l+n.w*u.x[0],y:n.t+n.h*(1-u.y[1]),width:n.w*(u.x[1]-u.x[0]),height:n.h*(u.y[1]-u.y[0]),preserveAspectRatio:"none"});var p=s.select(i._subplot.div);if(!(null===p.select(".mapboxgl-ctrl-logo").node().offsetParent)){var d=e._glimages.append("g");d.attr("transform","translate("+(n.l+n.w*u.x[0]+10)+", "+(n.t+n.h*(1-u.y[0])-31)+")"),d.append("path").attr("d",h.mapboxLogo.path0).style({opacity:.9,fill:"#ffffff","enable-background":"new"}),d.append("path").attr("d",h.mapboxLogo.path1).style("opacity",.35).style("enable-background","new"),d.append("path").attr("d",h.mapboxLogo.path2).style("opacity",.35).style("enable-background","new"),d.append("polygon").attr("points",h.mapboxLogo.polygon).style({opacity:.9,fill:"#ffffff","enable-background":"new"})}var g=p.select(".mapboxgl-ctrl-attrib").text().replace("Improve this map",""),v=e._glimages.append("g"),m=v.append("text");m.text(g).classed("static-attribution",!0).attr({"font-size":12,"font-family":"Arial",color:"rgba(0, 0, 0, 0.75)","text-anchor":"end","data-unformatted":g});var y=l.bBox(m.node()),x=n.w*(u.x[1]-u.x[0]);if(y.width>x/2){var b=g.split("|").join("<br>");m.text(b).attr("data-unformatted",b).call(c.convertToTspans,t),y=l.bBox(m.node())}m.attr("transform","translate(-3, "+(8-y.height)+")"),v.insert("rect",".static-attribution").attr({x:-y.width-6,y:-y.height-3,width:y.width+6,height:y.height+3,fill:"rgba(255, 255, 255, 0.75)"});var _=1;y.width+6>x&&(_=x/(y.width+6));var w=[n.l+n.w*u.x[1],n.t+n.h*(1-u.y[0])];v.attr("transform","translate("+w[0]+","+w[1]+") scale("+_+")")}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{"../../components/drawing":612,"../../constants/xmlns_namespaces":694,"../../lib":717,"../../lib/svg_text_utils":741,"../../plots/get_data":800,"./constants":818,"./layout_attributes":822,"./layout_defaults":823,"./mapbox":824,d3:165,"mapbox-gl":427}],821:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./convert_text_opts"),i=t("./constants");function o(t,e){this.subplot=t,this.uid=t.uid+"-"+e,this.index=e,this.idSource="source-"+this.uid,this.idLayer=i.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var s=o.prototype;function l(t){if(!t.visible)return!1;var e=t.source;if(Array.isArray(e)&&e.length>0){for(var r=0;r<e.length;r++)if("string"!=typeof e[r]||0===e[r].length)return!1;return!0}return n.isPlainObject(e)||"string"==typeof e&&e.length>0}function c(t){var e={},r={};switch(t.type){case"circle":n.extendFlat(r,{"circle-radius":t.circle.radius,"circle-color":t.color,"circle-opacity":t.opacity});break;case"line":n.extendFlat(r,{"line-width":t.line.width,"line-color":t.color,"line-opacity":t.opacity,"line-dasharray":t.line.dash});break;case"fill":n.extendFlat(r,{"fill-color":t.color,"fill-outline-color":t.fill.outlinecolor,"fill-opacity":t.opacity});break;case"symbol":var i=t.symbol,o=a(i.textposition,i.iconsize);n.extendFlat(e,{"icon-image":i.icon+"-15","icon-size":i.iconsize/10,"text-field":i.text,"text-size":i.textfont.size,"text-anchor":o.anchor,"text-offset":o.offset,"symbol-placement":i.placement}),n.extendFlat(r,{"icon-color":t.color,"text-color":i.textfont.color,"text-opacity":t.opacity});break;case"raster":n.extendFlat(r,{"raster-fade-duration":0,"raster-opacity":t.opacity})}return{layout:e,paint:r}}s.update=function(t){this.visible?this.needsNewImage(t)?this.updateImage(t):this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=l(t)},s.needsNewImage=function(t){return this.subplot.map.getSource(this.idSource)&&"image"===this.sourceType&&"image"===t.sourcetype&&(this.source!==t.source||JSON.stringify(this.coordinates)!==JSON.stringify(t.coordinates))},s.needsNewSource=function(t){return this.sourceType!==t.sourcetype||this.source!==t.source||this.layerType!==t.type},s.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup["layout-"+this.index]},s.updateImage=function(t){this.subplot.map.getSource(this.idSource).updateImage({url:t.source,coordinates:t.coordinates})},s.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,l(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,a={type:r};"geojson"===r?e="data":"vector"===r?e="string"==typeof n?"url":"tiles":"raster"===r?(e="tiles",a.tileSize=256):"image"===r&&(e="url",a.coordinates=t.coordinates);a[e]=n,t.sourceattribution&&(a.attribution=t.sourceattribution);return a}(t);e.addSource(this.idSource,r)}},s.updateLayer=function(t){var e,r=this.subplot,n=c(t),a=this.subplot.belowLookup["layout-"+this.index];if("traces"===a)for(var o=r.getMapLayers(),s=0;s<o.length;s++){var u=o[s].id;if("string"==typeof u&&0===u.indexOf(i.traceLayerPrefix)){e=u;break}}else e=a;this.removeLayer(),l(t)&&r.addLayer({id:this.idLayer,source:this.idSource,"source-layer":t.sourcelayer||"",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:n.layout,paint:n.paint},e),this.layerType=t.type,this.below=a},s.updateStyle=function(t){if(l(t)){var e=c(t);this.subplot.setOptions(this.idLayer,"setLayoutProperty",e.layout),this.subplot.setOptions(this.idLayer,"setPaintProperty",e.paint)}},s.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},s.dispose=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer),t.getSource(this.idSource)&&t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new o(t,e);return n.update(r),n}},{"../../lib":717,"./constants":818,"./convert_text_opts":819}],822:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/color").defaultLine,i=t("../domain").attributes,o=t("../font_attributes"),s=t("../../traces/scatter/attributes").textposition,l=t("../../plot_api/edit_types").overrideAll,c=t("../../plot_api/plot_template").templatedArray,u=t("./constants"),h=o({});h.family.dflt="Open Sans Regular, Arial Unicode MS Regular",(e.exports=l({_arrayAttrRegexps:[n.counterRegex("mapbox",".layers",!0)],domain:i({name:"mapbox"}),accesstoken:{valType:"string",noBlank:!0,strict:!0},style:{valType:"any",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:"number",dflt:0},lat:{valType:"number",dflt:0}},zoom:{valType:"number",dflt:1},bearing:{valType:"number",dflt:0},pitch:{valType:"number",dflt:0},layers:c("layer",{visible:{valType:"boolean",dflt:!0},sourcetype:{valType:"enumerated",values:["geojson","vector","raster","image"],dflt:"geojson"},source:{valType:"any"},sourcelayer:{valType:"string",dflt:""},sourceattribution:{valType:"string"},type:{valType:"enumerated",values:["circle","line","fill","symbol","raster"],dflt:"circle"},coordinates:{valType:"any"},below:{valType:"string"},color:{valType:"color",dflt:a},opacity:{valType:"number",min:0,max:1,dflt:1},minzoom:{valType:"number",min:0,max:24,dflt:0},maxzoom:{valType:"number",min:0,max:24,dflt:24},circle:{radius:{valType:"number",dflt:15}},line:{width:{valType:"number",dflt:2},dash:{valType:"data_array"}},fill:{outlinecolor:{valType:"color",dflt:a}},symbol:{icon:{valType:"string",dflt:"marker"},iconsize:{valType:"number",dflt:10},text:{valType:"string",dflt:""},placement:{valType:"enumerated",values:["point","line","line-center"],dflt:"point"},textfont:h,textposition:n.extendFlat({},s,{arrayOk:!1})}})},"plot","from-root")).uirevision={valType:"any",editType:"none"}},{"../../components/color":591,"../../lib":717,"../../plot_api/edit_types":748,"../../plot_api/plot_template":755,"../../traces/scatter/attributes":1120,"../domain":790,"../font_attributes":791,"./constants":818}],823:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../subplot_defaults"),i=t("../array_container_defaults"),o=t("./layout_attributes");function s(t,e,r,n){r("accesstoken",n.accessToken),r("style"),r("center.lon"),r("center.lat"),r("zoom"),r("bearing"),r("pitch"),i(t,e,{name:"layers",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,a){return n.coerce(t,e,o.layers,r,a)}if(r("visible")){var a,i=r("sourcetype"),s="raster"===i||"image"===i;r("source"),r("sourceattribution"),"vector"===i&&r("sourcelayer"),"image"===i&&r("coordinates"),s&&(a="raster");var l=r("type",a);s&&"raster"!==l&&(l=e.type="raster",n.log("Source types *raster* and *image* must drawn *raster* layer type.")),r("below"),r("color"),r("opacity"),r("minzoom"),r("maxzoom"),"circle"===l&&r("circle.radius"),"line"===l&&(r("line.width"),r("line.dash")),"fill"===l&&r("fill.outlinecolor"),"symbol"===l&&(r("symbol.icon"),r("symbol.iconsize"),r("symbol.text"),n.coerceFont(r,"symbol.textfont"),r("symbol.textposition"),r("symbol.placement"))}}e.exports=function(t,e,r){a(t,e,r,{type:"mapbox",attributes:o,handleDefaults:s,partition:"y",accessToken:e._mapboxAccessToken})}},{"../../lib":717,"../array_container_defaults":761,"../subplot_defaults":840,"./layout_attributes":822}],824:[function(t,e,r){"use strict";var n=t("mapbox-gl"),a=t("../../components/fx"),i=t("../../lib"),o=t("../../lib/geo_location_utils"),s=t("../../registry"),l=t("../cartesian/axes"),c=t("../../components/dragelement"),u=t("../cartesian/select").prepSelect,h=t("../cartesian/select").selectOnClick,f=t("./constants"),p=t("./layers");function d(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+"-"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={},this.dragging=!1,this.wheeling=!1}var g=d.prototype;g.plot=function(t,e,r){var n,a=this,i=e[a.id];a.map&&i.accesstoken!==a.accessToken&&(a.map.remove(),a.map=null,a.styleObj=null,a.traceHash=[],a.layerList={}),n=a.map?new Promise(function(r,n){a.updateMap(t,e,r,n)}):new Promise(function(r,n){a.createMap(t,e,r,n)}),r.push(n)},g.createMap=function(t,e,r,a){var i=this,s=e[i.id],l=i.styleObj=m(s.style);i.accessToken=s.accesstoken;var c=i.map=new n.Map({container:i.div,style:l.style,center:x(s.center),zoom:s.zoom,bearing:s.bearing,pitch:s.pitch,interactive:!i.isStatic,preserveDrawingBuffer:i.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));c._canvas.style.left="0px",c._canvas.style.top="0px",i.rejectOnError(a),i.isStatic||i.initFx(t,e);var u=[];u.push(new Promise(function(t){c.once("load",t)})),u=u.concat(o.fetchTraceGeoData(t)),Promise.all(u).then(function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)}).catch(a)},g.updateMap=function(t,e,r,n){var a=this,i=a.map,s=e[this.id];a.rejectOnError(n);var l=[],c=m(s.style);a.styleObj.id!==c.id&&(a.styleObj=c,i.setStyle(c.style),a.traceHash={},l.push(new Promise(function(t){i.once("styledata",t)}))),l=l.concat(o.fetchTraceGeoData(t)),Promise.all(l).then(function(){a.fillBelowLookup(t,e),a.updateData(t),a.updateLayout(e),a.resolveOnRender(r)}).catch(n)},g.fillBelowLookup=function(t,e){var r,n,a=e[this.id].layers,i=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;"string"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),""===n&&(o=!0),i["trace-"+s.uid]=n||""}for(r=0;r<a.length;r++){var c=a[r];n="string"==typeof c.below?c.below:o?"traces":"",i["layout-"+r]=n}var u,h,f={};for(u in i)f[n=i[u]]?f[n].push(u):f[n]=[u];for(n in f){var p=f[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf("trace-")?(h=u.split("trace-")[1],this.traceHash[h]&&(this.traceHash[h].below=null)):0===u.indexOf("layout-")&&(h=u.split("layout-")[1],this.layerList[h]&&(this.layerList[h].below=null))}};var v={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function m(t){var e={};return i.isPlainObject(t)?(e.id=t.id,e.style=t):"string"==typeof t?(e.id=t,-1!==f.styleValuesMapbox.indexOf(t)?e.style=y(t):f.stylesNonMapbox[t]?e.style=f.stylesNonMapbox[t]:e.style=t):(e.id=f.styleValueDflt,e.style=y(f.styleValueDflt)),e.transition={duration:0,delay:0},e}function y(t){return f.styleUrlPrefix+t+"-"+f.styleUrlSuffix}function x(t){return[t.lon,t.lat]}g.updateData=function(t){var e,r,n,a,i=this.traceHash,o=t.slice().sort(function(t,e){return v[t[0].trace.type]-v[e[0].trace.type]});for(n=0;n<o.length;n++){var s=o[n],l=!1;(e=i[(r=s[0].trace).uid])&&(e.type===r.type?(e.update(s),l=!0):e.dispose()),!l&&r._module&&(i[r.uid]=r._module.plot(this,s))}var c=Object.keys(i);t:for(n=0;n<c.length;n++){var u=c[n];for(a=0;a<t.length;a++)if(u===(r=t[a][0].trace).uid)continue t;(e=i[u]).dispose(),delete i[u]}},g.updateLayout=function(t){var e=this.map,r=t[this.id];this.dragging||this.wheeling||(e.setCenter(x(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch)),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},g.resolveOnRender=function(t){var e=this.map;e.on("render",function r(){e.loaded()&&(e.off("render",r),setTimeout(t,10))})},g.rejectOnError=function(t){var e=this.map;function r(){t(new Error(f.mapOnErrorMsg))}e.once("error",r),e.once("style.error",r),e.once("source.error",r),e.once("tile.error",r),e.once("layer.error",r)},g.createFramework=function(t){var e=this,r=e.div=document.createElement("div");r.id=e.uid,r.style.position="absolute",e.container.appendChild(r),e.xaxis={_id:"x",c2p:function(t){return e.project(t).x}},e.yaxis={_id:"y",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:"linear",showexponent:"all",exponentformat:"B"},l.setConvert(e.mockAxis,t)},g.initFx=function(t,e){var r=this,n=r.gd,i=r.map;function o(){a.loneUnhover(e._hoverlayer)}function l(){var t=r.getView();n.emit("plotly_relayouting",r.getViewEditsWithDerived(t))}i.on("moveend",function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||r.wheeling){var a=e[r.id];s.call("_storeDirectGUIEdit",n.layout,e._preGUI,r.getViewEdits(a));var i=r.getView();a._input.center=a.center=i.center,a._input.zoom=a.zoom=i.zoom,a._input.bearing=a.bearing=i.bearing,a._input.pitch=a.pitch=i.pitch,n.emit("plotly_relayout",r.getViewEditsWithDerived(i))}t.originalEvent&&"mouseup"===t.originalEvent.type?r.dragging=!1:r.wheeling&&(r.wheeling=!1),e._rehover&&e._rehover()}}),i.on("wheel",function(){r.wheeling=!0}),i.on("mousemove",function(t){var e=r.div.getBoundingClientRect();t.clientX=t.point.x+e.left,t.clientY=t.point.y+e.top,t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return t.lngLat.lng},r.yaxis.p2c=function(){return t.lngLat.lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&n._fullLayout[r.id]&&a.hover(n,t,r.id)},a.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id}),i.on("dragstart",function(){r.dragging=!0,o()}),i.on("zoomstart",o),i.on("mouseout",function(){n._fullLayout._hoversubplot=null}),i.on("drag",l),i.on("zoom",l),i.on("dblclick",function(){var t=n._fullLayout[r.id];s.call("_storeDirectGUIEdit",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;i.setCenter(x(e.center)),i.setZoom(e.zoom),i.setBearing(e.bearing),i.setPitch(e.pitch);var a=r.getView();t._input.center=t.center=a.center,t._input.zoom=t.zoom=a.zoom,t._input.bearing=t.bearing=a.bearing,t._input.pitch=t.pitch=a.pitch,n.emit("plotly_doubleclick",null),n.emit("plotly_relayout",r.getViewEditsWithDerived(a))}),r.clearSelect=function(){n._fullLayout._zoomlayer.selectAll(".select-outline").remove()},r.onClickInPanFn=function(t){return function(e){var i=n._fullLayout.clickmode;i.indexOf("select")>-1&&h(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),i.indexOf("event")>-1&&a.click(n,e.originalEvent)}}},g.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var a,o=t.dragmode;a="select"===o?function(t,r){(t.range={})[e.id]=[l([r.xmin,r.ymin]),l([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(l)};var s=e.dragOptions;e.dragOptions=i.extendDeep(s||{},{element:e.div,gd:n,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:a},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off("click",e.onClickInPanHandler),"select"===o||"lasso"===o?(r.dragPan.disable(),r.on("zoomstart",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){u(t,r,n,e.dragOptions,o)},c.init(e.dragOptions)):(r.dragPan.enable(),r.off("zoomstart",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on("click",e.onClickInPanHandler))}function l(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},g.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+"px",n.height=r.h*(e.y[1]-e.y[0])+"px",n.left=r.l+e.x[0]*r.w+"px",n.top=r.t+(1-e.y[1])*r.h+"px",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},g.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(p(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},g.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},g.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},g.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},g.getMapLayers=function(){return this.map.getStyle().layers},g.addLayer=function(t,e){var r=this.map;if("string"==typeof e){if(""===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),a=0;a<n.length;a++)if(e===n[a].id)return void r.addLayer(t,e);i.warn(["Trying to add layer with *below* value",e,"referencing a layer that does not exist","or that does not yet exist."].join(" "))}r.addLayer(t)},g.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},g.getView=function(){var t=this.map,e=t.getCenter(),r={lon:e.lng,lat:e.lat},n=t.getCanvas(),a=n.width,i=n.height;return{center:r,zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch(),_derived:{coordinates:[t.unproject([0,0]).toArray(),t.unproject([a,0]).toArray(),t.unproject([a,i]).toArray(),t.unproject([0,i]).toArray()]}}},g.getViewEdits=function(t){for(var e=this.id,r=["center","zoom","bearing","pitch"],n={},a=0;a<r.length;a++){var i=r[a];n[e+"."+i]=t[i]}return n},g.getViewEditsWithDerived=function(t){var e=this.id,r=this.getViewEdits(t);return r[e+"._derived"]=t._derived,r},e.exports=d},{"../../components/dragelement":609,"../../components/fx":630,"../../lib":717,"../../lib/geo_location_utils":711,"../../registry":846,"../cartesian/axes":765,"../cartesian/select":782,"./constants":818,"./layers":821,"mapbox-gl":427}],825:[function(t,e,r){"use strict";e.exports=function(t){var e=t.editType;return{t:{valType:"number",dflt:0,editType:e},r:{valType:"number",dflt:0,editType:e},b:{valType:"number",dflt:0,editType:e},l:{valType:"number",dflt:0,editType:e},editType:e}}},{}],826:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../registry"),o=t("../plot_api/plot_schema"),s=t("../plot_api/plot_template"),l=t("../lib"),c=t("../components/color"),u=t("../constants/numerical").BADNUM,h=t("./cartesian/axis_ids"),f=t("./animation_attributes"),p=t("./frame_attributes"),d=t("../plots/get_data").getModuleCalcData,g=l.relinkPrivateKeys,v=l._,m=e.exports={};l.extendFlat(m,i),m.attributes=t("./attributes"),m.attributes.type.values=m.allTypes,m.fontAttrs=t("./font_attributes"),m.layoutAttributes=t("./layout_attributes"),m.fontWeight="normal";var y=m.transformsRegistry,x=t("./command");m.executeAPICommand=x.executeAPICommand,m.computeAPICommandBindings=x.computeAPICommandBindings,m.manageCommandObserver=x.manageCommandObserver,m.hasSimpleAPICommandBindings=x.hasSimpleAPICommandBindings,m.redrawText=function(t){var e=(t=l.getGraphDiv(t))._fullLayout||{};if(!(!(e._has&&e._has("polar"))&&t.data&&t.data[0]&&t.data[0].r))return new Promise(function(e){setTimeout(function(){i.getComponentMethod("annotations","draw")(t),i.getComponentMethod("legend","draw")(t),i.getComponentMethod("colorbar","draw")(t),e(m.previousPromises(t))},300)})},m.resize=function(t){var e;t=l.getGraphDiv(t);var r=new Promise(function(r,n){t&&!l.isHidden(t)||n(new Error("Resize must be passed a displayed plot div element.")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._resolveResize&&(e=t._resolveResize),t._resolveResize=r,t._redrawTimer=setTimeout(function(){if(!t.layout||t.layout.width&&t.layout.height||l.isHidden(t))r(t);else{delete t.layout.width,delete t.layout.height;var e=t.changed;t.autoplay=!0,i.call("relayout",t,{autosize:!0}).then(function(){t.changed=e,t._resolveResize===r&&(delete t._resolveResize,r(t))})}},100)});return e&&e(r),r},m.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then(function(){t._promises=[]})},m.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=l.ensureSingle(e._paper,"text","js-plot-link-container",function(t){t.style({"font-family":'"Open Sans", Arial, sans-serif',"font-size":"12px",fill:c.defaultLine,"pointer-events":"all"}).each(function(){var t=n.select(this);t.append("tspan").classed("js-link-to-tool",!0),t.append("tspan").classed("js-link-spacer",!0),t.append("tspan").classed("js-sourcelinks",!0)})}),a=r.node(),i={y:e._paper.attr("height")-9};document.body.contains(a)&&a.getComputedTextLength()>=e.width-20?(i["text-anchor"]="start",i.x=5):(i["text-anchor"]="end",i.x=e._paper.attr("width")-7),r.attr(i);var o=r.select(".js-link-to-tool"),s=r.select(".js-link-spacer"),u=r.select(".js-sourcelinks");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text("");var r=e.append("a").attr({"xlink:xlink:href":"#",class:"link--impt link--embedview","font-weight":"bold"}).text(t._context.linkText+" "+String.fromCharCode(187));if(t._context.sendData)r.on("click",function(){m.sendDataToCloud(t)});else{var n=window.location.pathname.split("/"),a=window.location.search;r.attr({"xlink:xlink:show":"new","xlink:xlink:href":"/"+n[2].split(".")[0]+"/"+n[1]+a})}}(t,o),s.text(o.text()&&u.text()?" - ":"")}},m.sendDataToCloud=function(t){var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL;if(e){t.emit("plotly_beforeexport");var r=n.select(t).append("div").attr("id","hiddenform").style("display","none"),a=r.append("form").attr({action:e+"/external",method:"post",target:"_blank"});return a.append("input").attr({type:"text",name:"data"}).node().value=m.graphJson(t,!1,"keepdata"),a.node().submit(),r.remove(),t.emit("plotly_afterexport"),!1}};var b=["days","shortDays","months","shortMonths","periods","dateTime","date","time","decimal","thousands","grouping","currency"],_=["year","month","dayMonth","dayMonthYear"];function w(t,e){var r=t._context.locale,n=!1,a={};function o(t){for(var r=!0,i=0;i<e.length;i++){var o=e[i];a[o]||(t[o]?a[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(o(u),n))break;l=i.localeRegistry}var h=r.split("-")[0];if(n||h===r)break;r=h}return n||o(i.localeRegistry.en.format),a}function k(t,e){var r={_fullLayout:e},n="x"===t._id.charAt(0),a=t._mainAxis._anchorAxis,i="",o="",s="";if(a&&(s=a._mainAxis._id,i=n?t._id+s:s+t._id),!i||!e._plots[i]){i="";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],f=n?t._id+u:u+t._id;o||(o=f);var p=h.getFromId(r,u);if(s&&p.overlaying===s){i=f;break}}}return i||o}function T(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],a=n._module||y[n.type];if(a&&a.makesData)return!0}return!1}function M(t,e,r,n){for(var a=t.transforms,i=[t],o=0;o<a.length;o++){var s=a[o],l=y[s.type];l&&l.transform&&(i=l.transform(i,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return i}function A(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}m.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,a=t._fullLayout||{};if(a._skipDefaults)delete a._skipDefaults;else{var o,s=t._fullLayout={},c=t.layout||{},u=t._fullData||[],h=t._fullData=[],f=t.data||[],p=t.calcdata||[],d=t._context||{};t._transitionData||m.createTransitionData(t),s._dfltTitle={plot:v(t,"Click to enter Plot title"),x:v(t,"Click to enter X axis title"),y:v(t,"Click to enter Y axis title"),colorbar:v(t,"Click to enter Colorscale title"),annotation:v(t,"new text")},s._traceWord=v(t,"trace");var y=w(t,b);if(s._mapboxAccessToken=d.mapboxAccessToken,a._initialAutoSizeIsDone){var x=a.width,k=a.height;m.supplyLayoutGlobalDefaults(c,s,y),c.width||(s.width=x),c.height||(s.height=k),m.sanitizeMargins(s)}else{m.supplyLayoutGlobalDefaults(c,s,y);var T=!c.width||!c.height,M=s.autosize,S=d.autosizable;T&&(M||S)?m.plotAutoSize(t,c,s):T&&m.sanitizeMargins(s),!M&&T&&(c.width=s.width,c.height=s.height)}s._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),n.locale(t)}(y,s.separators),s._extraFormat=w(t,_),s._initialAutoSizeIsDone=!0,s._dataLength=f.length,s._modules=[],s._visibleModules=[],s._basePlotModules=[];var E=s._subplots=function(){var t,e,r=i.collectableSubplotTypes,n={};if(!r){r=[];var a=i.subplotsRegistry;for(var o in a){var s=a[o],c=s.attr;if(c&&(r.push(o),Array.isArray(c)))for(e=0;e<c.length;e++)l.pushUnique(r,c[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),L=s._splomAxes={x:{},y:{}},C=s._splomSubplots={};s._splomGridDflt={},s._scatterStackOpts={},s._firstScatter={},s._alignmentOpts={},s._colorAxes={},s._requestRangeslider={},s._traceUids=function(t,e){var r,n,a=e.length,i=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&i.push(o),n=o}var s=i.length,c=new Array(a),u={};function h(t,e){c[e]=t,u[t]=1}function f(t,e){if(t&&"string"==typeof t&&!u[t])return h(t,e),!0}for(r=0;r<a;r++){var p=e[r].uid;"number"==typeof p&&(p=String(p)),f(p,r)||(r<s&&f(i[r].uid,r)||h(l.randstr(u),r))}return c}(u,f),s._globalTransforms=(t._context||{}).globalTransforms,m.supplyDataDefaults(f,h,c,s);var P=Object.keys(L.x),O=Object.keys(L.y);if(P.length>1&&O.length>1){for(i.getComponentMethod("grid","sizeDefaults")(c,s),o=0;o<P.length;o++)l.pushUnique(E.xaxis,P[o]);for(o=0;o<O.length;o++)l.pushUnique(E.yaxis,O[o]);for(var z in C)l.pushUnique(E.cartesian,z)}if(s._has=m._hasPlotType.bind(s),u.length===h.length)for(o=0;o<h.length;o++)g(h[o],u[o]);m.supplyLayoutModuleDefaults(c,s,h,t._transitionData);var I=s._visibleModules,D=[];for(o=0;o<I.length;o++){var R=I[o].crossTraceDefaults;R&&l.pushUnique(D,R)}for(o=0;o<D.length;o++)D[o](h,s);s._hasOnlyLargeSploms=1===s._basePlotModules.length&&"splom"===s._basePlotModules[0].name&&P.length>15&&O.length>15&&0===s.shapes.length&&0===s.images.length,s._hasCartesian=s._has("cartesian"),s._hasGeo=s._has("geo"),s._hasGL3D=s._has("gl3d"),s._hasGL2D=s._has("gl2d"),s._hasTernary=s._has("ternary"),s._hasPie=s._has("pie"),m.linkSubplots(h,s,u,a),m.cleanPlot(h,s,u,a),a._zoomlayer&&!t._dragging&&a._zoomlayer.selectAll(".select-outline").remove(),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var a=0;a<t.length;a++){var i=t[a];i.meta?n[i.index]=i._meta={meta:i.meta}:e.meta&&(i._meta={meta:e.meta}),e.meta&&(i._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(h,s),g(s,a),i.getComponentMethod("colorscale","crossTraceDefaults")(h,s),s._preGUI||(s._preGUI={}),s._tracePreGUI||(s._tracePreGUI={});var F,B=s._tracePreGUI,N={};for(F in B)N[F]="old";for(o=0;o<h.length;o++)N[F=h[o]._fullInput.uid]||(B[F]={}),N[F]="new";for(F in N)"old"===N[F]&&delete B[F];A(s),i.getComponentMethod("rangeslider","makeData")(s),r||p.length!==h.length||m.supplyDefaultsUpdateCalc(p,h)}},m.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],a=(t[r]||[])[0];if(a&&a.trace){var i=a.trace;if(i._hasCalcTransform){var o,s,c,u=i._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],c=l.nestedProperty(i,s).get().slice(),l.nestedProperty(n,s).set(c)}a.trace=n}}},m.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},m._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var a=n[e].name;if(a===t)return!0;var o=i.modules[a];if(o&&o.categories[t])return!0}return!1},m.cleanPlot=function(t,e,r,n){var a,i,o=n._basePlotModules||[];for(a=0;a<o.length;a++){var s=o[a];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has("gl"),c=e._has&&e._has("gl");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(".gl-canvas").remove(),n._glcontainer.selectAll(".no-webgl").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(a=0;a<r.length;a++){var h=r[a].uid;for(i=0;i<t.length;i++){if(h===t[i].uid)continue t}u&&n._infolayer.select(".cb"+h).remove()}},m.linkSubplots=function(t,e,r,n){var a,o,s=n._plots||{},c=e._plots={},u=e._subplots,f={_fullData:t,_fullLayout:e},p=u.cartesian.concat(u.gl2d||[]);for(a=0;a<p.length;a++){var d,g=p[a],v=s[g],m=h.getFromId(f,g,"x"),y=h.getFromId(f,g,"y");for(v?d=c[g]=v:(d=c[g]={}).id=g,m._counterAxes.push(y._id),y._counterAxes.push(m._id),m._subplotsWith.push(g),y._subplotsWith.push(g),d.xaxis=m,d.yaxis=y,d._hasClipOnAxisFalse=!1,o=0;o<t.length;o++){var x=t[o];if(x.xaxis===d.xaxis._id&&x.yaxis===d.yaxis._id&&!1===x.cliponaxis){d._hasClipOnAxisFalse=!0;break}}}var b,_=h.list(f,null,!0);for(a=0;a<_.length;a++){var w=null;(b=_[a]).overlaying&&(w=h.getFromId(f,b.overlaying))&&w.overlaying&&(b.overlaying=!1,w=null),b._mainAxis=w||b,w&&(b.domain=w.domain.slice()),b._anchorAxis="free"===b.anchor?null:h.getFromId(f,b.anchor)}for(a=0;a<_.length;a++)if((b=_[a])._counterAxes.sort(h.idSort),b._subplotsWith.sort(l.subplotSort),b._mainSubplot=k(b,e),b._counterAxes.length&&(b.spikemode&&-1!==b.spikemode.indexOf("across")||b.automargin&&b.mirror&&"free"!==b.anchor||i.getComponentMethod("rangeslider","isVisible")(b))){var T=1,M=0;for(o=0;o<b._counterAxes.length;o++){var A=h.getFromId(f,b._counterAxes[o]);T=Math.min(T,A.domain[0]),M=Math.max(M,A.domain[1])}T<M&&(b._counterDomainMin=T,b._counterDomainMax=M)}},m.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],o.crawl(t._module.attributes,function(t,n,a,i){r[i]=n,r.length=i+1,"color"===t.valType&&void 0===t.dflt&&e.push(r.join("."))})),n=0;n<e.length;n++){l.nestedProperty(t,"_input."+e[n]).get()||l.nestedProperty(t,e[n]).set(null)}},m.supplyDataDefaults=function(t,e,r,n){var a,o,c,u=n._modules,h=n._visibleModules,f=n._basePlotModules,p=0,d=0;function v(t){e.push(t);var r=t._module;r&&(l.pushUnique(u,r),!0===t.visible&&l.pushUnique(h,r),l.pushUnique(f,t._module.basePlotModule),p++,!1!==t._input.visible&&d++)}n._transformModules=[];var y={},x=[],b=(r.template||{}).data||{},_=s.traceTemplater(b);for(a=0;a<t.length;a++){if(c=t[a],(o=_.newTrace(c)).uid=n._traceUids[a],m.supplyTraceDefaults(c,o,d,n,a),o.index=a,o._input=c,o._expandedIndex=p,o.transforms&&o.transforms.length)for(var w=!1!==c.visible&&!1===o.visible,k=M(o,e,r,n),T=0;T<k.length;T++){var A=k[T],S={_template:o._template,type:o.type,uid:o.uid+T};w&&!1===A.visible&&delete A.visible,m.supplyTraceDefaults(A,S,p,n,a),g(S,A),S.index=a,S._input=c,S._fullInput=o,S._expandedIndex=p,S._expandedInput=A,v(S)}else o._fullInput=o,o._expandedInput=o,v(o);i.traceIs(o,"carpetAxis")&&(y[o.carpet]=o),i.traceIs(o,"carpetDependent")&&x.push(a)}for(a=0;a<x.length;a++)if((o=e[x[a]]).visible){var E=y[o.carpet];o._carpet=E,E&&E.visible?(o.xaxis=E.xaxis,o.yaxis=E.yaxis):o.visible=!1}},m.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return l.coerce(t||{},r,f,e,n)}if(n("mode"),n("direction"),n("fromcurrent"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=m.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=m.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=m.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=m.supplyAnimationTransitionDefaults(t.transition||{});return r},m.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.frame,r,n)}return r("duration"),r("redraw"),e},m.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.transition,r,n)}return r("duration"),r("easing"),e},m.supplyFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t,e,p,r,n)}return r("group"),r("name"),r("traces"),r("baseframe"),r("data"),r("layout"),e},m.supplyTraceDefaults=function(t,e,r,n,a){var o,s=n.colorway||c.defaults,u=s[r%s.length];function h(r,n){return l.coerce(t,e,m.attributes,r,n)}var f=h("visible");h("type"),h("name",n._traceWord+" "+a),h("uirevision",n.uirevision);var p=m.getModule(e);if(e._module=p,p){var d=p.basePlotModule,g=d.attr,v=d.attributes;if(g&&v){var y=n._subplots,x="";if(f||"gl2d"!==d.name){if(Array.isArray(g))for(o=0;o<g.length;o++){var b=g[o],_=l.coerce(t,e,v,b);y[b]&&l.pushUnique(y[b],_),x+=_}else x=l.coerce(t,e,v,g);y[d.name]&&l.pushUnique(y[d.name],x)}}}return f&&(h("customdata"),h("ids"),h("meta"),i.traceIs(e,"showLegend")?(l.coerce(t,e,p.attributes.showlegend?p.attributes:m.attributes,"showlegend"),h("legendgroup"),e._dfltShowLegend=!0):e._dfltShowLegend=!1,p&&p.supplyDefaults(t,e,u,n),i.traceIs(e,"noOpacity")||h("opacity"),i.traceIs(e,"notLegendIsolatable")&&(e.visible=!!e.visible),i.traceIs(e,"noHover")||(e.hovertemplate||l.coerceHoverinfo(t,e,n),"parcats"!==e.type&&i.getComponentMethod("fx","supplyDefaults")(t,e,u,n)),p&&p.selectPoints&&h("selectedpoints"),m.supplyTransformDefaults(t,e,n)),e},m.hasMakesDataTransform=T,m.supplyTransformDefaults=function(t,e,r){if(e._length||T(t)){var n=r._globalTransforms||[],a=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var i=t.transforms||[],o=n.concat(i),s=e.transforms=[],c=0;c<o.length;c++){var u,h=o[c],f=h.type,p=y[f],d=!(h._module&&h._module===p),g=p&&"function"==typeof p.transform;p||l.warn("Unrecognized transform type "+f+"."),p&&p.supplyDefaults&&(d||g)?((u=p.supplyDefaults(h,e,r,t)).type=f,u._module=p,l.pushUnique(a,p)):u=l.extendFlat({},h),s.push(u)}}},m.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return l.coerce(t,e,m.layoutAttributes,r,n)}var a=t.template;l.isPlainObject(a)&&(e.template=a,e._template=a.layout,e._dataTemplate=a.data);var o=l.coerceFont(n,"font");n("title.text",e._dfltTitle.plot),l.coerceFont(n,"title.font",{family:o.family,size:Math.round(1.4*o.size),color:o.color}),n("title.xref"),n("title.yref"),n("title.x"),n("title.y"),n("title.xanchor"),n("title.yanchor"),n("title.pad.t"),n("title.pad.r"),n("title.pad.b"),n("title.pad.l"),n("uniformtext.mode")&&n("uniformtext.minsize"),n("autosize",!(t.width&&t.height)),n("width"),n("height"),n("margin.l"),n("margin.r"),n("margin.t"),n("margin.b"),n("margin.pad"),n("margin.autoexpand"),t.width&&t.height&&m.sanitizeMargins(e),i.getComponentMethod("grid","sizeDefaults")(t,e),n("paper_bgcolor"),n("separators",r.decimal+r.thousands),n("hidesources"),n("colorway"),n("datarevision");var s=n("uirevision");n("editrevision",s),n("selectionrevision",s),n("modebar.orientation"),n("modebar.bgcolor",c.addOpacity(e.paper_bgcolor,.5));var u=c.contrast(c.rgb(e.modebar.bgcolor));n("modebar.color",c.addOpacity(u,.3)),n("modebar.activecolor",c.addOpacity(u,.7)),n("modebar.uirevision",s),n("meta"),l.isPlainObject(t.transition)&&(n("transition.duration"),n("transition.easing"),n("transition.ordering")),i.getComponentMethod("calendars","handleDefaults")(t,e,"calendar"),i.getComponentMethod("fx","supplyLayoutGlobalDefaults")(t,e,n)},m.plotAutoSize=function(t,e,r){var n,i,o=t._context||{},s=o.frameMargins,c=l.isPlotDiv(t);if(c&&t.emit("plotly_autosize"),o.fillFrame)n=window.innerWidth,i=window.innerHeight,document.body.style.overflow="hidden";else{var u=c?window.getComputedStyle(t):{};if(n=parseFloat(u.width)||parseFloat(u.maxWidth)||r.width,i=parseFloat(u.height)||parseFloat(u.maxHeight)||r.height,a(s)&&s>0){var h=1-2*s;n=Math.round(h*n),i=Math.round(h*i)}}var f=m.layoutAttributes.width.min,p=m.layoutAttributes.height.min;n<f&&(n=f),i<p&&(i=p);var d=!e.width&&Math.abs(r.width-n)>1,g=!e.height&&Math.abs(r.height-i)>1;(g||d)&&(d&&(r.width=n),g&&(r.height=i)),t._initialAutoSize||(t._initialAutoSize={width:n,height:i}),m.sanitizeMargins(r)},m.supplyLayoutModuleDefaults=function(t,e,r,n){var a,o,s,c=i.componentsRegistry,u=e._basePlotModules,h=i.subplotsRegistry.cartesian;for(a in c)(s=c[a]).includeBasePlot&&s.includeBasePlot(t,e);for(var f in u.length||u.push(h),e._has("cartesian")&&(i.getComponentMethod("grid","contentDefaults")(t,e),h.finalizeSubplots(t,e)),e._subplots)e._subplots[f].sort(l.subplotSort);for(o=0;o<u.length;o++)(s=u[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(o=0;o<p.length;o++)(s=p[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(o=0;o<d.length;o++)(s=d[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(a in c)(s=c[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},m.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(".gl-canvas").remove(),e._glcontainer.remove(),e._glcanvas=null),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),l.clearThrottle(),l.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.framework,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},m.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var a=r[e];a.style&&l.pushUnique(n,a.style)}for(e=0;e<n.length;e++)n[e](t)},m.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,a=t.margin,i=r-(a.l+a.r),o=n-(a.t+a.b);i<0&&(e=(r-1)/(a.l+a.r),a.l=Math.floor(e*a.l),a.r=Math.floor(e*a.r)),o<0&&(e=(n-1)/(a.t+a.b),a.t=Math.floor(e*a.t),a.b=Math.floor(e*a.b))}},m.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},m.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1},m.autoMargin=function(t,e,r){var n=t._fullLayout,a=n._pushmargin,i=n._pushmarginIds;if(!1!==n.margin.autoexpand){if(r){var o=r.pad;if(void 0===o){var s=n.margin;o=Math.min(12,s.l,s.r,s.t,s.b)}r.l+r.r>.5*n.width&&(l.log("Margin push",e,"is too big in x, dropping"),r.l=r.r=0),r.b+r.t>.5*n.height&&(l.log("Margin push",e,"is too big in y, dropping"),r.b=r.t=0);var c=void 0!==r.xl?r.xl:r.x,u=void 0!==r.xr?r.xr:r.x,h=void 0!==r.yt?r.yt:r.y,f=void 0!==r.yb?r.yb:r.y;a[e]={l:{val:c,size:r.l+o},r:{val:u,size:r.r+o},b:{val:f,size:r.b+o},t:{val:h,size:r.t+o}},i[e]=1}else delete a[e],delete i[e];if(!n._replotting)return m.doAutoMargin(t)}},m.doAutoMargin=function(t){var e=t._fullLayout;e._size||(e._size={}),A(e);var r=e._size,n=e.margin,o=l.extendFlat({},r),s=n.l,c=n.r,u=n.t,h=n.b,f=e.width,p=e.height,d=e._pushmargin,g=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var v in d)g[v]||delete d[v];for(var y in d.base={l:{val:0,size:s},r:{val:1,size:c},t:{val:1,size:u},b:{val:0,size:h}},d){var x=d[y].l||{},b=d[y].b||{},_=x.val,w=x.size,k=b.val,T=b.size;for(var M in d){if(a(w)&&d[M].r){var S=d[M].r.val,E=d[M].r.size;if(S>_){var L=(w*S+(E-f)*_)/(S-_),C=(E*(1-_)+(w-f)*(1-S))/(S-_);L>=0&&C>=0&&f-(L+C)>0&&L+C>s+c&&(s=L,c=C)}}if(a(T)&&d[M].t){var P=d[M].t.val,O=d[M].t.size;if(P>k){var z=(T*P+(O-p)*k)/(P-k),I=(O*(1-k)+(T-p)*(1-P))/(P-k);z>=0&&I>=0&&p-(I+z)>0&&z+I>h+u&&(h=z,u=I)}}}}}if(r.l=Math.round(s),r.r=Math.round(c),r.t=Math.round(u),r.b=Math.round(h),r.p=Math.round(n.pad),r.w=Math.round(f)-r.l-r.r,r.h=Math.round(p)-r.t-r.b,!e._replotting&&m.didMarginChange(o,r)){"_redrawFromAutoMarginCount"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1;var D=3*(1+Object.keys(g).length);if(e._redrawFromAutoMarginCount<D)return i.call("plot",t);l.warn("Too many auto-margin redraws.")}};var S=["l","r","t","b","p","w","h"];function E(t,e,r){var n=!1;var a=[m.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,m.rehover,function(){return t.emit("plotly_transitioning",[]),new Promise(function(a){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push(function(){n=!0}),r.redraw&&t._transitionData._interruptCallbacks.push(function(){return i.call("redraw",t)}),t._transitionData._interruptCallbacks.push(function(){t.emit("plotly_transitioninterrupted",[])});var o=0,s=0;function l(){return o++,function(){var e;s++,n||s!==o||(e=a,t._transitionData&&(function(t){if(t)for(;t.length;)t.shift()}(t._transitionData._interruptCallbacks),Promise.resolve().then(function(){if(r.redraw)return i.call("redraw",t)}).then(function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit("plotly_transitioned",[])}).then(e)))}}r.runFn(l),setTimeout(l())})}],o=l.syncOrAsync(a,t);return o&&o.then||(o=Promise.resolve()),o.then(function(){return t})}m.didMarginChange=function(t,e){for(var r=0;r<S.length;r++){var n=S[r],i=t[n],o=e[n];if(!a(i)||Math.abs(o-i)>1)return!0}return!1},m.graphJson=function(t,e,r,n,a,i){(a&&e&&!t._fullData||a&&!e&&!t._fullLayout)&&m.supplyDefaults(t);var o=a?t._fullData:t.data,s=a?t._fullLayout:t.layout,c=(t._transitionData||{})._frames;function u(t,e){if("function"==typeof t)return e?"_function_":null;if(l.isPlainObject(t)){var n,a={};return Object.keys(t).sort().forEach(function(i){if(-1===["_","["].indexOf(i.charAt(0)))if("function"!=typeof t[i]){if("keepdata"===r){if("src"===i.substr(i.length-3))return}else if("keepstream"===r){if("string"==typeof(n=t[i+"src"])&&n.indexOf(":")>0&&!l.isPlainObject(t.stream))return}else if("keepall"!==r&&"string"==typeof(n=t[i+"src"])&&n.indexOf(":")>0)return;a[i]=u(t[i],e)}else e&&(a[i]="_function")}),a}return Array.isArray(t)?t.map(function(t){return u(t,e)}):l.isTypedArray(t)?l.simpleMap(t,l.identity):l.isJSDate(t)?l.ms2DateTimeLocal(+t):t}var h={data:(o||[]).map(function(t){var r=u(t);return e&&delete r.fit,r})};return e||(h.layout=u(s)),t.framework&&t.framework.isPolar&&(h=t.framework.getConfig()),c&&(h.frames=u(c)),i&&(h.config=u(t._context,!0)),"object"===n?h:JSON.stringify(h)},m.modifyFrames=function(t,e){var r,n,a,i=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case"replace":a=n.value;var s=(i[n.index]||{}).name,l=a.name;i[n.index]=o[l]=a,l!==s&&(delete o[s],o[l]=a);break;case"insert":o[(a=n.value).name]=a,i.splice(n.index,0,a);break;case"delete":delete o[(a=i[n.index]).name],i.splice(n.index,1)}return Promise.resolve()},m.computeFrame=function(t,e){var r,n,a,i,o=t._transitionData._frameHash;if(!e)throw new Error("computeFrame must be given a string frame name");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=m.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(a=n[r])&&(-1===(i=u.traces.indexOf(a))&&(i=u.data.length,u.traces[i]=a),u.data[i]=m.extendTrace(u.data[i],s.data[r]))}return u},m.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var a=r[n];a&&a.name&&(e[a.name]=a)}},m.extendObjectWithContainers=function(t,e,r){var n,a,i,o,s,c,u,h=l.extendDeepNoArrays({},e||{}),f=l.expandObjectPaths(h),p={};if(r&&r.length)for(i=0;i<r.length;i++)void 0===(a=(n=l.nestedProperty(f,r[i])).get())?l.nestedProperty(p,r[i]).set(null):(n.set(null),l.nestedProperty(p,r[i]).set(a));if(t=l.extendDeepNoArrays(t||{},f),r&&r.length)for(i=0;i<r.length;i++)if(c=l.nestedProperty(p,r[i]).get()){for(u=(s=l.nestedProperty(t,r[i])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<c.length;o++){var d=c[o];u[o]=null===d?null:m.extendObjectWithContainers(u[o],d)}s.set(u)}return t},m.dataArrayContainers=["transforms","dimensions"],m.layoutArrayContainers=i.layoutArrayContainers,m.extendTrace=function(t,e){return m.extendObjectWithContainers(t,e,m.dataArrayContainers)},m.extendLayout=function(t,e){return m.extendObjectWithContainers(t,e,m.layoutArrayContainers)},m.transition=function(t,e,r,n,a,i){var o={redraw:a.redraw},s={},c=[];return o.prepareFn=function(){for(var a=Array.isArray(e)?e.length:0,i=n.slice(0,a),o=0;o<i.length;o++){var u=i[o],h=t._fullData[u]._module;if(h){if(h.animatable){var f=h.basePlotModule.name;s[f]||(s[f]=[]),s[f].push(u)}t.data[i[o]]=m.extendTrace(t.data[i[o]],e[o])}}var p=l.expandObjectPaths(l.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var g in p)d.test(g)&&delete p[g].range;m.extendLayout(t.layout,p),delete t.calcdata,m.supplyDefaults(t),m.doCalcdata(t);var v=l.expandObjectPaths(r);if(v){var y=t._fullLayout._plots;for(var x in y){var b=y[x],_=b.xaxis,w=b.yaxis,k=_.range.slice(),T=w.range.slice(),M=null,A=null,S=null,E=null;Array.isArray(v[_._name+".range"])?M=v[_._name+".range"].slice():Array.isArray((v[_._name]||{}).range)&&(M=v[_._name].range.slice()),Array.isArray(v[w._name+".range"])?A=v[w._name+".range"].slice():Array.isArray((v[w._name]||{}).range)&&(A=v[w._name].range.slice()),k&&M&&(_.r2l(k[0])!==_.r2l(M[0])||_.r2l(k[1])!==_.r2l(M[1]))&&(S={xr0:k,xr1:M}),T&&A&&(w.r2l(T[0])!==w.r2l(A[0])||w.r2l(T[1])!==w.r2l(A[1]))&&(E={yr0:T,yr1:A}),(S||E)&&c.push(l.extendFlat({plotinfo:b},S,E))}}return Promise.resolve()},o.runFn=function(e){var n,a,o=t._fullLayout._basePlotModules,u=c.length;if(r)for(a=0;a<o.length;a++)o[a].transitionAxes&&o[a].transitionAxes(t,c,i,e);for(var h in u?((n=l.extendFlat({},i)).duration=0,delete s.cartesian):n=i,s){var f=s[h];t._fullData[f[0]]._module.basePlotModule.plot(t,f,n,e)}},E(t,i,o)},m.transitionFromReact=function(t,e,r,n){var a=t._fullLayout,i=a.transition,o={},s=[];return o.prepareFn=function(){var t=a._plots;for(var i in o.redraw=!1,"some"===e.anim&&(o.redraw=!0),"some"===r.anim&&(o.redraw=!0),t){var c=t[i],u=c.xaxis,h=c.yaxis,f=n[u._name].range.slice(),p=n[h._name].range.slice(),d=u.range.slice(),g=h.range.slice();u.setScale(),h.setScale();var v=null,m=null;u.r2l(f[0])===u.r2l(d[0])&&u.r2l(f[1])===u.r2l(d[1])||(v={xr0:f,xr1:d}),h.r2l(p[0])===h.r2l(g[0])&&h.r2l(p[1])===h.r2l(g[1])||(m={yr0:p,yr1:g}),(v||m)&&s.push(l.extendFlat({plotinfo:c},v,m))}return Promise.resolve()},o.runFn=function(r){for(var n,a,o,c=t._fullData,u=t._fullLayout._basePlotModules,h=[],f=0;f<c.length;f++)h.push(f);function p(){for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){for(var e=0;e<u.length;e++)u[e].plot(t,o,a,r)}s.length&&e.anim?"traces first"===i.ordering?(n=l.extendFlat({},i,{duration:0}),o=h,a=i,setTimeout(p,i.duration),d()):(n=i,o=null,a=l.extendFlat({},i,{duration:0}),setTimeout(d,n.duration),p()):s.length?(n=i,p()):e.anim&&(o=h,a=i,d())},E(t,i,o)},m.doCalcdata=function(t,e){var r,n,a,s,c=h.list(t),f=t._fullData,p=t._fullLayout,d=new Array(f.length),g=(t.calcdata||[]).slice();for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},p._sunburstcolormap={},p._treemapcolormap={},p._funnelareacolormap={},a=0;a<f.length;a++)Array.isArray(e)&&-1===e.indexOf(a)&&(d[a]=g[a]);for(a=0;a<f.length;a++)(r=f[a])._arrayAttrs=o.findArrayAttributes(r),r._extremes={};var v=p._subplots.polar||[];for(a=0;a<v.length;a++)c.push(p[v[a]].radialaxis,p[v[a]].angularaxis);for(var m in p._colorAxes){var x=p[m];!1!==x.cauto&&(delete x.cmin,delete x.cmax)}var b=!1;function _(e){if(r=f[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var a=n.calc(t,r);a[0]&&a[0].t&&a[0].t._scene&&delete a[0].t._scene.dirty}for(s=0;s<r.transforms.length;s++){var i=r.transforms[s];(n=y[i.type])&&n.calcTransform&&(r._hasCalcTransform=!0,b=!0,n.calcTransform(t,r,i))}}}function w(e,a){if(r=f[e],!!(n=r._module).isContainer===a){var i=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var o=r.transforms||[];for(s=o.length-1;s>=0;s--)if(o[s].enabled){r._indexToPoints=o[s]._indexToPoints;break}n&&n.calc&&(i=n.calc(t,r))}Array.isArray(i)&&i[0]||(i=[{x:u,y:u}]),i[0].t||(i[0].t={}),i[0].trace=r,d[e]=i}}for(C(c,f,p),a=0;a<f.length;a++)w(a,!0);for(a=0;a<f.length;a++)_(a);for(b&&C(c,f,p),a=0;a<f.length;a++)w(a,!0);for(a=0;a<f.length;a++)w(a,!1);P(t);var k=function(t,e){var r,n,a,o,s,c=[];function u(t,r,n){var a=r._id.charAt(0);if("histogram2dcontour"===t){var i=r._counterAxes[0],o=h.getFromId(e,i),s="x"===a||"x"===i&&"category"===o.type,l="y"===a||"y"===i&&"category"===o.type;return function(t,e){return 0===t||0===e?-1:s&&t===n[e].length-1?-1:l&&e===n.length-1?-1:("y"===a?e:t)-1}}return function(t,e){return"y"===a?e:t}}var f={min:function(t){return l.aggNums(Math.min,null,t)},max:function(t){return l.aggNums(Math.max,null,t)},sum:function(t){return l.aggNums(function(t,e){return t+e},null,t)},total:function(t){return l.aggNums(function(t,e){return t+e},null,t)},mean:function(t){return l.mean(t)},median:function(t){return l.median(t)}};for(r=0;r<t.length;r++){var p=t[r];if("category"===p.type){var d=p.categoryorder.match(L);if(d){var g=d[1],v=d[2],m=[];for(n=0;n<p._categories.length;n++)m.push([p._categories[n],[]]);for(n=0;n<p._traceIndices.length;n++){var y=p._traceIndices[n],x=e._fullData[y],b=p._id.charAt(0);if(!0===x.visible){var _=x.type;i.traceIs(x,"histogram")&&(delete x._xautoBinFinished,delete x._yautoBinFinished);var w=e.calcdata[y];for(a=0;a<w.length;a++){var k,T,M,A=w[a];if("splom"===_){var S=x._axesDim[p._id];if("y"===b){var E=x._diag[S][0];E&&(p=e._fullLayout[h.id2name(E)])}var C=A.trace.dimensions[S].values;for(o=0;o<C.length;o++)for(k=C[o],T=p._categoriesMap[k],s=0;s<A.trace.dimensions.length;s++)if(s!==S){var P=A.trace.dimensions[s];m[T][1].push(P.values[o])}}else if("scattergl"===_){for(o=0;o<A.t.x.length;o++)"x"===b&&(k=A.t.x[o],T=k,M=A.t.y[o]),"y"===b&&(k=A.t.y[o],T=k,M=A.t.x[o]),m[T][1].push(M);A.t&&A.t._scene&&delete A.t._scene.dirty}else if(A.hasOwnProperty("z")){M=A.z;var O=u(x.type,p,M);for(o=0;o<M.length;o++)for(s=0;s<M[o].length;s++)(T=O(s,o))+1&&m[T][1].push(M[o][s])}else for("x"===b?(k=A.p+1?A.p:A.x,M=A.s||A.v||A.y):"y"===b&&(k=A.p+1?A.p:A.y,M=A.s||A.v||A.x),Array.isArray(M)||(M=[M]),o=0;o<M.length;o++)m[k][1].push(M[o])}}}p._categoriesValue=m;var z=[];for(n=0;n<m.length;n++)z.push([m[n][0],f[g](m[n][1])]);z.sort(function(t,e){return t[1]-e[1]}),p._categoriesAggregatedValue=z,p._initialCategories=z.map(function(t){return t[0]}),"descending"===v&&p._initialCategories.reverse(),c=c.concat(p.sortByInitialCategories())}}}return c}(c,t);if(k.length){for(p._numBoxes=0,p._numViolins=0,a=0;a<k.length;a++)w(k[a],!0);for(a=0;a<k.length;a++)w(k[a],!1);P(t)}i.getComponentMethod("fx","calc")(t),i.getComponentMethod("errorbars","calc")(t)};var L=/(total|sum|min|max|mean|median) (ascending|descending)/;function C(t,e,r){var n,a,i,o={};for(n=0;n<t.length;n++)i=(a=t[n])._id,a.clearCalc(),"multicategory"===a.type&&a.setupMultiCategory(e),o[a._id]=1;var s=r._axisMatchGroups||[];for(n=0;n<s.length;n++)for(i in s[n])o[i]||(a=r[h.id2name(i)]).clearCalc()}function P(t){var e,r,n,a=t._fullLayout,i=a._visibleModules,o={};for(r=0;r<i.length;r++){var s=i[r],c=s.crossTraceCalc;if(c){var u=s.basePlotModule.name;o[u]?l.pushUnique(o[u],c):o[u]=[c]}}for(n in o){var h=o[n],f=a._subplots[n];if(Array.isArray(f))for(e=0;e<f.length;e++){var p=f[e],d="cartesian"===n?a._plots[p]:a[p];for(r=0;r<h.length;r++)h[r](t,d,p)}else for(r=0;r<h.length;r++)h[r](t)}}m.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},m.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},m.generalUpdatePerTraceModule=function(t,e,r,n){var a,i=e.traceHash,o={};for(a=0;a<r.length;a++){var s=r[a],c=s[0].trace;c.visible&&(o[c.type]=o[c.type]||[],o[c.type].push(s))}for(var u in i)if(!o[u]){var h=i[u][0];h[0].trace.visible=!1,o[u]=[h]}for(var f in o){var p=o[f];p[0][0].trace._module.plot(t,e,l.filterVisible(p),n)}e.traceHash=o},m.plotBasePlot=function(t,e,r,n,a){var o=i.getModule(t),s=d(e.calcdata,o)[0];o.plot(e,s,n,a)},m.cleanBasePlot=function(t,e,r,n,a){var i=a._has&&a._has(t),o=r._has&&r._has(t);i&&!o&&a["_"+t+"layer"].selectAll("g.trace").remove()}},{"../components/color":591,"../constants/numerical":693,"../lib":717,"../plot_api/plot_schema":754,"../plot_api/plot_template":755,"../plots/get_data":800,"../registry":846,"./animation_attributes":760,"./attributes":762,"./cartesian/axis_ids":768,"./command":789,"./font_attributes":791,"./frame_attributes":792,"./layout_attributes":817,d3:165,"fast-isnumeric":228}],827:[function(t,e,r){"use strict";e.exports={attr:"subplot",name:"polar",axisNames:["angularaxis","radialaxis"],axisName2dataArray:{angularaxis:"theta",radialaxis:"r"},layerNames:["draglayer","plotbg","backplot","angular-grid","radial-grid","frontplot","angular-line","radial-line","angular-axis","radial-axis"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],828:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../lib/polygon").tester,i=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var a,i,o=n[0],s=n[1],l=h(Math.sin(e)-Math.sin(t)),c=h(Math.cos(e)-Math.cos(t)),u=Math.tan(r),f=h(1/u),p=l/c,d=s-p*o;return f?l&&c?i=u*(a=d/(u-p)):c?(a=s*f,i=s):(a=o,i=o*u):l&&c?(a=0,i=d):c?(a=0,i=s):a=i=NaN,[a,i]}function u(t,e,r,a){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,a=new Array(n+1);for(r=0;r<n;r++){var i=e[r];a[r]=[t*Math.cos(i),t*Math.sin(i)]}return a[r]=a[0].slice(),a}(t,a):function(t,e,r,a){var s,u,h=a.length,f=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function g(t){return n.mod(t,h)}function v(t){return o(t,[e,r])}var m=i(a,function(t){return v(t)?l(t,e):1/0}),y=d(a[m],a[g(m-1)],e);for(f.push(y),s=m,u=0;u<h;s++,u++){var x=a[g(s)];if(!v(x))break;f.push(p(x))}var b=i(a,function(t){return v(t)?l(t,r):1/0}),_=d(a[b],a[g(b+1)],r);return f.push(_),f.push([0,0]),f.push(f[0].slice()),f}(t,e,r,a)}function h(t){return Math.abs(t)>1e-10?t:0}function f(t,e,r){e=e||0,r=r||0;for(var n=t.length,a=new Array(n),i=0;i<n;i++){var o=t[i];a[i]=[e+o[0],r-o[1]]}return a}e.exports={isPtInsidePolygon:function(t,e,r,n,i){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=a(u(s,n[0],n[1],i)),h=a(u(l,n[0],n[1],i)),f=[t*Math.cos(e),t*Math.sin(e)];return h.contains(f)&&!c.contains(f)},findPolygonOffset:function(t,e,r,n){for(var a=1/0,i=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];a=Math.min(a,l[0]),i=Math.min(i,-l[1])}return[a,i]},findEnclosingVertexAngles:function(t,e){var r=i(e,function(e){var r=s(e,t);return r>0?r:1/0}),a=n.mod(r+1,e.length);return[e[r],e[a]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var a=-e*r,i=e*e+1,o=2*(e*a-r),s=a*a+r*r-t*t,l=Math.sqrt(o*o-4*i*s),c=(-o+l)/(2*i),u=(-o-l)/(2*i);return[[c,e*c+a+n],[u,e*u+a+n]]},clampTiny:h,pathPolygon:function(t,e,r,n,a,i){return"M"+f(u(t,e,r,n),a,i).join("L")},pathPolygonAnnulus:function(t,e,r,n,a,i,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=f(u(s,r,n,a),i,o);return"M"+f(u(l,r,n,a),i,o).reverse().join("L")+"M"+c.join("L")}}},{"../../lib":717,"../../lib/polygon":729}],829:[function(t,e,r){"use strict";var n=t("../get_data").getSubplotCalcData,a=t("../../lib").counterRegex,i=t("./polar"),o=t("./constants"),s=o.attr,l=o.name,c=a(l),u={};u[s]={valType:"subplotid",dflt:l,editType:"calc"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t("./layout_attributes"),supplyLayoutDefaults:t("./layout_defaults"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots[l],o=0;o<a.length;o++){var s=a[o],c=n(r,l,s),u=e[s]._subplot;u||(u=i(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var a=n._subplots[l]||[],i=n._has&&n._has("gl"),o=e._has&&e._has("gl"),s=i&&!o,c=0;c<a.length;c++){var u=a[c],h=n[u]._subplot;if(!e[u]&&h)for(var f in h.framework.remove(),h.layers["radial-axis-title"].remove(),h.clipPaths)h.clipPaths[f].remove();s&&h._scene&&(h._scene.destroy(),h._scene=null)}},toSVG:t("../cartesian").toSVG}},{"../../lib":717,"../cartesian":776,"../get_data":800,"./constants":827,"./layout_attributes":830,"./layout_defaults":831,"./polar":838}],830:[function(t,e,r){"use strict";var n=t("../../components/color/attributes"),a=t("../cartesian/layout_attributes"),i=t("../domain").attributes,o=t("../../lib").extendFlat,s=t("../../plot_api/edit_types").overrideAll,l=s({color:a.color,showline:o({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:o({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth},"plot","from-root"),c=s({tickmode:a.tickmode,nticks:a.nticks,tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,layer:a.layer},"plot","from-root"),u={visible:o({},a.visible,{dflt:!0}),type:o({},a.type,{values:["-","linear","log","date","category"]}),autorange:o({},a.autorange,{editType:"plot"}),rangemode:{valType:"enumerated",values:["tozero","nonnegative","normal"],dflt:"tozero",editType:"calc"},range:o({},a.range,{items:[{valType:"any",editType:"plot",impliedEdits:{"^autorange":!1}},{valType:"any",editType:"plot",impliedEdits:{"^autorange":!1}}],editType:"plot"}),categoryorder:a.categoryorder,categoryarray:a.categoryarray,angle:{valType:"angle",editType:"plot"},side:{valType:"enumerated",values:["clockwise","counterclockwise"],dflt:"clockwise",editType:"plot"},title:{text:o({},a.title.text,{editType:"plot",dflt:""}),font:o({},a.title.font,{editType:"plot"}),editType:"plot"},hoverformat:a.hoverformat,uirevision:{valType:"any",editType:"none"},editType:"calc",_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}};o(u,l,c);var h={visible:o({},a.visible,{dflt:!0}),type:{valType:"enumerated",values:["-","linear","category"],dflt:"-",editType:"calc",_noTemplating:!0},categoryorder:a.categoryorder,categoryarray:a.categoryarray,thetaunit:{valType:"enumerated",values:["radians","degrees"],dflt:"degrees",editType:"calc"},period:{valType:"number",editType:"calc",min:0},direction:{valType:"enumerated",values:["counterclockwise","clockwise"],dflt:"counterclockwise",editType:"calc"},rotation:{valType:"angle",editType:"calc"},hoverformat:a.hoverformat,uirevision:{valType:"any",editType:"none"},editType:"calc"};o(h,l,c),e.exports={domain:i({name:"polar",editType:"plot"}),sector:{valType:"info_array",items:[{valType:"number",editType:"plot"},{valType:"number",editType:"plot"}],dflt:[0,360],editType:"plot"},hole:{valType:"number",min:0,max:1,dflt:0,editType:"plot"},bgcolor:{valType:"color",editType:"plot",dflt:n.background},radialaxis:u,angularaxis:h,gridshape:{valType:"enumerated",values:["circular","linear"],dflt:"circular",editType:"plot"},uirevision:{valType:"any",editType:"none"},editType:"calc"}},{"../../components/color/attributes":590,"../../lib":717,"../../plot_api/edit_types":748,"../cartesian/layout_attributes":777,"../domain":790}],831:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/color"),i=t("../../plot_api/plot_template"),o=t("../subplot_defaults"),s=t("../get_data").getSubplotData,l=t("../cartesian/tick_value_defaults"),c=t("../cartesian/tick_mark_defaults"),u=t("../cartesian/tick_label_defaults"),h=t("../cartesian/category_order_defaults"),f=t("../cartesian/line_grid_defaults"),p=t("../cartesian/axis_autotype"),d=t("./layout_attributes"),g=t("./set_convert"),v=t("./constants"),m=v.axisNames;function y(t,e,r,o){var p=r("bgcolor");o.bgColor=a.combine(p,o.paper_bgcolor);var y=r("sector");r("hole");var b,_=s(o.fullData,v.name,o.id),w=o.layoutOut;function k(t,e){return r(b+"."+t,e)}for(var T=0;T<m.length;T++){b=m[T],n.isPlainObject(t[b])||(t[b]={});var M=t[b],A=i.newContainer(e,b);A._id=A._name=b,A._attr=o.id+"."+b,A._traceIndices=_.map(function(t){return t._expandedIndex});var S=v.axisName2dataArray[b],E=x(M,A,k,_,S);h(M,A,k,{axData:_,dataAttr:S});var L,C,P=k("visible");switch(g(A,e,w),k("uirevision",e.uirevision),P&&(C=(L=k("color"))===M.color?L:o.font.color),A._m=1,b){case"radialaxis":var O=k("autorange",!A.isValidRange(M.range));M.autorange=O,!O||"linear"!==E&&"-"!==E||k("rangemode"),"reversed"===O&&(A._m=-1),k("range"),A.cleanRange("range",{dfltRange:[0,1]}),P&&(k("side"),k("angle",y[0]),k("title.text"),n.coerceFont(k,"title.font",{family:o.font.family,size:Math.round(1.2*o.font.size),color:C}));break;case"angularaxis":if("date"===E){n.log("Polar plots do not support date angular axes yet.");for(var z=0;z<_.length;z++)_[z].visible=!1;E=M.type=A.type="linear"}k("linear"===E?"thetaunit":"period");var I=k("direction");k("rotation",{counterclockwise:0,clockwise:90}[I])}if(P)l(M,A,k,A.type),u(M,A,k,A.type,{tickSuffixDflt:"degrees"===A.thetaunit?"\xb0":void 0}),c(M,A,k,{outerTicks:!0}),k("showticklabels")&&(n.coerceFont(k,"tickfont",{family:o.font.family,size:o.font.size,color:C}),k("tickangle"),k("tickformat")),f(M,A,k,{dfltColor:L,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),k("layer");"category"!==E&&k("hoverformat"),A._input=M}"category"===e.angularaxis.type&&r("gridshape")}function x(t,e,r,n,a){if("-"===r("type")){for(var i,o=0;o<n.length;o++)if(n[o].visible){i=n[o];break}i&&i[a]&&(e.type=p(i[a],"gregorian")),"-"===e.type?e.type="linear":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:v.name,attributes:d,handleDefaults:y,font:e.font,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{"../../components/color":591,"../../lib":717,"../../plot_api/plot_template":755,"../cartesian/axis_autotype":766,"../cartesian/category_order_defaults":769,"../cartesian/line_grid_defaults":779,"../cartesian/tick_label_defaults":784,"../cartesian/tick_mark_defaults":785,"../cartesian/tick_value_defaults":786,"../get_data":800,"../subplot_defaults":840,"./constants":827,"./layout_attributes":830,"./set_convert":839}],832:[function(t,e,r){"use strict";var n=t("../../../traces/scatter/attributes"),a=n.marker,i=t("../../../lib/extend").extendFlat;["Area traces are deprecated!","Please switch to the *barpolar* trace type."].join(" ");e.exports={r:i({},n.r,{}),t:i({},n.t,{}),marker:{color:i({},a.color,{}),size:i({},a.size,{}),symbol:i({},a.symbol,{}),opacity:i({},a.opacity,{}),editType:"calc"}}},{"../../../lib/extend":708,"../../../traces/scatter/attributes":1120}],833:[function(t,e,r){"use strict";var n=t("../../cartesian/layout_attributes"),a=t("../../../lib/extend").extendFlat,i=t("../../../plot_api/edit_types").overrideAll,o=["Legacy polar charts are deprecated!","Please switch to *polar* subplots."].join(" "),s=a({},n.domain,{});function l(t,e){return a({},e,{showline:{valType:"boolean"},showticklabels:{valType:"boolean"},tickorientation:{valType:"enumerated",values:["horizontal","vertical"]},ticklen:{valType:"number",min:0},tickcolor:{valType:"color"},ticksuffix:{valType:"string"},endpadding:{valType:"number",description:o},visible:{valType:"boolean"}})}e.exports=i({radialaxis:l(0,{range:{valType:"info_array",items:[{valType:"number"},{valType:"number"}]},domain:s,orientation:{valType:"number"}}),angularaxis:l(0,{range:{valType:"info_array",items:[{valType:"number",dflt:0},{valType:"number",dflt:360}]},domain:s}),layout:{direction:{valType:"enumerated",values:["clockwise","counterclockwise"]},orientation:{valType:"angle"}}},"plot","nested")},{"../../../lib/extend":708,"../../../plot_api/edit_types":748,"../../cartesian/layout_attributes":777}],834:[function(t,e,r){"use strict";(e.exports=t("./micropolar")).manager=t("./micropolar_manager")},{"./micropolar":835,"./micropolar_manager":836}],835:[function(t,e,r){var n=t("d3"),a=t("../../../lib").extendDeepAll,i=t("../../../constants/alignment").MID_SHIFT,o=e.exports={version:"0.2.2"};o.Axis=function(){var t,e,r,s,l={data:[],layout:{}},c={},u={},h=n.dispatch("hover"),f={};return f.render=function(c){return function(c){e=c||e;var h=l.data,f=l.layout;("string"==typeof e||e.nodeName)&&(e=n.select(e)),e.datum(h).each(function(e,l){var c=e.slice();u={data:o.util.cloneJson(c),layout:o.util.cloneJson(f)};var h=0;c.forEach(function(t,e){t.color||(t.color=f.defaultColorRange[h],h=(h+1)%f.defaultColorRange.length),t.strokeColor||(t.strokeColor="LinePlot"===t.geometry?t.color:n.rgb(t.color).darker().toString()),u.data[e].color=t.color,u.data[e].strokeColor=t.strokeColor,u.data[e].strokeDash=t.strokeDash,u.data[e].strokeSize=t.strokeSize});var p=c.filter(function(t,e){var r=t.visible;return"undefined"==typeof r||!0===r}),d=!1,g=p.map(function(t,e){return d=d||"undefined"!=typeof t.groupId,t});if(d){var v=n.nest().key(function(t,e){return"undefined"!=typeof t.groupId?t.groupId:"unstacked"}).entries(g),m=[],y=v.map(function(t,e){if("unstacked"===t.key)return t.values;var r=t.values[0].r.map(function(t,e){return 0});return t.values.forEach(function(t,e,n){t.yStack=[r],m.push(r),r=o.util.sumArrays(t.r,r)}),t.values});p=n.merge(y)}p.forEach(function(t,e){t.t=Array.isArray(t.t[0])?t.t:[t.t],t.r=Array.isArray(t.r[0])?t.r:[t.r]});var x=Math.min(f.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2;x=Math.max(10,x);var b,_=[f.margin.left+x,f.margin.top+x];b=d?[0,n.max(o.util.sumArrays(o.util.arrayLast(p).r[0],o.util.arrayLast(m)))]:n.extent(o.util.flattenArray(p.map(function(t,e){return t.r}))),f.radialAxis.domain!=o.DATAEXTENT&&(b[0]=0),r=n.scale.linear().domain(f.radialAxis.domain!=o.DATAEXTENT&&f.radialAxis.domain?f.radialAxis.domain:b).range([0,x]),u.layout.radialAxis.domain=r.domain();var w,k=o.util.flattenArray(p.map(function(t,e){return t.t})),T="string"==typeof k[0];T&&(k=o.util.deduplicate(k),w=k.slice(),k=n.range(k.length),p=p.map(function(t,e){var r=t;return t.t=[k],d&&(r.yStack=t.yStack),r}));var M=p.filter(function(t,e){return"LinePlot"===t.geometry||"DotPlot"===t.geometry}).length===p.length,A=null===f.needsEndSpacing?T||!M:f.needsEndSpacing,S=f.angularAxis.domain&&f.angularAxis.domain!=o.DATAEXTENT&&!T&&f.angularAxis.domain[0]>=0?f.angularAxis.domain:n.extent(k),E=Math.abs(k[1]-k[0]);M&&!T&&(E=0);var L=S.slice();A&&T&&(L[1]+=E);var C=f.angularAxis.ticksCount||4;C>8&&(C=C/(C/8)+C%8),f.angularAxis.ticksStep&&(C=(L[1]-L[0])/C);var P=f.angularAxis.ticksStep||(L[1]-L[0])/(C*(f.minorTicks+1));w&&(P=Math.max(Math.round(P),1)),L[2]||(L[2]=P);var O=n.range.apply(this,L);if(O=O.map(function(t,e){return parseFloat(t.toPrecision(12))}),s=n.scale.linear().domain(L.slice(0,2)).range("clockwise"===f.direction?[0,360]:[360,0]),u.layout.angularAxis.domain=s.domain(),u.layout.angularAxis.endPadding=A?E:0,"undefined"==typeof(t=n.select(this).select("svg.chart-root"))||t.empty()){var z=(new DOMParser).parseFromString("<svg xmlns='http://www.w3.org/2000/svg' class='chart-root'>' + '<g class='outer-group'>' + '<g class='chart-group'>' + '<circle class='background-circle'></circle>' + '<g class='geometry-group'></g>' + '<g class='radial axis-group'>' + '<circle class='outside-circle'></circle>' + '</g>' + '<g class='angular axis-group'></g>' + '<g class='guides-group'><line></line><circle r='0'></circle></g>' + '</g>' + '<g class='legend-group'></g>' + '<g class='tooltips-group'></g>' + '<g class='title-group'><text></text></g>' + '</g>' + '</svg>","application/xml"),I=this.appendChild(this.ownerDocument.importNode(z.documentElement,!0));t=n.select(I)}t.select(".guides-group").style({"pointer-events":"none"}),t.select(".angular.axis-group").style({"pointer-events":"none"}),t.select(".radial.axis-group").style({"pointer-events":"none"});var D,R=t.select(".chart-group"),F={fill:"none",stroke:f.tickColor},B={"font-size":f.font.size,"font-family":f.font.family,fill:f.font.color,"text-shadow":["-1px 0px","1px -1px","-1px 1px","1px 1px"].map(function(t,e){return" "+t+" 0 "+f.font.outlineColor}).join(",")};if(f.showLegend){D=t.select(".legend-group").attr({transform:"translate("+[x,f.margin.top]+")"}).style({display:"block"});var N=p.map(function(t,e){var r=o.util.cloneJson(t);return r.symbol="DotPlot"===t.geometry?t.dotType||"circle":"LinePlot"!=t.geometry?"square":"line",r.visibleInLegend="undefined"==typeof t.visibleInLegend||t.visibleInLegend,r.color="LinePlot"===t.geometry?t.strokeColor:t.color,r});o.Legend().config({data:p.map(function(t,e){return t.name||"Element"+e}),legendConfig:a({},o.Legend.defaultConfig().legendConfig,{container:D,elements:N,reverseOrder:f.legend.reverseOrder})})();var j=D.node().getBBox();x=Math.min(f.width-j.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2,x=Math.max(10,x),_=[f.margin.left+x,f.margin.top+x],r.range([0,x]),u.layout.radialAxis.domain=r.domain(),D.attr("transform","translate("+[_[0]+x,_[1]-x]+")")}else D=t.select(".legend-group").style({display:"none"});t.attr({width:f.width,height:f.height}).style({opacity:f.opacity}),R.attr("transform","translate("+_+")").style({cursor:"crosshair"});var V=[(f.width-(f.margin.left+f.margin.right+2*x+(j?j.width:0)))/2,(f.height-(f.margin.top+f.margin.bottom+2*x))/2];if(V[0]=Math.max(0,V[0]),V[1]=Math.max(0,V[1]),t.select(".outer-group").attr("transform","translate("+V+")"),f.title&&f.title.text){var U=t.select("g.title-group text").style(B).text(f.title.text),q=U.node().getBBox();U.attr({x:_[0]-q.width/2,y:_[1]-x-20})}var H=t.select(".radial.axis-group");if(f.radialAxis.gridLinesVisible){var G=H.selectAll("circle.grid-circle").data(r.ticks(5));G.enter().append("circle").attr({class:"grid-circle"}).style(F),G.attr("r",r),G.exit().remove()}H.select("circle.outside-circle").attr({r:x}).style(F);var Y=t.select("circle.background-circle").attr({r:x}).style({fill:f.backgroundColor,stroke:f.stroke});function W(t,e){return s(t)%360+f.orientation}if(f.radialAxis.visible){var X=n.svg.axis().scale(r).ticks(5).tickSize(5);H.call(X).attr({transform:"rotate("+f.radialAxis.orientation+")"}),H.selectAll(".domain").style(F),H.selectAll("g>text").text(function(t,e){return this.textContent+f.radialAxis.ticksSuffix}).style(B).style({"text-anchor":"start"}).attr({x:0,y:0,dx:0,dy:0,transform:function(t,e){return"horizontal"===f.radialAxis.tickOrientation?"rotate("+-f.radialAxis.orientation+") translate("+[0,B["font-size"]]+")":"translate("+[0,B["font-size"]]+")"}}),H.selectAll("g>line").style({stroke:"black"})}var Z=t.select(".angular.axis-group").selectAll("g.angular-tick").data(O),J=Z.enter().append("g").classed("angular-tick",!0);Z.attr({transform:function(t,e){return"rotate("+W(t)+")"}}).style({display:f.angularAxis.visible?"block":"none"}),Z.exit().remove(),J.append("line").classed("grid-line",!0).classed("major",function(t,e){return e%(f.minorTicks+1)==0}).classed("minor",function(t,e){return!(e%(f.minorTicks+1)==0)}).style(F),J.selectAll(".minor").style({stroke:f.minorTickColor}),Z.select("line.grid-line").attr({x1:f.tickLength?x-f.tickLength:0,x2:x}).style({display:f.angularAxis.gridLinesVisible?"block":"none"}),J.append("text").classed("axis-text",!0).style(B);var K=Z.select("text.axis-text").attr({x:x+f.labelOffset,dy:i+"em",transform:function(t,e){var r=W(t),n=x+f.labelOffset,a=f.angularAxis.tickOrientation;return"horizontal"==a?"rotate("+-r+" "+n+" 0)":"radial"==a?r<270&&r>90?"rotate(180 "+n+" 0)":null:"rotate("+(r<=180&&r>0?-90:90)+" "+n+" 0)"}}).style({"text-anchor":"middle",display:f.angularAxis.labelsVisible?"block":"none"}).text(function(t,e){return e%(f.minorTicks+1)!=0?"":w?w[t]+f.angularAxis.ticksSuffix:t+f.angularAxis.ticksSuffix}).style(B);f.angularAxis.rewriteTicks&&K.text(function(t,e){return e%(f.minorTicks+1)!=0?"":f.angularAxis.rewriteTicks(this.textContent,e)});var Q=n.max(R.selectAll(".angular-tick text")[0].map(function(t,e){return t.getCTM().e+t.getBBox().width}));D.attr({transform:"translate("+[x+Q,f.margin.top]+")"});var $=t.select("g.geometry-group").selectAll("g").size()>0,tt=t.select("g.geometry-group").selectAll("g.geometry").data(p);if(tt.enter().append("g").attr({class:function(t,e){return"geometry geometry"+e}}),tt.exit().remove(),p[0]||$){var et=[];p.forEach(function(t,e){var n={};n.radialScale=r,n.angularScale=s,n.container=tt.filter(function(t,r){return r==e}),n.geometry=t.geometry,n.orientation=f.orientation,n.direction=f.direction,n.index=e,et.push({data:t,geometryConfig:n})});var rt=n.nest().key(function(t,e){return"undefined"!=typeof t.data.groupId||"unstacked"}).entries(et),nt=[];rt.forEach(function(t,e){"unstacked"===t.key?nt=nt.concat(t.values.map(function(t,e){return[t]})):nt.push(t.values)}),nt.forEach(function(t,e){var r;r=Array.isArray(t)?t[0].geometryConfig.geometry:t.geometryConfig.geometry;var n=t.map(function(t,e){return a(o[r].defaultConfig(),t)});o[r]().config(n)()})}var at,it,ot=t.select(".guides-group"),st=t.select(".tooltips-group"),lt=o.tooltipPanel().config({container:st,fontSize:8})(),ct=o.tooltipPanel().config({container:st,fontSize:8})(),ut=o.tooltipPanel().config({container:st,hasTick:!0})();if(!T){var ht=ot.select("line").attr({x1:0,y1:0,y2:0}).style({stroke:"grey","pointer-events":"none"});R.on("mousemove.angular-guide",function(t,e){var r=o.util.getMousePos(Y).angle;ht.attr({x2:-x,transform:"rotate("+r+")"}).style({opacity:.5});var n=(r+180+360-f.orientation)%360;at=s.invert(n);var a=o.util.convertToCartesian(x+12,r+180);lt.text(o.util.round(at)).move([a[0]+_[0],a[1]+_[1]])}).on("mouseout.angular-guide",function(t,e){ot.select("line").style({opacity:0})})}var ft=ot.select("circle").style({stroke:"grey",fill:"none"});R.on("mousemove.radial-guide",function(t,e){var n=o.util.getMousePos(Y).radius;ft.attr({r:n}).style({opacity:.5}),it=r.invert(o.util.getMousePos(Y).radius);var a=o.util.convertToCartesian(n,f.radialAxis.orientation);ct.text(o.util.round(it)).move([a[0]+_[0],a[1]+_[1]])}).on("mouseout.radial-guide",function(t,e){ft.style({opacity:0}),ut.hide(),lt.hide(),ct.hide()}),t.selectAll(".geometry-group .mark").on("mouseover.tooltip",function(e,r){var a=n.select(this),i=this.style.fill,s="black",l=this.style.opacity||1;if(a.attr({"data-opacity":l}),i&&"none"!==i){a.attr({"data-fill":i}),s=n.hsl(i).darker().toString(),a.style({fill:s,opacity:1});var c={t:o.util.round(e[0]),r:o.util.round(e[1])};T&&(c.t=w[e[0]]);var u="t: "+c.t+", r: "+c.r,h=this.getBoundingClientRect(),f=t.node().getBoundingClientRect(),p=[h.left+h.width/2-V[0]-f.left,h.top+h.height/2-V[1]-f.top];ut.config({color:s}).text(u),ut.move(p)}else i=this.style.stroke||"black",a.attr({"data-stroke":i}),s=n.hsl(i).darker().toString(),a.style({stroke:s,opacity:1})}).on("mousemove.tooltip",function(t,e){if(0!=n.event.which)return!1;n.select(this).attr("data-fill")&&ut.show()}).on("mouseout.tooltip",function(t,e){ut.hide();var r=n.select(this),a=r.attr("data-fill");a?r.style({fill:a,opacity:r.attr("data-opacity")}):r.style({stroke:r.attr("data-stroke"),opacity:r.attr("data-opacity")})})})}(c),this},f.config=function(t){if(!arguments.length)return l;var e=o.util.cloneJson(t);return e.data.forEach(function(t,e){l.data[e]||(l.data[e]={}),a(l.data[e],o.Axis.defaultConfig().data[0]),a(l.data[e],t)}),a(l.layout,o.Axis.defaultConfig().layout),a(l.layout,e.layout),this},f.getLiveConfig=function(){return u},f.getinputConfig=function(){return c},f.radialScale=function(t){return r},f.angularScale=function(t){return s},f.svg=function(){return t},n.rebind(f,h,"on"),f},o.Axis.defaultConfig=function(t,e){return{data:[{t:[1,2,3,4],r:[10,11,12,13],name:"Line1",geometry:"LinePlot",color:null,strokeDash:"solid",strokeColor:null,strokeSize:"1",visibleInLegend:!0,opacity:1}],layout:{defaultColorRange:n.scale.category10().range(),title:null,height:450,width:500,margin:{top:40,right:40,bottom:40,left:40},font:{size:12,color:"gray",outlineColor:"white",family:"Tahoma, sans-serif"},direction:"clockwise",orientation:0,labelOffset:10,radialAxis:{domain:null,orientation:-45,ticksSuffix:"",visible:!0,gridLinesVisible:!0,tickOrientation:"horizontal",rewriteTicks:null},angularAxis:{domain:[0,360],ticksSuffix:"",visible:!0,gridLinesVisible:!0,labelsVisible:!0,tickOrientation:"horizontal",rewriteTicks:null,ticksCount:null,ticksStep:null},minorTicks:0,tickLength:null,tickColor:"silver",minorTickColor:"#eee",backgroundColor:"none",needsEndSpacing:null,showLegend:!0,legend:{reverseOrder:!1},opacity:1}}},o.util={},o.DATAEXTENT="dataExtent",o.AREA="AreaChart",o.LINE="LinePlot",o.DOT="DotPlot",o.BAR="BarChart",o.util._override=function(t,e){for(var r in t)r in e&&(e[r]=t[r])},o.util._extend=function(t,e){for(var r in t)e[r]=t[r]},o.util._rndSnd=function(){return 2*Math.random()-1+(2*Math.random()-1)+(2*Math.random()-1)},o.util.dataFromEquation2=function(t,e){var r=e||6;return n.range(0,360+r,r).map(function(e,r){var n=e*Math.PI/180;return[e,t(n)]})},o.util.dataFromEquation=function(t,e,r){var a=e||6,i=[],o=[];n.range(0,360+a,a).forEach(function(e,r){var n=e*Math.PI/180,a=t(n);i.push(e),o.push(a)});var s={t:i,r:o};return r&&(s.name=r),s},o.util.ensureArray=function(t,e){if("undefined"==typeof t)return null;var r=[].concat(t);return n.range(e).map(function(t,e){return r[e]||r[0]})},o.util.fillArrays=function(t,e,r){return e.forEach(function(e,n){t[e]=o.util.ensureArray(t[e],r)}),t},o.util.cloneJson=function(t){return JSON.parse(JSON.stringify(t))},o.util.validateKeys=function(t,e){"string"==typeof e&&(e=e.split("."));var r=e.shift();return t[r]&&(!e.length||objHasKeys(t[r],e))},o.util.sumArrays=function(t,e){return n.zip(t,e).map(function(t,e){return n.sum(t)})},o.util.arrayLast=function(t){return t[t.length-1]},o.util.arrayEqual=function(t,e){for(var r=Math.max(t.length,e.length,1);r-- >=0&&t[r]===e[r];);return-2===r},o.util.flattenArray=function(t){for(var e=[];!o.util.arrayEqual(e,t);)e=t,t=[].concat.apply([],t);return t},o.util.deduplicate=function(t){return t.filter(function(t,e,r){return r.indexOf(t)==e})},o.util.convertToCartesian=function(t,e){var r=e*Math.PI/180;return[t*Math.cos(r),t*Math.sin(r)]},o.util.round=function(t,e){var r=e||2,n=Math.pow(10,r);return Math.round(t*n)/n},o.util.getMousePos=function(t){var e=n.mouse(t.node()),r=e[0],a=e[1],i={};return i.x=r,i.y=a,i.pos=e,i.angle=180*(Math.atan2(a,r)+Math.PI)/Math.PI,i.radius=Math.sqrt(r*r+a*a),i},o.util.duplicatesCount=function(t){for(var e,r={},n={},a=0,i=t.length;a<i;a++)(e=t[a])in r?(r[e]++,n[e]=r[e]):r[e]=1;return n},o.util.duplicates=function(t){return Object.keys(o.util.duplicatesCount(t))},o.util.translator=function(t,e,r,n){if(n){var a=r.slice();r=e,e=a}var i=e.reduce(function(t,e){if("undefined"!=typeof t)return t[e]},t);"undefined"!=typeof i&&(e.reduce(function(t,r,n){if("undefined"!=typeof t)return n===e.length-1&&delete t[r],t[r]},t),r.reduce(function(t,e,n){return"undefined"==typeof t[e]&&(t[e]={}),n===r.length-1&&(t[e]=i),t[e]},t))},o.PolyChart=function(){var t=[o.PolyChart.defaultConfig()],e=n.dispatch("hover"),r={solid:"none",dash:[5,2],dot:[2,5]};function i(){var e=t[0].geometryConfig,a=e.container;"string"==typeof a&&(a=n.select(a)),a.datum(t).each(function(t,a){var i=!!t[0].data.yStack,o=t.map(function(t,e){return i?n.zip(t.data.t[0],t.data.r[0],t.data.yStack[0]):n.zip(t.data.t[0],t.data.r[0])}),s=e.angularScale,l=e.radialScale.domain()[0],c={bar:function(r,a,i){var o=t[i].data,l=e.radialScale(r[1])-e.radialScale(0),c=e.radialScale(r[2]||0),u=o.barWidth;n.select(this).attr({class:"mark bar",d:"M"+[[l+c,-u/2],[l+c,u/2],[c,u/2],[c,-u/2]].join("L")+"Z",transform:function(t,r){return"rotate("+(e.orientation+s(t[0]))+")"}})}};c.dot=function(r,a,i){var o=r[2]?[r[0],r[1]+r[2]]:r,s=n.svg.symbol().size(t[i].data.dotSize).type(t[i].data.dotType)(r,a);n.select(this).attr({class:"mark dot",d:s,transform:function(t,r){var n,a,i,s=(n=function(t,r){var n=e.radialScale(t[1]),a=(e.angularScale(t[0])+e.orientation)*Math.PI/180;return{r:n,t:a}}(o),a=n.r*Math.cos(n.t),i=n.r*Math.sin(n.t),{x:a,y:i});return"translate("+[s.x,s.y]+")"}})};var u=n.svg.line.radial().interpolate(t[0].data.lineInterpolation).radius(function(t){return e.radialScale(t[1])}).angle(function(t){return e.angularScale(t[0])*Math.PI/180});c.line=function(r,a,i){var s=r[2]?o[i].map(function(t,e){return[t[0],t[1]+t[2]]}):o[i];if(n.select(this).each(c.dot).style({opacity:function(e,r){return+t[i].data.dotVisible},fill:d.stroke(r,a,i)}).attr({class:"mark dot"}),!(a>0)){var l=n.select(this.parentNode).selectAll("path.line").data([0]);l.enter().insert("path"),l.attr({class:"line",d:u(s),transform:function(t,r){return"rotate("+(e.orientation+90)+")"},"pointer-events":"none"}).style({fill:function(t,e){return d.fill(r,a,i)},"fill-opacity":0,stroke:function(t,e){return d.stroke(r,a,i)},"stroke-width":function(t,e){return d["stroke-width"](r,a,i)},"stroke-dasharray":function(t,e){return d["stroke-dasharray"](r,a,i)},opacity:function(t,e){return d.opacity(r,a,i)},display:function(t,e){return d.display(r,a,i)}})}};var h=e.angularScale.range(),f=Math.abs(h[1]-h[0])/o[0].length*Math.PI/180,p=n.svg.arc().startAngle(function(t){return-f/2}).endAngle(function(t){return f/2}).innerRadius(function(t){return e.radialScale(l+(t[2]||0))}).outerRadius(function(t){return e.radialScale(l+(t[2]||0))+e.radialScale(t[1])});c.arc=function(t,r,a){n.select(this).attr({class:"mark arc",d:p,transform:function(t,r){return"rotate("+(e.orientation+s(t[0])+90)+")"}})};var d={fill:function(e,r,n){return t[n].data.color},stroke:function(e,r,n){return t[n].data.strokeColor},"stroke-width":function(e,r,n){return t[n].data.strokeSize+"px"},"stroke-dasharray":function(e,n,a){return r[t[a].data.strokeDash]},opacity:function(e,r,n){return t[n].data.opacity},display:function(e,r,n){return"undefined"==typeof t[n].data.visible||t[n].data.visible?"block":"none"}},g=n.select(this).selectAll("g.layer").data(o);g.enter().append("g").attr({class:"layer"});var v=g.selectAll("path.mark").data(function(t,e){return t});v.enter().append("path").attr({class:"mark"}),v.style(d).each(c[e.geometryType]),v.exit().remove(),g.exit().remove()})}return i.config=function(e){return arguments.length?(e.forEach(function(e,r){t[r]||(t[r]={}),a(t[r],o.PolyChart.defaultConfig()),a(t[r],e)}),this):t},i.getColorScale=function(){},n.rebind(i,e,"on"),i},o.PolyChart.defaultConfig=function(){return{data:{name:"geom1",t:[[1,2,3,4]],r:[[1,2,3,4]],dotType:"circle",dotSize:64,dotVisible:!1,barWidth:20,color:"#ffa500",strokeSize:1,strokeColor:"silver",strokeDash:"solid",opacity:1,index:0,visible:!0,visibleInLegend:!0},geometryConfig:{geometry:"LinePlot",geometryType:"arc",direction:"clockwise",orientation:0,container:"body",radialScale:null,angularScale:null,colorScale:n.scale.category20()}}},o.BarChart=function(){return o.PolyChart()},o.BarChart.defaultConfig=function(){return{geometryConfig:{geometryType:"bar"}}},o.AreaChart=function(){return o.PolyChart()},o.AreaChart.defaultConfig=function(){return{geometryConfig:{geometryType:"arc"}}},o.DotPlot=function(){return o.PolyChart()},o.DotPlot.defaultConfig=function(){return{geometryConfig:{geometryType:"dot",dotType:"circle"}}},o.LinePlot=function(){return o.PolyChart()},o.LinePlot.defaultConfig=function(){return{geometryConfig:{geometryType:"line"}}},o.Legend=function(){var t=o.Legend.defaultConfig(),e=n.dispatch("hover");function r(){var e=t.legendConfig,i=t.data.map(function(t,r){return[].concat(t).map(function(t,n){var i=a({},e.elements[r]);return i.name=t,i.color=[].concat(e.elements[r].color)[n],i})}),o=n.merge(i);o=o.filter(function(t,r){return e.elements[r]&&(e.elements[r].visibleInLegend||"undefined"==typeof e.elements[r].visibleInLegend)}),e.reverseOrder&&(o=o.reverse());var s=e.container;("string"==typeof s||s.nodeName)&&(s=n.select(s));var l=o.map(function(t,e){return t.color}),c=e.fontSize,u=null==e.isContinuous?"number"==typeof o[0]:e.isContinuous,h=u?e.height:c*o.length,f=s.classed("legend-group",!0).selectAll("svg").data([0]),p=f.enter().append("svg").attr({width:300,height:h+c,xmlns:"http://www.w3.org/2000/svg","xmlns:xlink":"http://www.w3.org/1999/xlink",version:"1.1"});p.append("g").classed("legend-axis",!0),p.append("g").classed("legend-marks",!0);var d=n.range(o.length),g=n.scale[u?"linear":"ordinal"]().domain(d).range(l),v=n.scale[u?"linear":"ordinal"]().domain(d)[u?"range":"rangePoints"]([0,h]);if(u){var m=f.select(".legend-marks").append("defs").append("linearGradient").attr({id:"grad1",x1:"0%",y1:"0%",x2:"0%",y2:"100%"}).selectAll("stop").data(l);m.enter().append("stop"),m.attr({offset:function(t,e){return e/(l.length-1)*100+"%"}}).style({"stop-color":function(t,e){return t}}),f.append("rect").classed("legend-mark",!0).attr({height:e.height,width:e.colorBandWidth,fill:"url(#grad1)"})}else{var y=f.select(".legend-marks").selectAll("path.legend-mark").data(o);y.enter().append("path").classed("legend-mark",!0),y.attr({transform:function(t,e){return"translate("+[c/2,v(e)+c/2]+")"},d:function(t,e){var r,a,i,o=t.symbol;return i=3*(a=c),"line"===(r=o)?"M"+[[-a/2,-a/12],[a/2,-a/12],[a/2,a/12],[-a/2,a/12]]+"Z":-1!=n.svg.symbolTypes.indexOf(r)?n.svg.symbol().type(r).size(i)():n.svg.symbol().type("square").size(i)()},fill:function(t,e){return g(e)}}),y.exit().remove()}var x=n.svg.axis().scale(v).orient("right"),b=f.select("g.legend-axis").attr({transform:"translate("+[u?e.colorBandWidth:c,c/2]+")"}).call(x);return b.selectAll(".domain").style({fill:"none",stroke:"none"}),b.selectAll("line").style({fill:"none",stroke:u?e.textColor:"none"}),b.selectAll("text").style({fill:e.textColor,"font-size":e.fontSize}).text(function(t,e){return o[e].name}),r}return r.config=function(e){return arguments.length?(a(t,e),this):t},n.rebind(r,e,"on"),r},o.Legend.defaultConfig=function(t,e){return{data:["a","b","c"],legendConfig:{elements:[{symbol:"line",color:"red"},{symbol:"square",color:"yellow"},{symbol:"diamond",color:"limegreen"}],height:150,colorBandWidth:30,fontSize:12,container:"body",isContinuous:null,textColor:"grey",reverseOrder:!1}}},o.tooltipPanel=function(){var t,e,r,i={container:null,hasTick:!1,fontSize:12,color:"white",padding:5},s="tooltip-"+o.tooltipPanel.uid++,l=10,c=function(){var n=(t=i.container.selectAll("g."+s).data([0])).enter().append("g").classed(s,!0).style({"pointer-events":"none",display:"none"});return r=n.append("path").style({fill:"white","fill-opacity":.9}).attr({d:"M0 0"}),e=n.append("text").attr({dx:i.padding+l,dy:.3*+i.fontSize}),c};return c.text=function(a){var o=n.hsl(i.color).l,s=o>=.5?"#aaa":"white",u=o>=.5?"black":"white",h=a||"";e.style({fill:u,"font-size":i.fontSize+"px"}).text(h);var f=i.padding,p=e.node().getBBox(),d={fill:i.color,stroke:s,"stroke-width":"2px"},g=p.width+2*f+l,v=p.height+2*f;return r.attr({d:"M"+[[l,-v/2],[l,-v/4],[i.hasTick?0:l,0],[l,v/4],[l,v/2],[g,v/2],[g,-v/2]].join("L")+"Z"}).style(d),t.attr({transform:"translate("+[l,-v/2+2*f]+")"}),t.style({display:"block"}),c},c.move=function(e){if(t)return t.attr({transform:"translate("+[e[0],e[1]]+")"}).style({display:"block"}),c},c.hide=function(){if(t)return t.style({display:"none"}),c},c.show=function(){if(t)return t.style({display:"block"}),c},c.config=function(t){return a(i,t),c},c},o.tooltipPanel.uid=1,o.adapter={},o.adapter.plotly=function(){var t={convert:function(t,e){var r={};if(t.data&&(r.data=t.data.map(function(t,r){var n=a({},t);return[[n,["marker","color"],["color"]],[n,["marker","opacity"],["opacity"]],[n,["marker","line","color"],["strokeColor"]],[n,["marker","line","dash"],["strokeDash"]],[n,["marker","line","width"],["strokeSize"]],[n,["marker","symbol"],["dotType"]],[n,["marker","size"],["dotSize"]],[n,["marker","barWidth"],["barWidth"]],[n,["line","interpolation"],["lineInterpolation"]],[n,["showlegend"],["visibleInLegend"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e||delete n.marker,e&&delete n.groupId,e?("LinePlot"===n.geometry?(n.type="scatter",!0===n.dotVisible?(delete n.dotVisible,n.mode="lines+markers"):n.mode="lines"):"DotPlot"===n.geometry?(n.type="scatter",n.mode="markers"):"AreaChart"===n.geometry?n.type="area":"BarChart"===n.geometry&&(n.type="bar"),delete n.geometry):("scatter"===n.type?"lines"===n.mode?n.geometry="LinePlot":"markers"===n.mode?n.geometry="DotPlot":"lines+markers"===n.mode&&(n.geometry="LinePlot",n.dotVisible=!0):"area"===n.type?n.geometry="AreaChart":"bar"===n.type&&(n.geometry="BarChart"),delete n.mode,delete n.type),n}),!e&&t.layout&&"stack"===t.layout.barmode)){var i=o.util.duplicates(r.data.map(function(t,e){return t.geometry}));r.data.forEach(function(t,e){var n=i.indexOf(t.geometry);-1!=n&&(r.data[e].groupId=n)})}if(t.layout){var s=a({},t.layout);if([[s,["plot_bgcolor"],["backgroundColor"]],[s,["showlegend"],["showLegend"]],[s,["radialaxis"],["radialAxis"]],[s,["angularaxis"],["angularAxis"]],[s.angularaxis,["showline"],["gridLinesVisible"]],[s.angularaxis,["showticklabels"],["labelsVisible"]],[s.angularaxis,["nticks"],["ticksCount"]],[s.angularaxis,["tickorientation"],["tickOrientation"]],[s.angularaxis,["ticksuffix"],["ticksSuffix"]],[s.angularaxis,["range"],["domain"]],[s.angularaxis,["endpadding"],["endPadding"]],[s.radialaxis,["showline"],["gridLinesVisible"]],[s.radialaxis,["tickorientation"],["tickOrientation"]],[s.radialaxis,["ticksuffix"],["ticksSuffix"]],[s.radialaxis,["range"],["domain"]],[s.angularAxis,["showline"],["gridLinesVisible"]],[s.angularAxis,["showticklabels"],["labelsVisible"]],[s.angularAxis,["nticks"],["ticksCount"]],[s.angularAxis,["tickorientation"],["tickOrientation"]],[s.angularAxis,["ticksuffix"],["ticksSuffix"]],[s.angularAxis,["range"],["domain"]],[s.angularAxis,["endpadding"],["endPadding"]],[s.radialAxis,["showline"],["gridLinesVisible"]],[s.radialAxis,["tickorientation"],["tickOrientation"]],[s.radialAxis,["ticksuffix"],["ticksSuffix"]],[s.radialAxis,["range"],["domain"]],[s.font,["outlinecolor"],["outlineColor"]],[s.legend,["traceorder"],["reverseOrder"]],[s,["labeloffset"],["labelOffset"]],[s,["defaultcolorrange"],["defaultColorRange"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e?("undefined"!=typeof s.tickLength&&(s.angularaxis.ticklen=s.tickLength,delete s.tickLength),s.tickColor&&(s.angularaxis.tickcolor=s.tickColor,delete s.tickColor)):(s.angularAxis&&"undefined"!=typeof s.angularAxis.ticklen&&(s.tickLength=s.angularAxis.ticklen),s.angularAxis&&"undefined"!=typeof s.angularAxis.tickcolor&&(s.tickColor=s.angularAxis.tickcolor)),s.legend&&"boolean"!=typeof s.legend.reverseOrder&&(s.legend.reverseOrder="normal"!=s.legend.reverseOrder),s.legend&&"boolean"==typeof s.legend.traceorder&&(s.legend.traceorder=s.legend.traceorder?"reversed":"normal",delete s.legend.reverseOrder),s.margin&&"undefined"!=typeof s.margin.t){var l=["t","r","b","l","pad"],c=["top","right","bottom","left","pad"],u={};n.entries(s.margin).forEach(function(t,e){u[c[l.indexOf(t.key)]]=t.value}),s.margin=u}e&&(delete s.needsEndSpacing,delete s.minorTickColor,delete s.minorTicks,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksStep,delete s.angularaxis.rewriteTicks,delete s.angularaxis.nticks,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksStep,delete s.radialaxis.rewriteTicks,delete s.radialaxis.nticks),r.layout=s}return r}};return t}},{"../../../constants/alignment":686,"../../../lib":717,d3:165}],836:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../../lib"),i=t("../../../components/color"),o=t("./micropolar"),s=t("./undo_manager"),l=a.extendDeepAll,c=e.exports={};c.framework=function(t){var e,r,a,i,u,h=new s;function f(r,s){return s&&(u=s),n.select(n.select(u).node().parentNode).selectAll(".svg-container>*:not(.chart-root)").remove(),e=e?l(e,r):r,a||(a=o.Axis()),i=o.adapter.plotly().convert(e),a.config(i).render(u),t.data=e.data,t.layout=e.layout,c.fillLayout(t),e}return f.isPolar=!0,f.svg=function(){return a.svg()},f.getConfig=function(){return e},f.getLiveConfig=function(){return o.adapter.plotly().convert(a.getLiveConfig(),!0)},f.getLiveScales=function(){return{t:a.angularScale(),r:a.radialScale()}},f.setUndoPoint=function(){var t,n,a=this,i=o.util.cloneJson(e);t=i,n=r,h.add({undo:function(){n&&a(n)},redo:function(){a(t)}}),r=o.util.cloneJson(i)},f.undo=function(){h.undo()},f.redo=function(){h.redo()},f},c.fillLayout=function(t){var e=n.select(t).selectAll(".plot-container"),r=e.selectAll(".svg-container"),a=t.framework&&t.framework.svg&&t.framework.svg(),o={width:800,height:600,paper_bgcolor:i.background,_container:e,_paperdiv:r,_paper:a};t._fullLayout=l(o,t.layout)}},{"../../../components/color":591,"../../../lib":717,"./micropolar":835,"./undo_manager":837,d3:165}],837:[function(t,e,r){"use strict";e.exports=function(){var t,e=[],r=-1,n=!1;function a(t,e){return t?(n=!0,t[e](),n=!1,this):this}return{add:function(t){return n?this:(e.splice(r+1,e.length-r),e.push(t),r=e.length-1,this)},setCallback:function(e){t=e},undo:function(){var n=e[r];return n?(a(n,"undo"),r-=1,t&&t(n.undo),this):this},redo:function(){var n=e[r+1];return n?(a(n,"redo"),r+=1,t&&t(n.redo),this):this},clear:function(){e=[],r=-1},hasUndo:function(){return-1!==r},hasRedo:function(){return r<e.length-1},getCommands:function(){return e},getPreviousCommand:function(){return e[r-1]},getIndex:function(){return r}}}},{}],838:[function(t,e,r){"use strict";var n=t("d3"),a=t("tinycolor2"),i=t("../../registry"),o=t("../../lib"),s=t("../../components/color"),l=t("../../components/drawing"),c=t("../plots"),u=t("../../plots/cartesian/axes"),h=t("../cartesian/set_convert"),f=t("./set_convert"),p=t("../cartesian/autorange").doAutoRange,d=t("../cartesian/dragbox"),g=t("../../components/dragelement"),v=t("../../components/fx"),m=t("../../components/titles"),y=t("../cartesian/select").prepSelect,x=t("../cartesian/select").selectOnClick,b=t("../cartesian/select").clearSelect,_=t("../../lib/setcursor"),w=t("../../lib/clear_gl_canvases"),k=t("../../plot_api/subroutines").redrawReglTraces,T=t("../../constants/alignment").MID_SHIFT,M=t("./constants"),A=t("./helpers"),S=o._,E=o.mod,L=o.deg2rad,C=o.rad2deg;function P(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n="clip"+r._uid+e;this.clipIds.forTraces=n+"-for-traces",this.clipPaths.forTraces=r._clips.append("clipPath").attr("id",this.clipIds.forTraces),this.clipPaths.forTraces.append("path"),this.framework=r._polarlayer.append("g").attr("class",e),this.radialTickLayout=null,this.angularTickLayout=null}var O=P.prototype;function z(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return"side"in t&&(e+=t.side),e}function I(t,e){return e[o.findIndexOfMin(e,function(e){return o.angleDist(t,e)})]}function D(t,e,r){return e?(t.attr("display",null),t.attr(r)):t&&t.attr("display","none"),t}function R(t,e){return"translate("+t+","+e+")"}function F(t){return"rotate("+t+")"}e.exports=function(t,e){return new P(t,e)},O.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),c.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},O.updateLayers=function(t,e){var r=this.layers,a=e.radialaxis,i=e.angularaxis,o=M.layerNames,s=o.indexOf("frontplot"),l=o.slice(0,s),c="below traces"===i.layer,u="below traces"===a.layer;c&&l.push("angular-line"),u&&l.push("radial-line"),c&&l.push("angular-axis"),u&&l.push("radial-axis"),l.push("frontplot"),c||l.push("angular-line"),u||l.push("radial-line"),c||l.push("angular-axis"),u||l.push("radial-axis");var h=this.framework.selectAll(".polarsublayer").data(l,String);h.enter().append("g").attr("class",function(t){return"polarsublayer "+t}).each(function(t){var e=r[t]=n.select(this);switch(t){case"frontplot":e.append("g").classed("barlayer",!0),e.append("g").classed("scatterlayer",!0);break;case"backplot":e.append("g").classed("maplayer",!0);break;case"plotbg":r.bg=e.append("path");break;case"radial-grid":case"angular-grid":e.style("fill","none");break;case"radial-line":e.append("line").style("fill","none");break;case"angular-line":e.append("path").style("fill","none")}}),h.order()},O.updateLayout=function(t,e){var r=this.layers,n=t._size,a=e.radialaxis,i=e.angularaxis,o=e.domain.x,c=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-c[1]);var u=this.xLength=n.w*(o[1]-o[0]),h=this.yLength=n.h*(c[1]-c[0]),f=e.sector;this.sectorInRad=f.map(L);var p,d,g,v,m,y=this.sectorBBox=function(t){var e,r,n,a,i=t[0],o=t[1]-i,s=E(i,360),l=s+o,c=Math.cos(L(s)),u=Math.sin(L(s)),h=Math.cos(L(l)),f=Math.sin(L(l));a=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&f<=0?0:Math.max(u,f);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&h>=0?0:Math.min(c,h);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&f>=0?0:Math.min(u,f);n=l>=360?1:c<=0&&h<=0?0:Math.max(c,h);return[e,r,n,a]}(f),x=y[2]-y[0],b=y[3]-y[1],_=h/u,w=Math.abs(b/x);_>w?(p=u,m=(h-(d=u*w))/n.h/2,g=[o[0],o[1]],v=[c[0]+m,c[1]-m]):(d=h,m=(u-(p=h/w))/n.w/2,g=[o[0]+m,o[1]-m],v=[c[0],c[1]]),this.xLength2=p,this.yLength2=d,this.xDomain2=g,this.yDomain2=v;var k=this.xOffset2=n.l+n.w*g[0],T=this.yOffset2=n.t+n.h*(1-v[1]),M=this.radius=p/x,A=this.innerRadius=e.hole*M,S=this.cx=k-M*y[0],C=this.cy=T+M*y[3],P=this.cxx=S-k,O=this.cyy=C-T;this.radialAxis=this.mockAxis(t,e,a,{_id:"x",side:{counterclockwise:"top",clockwise:"bottom"}[a.side],domain:[A/n.w,M/n.w]}),this.angularAxis=this.mockAxis(t,e,i,{side:"right",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:"x",domain:g}),this.yaxis=this.mockCartesianAxis(t,e,{_id:"y",domain:v});var z=this.pathSubplot();this.clipPaths.forTraces.select("path").attr("d",z).attr("transform",R(P,O)),r.frontplot.attr("transform",R(k,T)).call(l.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr("d",z).attr("transform",R(S,C)).call(s.fill,e.bgcolor)},O.mockAxis=function(t,e,r,n){var a=o.extendFlat({},r,n);return f(a,e,t),a},O.mockCartesianAxis=function(t,e,r){var n=this,a=r._id,i=o.extendFlat({type:"linear"},r);h(i,t);var s={x:[0,2],y:[1,3]};return i.setRange=function(){var t=n.sectorBBox,r=s[a],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);i.range=[t[r[0]]*l,t[r[1]]*l]},i.isPtWithinRange="x"===a?function(t){return n.isPtInside(t)}:function(){return!0},i.setRange(),i.setScale(),i},O.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,a=e.radialaxis;n.setScale(),p(r,n);var i=n.range;a.range=i.slice(),a._input.range=i.slice(),n._rl=[n.r2l(i[0],null,"gregorian"),n.r2l(i[1],null,"gregorian")]},O.updateRadialAxis=function(t,e){var r=this,n=r.gd,a=r.layers,i=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.radialaxis,p=E(e.sector[0],360),d=r.radialAxis,g=l<i;r.fillViewInitialKey("radialaxis.angle",f.angle),r.fillViewInitialKey("radialaxis.range",d.range.slice()),d.setGeometry(),"auto"===d.tickangle&&p>90&&p<=270&&(d.tickangle=180);var v=function(t){return"translate("+(d.l2p(t.x)+l)+",0)"},m=z(f);if(r.radialTickLayout!==m&&(a["radial-axis"].selectAll(".xtick").remove(),r.radialTickLayout=m),g){d.setScale();var y=u.calcTicks(d),x=u.clipEnds(d,y),b=u.getTickSigns(d)[2];u.drawTicks(n,d,{vals:y,layer:a["radial-axis"],path:u.makeTickPath(d,0,b),transFn:v,crisp:!1}),u.drawGrid(n,d,{vals:x,layer:a["radial-grid"],path:function(t){return r.pathArc(d.r2p(t.x)+l)},transFn:o.noop,crisp:!1}),u.drawLabels(n,d,{vals:y,layer:a["radial-axis"],transFn:v,labelFns:u.makeLabelFns(d,0)})}var _=r.radialAxisAngle=r.vangles?C(I(L(f.angle),r.vangles)):f.angle,w=R(c,h),k=w+F(-_);D(a["radial-axis"],g&&(f.showticklabels||f.ticks),{transform:k}),D(a["radial-grid"],g&&f.showgrid,{transform:w}),D(a["radial-line"].select("line"),g&&f.showline,{x1:l,y1:0,x2:i,y2:0,transform:k}).attr("stroke-width",f.linewidth).call(s.stroke,f.linecolor)},O.updateRadialAxisTitle=function(t,e,r){var n=this.gd,a=this.radius,i=this.cx,o=this.cy,s=e.radialaxis,c=this.id+"title",u=void 0!==r?r:this.radialAxisAngle,h=L(u),f=Math.cos(h),p=Math.sin(h),d=0;if(s.title){var g=l.bBox(this.layers["radial-axis"].node()).height,v=s.title.font.size;d="counterclockwise"===s.side?-g-.4*v:g+.8*v}this.layers["radial-axis-title"]=m.draw(n,c,{propContainer:s,propName:this.id+".radialaxis.title",placeholder:S(n,"Click to enter radial axis title"),attributes:{x:i+a/2*f+d*p,y:o-a/2*p+d*f,"text-anchor":"middle"},transform:{rotate:-u}})},O.updateAngularAxis=function(t,e){var r=this,n=r.gd,a=r.layers,i=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.angularaxis,p=r.angularAxis;r.fillViewInitialKey("angularaxis.rotation",f.rotation),p.setGeometry(),p.setScale();var d=function(t){return p.t2g(t.x)};"linear"===p.type&&"radians"===p.thetaunit&&(p.tick0=C(p.tick0),p.dtick=C(p.dtick));var g=function(t){return R(c+i*Math.cos(t),h-i*Math.sin(t))},v=u.makeLabelFns(p,0).labelStandoff,m={xFn:function(t){var e=d(t);return Math.cos(e)*v},yFn:function(t){var e=d(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(v+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*T)},anchorFn:function(t){var e=d(t),r=Math.cos(e);return Math.abs(r)<.1?"middle":r>0?"start":"end"},heightFn:function(t,e,r){var n=d(t);return-.5*(1+Math.sin(n))*r}},y=z(f);r.angularTickLayout!==y&&(a["angular-axis"].selectAll("."+p._id+"tick").remove(),r.angularTickLayout=y);var x,b=u.calcTicks(p);if("linear"===e.gridshape?(x=b.map(d),o.angleDelta(x[0],x[1])<0&&(x=x.slice().reverse())):x=null,r.vangles=x,"category"===p.type&&(b=b.filter(function(t){return o.isAngleInsideSector(d(t),r.sectorInRad)})),p.visible){var _="inside"===p.ticks?-1:1,w=(p.linewidth||1)/2;u.drawTicks(n,p,{vals:b,layer:a["angular-axis"],path:"M"+_*w+",0h"+_*p.ticklen,transFn:function(t){var e=d(t);return g(e)+F(-C(e))},crisp:!1}),u.drawGrid(n,p,{vals:b,layer:a["angular-grid"],path:function(t){var e=d(t),r=Math.cos(e),n=Math.sin(e);return"M"+[c+l*r,h-l*n]+"L"+[c+i*r,h-i*n]},transFn:o.noop,crisp:!1}),u.drawLabels(n,p,{vals:b,layer:a["angular-axis"],repositionOnUpdate:!0,transFn:function(t){return g(d(t))},labelFns:m})}D(a["angular-line"].select("path"),f.showline,{d:r.pathSubplot(),transform:R(c,h)}).attr("stroke-width",f.linewidth).call(s.stroke,f.linecolor)},O.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},O.updateMainDrag=function(t){var e=this,r=e.gd,o=e.layers,s=t._zoomlayer,l=M.MINZOOM,c=M.OFFEDGE,u=e.radius,h=e.innerRadius,f=e.cx,p=e.cy,m=e.cxx,_=e.cyy,w=e.sectorInRad,k=e.vangles,T=e.radialAxis,S=A.clampTiny,E=A.findXYatLength,L=A.findEnclosingVertexAngles,C=M.cornerHalfWidth,P=M.cornerLen/2,O=d.makeDragger(o,"path","maindrag","crosshair");n.select(O).attr("d",e.pathSubplot()).attr("transform",R(f,p));var z,I,D,F,B,N,j,V,U,q={element:O,gd:r,subplot:e.id,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis},xaxes:[e.xaxis],yaxes:[e.yaxis]};function H(t,e){return Math.sqrt(t*t+e*e)}function G(t,e){return H(t-m,e-_)}function Y(t,e){return Math.atan2(_-e,t-m)}function W(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function X(t,r){if(0===t)return e.pathSector(2*C);var n=P/t,a=r-n,i=r+n,o=Math.max(0,Math.min(t,u)),s=o-C,l=o+C;return"M"+W(s,a)+"A"+[s,s]+" 0,0,0 "+W(s,i)+"L"+W(l,i)+"A"+[l,l]+" 0,0,1 "+W(l,a)+"Z"}function Z(t,r,n){if(0===t)return e.pathSector(2*C);var a,i,o=W(t,r),s=W(t,n),l=S((o[0]+s[0])/2),c=S((o[1]+s[1])/2);if(l&&c){var u=c/l,h=-1/u,f=E(C,u,l,c);a=E(P,h,f[0][0],f[0][1]),i=E(P,h,f[1][0],f[1][1])}else{var p,d;c?(p=P,d=C):(p=C,d=P),a=[[l-p,c-d],[l+p,c-d]],i=[[l-p,c+d],[l+p,c+d]]}return"M"+a.join("L")+"L"+i.reverse().join("L")+"Z"}function J(t,e){return e=Math.max(Math.min(e,u),h),t<c?t=0:u-t<c?t=u:e<c?e=0:u-e<c&&(e=u),Math.abs(e-t)>l?(t<e?(D=t,F=e):(D=e,F=t),!0):(D=null,F=null,!1)}function K(t,e){t=t||B,e=e||"M0,0Z",V.attr("d",t),U.attr("d",e),d.transitionZoombox(V,U,N,j),N=!0;var n={};rt(n),r.emit("plotly_relayouting",n)}function Q(t,r){var n,a,i=z+t,o=I+r,s=G(z,I),l=Math.min(G(i,o),u),c=Y(z,I);J(s,l)&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),a=X(D,c)+X(F,c)),K(n,a)}function $(t,e,r,n){var a=A.findIntersectionXY(r,n,r,[t-m,_-e]);return H(a[0],a[1])}function tt(t,r){var n,a,i=z+t,o=I+r,s=Y(z,I),l=Y(i,o),c=L(s,k),h=L(l,k);J($(z,I,c[0],c[1]),Math.min($(i,o,h[0],h[1]),u))&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),a=[Z(D,c[0],c[1]),Z(F,c[0],c[1])].join(" ")),K(n,a)}function et(){if(d.removeZoombox(r),null!==D&&null!==F){var t={};rt(t),d.showDoubleClickNotifier(r),i.call("_guiRelayout",r,t)}}function rt(t){var r=T._rl,n=(r[1]-r[0])/(1-h/u)/u,a=[r[0]+(D-h)*n,r[0]+(F-h)*n];t[e.id+".radialaxis.range"]=a}function nt(t,n){var a=r._fullLayout.clickmode;if(d.removeZoombox(r),2===t){var o={};for(var s in e.viewInitial)o[e.id+"."+s]=e.viewInitial[s];r.emit("plotly_doubleclick",null),i.call("_guiRelayout",r,o)}a.indexOf("select")>-1&&1===t&&x(n,r,[e.xaxis],[e.yaxis],e.id,q),a.indexOf("event")>-1&&v.click(r,n,e.id)}q.prepFn=function(t,n,i){var o=r._fullLayout.dragmode,l=O.getBoundingClientRect();if(z=n-l.left,I=i-l.top,k){var c=A.findPolygonOffset(u,w[0],w[1],k);z+=m+c[0],I+=_+c[1]}switch(o){case"zoom":q.moveFn=k?tt:Q,q.clickFn=nt,q.doneFn=et,function(){D=null,F=null,B=e.pathSubplot(),N=!1;var t=r._fullLayout[e.id];j=a(t.bgcolor).getLuminance(),(V=d.makeZoombox(s,j,f,p,B)).attr("fill-rule","evenodd"),U=d.makeCorners(s,f,p),b(r)}();break;case"select":case"lasso":y(t,n,i,q,o)}},O.onmousemove=function(t){v.hover(r,t,e.id),r._fullLayout._lasthover=O,r._fullLayout._hoversubplot=e.id},O.onmouseout=function(t){r._dragging||g.unhover(r,t)},g.init(q)},O.updateRadialDrag=function(t,e,r){var a=this,s=a.gd,l=a.layers,c=a.radius,u=a.innerRadius,h=a.cx,f=a.cy,p=a.radialAxis,v=M.radialDragBoxSize,m=v/2;if(p.visible){var y,x,_,T=L(a.radialAxisAngle),A=p._rl,S=A[0],E=A[1],P=A[r],O=.75*(A[1]-A[0])/(1-e.hole)/c;r?(y=h+(c+m)*Math.cos(T),x=f-(c+m)*Math.sin(T),_="radialdrag"):(y=h+(u-m)*Math.cos(T),x=f-(u-m)*Math.sin(T),_="radialdrag-inner");var z,B,N,j=d.makeRectDragger(l,_,"crosshair",-m,-m,v,v),V={element:j,gd:s};D(n.select(j),p.visible&&u<c,{transform:R(y,x)}),V.prepFn=function(){z=null,B=null,N=null,V.moveFn=U,V.doneFn=q,b(s)},V.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<M.MINDRAG&&(t=0,e=0),[t,e]},g.init(V)}function U(t,e){if(z)z(t,e);else{var n=[t,-e],i=[Math.cos(T),Math.sin(T)],l=Math.abs(o.dot(n,i)/Math.sqrt(o.dot(n,n)));isNaN(l)||(z=l<.5?H:G)}var c={};!function(t){null!==B?t[a.id+".radialaxis.angle"]=B:null!==N&&(t[a.id+".radialaxis.range["+r+"]"]=N)}(c),s.emit("plotly_relayouting",c)}function q(){null!==B?i.call("_guiRelayout",s,a.id+".radialaxis.angle",B):null!==N&&i.call("_guiRelayout",s,a.id+".radialaxis.range["+r+"]",N)}function H(t,e){if(0!==r){var n=y+t,i=x+e;B=Math.atan2(f-i,n-h),a.vangles&&(B=I(B,a.vangles)),B=C(B);var o=R(h,f)+F(-B);l["radial-axis"].attr("transform",o),l["radial-line"].select("line").attr("transform",o);var s=a.gd._fullLayout,c=s[a.id];a.updateRadialAxisTitle(s,c,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(T),Math.sin(T)]);if(N=P-O*n,O>0==(r?N>S:N<E)){var l=s._fullLayout,c=l[a.id];p.range[r]=N,p._rl[r]=N,a.updateRadialAxis(l,c),a.xaxis.setRange(),a.xaxis.setScale(),a.yaxis.setRange(),a.yaxis.setScale();var u=!1;for(var h in a.traceHash){var f=a.traceHash[h],d=o.filterVisible(f);f[0][0].trace._module.plot(s,a,d,c),i.traceIs(h,"gl")&&d.length&&(u=!0)}u&&(w(s),k(s))}else N=null}},O.updateAngularDrag=function(t){var e=this,r=e.gd,a=e.layers,s=e.radius,c=e.angularAxis,u=e.cx,h=e.cy,f=e.cxx,p=e.cyy,v=M.angularDragBoxSize,m=d.makeDragger(a,"path","angulardrag","move"),y={element:m,gd:r};function x(t,e){return Math.atan2(p+v-e,t-f-v)}n.select(m).attr("d",e.pathAnnulus(s,s+v)).attr("transform",R(u,h)).call(_,"move");var T,A,S,E,L,P,O=a.frontplot.select(".scatterlayer").selectAll(".trace"),z=O.selectAll(".point"),I=O.selectAll(".textpoint");function D(t,s){var d=e.gd._fullLayout,g=d[e.id],v=x(T+t,A+s),m=C(v-P);if(E=S+m,a.frontplot.attr("transform",R(e.xOffset2,e.yOffset2)+F([-m,f,p])),e.vangles){L=e.radialAxisAngle+m;var y=R(u,h)+F(-m),b=R(u,h)+F(-L);a.bg.attr("transform",y),a["radial-grid"].attr("transform",y),a["radial-axis"].attr("transform",b),a["radial-line"].select("line").attr("transform",b),e.updateRadialAxisTitle(d,g,L)}else e.clipPaths.forTraces.select("path").attr("transform",R(f,p)+F(m));z.each(function(){var t=n.select(this),e=l.getTranslate(t);t.attr("transform",R(e.x,e.y)+F([m]))}),I.each(function(){var t=n.select(this),e=t.select("text"),r=l.getTranslate(t);t.attr("transform",F([m,e.attr("x"),e.attr("y")])+R(r.x,r.y))}),c.rotation=o.modHalf(E,360),e.updateAngularAxis(d,g),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&O.call(l.hideOutsideRangePoints,e);var _=!1;for(var M in e.traceHash)if(i.traceIs(M,"gl")){var D=e.traceHash[M],N=o.filterVisible(D);D[0][0].trace._module.plot(r,e,N,g),N.length&&(_=!0)}_&&(w(r),k(r));var j={};B(j),r.emit("plotly_relayouting",j)}function B(t){t[e.id+".angularaxis.rotation"]=E,e.vangles&&(t[e.id+".radialaxis.angle"]=L)}function N(){I.select("text").attr("transform",null);var t={};B(t),i.call("_guiRelayout",r,t)}y.prepFn=function(n,a,i){var o=t[e.id];S=o.angularaxis.rotation;var s=m.getBoundingClientRect();T=a-s.left,A=i-s.top,P=x(T,A),y.moveFn=D,y.doneFn=N,b(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(y.prepFn=o.noop,_(n.select(m),null)),g.init(y)},O.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),a=this.radialAxis,i=a.c2l(t.r),s=a._rl;return(r?A.isPtInsidePolygon:o.isPtInsideSector)(i,n,s,e,r)},O.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?A.pathPolygon:o.pathArc)(t,e[0],e[1],r)},O.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?A.pathPolygon:o.pathSector)(t,e[0],e[1],r)},O.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?A.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},O.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},O.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{"../../components/color":591,"../../components/dragelement":609,"../../components/drawing":612,"../../components/fx":630,"../../components/titles":679,"../../constants/alignment":686,"../../lib":717,"../../lib/clear_gl_canvases":702,"../../lib/setcursor":737,"../../plot_api/subroutines":756,"../../plots/cartesian/axes":765,"../../registry":846,"../cartesian/autorange":764,"../cartesian/dragbox":773,"../cartesian/select":782,"../cartesian/set_convert":783,"../plots":826,"./constants":827,"./helpers":828,"./set_convert":839,d3:165,tinycolor2:535}],839:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../cartesian/set_convert"),i=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(a(t,r),t._id){case"x":case"radialaxis":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],a=r.innerRadius,i=(r.radius-a)/(n-e),o=a/i,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*i},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case"angularaxis":!function(t,e){var r=t.type;if("linear"===r){var a=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return"degrees"===e?i(t):t}(a(t),e)},t.c2d=function(t,e){return s(function(t,e){return"degrees"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,a){var i,o,s=e[a],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&"linear"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(i=new Array(l),o=0;o<l;o++)i[o]=c(s[o])}else{var u=a+"0",h="d"+a,f=u in e?c(e[u]):0,p=e[h]?c(e[h]):(t.period||2*Math.PI)/l;for(i=new Array(l),o=0;o<l;o++)i[o]=f+o*p}return i},t.setGeometry=function(){var a,s,l,c,u=e.sector,h=u.map(i),f={clockwise:-1,counterclockwise:1}[t.direction],p=i(t.rotation),d=function(t){return f*t+p},g=function(t){return(t-p)/f};switch(r){case"linear":s=a=n.identity,c=i,l=o,t.range=n.isFullCircle(h)?[u[0],u[0]+360]:h.map(g).map(o);break;case"category":var v=t._categories.length,m=t.period?Math.max(t.period,v):v;0===m&&(m=1),s=c=function(t){return 2*t*Math.PI/m},a=l=function(t){return t*m/Math.PI/2},t.range=[0,m]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return a(g(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(g(t))}}}(t,e)}}},{"../../lib":717,"../cartesian/set_convert":783}],840:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../plot_api/plot_template"),i=t("./domain").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,h=o.handleDefaults,f=o.partition||"x",p=e._subplots[c],d=p.length,g=d&&p[0].replace(/\d+$/,"");function v(t,e){return n.coerce(s,l,u,t,e)}for(var m=0;m<d;m++){var y=p[m];s=t[y]?t[y]:t[y]={},l=a.newContainer(e,y,g),v("uirevision",e.uirevision);var x={};x[f]=[m/d,(m+1)/d],i(l,e,v,x),o.id=y,h(s,l,v,o)}}},{"../lib":717,"../plot_api/plot_template":755,"./domain":790}],841:[function(t,e,r){"use strict";['Variables are inserted using %{variable}, for example "y: %{y}".','Numbers are formatted using d3-format\'s syntax %{variable:d3-format}, for example "Price: %{y:$.2f}".',t("../constants/docs").FORMAT_LINK,"for details on the formatting syntax.",'Dates are formatted using d3-time-format\'s syntax %{variable|d3-time-format}, for example "Day: %{2019-01-01|%A}".',t("../constants/docs").DATE_FORMAT_LINK,"for details on the date formatting syntax."].join(" ");function n(t){var e=t.description?" "+t.description:"",r=t.keys||[];if(r.length>0){for(var n=[],a=0;a<r.length;a++)n[a]="`"+r[a]+"`";e+="Finally, the template string has access to ",e=1===r.length?"variable "+n[0]:"variables "+n.slice(0,-1).join(", ")+" and "+n.slice(-1)+"."}return e}r.hovertemplateAttrs=function(t,e){t=t||{};n(e=e||{});var r={valType:"string",dflt:"",editType:t.editType||"none"};return!1!==t.arrayOk&&(r.arrayOk=!0),r},r.texttemplateAttrs=function(t,e){t=t||{};n(e=e||{});var r={valType:"string",dflt:"",editType:t.editType||"calc"};return!1!==t.arrayOk&&(r.arrayOk=!0),r}},{"../constants/docs":688}],842:[function(t,e,r){"use strict";var n=t("./ternary"),a=t("../../plots/get_data").getSubplotCalcData,i=t("../../lib").counterRegex;r.name="ternary";var o=r.attr="subplot";r.idRoot="ternary",r.idRegex=r.attrRegex=i("ternary"),(r.attributes={})[o]={valType:"subplotid",dflt:"ternary",editType:"calc"},r.layoutAttributes=t("./layout_attributes"),r.supplyLayoutDefaults=t("./layout_defaults"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots.ternary,o=0;o<i.length;o++){var s=i[o],l=a(r,"ternary",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var a=n._subplots.ternary||[],i=0;i<a.length;i++){var o=a[i],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers["a-title"].remove(),s.layers["b-title"].remove(),s.layers["c-title"].remove())}}},{"../../lib":717,"../../plots/get_data":800,"./layout_attributes":843,"./layout_defaults":844,"./ternary":845}],843:[function(t,e,r){"use strict";var n=t("../../components/color/attributes"),a=t("../domain").attributes,i=t("../cartesian/layout_attributes"),o=t("../../plot_api/edit_types").overrideAll,s=t("../../lib/extend").extendFlat,l={title:{text:i.title.text,font:i.title.font},color:i.color,tickmode:i.tickmode,nticks:s({},i.nticks,{dflt:6,min:1}),tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:s({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:s({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth,layer:i.layer,min:{valType:"number",dflt:0,min:0},_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},c=e.exports=o({domain:a({name:"ternary"}),bgcolor:{valType:"color",dflt:n.background},sum:{valType:"number",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},"plot","from-root");c.uirevision={valType:"any",editType:"none"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:"any",editType:"none"}},{"../../components/color/attributes":590,"../../lib/extend":708,"../../plot_api/edit_types":748,"../cartesian/layout_attributes":777,"../domain":790}],844:[function(t,e,r){"use strict";var n=t("../../components/color"),a=t("../../plot_api/plot_template"),i=t("../../lib"),o=t("../subplot_defaults"),s=t("../cartesian/tick_label_defaults"),l=t("../cartesian/tick_mark_defaults"),c=t("../cartesian/tick_value_defaults"),u=t("../cartesian/line_grid_defaults"),h=t("./layout_attributes"),f=["aaxis","baxis","caxis"];function p(t,e,r,i){var o,s,l,c=r("bgcolor"),u=r("sum");i.bgColor=n.combine(c,i.paper_bgcolor);for(var h=0;h<f.length;h++)s=t[o=f[h]]||{},(l=a.newContainer(e,o))._name=o,d(s,l,i,e);var p=e.aaxis,g=e.baxis,v=e.caxis;p.min+g.min+v.min>=u&&(p.min=0,g.min=0,v.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var a=h[e._name];function o(r,n){return i.coerce(t,e,a,r,n)}o("uirevision",n.uirevision),e.type="linear";var f=o("color"),p=f!==a.color.dflt?f:r.font.color,d=e._name.charAt(0).toUpperCase(),g="Component "+d,v=o("title.text",g);e._hovertitle=v===g?v:d,i.coerceFont(o,"title.font",{family:r.font.family,size:Math.round(1.2*r.font.size),color:p}),o("min"),c(t,e,o,"linear"),s(t,e,o,"linear",{}),l(t,e,o,{outerTicks:!0}),o("showticklabels")&&(i.coerceFont(o,"tickfont",{family:r.font.family,size:r.font.size,color:p}),o("tickangle"),o("tickformat")),u(t,e,o,{dfltColor:f,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:a}),o("hoverformat"),o("layer")}e.exports=function(t,e,r){o(t,e,r,{type:"ternary",attributes:h,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{"../../components/color":591,"../../lib":717,"../../plot_api/plot_template":755,"../cartesian/line_grid_defaults":779,"../cartesian/tick_label_defaults":784,"../cartesian/tick_mark_defaults":785,"../cartesian/tick_value_defaults":786,"../subplot_defaults":840,"./layout_attributes":843}],845:[function(t,e,r){"use strict";var n=t("d3"),a=t("tinycolor2"),i=t("../../registry"),o=t("../../lib"),s=o._,l=t("../../components/color"),c=t("../../components/drawing"),u=t("../cartesian/set_convert"),h=t("../../lib/extend").extendFlat,f=t("../plots"),p=t("../cartesian/axes"),d=t("../../components/dragelement"),g=t("../../components/fx"),v=t("../../components/titles"),m=t("../cartesian/select").prepSelect,y=t("../cartesian/select").selectOnClick,x=t("../cartesian/select").clearSelect,b=t("../cartesian/constants");function _(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=_;var w=_.prototype;w.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},w.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var a=0;a<t.length;a++){if(!1===t[a][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),f.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select("path").call(l.fill,r.bgcolor)},w.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId="clip"+this.layoutId+this.id,a=this.clipIdRelative="clip-relative"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,"clipPath",n,function(t){t.append("path").attr("d","M0,0Z")}),this.clipDefRelative=o.ensureSingleById(t._clips,"clipPath",a,function(t){t.append("path").attr("d","M0,0Z")}),this.plotContainer=o.ensureSingle(this.container,"g",this.id),this.updateLayers(r),c.setClipUrl(this.layers.backplot,n,e),c.setClipUrl(this.layers.grids,n,e)},w.updateLayers=function(t){var e=this.layers,r=["draglayer","plotbg","backplot","grids"];"below traces"===t.aaxis.layer&&r.push("aaxis","aline"),"below traces"===t.baxis.layer&&r.push("baxis","bline"),"below traces"===t.caxis.layer&&r.push("caxis","cline"),r.push("frontplot"),"above traces"===t.aaxis.layer&&r.push("aaxis","aline"),"above traces"===t.baxis.layer&&r.push("baxis","bline"),"above traces"===t.caxis.layer&&r.push("caxis","cline");var a=this.plotContainer.selectAll("g.toplevel").data(r,String),i=["agrid","bgrid","cgrid"];a.enter().append("g").attr("class",function(t){return"toplevel "+t}).each(function(t){var r=n.select(this);e[t]=r,"frontplot"===t?r.append("g").classed("scatterlayer",!0):"backplot"===t?r.append("g").classed("maplayer",!0):"plotbg"===t?r.append("path").attr("d","M0,0Z"):"aline"===t||"bline"===t||"cline"===t?r.append("path"):"grids"===t&&i.forEach(function(t){e[t]=r.append("g").classed("grid "+t,!0)})}),a.order()};var k=Math.sqrt(4/3);w.adjustLayout=function(t,e){var r,n,a,i,o,s,f=this,p=t.domain,d=(p.x[0]+p.x[1])/2,g=(p.y[0]+p.y[1])/2,v=p.x[1]-p.x[0],m=p.y[1]-p.y[0],y=v*e.w,x=m*e.h,b=t.sum,_=t.aaxis.min,w=t.baxis.min,T=t.caxis.min;y>k*x?a=(i=x)*k:i=(a=y)/k,o=v*a/y,s=m*i/x,r=e.l+e.w*d-a/2,n=e.t+e.h*(1-g)-i/2,f.x0=r,f.y0=n,f.w=a,f.h=i,f.sum=b,f.xaxis={type:"linear",range:[_+2*T-b,b-_-2*w],domain:[d-o/2,d+o/2],_id:"x"},u(f.xaxis,f.graphDiv._fullLayout),f.xaxis.setScale(),f.xaxis.isPtWithinRange=function(t){return t.a>=f.aaxis.range[0]&&t.a<=f.aaxis.range[1]&&t.b>=f.baxis.range[1]&&t.b<=f.baxis.range[0]&&t.c>=f.caxis.range[1]&&t.c<=f.caxis.range[0]},f.yaxis={type:"linear",range:[_,b-w-T],domain:[g-s/2,g+s/2],_id:"y"},u(f.yaxis,f.graphDiv._fullLayout),f.yaxis.setScale(),f.yaxis.isPtWithinRange=function(){return!0};var M=f.yaxis.domain[0],A=f.aaxis=h({},t.aaxis,{range:[_,b-w-T],side:"left",tickangle:(+t.aaxis.tickangle||0)-30,domain:[M,M+s*k],anchor:"free",position:0,_id:"y",_length:a});u(A,f.graphDiv._fullLayout),A.setScale();var S=f.baxis=h({},t.baxis,{range:[b-_-T,w],side:"bottom",domain:f.xaxis.domain,anchor:"free",position:0,_id:"x",_length:a});u(S,f.graphDiv._fullLayout),S.setScale();var E=f.caxis=h({},t.caxis,{range:[b-_-w,T],side:"right",tickangle:(+t.caxis.tickangle||0)+30,domain:[M,M+s*k],anchor:"free",position:0,_id:"y",_length:a});u(E,f.graphDiv._fullLayout),E.setScale();var L="M"+r+","+(n+i)+"h"+a+"l-"+a/2+",-"+i+"Z";f.clipDef.select("path").attr("d",L),f.layers.plotbg.select("path").attr("d",L);var C="M0,"+i+"h"+a+"l-"+a/2+",-"+i+"Z";f.clipDefRelative.select("path").attr("d",C);var P="translate("+r+","+n+")";f.plotContainer.selectAll(".scatterlayer,.maplayer").attr("transform",P),f.clipDefRelative.select("path").attr("transform",null);var O="translate("+(r-S._offset)+","+(n+i)+")";f.layers.baxis.attr("transform",O),f.layers.bgrid.attr("transform",O);var z="translate("+(r+a/2)+","+n+")rotate(30)translate(0,"+-A._offset+")";f.layers.aaxis.attr("transform",z),f.layers.agrid.attr("transform",z);var I="translate("+(r+a/2)+","+n+")rotate(-30)translate(0,"+-E._offset+")";f.layers.caxis.attr("transform",I),f.layers.cgrid.attr("transform",I),f.drawAxes(!0),f.layers.aline.select("path").attr("d",A.showline?"M"+r+","+(n+i)+"l"+a/2+",-"+i:"M0,0").call(l.stroke,A.linecolor||"#000").style("stroke-width",(A.linewidth||0)+"px"),f.layers.bline.select("path").attr("d",S.showline?"M"+r+","+(n+i)+"h"+a:"M0,0").call(l.stroke,S.linecolor||"#000").style("stroke-width",(S.linewidth||0)+"px"),f.layers.cline.select("path").attr("d",E.showline?"M"+(r+a/2)+","+n+"l"+a/2+","+i:"M0,0").call(l.stroke,E.linecolor||"#000").style("stroke-width",(E.linewidth||0)+"px"),f.graphDiv._context.staticPlot||f.initInteractions(),c.setClipUrl(f.layers.frontplot,f._hasClipOnAxisFalse?null:f.clipId,f.graphDiv)},w.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+"title",n=this.layers,a=this.aaxis,i=this.baxis,o=this.caxis;if(this.drawAx(a),this.drawAx(i),this.drawAx(o),t){var l=Math.max(a.showticklabels?a.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+("outside"===o.ticks?.87*o.ticklen:0)),c=(i.showticklabels?i.tickfont.size:0)+("outside"===i.ticks?i.ticklen:0)+3;n["a-title"]=v.draw(e,"a"+r,{propContainer:a,propName:this.id+".aaxis.title",placeholder:s(e,"Click to enter Component A title"),attributes:{x:this.x0+this.w/2,y:this.y0-a.title.font.size/3-l,"text-anchor":"middle"}}),n["b-title"]=v.draw(e,"b"+r,{propContainer:i,propName:this.id+".baxis.title",placeholder:s(e,"Click to enter Component B title"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*i.title.font.size+c,"text-anchor":"middle"}}),n["c-title"]=v.draw(e,"c"+r,{propContainer:o,propName:this.id+".caxis.title",placeholder:s(e,"Click to enter Component C title"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,"text-anchor":"middle"}})}},w.drawAx=function(t){var e,r=this.graphDiv,n=t._name,a=n.charAt(0),i=t._id,s=this.layers[n],l=a+"tickLayout",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll("."+i+"tick").remove(),this[l]=c),t.setScale();var u=p.calcTicks(t),h=p.clipEnds(t,u),f=p.makeTransFn(t),d=p.getTickSigns(t)[2],g=o.deg2rad(30),v=d*(t.linewidth||1)/2,m=d*t.ticklen,y=this.w,x=this.h,b="b"===a?"M0,"+v+"l"+Math.sin(g)*m+","+Math.cos(g)*m:"M"+v+",0l"+Math.cos(g)*m+","+-Math.sin(g)*m,_={a:"M0,0l"+x+",-"+y/2,b:"M0,0l-"+y/2+",-"+x,c:"M0,0l-"+x+","+y/2}[a];p.drawTicks(r,t,{vals:"inside"===t.ticks?h:u,layer:s,path:b,transFn:f,crisp:!1}),p.drawGrid(r,t,{vals:h,layer:this.layers[a+"grid"],path:_,transFn:f,crisp:!1}),p.drawLabels(r,t,{vals:u,layer:s,transFn:f,labelFns:p.makeLabelFns(t,0,30)})};var T=b.MINZOOM/2+.87,M="m-0.87,.5h"+T+"v3h-"+(T+5.2)+"l"+(T/2+2.6)+",-"+(.87*T+4.5)+"l2.6,1.5l-"+T/2+","+.87*T+"Z",A="m0.87,.5h-"+T+"v3h"+(T+5.2)+"l-"+(T/2+2.6)+",-"+(.87*T+4.5)+"l-2.6,1.5l"+T/2+","+.87*T+"Z",S="m0,1l"+T/2+","+.87*T+"l2.6,-1.5l-"+(T/2+2.6)+",-"+(.87*T+4.5)+"l-"+(T/2+2.6)+","+(.87*T+4.5)+"l2.6,1.5l"+T/2+",-"+.87*T+"Z",E="m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2Z",L=!0;function C(t){n.select(t).selectAll(".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners").remove()}w.initInteractions=function(){var t,e,r,n,u,h,f,p,v,_,w=this,T=w.layers.plotbg.select("path").node(),P=w.graphDiv,O=P._fullLayout._zoomlayer,z={element:T,gd:P,plotinfo:{id:w.id,xaxis:w.xaxis,yaxis:w.yaxis},subplot:w.id,prepFn:function(i,o,s){z.xaxes=[w.xaxis],z.yaxes=[w.yaxis];var c=P._fullLayout.dragmode;z.minDrag="lasso"===c?1:void 0,"zoom"===c?(z.moveFn=N,z.clickFn=D,z.doneFn=j,function(i,o,s){var c=T.getBoundingClientRect();t=o-c.left,e=s-c.top,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,n=w.aaxis.range[1]-r.a,h=a(w.graphDiv._fullLayout[w.id].bgcolor).getLuminance(),f="M0,"+w.h+"L"+w.w/2+", 0L"+w.w+","+w.h+"Z",p=!1,v=O.append("path").attr("class","zoombox").attr("transform","translate("+w.x0+", "+w.y0+")").style({fill:h>.2?"rgba(0,0,0,0)":"rgba(255,255,255,0)","stroke-width":0}).attr("d",f),_=O.append("path").attr("class","zoombox-corners").attr("transform","translate("+w.x0+", "+w.y0+")").style({fill:l.background,stroke:l.defaultLine,"stroke-width":1,opacity:0}).attr("d","M0,0Z"),x(P)}(0,o,s)):"pan"===c?(z.moveFn=V,z.clickFn=D,z.doneFn=U,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,x(P)):"select"!==c&&"lasso"!==c||m(i,o,s,z,c)}};function I(t){var e={};return e[w.id+".aaxis.min"]=t.a,e[w.id+".baxis.min"]=t.b,e[w.id+".caxis.min"]=t.c,e}function D(t,e){var r=P._fullLayout.clickmode;C(P),2===t&&(P.emit("plotly_doubleclick",null),i.call("_guiRelayout",P,I({a:0,b:0,c:0}))),r.indexOf("select")>-1&&1===t&&y(e,P,[w.xaxis],[w.yaxis],w.id,z),r.indexOf("event")>-1&&g.click(P,e,w.id)}function R(t,e){return 1-e/w.h}function F(t,e){return 1-(t+(w.h-e)/Math.sqrt(3))/w.w}function B(t,e){return(t-(w.h-e)/Math.sqrt(3))/w.w}function N(a,i){var o=t+a,s=e+i,l=Math.max(0,Math.min(1,R(0,e),R(0,s))),c=Math.max(0,Math.min(1,F(t,e),F(o,s))),d=Math.max(0,Math.min(1,B(t,e),B(o,s))),g=(l/2+d)*w.w,m=(1-l/2-c)*w.w,y=(g+m)/2,x=m-g,T=(1-l)*w.h,L=T-x/k;x<b.MINZOOM?(u=r,v.attr("d",f),_.attr("d","M0,0Z")):(u={a:r.a+l*n,b:r.b+c*n,c:r.c+d*n},v.attr("d",f+"M"+g+","+T+"H"+m+"L"+y+","+L+"L"+g+","+T+"Z"),_.attr("d","M"+t+","+e+E+"M"+g+","+T+M+"M"+m+","+T+A+"M"+y+","+L+S)),p||(v.transition().style("fill",h>.2?"rgba(0,0,0,0.4)":"rgba(255,255,255,0.3)").duration(200),_.transition().style("opacity",1).duration(200),p=!0),P.emit("plotly_relayouting",I(u))}function j(){C(P),u!==r&&(i.call("_guiRelayout",P,I(u)),L&&P.data&&P._context.showTips&&(o.notifier(s(P,"Double-click to zoom back out"),"long"),L=!1))}function V(t,e){var n=t/w.xaxis._m,a=e/w.yaxis._m,i=[(u={a:r.a-a,b:r.b+(n+a)/2,c:r.c-(n-a)/2}).a,u.b,u.c].sort(),o=i.indexOf(u.a),s=i.indexOf(u.b),l=i.indexOf(u.c);i[0]<0&&(i[1]+i[0]/2<0?(i[2]+=i[0]+i[1],i[0]=i[1]=0):(i[2]+=i[0]/2,i[1]+=i[0]/2,i[0]=0),u={a:i[o],b:i[s],c:i[l]},e=(r.a-u.a)*w.yaxis._m,t=(r.c-u.c-r.b+u.b)*w.xaxis._m);var h="translate("+(w.x0+t)+","+(w.y0+e)+")";w.plotContainer.selectAll(".scatterlayer,.maplayer").attr("transform",h);var f="translate("+-t+","+-e+")";w.clipDefRelative.select("path").attr("transform",f),w.aaxis.range=[u.a,w.sum-u.b-u.c],w.baxis.range=[w.sum-u.a-u.c,u.b],w.caxis.range=[w.sum-u.a-u.b,u.c],w.drawAxes(!1),w._hasClipOnAxisFalse&&w.plotContainer.select(".scatterlayer").selectAll(".trace").call(c.hideOutsideRangePoints,w),P.emit("plotly_relayouting",I(u))}function U(){i.call("_guiRelayout",P,I(u))}T.onmousemove=function(t){g.hover(P,t,w.id),P._fullLayout._lasthover=T,P._fullLayout._hoversubplot=w.id},T.onmouseout=function(t){P._dragging||d.unhover(P,t)},d.init(z)}},{"../../components/color":591,"../../components/dragelement":609,"../../components/drawing":612,"../../components/fx":630,"../../components/titles":679,"../../lib":717,"../../lib/extend":708,"../../registry":846,"../cartesian/axes":765,"../cartesian/constants":771,"../cartesian/select":782,"../cartesian/set_convert":783,"../plots":826,d3:165,tinycolor2:535}],846:[function(t,e,r){"use strict";var n=t("./lib/loggers"),a=t("./lib/noop"),i=t("./lib/push_unique"),o=t("./lib/is_plain_object"),s=t("./lib/dom").addStyleRule,l=t("./lib/extend"),c=t("./plots/attributes"),u=t("./plots/layout_attributes"),h=l.extendFlat,f=l.extendDeepAll;function p(t){var e=t.name,a=t.categories,i=t.meta;if(r.modules[e])n.log("Type "+e+" already registered");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log("Plot type "+e+" already registered.");for(var a in m(t),r.subplotsRegistry[e]=t,r.componentsRegistry)b(a,t.name)}(t.basePlotModule);for(var o={},l=0;l<a.length;l++)o[a[l]]=!0,r.allCategories[a[l]]=!0;for(var c in r.modules[e]={_module:t,categories:o},i&&Object.keys(i).length&&(r.modules[e].meta=i),r.allTypes.push(e),r.componentsRegistry)y(c,e);t.layoutAttributes&&h(r.traceLayoutAttributes,t.layoutAttributes);var u=t.basePlotModule,f=u.name;if("mapbox"===f){var p=u.constants.styleRules;for(var d in p)s(".js-plotly-plot .plotly .mapboxgl-"+d,p[d])}"geo"!==f&&"mapbox"!==f||void 0===typeof window||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if("string"!=typeof t.name)throw new Error("Component module *name* must be a string.");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&i(r.layoutArrayContainers,e),m(t)),r.modules)y(e,n);for(var a in r.subplotsRegistry)b(e,a);for(var o in r.transformsRegistry)x(e,o);t.schema&&t.schema.layout&&f(u,t.schema.layout)}function g(t){if("string"!=typeof t.name)throw new Error("Transform module *name* must be a string.");var e="Transform module "+t.name,a="function"==typeof t.transform,i="function"==typeof t.calcTransform;if(!a&&!i)throw new Error(e+" is missing a *transform* or *calcTransform* method.");for(var s in a&&i&&n.log([e+" has both a *transform* and *calcTransform* methods.","Please note that all *transform* methods are executed","before all *calcTransform* methods."].join(" ")),o(t.attributes)||n.log(e+" registered without an *attributes* object."),"function"!=typeof t.supplyDefaults&&n.log(e+" registered without a *supplyDefaults* method."),r.transformsRegistry[t.name]=t,r.componentsRegistry)x(s,t.name)}function v(t){var e=t.name,n=e.split("-")[0],a=t.dictionary,i=t.format,o=a&&Object.keys(a).length,s=i&&Object.keys(i).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=a),s&&u.format===c.format&&(u.format=i)}o&&(c.dictionary=a),s&&(c.format=i)}function m(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)i(r.layoutArrayRegexes,e[n])}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var a=n.traces[e];a&&f(r.modules[e]._module.attributes,a)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var a=n.transforms[e];a&&f(r.transformsRegistry[e].attributes,a)}}function b(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var a=r.subplotsRegistry[e],i=a.layoutAttributes,o="subplot"===a.attr?a.name:a.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];i&&s&&f(i,s)}}function _(t){return"object"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error("No argument passed to Plotly.register.");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error("Invalid module was attempted to be registered!");switch(n.moduleType){case"trace":p(n);break;case"transform":g(n);break;case"component":d(n);break;case"locale":v(n);break;case"apiMethod":var a=n.name;r.apiMethodRegistry[a]=n.fn;break;default:throw new Error("Invalid module was attempted to be registered!")}}},r.getModule=function(t){var e=r.modules[_(t)];return!!e&&e._module},r.traceIs=function(t,e){if("various"===(t=_(t)))return!1;var a=r.modules[t];return a||(t&&"area"!==t&&n.log("Unrecognized trace type "+t+"."),a=r.modules[c.type.dflt]),!!a.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],a=0;a<n.length;a++)n[a].type===e&&r.push(a);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||a},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{"./lib/dom":706,"./lib/extend":708,"./lib/is_plain_object":718,"./lib/loggers":721,"./lib/noop":726,"./lib/push_unique":731,"./plots/attributes":762,"./plots/layout_attributes":817}],847:[function(t,e,r){"use strict";var n=t("../registry"),a=t("../lib"),i=a.extendFlat,o=a.extendDeep;function s(t){var e;switch(t){case"themes__thumb":e={autosize:!0,width:150,height:150,title:{text:""},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case"thumbnail":e={title:{text:""},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:"",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r;t.framework&&t.framework.isPolar&&(t=t.framework.getConfig());var a,l=t.data,c=t.layout,u=o([],l),h=o({},c,s(e.tileClass)),f=t._context||{};if(e.width&&(h.width=e.width),e.height&&(h.height=e.height),"thumbnail"===e.tileClass||"themes__thumb"===e.tileClass){h.annotations=[];var p=Object.keys(h);for(r=0;r<p.length;r++)a=p[r],["xaxis","yaxis","zaxis"].indexOf(a.slice(0,5))>-1&&(h[p[r]].title={text:""});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,"pie-like")&&(d.textposition="none")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)h.annotations.push(e.annotations[r]);var g=Object.keys(h).filter(function(t){return t.match(/^scene\d*$/)});if(g.length){var v={};for("thumbnail"===e.tileClass&&(v={title:{text:""},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<g.length;r++){var m=h[g[r]];m.xaxis||(m.xaxis={}),m.yaxis||(m.yaxis={}),m.zaxis||(m.zaxis={}),i(m.xaxis,v),i(m.yaxis,v),i(m.zaxis,v),m._scene=null}}var y=document.createElement("div");e.tileClass&&(y.className=e.tileClass);var x={gd:y,td:y,layout:h,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:f.mapboxAccessToken}};return"transparent"!==e.setBackground&&(x.config.setBackground=e.setBackground||"opaque"),x.gd.defaultLayout=s(e.tileClass),x}},{"../lib":717,"../registry":846}],848:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../plot_api/to_image"),i=t("./filesaver"),o=t("./helpers");e.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||"png",e.imageDataOnly=!0,new Promise(function(s,l){r&&r._snapshotInProgress&&l(new Error("Snapshotting already in progress.")),n.isIE()&&"svg"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=a(t,e),u=e.filename||t.fn||"newplot";u+="."+e.format.replace("-","."),c.then(function(t){return r&&(r._snapshotInProgress=!1),i(t,u,e.format)}).then(function(t){s(t)}).catch(function(t){r&&(r._snapshotInProgress=!1),l(t)})})}},{"../lib":717,"../plot_api/to_image":758,"./filesaver":849,"./helpers":850}],849:[function(t,e,r){"use strict";var n=t("../lib"),a=t("./helpers");e.exports=function(t,e,r){var i=document.createElement("a"),o="download"in i;return new Promise(function(s,l){var c,u;if(n.isIE9orBelow()&&l(new Error("IE < 10 unsupported")),n.isSafari()){var h="svg"===r?",":";base64,";return a.octetStream(h+encodeURIComponent(t)),s(e)}return n.isIE()?(c=a.createBlob(t,"svg"),window.navigator.msSaveBlob(c,e),c=null,s(e)):o?(c=a.createBlob(t,r),u=a.createObjectURL(c),i.href=u,i.download=e,document.body.appendChild(i),i.click(),document.body.removeChild(i),a.revokeObjectURL(u),c=null,s(e)):void l(new Error("download error"))})}},{"../lib":717,"./helpers":850}],850:[function(t,e,r){"use strict";var n=t("../registry");r.getDelay=function(t){return t._has&&(t._has("gl3d")||t._has("gl2d")||t._has("mapbox"))?500:0},r.getRedrawFunc=function(t){return function(){var e=t._fullLayout||{};!(e._has&&e._has("polar"))&&t.data&&t.data[0]&&t.data[0].r||n.getComponentMethod("colorbar","draw")(t)}},r.encodeSVG=function(t){return"data:image/svg+xml,"+encodeURIComponent(t)},r.encodeJSON=function(t){return"data:application/json,"+encodeURIComponent(t)};var a=window.URL||window.webkitURL;r.createObjectURL=function(t){return a.createObjectURL(t)},r.revokeObjectURL=function(t){return a.revokeObjectURL(t)},r.createBlob=function(t,e){if("svg"===e)return new window.Blob([t],{type:"image/svg+xml;charset=utf-8"});if("full-json"===e)return new window.Blob([t],{type:"application/json;charset=utf-8"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),a=0;a<e;a++)n[a]=t.charCodeAt(a);return r}(window.atob(t));return new window.Blob([r],{type:"image/"+e})},r.octetStream=function(t){document.location.href="data:application/octet-stream"+t},r.IMAGE_URL_PREFIX=/^data:image\/\w+;base64,/,r.MSG_IE_BAD_FORMAT="Sorry IE does not support downloading from canvas. Try {format:'svg'} instead."},{"../registry":846}],851:[function(t,e,r){"use strict";var n=t("./helpers"),a={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t("./cloneplot"),toSVG:t("./tosvg"),svgToImg:t("./svgtoimg"),toImage:t("./toimage"),downloadImage:t("./download")};e.exports=a},{"./cloneplot":847,"./download":848,"./helpers":850,"./svgtoimg":852,"./toimage":853,"./tosvg":854}],852:[function(t,e,r){"use strict";var n=t("../lib"),a=t("events").EventEmitter,i=t("./helpers");e.exports=function(t){var e=t.emitter||new a,r=new Promise(function(a,o){var s=window.Image,l=t.svg,c=t.format||"png";if(n.isIE()&&"svg"!==c){var u=new Error(i.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit("error",u)}var h,f,p=t.canvas,d=t.scale||1,g=t.width||300,v=t.height||150,m=d*g,y=d*v,x=p.getContext("2d"),b=new s;"svg"===c||n.isIE9orBelow()||n.isSafari()?f=i.encodeSVG(l):(h=i.createBlob(l,"svg"),f=i.createObjectURL(h)),p.width=m,p.height=y,b.onload=function(){var r;switch(h=null,i.revokeObjectURL(f),"svg"!==c&&x.drawImage(b,0,0,m,y),c){case"jpeg":r=p.toDataURL("image/jpeg");break;case"png":r=p.toDataURL("image/png");break;case"webp":r=p.toDataURL("image/webp");break;case"svg":r=f;break;default:var n="Image format is not jpeg, png, svg or webp.";if(o(new Error(n)),!t.promise)return e.emit("error",n)}a(r),t.promise||e.emit("success",r)},b.onerror=function(r){if(h=null,i.revokeObjectURL(f),o(r),!t.promise)return e.emit("error",r)},b.src=f});return t.promise?r:e}},{"../lib":717,"./helpers":850,events:106}],853:[function(t,e,r){"use strict";var n=t("events").EventEmitter,a=t("../registry"),i=t("../lib"),o=t("./helpers"),s=t("./cloneplot"),l=t("./tosvg"),c=t("./svgtoimg");e.exports=function(t,e){var r=new n,u=s(t,{format:"png"}),h=u.gd;h.style.position="absolute",h.style.left="-5000px",document.body.appendChild(h);var f=o.getRedrawFunc(h);return a.call("plot",h,u.data,u.layout,u.config).then(f).then(function(){var t=o.getDelay(h._fullLayout);setTimeout(function(){var t=l(h),n=document.createElement("canvas");n.id=i.randstr(),(r=c({format:e.format,width:h._fullLayout.width,height:h._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){h&&document.body.removeChild(h)}},t)}).catch(function(t){r.emit("error",t)}),r}},{"../lib":717,"../registry":846,"./cloneplot":847,"./helpers":850,"./svgtoimg":852,"./tosvg":854,events:106}],854:[function(t,e,r){"use strict";var n=t("d3"),a=t("../lib"),i=t("../components/drawing"),o=t("../components/color"),s=t("../constants/xmlns_namespaces"),l=/"/g,c=new RegExp('("TOBESTRIPPED)|(TOBESTRIPPED")',"g");e.exports=function(t,e,r){var u,h=t._fullLayout,f=h._paper,p=h._toppaper,d=h.width,g=h.height;f.insert("rect",":first-child").call(i.setRect,0,0,d,g).call(o.fill,h.paper_bgcolor);var v=h._basePlotModules||[];for(u=0;u<v.length;u++){var m=v[u];m.toSVG&&m.toSVG(t)}if(p){var y=p.node().childNodes,x=Array.prototype.slice.call(y);for(u=0;u<x.length;u++){var b=x[u];b.childNodes.length&&f.node().appendChild(b)}}if(h._draggers&&h._draggers.remove(),f.node().style.background="",f.selectAll("text").attr({"data-unformatted":null,"data-math":null}).each(function(){var t=n.select(this);if("hidden"!==this.style.visibility&&"none"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('"')&&t.style("font-family",e.replace(l,"TOBESTRIPPED"))}else t.remove()}),h._gradientUrlQueryParts){var _=[];for(var w in h._gradientUrlQueryParts)_.push(w);_.length&&f.selectAll(_.join(",")).each(function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf("url(")&&t.style("fill",e.replace(l,"TOBESTRIPPED"));var r=this.style.stroke;r&&-1!==r.indexOf("url(")&&t.style("stroke",r.replace(l,"TOBESTRIPPED"))})}"pdf"!==e&&"eps"!==e||f.selectAll("#MathJax_SVG_glyphs path").attr("stroke-width",0),f.node().setAttributeNS(s.xmlns,"xmlns",s.svg),f.node().setAttributeNS(s.xmlns,"xmlns:xlink",s.xlink),"svg"===e&&r&&(f.attr("width",r*d),f.attr("height",r*g),f.attr("viewBox","0 0 "+d+" "+g));var k=(new window.XMLSerializer).serializeToString(f.node());return k=function(t){var e=n.select("body").append("div").style({display:"none"}).html(""),r=t.replace(/(&[^;]*;)/gi,function(t){return"&lt;"===t?"&#60;":"&rt;"===t?"&#62;":-1!==t.indexOf("<")||-1!==t.indexOf(">")?"":e.html(t).text()});return e.remove(),r}(k),k=(k=k.replace(/&(?!\w+;|\#[0-9]+;| \#x[0-9A-F]+;)/g,"&amp;")).replace(c,"'"),a.isIE()&&(k=(k=(k=k.replace(/"/gi,"'")).replace(/(\('#)([^']*)('\))/gi,'("#$2")')).replace(/(\\')/gi,'"')),k}},{"../components/color":591,"../components/drawing":612,"../constants/xmlns_namespaces":694,"../lib":717,d3:165}],855:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,"tx"),n.mergeArray(e.hovertext,t,"htx");var a=e.marker;if(a){n.mergeArray(a.opacity,t,"mo",!0),n.mergeArray(a.color,t,"mc");var i=a.line;i&&(n.mergeArray(i.color,t,"mlc"),n.mergeArrayCastPositive(i.width,t,"mlw"))}}},{"../../lib":717}],856:[function(t,e,r){"use strict";var n=t("../scatter/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../../plots/template_attributes").texttemplateAttrs,o=t("../../components/colorscale/attributes"),s=t("../../plots/font_attributes"),l=t("./constants"),c=t("../../lib/extend").extendFlat,u=s({editType:"calc",arrayOk:!0,colorEditType:"style"}),h=c({},n.marker.line.width,{dflt:0}),f=c({width:h,editType:"calc"},o("marker.line")),p=c({line:f,editType:"calc"},o("marker"),{opacity:{valType:"number",arrayOk:!0,dflt:1,min:0,max:1,editType:"style"}});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,texttemplate:i({editType:"plot"},{keys:l.eventDataKeys}),hovertext:n.hovertext,hovertemplate:a({},{keys:l.eventDataKeys}),textposition:{valType:"enumerated",values:["inside","outside","auto","none"],dflt:"none",arrayOk:!0,editType:"calc"},insidetextanchor:{valType:"enumerated",values:["end","middle","start"],dflt:"end",editType:"plot"},textangle:{valType:"angle",dflt:"auto",editType:"plot"},textfont:c({},u,{}),insidetextfont:c({},u,{}),outsidetextfont:c({},u,{}),constraintext:{valType:"enumerated",values:["inside","outside","both","none"],dflt:"both",editType:"calc"},cliponaxis:c({},n.cliponaxis,{}),orientation:{valType:"enumerated",values:["v","h"],editType:"calc+clearAxisTypes"},base:{valType:"any",dflt:null,arrayOk:!0,editType:"calc"},offset:{valType:"number",dflt:null,arrayOk:!0,editType:"calc"},width:{valType:"number",dflt:null,min:0,arrayOk:!0,editType:"calc"},marker:p,offsetgroup:{valType:"string",dflt:"",editType:"calc"},alignmentgroup:{valType:"string",dflt:"",editType:"calc"},selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:"style"},textfont:n.selected.textfont,editType:"style"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:"style"},textfont:n.unselected.textfont,editType:"style"},r:n.r,t:n.t,_deprecated:{bardir:{valType:"enumerated",editType:"calc",values:["v","h"]}}}},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plots/font_attributes":791,"../../plots/template_attributes":841,"../scatter/attributes":1120,"./constants":858}],857:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../components/colorscale/helpers").hasColorscale,i=t("../../components/colorscale/calc"),o=t("./arrays_to_calcdata"),s=t("../scatter/calc_selection");e.exports=function(t,e){var r,l,c=n.getFromId(t,e.xaxis||"x"),u=n.getFromId(t,e.yaxis||"y");"h"===e.orientation?(r=c.makeCalcdata(e,"x"),l=u.makeCalcdata(e,"y")):(r=u.makeCalcdata(e,"y"),l=c.makeCalcdata(e,"x"));for(var h=Math.min(l.length,r.length),f=new Array(h),p=0;p<h;p++)f[p]={p:l[p],s:r[p]},e.ids&&(f[p].id=String(e.ids[p]));return a(e,"marker")&&i(t,e,{vals:e.marker.color,containerStr:"marker",cLetter:"c"}),a(e,"marker.line")&&i(t,e,{vals:e.marker.line.color,containerStr:"marker.line",cLetter:"c"}),o(f,e),s(f,e),f}},{"../../components/colorscale/calc":599,"../../components/colorscale/helpers":602,"../../plots/cartesian/axes":765,"../scatter/calc_selection":1122,"./arrays_to_calcdata":855}],858:[function(t,e,r){"use strict";e.exports={TEXTPAD:3,eventDataKeys:["value","label"]}},{}],859:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib").isArrayOrTypedArray,i=t("../../constants/numerical").BADNUM,o=t("../../registry"),s=t("../../plots/cartesian/axes"),l=t("../../plots/cartesian/axis_ids").getAxisGroup,c=t("./sieve.js");function u(t,e,r,o,u){if(o.length){var b,_,w,k;switch(function(t,e){var r,i;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c="funnel"===l.type?l._base:l.base,u="h"===l.orientation?l.xcalendar:l.ycalendar,h="category"===t.type||"multicategory"===t.type?function(){return null}:t.d2c;if(a(c)){for(i=0;i<Math.min(c.length,s.length);i++)o=h(c[i],0,u),n(o)?(s[i].b=+o,s[i].hasB=1):s[i].b=0;for(;i<s.length;i++)s[i].b=0}else{o=h(c,0,u);var f=n(o);for(o=f?o:0,i=0;i<s.length;i++)s[i].b=o,f&&(s[i].hasB=1)}}}(r,o),u.mode){case"overlay":h(e,r,o,u);break;case"group":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.offset?_.push(k):b.push(k);_.length&&function(t,e,r,n,a){var o=new c(n,{sepNegVal:!1,overlapNoMerge:!a.norm});(function(t,e,r,n){for(var a=t._fullLayout,i=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,h=i.length!==o.length,f=s*(1-n.gap),v=l(a,e._id)+c[0][0].trace.orientation,m=a._alignmentOpts[v]||{},y=0;y<u;y++){var x,b,_=c[y],w=_[0].trace,k=m[w.alignmentgroup]||{},T=Object.keys(k.offsetGroups||{}).length,M=(x=T?f/T:h?f/u:f)*(1-(n.groupgap||0));b=T?((2*w._offsetIndex+1-T)*x-M)/2:h?((2*y+1-u)*x-M)/2:-M/2;var A=_[0].t;A.barwidth=M,A.poffset=b,A.bargroupwidth=f,A.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),g(e,r,h)})(t,e,o,a),function(t){for(var e=t.traces,r=0;r<e.length;r++){var n=e[r],a=n[0].trace;if(void 0===a.base)for(var o=new c([n],{sepNegVal:!0,overlapNoMerge:!0}),s=0;s<n.length;s++){var l=n[s];if(l.p!==i){var u=o.put(l.p,l.b+l.s);u&&(l.b=u)}}}}(o),a.norm?(m(o),y(r,o,a)):v(r,o)}(t,e,r,_,u),b.length&&h(e,r,b,u);break;case"stack":case"relative":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.base?_.push(k):b.push(k);_.length&&function(t,e,r,n,a){var o=new c(n,{sepNegVal:"relative"===a.mode,overlapNoMerge:!(a.norm||"stack"===a.mode||"relative"===a.mode)});f(e,o,a),function(t,e,r){var n,a,o,l,c,u,h=x(t),f=e.traces;for(l=0;l<f.length;l++)if(n=f[l],"funnel"===(a=n[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==i&&e.put(u.p,-.5*u.s);for(l=0;l<f.length;l++){n=f[l],a=n[0].trace,o="funnel"===a.type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==i){var d;d=o?u.s:u.s+u.b;var g=e.put(u.p,d),v=g+d;u.b=g,u[h]=v,r.norm||(p.push(v),u.hasB&&p.push(g))}r.norm||(a._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,a);for(var l=0;l<n.length;l++)for(var u=n[l],h=0;h<u.length;h++){var p=u[h];if(p.s!==i){var d=p.b+p.s===o.get(p.p,p.s);d&&(p._outmost=!0)}}a.norm&&y(r,o,a)}(0,e,r,_,u),b.length&&h(e,r,b,u)}!function(t,e){var r,a,i,o=x(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(i=t[r],a=0;a<i.length;a++){var u=i[a].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var h=1e4/(c-l),f=s.round=function(t){return String(Math.round(h*(t-l)))};for(r=0;r<t.length;r++){(i=t[r])[0].t.extents=s;var p=i[0].t.poffset,d=Array.isArray(p);for(a=0;a<i.length;a++){var g=i[a],v=g[o]-g.w/2;if(n(v)){var m=g[o]+g.w/2,y=f(g.p);s[y]?s[y]=[Math.min(v,s[y][0]),Math.max(m,s[y][1])]:s[y]=[v,m]}g.p0=g.p+(d?p[a]:p),g.p1=g.p0+g.w,g.s0=g.b,g.s1=g.s0+g.s}}}(o,e)}}function h(t,e,r,n){for(var a=0;a<r.length;a++){var i=r[a],o=new c([i],{sepNegVal:!1,overlapNoMerge:!n.norm});f(t,o,n),n.norm?(m(o),y(e,o,n)):v(e,o)}}function f(t,e,r){for(var n=e.minDiff,a=e.traces,i=n*(1-r.gap),o=i*(1-(r.groupgap||0)),s=-o/2,l=0;l<a.length;l++){var c=a[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=i,c.bardelta=n}e.binWidth=a[0][0].t.barwidth/100,p(e),d(t,e),g(t,e)}function p(t){var e,r,i=t.traces;for(e=0;e<i.length;e++){var o,s=i[e],l=s[0],c=l.trace,u=l.t,h=c._offset||c.offset,f=u.poffset;if(a(h)){for(o=Array.prototype.slice.call(h,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=f);for(r=o.length;r<s.length;r++)o.push(f);u.poffset=o}else void 0!==h&&(u.poffset=h);var p=c._width||c.width,d=u.barwidth;if(a(p)){var g=Array.prototype.slice.call(p,0,s.length);for(r=0;r<g.length;r++)n(g[r])||(g[r]=d);for(r=g.length;r<s.length;r++)g.push(d);if(u.barwidth=g,void 0===h){for(o=[],r=0;r<s.length;r++)o.push(f+(d-g[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===h&&(u.poffset=f+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),a=0;a<r.length;a++)for(var i=r[a],o=i[0].t,s=o.poffset,l=Array.isArray(s),c=o.barwidth,u=Array.isArray(c),h=0;h<i.length;h++){var f=i[h],p=f.w=u?c[h]:c;f[n]=f.p+(l?s[h]:s)+p/2}}function g(t,e,r){var n=e.traces,a=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var i=0;i<n.length;i++){var o,l,c,u,h=n[i],f=h[0],p=f.trace,d=[];for(u=0;u<h.length;u++)l=(o=h[u]).p-a,c=o.p+a,d.push(l,c);if(p.width||p.offset){var g=f.t,v=g.poffset,m=g.barwidth,y=Array.isArray(v),x=Array.isArray(m);for(u=0;u<h.length;u++){o=h[u];var b=y?v[u]:v,_=x?m[u]:m;c=(l=o.p+b)+_,d.push(l,c)}}p._extremes[t._id]=s.findExtremes(t,d,{padded:!1})}}function v(t,e){for(var r=e.traces,n=x(t),a=0;a<r.length;a++){for(var i=r[a],o=i[0].trace,l=[],c=!0,u=0;u<i.length;u++){var h=i[u],f=h.b,p=f+h.s;h[n]=p,l.push(p),h.hasB&&l.push(f),h.hasB&&h.b>0&&h.s>0||(c=!1)}o._extremes[t._id]=s.findExtremes(t,l,{tozero:!c,padded:!0})}}function m(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],a=0;a<n.length;a++){var o=n[a];o.s!==i&&t.put(o.p,o.b+o.s)}}function y(t,e,r){var a=e.traces,o=x(t),l="fraction"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),h="stack"===r.mode?l:u;function f(e){return n(t.c2l(e))&&(e<u-c||e>h+c||!n(u))}for(var p=0;p<a.length;p++){for(var d=a[p],g=d[0].trace,v=[],m=!0,y=!1,b=0;b<d.length;b++){var _=d[b];if(_.s!==i){var w=Math.abs(l/e.get(_.p,_.s));_.b*=w,_.s*=w;var k=_.b,T=k+_.s;_[o]=T,v.push(T),y=y||f(T),_.hasB&&(v.push(k),y=y||f(k)),_.hasB&&_.b>0&&_.s>0||(m=!1)}}g._extremes[t._id]=s.findExtremes(t,v,{tozero:!m,padded:y})}}function x(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,a=t._fullLayout,i=t._fullData,s=t.calcdata,l=[],c=[],h=0;h<i.length;h++){var f=i[h];if(!0===f.visible&&o.traceIs(f,"bar")&&f.xaxis===r._id&&f.yaxis===n._id&&("h"===f.orientation?l.push(s[h]):c.push(s[h]),f._computePh))for(var p=t.calcdata[h],d=0;d<p.length;d++)"function"==typeof p[d].ph0&&(p[d].ph0=p[d].ph0()),"function"==typeof p[d].ph1&&(p[d].ph1=p[d].ph1())}var g={mode:a.barmode,norm:a.barnorm,gap:a.bargap,groupgap:a.bargroupgap};u(t,r,n,c,g),u(t,n,r,l,g)},setGroupPositions:u}},{"../../constants/numerical":693,"../../lib":717,"../../plots/cartesian/axes":765,"../../plots/cartesian/axis_ids":768,"../../registry":846,"./sieve.js":869,"fast-isnumeric":228}],860:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/color"),i=t("../../registry"),o=t("../scatter/xy_defaults"),s=t("./style_defaults"),l=t("../../plots/cartesian/axis_ids").getAxisGroup,c=t("./attributes"),u=n.coerceFont;function h(t,e,r,n){var a=e.orientation,i=e[{v:"x",h:"y"}[a]+"axis"],o=l(r,i)+a,s=r._alignmentOpts||{},c=n("alignmentgroup"),u=s[o];u||(u=s[o]={});var h=u[c];h?h.traces.push(e):h=u[c]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var f=n("offsetgroup"),p=h.offsetGroups,d=p[f];f&&(d||(d=p[f]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}function f(t,e,r,a,i,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),h=!(!1===o.moduleHasCliponaxis),f=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=!!o.hasPathbar,g=Array.isArray(i)||"auto"===i,v=g||"inside"===i,m=g||"outside"===i;if(v||m){var y=u(a,"textfont",r.font),x=n.extendFlat({},y),b=!(t.textfont&&t.textfont.color);if(b&&delete x.color,u(a,"insidetextfont",x),d){var _=n.extendFlat({},y);b&&delete _.color,u(a,"pathbar.textfont",_)}m&&u(a,"outsidetextfont",y),s&&a("selected.textfont.color"),l&&a("unselected.textfont.color"),c&&a("constraintext"),h&&a("cliponaxis"),f&&a("textangle"),a("texttemplate")}v&&p&&a("insidetextanchor")}e.exports={supplyDefaults:function(t,e,r,l){function u(r,a){return n.coerce(t,e,c,r,a)}if(o(t,e,l,u)){u("orientation",e.x&&!e.y?"h":"v"),u("base"),u("offset"),u("width"),u("text"),u("hovertext"),u("hovertemplate");var h=u("textposition");f(t,0,l,u,h,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),s(t,e,u,r,l);var p=(e.marker.line||{}).color,d=i.getComponentMethod("errorbars","supplyDefaults");d(t,e,p||a.defaultLine,{axis:"y"}),d(t,e,p||a.defaultLine,{axis:"x",inherit:"y"}),n.coerceSelectionMarkerOpacity(e,u)}else e.visible=!1},crossTraceDefaults:function(t,e){var r;function a(t){return n.coerce(r._input,r,c,t)}if("group"===e.barmode)for(var i=0;i<t.length;i++)"bar"===(r=t[i]).type&&(r._input,h(0,r,e,a))},handleGroupingDefaults:h,handleText:f}},{"../../components/color":591,"../../lib":717,"../../plots/cartesian/axis_ids":768,"../../registry":846,"../scatter/xy_defaults":1146,"./attributes":856,"./style_defaults":871}],861:[function(t,e,r){"use strict";e.exports=function(t,e,r){return t.x="xVal"in e?e.xVal:e.x,t.y="yVal"in e?e.yVal:e.y,e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),"h"===r.orientation?(t.label=t.y,t.value=t.x):(t.label=t.x,t.value=t.y),t}},{}],862:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("tinycolor2"),i=t("../../lib").isArrayOrTypedArray;r.coerceString=function(t,e,r){if("string"==typeof e){if(e||!t.noBlank)return e}else if(("number"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var a=t.min,i=t.max;if(!(void 0!==a&&e<a||void 0!==i&&e>i))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return a(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r},r.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:i(t.marker.line.width)?0:t.marker.line.width}},{"../../lib":717,"fast-isnumeric":228,tinycolor2:535}],863:[function(t,e,r){"use strict";var n=t("../../components/fx"),a=t("../../registry"),i=t("../../components/color"),o=t("../../lib").fillText,s=t("./helpers").getLineWidth,l=t("../../plots/cartesian/axes").hoverLabelText,c=t("../../constants/numerical").BADNUM;function u(t,e,r,a){var i,s,u,h,f,p,d,g=t.cd,v=g[0].trace,m=g[0].t,y="closest"===a,x="waterfall"===v.type,b=t.maxHoverDistance;function _(t){return t[u]-t.w/2}function w(t){return t[u]+t.w/2}var k=y?_:function(t){return Math.min(_(t),t.p-m.bardelta/2)},T=y?w:function(t){return Math.max(w(t),t.p+m.bardelta/2)};function M(t,e){return n.inbox(t-i,e-i,b+Math.min(1,Math.abs(e-t)/d)-1)}function A(t){return M(k(t),T(t))}function S(t){var e=s,r=t.b,a=t[h];if(x){var i=Math.abs(t.rawS)||0;e>0?a+=i:e<0&&(a-=i)}return n.inbox(r-e,a-e,b+(a-e)/(a-r)-1)}"h"===v.orientation?(i=r,s=e,u="y",h="x",f=S,p=A):(i=e,s=r,u="x",h="y",p=S,f=A);var E=t[u+"a"],L=t[h+"a"];d=Math.abs(E.r2c(E.range[1])-E.r2c(E.range[0]));var C=n.getDistanceFunction(a,f,p,function(t){return(f(t)+p(t))/2});if(n.getClosest(g,C,t),!1!==t.index&&g[t.index].p!==c){y||(k=function(t){return Math.min(_(t),t.p-m.bargroupwidth/2)},T=function(t){return Math.max(w(t),t.p+m.bargroupwidth/2)});var P=g[t.index],O=v.base?P.b+P.s:P.s;t[h+"0"]=t[h+"1"]=L.c2p(P[h],!0),t[h+"LabelVal"]=O;var z=m.extents[m.extents.round(P.p)];return t[u+"0"]=E.c2p(y?k(P):z[0],!0),t[u+"1"]=E.c2p(y?T(P):z[1],!0),t[u+"LabelVal"]=P.p,t.labelLabel=l(E,t[u+"LabelVal"]),t.valueLabel=l(L,t[h+"LabelVal"]),t.spikeDistance=(S(P)+function(t){return M(_(t),w(t))}(P))/2-b,t[u+"Spike"]=E.c2p(P.p,!0),o(P,v,t),t.hovertemplate=v.hovertemplate,t}}function h(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,a=s(t,e);return i.opacity(r)?r:i.opacity(n)&&a?n:void 0}e.exports={hoverPoints:function(t,e,r,n){var i=u(t,e,r,n);if(i){var o=i.cd,s=o[0].trace,l=o[i.index];return i.color=h(s,l),a.getComponentMethod("errorbars","hoverInfo")(l,s,i),[i]}},hoverOnBars:u,getTraceColor:h}},{"../../components/color":591,"../../components/fx":630,"../../constants/numerical":693,"../../lib":717,"../../plots/cartesian/axes":765,"../../registry":846,"./helpers":862}],864:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults").supplyDefaults,crossTraceDefaults:t("./defaults").crossTraceDefaults,supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc"),crossTraceCalc:t("./cross_trace_calc").crossTraceCalc,colorbar:t("../scatter/marker_colorbar"),arraysToCalcdata:t("./arrays_to_calcdata"),plot:t("./plot").plot,style:t("./style").style,styleOnSelect:t("./style").styleOnSelect,hoverPoints:t("./hover").hoverPoints,eventData:t("./event_data"),selectPoints:t("./select"),moduleType:"trace",name:"bar",basePlotModule:t("../../plots/cartesian"),categories:["bar-like","cartesian","svg","bar","oriented","errorBarsOK","showLegend","zoomScale"],animatable:!0,meta:{}}},{"../../plots/cartesian":776,"../scatter/marker_colorbar":1138,"./arrays_to_calcdata":855,"./attributes":856,"./calc":857,"./cross_trace_calc":859,"./defaults":860,"./event_data":861,"./hover":863,"./layout_attributes":865,"./layout_defaults":866,"./plot":867,"./select":868,"./style":870}],865:[function(t,e,r){"use strict";e.exports={barmode:{valType:"enumerated",values:["stack","group","overlay","relative"],dflt:"group",editType:"calc"},barnorm:{valType:"enumerated",values:["","fraction","percent"],dflt:"",editType:"calc"},bargap:{valType:"number",min:0,max:1,editType:"calc"},bargroupgap:{valType:"number",min:0,max:1,dflt:0,editType:"calc"}}},{}],866:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../plots/cartesian/axes"),i=t("../../lib"),o=t("./layout_attributes");e.exports=function(t,e,r){function s(r,n){return i.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,h={},f=s("barmode"),p=0;p<r.length;p++){var d=r[p];if(n.traceIs(d,"bar")&&d.visible){if(l=!0,"group"===f){var g=d.xaxis+d.yaxis;h[g]&&(u=!0),h[g]=!0}if(d.visible&&"histogram"===d.type)"category"!==a.getFromId({_fullLayout:e},d["v"===d.orientation?"xaxis":"yaxis"]).type&&(c=!0)}}l?("overlay"!==f&&s("barnorm"),s("bargap",c&&!u?0:.2),s("bargroupgap")):delete e.barmode}},{"../../lib":717,"../../plots/cartesian/axes":765,"../../registry":846,"./layout_attributes":865}],867:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../../lib"),o=t("../../lib/svg_text_utils"),s=t("../../components/color"),l=t("../../components/drawing"),c=t("../../registry"),u=t("../../plots/cartesian/axes").tickText,h=t("./uniform_text"),f=h.recordMinTextSize,p=h.clearMinTextSize,d=t("./style"),g=t("./helpers"),v=t("./constants"),m=t("./attributes"),y=m.text,x=m.textposition,b=t("../../components/fx/helpers").appendArrayPointValue,_=v.TEXTPAD;function w(t){return t.id}function k(t){if(t.ids)return w}function T(t,e){return t<e?1:-1}function M(t,e,r,n){var a;return!e.uniformtext.mode&&A(r)?(n&&(a=n()),t.transition().duration(r.duration).ease(r.easing).each("end",function(){a&&a()}).each("interrupt",function(){a&&a()})):t}function A(t){return t&&t.duration>0}function S(t){return"auto"===t?0:t}function E(t,e){var r=Math.PI/180*e,n=Math.abs(Math.sin(r)),a=Math.abs(Math.cos(r));return{x:t.width*a+t.height*n,y:t.width*n+t.height*a}}function L(t,e,r,n,a,i){var o=!!i.isHorizontal,s=!!i.constrained,l=i.angle||0,c=i.anchor||"end",u="end"===c,h="start"===c,f=((i.leftToRight||0)+1)/2,p=1-f,d=a.width,g=a.height,v=Math.abs(e-t),m=Math.abs(n-r),y=v>2*_&&m>2*_?_:0;v-=2*y,m-=2*y;var x=S(l);"auto"!==l||d<=v&&g<=m||!(d>v||g>m)||(d>m||g>v)&&d<g==v<m||(x+=90);var b=E(a,x),w=1;s&&(w=Math.min(1,v/b.x,m/b.y));var k=a.left*p+a.right*f,M=(a.top+a.bottom)/2,A=(t+_)*p+(e-_)*f,L=(r+n)/2,C=0,P=0;if(h||u){var O=(o?b.x:b.y)/2,z=o?T(t,e):T(r,n);o?h?(A=t+z*y,C=-z*O):(A=e-z*y,C=z*O):h?(L=r+z*y,P=-z*O):(L=n-z*y,P=z*O)}return{textX:k,textY:M,targetX:A,targetY:L,anchorX:C,anchorY:P,scale:w,rotate:x}}e.exports={plot:function(t,e,r,h,v,m){var w=e.xaxis,C=e.yaxis,P=t._fullLayout;v||(v={mode:P.barmode,norm:P.barmode,gap:P.bargap,groupgap:P.bargroupgap},p("bar",P));var O=i.makeTraceGroups(h,r,"trace bars").each(function(r){var c=n.select(this),h=r[0].trace,p="waterfall"===h.type,O="funnel"===h.type,z="bar"===h.type||O,I=0;p&&h.connector.visible&&"between"===h.connector.mode&&(I=h.connector.line.width/2);var D="h"===h.orientation,R=A(v),F=i.ensureSingle(c,"g","points"),B=k(h),N=F.selectAll("g.point").data(i.identity,B);N.enter().append("g").classed("point",!0),N.exit().remove(),N.each(function(c,p){var k,A,O=n.select(this),F=function(t,e,r,n){var a=[],i=[],o=n?e:r,s=n?r:e;return a[0]=o.c2p(t.s0,!0),i[0]=s.c2p(t.p0,!0),a[1]=o.c2p(t.s1,!0),i[1]=s.c2p(t.p1,!0),n?[a,i]:[i,a]}(c,w,C,D),B=F[0][0],N=F[0][1],j=F[1][0],V=F[1][1],U=0==(D?N-B:V-j);if(U&&z&&g.getLineWidth(h,c)&&(U=!1),U||(U=!(a(B)&&a(N)&&a(j)&&a(V))),c.isBlank=U,U&&(D?N=B:V=j),I&&!U&&(D?(B-=T(B,N)*I,N+=T(B,N)*I):(j-=T(j,V)*I,V+=T(j,V)*I)),"waterfall"===h.type){if(!U){var q=h[c.dir].marker;k=q.line.width,A=q.color}}else k=g.getLineWidth(h,c),A=c.mc||h.marker.color;function H(t){var e=n.round(k/2%1,2);return 0===v.gap&&0===v.groupgap?n.round(Math.round(t)-e,2):t}if(!t._context.staticPlot){var G=s.opacity(A)<1||k>.01?H:function(t,e,r){return r&&t===e?t:Math.abs(t-e)>=2?H(t):t>e?Math.ceil(t):Math.floor(t)};B=G(B,N,D),N=G(N,B,D),j=G(j,V,!D),V=G(V,j,!D)}var Y=M(i.ensureSingle(O,"path"),P,v,m);if(Y.style("vector-effect","non-scaling-stroke").attr("d",isNaN((N-B)*(V-j))?"M0,0Z":"M"+B+","+j+"V"+V+"H"+N+"V"+j+"Z").call(l.setClipUrl,e.layerClipId,t),!P.uniformtext.mode&&R){var W=l.makePointStyleFns(h);l.singlePointStyle(c,Y,h,W,t)}!function(t,e,r,n,a,s,c,h,p,v,m){var w,k=e.xaxis,A=e.yaxis,C=t._fullLayout;function P(e,r,n){var a=i.ensureSingle(e,"text").text(r).attr({class:"bartext bartext-"+w,"text-anchor":"middle","data-notex":1}).call(l.font,n).call(o.convertToTspans,t);return a}var O=n[0].trace,z="h"===O.orientation,I=function(t,e,r,n,a){var o,s=e[0].trace;return o=s.texttemplate?function(t,e,r,n,a){var o=e[0].trace,s=i.castOption(o,r,"texttemplate");if(!s)return"";var l,c,h,f,p="waterfall"===o.type,d="funnel"===o.type;function g(t){return u(f,+t,!0).text}"h"===o.orientation?(l="y",c=a,h="x",f=n):(l="x",c=n,h="y",f=a);var v,m=e[r],y={};y.label=m.p,y.labelLabel=y[l+"Label"]=(v=m.p,u(c,v,!0).text);var x=i.castOption(o,m.i,"text");(0===x||x)&&(y.text=x),y.value=m.s,y.valueLabel=y[h+"Label"]=g(m.s);var _={};b(_,o,m.i),p&&(y.delta=+m.rawS||m.s,y.deltaLabel=g(y.delta),y.final=m.v,y.finalLabel=g(y.final),y.initial=y.final-y.delta,y.initialLabel=g(y.initial)),d&&(y.value=m.s,y.valueLabel=g(y.value),y.percentInitial=m.begR,y.percentInitialLabel=i.formatPercent(m.begR),y.percentPrevious=m.difR,y.percentPreviousLabel=i.formatPercent(m.difR),y.percentTotal=m.sumR,y.percenTotalLabel=i.formatPercent(m.sumR));var w=i.castOption(o,m.i,"customdata");return w&&(y.customdata=w),i.texttemplateString(s,y,t._d3locale,_,y,o._meta||{})}(t,e,r,n,a):s.textinfo?function(t,e,r,n){var a=t[0].trace,o="h"===a.orientation,s="waterfall"===a.type,l="funnel"===a.type;function c(t){var e=o?r:n;return u(e,+t,!0).text}var h,f,p=a.textinfo,d=t[e],g=p.split("+"),v=[],m=function(t){return-1!==g.indexOf(t)};if(m("label")&&v.push((f=t[e].p,u(o?n:r,f,!0).text)),m("text")&&(0===(h=i.castOption(a,d.i,"text"))||h)&&v.push(h),s){var y=+d.rawS||d.s,x=d.v,b=x-y;m("initial")&&v.push(c(b)),m("delta")&&v.push(c(y)),m("final")&&v.push(c(x))}if(l){m("value")&&v.push(c(d.s));var _=0;m("percent initial")&&_++,m("percent previous")&&_++,m("percent total")&&_++;var w=_>1;m("percent initial")&&(h=i.formatPercent(d.begR),w&&(h+=" of initial"),v.push(h)),m("percent previous")&&(h=i.formatPercent(d.difR),w&&(h+=" of previous"),v.push(h)),m("percent total")&&(h=i.formatPercent(d.sumR),w&&(h+=" of total"),v.push(h))}return v.join("<br>")}(e,r,n,a):g.getValue(s.text,r),g.coerceString(y,o)}(C,n,a,k,A);w=function(t,e){var r=g.getValue(t.textposition,e);return g.coerceEnumerated(x,r)}(O,a);var D="stack"===v.mode||"relative"===v.mode,R=n[a],F=!D||R._outmost;if(I&&"none"!==w&&(!R.isBlank&&s!==c&&h!==p||"auto"!==w&&"inside"!==w)){var B=C.font,N=d.getBarColor(n[a],O),j=d.getInsideTextFont(O,a,B,N),V=d.getOutsideTextFont(O,a,B),U=r.datum();z?"log"===k.type&&U.s0<=0&&(s=k.range[0]<k.range[1]?0:k._length):"log"===A.type&&U.s0<=0&&(h=A.range[0]<A.range[1]?A._length:0);var q,H,G,Y,W,X=Math.abs(c-s)-2*_,Z=Math.abs(p-h)-2*_;if("outside"===w&&(F||R.hasB||(w="inside")),"auto"===w)if(F){w="inside",W=i.ensureUniformFontSize(t,j),q=P(r,I,W),H=l.bBox(q.node()),G=H.width,Y=H.height;var J=G>0&&Y>0,K=G<=X&&Y<=Z,Q=G<=Z&&Y<=X,$=z?X>=G*(Z/Y):Z>=Y*(X/G);J&&(K||Q||$)?w="inside":(w="outside",q.remove(),q=null)}else w="inside";if(!q){W=i.ensureUniformFontSize(t,"outside"===w?V:j);var tt=(q=P(r,I,W)).attr("transform");if(q.attr("transform",""),H=l.bBox(q.node()),G=H.width,Y=H.height,q.attr("transform",tt),G<=0||Y<=0)return void q.remove()}var et,rt,nt=O.textangle;"outside"===w?(rt="both"===O.constraintext||"outside"===O.constraintext,et=function(t,e,r,n,a,i){var o,s=!!i.isHorizontal,l=!!i.constrained,c=i.angle||0,u=a.width,h=a.height,f=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*_?_:0:f>2*_?_:0;var d=1;l&&(d=s?Math.min(1,p/h):Math.min(1,f/u));var g=S(c),v=E(a,g),m=(s?v.x:v.y)/2,y=(a.left+a.right)/2,x=(a.top+a.bottom)/2,b=(t+e)/2,w=(r+n)/2,k=0,M=0,A=s?T(e,t):T(r,n);return s?(b=e-A*o,k=A*m):(w=n+A*o,M=-A*m),{textX:y,textY:x,targetX:b,targetY:w,anchorX:k,anchorY:M,scale:d,rotate:g}}(s,c,h,p,H,{isHorizontal:z,constrained:rt,angle:nt})):(rt="both"===O.constraintext||"inside"===O.constraintext,et=L(s,c,h,p,H,{isHorizontal:z,constrained:rt,angle:nt,anchor:O.insidetextanchor})),et.fontSize=W.size,f(O.type,et,C),R.transform=et,M(q,C,v,m).attr("transform",i.getTextTransform(et))}else r.select("text").remove()}(t,e,O,r,p,B,N,j,V,v,m),e.layerClipId&&l.hideOutsideRangePoint(c,O.select("text"),w,C,h.xcalendar,h.ycalendar)});var j=!1===h.cliponaxis;l.setClipUrl(c,j?null:e.layerClipId,t)});c.getComponentMethod("errorbars","plot")(t,O,e,v)},toMoveInsideBar:L}},{"../../components/color":591,"../../components/drawing":612,"../../components/fx/helpers":626,"../../lib":717,"../../lib/svg_text_utils":741,"../../plots/cartesian/axes":765,"../../registry":846,"./attributes":856,"./constants":858,"./helpers":862,"./style":870,"./uniform_text":872,d3:165,"fast-isnumeric":228}],868:[function(t,e,r){"use strict";function n(t,e,r,n,a){var i=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return a?[(i+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(i+o)/2,l]}e.exports=function(t,e){var r,a=t.cd,i=t.xaxis,o=t.yaxis,s=a[0].trace,l="funnel"===s.type,c="h"===s.orientation,u=[];if(!1===e)for(r=0;r<a.length;r++)a[r].selected=0;else for(r=0;r<a.length;r++){var h=a[r],f="ct"in h?h.ct:n(h,i,o,c,l);e.contains(f,!1,r,t)?(u.push({pointNumber:r,x:i.c2d(h.x),y:o.c2d(h.y)}),h.selected=1):h.selected=0}return u}},{}],869:[function(t,e,r){"use strict";e.exports=i;var n=t("../../lib").distinctVals,a=t("../../constants/numerical").BADNUM;function i(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,i=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l];c.p!==a&&i.push(c.p)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=i;var u=n(i);this.distinctPositions=u.vals,1===u.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(u.minDiff,r),this.binWidth=this.minDiff,this.bins={}}i.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},i.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},i.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?"v":"^")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},{"../../constants/numerical":693,"../../lib":717}],870:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/color"),i=t("../../components/drawing"),o=t("../../lib"),s=t("../../registry"),l=t("./uniform_text").resizeText,c=t("./attributes"),u=c.textfont,h=c.insidetextfont,f=c.outsidetextfont,p=t("./helpers");function d(t,e,r){i.pointStyle(t.selectAll("path"),e,r),g(t,e,r)}function g(t,e,r){t.selectAll("text").each(function(t){var a=n.select(this),s=o.ensureUniformFontSize(r,v(a,t,e,r));i.font(a,s)})}function v(t,e,r,n){var a=n._fullLayout.font,i=r.textfont;if(t.classed("bartext-inside")){var o=_(e,r);i=y(r,e.i,a,o)}else t.classed("bartext-outside")&&(i=x(r,e.i,a));return i}function m(t,e,r){return b(u,t.textfont,e,r)}function y(t,e,r,n){var i=m(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(i={color:a.contrast(n),family:i.family,size:i.size}),b(h,t.insidetextfont,e,i)}function x(t,e,r){var n=m(t,e,r);return b(f,t.outsidetextfont,e,n)}function b(t,e,r,n){e=e||{};var a=p.getValue(e.family,r),i=p.getValue(e.size,r),o=p.getValue(e.color,r);return{family:p.coerceString(t.family,a,n.family),size:p.coerceNumber(t.size,i,n.size),color:p.coerceColor(t.color,o,n.color)}}function _(t,e){return"waterfall"===e.type?e[t.dir].marker.color:t.mc||e.marker.color}e.exports={style:function(t){var e=n.select(t).selectAll("g.barlayer").selectAll("g.trace");l(t,e,"bar");var r=e.size(),a=t._fullLayout;e.style("opacity",function(t){return t[0].trace.opacity}).each(function(t){("stack"===a.barmode&&r>1||0===a.bargap&&0===a.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr("shape-rendering","crispEdges")}),e.selectAll("g.points").each(function(e){d(n.select(this),e[0].trace,t)}),s.getComponentMethod("errorbars","style")(e)},styleTextPoints:g,styleOnSelect:function(t,e,r){var a=e[0].trace;a.selectedpoints?function(t,e,r){i.selectedPointStyle(t.selectAll("path"),e),function(t,e,r){t.each(function(t){var a,s=n.select(this);if(t.selected){a=o.ensureUniformFontSize(r,v(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(a.color=l),i.font(s,a)}else i.selectedTextStyle(s,e)})}(t.selectAll("text"),e,r)}(r,a,t):(d(r,a,t),s.getComponentMethod("errorbars","style")(r))},getInsideTextFont:y,getOutsideTextFont:x,getBarColor:_,resizeText:l}},{"../../components/color":591,"../../components/drawing":612,"../../lib":717,"../../registry":846,"./attributes":856,"./helpers":862,"./uniform_text":872,d3:165}],871:[function(t,e,r){"use strict";var n=t("../../components/color"),a=t("../../components/colorscale/helpers").hasColorscale,i=t("../../components/colorscale/defaults");e.exports=function(t,e,r,o,s){r("marker.color",o),a(t,"marker")&&i(t,e,s,r,{prefix:"marker.",cLetter:"c"}),r("marker.line.color",n.defaultLine),a(t,"marker.line")&&i(t,e,s,r,{prefix:"marker.line.",cLetter:"c"}),r("marker.line.width"),r("marker.opacity"),r("selected.marker.color"),r("unselected.marker.color")}},{"../../components/color":591,"../../components/colorscale/defaults":601,"../../components/colorscale/helpers":602}],872:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib");function i(t){return"_"+t+"Text_minsize"}e.exports={recordMinTextSize:function(t,e,r){if(r.uniformtext.mode){var n=i(t),a=r.uniformtext.minsize,o=e.scale*e.fontSize;e.hide=o<a,r[n]=r[n]||1/0,e.hide||(r[n]=Math.min(r[n],Math.max(o,a)))}},clearMinTextSize:function(t,e){e[i(t)]=void 0},resizeText:function(t,e,r){var i=t._fullLayout,o=i["_"+r+"Text_minsize"];if(o){var s,l="hide"===i.uniformtext.mode;switch(r){case"funnelarea":case"pie":case"sunburst":s="g.slice";break;case"treemap":s="g.slice, g.pathbar";break;default:s="g.points > g.point"}e.selectAll(s).each(function(t){var e=t.transform;e&&(e.scale=l&&e.hide?0:o/e.fontSize,n.select(this).select("text").attr("transform",a.getTextTransform(e)))})}}}},{"../../lib":717,d3:165}],873:[function(t,e,r){"use strict";var n=t("../../plots/template_attributes").hovertemplateAttrs,a=t("../../lib/extend").extendFlat,i=t("../scatterpolar/attributes"),o=t("../bar/attributes");e.exports={r:i.r,theta:i.theta,r0:i.r0,dr:i.dr,theta0:i.theta0,dtheta:i.dtheta,thetaunit:i.thetaunit,base:a({},o.base,{}),offset:a({},o.offset,{}),width:a({},o.width,{}),text:a({},o.text,{}),hovertext:a({},o.hovertext,{}),marker:o.marker,hoverinfo:i.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{"../../lib/extend":708,"../../plots/template_attributes":841,"../bar/attributes":856,"../scatterpolar/attributes":1193}],874:[function(t,e,r){"use strict";var n=t("../../components/colorscale/helpers").hasColorscale,a=t("../../components/colorscale/calc"),i=t("../bar/arrays_to_calcdata"),o=t("../bar/cross_trace_calc").setGroupPositions,s=t("../scatter/calc_selection"),l=t("../../registry").traceIs,c=t("../../lib").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,"r"),h=c.makeCalcdata(e,"theta"),f=e._length,p=new Array(f),d=u,g=h,v=0;v<f;v++)p[v]={p:g[v],s:d[v]};function m(t){var r=e[t];void 0!==r&&(e["_"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return"linear"===c.type&&(m("width"),m("offset")),n(e,"marker")&&a(t,e,{vals:e.marker.color,containerStr:"marker",cLetter:"c"}),n(e,"marker.line")&&a(t,e,{vals:e.marker.line.color,containerStr:"marker.line",cLetter:"c"}),i(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,a=[],i=0;i<n.length;i++){var s=n[i],u=s[0].trace;!0===u.visible&&l(u,"bar")&&u.subplot===r&&a.push(s)}var h=c({},e.radialaxis,{_id:"x"}),f=e.angularaxis;o(t,f,h,a,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},{"../../components/colorscale/calc":599,"../../components/colorscale/helpers":602,"../../lib":717,"../../registry":846,"../bar/arrays_to_calcdata":855,"../bar/cross_trace_calc":859,"../scatter/calc_selection":1122}],875:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatterpolar/defaults").handleRThetaDefaults,i=t("../bar/style_defaults"),o=t("./attributes");e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,o,r,a)}a(t,e,s,l)?(l("thetaunit"),l("base"),l("offset"),l("width"),l("text"),l("hovertext"),l("hovertemplate"),i(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{"../../lib":717,"../bar/style_defaults":871,"../scatterpolar/defaults":1195,"./attributes":873}],876:[function(t,e,r){"use strict";var n=t("../../components/fx"),a=t("../../lib"),i=t("../bar/hover").getTraceColor,o=a.fillText,s=t("../scatterpolar/hover").makeHoverPointText,l=t("../../plots/polar/helpers").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.subplot,f=h.radialAxis,p=h.angularAxis,d=h.vangles,g=d?l:a.isPtInsideSector,v=t.maxHoverDistance,m=p._period||2*Math.PI,y=Math.abs(f.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);f.range[0]>f.range[1]&&(x+=Math.PI);if(n.getClosest(c,function(t){return g(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?v+Math.min(1,Math.abs(t.thetag1-t.thetag0)/m)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0},t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=a.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,h,t),t.hovertemplate=u.hovertemplate,t.color=i(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign="left"),[t]}}},{"../../components/fx":630,"../../lib":717,"../../plots/polar/helpers":828,"../bar/hover":863,"../scatterpolar/hover":1197}],877:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"barpolar",basePlotModule:t("../../plots/polar"),categories:["polar","bar","showLegend"],attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults"),supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc").calc,crossTraceCalc:t("./calc").crossTraceCalc,plot:t("./plot"),colorbar:t("../scatter/marker_colorbar"),formatLabels:t("../scatterpolar/format_labels"),style:t("../bar/style").style,styleOnSelect:t("../bar/style").styleOnSelect,hoverPoints:t("./hover"),selectPoints:t("../bar/select"),meta:{}}},{"../../plots/polar":829,"../bar/select":868,"../bar/style":870,"../scatter/marker_colorbar":1138,"../scatterpolar/format_labels":1196,"./attributes":873,"./calc":874,"./defaults":875,"./hover":876,"./layout_attributes":878,"./layout_defaults":879,"./plot":880}],878:[function(t,e,r){"use strict";e.exports={barmode:{valType:"enumerated",values:["stack","overlay"],dflt:"stack",editType:"calc"},bargap:{valType:"number",dflt:.1,min:0,max:1,editType:"calc"}}},{}],879:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e,r){var i,o={};function s(r,o){return n.coerce(t[i]||{},e[i],a,r,o)}for(var l=0;l<r.length;l++){var c=r[l];"barpolar"===c.type&&!0===c.visible&&(o[i=c.subplot]||(s("barmode"),s("bargap"),o[i]=1))}}},{"../../lib":717,"./layout_attributes":878}],880:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../../lib"),o=t("../../components/drawing"),s=t("../../plots/polar/helpers");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,h=e.angularAxis,f=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,a,o,l){var c,u;i.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var h=s.findEnclosingVertexAngles(c,t.vangles)[0],f=s.findEnclosingVertexAngles(u,t.vangles)[1],p=[h,(c+u)/2,f];return s.pathPolygonAnnulus(n,a,c,u,p,e,r)};return function(t,n,a,o){return i.pathAnnulus(t,n,a,o,e,r)}}(e),p=e.layers.frontplot.select("g.barlayer");i.makeTraceGroups(p,r,"trace bars").each(function(){var r=n.select(this),s=i.ensureSingle(r,"g","points").selectAll("g.point").data(i.identity);s.enter().append("g").style("vector-effect","non-scaling-stroke").style("stroke-miterlimit",2).classed("point",!0),s.exit().remove(),s.each(function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=h.c2g(t.p0),d=t.thetag1=h.c2g(t.p1);if(a(o)&&a(s)&&a(p)&&a(d)&&o!==s&&p!==d){var g=u.c2g(t.s1),v=(p+d)/2;t.ct=[l.c2p(g*Math.cos(v)),c.c2p(g*Math.sin(v))],e=f(o,s,p,d)}else e="M0,0Z";i.ensureSingle(r,"path").attr("d",e)}),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)})}},{"../../components/drawing":612,"../../lib":717,"../../plots/polar/helpers":828,d3:165,"fast-isnumeric":228}],881:[function(t,e,r){"use strict";var n=t("../scatter/attributes"),a=t("../bar/attributes"),i=t("../../components/color/attributes"),o=t("../../plots/template_attributes").hovertemplateAttrs,s=t("../../lib/extend").extendFlat,l=n.marker,c=l.line;e.exports={y:{valType:"data_array",editType:"calc+clearAxisTypes"},x:{valType:"data_array",editType:"calc+clearAxisTypes"},x0:{valType:"any",editType:"calc+clearAxisTypes"},y0:{valType:"any",editType:"calc+clearAxisTypes"},dx:{valType:"number",editType:"calc"},dy:{valType:"number",editType:"calc"},name:{valType:"string",editType:"calc+clearAxisTypes"},q1:{valType:"data_array",editType:"calc+clearAxisTypes"},median:{valType:"data_array",editType:"calc+clearAxisTypes"},q3:{valType:"data_array",editType:"calc+clearAxisTypes"},lowerfence:{valType:"data_array",editType:"calc"},upperfence:{valType:"data_array",editType:"calc"},notched:{valType:"boolean",editType:"calc"},notchwidth:{valType:"number",min:0,max:.5,dflt:.25,editType:"calc"},notchspan:{valType:"data_array",editType:"calc"},boxpoints:{valType:"enumerated",values:["all","outliers","suspectedoutliers",!1],editType:"calc"},jitter:{valType:"number",min:0,max:1,editType:"calc"},pointpos:{valType:"number",min:-2,max:2,editType:"calc"},boxmean:{valType:"enumerated",values:[!0,"sd",!1],editType:"calc"},mean:{valType:"data_array",editType:"calc"},sd:{valType:"data_array",editType:"calc"},orientation:{valType:"enumerated",values:["v","h"],editType:"calc+clearAxisTypes"},quartilemethod:{valType:"enumerated",values:["linear","exclusive","inclusive"],dflt:"linear",editType:"calc"},width:{valType:"number",min:0,dflt:0,editType:"calc"},marker:{outliercolor:{valType:"color",dflt:"rgba(0, 0, 0, 0)",editType:"style"},symbol:s({},l.symbol,{arrayOk:!1,editType:"plot"}),opacity:s({},l.opacity,{arrayOk:!1,dflt:1,editType:"style"}),size:s({},l.size,{arrayOk:!1,editType:"calc"}),color:s({},l.color,{arrayOk:!1,editType:"style"}),line:{color:s({},c.color,{arrayOk:!1,dflt:i.defaultLine,editType:"style"}),width:s({},c.width,{arrayOk:!1,dflt:0,editType:"style"}),outliercolor:{valType:"color",editType:"style"},outlierwidth:{valType:"number",min:0,dflt:1,editType:"style"},editType:"style"},editType:"plot"},line:{color:{valType:"color",editType:"style"},width:{valType:"number",min:0,dflt:2,editType:"style"},editType:"plot"},fillcolor:n.fillcolor,whiskerwidth:{valType:"number",min:0,max:1,dflt:.5,editType:"calc"},offsetgroup:a.offsetgroup,alignmentgroup:a.alignmentgroup,selected:{marker:n.selected.marker,editType:"style"},unselected:{marker:n.unselected.marker,editType:"style"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),hovertemplate:o({}),hoveron:{valType:"flaglist",flags:["boxes","points"],dflt:"boxes+points",editType:"style"}}},{"../../components/color/attributes":590,"../../lib/extend":708,"../../plots/template_attributes":841,"../bar/attributes":856,"../scatter/attributes":1120}],882:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../plots/cartesian/axes"),i=t("../../lib"),o=t("../../constants/numerical").BADNUM,s=i._;e.exports=function(t,e){var r,l,m,y,x,b,_=t._fullLayout,w=a.getFromId(t,e.xaxis||"x"),k=a.getFromId(t,e.yaxis||"y"),T=[],M="violin"===e.type?"_numViolins":"_numBoxes";"h"===e.orientation?(m=w,y="x",x=k,b="y"):(m=k,y="y",x=w,b="x");var A,S,E,L,C,P,O=function(t,e,r,a){var o,s=e+"0"in t,l="d"+e in t;if(e in t||s&&l)return r.makeCalcdata(t,e);o=s?t[e+"0"]:"name"in t&&("category"===r.type||n(t.name)&&-1!==["linear","log"].indexOf(r.type)||i.isDateTime(t.name)&&"date"===r.type)?t.name:a;for(var c="multicategory"===r.type?r.r2c_just_indices(o):r.d2c(o,0,t[e+"calendar"]),u=t._length,h=new Array(u),f=0;f<u;f++)h[f]=c;return h}(e,b,x,_[M]),z=i.distinctVals(O),I=z.vals,D=z.minDiff/2,R="all"===(e.boxpoints||e.points)?i.identity:function(t){return t.v<A.lf||t.v>A.uf};if(e._hasPreCompStats){var F=e[y],B=function(t){return m.d2c((e[t]||[])[r])},N=1/0,j=-1/0;for(r=0;r<e._length;r++){var V=O[r];if(n(V)){if((A={}).pos=A[b]=V,A.q1=B("q1"),A.med=B("median"),A.q3=B("q3"),S=[],F&&i.isArrayOrTypedArray(F[r]))for(l=0;l<F[r].length;l++)(P=m.d2c(F[r][l]))!==o&&(c(C={v:P,i:[r,l]},e,[r,l]),S.push(C));if(A.pts=S.sort(u),L=(E=A[y]=S.map(h)).length,A.med!==o&&A.q1!==o&&A.q3!==o&&A.med>=A.q1&&A.q3>=A.med){var U=B("lowerfence");A.lf=U!==o&&U<=A.q1?U:f(A,E,L);var q=B("upperfence");A.uf=q!==o&&q>=A.q3?q:p(A,E,L);var H=B("mean");A.mean=H!==o?H:L?i.mean(E,L):(A.q1+A.q3)/2;var G=B("sd");A.sd=H!==o&&G>=0?G:L?i.stdev(E,L,A.mean):A.q3-A.q1,A.lo=d(A),A.uo=g(A);var Y=B("notchspan");Y=Y!==o&&Y>0?Y:v(A,L),A.ln=A.med-Y,A.un=A.med+Y;var W=A.lf,X=A.uf;e.boxpoints&&E.length&&(W=Math.min(W,E[0]),X=Math.max(X,E[L-1])),e.notched&&(W=Math.min(W,A.ln),X=Math.max(X,A.un)),A.min=W,A.max=X}else{var Z;i.warn(["Invalid input - make sure that q1 <= median <= q3","q1 = "+A.q1,"median = "+A.med,"q3 = "+A.q3].join("\n")),Z=A.med!==o?A.med:A.q1!==o?A.q3!==o?(A.q1+A.q3)/2:A.q1:A.q3!==o?A.q3:0,A.med=Z,A.q1=A.q3=Z,A.lf=A.uf=Z,A.mean=A.sd=Z,A.ln=A.un=Z,A.min=A.max=Z}N=Math.min(N,A.min),j=Math.max(j,A.max),A.pts2=S.filter(R),T.push(A)}}e._extremes[m._id]=a.findExtremes(m,[N,j],{padded:!0})}else{var J=m.makeCalcdata(e,y),K=function(t,e){for(var r=t.length,n=new Array(r+1),a=0;a<r;a++)n[a]=t[a]-e;return n[r]=t[r-1]+e,n}(I,D),Q=I.length,$=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(Q);for(r=0;r<e._length;r++)if(P=J[r],n(P)){var tt=i.findBin(O[r],K);tt>=0&&tt<Q&&(c(C={v:P,i:r},e,r),$[tt].push(C))}var et=1/0,rt=-1/0,nt=e.quartilemethod,at="exclusive"===nt,it="inclusive"===nt;for(r=0;r<Q;r++)if($[r].length>0){var ot,st;if((A={}).pos=A[b]=I[r],S=A.pts=$[r].sort(u),L=(E=A[y]=S.map(h)).length,A.min=E[0],A.max=E[L-1],A.mean=i.mean(E,L),A.sd=i.stdev(E,L,A.mean),A.med=i.interp(E,.5),L%2&&(at||it))at?(ot=E.slice(0,L/2),st=E.slice(L/2+1)):it&&(ot=E.slice(0,L/2+1),st=E.slice(L/2)),A.q1=i.interp(ot,.5),A.q3=i.interp(st,.5);else A.q1=i.interp(E,.25),A.q3=i.interp(E,.75);A.lf=f(A,E,L),A.uf=p(A,E,L),A.lo=d(A),A.uo=g(A);var lt=v(A,L);A.ln=A.med-lt,A.un=A.med+lt,et=Math.min(et,A.ln),rt=Math.max(rt,A.un),A.pts2=S.filter(R),T.push(A)}e._extremes[m._id]=a.findExtremes(m,e.notched?J.concat([et,rt]):J,{padded:!0})}return function(t,e){if(i.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],a={},o=0;o<n.length;o++)a[n[o].i]=o;i.tagSelected(n,e,a)}}(T,e),T.length>0?(T[0].t={num:_[M],dPos:D,posLetter:b,valLetter:y,labels:{med:s(t,"median:"),min:s(t,"min:"),q1:s(t,"q1:"),q3:s(t,"q3:"),max:s(t,"max:"),mean:"sd"===e.boxmean?s(t,"mean \xb1 \u03c3:"):s(t,"mean:"),lf:s(t,"lower fence:"),uf:s(t,"upper fence:")}},_[M]++,T):[{t:{empty:!0}}]};var l={text:"tx",hovertext:"htx"};function c(t,e,r){for(var n in l)i.isArrayOrTypedArray(e[n])&&(Array.isArray(r)?i.isArrayOrTypedArray(e[n][r[0]])&&(t[l[n]]=e[n][r[0]][r[1]]):t[l[n]]=e[n][r])}function u(t,e){return t.v-e.v}function h(t){return t.v}function f(t,e,r){return 0===r?t.q1:Math.min(t.q1,e[Math.min(i.findBin(2.5*t.q1-1.5*t.q3,e,!0)+1,r-1)])}function p(t,e,r){return 0===r?t.q3:Math.max(t.q3,e[Math.max(i.findBin(2.5*t.q3-1.5*t.q1,e),0)])}function d(t){return 4*t.q1-3*t.q3}function g(t){return 4*t.q3-3*t.q1}function v(t,e){return 0===e?0:1.57*(t.q3-t.q1)/Math.sqrt(e)}},{"../../constants/numerical":693,"../../lib":717,"../../plots/cartesian/axes":765,"fast-isnumeric":228}],883:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../lib"),i=t("../../plots/cartesian/axis_ids").getAxisGroup,o=["v","h"];function s(t,e,r,o){var s,l,c,u=e.calcdata,h=e._fullLayout,f=o._id,p=f.charAt(0),d=[],g=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(o.c2l(c[l].pos,!0)),g+=(c[l].pts2||[]).length;if(d.length){var v=a.distinctVals(d),m=v.minDiff/2;n.minDtick(o,v.minDiff,v.vals[0],!0);var y=h["violin"===t?"_numViolins":"_numBoxes"],x="group"===h[t+"mode"]&&y>1,b=1-h[t+"gap"],_=1-h[t+"groupgap"];for(s=0;s<r.length;s++){var w,k,T,M,A,S,E=(c=u[r[s]])[0].trace,L=c[0].t,C=E.width,P=E.side;if(C)w=k=M=C/2,T=0;else if(w=m,x){var O=i(h,o._id)+E.orientation,z=(h._alignmentOpts[O]||{})[E.alignmentgroup]||{},I=Object.keys(z.offsetGroups||{}).length,D=I||y;k=w*b*_/D,T=2*w*(((I?E._offsetIndex:L.num)+.5)/D-.5)*b,M=w*b/D}else k=w*b*_,T=0,M=w;L.dPos=w,L.bPos=T,L.bdPos=k,L.wHover=M;var R,F,B,N,j,V,U=T+k,q=Boolean(C);if("positive"===P?(A=w*(C?1:.5),R=U,S=R=T):"negative"===P?(A=R=T,S=w*(C?1:.5),F=U):(A=S=w,R=F=U),(E.boxpoints||E.points)&&g>0){var H=E.pointpos,G=E.jitter,Y=E.marker.size/2,W=0;H+G>=0&&((W=U*(H+G))>A?(q=!0,j=Y,B=W):W>R&&(j=Y,B=A)),W<=A&&(B=A);var X=0;H-G<=0&&((X=-U*(H-G))>S?(q=!0,V=Y,N=X):X>F&&(V=Y,N=S)),X<=S&&(N=S)}else B=A,N=S;var Z=new Array(c.length);for(l=0;l<c.length;l++)Z[l]=c[l].pos;E._extremes[f]=n.findExtremes(o,Z,{padded:q,vpadminus:N,vpadplus:B,vpadLinearized:!0,ppadminus:{x:V,y:j}[p],ppadplus:{x:j,y:V}[p]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,a=e.yaxis,i=0;i<o.length;i++){for(var l=o[i],c="h"===l?a:n,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||"box"!==d.type&&"candlestick"!==d.type||p.empty||(d.orientation||"v")!==l||d.xaxis!==n._id||d.yaxis!==a._id||u.push(h)}s("box",t,u,c)}},setPositionOffset:s}},{"../../lib":717,"../../plots/cartesian/axes":765,"../../plots/cartesian/axis_ids":768}],884:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../registry"),i=t("../../components/color"),o=t("../bar/defaults").handleGroupingDefaults,s=t("../../plots/cartesian/axis_autotype"),l=t("./attributes");function c(t,e,r,i){function o(t){var e=0;return t&&t.length&&(e+=1,n.isArrayOrTypedArray(t[0])&&t[0].length&&(e+=1)),e}function c(e){return n.validate(t[e],l[e])}var u,h=r("y"),f=r("x");if("box"===e.type){var p=r("q1"),d=r("median"),g=r("q3");e._hasPreCompStats=p&&p.length&&d&&d.length&&g&&g.length,u=Math.min(n.minRowLength(p),n.minRowLength(d),n.minRowLength(g))}var v,m,y=o(h),x=o(f),b=y&&n.minRowLength(h),_=x&&n.minRowLength(f);if(e._hasPreCompStats)switch(String(x)+String(y)){case"00":var w=c("x0")||c("dx");v=(c("y0")||c("dy"))&&!w?"h":"v",m=u;break;case"10":v="v",m=Math.min(u,_);break;case"20":v="h",m=Math.min(u,f.length);break;case"01":v="h",m=Math.min(u,b);break;case"02":v="v",m=Math.min(u,h.length);break;case"12":v="v",m=Math.min(u,_,h.length);break;case"21":v="h",m=Math.min(u,f.length,b);break;case"11":m=0;break;case"22":var k,T=!1;for(k=0;k<f.length;k++)if("category"===s(f[k])){T=!0;break}if(T)v="v",m=Math.min(u,_,h.length);else{for(k=0;k<h.length;k++)if("category"===s(h[k])){T=!0;break}T?(v="h",m=Math.min(u,f.length,b)):(v="v",m=Math.min(u,_,h.length))}}else y>0?(v="v",m=x>0?Math.min(_,b):Math.min(b)):x>0?(v="h",m=Math.min(_)):m=0;if(m){e._length=m;var M=r("orientation",v);e._hasPreCompStats?"v"===M&&0===x?(r("x0",0),r("dx",1)):"h"===M&&0===y&&(r("y0",0),r("dy",1)):"v"===M&&0===x?r("x0"):"h"===M&&0===y&&r("y0"),a.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x","y"],i)}else e.visible=!1}function u(t,e,r,a){var i=a.prefix,o=n.coerce2(t,e,l,"marker.outliercolor"),s=r("marker.line.outliercolor"),c="outliers";e._hasPreCompStats?c="all":(o||s)&&(c="suspectedoutliers");var u=r(i+"points",c);u?(r("jitter","all"===u?.3:0),r("pointpos","all"===u?-1.5:0),r("marker.symbol"),r("marker.opacity"),r("marker.size"),r("marker.color",e.line.color),r("marker.line.color"),r("marker.line.width"),"suspectedoutliers"===u&&(r("marker.line.outliercolor",e.marker.color),r("marker.line.outlierwidth")),r("selected.marker.color"),r("unselected.marker.color"),r("selected.marker.size"),r("unselected.marker.size"),r("text"),r("hovertext")):delete e.marker;var h=r("hoveron");"all"!==h&&-1===h.indexOf("points")||r("hovertemplate"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,a){function o(r,a){return n.coerce(t,e,l,r,a)}if(c(t,e,o,a),!1!==e.visible){var s=e._hasPreCompStats;s&&(o("lowerfence"),o("upperfence")),o("line.color",(t.marker||{}).color||r),o("line.width"),o("fillcolor",i.addOpacity(e.line.color,.5));var h=!1;if(s){var f=o("mean"),p=o("sd");f&&f.length&&(h=!0,p&&p.length&&(h="sd"))}o("boxmean",h),o("whiskerwidth"),o("width"),o("quartilemethod");var d=!1;if(s){var g=o("notchspan");g&&g.length&&(d=!0)}else n.validate(t.notchwidth,l.notchwidth)&&(d=!0);o("notched",d)&&o("notchwidth"),u(t,e,o,{prefix:"box"})}},crossTraceDefaults:function(t,e){var r,a;function i(t){return n.coerce(a._input,a,l,t)}for(var s=0;s<t.length;s++){var c=(a=t[s]).type;"box"!==c&&"violin"!==c||(r=a._input,"group"===e[c+"mode"]&&o(r,a,e,i))}},handleSampleDefaults:c,handlePointsDefaults:u}},{"../../components/color":591,"../../lib":717,"../../plots/cartesian/axis_autotype":766,"../../registry":846,"../bar/defaults":860,"./attributes":881}],885:[function(t,e,r){"use strict";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),"xVal"in e&&(t.x=e.xVal),"yVal"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],886:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../lib"),i=t("../../components/fx"),o=t("../../components/color"),s=a.fillText;function l(t,e,r,s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w=t.cd,k=t.xa,T=t.ya,M=w[0].trace,A=w[0].t,S="violin"===M.type,E=[],L=A.bdPos,C=A.wHover,P=function(t){return u.c2l(t.pos)+A.bPos-u.c2l(p)};S&&"both"!==M.side?("positive"===M.side&&(v=function(t){var e=P(t);return i.inbox(e,e+C,m)},x=L,b=0),"negative"===M.side&&(v=function(t){var e=P(t);return i.inbox(e-C,e,m)},x=0,b=L)):(v=function(t){var e=P(t);return i.inbox(e-C,e+C,m)},x=b=L),_=S?function(t){return i.inbox(t.span[0]-f,t.span[1]-f,m)}:function(t){return i.inbox(t.min-f,t.max-f,m)},"h"===M.orientation?(f=e,p=r,d=_,g=v,l="y",u=T,c="x",h=k):(f=r,p=e,d=v,g=_,l="x",u=k,c="y",h=T);var O=Math.min(1,L/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function z(t){return(d(t)+g(t))/2}m=t.maxHoverDistance-O,y=t.maxSpikeDistance-O;var I=i.getDistanceFunction(s,d,g,z);if(i.getClosest(w,I,t),!1===t.index)return[];var D=w[t.index],R=M.line.color,F=(M.marker||{}).color;o.opacity(R)&&M.line.width?t.color=R:o.opacity(F)&&M.boxpoints?t.color=F:t.color=M.fillcolor,t[l+"0"]=u.c2p(D.pos+A.bPos-b,!0),t[l+"1"]=u.c2p(D.pos+A.bPos+x,!0),t[l+"LabelVal"]=D.pos;var B=l+"Spike";t.spikeDistance=z(D)*y/m,t[B]=u.c2p(D.pos,!0);var N={},j=["med","q1","q3","min","max"];(M.boxmean||(M.meanline||{}).visible)&&j.push("mean"),(M.boxpoints||M.points)&&j.push("lf","uf");for(var V=0;V<j.length;V++){var U=j[V];if(U in D&&!(D[U]in N)){N[D[U]]=!0;var q=D[U],H=h.c2p(q,!0),G=a.extendFlat({},t);G.attr=U,G[c+"0"]=G[c+"1"]=H,G[c+"LabelVal"]=q,G[c+"Label"]=(A.labels?A.labels[U]+" ":"")+n.hoverLabelText(h,q),G.hoverOnBox=!0,"mean"===U&&"sd"in D&&"sd"===M.boxmean&&(G[c+"err"]=D.sd),t.name="",t.spikeDistance=void 0,t[B]=void 0,G.hovertemplate=!1,E.push(G)}}return E}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,h=t.ya,f=c[0].trace,p=u.c2p(e),d=h.c2p(r),g=i.quadrature(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)},function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(h.c2p(t.y)-d)-e,1-3/e)}),v=!1,m=0;m<c.length;m++){o=c[m];for(var y=0;y<(o.pts||[]).length;y++){var x=g(l=o.pts[y]);x<=t.distance&&(t.distance=x,v=[m,y])}}if(!v)return!1;l=(o=c[v[0]]).pts[v[1]];var b,_=u.c2p(l.x,!0),w=h.c2p(l.y,!0),k=l.mrc||1;return n=a.extendFlat({},t,{index:l.i,color:(f.marker||{}).color,name:f.name,x0:_-k,x1:_+k,y0:w-k,y1:w+k,spikeDistance:t.distance,hovertemplate:f.hovertemplate}),"h"===f.orientation?(b=h,n.xLabelVal=l.x,n.yLabelVal=o.pos):(b=u,n.xLabelVal=o.pos,n.yLabelVal=l.y),n[b._id.charAt(0)+"Spike"]=b.c2p(o.pos,!0),s(l,f,n),n}e.exports={hoverPoints:function(t,e,r,n){var a,i=t.cd[0].trace.hoveron,o=[];return-1!==i.indexOf("boxes")&&(o=o.concat(l(t,e,r,n))),-1!==i.indexOf("points")&&(a=c(t,e,r)),"closest"===n?a?[a]:o:a?(o.push(a),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{"../../components/color":591,"../../components/fx":630,"../../lib":717,"../../plots/cartesian/axes":765}],887:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults").supplyDefaults,crossTraceDefaults:t("./defaults").crossTraceDefaults,supplyLayoutDefaults:t("./layout_defaults").supplyLayoutDefaults,calc:t("./calc"),crossTraceCalc:t("./cross_trace_calc").crossTraceCalc,plot:t("./plot").plot,style:t("./style").style,styleOnSelect:t("./style").styleOnSelect,hoverPoints:t("./hover").hoverPoints,eventData:t("./event_data"),selectPoints:t("./select"),moduleType:"trace",name:"box",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","symbols","oriented","box-violin","showLegend","boxLayout","zoomScale"],meta:{}}},{"../../plots/cartesian":776,"./attributes":881,"./calc":882,"./cross_trace_calc":883,"./defaults":884,"./event_data":885,"./hover":886,"./layout_attributes":888,"./layout_defaults":889,"./plot":890,"./select":891,"./style":892}],888:[function(t,e,r){"use strict";e.exports={boxmode:{valType:"enumerated",values:["group","overlay"],dflt:"overlay",editType:"calc"},boxgap:{valType:"number",min:0,max:1,dflt:.3,editType:"calc"},boxgroupgap:{valType:"number",min:0,max:1,dflt:.3,editType:"calc"}}},{}],889:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("./layout_attributes");function o(t,e,r,a,i){for(var o=i+"Layout",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(a(i+"mode"),a(i+"gap"),a(i+"groupgap"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,function(r,n){return a.coerce(t,e,i,r,n)},"box")},_supply:o}},{"../../lib":717,"../../registry":846,"./layout_attributes":888}],890:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../components/drawing"),o=5,s=.01;function l(t,e,r,i){var o,s,l=e.pos,c=e.val,u=i.bPos,h=i.wdPos||0,f=i.bPosPxOffset||0,p=r.whiskerwidth||0,d=r.notched||!1,g=d?1-2*r.notchwidth:1;Array.isArray(i.bdPos)?(o=i.bdPos[0],s=i.bdPos[1]):(o=i.bdPos,s=i.bdPos);var v=t.selectAll("path.box").data("violin"!==r.type||r.box.visible?a.identity:[]);v.enter().append("path").style("vector-effect","non-scaling-stroke").attr("class","box"),v.exit().remove(),v.each(function(t){if(t.empty)return"M0,0Z";var e=l.c2l(t.pos+u,!0),i=l.l2p(e)+f,v=l.l2p(e-o)+f,m=l.l2p(e+s)+f,y=l.l2p(e-h)+f,x=l.l2p(e+h)+f,b=l.l2p(e-o*g)+f,_=l.l2p(e+s*g)+f,w=c.c2p(t.q1,!0),k=c.c2p(t.q3,!0),T=a.constrain(c.c2p(t.med,!0),Math.min(w,k)+1,Math.max(w,k)-1),M=void 0===t.lf||!1===r.boxpoints,A=c.c2p(M?t.min:t.lf,!0),S=c.c2p(M?t.max:t.uf,!0),E=c.c2p(t.ln,!0),L=c.c2p(t.un,!0);"h"===r.orientation?n.select(this).attr("d","M"+T+","+b+"V"+_+"M"+w+","+v+"V"+m+(d?"H"+E+"L"+T+","+_+"L"+L+","+m:"")+"H"+k+"V"+v+(d?"H"+L+"L"+T+","+b+"L"+E+","+v:"")+"ZM"+w+","+i+"H"+A+"M"+k+","+i+"H"+S+(0===p?"":"M"+A+","+y+"V"+x+"M"+S+","+y+"V"+x)):n.select(this).attr("d","M"+b+","+T+"H"+_+"M"+v+","+w+"H"+m+(d?"V"+E+"L"+_+","+T+"L"+m+","+L:"")+"V"+k+"H"+v+(d?"V"+L+"L"+b+","+T+"L"+v+","+E:"")+"ZM"+i+","+w+"V"+A+"M"+i+","+k+"V"+S+(0===p?"":"M"+y+","+A+"H"+x+"M"+y+","+S+"H"+x))})}function c(t,e,r,n){var l=e.x,c=e.y,u=n.bdPos,h=n.bPos,f=r.boxpoints||r.points;a.seedPseudoRandom();var p=t.selectAll("g.points").data(f?function(t){return t.forEach(function(t){t.t=n,t.trace=r}),t}:[]);p.enter().append("g").attr("class","points"),p.exit().remove();var d=p.selectAll("path").data(function(t){var e,n,i=t.pts2,l=Math.max((t.max-t.min)/10,t.q3-t.q1),c=1e-9*l,p=l*s,d=[],g=0;if(r.jitter){if(0===l)for(g=1,d=new Array(i.length),e=0;e<i.length;e++)d[e]=1;else for(e=0;e<i.length;e++){var v=Math.max(0,e-o),m=i[v].v,y=Math.min(i.length-1,e+o),x=i[y].v;"all"!==f&&(i[e].v<t.lf?x=Math.min(x,t.lf):m=Math.max(m,t.uf));var b=Math.sqrt(p*(y-v)/(x-m+c))||0;b=a.constrain(Math.abs(b),0,1),d.push(b),g=Math.max(b,g)}n=2*r.jitter/(g||1)}for(e=0;e<i.length;e++){var _=i[e],w=_.v,k=r.jitter?n*d[e]*(a.pseudoRandom()-.5):0,T=t.pos+h+u*(r.pointpos+k);"h"===r.orientation?(_.y=T,_.x=w):(_.x=T,_.y=w),"suspectedoutliers"===f&&w<t.uo&&w>t.lo&&(_.so=!0)}return i});d.enter().append("path").classed("point",!0),d.exit().remove(),d.call(i.translatePoints,l,c)}function u(t,e,r,i){var o,s,l=e.pos,c=e.val,u=i.bPos,h=i.bPosPxOffset||0,f=r.boxmean||(r.meanline||{}).visible;Array.isArray(i.bdPos)?(o=i.bdPos[0],s=i.bdPos[1]):(o=i.bdPos,s=i.bdPos);var p=t.selectAll("path.mean").data("box"===r.type&&r.boxmean||"violin"===r.type&&r.box.visible&&r.meanline.visible?a.identity:[]);p.enter().append("path").attr("class","mean").style({fill:"none","vector-effect":"non-scaling-stroke"}),p.exit().remove(),p.each(function(t){var e=l.c2l(t.pos+u,!0),a=l.l2p(e)+h,i=l.l2p(e-o)+h,p=l.l2p(e+s)+h,d=c.c2p(t.mean,!0),g=c.c2p(t.mean-t.sd,!0),v=c.c2p(t.mean+t.sd,!0);"h"===r.orientation?n.select(this).attr("d","M"+d+","+i+"V"+p+("sd"===f?"m0,0L"+g+","+a+"L"+d+","+i+"L"+v+","+a+"Z":"")):n.select(this).attr("d","M"+i+","+d+"H"+p+("sd"===f?"m0,0L"+a+","+g+"L"+i+","+d+"L"+a+","+v+"Z":""))})}e.exports={plot:function(t,e,r,i){var o=e.xaxis,s=e.yaxis;a.makeTraceGroups(i,r,"trace boxes").each(function(t){var e,r,a=n.select(this),i=t[0],h=i.t,f=i.trace;h.wdPos=h.bdPos*f.whiskerwidth,!0!==f.visible||h.empty?a.remove():("h"===f.orientation?(e=s,r=o):(e=o,r=s),l(a,{pos:e,val:r},f,h),c(a,{x:o,y:s},f,h),u(a,{pos:e,val:r},f,h))})},plotBoxAndWhiskers:l,plotPoints:c,plotBoxMean:u}},{"../../components/drawing":612,"../../lib":717,d3:165}],891:[function(t,e,r){"use strict";e.exports=function(t,e){var r,n,a=t.cd,i=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<a.length;r++)for(n=0;n<(a[r].pts||[]).length;n++)a[r].pts[n].selected=0;else for(r=0;r<a.length;r++)for(n=0;n<(a[r].pts||[]).length;n++){var l=a[r].pts[n],c=i.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:i.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],892:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/color"),i=t("../../components/drawing");e.exports={style:function(t,e,r){var o=r||n.select(t).selectAll("g.trace.boxes");o.style("opacity",function(t){return t[0].trace.opacity}),o.each(function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style("stroke-width",e+"px").call(a.stroke,r).call(a.fill,n)}var c=r.selectAll("path.box");if("candlestick"===o.type)c.each(function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style("opacity",o.selectedpoints&&!t.selected?.3:1)}});else{l(c,s,o.line.color,o.fillcolor),r.selectAll("path.mean").style({"stroke-width":s,"stroke-dasharray":2*s+"px,"+s+"px"}).call(a.stroke,o.line.color);var u=r.selectAll("path.point");i.pointStyle(u,o,t)}})},styleOnSelect:function(t,e,r){var n=e[0].trace,a=r.selectAll("path.point");n.selectedpoints?i.selectedPointStyle(a,n):i.pointStyle(a,n,t)}}},{"../../components/color":591,"../../components/drawing":612,d3:165}],893:[function(t,e,r){"use strict";var n=t("../../lib").extendFlat,a=t("../ohlc/attributes"),i=t("../box/attributes");function o(t){return{line:{color:n({},i.line.color,{dflt:t}),width:i.line.width,editType:"style"},fillcolor:i.fillcolor,editType:"style"}}e.exports={x:a.x,open:a.open,high:a.high,low:a.low,close:a.close,line:{width:n({},i.line.width,{}),editType:"style"},increasing:o(a.increasing.line.color.dflt),decreasing:o(a.decreasing.line.color.dflt),text:a.text,hovertext:a.hovertext,whiskerwidth:n({},i.whiskerwidth,{dflt:0}),hoverlabel:a.hoverlabel}},{"../../lib":717,"../box/attributes":881,"../ohlc/attributes":1066}],894:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../ohlc/calc").calcCommon;function o(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,s=a.getFromId(t,e.xaxis),l=a.getFromId(t,e.yaxis),c=s.makeCalcdata(e,"x"),u=i(t,e,c,l,o);return u.length?(n.extendFlat(u[0].t,{num:r._numBoxes,dPos:n.distinctVals(c).minDiff/2,posLetter:"x",valLetter:"y"}),r._numBoxes++,u):[{t:{empty:!0}}]}},{"../../lib":717,"../../plots/cartesian/axes":765,"../ohlc/calc":1067}],895:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/color"),i=t("../ohlc/ohlc_defaults"),o=t("./attributes");function s(t,e,r,n){var i=r(n+".line.color");r(n+".line.width",e.line.width),r(n+".fillcolor",a.addOpacity(i,.5))}e.exports=function(t,e,r,a){function l(r,a){return n.coerce(t,e,o,r,a)}i(t,e,l,a)?(l("line.width"),s(t,e,l,"increasing"),s(t,e,l,"decreasing"),l("text"),l("hovertext"),l("whiskerwidth"),a._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{"../../components/color":591,"../../lib":717,"../ohlc/ohlc_defaults":1071,"./attributes":893}],896:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"candlestick",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","showLegend","candlestick","boxLayout"],meta:{},attributes:t("./attributes"),layoutAttributes:t("../box/layout_attributes"),supplyLayoutDefaults:t("../box/layout_defaults").supplyLayoutDefaults,crossTraceCalc:t("../box/cross_trace_calc").crossTraceCalc,supplyDefaults:t("./defaults"),calc:t("./calc"),plot:t("../box/plot").plot,layerName:"boxlayer",style:t("../box/style").style,hoverPoints:t("../ohlc/hover").hoverPoints,selectPoints:t("../ohlc/select")}},{"../../plots/cartesian":776,"../box/cross_trace_calc":883,"../box/layout_attributes":888,"../box/layout_defaults":889,"../box/plot":890,"../box/style":892,"../ohlc/hover":1069,"../ohlc/select":1073,"./attributes":893,"./calc":894,"./defaults":895}],897:[function(t,e,r){"use strict";var n=t("./axis_defaults"),a=t("../../plot_api/plot_template");e.exports=function(t,e,r,i,o){i("a")||(i("da"),i("a0")),i("b")||(i("db"),i("b0")),function(t,e,r,i){["aaxis","baxis"].forEach(function(o){var s=o.charAt(0),l=t[o]||{},c=a.newContainer(e,o),u={tickfont:"x",id:s+"axis",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:i,bgColor:r.paper_bgcolor,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||"-"===l.type||(t[o]={type:l.type})})}(t,e,r,o)}},{"../../plot_api/plot_template":755,"./axis_defaults":902}],898:[function(t,e,r){"use strict";var n=t("../../lib").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;var a=1/0;var i=-1/0;var o=e.length;for(var s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(a=Math.min(c[0],a),i=Math.max(c[1],i))}else a=Math.min(l,a),i=Math.max(l,i)}return[a,i]}(t,0)}},{"../../lib":717}],899:[function(t,e,r){"use strict";var n=t("../../plots/font_attributes"),a=t("./axis_attributes"),i=t("../../components/color/attributes"),o=n({editType:"calc"});o.family.dflt='"Open Sans", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=i.defaultLine,e.exports={carpet:{valType:"string",editType:"calc"},x:{valType:"data_array",editType:"calc+clearAxisTypes"},y:{valType:"data_array",editType:"calc+clearAxisTypes"},a:{valType:"data_array",editType:"calc"},a0:{valType:"number",dflt:0,editType:"calc"},da:{valType:"number",dflt:1,editType:"calc"},b:{valType:"data_array",editType:"calc"},b0:{valType:"number",dflt:0,editType:"calc"},db:{valType:"number",dflt:1,editType:"calc"},cheaterslope:{valType:"number",dflt:1,editType:"calc"},aaxis:a,baxis:a,font:o,color:{valType:"color",dflt:i.defaultLine,editType:"plot"},transforms:void 0}},{"../../components/color/attributes":590,"../../plots/font_attributes":791,"./axis_attributes":901}],900:[function(t,e,r){"use strict";var n=t("../../lib").isArrayOrTypedArray;e.exports=function(t,e,r,a){var i,o,s,l,c,u,h,f,p,d,g,v,m,y=n(r)?"a":"b",x=("a"===y?t.aaxis:t.baxis).smoothing,b="a"===y?t.a2i:t.b2j,_="a"===y?r:a,w="a"===y?a:r,k="a"===y?e.a.length:e.b.length,T="a"===y?e.b.length:e.a.length,M=Math.floor("a"===y?t.b2j(w):t.a2i(w)),A="a"===y?function(e){return t.evalxy([],e,M)}:function(e){return t.evalxy([],M,e)};x&&(s=Math.max(0,Math.min(T-2,M)),l=M-s,o="a"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),E=b(_[1]),L=S<E?1:-1,C=1e-8*(E-S),P=L>0?Math.floor:Math.ceil,O=L>0?Math.ceil:Math.floor,z=L>0?Math.min:Math.max,I=L>0?Math.max:Math.min,D=P(S+C),R=O(E-C),F=[[h=A(S)]];for(i=D;i*L<R*L;i+=L)c=[],g=I(S,i),m=(v=z(E,i+L))-g,u=Math.max(0,Math.min(k-2,Math.floor(.5*(g+v)))),f=A(v),x&&(p=o(u,g-u),d=o(u,v-u),c.push([h[0]+p[0]/3*m,h[1]+p[1]/3*m]),c.push([f[0]-d[0]/3*m,f[1]-d[1]/3*m])),c.push(f),F.push(c),h=f;return F}},{"../../lib":717}],901:[function(t,e,r){"use strict";var n=t("../../plots/font_attributes"),a=t("../../components/color/attributes"),i=t("../../plots/cartesian/layout_attributes"),o=t("../../plot_api/edit_types").overrideAll;t("../../constants/docs").FORMAT_LINK,t("../../constants/docs").TIME_FORMAT_LINK;e.exports={color:{valType:"color",editType:"calc"},smoothing:{valType:"number",dflt:1,min:0,max:1.3,editType:"calc"},title:{text:{valType:"string",dflt:"",editType:"calc"},font:n({editType:"calc"}),offset:{valType:"number",dflt:10,editType:"calc"},editType:"calc"},type:{valType:"enumerated",values:["-","linear","date","category"],dflt:"-",editType:"calc"},autorange:{valType:"enumerated",values:[!0,!1,"reversed"],dflt:!0,editType:"calc"},rangemode:{valType:"enumerated",values:["normal","tozero","nonnegative"],dflt:"normal",editType:"calc"},range:{valType:"info_array",editType:"calc",items:[{valType:"any",editType:"calc"},{valType:"any",editType:"calc"}]},fixedrange:{valType:"boolean",dflt:!1,editType:"calc"},cheatertype:{valType:"enumerated",values:["index","value"],dflt:"value",editType:"calc"},tickmode:{valType:"enumerated",values:["linear","array"],dflt:"array",editType:"calc"},nticks:{valType:"integer",min:0,dflt:0,editType:"calc"},tickvals:{valType:"data_array",editType:"calc"},ticktext:{valType:"data_array",editType:"calc"},showticklabels:{valType:"enumerated",values:["start","end","both","none"],dflt:"start",editType:"calc"},tickfont:n({editType:"calc"}),tickangle:{valType:"angle",dflt:"auto",editType:"calc"},tickprefix:{valType:"string",dflt:"",editType:"calc"},showtickprefix:{valType:"enumerated",values:["all","first","last","none"],dflt:"all",editType:"calc"},ticksuffix:{valType:"string",dflt:"",editType:"calc"},showticksuffix:{valType:"enumerated",values:["all","first","last","none"],dflt:"all",editType:"calc"},showexponent:{valType:"enumerated",values:["all","first","last","none"],dflt:"all",editType:"calc"},exponentformat:{valType:"enumerated",values:["none","e","E","power","SI","B"],dflt:"B",editType:"calc"},separatethousands:{valType:"boolean",dflt:!1,editType:"calc"},tickformat:{valType:"string",dflt:"",editType:"calc"},tickformatstops:o(i.tickformatstops,"calc","from-root"),categoryorder:{valType:"enumerated",values:["trace","category ascending","category descending","array"],dflt:"trace",editType:"calc"},categoryarray:{valType:"data_array",editType:"calc"},labelpadding:{valType:"integer",dflt:10,editType:"calc"},labelprefix:{valType:"string",editType:"calc"},labelsuffix:{valType:"string",dflt:"",editType:"calc"},showline:{valType:"boolean",dflt:!1,editType:"calc"},linecolor:{valType:"color",dflt:a.defaultLine,editType:"calc"},linewidth:{valType:"number",min:0,dflt:1,editType:"calc"},gridcolor:{valType:"color",editType:"calc"},gridwidth:{valType:"number",min:0,dflt:1,editType:"calc"},showgrid:{valType:"boolean",dflt:!0,editType:"calc"},minorgridcount:{valType:"integer",min:0,dflt:0,editType:"calc"},minorgridwidth:{valType:"number",min:0,dflt:1,editType:"calc"},minorgridcolor:{valType:"color",dflt:a.lightLine,editType:"calc"},startline:{valType:"boolean",editType:"calc"},startlinecolor:{valType:"color",editType:"calc"},startlinewidth:{valType:"number",dflt:1,editType:"calc"},endline:{valType:"boolean",editType:"calc"},endlinewidth:{valType:"number",dflt:1,editType:"calc"},endlinecolor:{valType:"color",editType:"calc"},tick0:{valType:"number",min:0,dflt:0,editType:"calc"},dtick:{valType:"number",min:0,dflt:1,editType:"calc"},arraytick0:{valType:"integer",min:0,dflt:0,editType:"calc"},arraydtick:{valType:"integer",min:1,dflt:1,editType:"calc"},_deprecated:{title:{valType:"string",editType:"calc"},titlefont:n({editType:"calc"}),titleoffset:{valType:"number",dflt:10,editType:"calc"}},editType:"calc"}},{"../../components/color/attributes":590,"../../constants/docs":688,"../../plot_api/edit_types":748,"../../plots/cartesian/layout_attributes":777,"../../plots/font_attributes":791}],902:[function(t,e,r){"use strict";var n=t("./attributes"),a=t("../../components/color").addOpacity,i=t("../../registry"),o=t("../../lib"),s=t("../../plots/cartesian/tick_value_defaults"),l=t("../../plots/cartesian/tick_label_defaults"),c=t("../../plots/cartesian/category_order_defaults"),u=t("../../plots/cartesian/set_convert"),h=t("../../plots/cartesian/axis_autotype");e.exports=function(t,e,r){var f=r.letter,p=r.font||{},d=n[f+"axis"];function g(r,n){return o.coerce(t,e,d,r,n)}function v(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name);var m=g("type");("-"===m&&(r.data&&function(t,e){if("-"!==t.type)return;var r=t._id.charAt(0),n=t[r+"calendar"];t.type=h(e,n)}(e,r.data),"-"===e.type?e.type="linear":m=t.type=e.type),g("smoothing"),g("cheatertype"),g("showticklabels"),g("labelprefix",f+" = "),g("labelsuffix"),g("showtickprefix"),g("showticksuffix"),g("separatethousands"),g("tickformat"),g("exponentformat"),g("showexponent"),g("categoryorder"),g("tickmode"),g("tickvals"),g("ticktext"),g("tick0"),g("dtick"),"array"===e.tickmode&&(g("arraytick0"),g("arraydtick")),g("labelpadding"),e._hovertitle=f,"date"===m)&&i.getComponentMethod("calendars","handleDefaults")(t,e,"calendar",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=g("color",r.dfltColor),x=y===t.color?y:p.color;g("title.text")&&(o.coerceFont(g,"title.font",{family:p.family,size:Math.round(1.2*p.size),color:x}),g("title.offset")),g("tickangle"),g("autorange",!e.isValidRange(t.range))&&g("rangemode"),g("range"),e.cleanRange(),g("fixedrange"),s(t,e,g,m),l(t,e,g,m,r),c(t,e,g,{data:r.data,dataAttr:f});var b=v("gridcolor",a(y,.3)),_=v("gridwidth"),w=g("showgrid");w||(delete e.gridcolor,delete e.gridwidth);var k=v("startlinecolor",y),T=v("startlinewidth",_);g("startline",e.showgrid||!!k||!!T)||(delete e.startlinecolor,delete e.startlinewidth);var M=v("endlinecolor",y),A=v("endlinewidth",_);return g("endline",e.showgrid||!!M||!!A)||(delete e.endlinecolor,delete e.endlinewidth),w?(g("minorgridcount"),g("minorgridwidth",_),g("minorgridcolor",a(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),"none"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g("tickmode"),e}},{"../../components/color":591,"../../lib":717,"../../plots/cartesian/axis_autotype":766,"../../plots/cartesian/category_order_defaults":769,"../../plots/cartesian/set_convert":783,"../../plots/cartesian/tick_label_defaults":784,"../../plots/cartesian/tick_value_defaults":786,"../../registry":846,"./attributes":899}],903:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../lib").isArray1D,i=t("./cheater_basis"),o=t("./array_minmax"),s=t("./calc_gridlines"),l=t("./calc_labels"),c=t("./calc_clippath"),u=t("../heatmap/clean_2d_array"),h=t("./smooth_fill_2d_array"),f=t("../heatmap/convert_column_xyz"),p=t("./set_convert");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),g=e.aaxis,v=e.baxis,m=e.x,y=e.y,x=[];m&&a(m)&&x.push("x"),y&&a(y)&&x.push("y"),x.length&&f(e,g,v,"a","b",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;m=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var k="index"===g.cheatertype?b.length:b,T="index"===v.cheatertype?_.length:_;m=i(k,T,e.cheaterslope)}e._x=m=u(m),e._y=y=u(y),h(m,b,_),h(y,b,_),p(e),e.setScale();var M=o(m),A=o(y),S=.5*(M[1]-M[0]),E=.5*(M[1]+M[0]),L=.5*(A[1]-A[0]),C=.5*(A[1]+A[0]);return M=[E-1.3*S,E+1.3*S],A=[C-1.3*L,C+1.3*L],e._extremes[r._id]=n.findExtremes(r,M,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,A,{padded:!0}),s(e,"a","b"),s(e,"b","a"),l(e,g),l(e,v),w.clipsegments=c(e._xctrl,e._yctrl,g,v),w.x=m,w.y=y,w.a=b,w.b=_,[w]}},{"../../lib":717,"../../plots/cartesian/axes":765,"../heatmap/clean_2d_array":1002,"../heatmap/convert_column_xyz":1004,"./array_minmax":898,"./calc_clippath":904,"./calc_gridlines":905,"./calc_labels":906,"./cheater_basis":908,"./set_convert":921,"./smooth_fill_2d_array":922}],904:[function(t,e,r){"use strict";e.exports=function(t,e,r,n){var a,i,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,h=t.length-1;for(a=0,i=[],o=[];a<=u;a++)i[a]=t[0][a],o[a]=e[0][a];for(s.push({x:i,y:o,bicubic:l}),a=0,i=[],o=[];a<=h;a++)i[a]=t[a][u],o[a]=e[a][u];for(s.push({x:i,y:o,bicubic:c}),a=u,i=[],o=[];a>=0;a--)i[u-a]=t[h][a],o[u-a]=e[h][a];for(s.push({x:i,y:o,bicubic:l}),a=h,i=[],o=[];a>=0;a--)i[h-a]=t[a][0],o[h-a]=e[a][0];return s.push({x:i,y:o,bicubic:c}),s}},{}],905:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../lib/extend").extendFlat;e.exports=function(t,e,r){var i,o,s,l,c,u,h,f,p,d,g,v,m,y,x=t["_"+e],b=t[e+"axis"],_=b._gridlines=[],w=b._minorgridlines=[],k=b._boundarylines=[],T=t["_"+r],M=t[r+"axis"];"array"===b.tickmode&&(b.tickvals=x.slice());var A=t._xctrl,S=t._yctrl,E=A[0].length,L=A.length,C=t._a.length,P=t._b.length;n.prepTicks(b),"array"===b.tickmode&&delete b.tickvals;var O=b.smoothing?3:1;function z(n){var a,i,o,s,l,c,u,h,p,d,g,v,m=[],y=[],x={};if("b"===e)for(i=t.b2j(n),o=Math.floor(Math.max(0,Math.min(P-2,i))),s=i-o,x.length=P,x.crossLength=C,x.xy=function(e){return t.evalxy([],e,i)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},a=0;a<C;a++)c=Math.min(C-2,a),u=a-c,h=t.evalxy([],a,i),M.smoothing&&a>0&&(p=t.dxydi([],a-1,o,0,s),m.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],a-1,o,1,s),m.push(h[0]-d[0]/3),y.push(h[1]-d[1]/3)),m.push(h[0]),y.push(h[1]),l=h;else for(a=t.a2i(n),c=Math.floor(Math.max(0,Math.min(C-2,a))),u=a-c,x.length=C,x.crossLength=P,x.xy=function(e){return t.evalxy([],a,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},i=0;i<P;i++)o=Math.min(P-2,i),s=i-o,h=t.evalxy([],a,i),M.smoothing&&i>0&&(g=t.dxydj([],c,i-1,u,0),m.push(l[0]+g[0]/3),y.push(l[1]+g[1]/3),v=t.dxydj([],c,i-1,u,1),m.push(h[0]-v[0]/3),y.push(h[1]-v[1]/3)),m.push(h[0]),y.push(h[1]),l=h;return x.axisLetter=e,x.axis=b,x.crossAxis=M,x.value=n,x.constvar=r,x.index=f,x.x=m,x.y=y,x.smoothing=M.smoothing,x}function I(n){var a,i,o,s,l,c=[],u=[],h={};if(h.length=x.length,h.crossLength=T.length,"b"===e)for(o=Math.max(0,Math.min(P-2,n)),l=Math.min(1,Math.max(0,n-o)),h.xy=function(e){return t.evalxy([],e,n)},h.dxy=function(e,r){return t.dxydi([],e,o,r,l)},a=0;a<E;a++)c[a]=A[n*O][a],u[a]=S[n*O][a];else for(i=Math.max(0,Math.min(C-2,n)),s=Math.min(1,Math.max(0,n-i)),h.xy=function(e){return t.evalxy([],n,e)},h.dxy=function(e,r){return t.dxydj([],i,e,s,r)},a=0;a<L;a++)c[a]=A[a][n*O],u[a]=S[a][n*O];return h.axisLetter=e,h.axis=b,h.crossAxis=M,h.value=x[n],h.constvar=r,h.index=n,h.x=c,h.y=u,h.smoothing=M.smoothing,h}if("array"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort(function(t,e){return t-e}))[0]-1,h=c[1]+1,f=u;f<h;f++)(o=b.arraytick0+b.arraydtick*f)<0||o>x.length-1||_.push(a(I(o),{color:b.gridcolor,width:b.gridwidth}));for(f=u;f<h;f++)if(s=b.arraytick0+b.arraydtick*f,g=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||g<0||g>x.length-1))for(v=x[s],m=x[g],i=0;i<b.minorgridcount;i++)(y=g-s)<=0||(d=v+(m-v)*(i+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(a(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(a(I(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(a(I(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort(function(t,e){return t-e}))[0],h=c[1],f=u;f<=h;f++)p=b.tick0+b.dtick*f,_.push(a(z(p),{color:b.gridcolor,width:b.gridwidth}));for(f=u-1;f<h+1;f++)for(p=b.tick0+b.dtick*f,i=0;i<b.minorgridcount;i++)(d=p+b.dtick*(i+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(a(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(a(z(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(a(z(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{"../../lib/extend":708,"../../plots/cartesian/axes":765}],906:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../lib/extend").extendFlat;e.exports=function(t,e){var r,i,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==["start","both"].indexOf(e.showticklabels)&&(i=n.tickText(e,o.value),a(i,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(i)),-1!==["end","both"].indexOf(e.showticklabels)&&(i=n.tickText(e,o.value),a(i,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(i))}},{"../../lib/extend":708,"../../plots/cartesian/axes":765}],907:[function(t,e,r){"use strict";e.exports=function(t,e,r,n){var a=t[0]-e[0],i=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(a*a+i*i,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*a-l*l*o)*n,h=(c*c*i-l*l*s)*n,f=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(f&&u/f),e[1]+(f&&h/f)],[e[0]-(p&&u/p),e[1]-(p&&h/p)]]}},{}],908:[function(t,e,r){"use strict";var n=t("../../lib").isArrayOrTypedArray;e.exports=function(t,e,r){var a,i,o,s,l,c,u=[],h=n(t)?t.length:t,f=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(h-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(f-1));var g=1/0,v=-1/0;for(i=0;i<f;i++)for(u[i]=[],l=d?(d[i]-d[0])*s:i/(f-1),a=0;a<h;a++)c=(p?(p[a]-p[0])*o:a/(h-1))-l*r,g=Math.min(c,g),v=Math.max(c,v),u[i][a]=c;var m=1/(v-g),y=-g*m;for(i=0;i<f;i++)for(a=0;a<h;a++)u[i][a]=m*u[i][a]+y;return u}},{"../../lib":717}],909:[function(t,e,r){"use strict";var n=t("./catmull_rom"),a=t("../../lib").ensureArray;function i(t,e,r){var n=-.5*r[0]+1.5*e[0],a=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*a+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,h,f,p,d,g,v,m,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=a(t,w),e=a(e,w),h=0;h<w;h++)t[h]=a(t[h],_),e[h]=a(e[h],_);for(u=0,f=0;u<b;u++,f+=l?3:1)for(p=t[f],d=e[f],g=r[u],v=o[u],c=0,h=0;c<x;c++,h+=s?3:1)p[h]=g[c],d[h]=v[c];if(s)for(u=0,f=0;u<b;u++,f+=l?3:1){for(c=1,h=3;c<x-1;c++,h+=3)m=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[f][h-1]=m[0][0],e[f][h-1]=m[0][1],t[f][h+1]=m[1][0],e[f][h+1]=m[1][1];y=i([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=y[0],e[f][1]=y[1],y=i([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=y[0],e[f][_-2]=y[1]}if(l)for(h=0;h<_;h++){for(f=3;f<w-3;f+=3)m=n([t[f-3][h],e[f-3][h]],[t[f][h],e[f][h]],[t[f+3][h],e[f+3][h]],l),t[f-1][h]=m[0][0],e[f-1][h]=m[0][1],t[f+1][h]=m[1][0],e[f+1][h]=m[1][1];y=i([t[0][h],e[0][h]],[t[2][h],e[2][h]],[t[3][h],e[3][h]]),t[1][h]=y[0],e[1][h]=y[1],y=i([t[w-1][h],e[w-1][h]],[t[w-3][h],e[w-3][h]],[t[w-4][h],e[w-4][h]]),t[w-2][h]=y[0],e[w-2][h]=y[1]}if(s&&l)for(f=1;f<w;f+=(f+1)%3==0?2:1){for(h=3;h<_-3;h+=3)m=n([t[f][h-3],e[f][h-3]],[t[f][h],e[f][h]],[t[f][h+3],e[f][h+3]],s),t[f][h-1]=.5*(t[f][h-1]+m[0][0]),e[f][h-1]=.5*(e[f][h-1]+m[0][1]),t[f][h+1]=.5*(t[f][h+1]+m[1][0]),e[f][h+1]=.5*(e[f][h+1]+m[1][1]);y=i([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=.5*(t[f][1]+y[0]),e[f][1]=.5*(e[f][1]+y[1]),y=i([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=.5*(t[f][_-2]+y[0]),e[f][_-2]=.5*(e[f][_-2]+y[1])}return[t,e]}},{"../../lib":717,"./catmull_rom":907}],910:[function(t,e,r){"use strict";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],911:[function(t,e,r){"use strict";e.exports=function(t,e,r){return e&&r?function(e,r,n,a,i){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=a*a,p=1-a,d=p*p,g=p*a*2,v=-3*d,m=3*(d-g),y=3*(g-f),x=3*f,b=i*i,_=b*i,w=1-i,k=w*w,T=k*w;for(h=0;h<t.length;h++)o=v*(u=t[h])[n][r]+m*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=v*u[n+1][r]+m*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=v*u[n+2][r]+m*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=v*u[n+3][r]+m*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[h]=T*o+3*(k*i*s+w*b*l)+_*c;return e}:e?function(e,r,n,a,i){var o,s,l,c;e||(e=[]),r*=3;var u=a*a,h=1-a,f=h*h,p=h*a*2,d=-3*f,g=3*(f-p),v=3*(p-u),m=3*u,y=1-i;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+g*c[n][r+1]+v*c[n][r+2]+m*c[n][r+3],s=d*c[n+1][r]+g*c[n+1][r+1]+v*c[n+1][r+2]+m*c[n+1][r+3],e[l]=y*o+i*s;return e}:r?function(e,r,n,a,i){var o,s,l,c,u,h;e||(e=[]),n*=3;var f=i*i,p=f*i,d=1-i,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n][r+1]-h[n][r],s=h[n+1][r+1]-h[n+1][r],l=h[n+2][r+1]-h[n+2][r],c=h[n+3][r+1]-h[n+3][r],e[u]=v*o+3*(g*i*s+d*f*l)+p*c;return e}:function(e,r,n,a,i){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+i*s;return e}}},{}],912:[function(t,e,r){"use strict";e.exports=function(t,e,r){return e&&r?function(e,r,n,a,i){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d,m=i*i,y=1-i,x=y*y,b=y*i*2,_=-3*x,w=3*(x-b),k=3*(b-m),T=3*m;for(h=0;h<t.length;h++)o=_*(u=t[h])[n][r]+w*u[n+1][r]+k*u[n+2][r]+T*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+k*u[n+2][r+1]+T*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+k*u[n+2][r+2]+T*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+k*u[n+2][r+3]+T*u[n+3][r+3],e[h]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:e?function(e,r,n,a,i){var o,s,l,c,u,h;e||(e=[]),r*=3;var f=i*i,p=f*i,d=1-i,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n+1][r]-h[n][r],s=h[n+1][r+1]-h[n][r+1],l=h[n+1][r+2]-h[n][r+2],c=h[n+1][r+3]-h[n][r+3],e[u]=v*o+3*(g*i*s+d*f*l)+p*c;return e}:r?function(e,r,n,a,i){var o,s,l,c;e||(e=[]),n*=3;var u=1-a,h=i*i,f=1-i,p=f*f,d=f*i*2,g=-3*p,v=3*(p-d),m=3*(d-h),y=3*h;for(l=0;l<t.length;l++)o=g*(c=t[l])[n][r]+v*c[n+1][r]+m*c[n+2][r]+y*c[n+3][r],s=g*c[n][r+1]+v*c[n+1][r+1]+m*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+a*s;return e}:function(e,r,n,a,i){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+a*s;return e}}},{}],913:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a){var i=e-2,o=r-2;return n&&a?function(e,r,n){var a,s,l,c,u,h;e||(e=[]);var f=Math.max(0,Math.min(Math.floor(r),i)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3,p*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=g*g,w=_*g,k=1-g,T=k*k,M=T*k;for(h=0;h<t.length;h++)a=b*(u=t[h])[p][f]+3*(x*d*u[p][f+1]+y*v*u[p][f+2])+m*u[p][f+3],s=b*u[p+1][f]+3*(x*d*u[p+1][f+1]+y*v*u[p+1][f+2])+m*u[p+1][f+3],l=b*u[p+2][f]+3*(x*d*u[p+2][f+1]+y*v*u[p+2][f+2])+m*u[p+2][f+3],c=b*u[p+3][f]+3*(x*d*u[p+3][f+1]+y*v*u[p+3][f+2])+m*u[p+3][f+3],e[h]=M*a+3*(T*g*s+k*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var a,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),i)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=1-g;for(u=0;u<t.length;u++)a=_*(h=t[u])[p][f]+g*h[p+1][f],s=_*h[p][f+1]+g*h[p+1][f+1],l=_*h[p][f+2]+g*h[p+1][f+1],c=_*h[p][f+3]+g*h[p+1][f+1],e[u]=b*a+3*(x*d*s+y*v*l)+m*c;return e}:a?function(e,r,n){e||(e=[]);var a,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),i)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));p*=3;var v=g*g,m=v*g,y=1-g,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)a=_*(h=t[u])[p][f]+d*h[p][f+1],s=_*h[p+1][f]+d*h[p+1][f+1],l=_*h[p+2][f]+d*h[p+2][f+1],c=_*h[p+3][f]+d*h[p+3][f+1],e[u]=b*a+3*(x*g*s+y*v*l)+m*c;return e}:function(e,r,n){e||(e=[]);var a,s,l,c,u=Math.max(0,Math.min(Math.floor(r),i)),h=Math.max(0,Math.min(Math.floor(n),o)),f=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-h)),d=1-p,g=1-f;for(l=0;l<t.length;l++)a=g*(c=t[l])[h][u]+f*c[h][u+1],s=g*c[h+1][u]+f*c[h+1][u+1],e[l]=d*a+p*s;return e}}},{}],914:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./xy_defaults"),i=t("./ab_defaults"),o=t("./attributes"),s=t("../../components/color/attributes");e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,o,r,a)}e._clipPathId="clip"+e.uid+"carpet";var u=c("color",s.defaultLine);(n.coerceFont(c,"font"),c("carpet"),i(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),a(t,e,c)||(e.visible=!1),e._cheater&&c("cheaterslope")):e.visible=!1}},{"../../components/color/attributes":590,"../../lib":717,"./ab_defaults":897,"./attributes":899,"./xy_defaults":923}],915:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),plot:t("./plot"),calc:t("./calc"),animatable:!0,isContainer:!0,moduleType:"trace",name:"carpet",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","carpet","carpetAxis","notLegendIsolatable","noMultiCategory","noHover","noSortingByValue"],meta:{}}},{"../../plots/cartesian":776,"./attributes":899,"./calc":903,"./defaults":914,"./plot":920}],916:[function(t,e,r){"use strict";e.exports=function(t,e){for(var r,n=t._fullData.length,a=0;a<n;a++){var i=t._fullData[a];if(i.index!==e.index&&("carpet"===i.type&&(r||(r=i),i.carpet===e.carpet)))return i}return r}},{}],917:[function(t,e,r){"use strict";e.exports=function(t,e,r){if(0===t.length)return"";var n,a=[],i=r?3:1;for(n=0;n<t.length;n+=i)a.push(t[n]+","+e[n]),r&&n<t.length-i&&(a.push("C"),a.push([t[n+1]+","+e[n+1],t[n+2]+","+e[n+2]+" "].join(" ")));return a.join(r?"":"L")}},{}],918:[function(t,e,r){"use strict";var n=t("../../lib").isArrayOrTypedArray;e.exports=function(t,e,r){var a;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],a=0;a<e.length;a++)t[a]=r(e[a]);return t}},{"../../lib":717}],919:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a,i){var o=a[0]*t.dpdx(e),s=a[1]*t.dpdy(r),l=1,c=1;if(i){var u=Math.sqrt(a[0]*a[0]+a[1]*a[1]),h=Math.sqrt(i[0]*i[0]+i[1]*i[1]),f=(a[0]*i[0]+a[1]*i[1])/u/h;c=Math.max(0,f)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],920:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/drawing"),i=t("./map_1d_array"),o=t("./makepath"),s=t("./orient_text"),l=t("../../lib/svg_text_utils"),c=t("../../lib"),u=t("../../constants/alignment");function h(t,e,r,a,s,l){var c="const-"+s+"-lines",u=r.selectAll("."+c).data(l);u.enter().append("path").classed(c,!0).style("vector-effect","non-scaling-stroke"),u.each(function(r){var a=r,s=a.x,l=a.y,c=i([],s,t.c2p),u=i([],l,e.c2p),h="M"+o(c,u,a.smoothing);n.select(this).attr("d",h).style("stroke-width",a.width).style("stroke",a.color).style("fill","none")}),u.exit().remove()}function f(t,e,r,i,o,c,u,h){var f=c.selectAll("text."+h).data(u);f.enter().append("text").classed(h,!0);var p=0,d={};return f.each(function(o,c){var u;if("auto"===o.axis.tickangle)u=s(i,e,r,o.xy,o.dxy);else{var h=(o.axis.tickangle+180)*Math.PI/180;u=s(i,e,r,o.xy,[Math.cos(h),Math.sin(h)])}c||(d={angle:u.angle,flip:u.flip});var f=(o.endAnchor?-1:1)*u.flip,g=n.select(this).attr({"text-anchor":f>0?"start":"end","data-notex":1}).call(a.font,o.font).text(o.text).call(l.convertToTspans,t),v=a.bBox(this);g.attr("transform","translate("+u.p[0]+","+u.p[1]+") rotate("+u.angle+")translate("+o.axis.labelpadding*f+","+.3*v.height+")"),p=Math.max(p,v.width+o.axis.labelpadding)}),f.exit().remove(),d.maxExtent=p,d}e.exports=function(t,e,r,a){var l=e.xaxis,u=e.yaxis,p=t._fullLayout._clips;c.makeTraceGroups(a,r,"trace").each(function(e){var r=n.select(this),a=e[0],d=a.trace,v=d.aaxis,m=d.baxis,y=c.ensureSingle(r,"g","minorlayer"),x=c.ensureSingle(r,"g","majorlayer"),b=c.ensureSingle(r,"g","boundarylayer"),_=c.ensureSingle(r,"g","labellayer");r.style("opacity",d.opacity),h(l,u,x,v,"a",v._gridlines),h(l,u,x,m,"b",m._gridlines),h(l,u,y,v,"a",v._minorgridlines),h(l,u,y,m,"b",m._minorgridlines),h(l,u,b,v,"a-boundary",v._boundarylines),h(l,u,b,m,"b-boundary",m._boundarylines);var w=f(t,l,u,d,a,_,v._labels,"a-label"),k=f(t,l,u,d,a,_,m._labels,"b-label");!function(t,e,r,n,a,i,o,l){var u,h,f,p,d=c.aggNums(Math.min,null,r.a),v=c.aggNums(Math.max,null,r.a),m=c.aggNums(Math.min,null,r.b),y=c.aggNums(Math.max,null,r.b);u=.5*(d+v),h=m,f=r.ab2xy(u,h,!0),p=r.dxyda_rough(u,h),void 0===o.angle&&c.extendFlat(o,s(r,a,i,f,r.dxydb_rough(u,h)));g(t,e,r,n,f,p,r.aaxis,a,i,o,"a-title"),u=d,h=.5*(m+y),f=r.ab2xy(u,h,!0),p=r.dxydb_rough(u,h),void 0===l.angle&&c.extendFlat(l,s(r,a,i,f,r.dxyda_rough(u,h)));g(t,e,r,n,f,p,r.baxis,a,i,l,"b-title")}(t,_,d,a,l,u,w,k),function(t,e,r,n,a){var s,l,u,h,f=r.select("#"+t._clipPathId);f.size()||(f=r.append("clipPath").classed("carpetclip",!0));var p=c.ensureSingle(f,"path","carpetboundary"),d=e.clipsegments,g=[];for(h=0;h<d.length;h++)s=d[h],l=i([],s.x,n.c2p),u=i([],s.y,a.c2p),g.push(o(l,u,s.bicubic));var v="M"+g.join("L")+"Z";f.attr("id",t._clipPathId),p.attr("d",v)}(d,a,p,l,u)})};var p=u.LINE_SPACING,d=(1-u.MID_SHIFT)/p+1;function g(t,e,r,i,o,c,u,h,f,g,v){var m=[];u.title.text&&m.push(u.title.text);var y=e.selectAll("text."+v).data(m),x=g.maxExtent;y.enter().append("text").classed(v,!0),y.each(function(){var e=s(r,h,f,o,c);-1===["start","both"].indexOf(u.showticklabels)&&(x=0);var i=u.title.font.size;x+=i+u.title.offset;var v=(g.angle+(g.flip<0?180:0)-e.angle+450)%360,m=v>90&&v<270,y=n.select(this);y.text(u.title.text).call(l.convertToTspans,t),m&&(x=(-l.lineCount(y)+d)*p*i-x),y.attr("transform","translate("+e.p[0]+","+e.p[1]+") rotate("+e.angle+") translate(0,"+x+")").classed("user-select-none",!0).attr("text-anchor","middle").call(a.font,u.title.font)}),y.exit().remove()}},{"../../components/drawing":612,"../../constants/alignment":686,"../../lib":717,"../../lib/svg_text_utils":741,"./makepath":917,"./map_1d_array":918,"./orient_text":919,d3:165}],921:[function(t,e,r){"use strict";var n=t("./constants"),a=t("../../lib/search").findBin,i=t("./compute_control_points"),o=t("./create_spline_evaluator"),s=t("./create_i_derivative_evaluator"),l=t("./create_j_derivative_evaluator");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,h=t.aaxis,f=t.baxis,p=e[0],d=e[c-1],g=r[0],v=r[u-1],m=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=m*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,g-=b,v+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>g&&e<v},t.isOccluded=function(t,e){return t<p||t>d||e<g||e>v},t.setScale=function(){var e=t._x,r=t._y,n=i(t._xctrl,t._yctrl,e,r,h.smoothing,f.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,h.smoothing,f.smoothing),t.dxydi=s([t._xctrl,t._yctrl],h.smoothing,f.smoothing),t.dxydj=l([t._xctrl,t._yctrl],h.smoothing,f.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(a(t,e),c-2)),n=e[r],i=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(i-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(a(t,r),u-2)),n=r[e],i=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(i-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,a,i){if(!i&&(n<e[0]||n>e[c-1]|a<r[0]||a>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(a),l=t.evalxy([],o,s);if(i){var h,f,p,d,g=0,v=0,m=[];n<e[0]?(h=0,f=0,g=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(h=c-2,f=1,g=(n-e[c-1])/(e[c-1]-e[c-2])):f=o-(h=Math.max(0,Math.min(c-2,Math.floor(o)))),a<r[0]?(p=0,d=0,v=(a-r[0])/(r[1]-r[0])):a>r[u-1]?(p=u-2,d=1,v=(a-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),g&&(t.dxydi(m,h,p,f,d),l[0]+=m[0]*g,l[1]+=m[1]*g),v&&(t.dxydj(m,h,p,f,d),l[0]+=m[0]*v,l[1]+=m[1]*v)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,a){var i=t.dxydi(null,e,r,n,a),o=t.dadi(e,n);return[i[0]/o,i[1]/o]},t.dxydb=function(e,r,n,a){var i=t.dxydj(null,e,r,n,a),o=t.dbdj(r,a);return[i[0]/o,i[1]/o]},t.dxyda_rough=function(e,r,n){var a=m*(n||.1),i=t.ab2xy(e+a,r,!0),o=t.ab2xy(e-a,r,!0);return[.5*(i[0]-o[0])/a,.5*(i[1]-o[1])/a]},t.dxydb_rough=function(e,r,n){var a=y*(n||.1),i=t.ab2xy(e,r+a,!0),o=t.ab2xy(e,r-a,!0);return[.5*(i[0]-o[0])/a,.5*(i[1]-o[1])/a]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{"../../lib/search":736,"./compute_control_points":909,"./constants":910,"./create_i_derivative_evaluator":911,"./create_j_derivative_evaluator":912,"./create_spline_evaluator":913}],922:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e,r){var a,i,o,s=[],l=[],c=t[0].length,u=t.length;function h(e,r){var n,a=0,i=0;return e>0&&void 0!==(n=t[r][e-1])&&(i++,a+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(i++,a+=n),r>0&&void 0!==(n=t[r-1][e])&&(i++,a+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(i++,a+=n),a/Math.max(1,i)}var f,p,d,g,v,m,y,x,b,_,w,k=0;for(a=0;a<c;a++)for(i=0;i<u;i++)void 0===t[i][a]&&(s.push(a),l.push(i),t[i][a]=h(a,i)),k=Math.max(k,Math.abs(t[i][a]));if(!s.length)return t;var T=0,M=0,A=s.length;do{for(T=0,o=0;o<A;o++){a=s[o],i=l[o];var S,E,L,C,P,O,z=0,I=0;0===a?(L=e[P=Math.min(c-1,2)],C=e[1],S=t[i][P],I+=(E=t[i][1])+(E-S)*(e[0]-C)/(C-L),z++):a===c-1&&(L=e[P=Math.max(0,c-3)],C=e[c-2],S=t[i][P],I+=(E=t[i][c-2])+(E-S)*(e[c-1]-C)/(C-L),z++),(0===a||a===c-1)&&i>0&&i<u-1&&(f=r[i+1]-r[i],I+=((p=r[i]-r[i-1])*t[i+1][a]+f*t[i-1][a])/(p+f),z++),0===i?(L=r[O=Math.min(u-1,2)],C=r[1],S=t[O][a],I+=(E=t[1][a])+(E-S)*(r[0]-C)/(C-L),z++):i===u-1&&(L=r[O=Math.max(0,u-3)],C=r[u-2],S=t[O][a],I+=(E=t[u-2][a])+(E-S)*(r[u-1]-C)/(C-L),z++),(0===i||i===u-1)&&a>0&&a<c-1&&(f=e[a+1]-e[a],I+=((p=e[a]-e[a-1])*t[i][a+1]+f*t[i][a-1])/(p+f),z++),z?I/=z:(d=e[a+1]-e[a],g=e[a]-e[a-1],x=(v=r[i+1]-r[i])*(m=r[i]-r[i-1])*(v+m),I=((y=d*g*(d+g))*(m*t[i+1][a]+v*t[i-1][a])+x*(g*t[i][a+1]+d*t[i][a-1]))/(x*(g+d)+y*(m+v))),T+=(_=(b=I-t[i][a])/k)*_,w=z?0:.85,t[i][a]+=b*(1+w)}T=Math.sqrt(T)}while(M++<100&&T>1e-5);return n.log("Smoother converged to",T,"after",M,"iterations"),t}},{"../../lib":717}],923:[function(t,e,r){"use strict";var n=t("../../lib").isArray1D;e.exports=function(t,e,r){var a=r("x"),i=a&&a.length,o=r("y"),s=o&&o.length;if(!i&&!s)return!1;if(e._cheater=!a,i&&!n(a)||s&&!n(o))e._length=null;else{var l=i?a.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{"../../lib":717}],924:[function(t,e,r){"use strict";var n=t("../../plots/template_attributes").hovertemplateAttrs,a=t("../scattergeo/attributes"),i=t("../../components/colorscale/attributes"),o=t("../../plots/attributes"),s=t("../../components/color/attributes").defaultLine,l=t("../../lib/extend").extendFlat,c=a.marker.line;e.exports=l({locations:{valType:"data_array",editType:"calc"},locationmode:a.locationmode,z:{valType:"data_array",editType:"calc"},geojson:l({},a.geojson,{}),featureidkey:a.featureidkey,text:l({},a.text,{}),hovertext:l({},a.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:"calc"},opacity:{valType:"number",arrayOk:!0,min:0,max:1,dflt:1,editType:"style"},editType:"calc"},selected:{marker:{opacity:a.selected.marker.opacity,editType:"plot"},editType:"plot"},unselected:{marker:{opacity:a.unselected.marker.opacity,editType:"plot"},editType:"plot"},hoverinfo:l({},o.hoverinfo,{editType:"calc",flags:["location","z","text","name"]}),hovertemplate:n(),showlegend:l({},o.showlegend,{dflt:!1})},i("",{cLetter:"z",editTypeOverride:"calc"}))},{"../../components/color/attributes":590,"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plots/attributes":762,"../../plots/template_attributes":841,"../scattergeo/attributes":1161}],925:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../constants/numerical").BADNUM,i=t("../../components/colorscale/calc"),o=t("../scatter/arrays_to_calcdata"),s=t("../scatter/calc_selection");function l(t){return t&&"string"==typeof t}e.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var h=0;h<c;h++){var f=u[h]={},p=e.locations[h],d=e.z[h];r(p)&&n(d)?(f.loc=p,f.z=d):(f.loc=null,f.z=a),f.index=h}return o(u,e),i(t,e,{vals:e.z,containerStr:"",cLetter:"z"}),s(u,e),u}},{"../../components/colorscale/calc":599,"../../constants/numerical":693,"../scatter/arrays_to_calcdata":1119,"../scatter/calc_selection":1122,"fast-isnumeric":228}],926:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/colorscale/defaults"),i=t("./attributes");e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}var l=s("locations"),c=s("z");if(l&&l.length&&n.isArrayOrTypedArray(c)&&c.length){e._length=Math.min(l.length,c.length);var u,h=s("geojson");("string"==typeof h&&""!==h||n.isPlainObject(h))&&(u="geojson-id"),"geojson-id"===s("locationmode",u)&&s("featureidkey"),s("text"),s("hovertext"),s("hovertemplate"),s("marker.line.width")&&s("marker.line.color"),s("marker.opacity"),a(t,e,o,s,{prefix:"",cLetter:"z"}),n.coerceSelectionMarkerOpacity(e,s)}else e.visible=!1}},{"../../components/colorscale/defaults":601,"../../lib":717,"./attributes":924}],927:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a){t.location=e.location,t.z=e.z;var i=n[a];return i.fIn&&i.fIn.properties&&(t.properties=i.fIn.properties),t.ct=i.ct,t}},{}],928:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("./attributes"),i=t("../../lib").fillText;e.exports=function(t,e,r){var o,s,l,c,u=t.cd,h=u[0].trace,f=t.subplot;for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains([e,r])&&(c=!c),o._polygons[l].contains([e+360,r])&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(f.mockAxis,f.mockAxis.c2l(o.z),"hover").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(e.hovertemplate)return;var n=r.hi||e.hoverinfo,o=String(r.loc),s="all"===n?a.hoverinfo.flags:n.split("+"),l=-1!==s.indexOf("name"),c=-1!==s.indexOf("location"),u=-1!==s.indexOf("z"),h=-1!==s.indexOf("text"),f=[];!l&&c?t.nameOverride=o:(l&&(t.nameOverride=e.name),c&&f.push(o));u&&f.push(t.zLabel);h&&i(r,e,f);t.extraText=f.join("<br>")}(t,h,o,f.mockAxis),[t]}},{"../../lib":717,"../../plots/cartesian/axes":765,"./attributes":924}],929:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../heatmap/colorbar"),calc:t("./calc"),calcGeoJSON:t("./plot").calcGeoJSON,plot:t("./plot").plot,style:t("./style").style,styleOnSelect:t("./style").styleOnSelect,hoverPoints:t("./hover"),eventData:t("./event_data"),selectPoints:t("./select"),moduleType:"trace",name:"choropleth",basePlotModule:t("../../plots/geo"),categories:["geo","noOpacity","showLegend"],meta:{}}},{"../../plots/geo":795,"../heatmap/colorbar":1003,"./attributes":924,"./calc":925,"./defaults":926,"./event_data":927,"./hover":928,"./plot":930,"./select":931,"./style":932}],930:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../lib/geo_location_utils"),o=t("../../lib/topojson_utils").getTopojsonFeatures,s=t("../../plots/cartesian/autorange").findExtremes,l=t("./style").style;e.exports={calcGeoJSON:function(t,e){for(var r=t[0].trace,n=e[r.geo],a=n._subplot,l=r.locationmode,c=r._length,u="geojson-id"===l?i.extractTraceFeature(t):o(r,a.topojson),h=[],f=[],p=0;p<c;p++){var d=t[p],g="geojson-id"===l?d.fOut:i.locationToFeature(l,d.loc,u);if(g){d.geojson=g,d.ct=g.properties.ct,d._polygons=i.feature2polygons(g);var v=i.computeBbox(g);h.push(v[0],v[2]),f.push(v[1],v[3])}else d.geojson=null}if("geojson"===n.fitbounds&&"geojson-id"===l){var m=i.computeBbox(i.getTraceGeojson(r));h=[m[0],m[2]],f=[m[1],m[3]]}var y={padded:!0};r._extremes.lon=s(n.lonaxis._ax,h,y),r._extremes.lat=s(n.lataxis._ax,f,y)},plot:function(t,e,r){var i=e.layers.backplot.select(".choroplethlayer");a.makeTraceGroups(i,r,"trace choropleth").each(function(e){var r=n.select(this).selectAll("path.choroplethlocation").data(a.identity);r.enter().append("path").classed("choroplethlocation",!0),r.exit().remove(),l(t,e)})}}},{"../../lib":717,"../../lib/geo_location_utils":711,"../../lib/topojson_utils":744,"../../plots/cartesian/autorange":764,"./style":932,d3:165}],931:[function(t,e,r){"use strict";e.exports=function(t,e){var r,n,a,i,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(a=(n=s[r]).ct)&&(i=l.c2p(a),o=c.c2p(a),e.contains([i,o],null,r,t)?(u.push({pointNumber:r,lon:a[0],lat:a[1]}),n.selected=1):n.selected=0);return u}},{}],932:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/color"),i=t("../../components/drawing"),o=t("../../components/colorscale");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(".choroplethlocation"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each(function(t){n.select(this).attr("fill",u(t.z)).call(a.stroke,t.mlc||c.color).call(i.dashLine,"",t.mlw||c.width||0).style("opacity",l.opacity)}),i.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?i.selectedPointStyle(r.selectAll(".choroplethlocation"),n,t):s(t,e)}}},{"../../components/color":591,"../../components/colorscale":603,"../../components/drawing":612,d3:165}],933:[function(t,e,r){"use strict";var n=t("../choropleth/attributes"),a=t("../../components/colorscale/attributes"),i=t("../../plots/template_attributes").hovertemplateAttrs,o=t("../../plots/attributes"),s=t("../../lib/extend").extendFlat;e.exports=s({locations:{valType:"data_array",editType:"calc"},z:{valType:"data_array",editType:"calc"},geojson:{valType:"any",editType:"calc"},featureidkey:s({},n.featureidkey,{}),below:{valType:"string",editType:"plot"},text:n.text,hovertext:n.hovertext,marker:{line:{color:s({},n.marker.line.color,{editType:"plot"}),width:s({},n.marker.line.width,{editType:"plot"}),editType:"calc"},opacity:s({},n.marker.opacity,{editType:"plot"}),editType:"calc"},selected:{marker:{opacity:s({},n.selected.marker.opacity,{editType:"plot"}),editType:"plot"},editType:"plot"},unselected:{marker:{opacity:s({},n.unselected.marker.opacity,{editType:"plot"}),editType:"plot"},editType:"plot"},hoverinfo:n.hoverinfo,hovertemplate:i({},{keys:["properties"]}),showlegend:s({},o.showlegend,{dflt:!1})},a("",{cLetter:"z",editTypeOverride:"calc"}))},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plots/attributes":762,"../../plots/template_attributes":841,"../choropleth/attributes":924}],934:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../components/colorscale"),o=t("../../components/drawing"),s=t("../../lib/geojson_utils").makeBlank,l=t("../../lib/geo_location_utils");function c(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var i=o.makeSelectedPointStyleFns(r),s=0;s<t.length;s++){var l=t[s];l.fOut&&(l.fOut.properties.mo2=i.selectedOpacityFn(l))}e={type:"identity",property:"mo2"}}else e=a.isArrayOrTypedArray(r.marker.opacity)?{type:"identity",property:"mo"}:r.marker.opacity;return a.extendFlat(n.fill.paint,{"fill-opacity":e}),a.extendFlat(n.line.paint,{"line-opacity":e}),n}e.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,o={layout:{visibility:"none"},paint:{}},u={layout:{visibility:"none"},paint:{}},h=e._opts={fill:o,line:u,geojson:s()};if(!r)return h;var f=l.extractTraceFeature(t);if(!f)return h;var p,d,g,v=i.makeColorScaleFuncFromTrace(e),m=e.marker,y=m.line||{};a.isArrayOrTypedArray(m.opacity)&&(p=function(t){var e=t.mo;return n(e)?+a.constrain(e,0,1):0}),a.isArrayOrTypedArray(y.color)&&(d=function(t){return t.mlc}),a.isArrayOrTypedArray(y.width)&&(g=function(t){return t.mlw});for(var x=0;x<t.length;x++){var b=t[x],_=b.fOut;if(_){var w=_.properties;w.fc=v(b.z),p&&(w.mo=p(b)),d&&(w.mlc=d(b)),g&&(w.mlw=g(b)),b.ct=w.ct,b._polygons=l.feature2polygons(_)}}var k=p?{type:"identity",property:"mo"}:m.opacity;return a.extendFlat(o.paint,{"fill-color":{type:"identity",property:"fc"},"fill-opacity":k}),a.extendFlat(u.paint,{"line-color":d?{type:"identity",property:"mlc"}:y.color,"line-width":g?{type:"identity",property:"mlw"}:y.width,"line-opacity":k}),o.layout.visibility="visible",u.layout.visibility="visible",h.geojson={type:"FeatureCollection",features:f},c(t),h},convertOnSelect:c}},{"../../components/colorscale":603,"../../components/drawing":612,"../../lib":717,"../../lib/geo_location_utils":711,"../../lib/geojson_utils":712,"fast-isnumeric":228}],935:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/colorscale/defaults"),i=t("./attributes");e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}var l=s("locations"),c=s("z"),u=s("geojson");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&("string"==typeof u&&""!==u||n.isPlainObject(u))?(s("featureidkey"),e._length=Math.min(l.length,c.length),s("below"),s("text"),s("hovertext"),s("hovertemplate"),s("marker.line.width")&&s("marker.line.color"),s("marker.opacity"),a(t,e,o,s,{prefix:"",cLetter:"z"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{"../../components/colorscale/defaults":601,"../../lib":717,"./attributes":933}],936:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../heatmap/colorbar"),calc:t("../choropleth/calc"),plot:t("./plot"),hoverPoints:t("../choropleth/hover"),eventData:t("../choropleth/event_data"),selectPoints:t("../choropleth/select"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var a=r[n].id;if("string"==typeof a&&0===a.indexOf("water"))for(var i=n+1;i<r.length;i++)if("string"==typeof(a=r[i].id)&&-1===a.indexOf("plotly-"))return a}},moduleType:"trace",name:"choroplethmapbox",basePlotModule:t("../../plots/mapbox"),categories:["mapbox","gl","noOpacity","showLegend"],meta:{hr_name:"choropleth_mapbox"}}},{"../../plots/mapbox":820,"../choropleth/calc":925,"../choropleth/event_data":927,"../choropleth/hover":928,"../choropleth/select":931,"../heatmap/colorbar":1003,"./attributes":933,"./defaults":935,"./plot":937}],937:[function(t,e,r){"use strict";var n=t("./convert").convert,a=t("./convert").convertOnSelect,i=t("../../plots/mapbox/constants").traceLayerPrefix;function o(t,e){this.type="choroplethmapbox",this.subplot=t,this.uid=e,this.sourceId="source-"+e,this.layerList=[["fill",i+e+"-fill"],["line",i+e+"-line"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t))},s.updateOnSelect=function(t){this._update(a(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup["trace-"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var a=0;a<r.length;a++){var i=r[a],o=i[0],s=i[1],l=t[o];e.setOptions(s,"setLayoutProperty",l.layout),"visible"===l.layout.visibility&&e.setOptions(s,"setPaintProperty",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,a=this.sourceId,i=0;i<n.length;i++){var o=n[i],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:a,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,a=new o(t,r.uid),i=a.sourceId,s=n(e),l=a.below=t.belowLookup["trace-"+r.uid];return t.map.addSource(i,{type:"geojson",data:s.geojson}),a._addLayers(s,l),e[0].trace._glTrace=a,a}},{"../../plots/mapbox/constants":818,"./convert":934}],938:[function(t,e,r){"use strict";var n=t("../../components/colorscale/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../mesh3d/attributes"),o=t("../../plots/attributes"),s=t("../../lib/extend").extendFlat,l={x:{valType:"data_array",editType:"calc+clearAxisTypes"},y:{valType:"data_array",editType:"calc+clearAxisTypes"},z:{valType:"data_array",editType:"calc+clearAxisTypes"},u:{valType:"data_array",editType:"calc"},v:{valType:"data_array",editType:"calc"},w:{valType:"data_array",editType:"calc"},sizemode:{valType:"enumerated",values:["scaled","absolute"],editType:"calc",dflt:"scaled"},sizeref:{valType:"number",editType:"calc",min:0},anchor:{valType:"enumerated",editType:"calc",values:["tip","tail","cm","center"],dflt:"cm"},text:{valType:"string",dflt:"",arrayOk:!0,editType:"calc"},hovertext:{valType:"string",dflt:"",arrayOk:!0,editType:"calc"},hovertemplate:a({editType:"calc"},{keys:["norm"]}),showlegend:s({},o.showlegend,{dflt:!1})};s(l,n("",{colorAttr:"u/v/w norm",showScaleDflt:!0,editTypeOverride:"calc"}));["opacity","lightposition","lighting"].forEach(function(t){l[t]=i[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:"calc",flags:["x","y","z","u","v","w","norm","text","name"],dflt:"x+y+z+norm+text+name"}),l.transforms=void 0,e.exports=l},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plots/attributes":762,"../../plots/template_attributes":841,"../mesh3d/attributes":1061}],939:[function(t,e,r){"use strict";var n=t("../../components/colorscale/calc");e.exports=function(t,e){for(var r=e.u,a=e.v,i=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,a.length,i.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],h=a[c],f=i[c],p=Math.sqrt(u*u+h*h+f*f);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:"",cLetter:"c"})}},{"../../components/colorscale/calc":599}],940:[function(t,e,r){"use strict";var n=t("gl-cone3d"),a=t("gl-cone3d").createConeMesh,i=t("../../lib").simpleMap,o=t("../../lib/gl_format_color").parseColorScale,s=t("../../components/colorscale").extractOpts,l=t("../../plots/gl3d/zip3");function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],a=this.data.z[e],i=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,a,i,o,s,Math.sqrt(i*i+o*o+s*s)];var l=this.data.hovertext||this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var h={xaxis:0,yaxis:1,zaxis:2},f={tip:1,tail:0,cm:.25,center:.5},p={tip:1,tail:1,cm:.75,center:.5};function d(t,e){var r=t.fullSceneLayout,a=t.dataScale,c={};function u(t,e){var n=r[e],o=a[h[e]];return i(t,function(t){return n.d2l(t)*o})}c.vectors=l(u(e.u,"xaxis"),u(e.v,"yaxis"),u(e.w,"zaxis"),e._len),c.positions=l(u(e.x,"xaxis"),u(e.y,"yaxis"),u(e.z,"zaxis"),e._len);var d=s(e);c.colormap=o(e),c.vertexIntensityBounds=[d.min/e._normMax,d.max/e._normMax],c.coneOffset=f[e.anchor],"scaled"===e.sizemode?c.coneSize=e.sizeref||.5:c.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var g=n(c),v=e.lightposition;return g.lightPosition=[v.x,v.y,v.z],g.ambient=e.lighting.ambient,g.diffuse=e.lighting.diffuse,g.specular=e.lighting.specular,g.roughness=e.lighting.roughness,g.fresnel=e.lighting.fresnel,g.opacity=e.opacity,e._pad=p[e.anchor]*g.vectorScale*g.coneScale*e._normMax,g}u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),i=a(r,n),o=new c(t,e.uid);return o.mesh=i,o.data=e,i._trace=o,t.glplot.add(i),o}},{"../../components/colorscale":603,"../../lib":717,"../../lib/gl_format_color":714,"../../plots/gl3d/zip3":816,"gl-cone3d":245}],941:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/colorscale/defaults"),i=t("./attributes");e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}var l=s("u"),c=s("v"),u=s("w"),h=s("x"),f=s("y"),p=s("z");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s("sizeref"),s("sizemode"),s("anchor"),s("lighting.ambient"),s("lighting.diffuse"),s("lighting.specular"),s("lighting.roughness"),s("lighting.fresnel"),s("lightposition.x"),s("lightposition.y"),s("lightposition.z"),a(t,e,o,s,{prefix:"",cLetter:"c"}),s("text"),s("hovertext"),s("hovertemplate"),e._length=null):e.visible=!1}},{"../../components/colorscale/defaults":601,"../../lib":717,"./attributes":938}],942:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"cone",basePlotModule:t("../../plots/gl3d"),categories:["gl3d","showLegend"],attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:{min:"cmin",max:"cmax"},calc:t("./calc"),plot:t("./convert"),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},{"../../plots/gl3d":805,"./attributes":938,"./calc":939,"./convert":940,"./defaults":941}],943:[function(t,e,r){"use strict";var n=t("../heatmap/attributes"),a=t("../scatter/attributes"),i=t("../../components/colorscale/attributes"),o=t("../../components/drawing/attributes").dash,s=t("../../plots/font_attributes"),l=t("../../lib/extend").extendFlat,c=t("../../constants/filter_ops"),u=c.COMPARISON_OPS2,h=c.INTERVAL_OPS,f=(t("../../constants/docs").FORMAT_LINK,a.line);e.exports=l({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate,hoverongaps:n.hoverongaps,connectgaps:l({},n.connectgaps,{}),fillcolor:{valType:"color",editType:"calc"},autocontour:{valType:"boolean",dflt:!0,editType:"calc",impliedEdits:{"contours.start":void 0,"contours.end":void 0,"contours.size":void 0}},ncontours:{valType:"integer",dflt:15,min:1,editType:"calc"},contours:{type:{valType:"enumerated",values:["levels","constraint"],dflt:"levels",editType:"calc"},start:{valType:"number",dflt:null,editType:"plot",impliedEdits:{"^autocontour":!1}},end:{valType:"number",dflt:null,editType:"plot",impliedEdits:{"^autocontour":!1}},size:{valType:"number",dflt:null,min:0,editType:"plot",impliedEdits:{"^autocontour":!1}},coloring:{valType:"enumerated",values:["fill","heatmap","lines","none"],dflt:"fill",editType:"calc"},showlines:{valType:"boolean",dflt:!0,editType:"plot"},showlabels:{valType:"boolean",dflt:!1,editType:"plot"},labelfont:s({editType:"plot",colorEditType:"style"}),labelformat:{valType:"string",dflt:"",editType:"plot"},operation:{valType:"enumerated",values:[].concat(u).concat(h),dflt:"=",editType:"calc"},value:{valType:"any",dflt:0,editType:"calc"},editType:"calc",impliedEdits:{autocontour:!1}},line:{color:l({},f.color,{editType:"style+colorbars"}),width:{valType:"number",min:0,editType:"style+colorbars"},dash:o,smoothing:l({},f.smoothing,{}),editType:"plot"}},i("",{cLetter:"z",autoColorDflt:!1,editTypeOverride:"calc"}))},{"../../components/colorscale/attributes":598,"../../components/drawing/attributes":611,"../../constants/docs":688,"../../constants/filter_ops":689,"../../lib/extend":708,"../../plots/font_attributes":791,"../heatmap/attributes":1e3,"../scatter/attributes":1120}],944:[function(t,e,r){"use strict";var n=t("../../components/colorscale"),a=t("../heatmap/calc"),i=t("./set_contours"),o=t("./end_plus");e.exports=function(t,e){var r=a(t,e),s=r[0].z;i(e,s);var l,c=e.contours,u=n.extractOpts(e);if("heatmap"===c.coloring&&u.auto&&!1===e.autocontour){var h=c.start,f=o(c),p=c.size||1,d=Math.floor((f-h)/p)+1;isFinite(p)||(p=1,d=1);var g=h-p/2;l=[g,g+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:"z"}),r}},{"../../components/colorscale":603,"../heatmap/calc":1001,"./end_plus":954,"./set_contours":962}],945:[function(t,e,r){"use strict";e.exports=function(t,e){var r,n=t[0],a=n.z;switch(e.type){case"levels":var i=Math.min(a[0][0],a[0][1]);for(r=0;r<t.length;r++){var o=t[r];o.prefixBoundary=!o.edgepaths.length&&(i>o.level||o.starts.length&&i===o.level)}break;case"constraint":if(n.prefixBoundary=!1,n.edgepaths.length)return;var s=n.x.length,l=n.y.length,c=-1/0,u=1/0;for(r=0;r<l;r++)u=Math.min(u,a[r][0]),u=Math.min(u,a[r][s-1]),c=Math.max(c,a[r][0]),c=Math.max(c,a[r][s-1]);for(r=1;r<s-1;r++)u=Math.min(u,a[0][r]),u=Math.min(u,a[l-1][r]),c=Math.max(c,a[0][r]),c=Math.max(c,a[l-1][r]);var h,f,p=e.value;switch(e._operation){case">":p>c&&(n.prefixBoundary=!0);break;case"<":(p<u||n.starts.length&&p===u)&&(n.prefixBoundary=!0);break;case"[]":h=Math.min(p[0],p[1]),((f=Math.max(p[0],p[1]))<u||h>c||n.starts.length&&f===u)&&(n.prefixBoundary=!0);break;case"][":h=Math.min(p[0],p[1]),f=Math.max(p[0],p[1]),h<u&&f>c&&(n.prefixBoundary=!0)}}}},{}],946:[function(t,e,r){"use strict";var n=t("../../components/colorscale"),a=t("./make_color_map"),i=t("./end_plus");e.exports={min:"zmin",max:"zmax",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=a(e,{isColorbar:!0});if("heatmap"===c){var h=n.extractOpts(e);r._fillgradient=h.reversescale?n.flipScale(h.colorscale):h.colorscale,r._zrange=[h.min,h.max]}else"fill"===c&&(r._fillcolor=u);r._line={color:"lines"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:i(o),size:l}}}},{"../../components/colorscale":603,"./end_plus":954,"./make_color_map":959}],947:[function(t,e,r){"use strict";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],948:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("./label_defaults"),i=t("../../components/color"),o=i.addOpacity,s=i.opacity,l=t("../../constants/filter_ops"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,i,l,h){var f,p,d,g=e.contours,v=r("contours.operation");(g._operation=c[v],function(t,e){var r;-1===u.indexOf(e.operation)?(t("contours.value",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t("contours.value",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),"="===v?f=g.showlines=!0:(f=r("contours.showlines"),d=r("fillcolor",o((t.line||{}).color||l,.5))),f)&&(p=r("line.color",d&&s(d)?o(e.fillcolor,1):l),r("line.width",2),r("line.dash"));r("line.smoothing"),a(r,i,p,h)}},{"../../components/color":591,"../../constants/filter_ops":689,"./label_defaults":958,"fast-isnumeric":228}],949:[function(t,e,r){"use strict";var n=t("../../constants/filter_ops"),a=t("fast-isnumeric");function i(t,e){var r,i=Array.isArray(e);function o(t){return a(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(i?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=i?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=i?e.map(o):[o(e)]),r}function o(t){return function(e){e=i(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=i(t,e),end:1/0,size:1/0}}}e.exports={"[]":o("[]"),"][":o("]["),">":s(">"),"<":s("<"),"=":s("=")}},{"../../constants/filter_ops":689,"fast-isnumeric":228}],950:[function(t,e,r){"use strict";e.exports=function(t,e,r,n){var a=n("contours.start"),i=n("contours.end"),o=!1===a||!1===i,s=r("contours.size");!(o?e.autocontour=!0:r("autocontour",!1))&&s||r("ncontours")}},{}],951:[function(t,e,r){"use strict";var n=t("../../lib");function a(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths),starts:n.extendDeep([],t.starts)})}e.exports=function(t,e){var r,i,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case"=":case"<":return t;case">":for(1!==t.length&&n.warn("Contour data invalid for the specified inequality operation."),i=t[0],r=0;r<i.edgepaths.length;r++)i.edgepaths[r]=s(i.edgepaths[r]);for(r=0;r<i.paths.length;r++)i.paths[r]=s(i.paths[r]);for(r=0;r<i.starts.length;r++)i.starts[r]=s(i.starts[r]);return t;case"][":var c=s;s=l,l=c;case"[]":for(2!==t.length&&n.warn("Contour data invalid for the specified inequality range operation."),i=a(t[0]),o=a(t[1]),r=0;r<i.edgepaths.length;r++)i.edgepaths[r]=s(i.edgepaths[r]);for(r=0;r<i.paths.length;r++)i.paths[r]=s(i.paths[r]);for(r=0;r<i.starts.length;r++)i.starts[r]=s(i.starts[r]);for(;o.edgepaths.length;)i.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)i.paths.push(l(o.paths.shift()));for(;o.starts.length;)i.starts.push(l(o.starts.shift()));return[i]}}},{"../../lib":717}],952:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../heatmap/xyz_defaults"),i=t("./constraint_defaults"),o=t("./contours_defaults"),s=t("./style_defaults"),l=t("./attributes");e.exports=function(t,e,r,c){function u(r,a){return n.coerce(t,e,l,r,a)}if(a(t,e,u,c)){u("text"),u("hovertext"),u("hovertemplate"),u("hoverongaps");var h="constraint"===u("contours.type");u("connectgaps",n.isArray1D(e.z)),h?i(t,e,u,c,r):(o(t,e,u,function(r){return n.coerce2(t,e,l,r)}),s(t,e,u,c))}else e.visible=!1}},{"../../lib":717,"../heatmap/xyz_defaults":1014,"./attributes":943,"./constraint_defaults":948,"./contours_defaults":950,"./style_defaults":964}],953:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./constraint_mapping"),i=t("./end_plus");e.exports=function(t,e,r){for(var o="constraint"===t.type?a[t._operation](t.value):t,s=o.size,l=[],c=i(o),u=r.trace._carpetTrace,h=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},f=o.start;f<c;f+=s)if(l.push(n.extendFlat({level:f,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},h)),l.length>1e3){n.warn("Too many contours, clipping at 1000",t);break}return l}},{"../../lib":717,"./constraint_mapping":949,"./end_plus":954}],954:[function(t,e,r){"use strict";e.exports=function(t){return t.end+t.size/1e6}},{}],955:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./constants");function i(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(","),h=t.crossings[u],f=function(t,e,r){var n=0,i=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:i=0===r[1]?1:-1:-1!==a.BOTTOMSTART.indexOf(t)?i=1:-1!==a.LEFTSTART.indexOf(t)?n=1:-1!==a.TOPSTART.indexOf(t)?i=-1:n=-1;return[n,i]}(h,r,e),p=[s(t,e,[-f[0],-f[1]])],d=t.z.length,g=t.z[0].length,v=e.slice(),m=f.slice();for(c=0;c<1e4;c++){if(h>20?(h=a.CHOOSESADDLE[h][(f[0]||f[1])<0?0:1],t.crossings[u]=a.SADDLEREMAINDER[h]):delete t.crossings[u],!(f=a.NEWDELTA[h])){n.log("Found bad marching index:",h,e,t.level);break}p.push(s(t,e,f)),e[0]+=f[0],e[1]+=f[1],u=e.join(","),i(p[p.length-1],p[p.length-2],o,l)&&p.pop();var y=f[0]&&(e[0]<0||e[0]>g-2)||f[1]&&(e[1]<0||e[1]>d-2);if(e[0]===v[0]&&e[1]===v[1]&&f[0]===m[0]&&f[1]===m[1]||r&&y)break;h=t.crossings[u]}1e4===c&&n.log("Infinite loop in contour?");var x,b,_,w,k,T,M,A,S,E,L,C,P,O,z,I=i(p[0],p[p.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<p.length;c++)C=p[c],P=p[c-1],O=void 0,z=void 0,O=C[2]-P[2],z=C[3]-P[3],D+=M=Math.sqrt(O*O+z*z),F.push(M);var N=D/F.length*R;function j(t){return p[t%p.length]}for(c=p.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(I&&c===p.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];k=c-b+_+1,T=Math.floor((c+b+_+2)/2),w=I||c!==p.length-2?I||-1!==b?k%2?j(T):[(j(T)[0]+j(T+1)[0])/2,(j(T)[1]+j(T+1)[1])/2]:p[0]:p[p.length-1],p.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),I&&(c===p.length-2?p[_]=p[p.length-1]:0===c&&(p[p.length-1]=p[0]))}for(p.splice(0,B),c=0;c<p.length;c++)p[c].length=2;if(!(p.length<2))if(I)p.pop(),t.paths.push(p);else{r||n.log("Unclosed interior contour?",t.level,v.join(","),p.join("L"));var V=!1;for(A=0;A<t.edgepaths.length;A++)if(E=t.edgepaths[A],!V&&i(E[0],p[p.length-1],o,l)){p.pop(),V=!0;var U=!1;for(S=0;S<t.edgepaths.length;S++)if(i((L=t.edgepaths[S])[L.length-1],p[0],o,l)){U=!0,p.shift(),t.edgepaths.splice(A,1),S===A?t.paths.push(p.concat(L)):(S>A&&S--,t.edgepaths[S]=L.concat(p,E));break}U||(t.edgepaths[A]=p.concat(E))}for(A=0;A<t.edgepaths.length&&!V;A++)i((E=t.edgepaths[A])[E.length-1],p[0],o,l)&&(p.shift(),t.edgepaths[A]=E.concat(p),V=!0);V||t.edgepaths.push(p)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),a=e[1]+Math.max(r[1],0),i=t.z[a][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-i)/(t.z[a][n+1]-i);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[a],!0),n+l,a]}var c=(t.level-i)/(t.z[a+1][n]-i);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[a]+c*t.y[a+1],!0),n,a+c]}e.exports=function(t,e,r){var a,i,s,l;for(e=e||.01,r=r||.01,i=0;i<t.length;i++){for(s=t[i],l=0;l<s.starts.length;l++)o(s,s.starts[l],"edge",e,r);for(a=0;Object.keys(s.crossings).length&&a<1e4;)a++,o(s,Object.keys(s.crossings)[0].split(",").map(Number),void 0,e,r);1e4===a&&n.log("Infinite loop in contour?")}}},{"../../lib":717,"./constants":947}],956:[function(t,e,r){"use strict";var n=t("../../components/color"),a=t("../heatmap/hover");e.exports=function(t,e,r,i,o){var s=a(t,e,r,i,o,!0);return s&&s.forEach(function(t){var e=t.trace;"constraint"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))}),s}},{"../../components/color":591,"../heatmap/hover":1007}],957:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc"),plot:t("./plot").plot,style:t("./style"),colorbar:t("./colorbar"),hoverPoints:t("./hover"),moduleType:"trace",name:"contour",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","2dMap","contour","showLegend"],meta:{}}},{"../../plots/cartesian":776,"./attributes":943,"./calc":944,"./colorbar":946,"./defaults":952,"./hover":956,"./plot":961,"./style":963}],958:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e,r,a){if(a||(a={}),t("contours.showlabels")){var i=e.font;n.coerceFont(t,"contours.labelfont",{family:i.family,size:i.size,color:r}),t("contours.labelformat")}!1!==a.hasHover&&t("zhoverformat")}},{"../../lib":717}],959:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/colorscale"),i=t("./end_plus");e.exports=function(t){var e=t.contours,r=e.start,o=i(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c="lines"===e.coloring?0:1,u=a.extractOpts(t);isFinite(s)||(s=1,l=1);var h,f,p=u.reversescale?a.flipScale(u.colorscale):u.colorscale,d=p.length,g=new Array(d),v=new Array(d);if("heatmap"===e.coloring){var m=u.min,y=u.max;for(f=0;f<d;f++)h=p[f],g[f]=h[0]*(y-m)+m,v[f]=h[1];var x=n.extent([m,y,e.start,e.start+s*(l-1)]),b=x[m<y?0:1],_=x[m<y?1:0];b!==m&&(g.splice(0,0,b),v.splice(0,0,v[0])),_!==y&&(g.push(_),v.push(v[v.length-1]))}else for(f=0;f<d;f++)h=p[f],g[f]=(h[0]*(l+c-1)-c/2)*s+r,v[f]=h[1];return a.makeColorScaleFunc({domain:g,range:v},{noNumericCheck:!0})}},{"../../components/colorscale":603,"./end_plus":954,d3:165}],960:[function(t,e,r){"use strict";var n=t("./constants");function a(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,i,o,s,l,c,u,h,f=t[0].z,p=f.length,d=f[0].length,g=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(i=o.slice(),0===e&&(i=i.concat(n.LEFTSTART)),e===d-2&&(i=i.concat(n.RIGHTSTART)),s=e+","+r,l=[[f[r][e],f[r][e+1]],[f[r+1][e],f[r+1][e+1]]],h=0;h<t.length;h++)(c=a((u=t[h]).level,l))&&(u.crossings[s]=c,-1!==i.indexOf(c)&&(u.starts.push([e,r]),g&&-1!==i.indexOf(c,i.indexOf(c)+1)&&u.starts.push([e,r])))}},{"./constants":947}],961:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../components/drawing"),o=t("../../components/colorscale"),s=t("../../lib/svg_text_utils"),l=t("../../plots/cartesian/axes"),c=t("../../plots/cartesian/set_convert"),u=t("../heatmap/plot"),h=t("./make_crossings"),f=t("./find_all_paths"),p=t("./empty_pathinfo"),d=t("./convert_to_constraints"),g=t("./close_boundaries"),v=t("./constants"),m=v.LABELOPTIMIZER;function y(t,e){var r,n,o,s,l,c,u,h="",f=0,p=t.edgepaths.map(function(t,e){return e}),d=!0;function g(t){return Math.abs(t[1]-e[2][1])<.01}function v(t){return Math.abs(t[0]-e[0][0])<.01}function m(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=i.smoothopen(t.edgepaths[f],t.smoothing),h+=d?c:c.replace(/^M/,"L"),p.splice(p.indexOf(f),1),r=t.edgepaths[f][t.edgepaths[f].length-1],s=-1,o=0;o<4;o++){if(!r){a.log("Missing end?",f,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!m(r)?n=e[1]:v(r)?n=e[0]:g(r)?n=e[3]:m(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):a.log("endpt to newendpt is not vert. or horz.",r,n,y)}if(r=n,s>=0)break;h+="L"+n}if(s===t.edgepaths.length){a.log("unclosed perimeter path");break}f=s,(d=-1===p.indexOf(f))&&(f=p[0],h+="Z")}for(f=0;f<t.paths.length;f++)h+=i.smoothclosed(t.paths[f],t.smoothing);return h}function x(t,e,r,n){var i=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*i,h=Math.sin(c)*i,f=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(h)+Math.cos(c)*o);if(f<1||p<1)return 1/0;var d=m.EDGECOST*(1/(f-1)+1/(p-1));d+=m.ANGLECOST*c*c;for(var g=s-u,v=l-h,y=s+u,x=l+h,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,k=Math.sin(_.theta)*_.width/2,T=2*a.segmentDistance(g,v,y,x,_.x-w,_.y-k,_.x+w,_.y+k)/(e.height+_.height),M=_.level===e.level,A=M?m.SAMELEVELDISTANCE:1;if(T<=A)return 1/0;d+=m.NEIGHBORCOST*(M?m.SAMELEVELFACTOR:1)/(T-A)}return d}function b(t){var e,r,n=t.trace._emptypoints,a=[],i=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<i;e++)a.push(s.slice());for(e=0;e<n.length;e++)a[(r=n[e])[0]][r[1]]=0;return t.zmask=a,a}r.plot=function(t,e,o,s){var l=e.xaxis,c=e.yaxis;a.makeTraceGroups(s,o,"contour").each(function(o){var s=n.select(this),m=o[0],x=m.trace,_=m.x,w=m.y,k=x.contours,T=p(k,e,m),M=a.ensureSingle(s,"g","heatmapcoloring"),A=[];"heatmap"===k.coloring&&(A=[o]),u(t,e,A,M),h(T),f(T);var S=l.c2p(_[0],!0),E=l.c2p(_[_.length-1],!0),L=c.c2p(w[0],!0),C=c.c2p(w[w.length-1],!0),P=[[S,C],[E,C],[E,L],[S,L]],O=T;"constraint"===k.type&&(O=d(T,k._operation)),function(t,e,r){var n=a.ensureSingle(t,"g","contourbg").selectAll("path").data("fill"===r.coloring?[0]:[]);n.enter().append("path"),n.exit().remove(),n.attr("d","M"+e.join("L")+"Z").style("stroke","none")}(s,P,k),function(t,e,r,i){var o="fill"===i.coloring||"constraint"===i.type&&"="!==i._operation,s="M"+r.join("L")+"Z";o&&g(e,i);var l=a.ensureSingle(t,"g","contourfill").selectAll("path").data(o?e:[]);l.enter().append("path"),l.exit().remove(),l.each(function(t){var e=(t.prefixBoundary?s:"")+y(t,r);e?n.select(this).attr("d",e).style("stroke","none"):n.select(this).remove()})}(s,O,P,k),function(t,e,o,s,l){var c=a.ensureSingle(t,"g","contourlines"),u=!1!==l.showlines,h=l.showlabels,f=u&&h,p=r.createLines(c,u||h,e),d=r.createLineClip(c,f,o,s.trace.uid),g=t.selectAll("g.contourlabels").data(h?[0]:[]);if(g.exit().remove(),g.enter().append("g").classed("contourlabels",!0),h){var m=[],y=[];a.clearLocationCache();var x=r.labelFormatter(o,s),b=i.tester.append("text").attr("data-notex",1).call(i.font,l.labelfont),_=e[0].xaxis,w=e[0].yaxis,k=_._length,T=w._length,M=_.range,A=w.range,S=a.aggNums(Math.min,null,s.x),E=a.aggNums(Math.max,null,s.x),L=a.aggNums(Math.min,null,s.y),C=a.aggNums(Math.max,null,s.y),P=Math.max(_.c2p(S,!0),0),O=Math.min(_.c2p(E,!0),k),z=Math.max(w.c2p(C,!0),0),I=Math.min(w.c2p(L,!0),T),D={};M[0]<M[1]?(D.left=P,D.right=O):(D.left=O,D.right=P),A[0]<A[1]?(D.top=z,D.bottom=I):(D.top=I,D.bottom=z),D.middle=(D.top+D.bottom)/2,D.center=(D.left+D.right)/2,m.push([[D.left,D.top],[D.right,D.top],[D.right,D.bottom],[D.left,D.bottom]]);var R=Math.sqrt(k*k+T*T),F=v.LABELDISTANCE*R/Math.max(1,e.length/v.LABELINCREASE);p.each(function(t){var e=r.calcTextOpts(t.level,x,b,o);n.select(this).selectAll("path").each(function(){var t=a.getVisibleSegment(this,D,e.height/2);if(t&&!(t.len<(e.width+e.height)*v.LABELMIN))for(var n=Math.min(Math.ceil(t.len/F),v.LABELMAX),i=0;i<n;i++){var o=r.findBestTextLocation(this,t,e,y,D);if(!o)break;r.addLabelData(o,e,y,m)}})}),b.remove(),r.drawLabels(g,y,o,d,f?m:null)}h&&!u&&p.remove()}(s,T,t,m,k),function(t,e,r,n,o){var s=n.trace,l=r._fullLayout._clips,c="clip"+s.uid,u=l.selectAll("#"+c).data(s.connectgaps?[]:[0]);if(u.enter().append("clipPath").classed("contourclip",!0).attr("id",c),u.exit().remove(),!1===s.connectgaps){var p={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:b(n),smoothing:0};h([p]),f([p]),g([p],{type:"levels"});var d=a.ensureSingle(u,"path","");d.attr("d",(p.prefixBoundary?"M"+o.join("L")+"Z":"")+y(p,o))}else c=null;i.setClipUrl(t,c,r)}(s,e,t,m,P)})},r.createLines=function(t,e,r){var n=r[0].smoothing,a=t.selectAll("g.contourlevel").data(e?r:[]);if(a.exit().remove(),a.enter().append("g").classed("contourlevel",!0),e){var o=a.selectAll("path.openline").data(function(t){return t.pedgepaths||t.edgepaths});o.exit().remove(),o.enter().append("path").classed("openline",!0),o.attr("d",function(t){return i.smoothopen(t,n)}).style("stroke-miterlimit",1).style("vector-effect","non-scaling-stroke");var s=a.selectAll("path.closedline").data(function(t){return t.ppaths||t.paths});s.exit().remove(),s.enter().append("path").classed("closedline",!0),s.attr("d",function(t){return i.smoothclosed(t,n)}).style("stroke-miterlimit",1).style("vector-effect","non-scaling-stroke")}return a},r.createLineClip=function(t,e,r,n){var a=e?"clipline"+n:null,o=r._fullLayout._clips.selectAll("#"+a).data(e?[0]:[]);return o.exit().remove(),o.enter().append("clipPath").classed("contourlineclip",!0).attr("id",a),i.setClipUrl(t,a,r),o},r.labelFormatter=function(t,e){var r=t._fullLayout,n=e.trace,a=n.contours,i={type:"linear",_id:"ycontour",showexponent:"all",exponentformat:"B"};if(a.labelformat)i.tickformat=a.labelformat,c(i,r);else{var s=o.extractOpts(n);if(s&&s.colorbar&&s.colorbar._axis)i=s.colorbar._axis;else{if("constraint"===a.type){var u=a.value;Array.isArray(u)?i.range=[u[0],u[u.length-1]]:i.range=[u,u]}else i.range=[a.start,a.end],i.nticks=(a.end-a.start)/a.size;i.range[0]===i.range[1]&&(i.range[1]+=i.range[0]||1),i.nticks||(i.nticks=1e3),c(i,r),l.prepTicks(i),i._tmin=null,i._tmax=null}}return function(t){return l.tickText(i,t).text}},r.calcTextOpts=function(t,e,r,n){var a=e(t);r.text(a).call(s.convertToTspans,n);var o=r.node(),l=i.bBox(o,!0);return{text:a,width:l.width,height:l.height,fontSize:+o.style["font-size"].replace("px",""),level:t,dy:(l.top+l.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,i){var o,s,l,c,u,h=r.width;e.isClosed?(s=e.len/m.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-h)/(m.INITIALSEARCHPOINTS+1),o=e.min+s+h/2,l=e.max-(s+h)/2);for(var f=1/0,p=0;p<m.ITERATIONS;p++){for(var d=o;d<l;d+=s){var g=a.getTextLocation(t,e.total,d,h),v=x(g,r,n,i);v<f&&(f=v,u=g,c=d)}if(f>2*m.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(f<=m.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var a=e.fontSize,i=e.width+a/3,o=Math.max(0,e.height-a/3),s=t.x,l=t.y,c=t.theta,u=Math.sin(c),h=Math.cos(c),f=function(t,e){return[s+t*h-e*u,l+t*u+e*h]},p=[f(-i/2,-o/2),f(-i/2,o/2),f(i/2,o/2),f(i/2,-o/2)];r.push({text:e.text,x:s,y:l,dy:e.dy,theta:c,level:e.level,width:i,height:o}),n.push(p)},r.drawLabels=function(t,e,r,i,o){var l=t.selectAll("text").data(e,function(t){return t.text+","+t.x+","+t.y+","+t.theta});if(l.exit().remove(),l.enter().append("text").attr({"data-notex":1,"text-anchor":"middle"}).each(function(t){var e=t.x+Math.sin(t.theta)*t.dy,a=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:a,transform:"rotate("+180*t.theta/Math.PI+" "+e+" "+a+")"}).call(s.convertToTspans,r)}),o){for(var c="",u=0;u<o.length;u++)c+="M"+o[u].join("L")+"Z";a.ensureSingle(i,"path","").attr("d",c)}}},{"../../components/colorscale":603,"../../components/drawing":612,"../../lib":717,"../../lib/svg_text_utils":741,"../../plots/cartesian/axes":765,"../../plots/cartesian/set_convert":783,"../heatmap/plot":1011,"./close_boundaries":945,"./constants":947,"./convert_to_constraints":951,"./empty_pathinfo":953,"./find_all_paths":955,"./make_crossings":960,d3:165}],962:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../lib");function i(t,e,r){var a={type:"linear",range:[t,e]};return n.autoTicks(a,(e-t)/(r||15)),a}e.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=a.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=a.aggNums(Math.max,null,e));var l=i(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),a.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if("constraint"!==r.type){var c,u=r.start,h=r.end,f=t._input.contours;if(u>h&&(r.start=f.start=h,h=r.end=f.end=u,u=r.start),!(r.size>0))c=u===h?1:i(u,h,t.ncontours).dtick,f.size=r.size=c}}},{"../../lib":717,"../../plots/cartesian/axes":765}],963:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/drawing"),i=t("../heatmap/style"),o=t("./make_color_map");e.exports=function(t){var e=n.select(t).selectAll("g.contour");e.style("opacity",function(t){return t[0].trace.opacity}),e.each(function(t){var e=n.select(this),r=t[0].trace,i=r.contours,s=r.line,l=i.size||1,c=i.start,u="constraint"===i.type,h=!u&&"lines"===i.coloring,f=!u&&"fill"===i.coloring,p=h||f?o(r):null;e.selectAll("g.contourlevel").each(function(t){n.select(this).selectAll("path").call(a.lineGroupStyle,s.width,h?p(t.level):s.color,s.dash)});var d=i.labelfont;if(e.selectAll("g.contourlabels text").each(function(t){a.font(n.select(this),{family:d.family,size:d.size,color:d.color||(h?p(t.level):s.color)})}),u)e.selectAll("g.contourfill path").style("fill",r.fillcolor);else if(f){var g;e.selectAll("g.contourfill path").style("fill",function(t){return void 0===g&&(g=t.level),p(t.level+.5*l)}),void 0===g&&(g=c),e.selectAll("g.contourbg path").style("fill",p(g-.5*l))}}),i(t)}},{"../../components/drawing":612,"../heatmap/style":1012,"./make_color_map":959,d3:165}],964:[function(t,e,r){"use strict";var n=t("../../components/colorscale/defaults"),a=t("./label_defaults");e.exports=function(t,e,r,i,o){var s,l=r("contours.coloring"),c="";"fill"===l&&(s=r("contours.showlines")),!1!==s&&("lines"!==l&&(c=r("line.color","#000")),r("line.width",.5),r("line.dash")),"none"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,i,r,{prefix:"",cLetter:"z"})),r("line.smoothing"),a(r,i,c,o)}},{"../../components/colorscale/defaults":601,"./label_defaults":958}],965:[function(t,e,r){"use strict";var n=t("../heatmap/attributes"),a=t("../contour/attributes"),i=t("../../components/colorscale/attributes"),o=t("../../lib/extend").extendFlat,s=a.contours;e.exports=o({carpet:{valType:"string",editType:"calc"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:a.fillcolor,autocontour:a.autocontour,ncontours:a.ncontours,contours:{type:s.type,start:s.start,end:s.end,size:s.size,coloring:{valType:"enumerated",values:["fill","lines","none"],dflt:"fill",editType:"calc"},showlines:s.showlines,showlabels:s.showlabels,labelfont:s.labelfont,labelformat:s.labelformat,operation:s.operation,value:s.value,editType:"calc",impliedEdits:{autocontour:!1}},line:{color:a.line.color,width:a.line.width,dash:a.line.dash,smoothing:a.line.smoothing,editType:"plot"},transforms:void 0},i("",{cLetter:"z",autoColorDflt:!1}))},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../contour/attributes":943,"../heatmap/attributes":1e3}],966:[function(t,e,r){"use strict";var n=t("../../components/colorscale/calc"),a=t("../../lib"),i=t("../heatmap/convert_column_xyz"),o=t("../heatmap/clean_2d_array"),s=t("../heatmap/interp2d"),l=t("../heatmap/find_empties"),c=t("../heatmap/make_bound_array"),u=t("./defaults"),h=t("../carpet/lookup_carpetid"),f=t("../contour/set_contours");e.exports=function(t,e){var r=e._carpetTrace=h(t,e);if(r&&r.visible&&"legendonly"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var g=function(t,e){var r,u,h,f,p,d,g,v=e._carpetTrace,m=v.aaxis,y=v.baxis;m._minDtick=0,y._minDtick=0,a.isArray1D(e.z)&&i(e,m,y,"a","b",["z"]);r=e._a=e._a||e.a,f=e._b=e._b||e.b,r=r?m.makeCalcdata(e,"_a"):[],f=f?y.makeCalcdata(e,"_b"):[],u=e.a0||0,h=e.da||1,p=e.b0||0,d=e.db||1,g=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(g),s(g,e._emptypoints);var x=a.maxRowLength(g),b="scaled"===e.xtype?"":r,_=c(e,b,u,h,x,m),w="scaled"===e.ytype?"":f,k=c(e,w,p,d,g.length,y),T={a:_,b:k,z:g};"levels"===e.contours.type&&"none"!==e.contours.coloring&&n(t,e,{vals:g,containerStr:"",cLetter:"z"});return[T]}(t,e);return f(e,e._z),g}}},{"../../components/colorscale/calc":599,"../../lib":717,"../carpet/lookup_carpetid":916,"../contour/set_contours":962,"../heatmap/clean_2d_array":1002,"../heatmap/convert_column_xyz":1004,"../heatmap/find_empties":1006,"../heatmap/interp2d":1009,"../heatmap/make_bound_array":1010,"./defaults":967}],967:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../heatmap/xyz_defaults"),i=t("./attributes"),o=t("../contour/constraint_defaults"),s=t("../contour/contours_defaults"),l=t("../contour/style_defaults");e.exports=function(t,e,r,c){function u(r,a){return n.coerce(t,e,i,r,a)}if(u("carpet"),t.a&&t.b){if(!a(t,e,u,c,"a","b"))return void(e.visible=!1);u("text"),"constraint"===u("contours.type")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,function(r){return n.coerce2(t,e,i,r)}),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{"../../lib":717,"../contour/constraint_defaults":948,"../contour/contours_defaults":950,"../contour/style_defaults":964,"../heatmap/xyz_defaults":1014,"./attributes":965}],968:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../contour/colorbar"),calc:t("./calc"),plot:t("./plot"),style:t("../contour/style"),moduleType:"trace",name:"contourcarpet",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","carpet","contour","symbols","showLegend","hasLines","carpetDependent","noHover","noSortingByValue"],meta:{}}},{"../../plots/cartesian":776,"../contour/colorbar":946,"../contour/style":963,"./attributes":965,"./calc":966,"./defaults":967,"./plot":969}],969:[function(t,e,r){"use strict";var n=t("d3"),a=t("../carpet/map_1d_array"),i=t("../carpet/makepath"),o=t("../../components/drawing"),s=t("../../lib"),l=t("../contour/make_crossings"),c=t("../contour/find_all_paths"),u=t("../contour/plot"),h=t("../contour/constants"),f=t("../contour/convert_to_constraints"),p=t("../contour/empty_pathinfo"),d=t("../contour/close_boundaries"),g=t("../carpet/lookup_carpetid"),v=t("../carpet/axis_aligned_line");function m(t,e,r){var n=t.getPointAtLength(e),a=t.getPointAtLength(r),i=a.x-n.x,o=a.y-n.y,s=Math.sqrt(i*i+o*o);return[i/s,o/s]}function y(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function x(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,b){var _=e.xaxis,w=e.yaxis;s.makeTraceGroups(b,r,"contour").each(function(r){var b=n.select(this),k=r[0],T=k.trace,M=T._carpetTrace=g(t,T),A=t.calcdata[M.index][0];if(M.visible&&"legendonly"!==M.visible){var S=k.a,E=k.b,L=T.contours,C=p(L,e,k),P="constraint"===L.type,O=L._operation,z=P?"="===O?"lines":"fill":L.coloring,I=[[S[0],E[E.length-1]],[S[S.length-1],E[E.length-1]],[S[S.length-1],E[0]],[S[0],E[0]]];l(C);var D=1e-8*(S[S.length-1]-S[0]),R=1e-8*(E[E.length-1]-E[0]);c(C,D,R);var F,B,N,j,V=C;"constraint"===L.type&&(V=f(C,O)),function(t,e){var r,n,a,i,o,s,l,c,u;for(r=0;r<t.length;r++){for(i=t[r],o=i.pedgepaths=[],s=i.ppaths=[],n=0;n<i.edgepaths.length;n++){for(u=i.edgepaths[n],l=[],a=0;a<u.length;a++)l[a]=e(u[a]);o.push(l)}for(n=0;n<i.paths.length;n++){for(u=i.paths[n],c=[],a=0;a<u.length;a++)c[a]=e(u[a]);s.push(c)}}}(C,H);var U=[];for(j=A.clipsegments.length-1;j>=0;j--)F=A.clipsegments[j],B=a([],F.x,_.c2p),N=a([],F.y,w.c2p),B.reverse(),N.reverse(),U.push(i(B,N,F.bicubic));var q="M"+U.join("L")+"Z";!function(t,e,r,n,o,l){var c,u,h,f,p=s.ensureSingle(t,"g","contourbg").selectAll("path").data("fill"!==l||o?[]:[0]);p.enter().append("path"),p.exit().remove();var d=[];for(f=0;f<e.length;f++)c=e[f],u=a([],c.x,r.c2p),h=a([],c.y,n.c2p),d.push(i(u,h,c.bicubic));p.attr("d","M"+d.join("L")+"Z").style("stroke","none")}(b,A.clipsegments,_,w,P,z),function(t,e,r,a,i,l,c,u,h,f,p){var g="fill"===f;g&&d(i,t.contours);var m=s.ensureSingle(e,"g","contourfill").selectAll("path").data(g?i:[]);m.enter().append("path"),m.exit().remove(),m.each(function(t){var e=(t.prefixBoundary?p:"")+function(t,e,r,n,a,i,l,c){var u,h,f,p,d,g,m,y="",x=e.edgepaths.map(function(t,e){return e}),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function k(t){return Math.abs(t[1]-r[0][1])<w}function T(t){return Math.abs(t[1]-r[2][1])<w}function M(t){return Math.abs(t[0]-r[0][0])<_}function A(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,o,s,u="";for(k(t)&&!A(t)||T(t)&&!M(t)?(s=a.aaxis,o=v(a,i,[t[0],e[0]],.5*(t[1]+e[1]))):(s=a.baxis,o=v(a,i,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<o.length;r++)for(u+=s.smoothing?"C":"L",n=0;n<o[r].length;n++){var h=o[r][n];u+=[l.c2p(h[0]),c.c2p(h[1])]+" "}return u}u=0,h=null;for(;x.length;){var E=e.edgepaths[u][0];for(h&&(y+=S(h,E)),m=o.smoothopen(e.edgepaths[u].map(n),e.smoothing),y+=b?m:m.replace(/^M/,"L"),x.splice(x.indexOf(u),1),h=e.edgepaths[u][e.edgepaths[u].length-1],d=-1,p=0;p<4;p++){if(!h){s.log("Missing end?",u,e);break}for(k(h)&&!A(h)?f=r[1]:M(h)?f=r[0]:T(h)?f=r[3]:A(h)&&(f=r[2]),g=0;g<e.edgepaths.length;g++){var L=e.edgepaths[g][0];Math.abs(h[0]-f[0])<_?Math.abs(h[0]-L[0])<_&&(L[1]-h[1])*(f[1]-L[1])>=0&&(f=L,d=g):Math.abs(h[1]-f[1])<w?Math.abs(h[1]-L[1])<w&&(L[0]-h[0])*(f[0]-L[0])>=0&&(f=L,d=g):s.log("endpt to newendpt is not vert. or horz.",h,f,L)}if(d>=0)break;y+=S(h,f),h=f}if(d===e.edgepaths.length){s.log("unclosed perimeter path");break}u=d,(b=-1===x.indexOf(u))&&(u=x[0],y+=S(h,f)+"Z",h=null)}for(u=0;u<e.paths.length;u++)y+=o.smoothclosed(e.paths[u].map(n),e.smoothing);return y}(0,t,l,c,u,h,r,a);e?n.select(this).attr("d",e).style("stroke","none"):n.select(this).remove()})}(T,b,_,w,V,I,H,M,A,z,q),function(t,e,r,a,i,l,c){var f=s.ensureSingle(t,"g","contourlines"),p=!1!==i.showlines,d=i.showlabels,g=p&&d,v=u.createLines(f,p||d,e),b=u.createLineClip(f,g,r,a.trace.uid),_=t.selectAll("g.contourlabels").data(d?[0]:[]);if(_.exit().remove(),_.enter().append("g").classed("contourlabels",!0),d){var w=l.xaxis,k=l.yaxis,T=w._length,M=k._length,A=[[[0,0],[T,0],[T,M],[0,M]]],S=[];s.clearLocationCache();var E=u.labelFormatter(r,a),L=o.tester.append("text").attr("data-notex",1).call(o.font,i.labelfont),C={left:0,right:T,center:T/2,top:0,bottom:M,middle:M/2},P=Math.sqrt(T*T+M*M),O=h.LABELDISTANCE*P/Math.max(1,e.length/h.LABELINCREASE);v.each(function(t){var e=u.calcTextOpts(t.level,E,L,r);n.select(this).selectAll("path").each(function(r){var n=s.getVisibleSegment(this,C,e.height/2);if(n&&(function(t,e,r,n,a,i){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=a.a[0],c=a.a[a.a.length-1],u=a.b[0],h=a.b[a.b.length-1];function f(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=y(a.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,i*x(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-h)<.1)&&(r=y(a.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,i*x(e,r)/2)),n}var p=m(t,0,1),d=m(t,n.total,n.total-1),g=f(o[0],p),v=n.total-f(o[o.length-1],d);n.min<g&&(n.min=g);n.max>v&&(n.max=v);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*h.LABELMIN)))for(var a=Math.min(Math.ceil(n.len/O),h.LABELMAX),i=0;i<a;i++){var o=u.findBestTextLocation(this,n,e,S,C);if(!o)break;u.addLabelData(o,e,S,A)}})}),L.remove(),u.drawLabels(_,S,r,b,g?A:null)}d&&!p&&v.remove()}(b,C,t,k,L,e,M),o.setClipUrl(b,M._clipPathId,t)}function H(t){var e=M.ab2xy(t[0],t[1],!0);return[_.c2p(e[0]),w.c2p(e[1])]}})}},{"../../components/drawing":612,"../../lib":717,"../carpet/axis_aligned_line":900,"../carpet/lookup_carpetid":916,"../carpet/makepath":917,"../carpet/map_1d_array":918,"../contour/close_boundaries":945,"../contour/constants":947,"../contour/convert_to_constraints":951,"../contour/empty_pathinfo":953,"../contour/find_all_paths":955,"../contour/make_crossings":960,"../contour/plot":961,d3:165}],970:[function(t,e,r){"use strict";var n=t("../../components/colorscale/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../../plots/attributes"),o=t("../scattermapbox/attributes"),s=t("../../lib/extend").extendFlat;e.exports=s({lon:o.lon,lat:o.lat,z:{valType:"data_array",editType:"calc"},radius:{valType:"number",editType:"plot",arrayOk:!0,min:1,dflt:30},below:{valType:"string",editType:"plot"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},i.hoverinfo,{flags:["lon","lat","z","text","name"]}),hovertemplate:a(),showlegend:s({},i.showlegend,{dflt:!1})},n("",{cLetter:"z",editTypeOverride:"calc"}))},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plots/attributes":762,"../../plots/template_attributes":841,"../scattermapbox/attributes":1184}],971:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib").isArrayOrTypedArray,i=t("../../constants/numerical").BADNUM,o=t("../../components/colorscale/calc"),s=t("../../lib")._;e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=a(c)&&c.length,h=0;h<r;h++){var f=l[h]={},p=e.lon[h],d=e.lat[h];if(f.lonlat=n(p)&&n(d)?[+p,+d]:[i,i],u){var g=c[h];f.z=n(g)?g:i}}return o(t,e,{vals:u?c:[0,1],containerStr:"",cLetter:"z"}),r&&(l[0].t={labels:{lat:s(t,"lat:")+" ",lon:s(t,"lon:")+" "}}),l}},{"../../components/colorscale/calc":599,"../../constants/numerical":693,"../../lib":717,"fast-isnumeric":228}],972:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../components/color"),o=t("../../components/colorscale"),s=t("../../constants/numerical").BADNUM,l=t("../../lib/geojson_utils").makeBlank;e.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:"none"},paint:{}},geojson:l()};if(!r)return c;var u,h=[],f=e.z,p=e.radius,d=a.isArrayOrTypedArray(f)&&f.length,g=a.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var v=t[u],m=v.lonlat;if(m[0]!==s){var y={};if(d){var x=v.z;y.z=x!==s?x:0}g&&(y.r=n(p[u])&&p[u]>0?+p[u]:0),h.push({type:"Feature",geometry:{type:"Point",coordinates:m},properties:y})}}var b=o.extractOpts(e),_=b.reversescale?o.flipScale(b.colorscale):b.colorscale,w=_[0][1],k=["interpolate",["linear"],["heatmap-density"],0,i.opacity(w)<1?w:i.addOpacity(w,0)];for(u=1;u<_.length;u++)k.push(_[u][0],_[u][1]);var T=["interpolate",["linear"],["get","z"],b.min,0,b.max,1];return a.extendFlat(c.heatmap.paint,{"heatmap-weight":d?T:1/(b.max-b.min),"heatmap-color":k,"heatmap-radius":g?{type:"identity",property:"r"}:e.radius,"heatmap-opacity":e.opacity}),c.geojson={type:"FeatureCollection",features:h},c.heatmap.layout.visibility="visible",c}},{"../../components/color":591,"../../components/colorscale":603,"../../constants/numerical":693,"../../lib":717,"../../lib/geojson_utils":712,"fast-isnumeric":228}],973:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/colorscale/defaults"),i=t("./attributes");e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}var l=s("lon")||[],c=s("lat")||[],u=Math.min(l.length,c.length);u?(e._length=u,s("z"),s("radius"),s("below"),s("text"),s("hovertext"),s("hovertemplate"),a(t,e,o,s,{prefix:"",cLetter:"z"})):e.visible=!1}},{"../../components/colorscale/defaults":601,"../../lib":717,"./attributes":970}],974:[function(t,e,r){"use strict";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},{}],975:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../scattermapbox/hover");e.exports=function(t,e,r){var o=i(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,"z"in u){var h=s.subplot.mockAxis;s.z=u.z,s.zLabel=a.tickText(h,h.c2l(u.z),"hover").text}return s.extraText=function(t,e,r){if(t.hovertemplate)return;var a=(e.hi||t.hoverinfo).split("+"),i=-1!==a.indexOf("all"),o=-1!==a.indexOf("lon"),s=-1!==a.indexOf("lat"),l=e.lonlat,c=[];function u(t){return t+"\xb0"}i||o&&s?c.push("("+u(l[0])+", "+u(l[1])+")"):o?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(i||-1!==a.indexOf("text"))&&n.fillText(e,t,c);return c.join("<br>")}(c,u,l[0].t.labels),[s]}}},{"../../lib":717,"../../plots/cartesian/axes":765,"../scattermapbox/hover":1189}],976:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../heatmap/colorbar"),formatLabels:t("../scattermapbox/format_labels"),calc:t("./calc"),plot:t("./plot"),hoverPoints:t("./hover"),eventData:t("./event_data"),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var a=r[n],i=a.id;if("symbol"===a.type&&"string"==typeof i&&-1===i.indexOf("plotly-"))return i}},moduleType:"trace",name:"densitymapbox",basePlotModule:t("../../plots/mapbox"),categories:["mapbox","gl","showLegend"],meta:{hr_name:"density_mapbox"}}},{"../../plots/mapbox":820,"../heatmap/colorbar":1003,"../scattermapbox/format_labels":1188,"./attributes":970,"./calc":971,"./defaults":973,"./event_data":974,"./hover":975,"./plot":977}],977:[function(t,e,r){"use strict";var n=t("./convert"),a=t("../../plots/mapbox/constants").traceLayerPrefix;function i(t,e){this.type="densitymapbox",this.subplot=t,this.uid=e,this.sourceId="source-"+e,this.layerList=[["heatmap",a+e+"-heatmap"]],this.below=null}var o=i.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,a=n(t),i=e.belowLookup["trace-"+this.uid];e.map.getSource(this.sourceId).setData(a.geojson),i!==this.below&&(this._removeLayers(),this._addLayers(a,i),this.below=i);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=a[l];e.setOptions(c,"setLayoutProperty",u.layout),"visible"===u.layout.visibility&&e.setOptions(c,"setPaintProperty",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,a=this.sourceId,i=0;i<n.length;i++){var o=n[i],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:a,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,a=new i(t,r.uid),o=a.sourceId,s=n(e),l=a.below=t.belowLookup["trace-"+r.uid];return t.map.addSource(o,{type:"geojson",data:s.geojson}),a._addLayers(s,l),a}},{"../../plots/mapbox/constants":818,"./convert":972}],978:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,"tx"),n.mergeArray(e.hovertext,t,"htx");var a=e.marker;if(a){n.mergeArray(a.opacity,t,"mo"),n.mergeArray(a.color,t,"mc");var i=a.line;i&&(n.mergeArray(i.color,t,"mlc"),n.mergeArrayCastPositive(i.width,t,"mlw"))}}},{"../../lib":717}],979:[function(t,e,r){"use strict";var n=t("../bar/attributes"),a=t("../scatter/attributes").line,i=t("../../plots/attributes"),o=t("../../plots/template_attributes").hovertemplateAttrs,s=t("../../plots/template_attributes").texttemplateAttrs,l=t("./constants"),c=t("../../lib/extend").extendFlat,u=t("../../components/color");e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:l.eventDataKeys}),hoverinfo:c({},i.hoverinfo,{flags:["name","x","y","text","percent initial","percent previous","percent total"]}),textinfo:{valType:"flaglist",flags:["label","text","percent initial","percent previous","percent total","value"],extras:["none"],editType:"plot",arrayOk:!1},texttemplate:s({editType:"plot"},{keys:l.eventDataKeys.concat(["label","value"])}),text:n.text,textposition:c({},n.textposition,{dflt:"auto"}),insidetextanchor:c({},n.insidetextanchor,{dflt:"middle"}),textangle:c({},n.textangle,{dflt:0}),textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:c({},n.orientation,{}),offset:c({},n.offset,{arrayOk:!1}),width:c({},n.width,{arrayOk:!1}),marker:n.marker,connector:{fillcolor:{valType:"color",editType:"style"},line:{color:c({},a.color,{dflt:u.defaultLine}),width:c({},a.width,{dflt:0,editType:"plot"}),dash:a.dash,editType:"style"},visible:{valType:"boolean",dflt:!0,editType:"plot"},editType:"plot"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{"../../components/color":591,"../../lib/extend":708,"../../plots/attributes":762,"../../plots/template_attributes":841,"../bar/attributes":856,"../scatter/attributes":1120,"./constants":981}],980:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("./arrays_to_calcdata"),i=t("../scatter/calc_selection"),o=t("../../constants/numerical").BADNUM;function s(t){return t===o?0:t}e.exports=function(t,e){var r,l,c,u,h=n.getFromId(t,e.xaxis||"x"),f=n.getFromId(t,e.yaxis||"y");"h"===e.orientation?(r=h.makeCalcdata(e,"x"),l=f.makeCalcdata(e,"y")):(r=f.makeCalcdata(e,"y"),l=h.makeCalcdata(e,"x"));var p,d=Math.min(l.length,r.length),g=new Array(d);for(e._base=[],c=0;c<d;c++){r[c]<0&&(r[c]=o);var v=!1;r[c]!==o&&c+1<d&&r[c+1]!==o&&(v=!0),u=g[c]={p:l[c],s:r[c],cNext:v},e._base[c]=-.5*u.s,e.ids&&(u.id=String(e.ids[c])),0===c&&(g[0].vTotal=0),g[0].vTotal+=s(u.s),u.begR=s(u.s)/s(g[0].s)}for(c=0;c<d;c++)(u=g[c]).s!==o&&(u.sumR=u.s/g[0].vTotal,u.difR=void 0!==p?u.s/p:1,p=u.s);return a(g,e),i(g,e),g}},{"../../constants/numerical":693,"../../plots/cartesian/axes":765,"../scatter/calc_selection":1122,"./arrays_to_calcdata":978}],981:[function(t,e,r){"use strict";e.exports={eventDataKeys:["percentInitial","percentPrevious","percentTotal"]}},{}],982:[function(t,e,r){"use strict";var n=t("../bar/cross_trace_calc").setGroupPositions;e.exports=function(t,e){var r,a,i=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(a=0;a<o.length;a++){var p=o[a],d="h"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&"funnel"===p.type&&(r=s[a],d?f.push(r):h.push(r),u.push(r))}var g={mode:i.funnelmode,norm:i.funnelnorm,gap:i.funnelgap,groupgap:i.funnelgroupgap};for(n(t,l,c,h,g),n(t,c,l,f,g),a=0;a<u.length;a++){r=u[a];for(var v=0;v<r.length;v++)v+1<r.length&&(r[v].nextP0=r[v+1].p0,r[v].nextS0=r[v+1].s0,r[v].nextP1=r[v+1].p1,r[v].nextS1=r[v+1].s1)}}},{"../bar/cross_trace_calc":859}],983:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../bar/defaults").handleGroupingDefaults,i=t("../bar/defaults").handleText,o=t("../scatter/xy_defaults"),s=t("./attributes"),l=t("../../components/color");e.exports={supplyDefaults:function(t,e,r,a){function c(r,a){return n.coerce(t,e,s,r,a)}if(o(t,e,a,c)){c("orientation",e.y&&!e.x?"v":"h"),c("offset"),c("width");var u=c("text");c("hovertext"),c("hovertemplate");var h=c("textposition");i(t,e,a,c,h,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),"none"===e.textposition||e.texttemplate||c("textinfo",Array.isArray(u)?"text+value":"value");var f=c("marker.color",r);c("marker.line.color",l.defaultLine),c("marker.line.width"),c("connector.visible")&&(c("connector.fillcolor",function(t){var e=n.isArrayOrTypedArray(t)?"#000":t;return l.addOpacity(e,.5*l.opacity(e))}(f)),c("connector.line.width")&&(c("connector.line.color"),c("connector.line.dash")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,i;function o(t){return n.coerce(i._input,i,s,t)}if("group"===e.funnelmode)for(var l=0;l<t.length;l++)r=(i=t[l])._input,a(r,i,e,o)}}},{"../../components/color":591,"../../lib":717,"../bar/defaults":860,"../scatter/xy_defaults":1146,"./attributes":979}],984:[function(t,e,r){"use strict";e.exports=function(t,e){return t.x="xVal"in e?e.xVal:e.x,t.y="yVal"in e?e.yVal:e.y,"percentInitial"in e&&(t.percentInitial=e.percentInitial),"percentPrevious"in e&&(t.percentPrevious=e.percentPrevious),"percentTotal"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],985:[function(t,e,r){"use strict";var n=t("../../components/color").opacity,a=t("../bar/hover").hoverOnBars,i=t("../../lib").formatPercent;e.exports=function(t,e,r,o){var s=a(t,e,r,o);if(s){var l=s.cd,c=l[0].trace,u="h"===c.orientation,h=l[s.index];s[(u?"x":"y")+"LabelVal"]=h.s,s.percentInitial=h.begR,s.percentInitialLabel=i(h.begR,1),s.percentPrevious=h.difR,s.percentPreviousLabel=i(h.difR,1),s.percentTotal=h.sumR,s.percentTotalLabel=i(h.sumR,1);var f=h.hi||c.hoverinfo,p=[];if(f&&"none"!==f&&"skip"!==f){var d="all"===f,g=f.split("+"),v=function(t){return d||-1!==g.indexOf(t)};v("percent initial")&&p.push(s.percentInitialLabel+" of initial"),v("percent previous")&&p.push(s.percentPreviousLabel+" of previous"),v("percent total")&&p.push(s.percentTotalLabel+" of total")}return s.extraText=p.join("<br>"),s.color=function(t,e){var r=t.marker,a=e.mc||r.color,i=e.mlc||r.line.color,o=e.mlw||r.line.width;if(n(a))return a;if(n(i)&&o)return i}(c,h),[s]}}},{"../../components/color":591,"../../lib":717,"../bar/hover":863}],986:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults").supplyDefaults,crossTraceDefaults:t("./defaults").crossTraceDefaults,supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc"),crossTraceCalc:t("./cross_trace_calc"),plot:t("./plot"),style:t("./style").style,hoverPoints:t("./hover"),eventData:t("./event_data"),selectPoints:t("../bar/select"),moduleType:"trace",name:"funnel",basePlotModule:t("../../plots/cartesian"),categories:["bar-like","cartesian","svg","oriented","showLegend","zoomScale"],meta:{}}},{"../../plots/cartesian":776,"../bar/select":868,"./attributes":979,"./calc":980,"./cross_trace_calc":982,"./defaults":983,"./event_data":984,"./hover":985,"./layout_attributes":987,"./layout_defaults":988,"./plot":989,"./style":990}],987:[function(t,e,r){"use strict";e.exports={funnelmode:{valType:"enumerated",values:["stack","group","overlay"],dflt:"stack",editType:"calc"},funnelgap:{valType:"number",min:0,max:1,editType:"calc"},funnelgroupgap:{valType:"number",min:0,max:1,dflt:0,editType:"calc"}}},{}],988:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e,r){var i=!1;function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&"funnel"===l.type){i=!0;break}}i&&(o("funnelmode"),o("funnelgap",.2),o("funnelgroupgap"))}},{"../../lib":717,"./layout_attributes":987}],989:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../components/drawing"),o=t("../../constants/numerical").BADNUM,s=t("../bar/plot"),l=t("../bar/uniform_text").clearMinTextSize;function c(t,e,r,n){var a=[],i=[],o=n?e:r,s=n?r:e;return a[0]=o.c2p(t.s0,!0),i[0]=s.c2p(t.p0,!0),a[1]=o.c2p(t.s1,!0),i[1]=s.c2p(t.p1,!0),a[2]=o.c2p(t.nextS0,!0),i[2]=s.c2p(t.nextP0,!0),a[3]=o.c2p(t.nextS1,!0),i[3]=s.c2p(t.nextP1,!0),n?[a,i]:[i,a]}e.exports=function(t,e,r,u){var h=t._fullLayout;l("funnel",h),function(t,e,r,s){var l=e.xaxis,u=e.yaxis;a.makeTraceGroups(s,r,"trace bars").each(function(r){var s=n.select(this),h=r[0].trace,f=a.ensureSingle(s,"g","regions");if(h.connector&&h.connector.visible){var p="h"===h.orientation,d=f.selectAll("g.region").data(a.identity);d.enter().append("g").classed("region",!0),d.exit().remove();var g=d.size();d.each(function(r,s){if(s===g-1||r.cNext){var h=c(r,l,u,p),f=h[0],d=h[1],v="";f[0]!==o&&d[0]!==o&&f[1]!==o&&d[1]!==o&&f[2]!==o&&d[2]!==o&&f[3]!==o&&d[3]!==o&&(v+=p?"M"+f[0]+","+d[1]+"L"+f[2]+","+d[2]+"H"+f[3]+"L"+f[1]+","+d[1]+"Z":"M"+f[1]+","+d[1]+"L"+f[2]+","+d[3]+"V"+d[2]+"L"+f[1]+","+d[0]+"Z"),""===v&&(v="M0,0Z"),a.ensureSingle(n.select(this),"path").attr("d",v).call(i.setClipUrl,e.layerClipId,t)}})}else f.remove()})}(t,e,r,u),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;a.makeTraceGroups(o,r,"trace bars").each(function(r){var o=n.select(this),u=r[0].trace,h=a.ensureSingle(o,"g","lines");if(u.connector&&u.connector.visible&&u.connector.line.width){var f="h"===u.orientation,p=h.selectAll("g.line").data(a.identity);p.enter().append("g").classed("line",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=c(r,s,l,f),h=u[0],p=u[1],g="";void 0!==h[3]&&void 0!==p[3]&&(f?(g+="M"+h[0]+","+p[1]+"L"+h[2]+","+p[2],g+="M"+h[1]+","+p[1]+"L"+h[3]+","+p[2]):(g+="M"+h[1]+","+p[1]+"L"+h[2]+","+p[3],g+="M"+h[1]+","+p[0]+"L"+h[2]+","+p[2])),""===g&&(g="M0,0Z"),a.ensureSingle(n.select(this),"path").attr("d",g).call(i.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,u),s.plot(t,e,r,u,{mode:h.funnelmode,norm:h.funnelmode,gap:h.funnelgap,groupgap:h.funnelgroupgap})}},{"../../components/drawing":612,"../../constants/numerical":693,"../../lib":717,"../bar/plot":867,"../bar/uniform_text":872,d3:165}],990:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/drawing"),i=t("../../components/color"),o=t("../../constants/interactions").DESELECTDIM,s=t("../bar/style"),l=t("../bar/uniform_text").resizeText,c=s.styleTextPoints;e.exports={style:function(t,e,r){var s=r||n.select(t).selectAll("g.funnellayer").selectAll("g.trace");l(t,s,"funnel"),s.style("opacity",function(t){return t[0].trace.opacity}),s.each(function(e){var r=n.select(this),s=e[0].trace;r.selectAll(".point > path").each(function(t){if(!t.isBlank){var e=s.marker;n.select(this).call(i.fill,t.mc||e.color).call(i.stroke,t.mlc||e.line.color).call(a.dashLine,e.line.dash,t.mlw||e.line.width).style("opacity",s.selectedpoints&&!t.selected?o:1)}}),c(r,s,t),r.selectAll(".regions").each(function(){n.select(this).selectAll("path").style("stroke-width",0).call(i.fill,s.connector.fillcolor)}),r.selectAll(".lines").each(function(){var t=s.connector.line;a.lineGroupStyle(n.select(this).selectAll("path"),t.width,t.color,t.dash)})})}}},{"../../components/color":591,"../../components/drawing":612,"../../constants/interactions":692,"../bar/style":870,"../bar/uniform_text":872,d3:165}],991:[function(t,e,r){"use strict";var n=t("../pie/attributes"),a=t("../../plots/attributes"),i=t("../../plots/domain").attributes,o=t("../../plots/template_attributes").hovertemplateAttrs,s=t("../../plots/template_attributes").texttemplateAttrs,l=t("../../lib/extend").extendFlat;e.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:l({},n.marker.line.color,{dflt:null}),width:l({},n.marker.line.width,{dflt:1}),editType:"calc"},editType:"calc"},text:n.text,hovertext:n.hovertext,scalegroup:l({},n.scalegroup,{}),textinfo:l({},n.textinfo,{flags:["label","text","value","percent"]}),texttemplate:s({editType:"plot"},{keys:["label","color","value","text","percent"]}),hoverinfo:l({},a.hoverinfo,{flags:["label","text","value","percent","name"]}),hovertemplate:o({},{keys:["label","color","value","text","percent"]}),textposition:l({},n.textposition,{values:["inside","none"],dflt:"inside"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:l({},n.title.position,{values:["top left","top center","top right"],dflt:"top center"}),editType:"plot"},domain:i({name:"funnelarea",trace:!0,editType:"calc"}),aspectratio:{valType:"number",min:0,dflt:1,editType:"plot"},baseratio:{valType:"number",min:0,max:1,dflt:.333,editType:"plot"}}},{"../../lib/extend":708,"../../plots/attributes":762,"../../plots/domain":790,"../../plots/template_attributes":841,"../pie/attributes":1094}],992:[function(t,e,r){"use strict";var n=t("../../plots/plots");r.name="funnelarea",r.plot=function(t,e,a,i){n.plotBasePlot(r.name,t,e,a,i)},r.clean=function(t,e,a,i){n.cleanBasePlot(r.name,t,e,a,i)}},{"../../plots/plots":826}],993:[function(t,e,r){"use strict";var n=t("../pie/calc");e.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:"funnelarea"})}}},{"../pie/calc":1096}],994:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("../../plots/domain").defaults,o=t("../bar/defaults").handleText,s=t("../pie/defaults").handleLabelsAndValues;e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,a,r,i)}var u=c("labels"),h=c("values"),f=s(u,h),p=f.len;if(e._hasLabels=f.hasLabels,e._hasValues=f.hasValues,!e._hasLabels&&e._hasValues&&(c("label0"),c("dlabel")),p){e._length=p,c("marker.line.width")&&c("marker.line.color",l.paper_bgcolor),c("marker.colors"),c("scalegroup");var d,g=c("text"),v=c("texttemplate");if(v||(d=c("textinfo",Array.isArray(g)?"text+percent":"percent")),c("hovertext"),c("hovertemplate"),v||d&&"none"!==d){var m=c("textposition");o(t,e,l,c,m,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}i(e,l,c),c("title.text")&&(c("title.position"),n.coerceFont(c,"title.font",l.font)),c("aspectratio"),c("baseratio")}else e.visible=!1}},{"../../lib":717,"../../plots/domain":790,"../bar/defaults":860,"../pie/defaults":1097,"./attributes":991}],995:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"funnelarea",basePlotModule:t("./base_plot"),categories:["pie-like","funnelarea","showLegend"],attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults"),supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc").calc,crossTraceCalc:t("./calc").crossTraceCalc,plot:t("./plot"),style:t("./style"),styleOne:t("../pie/style_one"),meta:{}}},{"../pie/style_one":1105,"./attributes":991,"./base_plot":992,"./calc":993,"./defaults":994,"./layout_attributes":996,"./layout_defaults":997,"./plot":998,"./style":999}],996:[function(t,e,r){"use strict";var n=t("../pie/layout_attributes").hiddenlabels;e.exports={hiddenlabels:n,funnelareacolorway:{valType:"colorlist",editType:"calc"},extendfunnelareacolors:{valType:"boolean",dflt:!0,editType:"calc"}}},{"../pie/layout_attributes":1101}],997:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r("hiddenlabels"),r("funnelareacolorway",e.colorway),r("extendfunnelareacolors")}},{"../../lib":717,"./layout_attributes":996}],998:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/drawing"),i=t("../../lib"),o=t("../../lib/svg_text_utils"),s=t("../bar/plot").toMoveInsideBar,l=t("../bar/uniform_text"),c=l.recordMinTextSize,u=l.clearMinTextSize,h=t("../pie/helpers"),f=t("../pie/plot"),p=f.attachFxHandlers,d=f.determineInsideTextFont,g=f.layoutAreas,v=f.prerenderTitles,m=f.positionTitleOutside,y=f.formatSliceLabel;function x(t,e){return"l"+(e[0]-t[0])+","+(e[1]-t[1])}e.exports=function(t,e){var r=t._fullLayout;u("funnelarea",r),v(e,t),g(e,r._size),i.makeTraceGroups(r._funnelarealayer,e,"trace").each(function(e){var l=n.select(this),u=e[0],f=u.trace;!function(t){if(!t.length)return;var e=t[0],r=e.trace,n=r.aspectratio,a=r.baseratio;a>.999&&(a=.999);var i,o=Math.pow(a,2),s=e.vTotal,l=s,c=s*o/(1-o)/s;function u(){var t,e={x:t=Math.sqrt(c),y:-t};return[e.x,e.y]}var h,f,p=[];for(p.push(u()),h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var d=f.v/l;c+=d,p.push(u())}var g=1/0,v=-1/0;for(h=0;h<p.length;h++)i=p[h],g=Math.min(g,i[1]),v=Math.max(v,i[1]);for(h=0;h<p.length;h++)p[h][1]-=(v+g)/2;var m=p[p.length-1][0],y=e.r,x=(v-g)/2,b=y/m,_=y/x*n;for(e.r=_*x,h=0;h<p.length;h++)p[h][0]*=b,p[h][1]*=_;var w=[-(i=p[0])[0],i[1]],k=[i[0],i[1]],T=0;for(h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var M=p[T+=1][0],A=p[T][1];f.TL=[-M,A],f.TR=[M,A],f.BL=w,f.BR=k,f.pxmid=(S=f.TR,E=f.BR,[.5*(S[0]+E[0]),.5*(S[1]+E[1])]),w=f.TL,k=f.TR}var S,E}(e),l.each(function(){var l=n.select(this).selectAll("g.slice").data(e);l.enter().append("g").classed("slice",!0),l.exit().remove(),l.each(function(l,g){if(l.hidden)n.select(this).selectAll("path,g").remove();else{l.pointNumber=l.i,l.curveNumber=f.index;var v=u.cx,m=u.cy,b=n.select(this),_=b.selectAll("path.surface").data([l]);_.enter().append("path").classed("surface",!0).style({"pointer-events":"all"}),b.call(p,t,e);var w="M"+(v+l.TR[0])+","+(m+l.TR[1])+x(l.TR,l.BR)+x(l.BR,l.BL)+x(l.BL,l.TL)+"Z";_.attr("d",w),y(t,l,u);var k=h.castOption(f.textposition,l.pts),T=b.selectAll("g.slicetext").data(l.text&&"none"!==k?[0]:[]);T.enter().append("g").classed("slicetext",!0),T.exit().remove(),T.each(function(){var u=i.ensureSingle(n.select(this),"text","",function(t){t.attr("data-notex",1)}),h=i.ensureUniformFontSize(t,d(f,l,r.font));u.text(l.text).attr({class:"slicetext",transform:"","text-anchor":"middle"}).call(a.font,h).call(o.convertToTspans,t);var p,y,x,b=a.bBox(u.node()),_=Math.min(l.BL[1],l.BR[1])+m,w=Math.max(l.TL[1],l.TR[1])+m;y=Math.max(l.TL[0],l.BL[0])+v,x=Math.min(l.TR[0],l.BR[0])+v,(p=s(y,x,_,w,b,{isHorizontal:!0,constrained:!0,angle:0,anchor:"middle"})).fontSize=h.size,c(f.type,p,r),e[g].transform=p,u.attr("transform",i.getTextTransform(p))})}});var g=n.select(this).selectAll("g.titletext").data(f.title.text?[0]:[]);g.enter().append("g").classed("titletext",!0),g.exit().remove(),g.each(function(){var e=i.ensureSingle(n.select(this),"text","",function(t){t.attr("data-notex",1)}),s=f.title.text;f._meta&&(s=i.templateString(s,f._meta)),e.text(s).attr({class:"titletext",transform:"","text-anchor":"middle"}).call(a.font,f.title.font).call(o.convertToTspans,t);var l=m(u,r._size);e.attr("transform","translate("+l.x+","+l.y+")"+(l.scale<1?"scale("+l.scale+")":"")+"translate("+l.tx+","+l.ty+")")})})})}},{"../../components/drawing":612,"../../lib":717,"../../lib/svg_text_utils":741,"../bar/plot":867,"../bar/uniform_text":872,"../pie/helpers":1099,"../pie/plot":1103,d3:165}],999:[function(t,e,r){"use strict";var n=t("d3"),a=t("../pie/style_one"),i=t("../bar/uniform_text").resizeText;e.exports=function(t){var e=t._fullLayout._funnelarealayer.selectAll(".trace");i(t,e,"funnelarea"),e.each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll("path.surface").each(function(t){n.select(this).call(a,t,e)})})}},{"../bar/uniform_text":872,"../pie/style_one":1105,d3:165}],1000:[function(t,e,r){"use strict";var n=t("../scatter/attributes"),a=t("../../plots/attributes"),i=t("../../plots/template_attributes").hovertemplateAttrs,o=t("../../components/colorscale/attributes"),s=(t("../../constants/docs").FORMAT_LINK,t("../../lib/extend").extendFlat);e.exports=s({z:{valType:"data_array",editType:"calc"},x:s({},n.x,{impliedEdits:{xtype:"array"}}),x0:s({},n.x0,{impliedEdits:{xtype:"scaled"}}),dx:s({},n.dx,{impliedEdits:{xtype:"scaled"}}),y:s({},n.y,{impliedEdits:{ytype:"array"}}),y0:s({},n.y0,{impliedEdits:{ytype:"scaled"}}),dy:s({},n.dy,{impliedEdits:{ytype:"scaled"}}),text:{valType:"data_array",editType:"calc"},hovertext:{valType:"data_array",editType:"calc"},transpose:{valType:"boolean",dflt:!1,editType:"calc"},xtype:{valType:"enumerated",values:["array","scaled"],editType:"calc+clearAxisTypes"},ytype:{valType:"enumerated",values:["array","scaled"],editType:"calc+clearAxisTypes"},zsmooth:{valType:"enumerated",values:["fast","best",!1],dflt:!1,editType:"calc"},hoverongaps:{valType:"boolean",dflt:!0,editType:"none"},connectgaps:{valType:"boolean",editType:"calc"},xgap:{valType:"number",dflt:0,min:0,editType:"plot"},ygap:{valType:"number",dflt:0,min:0,editType:"plot"},zhoverformat:{valType:"string",dflt:"",editType:"none"},hovertemplate:i(),showlegend:s({},a.showlegend,{dflt:!1})},{transforms:void 0},o("",{cLetter:"z",autoColorDflt:!1}))},{"../../components/colorscale/attributes":598,"../../constants/docs":688,"../../lib/extend":708,"../../plots/attributes":762,"../../plots/template_attributes":841,"../scatter/attributes":1120}],1001:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("../../plots/cartesian/axes"),o=t("../histogram2d/calc"),s=t("../../components/colorscale/calc"),l=t("./convert_column_xyz"),c=t("./clean_2d_array"),u=t("./interp2d"),h=t("./find_empties"),f=t("./make_bound_array");e.exports=function(t,e){var r,p,d,g,v,m,y,x,b,_=i.getFromId(t,e.xaxis||"x"),w=i.getFromId(t,e.yaxis||"y"),k=n.traceIs(e,"contour"),T=n.traceIs(e,"histogram"),M=n.traceIs(e,"gl2d"),A=k?"best":e.zsmooth;if(_._minDtick=0,w._minDtick=0,T)r=(b=o(t,e)).x,p=b.x0,d=b.dx,g=b.y,v=b.y0,m=b.dy,y=b.z;else{var S=e.z;a.isArray1D(S)?(l(e,_,w,"x","y",["z"]),r=e._x,g=e._y,S=e._z):(r=e._x=e.x?_.makeCalcdata(e,"x"):[],g=e._y=e.y?w.makeCalcdata(e,"y"):[]),p=e.x0,d=e.dx,v=e.y0,m=e.dy,y=c(S,e,_,w),(k||e.connectgaps)&&(e._emptypoints=h(y),u(y,e._emptypoints))}function E(t){A=e._input.zsmooth=e.zsmooth=!1,a.warn('cannot use zsmooth: "fast": '+t)}if("fast"===A)if("log"===_.type||"log"===w.type)E("log axis found");else if(!T){if(r.length){var L=(r[r.length-1]-r[0])/(r.length-1),C=Math.abs(L/100);for(x=0;x<r.length-1;x++)if(Math.abs(r[x+1]-r[x]-L)>C){E("x scale is not linear");break}}if(g.length&&"fast"===A){var P=(g[g.length-1]-g[0])/(g.length-1),O=Math.abs(P/100);for(x=0;x<g.length-1;x++)if(Math.abs(g[x+1]-g[x]-P)>O){E("y scale is not linear");break}}}var z=a.maxRowLength(y),I="scaled"===e.xtype?"":r,D=f(e,I,p,d,z,_),R="scaled"===e.ytype?"":g,F=f(e,R,v,m,y.length,w);M||(e._extremes[_._id]=i.findExtremes(_,D),e._extremes[w._id]=i.findExtremes(w,F));var B={x:D,y:F,z:y,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(I&&I.length===D.length-1&&(B.xCenter=I),R&&R.length===F.length-1&&(B.yCenter=R),T&&(B.xRanges=b.xRanges,B.yRanges=b.yRanges,B.pts=b.pts),k||s(t,e,{vals:y,cLetter:"z"}),k&&e.contours&&"heatmap"===e.contours.coloring){var N={type:"contour"===e.type?"heatmap":"histogram2d",xcalendar:e.xcalendar,ycalendar:e.ycalendar};B.xfill=f(N,I,p,d,z,_),B.yfill=f(N,R,v,m,y.length,w)}return[B]}},{"../../components/colorscale/calc":599,"../../lib":717,"../../plots/cartesian/axes":765,"../../registry":846,"../histogram2d/calc":1032,"./clean_2d_array":1002,"./convert_column_xyz":1004,"./find_empties":1006,"./interp2d":1009,"./make_bound_array":1010}],1002:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../constants/numerical").BADNUM;e.exports=function(t,e,r,o){var s,l,c,u,h,f;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,h=0;h<t.length;h++)s=Math.max(s,t[h].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===i||r===i?i:u(t,e,r)};function g(t){if(e&&"carpet"!==e.type&&"contourcarpet"!==e.type&&t&&"category"===t.type&&e["_"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e["_"+r+"CategoryMap"]||e[r];for(h=0;h<o.length;h++)n[o[h]]=h;return function(e){var r=n[t._categories[e]];return r+1?r:i}}return a.identity}var v=g(r),m=g(o);o&&"category"===o.type&&(s=o._categories.length);var y=new Array(s);for(h=0;h<s;h++)for(l=r&&"category"===r.type?r._categories.length:c(t,h),y[h]=new Array(l),f=0;f<l;f++)y[h][f]=p(d(t,m(h),v(f)));return y}},{"../../constants/numerical":693,"../../lib":717,"fast-isnumeric":228}],1003:[function(t,e,r){"use strict";e.exports={min:"zmin",max:"zmax"}},{}],1004:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../constants/numerical").BADNUM;e.exports=function(t,e,r,i,o,s){var l,c,u,h,f=t._length,p=e.makeCalcdata(t,i),d=r.makeCalcdata(t,o),g=t.text,v=void 0!==g&&n.isArray1D(g),m=t.hovertext,y=void 0!==m&&n.isArray1D(m),x=n.distinctVals(p),b=x.vals,_=n.distinctVals(d),w=_.vals,k=[];for(l=0;l<s.length;l++)k[l]=n.init2dArray(w.length,b.length);v&&(u=n.init2dArray(w.length,b.length)),y&&(h=n.init2dArray(w.length,b.length));var T=n.init2dArray(w.length,b.length);for(l=0;l<f;l++)if(p[l]!==a&&d[l]!==a){var M=n.findBin(p[l]+x.minDiff/2,b),A=n.findBin(d[l]+_.minDiff/2,w);for(c=0;c<s.length;c++){var S=t[s[c]];k[c][A][M]=S[l],T[A][M]=l}v&&(u[A][M]=g[l]),y&&(h[A][M]=m[l])}for(t["_"+i]=b,t["_"+o]=w,c=0;c<s.length;c++)t["_"+s[c]]=k[c];v&&(t._text=u),y&&(t._hovertext=h),e&&"category"===e.type&&(t["_"+i+"CategoryMap"]=b.map(function(t){return e._categories[t]})),r&&"category"===r.type&&(t["_"+o+"CategoryMap"]=w.map(function(t){return r._categories[t]})),t._after2before=T}},{"../../constants/numerical":693,"../../lib":717}],1005:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./xyz_defaults"),i=t("./style_defaults"),o=t("../../components/colorscale/defaults"),s=t("./attributes");e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,s,r,a)}a(t,e,c,l)?(c("text"),c("hovertext"),c("hovertemplate"),i(t,e,c,l),c("hoverongaps"),c("connectgaps",n.isArray1D(e.z)&&!1!==e.zsmooth),o(t,e,l,c,{prefix:"",cLetter:"z"})):e.visible=!1}},{"../../components/colorscale/defaults":601,"../../lib":717,"./attributes":1e3,"./style_defaults":1013,"./xyz_defaults":1014}],1006:[function(t,e,r){"use strict";var n=t("../../lib").maxRowLength;e.exports=function(t){var e,r,a,i,o,s,l,c,u=[],h={},f=[],p=t[0],d=[],g=[0,0,0],v=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],a=0;a<v;a++)void 0===d[a]&&((s=(void 0!==d[a-1]?1:0)+(void 0!==d[a+1]?1:0)+(void 0!==e[a]?1:0)+(void 0!==p[a]?1:0))?(0===r&&s++,0===a&&s++,r===t.length-1&&s++,a===d.length-1&&s++,s<4&&(h[[r,a]]=[r,a,s]),u.push([r,a,s])):f.push([r,a]));for(;f.length;){for(l={},c=!1,o=f.length-1;o>=0;o--)(s=((h[[(r=(i=f[o])[0])-1,a=i[1]]]||g)[2]+(h[[r+1,a]]||g)[2]+(h[[r,a-1]]||g)[2]+(h[[r,a+1]]||g)[2])/20)&&(l[i]=[r,a,s],f.splice(o,1),c=!0);if(!c)throw"findEmpties iterated with no new neighbors";for(i in l)h[i]=l[i],u.push(l[i])}return u.sort(function(t,e){return e[2]-t[2]})}},{"../../lib":717}],1007:[function(t,e,r){"use strict";var n=t("../../components/fx"),a=t("../../lib"),i=t("../../plots/cartesian/axes"),o=t("../../components/colorscale").extractOpts;e.exports=function(t,e,r,s,l,c){var u,h,f,p,d=t.cd[0],g=d.trace,v=t.xa,m=t.ya,y=d.x,x=d.y,b=d.z,_=d.xCenter,w=d.yCenter,k=d.zmask,T=g.zhoverformat,M=y,A=x;if(!1!==t.index){try{f=Math.round(t.index[1]),p=Math.round(t.index[0])}catch(e){return void a.error("Error hovering on heatmap, pointNumber must be [row,col], found:",t.index)}if(f<0||f>=b[0].length||p<0||p>b.length)return}else{if(n.inbox(e-y[0],e-y[y.length-1],0)>0||n.inbox(r-x[0],r-x[x.length-1],0)>0)return;if(c){var S;for(M=[2*y[0]-y[1]],S=1;S<y.length;S++)M.push((y[S]+y[S-1])/2);for(M.push([2*y[y.length-1]-y[y.length-2]]),A=[2*x[0]-x[1]],S=1;S<x.length;S++)A.push((x[S]+x[S-1])/2);A.push([2*x[x.length-1]-x[x.length-2]])}f=Math.max(0,Math.min(M.length-2,a.findBin(e,M))),p=Math.max(0,Math.min(A.length-2,a.findBin(r,A)))}var E=v.c2p(y[f]),L=v.c2p(y[f+1]),C=m.c2p(x[p]),P=m.c2p(x[p+1]);c?(L=E,u=y[f],P=C,h=x[p]):(u=_?_[f]:(y[f]+y[f+1])/2,h=w?w[p]:(x[p]+x[p+1])/2,v&&"category"===v.type&&(u=y[f]),m&&"category"===m.type&&(h=x[p]),g.zsmooth&&(E=L=v.c2p(u),C=P=m.c2p(h)));var O=b[p][f];if(k&&!k[p][f]&&(O=void 0),void 0!==O||g.hoverongaps){var z;Array.isArray(d.hovertext)&&Array.isArray(d.hovertext[p])?z=d.hovertext[p][f]:Array.isArray(d.text)&&Array.isArray(d.text[p])&&(z=d.text[p][f]);var I=o(g),D={type:"linear",range:[I.min,I.max],hoverformat:T,_separators:v._separators,_numFormat:v._numFormat},R=i.tickText(D,O,"hover").text;return[a.extendFlat(t,{index:g._after2before?g._after2before[p][f]:[p,f],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:E,x1:L,y0:C,y1:P,xLabelVal:u,yLabelVal:h,zLabelVal:O,zLabel:R,text:z})]}}},{"../../components/colorscale":603,"../../components/fx":630,"../../lib":717,"../../plots/cartesian/axes":765}],1008:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc"),plot:t("./plot"),colorbar:t("./colorbar"),style:t("./style"),hoverPoints:t("./hover"),moduleType:"trace",name:"heatmap",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","2dMap","showLegend"],meta:{}}},{"../../plots/cartesian":776,"./attributes":1e3,"./calc":1001,"./colorbar":1003,"./defaults":1005,"./hover":1007,"./plot":1011,"./style":1012}],1009:[function(t,e,r){"use strict";var n=t("../../lib"),a=[[-1,0],[1,0],[0,-1],[0,1]];function i(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,i,o,s,l,c,u,h,f,p,d,g,v,m=0;for(s=0;s<e.length;s++){for(i=(n=e[s])[0],o=n[1],d=t[i][o],p=0,f=0,l=0;l<4;l++)(u=t[i+(c=a[l])[0]])&&void 0!==(h=u[o+c[1]])&&(0===p?g=v=h:(g=Math.min(g,h),v=Math.max(v,h)),f++,p+=h);if(0===f)throw"iterateInterp2d order is wrong: no defined neighbors";t[i][o]=p/f,void 0===d?f<4&&(m=1):(t[i][o]=(1+r)*t[i][o]-r*d,v>g&&(m=Math.max(m,Math.abs(t[i][o]-d)/(v-g))))}return m}e.exports=function(t,e){var r,a=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&a>.01;r++)a=o(t,e,i(a));return a>.01&&n.log("interp2d didn't converge quickly",a),t}},{"../../lib":717}],1010:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib").isArrayOrTypedArray;e.exports=function(t,e,r,i,o,s){var l,c,u,h=[],f=n.traceIs(t,"contour"),p=n.traceIs(t,"histogram"),d=n.traceIs(t,"gl2d");if(a(e)&&e.length>1&&!p&&"category"!==s.type){var g=e.length;if(!(g<=o))return f?e.slice(0,o):e.slice(0,o+1);if(f||d)h=e.slice(0,o);else if(1===o)h=[e[0]-.5,e[0]+.5];else{for(h=[1.5*e[0]-.5*e[1]],u=1;u<g;u++)h.push(.5*(e[u-1]+e[u]));h.push(1.5*e[g-1]-.5*e[g-2])}if(g<o){var v=h[h.length-1],m=v-h[h.length-2];for(u=g;u<o;u++)v+=m,h.push(v)}}else{var y=t[s._id.charAt(0)+"calendar"];if(p)l=s.r2c(r,0,y);else if(a(e)&&1===e.length)l=e[0];else if(void 0===r)l=0;else{l=("log"===s.type?s.d2c:s.r2c)(r,0,y)}for(c=i||1,u=f||d?0:-.5;u<o;u++)h.push(l+c*u)}return h}},{"../../lib":717,"../../registry":846}],1011:[function(t,e,r){"use strict";var n=t("d3"),a=t("tinycolor2"),i=t("../../registry"),o=t("../../lib"),s=t("../../components/colorscale").makeColorScaleFuncFromTrace,l=t("../../constants/xmlns_namespaces");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),a=e[n],i=e[n+1],s=o.constrain(n+(t-a)/(i-a)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),a=e[n],i=(t-a)/(e[n+1]-a)||0;return i<=0?{bin0:n,bin1:n,frac:0}:i<.5?{bin0:n,bin1:n+1,frac:i}:{bin0:n+1,bin1:n,frac:1-i}}function h(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,f){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(f,r,"hm").each(function(e){var r,f,g,v,m,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,k=b.x,T=b.y,M=b.xCenter,A=b.yCenter,S=i.traceIs(_,"contour"),E=S?"best":_.zsmooth,L=w.length,C=o.maxRowLength(w),P=!1,O=!1;for(y=0;void 0===r&&y<k.length-1;)r=p.c2p(k[y]),y++;for(y=k.length-1;void 0===f&&y>0;)f=p.c2p(k[y]),y--;for(f<r&&(g=f,f=r,r=g,P=!0),y=0;void 0===v&&y<T.length-1;)v=d.c2p(T[y]),y++;for(y=T.length-1;void 0===m&&y>0;)m=d.c2p(T[y]),y--;if(m<v&&(g=v,v=m,m=g,O=!0),S&&(M=k,A=T,k=b.xfill,T=b.yfill),"fast"!==E){var z="best"===E?0:.5;r=Math.max(-z*p._length,r),f=Math.min((1+z)*p._length,f),v=Math.max(-z*d._length,v),m=Math.min((1+z)*d._length,m)}var I=Math.round(f-r),D=Math.round(m-v);if(I<=0||D<=0){x.selectAll("image").data([]).exit().remove()}else{var R,F;"fast"===E?(R=C,F=L):(R=I,F=D);var B=document.createElement("canvas");B.width=R,B.height=F;var N,j,V=B.getContext("2d"),U=s(_,{noNumericCheck:!0,returnArray:!0});"fast"===E?(N=P?function(t){return C-1-t}:o.identity,j=O?function(t){return L-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(k[t])-r),0,I)},j=function(t){return o.constrain(Math.round(d.c2p(T[t])-v),0,D)});var q,H,G,Y,W,X=j(0),Z=[X,X],J=P?0:1,K=O?0:1,Q=0,$=0,tt=0,et=0;if(E){var rt,nt=0;try{rt=new Uint8Array(I*D*4)}catch(t){rt=new Array(I*D*4)}if("best"===E){var at,it,ot,st=M||k,lt=A||T,ct=new Array(st.length),ut=new Array(lt.length),ht=new Array(I),ft=M?u:c,pt=A?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-v);for(y=0;y<I;y++)ht[y]=ft(y,ct);for(H=0;H<D;H++)for(it=w[(at=pt(H,ut)).bin0],ot=w[at.bin1],y=0;y<I;y++,nt+=4)h(rt,nt,W=Tt(it,ot,ht[y],at))}else for(H=0;H<L;H++)for(Y=w[H],Z=j(H),y=0;y<I;y++)W=kt(Y[y],1),h(rt,nt=4*(Z*I+N(y)),W);var dt=V.createImageData(I,D);try{dt.data.set(rt)}catch(t){var gt=dt.data,vt=gt.length;for(H=0;H<vt;H++)gt[H]=rt[H]}V.putImageData(dt,0,0)}else{var mt=_.xgap,yt=_.ygap,xt=Math.floor(mt/2),bt=Math.floor(yt/2);for(H=0;H<L;H++)if(Y=w[H],Z.reverse(),Z[K]=j(H+1),Z[0]!==Z[1]&&void 0!==Z[0]&&void 0!==Z[1])for(q=[G=N(0),G],y=0;y<C;y++)q.reverse(),q[J]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(W=kt(Y[y],(q[1]-q[0])*(Z[1]-Z[0])),V.fillStyle="rgba("+W.join(",")+")",V.fillRect(q[0]+xt,Z[0]+bt,q[1]-q[0]-mt,Z[1]-Z[0]-yt))}$=Math.round($/Q),tt=Math.round(tt/Q),et=Math.round(et/Q);var _t=a("rgb("+$+","+tt+","+et+")");t._hmpixcount=(t._hmpixcount||0)+Q,t._hmlumcount=(t._hmlumcount||0)+Q*_t.getLuminance();var wt=x.selectAll("image").data(e);wt.enter().append("svg:image").attr({xmlns:l.svg,preserveAspectRatio:"none"}),wt.attr({height:D,width:I,x:r,y:v,"xlink:href":B.toDataURL("image/png")})}function kt(t,e){if(void 0!==t){var r=U(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),Q+=e,$+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function Tt(t,e,r,n){var a=t[r.bin0];if(void 0===a)return kt(void 0,1);var i,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-a||0,u=s-a||0;return i=void 0===o?void 0===l?0:void 0===s?2*(l-a):2*(2*l-s-a)/3:void 0===l?void 0===s?0:2*(2*a-o-s)/3:void 0===s?2*(2*l-o-a)/3:l+a-o-s,kt(a+r.frac*c+n.frac*(u+r.frac*i))}})}},{"../../components/colorscale":603,"../../constants/xmlns_namespaces":694,"../../lib":717,"../../registry":846,d3:165,tinycolor2:535}],1012:[function(t,e,r){"use strict";var n=t("d3");e.exports=function(t){n.select(t).selectAll(".hm image").style("opacity",function(t){return t.trace.opacity})}},{d3:165}],1013:[function(t,e,r){"use strict";e.exports=function(t,e,r){!1===r("zsmooth")&&(r("xgap"),r("ygap")),r("zhoverformat")}},{}],1014:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../registry");function o(t,e){var r=e(t);return"scaled"===(r?e(t+"type","array"):"scaled")&&(e(t+"0"),e("d"+t)),r}e.exports=function(t,e,r,s,l,c){var u,h,f=r("z");if(l=l||"x",c=c||"y",void 0===f||!f.length)return 0;if(a.isArray1D(t.z)){u=r(l),h=r(c);var p=a.minRowLength(u),d=a.minRowLength(h);if(0===p||0===d)return 0;e._length=Math.min(p,d,f.length)}else{if(u=o(l,r),h=o(c,r),!function(t){for(var e,r=!0,i=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!a.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(i=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&i&&o}(f))return 0;r("transpose"),e._length=null}return i.getComponentMethod("calendars","handleTraceDefaults")(t,e,[l,c],s),!0}},{"../../lib":717,"../../registry":846,"fast-isnumeric":228}],1015:[function(t,e,r){"use strict";for(var n=t("../heatmap/attributes"),a=t("../../components/colorscale/attributes"),i=t("../../lib/extend").extendFlat,o=t("../../plot_api/edit_types").overrideAll,s=["z","x","x0","dx","y","y0","dy","text","transpose","xtype","ytype"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}i(l,a("",{cLetter:"z",autoColorDflt:!1})),e.exports=o(l,"calc","nested")},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plot_api/edit_types":748,"../heatmap/attributes":1e3}],1016:[function(t,e,r){"use strict";var n=t("gl-heatmap2d"),a=t("../../plots/cartesian/axes"),i=t("../../lib/str2rgbarray");function o(t,e){this.scene=t,this.uid=e,this.type="heatmapgl",this.name="",this.hoverinfo="all",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,a=n%r[0],i=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[a],e.y[i],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[i,a],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,a=e.length,o=new Array(a),s=new Array(4*a),l=0;l<a;l++){var c=e[l],u=i(c[1]);o[l]=r+c[0]*(n-r);for(var h=0;h<4;h++)s[4*l+h]=u[h]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c=this.scene.xaxis,u=this.scene.yaxis;t._extremes[c._id]=a.findExtremes(c,r.x),t._extremes[u._id]=a.findExtremes(u,r.y)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{"../../lib/str2rgbarray":740,"../../plots/cartesian/axes":765,"gl-heatmap2d":254}],1017:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("../heatmap/defaults"),colorbar:t("../heatmap/colorbar"),calc:t("../heatmap/calc"),plot:t("./convert"),moduleType:"trace",name:"heatmapgl",basePlotModule:t("../../plots/gl2d"),categories:["gl","gl2d","2dMap"],meta:{}}},{"../../plots/gl2d":803,"../heatmap/calc":1001,"../heatmap/colorbar":1003,"../heatmap/defaults":1005,"./attributes":1015,"./convert":1016}],1018:[function(t,e,r){"use strict";var n=t("../bar/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("./bin_attributes"),o=t("./constants"),s=t("../../lib/extend").extendFlat;e.exports={x:{valType:"data_array",editType:"calc+clearAxisTypes"},y:{valType:"data_array",editType:"calc+clearAxisTypes"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:"enumerated",values:["count","sum","avg","min","max"],dflt:"count",editType:"calc"},histnorm:{valType:"enumerated",values:["","percent","probability","density","probability density"],dflt:"",editType:"calc"},cumulative:{enabled:{valType:"boolean",dflt:!1,editType:"calc"},direction:{valType:"enumerated",values:["increasing","decreasing"],dflt:"increasing",editType:"calc"},currentbin:{valType:"enumerated",values:["include","exclude","half"],dflt:"include",editType:"calc"},editType:"calc"},nbinsx:{valType:"integer",min:0,dflt:0,editType:"calc"},xbins:i("x",!0),nbinsy:{valType:"integer",min:0,dflt:0,editType:"calc"},ybins:i("y",!0),autobinx:{valType:"boolean",dflt:null,editType:"calc"},autobiny:{valType:"boolean",dflt:null,editType:"calc"},bingroup:{valType:"string",dflt:"",editType:"calc"},hovertemplate:a({},{keys:o.eventDataKeys}),marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{"../../lib/extend":708,"../../plots/template_attributes":841,"../bar/attributes":856,"./bin_attributes":1020,"./constants":1024}],1019:[function(t,e,r){"use strict";e.exports=function(t,e){for(var r=t.length,n=0,a=0;a<r;a++)e[a]?(t[a]/=e[a],n+=t[a]):t[a]=null;return n}},{}],1020:[function(t,e,r){"use strict";e.exports=function(t,e){return{start:{valType:"any",editType:"calc"},end:{valType:"any",editType:"calc"},size:{valType:"any",editType:"calc"},editType:"calc"}}},{}],1021:[function(t,e,r){"use strict";var n=t("fast-isnumeric");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,a){var i=a[e];return n(i)?(i=Number(i),r[t]+=i,i):0},avg:function(t,e,r,a,i){var o=a[e];return n(o)&&(o=Number(o),r[t]+=o,i[t]++),0},min:function(t,e,r,a){var i=a[e];if(n(i)){if(i=Number(i),!n(r[t]))return r[t]=i,i;if(r[t]>i){var o=i-r[t];return r[t]=i,o}}return 0},max:function(t,e,r,a){var i=a[e];if(n(i)){if(i=Number(i),!n(r[t]))return r[t]=i,i;if(r[t]<i){var o=i-r[t];return r[t]=i,o}}return 0}}},{"fast-isnumeric":228}],1022:[function(t,e,r){"use strict";var n=t("../../constants/numerical"),a=n.ONEAVGYEAR,i=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t("../../plots/cartesian/axes").tickIncrement;function h(t,e,r,n){if(t*e<=0)return 1/0;for(var a=Math.abs(e-t),i="date"===r.type,o=f(a,i),s=0;s<10;s++){var l=f(80*o,i);if(o===l)break;if(!p(l,t,e,i,r,n))break;o=l}return o}function f(t,e){return e&&t>c?t>o?t>1.1*a?a:t>1.1*i?i:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,i,s){if(n&&t>o){var l=d(e,i,s),c=d(r,i,s),u=t===a?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,a,r).split("-");return""===n[0]&&(n.unshift(),n[0]="-"+n[0]),n}e.exports=function(t,e,r,n,i){var s,l,c=-1.1*e,f=-.1*e,p=t-f,d=r[0],g=r[1],v=Math.min(h(d+f,d+p,n,i),h(g+f,g+p,n,i)),m=Math.min(h(d+c,d+f,n,i),h(g+c,g+f,n,i));if(v>m&&m<Math.abs(g-d)/4e3?(s=v,l=!1):(s=Math.min(v,m),l=!0),"date"===n.type&&s>o){var y=s===a?1:6,x=s===a?"M12":"M1";return function(e,r){var o=n.c2d(e,a,i),s=o.indexOf("-",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,i);if(c<e){var h=u(c,x,!1,i);(c+h)/2<e+t&&(c=h)}return r&&l?u(c,x,!0,i):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{"../../constants/numerical":693,"../../plots/cartesian/axes":765}],1023:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../registry"),o=t("../../plots/cartesian/axes"),s=t("../bar/arrays_to_calcdata"),l=t("./bin_functions"),c=t("./norm_functions"),u=t("./average"),h=t("./bin_label_vals");function f(t,e,r,s,l){var c,u,h,p,d,g,v,m=s+"bins",y=t._fullLayout,x=e["_"+s+"bingroup"],b=y._histogramBinOpts[x],_="overlay"===y.barmode,w=function(t){return r.r2c(t,0,p)},k=function(t){return r.c2r(t,0,p)},T="date"===r.type?function(t){return t||0===t?a.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function M(t,e,r){e[t+"Found"]?(e[t]=T(e[t]),null===e[t]&&(e[t]=r[t])):(g[t]=e[t]=r[t],a.nestedProperty(u[0],m+"."+t).set(r[t]))}if(e["_"+s+"autoBinFinished"])delete e["_"+s+"autoBinFinished"];else{u=b.traces;var A=[],S=!0,E=!1,L=!1;for(c=0;c<u.length;c++)if((h=u[c]).visible){var C=b.dirs[c];d=h["_"+C+"pos0"]=r.makeCalcdata(h,C),A=a.concat(A,d),delete h["_"+s+"autoBinFinished"],!0===e.visible&&(S?S=!1:(delete h._autoBin,h["_"+s+"autoBinFinished"]=1),i.traceIs(h,"2dMap")&&(E=!0),"histogram2dcontour"===h.type&&(L=!0))}p=u[0][s+"calendar"];var P=o.autoBin(A,r,b.nbins,E,p,b.sizeFound&&b.size),O=u[0]._autoBin={};if(g=O[b.dirs[0]]={},L&&(b.size||(P.start=k(o.tickIncrement(w(P.start),P.size,!0,p))),void 0===b.end&&(P.end=k(o.tickIncrement(w(P.end),P.size,!1,p)))),_&&!i.traceIs(e,"2dMap")&&0===P._dataSpan&&"category"!==r.type&&"multicategory"!==r.type){if(l)return[P,d,!0];P=function(t,e,r,n,i){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,a=e.orientation,i=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];"histogram"===l.type&&!0===l.visible&&l.orientation===a&&l.xaxis===r&&l.yaxis===n&&i.push(l)}return i}(t,e),h=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)h=!0;else if(h){var g=f(t,s,r,n,!0),v=g[0],m=g[2];s["_"+n+"autoBinFinished"]=1,s["_"+n+"pos0"]=g[1],m?d.push(s):p=Math.min(p,v.size)}else l=c._histogramBinOpts[s["_"+n+"bingroup"]],p=Math.min(p,l.size||s[i].size);var y=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o]["_"+n+"pos0"],b=0;b<x.length;b++)if(void 0!==x[b]){y[o]=x[b];break}isFinite(p)||(p=a.distinctVals(y).minDiff);for(o=0;o<d.length;o++){var _=(s=d[o])[n+"calendar"],w={start:r.c2r(y[o]-p/2,0,_),end:r.c2r(y[o]+p/2,0,_),size:p};s._input[i]=s[i]=w,(l=c._histogramBinOpts[s["_"+n+"bingroup"]])&&a.extendFlat(l,w)}return e[i]}(t,e,r,s,m)}(v=h.cumulative||{}).enabled&&"include"!==v.currentbin&&("decreasing"===v.direction?P.start=k(o.tickIncrement(w(P.start),P.size,!0,p)):P.end=k(o.tickIncrement(w(P.end),P.size,!1,p))),b.size=P.size,b.sizeFound||(g.size=P.size,a.nestedProperty(u[0],m+".size").set(P.size)),M("start",b,P),M("end",b,P)}d=e["_"+s+"pos0"],delete e["_"+s+"pos0"];var z=e._input[m]||{},I=a.extendFlat({},b),D=b.start,R=r.r2l(z.start),F=void 0!==R;if((b.startFound||F)&&R!==r.r2l(D)){var B=F?R:a.aggNums(Math.min,null,d),N={type:"category"===r.type||"multicategory"===r.type?"linear":r.type,r2l:r.r2l,dtick:b.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,b.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,b.size,!0,p)),I.start=r.l2r(j),F||a.nestedProperty(e,m+".start").set(I.start)}var V=b.end,U=r.r2l(z.end),q=void 0!==U;if((b.endFound||q)&&U!==r.r2l(V)){var H=q?U:a.aggNums(Math.max,null,d);I.end=r.l2r(H),q||a.nestedProperty(e,m+".start").set(I.end)}var G="autobin"+s;return!1===e._input[G]&&(e._input[m]=a.extendFlat({},e[m]||{}),delete e._input[G],delete e[G]),[I,d]}e.exports={calc:function(t,e){var r,i,p,d,g=[],v=[],m=o.getFromId(t,"h"===e.orientation?e.yaxis:e.xaxis),y="h"===e.orientation?"y":"x",x={x:"y",y:"x"}[y],b=e[y+"calendar"],_=e.cumulative,w=f(t,e,m,y),k=w[0],T=w[1],M="string"==typeof k.size,A=[],S=M?A:k,E=[],L=[],C=[],P=0,O=e.histnorm,z=e.histfunc,I=-1!==O.indexOf("density");_.enabled&&I&&(O=O.replace(/ ?density$/,""),I=!1);var D,R="max"===z||"min"===z?null:0,F=l.count,B=c[O],N=!1,j=function(t){return m.r2c(t,0,b)};for(a.isArrayOrTypedArray(e[x])&&"count"!==z&&(D=e[x],N="avg"===z,F=l[z]),r=j(k.start),p=j(k.end)+(r-o.tickIncrement(r,k.size,!1,b))/1e6;r<p&&g.length<1e6&&(i=o.tickIncrement(r,k.size,!1,b),g.push((r+i)/2),v.push(R),C.push([]),A.push(r),I&&E.push(1/(i-r)),N&&L.push(0),!(i<=r));)r=i;A.push(r),M||"date"!==m.type||(S={start:j(S.start),end:j(S.end),size:S.size}),t._fullLayout._roundFnOpts||(t._fullLayout._roundFnOpts={});var V=e["_"+y+"bingroup"],U={leftGap:1/0,rightGap:1/0};V&&(t._fullLayout._roundFnOpts[V]||(t._fullLayout._roundFnOpts[V]=U),U=t._fullLayout._roundFnOpts[V]);var q,H=v.length,G=!0,Y=U.leftGap,W=U.rightGap,X={};for(r=0;r<T.length;r++){var Z=T[r];(d=a.findBin(Z,S))>=0&&d<H&&(P+=F(d,r,v,D,L),G&&C[d].length&&Z!==T[C[d][0]]&&(G=!1),C[d].push(r),X[r]=d,Y=Math.min(Y,Z-A[d]),W=Math.min(W,A[d+1]-Z))}U.leftGap=Y,U.rightGap=W,G||(q=function(e,r){return function(){var n=t._fullLayout._roundFnOpts[V];return h(n.leftGap,n.rightGap,A,m,b)(e,r)}}),N&&(P=u(v,L)),B&&B(v,P,E),_.enabled&&function(t,e,r){var n,a,i;function o(e){i=t[e],t[e]/=2}function s(e){a=t[e],t[e]=i+a/2,i+=a}if("half"===r)if("increasing"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if("increasing"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];"exclude"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];"exclude"===r&&(t.push(0),t.shift())}}(v,_.direction,_.currentbin);var J=Math.min(g.length,v.length),K=[],Q=0,$=J-1;for(r=0;r<J;r++)if(v[r]){Q=r;break}for(r=J-1;r>=Q;r--)if(v[r]){$=r;break}for(r=Q;r<=$;r++)if(n(g[r])&&n(v[r])){var tt={p:g[r],s:v[r],b:0};_.enabled||(tt.pts=C[r],G?tt.ph0=tt.ph1=C[r].length?T[C[r][0]]:g[r]:(e._computePh=!0,tt.ph0=q(A[r]),tt.ph1=q(A[r+1],!0))),K.push(tt)}return 1===K.length&&(K[0].width1=o.tickIncrement(K[0].p,k.size,!1,b)-K[0].p),s(K,e),a.isArrayOrTypedArray(e.selectedpoints)&&a.tagSelected(K,e,X),K},calcAllAutoBins:f}},{"../../lib":717,"../../plots/cartesian/axes":765,"../../registry":846,"../bar/arrays_to_calcdata":855,"./average":1019,"./bin_functions":1021,"./bin_label_vals":1022,"./norm_functions":1030,"fast-isnumeric":228}],1024:[function(t,e,r){"use strict";e.exports={eventDataKeys:["binNumber"]}},{}],1025:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axis_ids"),i=t("../../registry").traceIs,o=t("../bar/defaults").handleGroupingDefaults,s=n.nestedProperty,l=a.getAxisGroup,c=[{aStr:{x:"xbins.start",y:"ybins.start"},name:"start"},{aStr:{x:"xbins.end",y:"ybins.end"},name:"end"},{aStr:{x:"xbins.size",y:"ybins.size"},name:"size"},{aStr:{x:"nbinsx",y:"nbinsy"},name:"nbins"}],u=["x","y"];e.exports=function(t,e){var r,h,f,p,d,g,v,m=e._histogramBinOpts={},y=[],x={},b=[];function _(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function w(t){return"v"===t.orientation?"x":"y"}function k(t,r,i){var o=t.uid+"__"+i;r||(r=o);var s=function(t,r){return a.getFromTrace({_fullLayout:e},t,r).type}(t,i),l=t[i+"calendar"]||"",c=m[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(i)):(r=o,s!==c.axType&&n.warn(["Attempted to group the bins of trace",t.index,"set on a","type:"+s,"axis","with bins on","type:"+c.axType,"axis."].join(" ")),l!==c.calendar&&n.warn(["Attempted to group the bins of trace",t.index,"set with a",l,"calendar","with bins",c.calendar?"on a "+c.calendar+" calendar":"w/o a set calendar"].join(" ")))),u&&(m[r]={traces:[t],dirs:[i],axType:s,calendar:t[i+"calendar"]||""}),t["_"+i+"bingroup"]=r}for(d=0;d<t.length;d++)r=t[d],i(r,"histogram")&&(y.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,i(r,"2dMap")||o(r._input,r,e,_));var T=e._alignmentOpts||{};for(d=0;d<y.length;d++){if(r=y[d],f="",!i(r,"2dMap")){if(p=w(r),"group"===e.barmode&&r.alignmentgroup){var M=r[p+"axis"],A=l(e,M)+r.orientation;(T[A]||{})[r.alignmentgroup]&&(f=A)}f||"overlay"===e.barmode||(f=l(e,r.xaxis)+l(e,r.yaxis)+w(r))}f?(x[f]||(x[f]=[]),x[f].push(r)):b.push(r)}for(f in x)if(1!==(h=x[f]).length){var S=!1;for(d=0;d<h.length;d++){r=h[d],S=_("bingroup");break}for(f=S||f,d=0;d<h.length;d++){var E=(r=h[d])._input.bingroup;E&&E!==f&&n.warn(["Trace",r.index,"must match","within bingroup",f+".","Ignoring its bingroup:",E,"setting."].join(" ")),r.bingroup=f,k(r,f,w(r))}}else b.push(h[0]);for(d=0;d<b.length;d++){r=b[d];var L=_("bingroup");if(i(r,"2dMap"))for(v=0;v<2;v++){var C=_((p=u[v])+"bingroup",L?L+"__"+p:null);k(r,C,p)}else k(r,L,w(r))}for(f in m){var P=m[f];for(h=P.traces,g=0;g<c.length;g++){var O,z,I=c[g],D=I.name;if("nbins"!==D||!P.sizeFound){for(d=0;d<h.length;d++){if(r=h[d],p=P.dirs[d],O=I.aStr[p],void 0!==s(r._input,O).get()){P[D]=_(O),P[D+"Found"]=!0;break}(z=(r._autoBin||{})[p]||{})[D]&&s(r,O).set(z[D])}if("start"===D||"end"===D)for(;d<h.length;d++)(r=h[d])["_"+p+"bingroup"]&&_(O,(z=(r._autoBin||{})[p]||{})[D]);"nbins"!==D||P.sizeFound||P.nbinsFound||(r=h[0],P[D]=_(O))}}}}},{"../../lib":717,"../../plots/cartesian/axis_ids":768,"../../registry":846,"../bar/defaults":860}],1026:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("../../components/color"),o=t("../bar/style_defaults"),s=t("./attributes");e.exports=function(t,e,r,l){function c(r,n){return a.coerce(t,e,s,r,n)}var u=c("x"),h=c("y");c("cumulative.enabled")&&(c("cumulative.direction"),c("cumulative.currentbin")),c("text"),c("hovertext"),c("hovertemplate");var f=c("orientation",h&&!u?"h":"v"),p="v"===f?"x":"y",d="v"===f?"y":"x",g=u&&h?Math.min(a.minRowLength(u)&&a.minRowLength(h)):a.minRowLength(e[p]||[]);if(g){e._length=g,n.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x","y"],l),e[d]&&c("histfunc"),c("histnorm"),c("autobin"+p),o(t,e,c,r,l),a.coerceSelectionMarkerOpacity(e,c);var v=(e.marker.line||{}).color,m=n.getComponentMethod("errorbars","supplyDefaults");m(t,e,v||i.defaultLine,{axis:"y"}),m(t,e,v||i.defaultLine,{axis:"x",inherit:"y"})}else e.visible=!1}},{"../../components/color":591,"../../lib":717,"../../registry":846,"../bar/style_defaults":871,"./attributes":1018}],1027:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a){if(t.x="xVal"in e?e.xVal:e.x,t.y="yVal"in e?e.yVal:e.y,"zLabelVal"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var i,o=Array.isArray(a)?n[0].pts[a[0]][a[1]]:n[a].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){i=[];for(var s=0;s<o.length;s++)i=i.concat(r._indexToPoints[o[s]])}else i=o;t.pointIndices=i}return t}},{}],1028:[function(t,e,r){"use strict";var n=t("../bar/hover").hoverPoints,a=t("../../plots/cartesian/axes").hoverLabelText;e.exports=function(t,e,r,i){var o=n(t,e,r,i);if(o){var s=(t=o[0]).cd[t.index],l=t.cd[0].trace;if(!l.cumulative.enabled){var c="h"===l.orientation?"y":"x";t[c+"Label"]=a(t[c+"a"],s.ph0,s.ph1)}return o}}},{"../../plots/cartesian/axes":765,"../bar/hover":863}],1029:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),layoutAttributes:t("../bar/layout_attributes"),supplyDefaults:t("./defaults"),crossTraceDefaults:t("./cross_trace_defaults"),supplyLayoutDefaults:t("../bar/layout_defaults"),calc:t("./calc").calc,crossTraceCalc:t("../bar/cross_trace_calc").crossTraceCalc,plot:t("../bar/plot").plot,layerName:"barlayer",style:t("../bar/style").style,styleOnSelect:t("../bar/style").styleOnSelect,colorbar:t("../scatter/marker_colorbar"),hoverPoints:t("./hover"),selectPoints:t("../bar/select"),eventData:t("./event_data"),moduleType:"trace",name:"histogram",basePlotModule:t("../../plots/cartesian"),categories:["bar-like","cartesian","svg","bar","histogram","oriented","errorBarsOK","showLegend"],meta:{}}},{"../../plots/cartesian":776,"../bar/cross_trace_calc":859,"../bar/layout_attributes":865,"../bar/layout_defaults":866,"../bar/plot":867,"../bar/select":868,"../bar/style":870,"../scatter/marker_colorbar":1138,"./attributes":1018,"./calc":1023,"./cross_trace_defaults":1025,"./defaults":1026,"./event_data":1027,"./hover":1028}],1030:[function(t,e,r){"use strict";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,a=0;a<r;a++)t[a]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var a=t.length;n=n||1;for(var i=0;i<a;i++)t[i]*=r[i]*n},"probability density":function(t,e,r,n){var a=t.length;n&&(e/=n);for(var i=0;i<a;i++)t[i]*=r[i]/e}}},{}],1031:[function(t,e,r){"use strict";var n=t("../histogram/attributes"),a=t("../histogram/bin_attributes"),i=t("../heatmap/attributes"),o=t("../../plots/attributes"),s=t("../../plots/template_attributes").hovertemplateAttrs,l=t("../../components/colorscale/attributes"),c=t("../../lib/extend").extendFlat;e.exports=c({x:n.x,y:n.y,z:{valType:"data_array",editType:"calc"},marker:{color:{valType:"data_array",editType:"calc"},editType:"calc"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:a("x"),nbinsy:n.nbinsy,ybins:a("y"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:c({},n.bingroup,{}),xbingroup:c({},n.bingroup,{}),ybingroup:c({},n.bingroup,{}),xgap:i.xgap,ygap:i.ygap,zsmooth:i.zsmooth,zhoverformat:i.zhoverformat,hovertemplate:s({},{keys:"z"}),showlegend:c({},o.showlegend,{dflt:!1})},l("",{cLetter:"z",autoColorDflt:!1}))},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plots/attributes":762,"../../plots/template_attributes":841,"../heatmap/attributes":1e3,"../histogram/attributes":1018,"../histogram/bin_attributes":1020}],1032:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../histogram/bin_functions"),o=t("../histogram/norm_functions"),s=t("../histogram/average"),l=t("../histogram/bin_label_vals"),c=t("../histogram/calc").calcAllAutoBins;function u(t,e,r,n){var a,i=new Array(t);if(n)for(a=0;a<t;a++)i[a]=1/(e[a+1]-e[a]);else{var o=1/r;for(a=0;a<t;a++)i[a]=o}return i}function h(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function f(t,e,r,n,a,i){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,a,i);for(o=0;o<s;o++){var h=(e||[])[o];c[o]=void 0===h?[u(t[o]),u(t[o+1],!0)]:[h,h]}return c}e.exports=function(t,e){var r,l,p,d,g=a.getFromId(t,e.xaxis),v=a.getFromId(t,e.yaxis),m=e.xcalendar,y=e.ycalendar,x=function(t){return g.r2c(t,0,m)},b=function(t){return v.r2c(t,0,y)},_=c(t,e,g,"x"),w=_[0],k=_[1],T=c(t,e,v,"y"),M=T[0],A=T[1],S=e._length;k.length>S&&k.splice(S,k.length-S),A.length>S&&A.splice(S,A.length-S);var E=[],L=[],C=[],P="string"==typeof w.size,O="string"==typeof M.size,z=[],I=[],D=P?z:w,R=O?I:M,F=0,B=[],N=[],j=e.histnorm,V=e.histfunc,U=-1!==j.indexOf("density"),q="max"===V||"min"===V?null:0,H=i.count,G=o[j],Y=!1,W=[],X=[],Z="z"in e?e.z:"marker"in e&&Array.isArray(e.marker.color)?e.marker.color:"";Z&&"count"!==V&&(Y="avg"===V,H=i[V]);var J=w.size,K=x(w.start),Q=x(w.end)+(K-a.tickIncrement(K,J,!1,m))/1e6;for(r=K;r<Q;r=a.tickIncrement(r,J,!1,m))L.push(q),z.push(r),Y&&C.push(0);z.push(r);var $,tt=L.length,et=(r-K)/tt,rt=($=K+et/2,g.c2r($,0,m)),nt=M.size,at=b(M.start),it=b(M.end)+(at-a.tickIncrement(at,nt,!1,y))/1e6;for(r=at;r<it;r=a.tickIncrement(r,nt,!1,y)){E.push(L.slice()),I.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Y&&B.push(C.slice())}I.push(r);var st=E.length,lt=(r-at)/st,ct=function(t){return v.c2r(t,0,y)}(at+lt/2);U&&(W=u(L.length,D,et,P),X=u(E.length,R,lt,O)),P||"date"!==g.type||(D=h(x,D)),O||"date"!==v.type||(R=h(b,R));var ut=!0,ht=!0,ft=new Array(tt),pt=new Array(st),dt=1/0,gt=1/0,vt=1/0,mt=1/0;for(r=0;r<S;r++){var yt=k[r],xt=A[r];p=n.findBin(yt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],Z,B[d]),N[d][p].push(r),ut&&(void 0===ft[p]?ft[p]=yt:ft[p]!==yt&&(ut=!1)),ht&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ht=!1)),dt=Math.min(dt,yt-z[p]),gt=Math.min(gt,z[p+1]-yt),vt=Math.min(vt,xt-I[d]),mt=Math.min(mt,I[d+1]-xt))}if(Y)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,X[d]);return{x:k,xRanges:f(z,ut&&ft,dt,gt,g,m),x0:rt,dx:et,y:A,yRanges:f(I,ht&&pt,vt,mt,v,y),y0:ct,dy:lt,z:E,pts:N}}},{"../../lib":717,"../../plots/cartesian/axes":765,"../histogram/average":1019,"../histogram/bin_functions":1021,"../histogram/bin_label_vals":1022,"../histogram/calc":1023,"../histogram/norm_functions":1030}],1033:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./sample_defaults"),i=t("../heatmap/style_defaults"),o=t("../../components/colorscale/defaults"),s=t("./attributes");e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,s,r,a)}a(t,e,c,l),!1!==e.visible&&(i(t,e,c,l),o(t,e,l,c,{prefix:"",cLetter:"z"}),c("hovertemplate"))}},{"../../components/colorscale/defaults":601,"../../lib":717,"../heatmap/style_defaults":1013,"./attributes":1031,"./sample_defaults":1036}],1034:[function(t,e,r){"use strict";var n=t("../heatmap/hover"),a=t("../../plots/cartesian/axes").hoverLabelText;e.exports=function(t,e,r,i,o,s){var l=n(t,e,r,i,o,s);if(l){var c=(t=l[0]).index,u=c[0],h=c[1],f=t.cd[0],p=f.xRanges[h],d=f.yRanges[u];return t.xLabel=a(t.xa,p[0],p[1]),t.yLabel=a(t.ya,d[0],d[1]),l}}},{"../../plots/cartesian/axes":765,"../heatmap/hover":1007}],1035:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),crossTraceDefaults:t("../histogram/cross_trace_defaults"),calc:t("../heatmap/calc"),plot:t("../heatmap/plot"),layerName:"heatmaplayer",colorbar:t("../heatmap/colorbar"),style:t("../heatmap/style"),hoverPoints:t("./hover"),eventData:t("../histogram/event_data"),moduleType:"trace",name:"histogram2d",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","2dMap","histogram","showLegend"],meta:{}}},{"../../plots/cartesian":776,"../heatmap/calc":1001,"../heatmap/colorbar":1003,"../heatmap/plot":1011,"../heatmap/style":1012,"../histogram/cross_trace_defaults":1025,"../histogram/event_data":1027,"./attributes":1031,"./defaults":1033,"./hover":1034}],1036:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib");e.exports=function(t,e,r,i){var o=r("x"),s=r("y"),l=a.minRowLength(o),c=a.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x","y"],i),(r("z")||r("marker.color"))&&r("histfunc"),r("histnorm"),r("autobinx"),r("autobiny")):e.visible=!1}},{"../../lib":717,"../../registry":846}],1037:[function(t,e,r){"use strict";var n=t("../histogram2d/attributes"),a=t("../contour/attributes"),i=t("../../components/colorscale/attributes"),o=t("../../lib/extend").extendFlat;e.exports=o({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:a.autocontour,ncontours:a.ncontours,contours:a.contours,line:{color:a.line.color,width:o({},a.line.width,{dflt:.5}),dash:a.line.dash,smoothing:a.line.smoothing,editType:"plot"},zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate},i("",{cLetter:"z",editTypeOverride:"calc"}))},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../contour/attributes":943,"../histogram2d/attributes":1031}],1038:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../histogram2d/sample_defaults"),i=t("../contour/contours_defaults"),o=t("../contour/style_defaults"),s=t("./attributes");e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,s,r,a)}a(t,e,c,l),!1!==e.visible&&(i(t,e,c,function(r){return n.coerce2(t,e,s,r)}),o(t,e,c,l),c("hovertemplate"))}},{"../../lib":717,"../contour/contours_defaults":950,"../contour/style_defaults":964,"../histogram2d/sample_defaults":1036,"./attributes":1037}],1039:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),crossTraceDefaults:t("../histogram/cross_trace_defaults"),calc:t("../contour/calc"),plot:t("../contour/plot").plot,layerName:"contourlayer",style:t("../contour/style"),colorbar:t("../contour/colorbar"),hoverPoints:t("../contour/hover"),moduleType:"trace",name:"histogram2dcontour",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","2dMap","contour","histogram","showLegend"],meta:{}}},{"../../plots/cartesian":776,"../contour/calc":944,"../contour/colorbar":946,"../contour/hover":956,"../contour/plot":961,"../contour/style":963,"../histogram/cross_trace_defaults":1025,"./attributes":1037,"./defaults":1038}],1040:[function(t,e,r){"use strict";for(var n=t("../../plots/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../../lib/extend").extendFlat,o=t("./constants").colormodel,s=["rgb","rgba","hsl","hsla"],l=[],c=[],u=0;u<s.length;u++)l.push("For the `"+s[u]+"` colormodel, it is ["+o[s[u]].min.join(", ")+"]."),c.push("For the `"+s[u]+"` colormodel, it is ["+o[s[u]].max.join(", ")+"].");e.exports=i({z:{valType:"data_array",editType:"calc"},colormodel:{valType:"enumerated",values:s,dflt:"rgb",editType:"calc"},zmin:{valType:"info_array",items:[{valType:"number",editType:"calc"},{valType:"number",editType:"calc"},{valType:"number",editType:"calc"},{valType:"number",editType:"calc"}],editType:"calc"},zmax:{valType:"info_array",items:[{valType:"number",editType:"calc"},{valType:"number",editType:"calc"},{valType:"number",editType:"calc"},{valType:"number",editType:"calc"}],editType:"calc"},x0:{valType:"any",dflt:0,editType:"calc+clearAxisTypes"},y0:{valType:"any",dflt:0,editType:"calc+clearAxisTypes"},dx:{valType:"number",dflt:1,editType:"calc"},dy:{valType:"number",dflt:1,editType:"calc"},text:{valType:"data_array",editType:"plot"},hovertext:{valType:"data_array",editType:"plot"},hoverinfo:i({},n.hoverinfo,{flags:["x","y","z","color","name","text"],dflt:"x+y+z+text+name"}),hovertemplate:a({},{keys:["z","color","colormodel"]}),transforms:void 0})},{"../../lib/extend":708,"../../plots/attributes":762,"../../plots/template_attributes":841,"./constants":1042}],1041:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./constants"),i=t("fast-isnumeric"),o=t("../../plots/cartesian/axes"),s=t("../../lib").maxRowLength;function l(t,e,r,a){return function(i){return n.constrain((i-t)*e,r,a)}}function c(t,e){return function(r){return n.constrain(r,t,e)}}e.exports=function(t,e){var r,n=o.getFromId(t,e.xaxis||"x"),u=o.getFromId(t,e.yaxis||"y"),h=n.d2c(e.x0)-e.dx/2,f=u.d2c(e.y0)-e.dy/2,p=e.z.length,d=s(e.z),g=[h,h+d*e.dx],v=[f,f+p*e.dy];if(n&&"log"===n.type)for(r=0;r<d;r++)g.push(h+r*e.dx);if(u&&"log"===u.type)for(r=0;r<p;r++)v.push(f+r*e.dy);return e._extremes[n._id]=o.findExtremes(n,g),e._extremes[u._id]=o.findExtremes(u,v),e._scaler=function(t){var e=t.colormodel,r=e.length,n=a.colormodel[e];t._sArray=[];for(var o=0;o<r;o++)n.min[o]!==t.zmin[o]||n.max[o]!==t.zmax[o]?t._sArray.push(l(t.zmin[o],(n.max[o]-n.min[o])/(t.zmax[o]-t.zmin[o]),n.min[o],n.max[o])):t._sArray.push(c(n.min[o],n.max[o]));return function(e){for(var n=e.slice(0,r),a=0;a<r;a++){var o=n[a];if(!i(o))return!1;n[a]=t._sArray[a](o)}return n}}(e),[{x0:h,y0:f,z:e.z,w:d,h:p}]}},{"../../lib":717,"../../plots/cartesian/axes":765,"./constants":1042,"fast-isnumeric":228}],1042:[function(t,e,r){"use strict";e.exports={colormodel:{rgb:{min:[0,0,0],max:[255,255,255],fmt:function(t){return t.slice(0,3)},suffix:["","",""]},rgba:{min:[0,0,0,0],max:[255,255,255,1],fmt:function(t){return t.slice(0,4)},suffix:["","","",""]},hsl:{min:[0,0,0],max:[360,100,100],fmt:function(t){var e=t.slice(0,3);return e[1]=e[1]+"%",e[2]=e[2]+"%",e},suffix:["\xb0","%","%"]},hsla:{min:[0,0,0,0],max:[360,100,100,1],fmt:function(t){var e=t.slice(0,4);return e[1]=e[1]+"%",e[2]=e[2]+"%",e},suffix:["\xb0","%","%",""]}}}},{}],1043:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("./constants");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}var o=r("z");if(void 0!==o&&o.length&&o[0]&&o[0].length){r("x0"),r("y0"),r("dx"),r("dy");var s=r("colormodel");r("zmin",i.colormodel[s].min),r("zmax",i.colormodel[s].max),r("text"),r("hovertext"),r("hovertemplate"),e._length=null}else e.visible=!1}},{"../../lib":717,"./attributes":1040,"./constants":1042}],1044:[function(t,e,r){"use strict";e.exports=function(t,e){return"xVal"in e&&(t.x=e.xVal),"yVal"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t.color=e.color,t.colormodel=e.trace.colormodel,t}},{}],1045:[function(t,e,r){"use strict";var n=t("../../components/fx"),a=t("../../lib"),i=t("./constants");e.exports=function(t,e,r){var o=t.cd[0],s=o.trace,l=t.xa,c=t.ya;if(!(n.inbox(e-o.x0,e-(o.x0+o.w*s.dx),0)>0||n.inbox(r-o.y0,r-(o.y0+o.h*s.dy),0)>0)){var u=Math.floor((e-o.x0)/s.dx),h=Math.floor(Math.abs(r-o.y0)/s.dy);if(o.z[h][u]){var f,p=o.hi||s.hoverinfo;if(p){var d=p.split("+");-1!==d.indexOf("all")&&(d=["color"]),-1!==d.indexOf("color")&&(f=!0)}var g,v=s.colormodel,m=v.length,y=s._scaler(o.z[h][u]),x=i.colormodel[v].suffix,b=[];(s.hovertemplate||f)&&(b.push("["+[y[0]+x[0],y[1]+x[1],y[2]+x[2]].join(", ")),4===m&&b.push(", "+y[3]+x[3]),b.push("]"),b=b.join(""),t.extraText=v.toUpperCase()+": "+b),Array.isArray(s.hovertext)&&Array.isArray(s.hovertext[h])?g=s.hovertext[h][u]:Array.isArray(s.text)&&Array.isArray(s.text[h])&&(g=s.text[h][u]);var _=c.c2p(o.y0+(h+.5)*s.dy),w=o.x0+(u+.5)*s.dx,k=o.y0+(h+.5)*s.dy,T="["+o.z[h][u].slice(0,s.colormodel.length).join(", ")+"]";return[a.extendFlat(t,{index:[h,u],x0:l.c2p(o.x0+u*s.dx),x1:l.c2p(o.x0+(u+1)*s.dx),y0:_,y1:_,color:y,xVal:w,xLabelVal:w,yVal:k,yLabelVal:k,zLabelVal:T,text:g,hovertemplateLabels:{zLabel:T,colorLabel:b,"color[0]Label":y[0]+x[0],"color[1]Label":y[1]+x[1],"color[2]Label":y[2]+x[2],"color[3]Label":y[3]+x[3]}})]}}}},{"../../components/fx":630,"../../lib":717,"./constants":1042}],1046:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc"),plot:t("./plot"),style:t("./style"),hoverPoints:t("./hover"),eventData:t("./event_data"),moduleType:"trace",name:"image",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","2dMap","noSortingByValue"],animatable:!1,meta:{}}},{"../../plots/cartesian":776,"./attributes":1040,"./calc":1041,"./defaults":1043,"./event_data":1044,"./hover":1045,"./plot":1047,"./style":1048}],1047:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../constants/xmlns_namespaces"),o=t("./constants");e.exports=function(t,e,r,s){var l=e.xaxis,c=e.yaxis;a.makeTraceGroups(s,r,"im").each(function(t){var e,r,s,u,h,f,p=n.select(this),d=t[0],g=d.trace,v=d.z,m=d.x0,y=d.y0,x=d.w,b=d.h,_=g.dx,w=g.dy;for(f=0;void 0===e&&f<x;)e=l.c2p(m+f*_),f++;for(f=x;void 0===r&&f>0;)r=l.c2p(m+f*_),f--;for(f=0;void 0===u&&f<b;)u=c.c2p(y+f*w),f++;for(f=b;void 0===h&&f>0;)h=c.c2p(y+f*w),f--;r<e&&(s=r,r=e,e=s),h<u&&(s=u,u=h,h=s);e=Math.max(-.5*l._length,e),r=Math.min(1.5*l._length,r),u=Math.max(-.5*c._length,u),h=Math.min(1.5*c._length,h);var k=Math.round(r-e),T=Math.round(h-u);if(k<=0||T<=0){p.selectAll("image").data([]).exit().remove()}else{var M=document.createElement("canvas");M.width=k,M.height=T;var A,S=M.getContext("2d"),E=function(t){return a.constrain(Math.round(l.c2p(m+t*_)-e),0,k)},L=function(t){return a.constrain(Math.round(c.c2p(y+t*w)-u),0,T)},C=o.colormodel[g.colormodel].fmt;for(f=0;f<d.w;f++){var P=E(f),O=E(f+1);if(O!==P&&!isNaN(O)&&!isNaN(P))for(var z=0;z<d.h;z++){var I=L(z),D=L(z+1);D===I||isNaN(D)||isNaN(I)||!v[z][f]||(A=g._scaler(v[z][f]),S.fillStyle=A?g.colormodel+"("+C(A).join(",")+")":"rgba(0,0,0,0)",S.fillRect(P,I,O-P,D-I))}}var R=p.selectAll("image").data(t);R.enter().append("svg:image").attr({xmlns:i.svg,preserveAspectRatio:"none"}),R.attr({height:T,width:k,x:e,y:u,"xlink:href":M.toDataURL("image/png")})}})}},{"../../constants/xmlns_namespaces":694,"../../lib":717,"./constants":1042,d3:165}],1048:[function(t,e,r){"use strict";var n=t("d3");e.exports=function(t){n.select(t).selectAll(".im image").style("opacity",function(t){return t.trace.opacity})}},{d3:165}],1049:[function(t,e,r){"use strict";var n=t("../../lib/extend").extendFlat,a=t("../../lib/extend").extendDeep,i=t("../../plot_api/edit_types").overrideAll,o=t("../../plots/font_attributes"),s=t("../../components/color/attributes"),l=t("../../plots/domain").attributes,c=t("../../plots/cartesian/layout_attributes"),u=t("../../plot_api/plot_template").templatedArray,h=t("../../constants/delta.js"),f=(t("../../constants/docs").FORMAT_LINK,o({editType:"plot",colorEditType:"plot"})),p={color:{valType:"color",editType:"plot"},line:{color:{valType:"color",dflt:s.defaultLine,editType:"plot"},width:{valType:"number",min:0,dflt:0,editType:"plot"},editType:"calc"},thickness:{valType:"number",min:0,max:1,dflt:1,editType:"plot"},editType:"calc"},d={valType:"info_array",items:[{valType:"number",editType:"plot"},{valType:"number",editType:"plot"}],editType:"plot"},g=u("step",a({},p,{range:d}));e.exports={mode:{valType:"flaglist",editType:"calc",flags:["number","delta","gauge"],dflt:"number"},value:{valType:"number",editType:"calc",anim:!0},align:{valType:"enumerated",values:["left","center","right"],editType:"plot"},domain:l({name:"indicator",trace:!0,editType:"calc"}),title:{text:{valType:"string",editType:"plot"},align:{valType:"enumerated",values:["left","center","right"],editType:"plot"},font:n({},f,{}),editType:"plot"},number:{valueformat:{valType:"string",dflt:"",editType:"plot"},font:n({},f,{}),prefix:{valType:"string",dflt:"",editType:"plot"},suffix:{valType:"string",dflt:"",editType:"plot"},editType:"plot"},delta:{reference:{valType:"number",editType:"calc"},position:{valType:"enumerated",values:["top","bottom","left","right"],dflt:"bottom",editType:"plot"},relative:{valType:"boolean",editType:"plot",dflt:!1},valueformat:{valType:"string",editType:"plot"},increasing:{symbol:{valType:"string",dflt:h.INCREASING.SYMBOL,editType:"plot"},color:{valType:"color",dflt:h.INCREASING.COLOR,editType:"plot"},editType:"plot"},decreasing:{symbol:{valType:"string",dflt:h.DECREASING.SYMBOL,editType:"plot"},color:{valType:"color",dflt:h.DECREASING.COLOR,editType:"plot"},editType:"plot"},font:n({},f,{}),editType:"calc"},gauge:{shape:{valType:"enumerated",editType:"plot",dflt:"angular",values:["angular","bullet"]},bar:a({},p,{color:{dflt:"green"}}),bgcolor:{valType:"color",editType:"plot"},bordercolor:{valType:"color",dflt:s.defaultLine,editType:"plot"},borderwidth:{valType:"number",min:0,dflt:1,editType:"plot"},axis:i({range:d,visible:n({},c.visible,{dflt:!0}),tickmode:c.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:"outside"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,showticklabels:c.showticklabels,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,showexponent:c.showexponent,editType:"plot"},"plot"),steps:g,threshold:{line:{color:n({},p.line.color,{}),width:n({},p.line.width,{dflt:1}),editType:"plot"},thickness:n({},p.thickness,{dflt:.85}),value:{valType:"number",editType:"calc",dflt:!1},editType:"plot"},editType:"plot"}}},{"../../components/color/attributes":590,"../../constants/delta.js":687,"../../constants/docs":688,"../../lib/extend":708,"../../plot_api/edit_types":748,"../../plot_api/plot_template":755,"../../plots/cartesian/layout_attributes":777,"../../plots/domain":790,"../../plots/font_attributes":791}],1050:[function(t,e,r){"use strict";var n=t("../../plots/plots");r.name="indicator",r.plot=function(t,e,a,i){n.plotBasePlot(r.name,t,e,a,i)},r.clean=function(t,e,a,i){n.cleanBasePlot(r.name,t,e,a,i)}},{"../../plots/plots":826}],1051:[function(t,e,r){"use strict";e.exports={calc:function(t,e){var r=[],n=e.value;"number"!=typeof e._lastValue&&(e._lastValue=e.value);var a=e._lastValue,i=a;return e._hasDelta&&"number"==typeof e.delta.reference&&(i=e.delta.reference),r[0]={y:n,lastY:a,delta:n-i,relativeDelta:(n-i)/i},r}}},{}],1052:[function(t,e,r){"use strict";e.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},{}],1053:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("../../plots/domain").defaults,o=t("../../plot_api/plot_template"),s=t("../../plots/array_container_defaults"),l=t("./constants.js"),c=t("../../plots/cartesian/tick_value_defaults"),u=t("../../plots/cartesian/tick_mark_defaults"),h=t("../../plots/cartesian/tick_label_defaults");function f(t,e){function r(r,i){return n.coerce(t,e,a.gauge.steps,r,i)}r("color"),r("line.color"),r("line.width"),r("range"),r("thickness")}e.exports={supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,a,r,i)}i(e,p,d),d("mode"),e._hasNumber=-1!==e.mode.indexOf("number"),e._hasDelta=-1!==e.mode.indexOf("delta"),e._hasGauge=-1!==e.mode.indexOf("gauge");var g=d("value");e._range=[0,"number"==typeof g?1.5*g:1];var v,m,y,x,b,_,w=new Array(2);function k(t,e){return n.coerce(y,x,a.gauge,t,e)}function T(t,e){return n.coerce(b,_,a.gauge.axis,t,e)}if(e._hasNumber&&(d("number.valueformat"),d("number.font.color",p.font.color),d("number.font.family",p.font.family),d("number.font.size"),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,w[0]=!0),d("number.prefix"),d("number.suffix"),v=e.number.font.size),e._hasDelta&&(d("delta.font.color",p.font.color),d("delta.font.family",p.font.family),d("delta.font.size"),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(v||l.defaultNumberFontSize),w[1]=!0),d("delta.reference",e.value),d("delta.relative"),d("delta.valueformat",e.delta.relative?"2%":""),d("delta.increasing.symbol"),d("delta.increasing.color"),d("delta.decreasing.symbol"),d("delta.decreasing.color"),d("delta.position"),m=e.delta.font.size),e._scaleNumbers=(!e._hasNumber||w[0])&&(!e._hasDelta||w[1])||!1,d("title.font.color",p.font.color),d("title.font.family",p.font.family),d("title.font.size",.25*(v||m||l.defaultNumberFontSize)),d("title.text"),e._hasGauge){(y=t.gauge)||(y={}),x=o.newContainer(e,"gauge"),k("shape"),(e._isBullet="bullet"===e.gauge.shape)||d("title.align","center"),(e._isAngular="angular"===e.gauge.shape)||d("align","center"),k("bgcolor",p.paper_bgcolor),k("borderwidth"),k("bordercolor"),k("bar.color"),k("bar.line.color"),k("bar.line.width"),k("bar.thickness",l.valueThickness*("bullet"===e.gauge.shape?.5:1)),s(y,x,{name:"steps",handleItemDefaults:f}),k("threshold.value"),k("threshold.thickness"),k("threshold.line.width"),k("threshold.line.color"),b={},y&&(b=y.axis||{}),_=o.newContainer(x,"axis"),T("visible"),e._range=T("range",e._range);var M={outerTicks:!0};c(b,_,T,"linear"),h(b,_,T,"linear",M),u(b,_,T,M)}else d("title.align","center"),d("align","center"),e._isAngular=e._isBullet=!1;e._length=null}}},{"../../lib":717,"../../plot_api/plot_template":755,"../../plots/array_container_defaults":761,"../../plots/cartesian/tick_label_defaults":784,"../../plots/cartesian/tick_mark_defaults":785,"../../plots/cartesian/tick_value_defaults":786,"../../plots/domain":790,"./attributes":1049,"./constants.js":1052}],1054:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"indicator",basePlotModule:t("./base_plot"),categories:["svg","noOpacity","noHover"],animatable:!0,attributes:t("./attributes"),supplyDefaults:t("./defaults").supplyDefaults,calc:t("./calc").calc,plot:t("./plot"),meta:{}}},{"./attributes":1049,"./base_plot":1050,"./calc":1051,"./defaults":1053,"./plot":1055}],1055:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=a.rad2deg,o=t("../../constants/alignment").MID_SHIFT,s=t("../../components/drawing"),l=t("./constants"),c=t("../../lib/svg_text_utils"),u=t("../../plots/cartesian/axes"),h=t("../../plots/cartesian/axis_defaults"),f=t("../../plots/cartesian/position_defaults"),p=t("../../plots/cartesian/layout_attributes"),d=t("../../components/color"),g={left:"start",center:"middle",right:"end"},v={left:0,center:.5,right:1},m=/[yzafpn\xb5mkMGTPEZY]/;function y(t){return t&&t.duration>0}function x(t){t.each(function(t){d.stroke(n.select(this),t.line.color)}).each(function(t){d.fill(n.select(this),t.color)}).style("stroke-width",function(t){return t.line.width})}function b(t,e,r){var n=t._fullLayout,i=a.extendFlat({type:"linear",ticks:"outside",range:r,showline:!0},e),o={type:"linear",_id:"x"+e._id},s={letter:"x",font:n.font,noHover:!0,noTickson:!0};function l(t,e){return a.coerce(i,o,p,t,e)}return h(i,o,l,s,n),f(i,o,l,s),o}function _(t,e){return"translate("+t+","+e+")"}function w(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+"x"+r]}function k(t,e,r,a){var i=document.createElementNS("http://www.w3.org/2000/svg","text"),o=n.select(i);return o.text(t).attr("x",0).attr("y",0).attr("text-anchor",r).attr("data-unformatted",t).call(c.convertToTspans,a).call(s.font,e),s.bBox(o.node())}function T(t,e,r,n,i,o){var s="_cache"+e;t[s]&&t[s].key===i||(t[s]={key:i,value:r});var l=a.aggNums(o,null,[t[s].value,n],2);return t[s].value=l,l}e.exports=function(t,e,r,h){var f,p=t._fullLayout;y(r)&&h&&(f=h()),a.makeTraceGroups(p._indicatorlayer,e,"trace").each(function(e){var h,M,A,S,E,L=e[0].trace,C=n.select(this),P=L._hasGauge,O=L._isAngular,z=L._isBullet,I=L.domain,D={w:p._size.w*(I.x[1]-I.x[0]),h:p._size.h*(I.y[1]-I.y[0]),l:p._size.l+p._size.w*I.x[0],r:p._size.r+p._size.w*(1-I.x[1]),t:p._size.t+p._size.h*(1-I.y[1]),b:p._size.b+p._size.h*I.y[0]},R=D.l+D.w/2,F=D.t+D.h/2,B=Math.min(D.w/2,D.h),N=l.innerRadius*B,j=L.align||"center";if(M=F,P){if(O&&(h=R,M=F+B/2,A=function(t){return e=t,r=.9*N,n=Math.sqrt(e.width/2*(e.width/2)+e.height*e.height),[r/n,e,r];var e,r,n}),z){var V=l.bulletPadding,U=1-l.bulletNumberDomainSize+V;h=D.l+(U+(1-U)*v[j])*D.w,A=function(t){return w(t,(l.bulletNumberDomainSize-V)*D.w,D.h)}}}else h=D.l+v[j]*D.w,A=function(t){return w(t,D.w,D.h)};!function(t,e,r,i){var o,l,h,f=r[0].trace,p=i.numbersX,x=i.numbersY,w=f.align||"center",M=g[w],A=i.transitionOpts,S=i.onComplete,E=a.ensureSingle(e,"g","numbers"),L=[];f._hasNumber&&L.push("number");f._hasDelta&&(L.push("delta"),"left"===f.delta.position&&L.reverse());var C=E.selectAll("text").data(L);function P(e,r,n,a){if(!e.match("s")||n>=0==a>=0||r(n).slice(-1).match(m)||r(a).slice(-1).match(m))return r;var i=e.slice().replace("s","f").replace(/\d+/,function(t){return parseInt(t)-1}),o=b(t,{tickformat:i});return function(t){return Math.abs(t)<1?u.tickText(o,t).text:r(t)}}C.enter().append("text"),C.attr("text-anchor",function(){return M}).attr("class",function(t){return t}).attr("x",null).attr("y",null).attr("dx",null).attr("dy",null),C.exit().remove();var O,z=f.mode+f.align;f._hasDelta&&(O=function(){var e=b(t,{tickformat:f.delta.valueformat},f._range);e.setScale(),u.prepTicks(e);var a=function(t){return u.tickText(e,t).text},i=function(t){var e=f.delta.relative?t.relativeDelta:t.delta;return e},o=function(t,e){return 0===t||"number"!=typeof t||isNaN(t)?"-":(t>0?f.delta.increasing.symbol:f.delta.decreasing.symbol)+e(t)},h=function(t){return t.delta>=0?f.delta.increasing.color:f.delta.decreasing.color};void 0===f._deltaLastValue&&(f._deltaLastValue=i(r[0]));var p=E.select("text.delta");function g(){p.text(o(i(r[0]),a)).call(d.fill,h(r[0])).call(c.convertToTspans,t)}p.call(s.font,f.delta.font).call(d.fill,h({delta:f._deltaLastValue})),y(A)?p.transition().duration(A.duration).ease(A.easing).tween("text",function(){var t=n.select(this),e=i(r[0]),s=f._deltaLastValue,l=P(f.delta.valueformat,a,s,e),c=n.interpolateNumber(s,e);return f._deltaLastValue=e,function(e){t.text(o(c(e),l)),t.call(d.fill,h({delta:c(e)}))}}).each("end",function(){g(),S&&S()}).each("interrupt",function(){g(),S&&S()}):g();return l=k(o(i(r[0]),a),f.delta.font,M,t),p}(),z+=f.delta.position+f.delta.font.size+f.delta.font.family+f.delta.valueformat,z+=f.delta.increasing.symbol+f.delta.decreasing.symbol,h=l);f._hasNumber&&(!function(){var e=b(t,{tickformat:f.number.valueformat},f._range);e.setScale(),u.prepTicks(e);var a=function(t){return u.tickText(e,t).text},i=f.number.suffix,l=f.number.prefix,h=E.select("text.number");function p(){var e="number"==typeof r[0].y?l+a(r[0].y)+i:"-";h.text(e).call(s.font,f.number.font).call(c.convertToTspans,t)}y(A)?h.transition().duration(A.duration).ease(A.easing).each("end",function(){p(),S&&S()}).each("interrupt",function(){p(),S&&S()}).attrTween("text",function(){var t=n.select(this),e=n.interpolateNumber(r[0].lastY,r[0].y);f._lastValue=r[0].y;var o=P(f.number.valueformat,a,r[0].lastY,r[0].y);return function(r){t.text(l+o(e(r))+i)}}):p();o=k(l+a(r[0].y)+i,f.number.font,M,t)}(),z+=f.number.font.size+f.number.font.family+f.number.valueformat+f.number.suffix+f.number.prefix,h=o);if(f._hasDelta&&f._hasNumber){var I,D,R=[(o.left+o.right)/2,(o.top+o.bottom)/2],F=[(l.left+l.right)/2,(l.top+l.bottom)/2],B=.75*f.delta.font.size;"left"===f.delta.position&&(I=T(f,"deltaPos",0,-1*(o.width*v[f.align]+l.width*(1-v[f.align])+B),z,Math.min),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:l.left+I,right:o.right,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),"right"===f.delta.position&&(I=T(f,"deltaPos",0,o.width*(1-v[f.align])+l.width*v[f.align]+B,z,Math.max),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:o.left,right:l.right+I,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),"bottom"===f.delta.position&&(I=null,D=l.height,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height,bottom:o.bottom+l.height}),"top"===f.delta.position&&(I=null,D=o.top,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height-l.height,bottom:o.bottom}),O.attr({dx:I,dy:D})}(f._hasNumber||f._hasDelta)&&E.attr("transform",function(){var t=i.numbersScaler(h);z+=t[2];var e,r=T(f,"numbersScale",1,t[0],z,Math.min);f._scaleNumbers||(r=1),e=f._isAngular?x-r*h.bottom:x-r*(h.top+h.bottom)/2,f._numbersTop=r*h.top+e;var n=h[w];"center"===w&&(n=(h.left+h.right)/2);var a=p-r*n;return _(a=T(f,"numbersTranslate",0,a,z,Math.max),e)+" scale("+r+")"})}(t,C,e,{numbersX:h,numbersY:M,numbersScaler:A,transitionOpts:r,onComplete:f}),P&&(S={range:L.gauge.axis.range,color:L.gauge.bgcolor,line:{color:L.gauge.bordercolor,width:0},thickness:1},E={range:L.gauge.axis.range,color:"rgba(0, 0, 0, 0)",line:{color:L.gauge.bordercolor,width:L.gauge.borderwidth},thickness:1});var q=C.selectAll("g.angular").data(O?e:[]);q.exit().remove();var H=C.selectAll("g.angularaxis").data(O?e:[]);H.exit().remove(),O&&function(t,e,r,a){var s,l,c,h,f=r[0].trace,p=a.size,d=a.radius,g=a.innerRadius,v=a.gaugeBg,m=a.gaugeOutline,w=[p.l+p.w/2,p.t+p.h/2+d/2],k=a.gauge,T=a.layer,M=a.transitionOpts,A=a.onComplete,S=Math.PI/2;function E(t){var e=f.gauge.axis.range[0],r=f.gauge.axis.range[1],n=(t-e)/(r-e)*Math.PI-S;return n<-S?-S:n>S?S:n}function L(t){return n.svg.arc().innerRadius((g+d)/2-t/2*(d-g)).outerRadius((g+d)/2+t/2*(d-g)).startAngle(-S)}function C(t){t.attr("d",function(t){return L(t.thickness).startAngle(E(t.range[0])).endAngle(E(t.range[1]))()})}k.enter().append("g").classed("angular",!0),k.attr("transform",_(w[0],w[1])),T.enter().append("g").classed("angularaxis",!0).classed("crisp",!0),T.selectAll("g.xangularaxistick,path,text").remove(),(s=b(t,f.gauge.axis)).type="linear",s.range=f.gauge.axis.range,s._id="xangularaxis",s.setScale();var P=function(t){return(s.range[0]-t.x)/(s.range[1]-s.range[0])*Math.PI+Math.PI},O={},z=u.makeLabelFns(s,0).labelStandoff;O.xFn=function(t){var e=P(t);return Math.cos(e)*z},O.yFn=function(t){var e=P(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(z+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*o)},O.anchorFn=function(t){var e=P(t),r=Math.cos(e);return Math.abs(r)<.1?"middle":r>0?"start":"end"},O.heightFn=function(t,e,r){var n=P(t);return-.5*(1+Math.sin(n))*r};var I=function(t){return _(w[0]+d*Math.cos(t),w[1]-d*Math.sin(t))};c=function(t){return I(P(t))};if(l=u.calcTicks(s),h=u.getTickSigns(s)[2],s.visible){h="inside"===s.ticks?-1:1;var D=(s.linewidth||1)/2;u.drawTicks(t,s,{vals:l,layer:T,path:"M"+h*D+",0h"+h*s.ticklen,transFn:function(t){var e=P(t);return I(e)+"rotate("+-i(e)+")"}}),u.drawLabels(t,s,{vals:l,layer:T,transFn:c,labelFns:O})}var R=[v].concat(f.gauge.steps),F=k.selectAll("g.bg-arc").data(R);F.enter().append("g").classed("bg-arc",!0).append("path"),F.select("path").call(C).call(x),F.exit().remove();var B=L(f.gauge.bar.thickness),N=k.selectAll("g.value-arc").data([f.gauge.bar]);N.enter().append("g").classed("value-arc",!0).append("path");var j=N.select("path");y(M)?(j.transition().duration(M.duration).ease(M.easing).each("end",function(){A&&A()}).each("interrupt",function(){A&&A()}).attrTween("d",(V=B,U=E(r[0].lastY),q=E(r[0].y),function(){var t=n.interpolate(U,q);return function(e){return V.endAngle(t(e))()}})),f._lastValue=r[0].y):j.attr("d","number"==typeof r[0].y?B.endAngle(E(r[0].y)):"M0,0Z");var V,U,q;j.call(x),N.exit().remove(),R=[];var H=f.gauge.threshold.value;H&&R.push({range:[H,H],color:f.gauge.threshold.color,line:{color:f.gauge.threshold.line.color,width:f.gauge.threshold.line.width},thickness:f.gauge.threshold.thickness});var G=k.selectAll("g.threshold-arc").data(R);G.enter().append("g").classed("threshold-arc",!0).append("path"),G.select("path").call(C).call(x),G.exit().remove();var Y=k.selectAll("g.gauge-outline").data([m]);Y.enter().append("g").classed("gauge-outline",!0).append("path"),Y.select("path").call(C).call(x),Y.exit().remove()}(t,0,e,{radius:B,innerRadius:N,gauge:q,layer:H,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var G=C.selectAll("g.bullet").data(z?e:[]);G.exit().remove();var Y=C.selectAll("g.bulletaxis").data(z?e:[]);Y.exit().remove(),z&&function(t,e,r,n){var a,i,o,s,c,h=r[0].trace,f=n.gauge,p=n.layer,g=n.gaugeBg,v=n.gaugeOutline,m=n.size,_=h.domain,w=n.transitionOpts,k=n.onComplete;f.enter().append("g").classed("bullet",!0),f.attr("transform","translate("+m.l+", "+m.t+")"),p.enter().append("g").classed("bulletaxis",!0).classed("crisp",!0),p.selectAll("g.xbulletaxistick,path,text").remove();var T=m.h,M=h.gauge.bar.thickness*T,A=_.x[0],S=_.x[0]+(_.x[1]-_.x[0])*(h._hasNumber||h._hasDelta?1-l.bulletNumberDomainSize:1);(a=b(t,h.gauge.axis))._id="xbulletaxis",a.domain=[A,S],a.setScale(),i=u.calcTicks(a),o=u.makeTransFn(a),s=u.getTickSigns(a)[2],c=m.t+m.h,a.visible&&(u.drawTicks(t,a,{vals:"inside"===a.ticks?u.clipEnds(a,i):i,layer:p,path:u.makeTickPath(a,c,s),transFn:o}),u.drawLabels(t,a,{vals:i,layer:p,transFn:o,labelFns:u.makeLabelFns(a,c)}));function E(t){t.attr("width",function(t){return Math.max(0,a.c2p(t.range[1])-a.c2p(t.range[0]))}).attr("x",function(t){return a.c2p(t.range[0])}).attr("y",function(t){return.5*(1-t.thickness)*T}).attr("height",function(t){return t.thickness*T})}var L=[g].concat(h.gauge.steps),C=f.selectAll("g.bg-bullet").data(L);C.enter().append("g").classed("bg-bullet",!0).append("rect"),C.select("rect").call(E).call(x),C.exit().remove();var P=f.selectAll("g.value-bullet").data([h.gauge.bar]);P.enter().append("g").classed("value-bullet",!0).append("rect"),P.select("rect").attr("height",M).attr("y",(T-M)/2).call(x),y(w)?P.select("rect").transition().duration(w.duration).ease(w.easing).each("end",function(){k&&k()}).each("interrupt",function(){k&&k()}).attr("width",Math.max(0,a.c2p(Math.min(h.gauge.axis.range[1],r[0].y)))):P.select("rect").attr("width","number"==typeof r[0].y?Math.max(0,a.c2p(Math.min(h.gauge.axis.range[1],r[0].y))):0);P.exit().remove();var O=r.filter(function(){return h.gauge.threshold.value}),z=f.selectAll("g.threshold-bullet").data(O);z.enter().append("g").classed("threshold-bullet",!0).append("line"),z.select("line").attr("x1",a.c2p(h.gauge.threshold.value)).attr("x2",a.c2p(h.gauge.threshold.value)).attr("y1",(1-h.gauge.threshold.thickness)/2*T).attr("y2",(1-(1-h.gauge.threshold.thickness)/2)*T).call(d.stroke,h.gauge.threshold.line.color).style("stroke-width",h.gauge.threshold.line.width),z.exit().remove();var I=f.selectAll("g.gauge-outline").data([v]);I.enter().append("g").classed("gauge-outline",!0).append("rect"),I.select("rect").call(E).call(x),I.exit().remove()}(t,0,e,{gauge:G,layer:Y,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var W=C.selectAll("text.title").data(e);W.exit().remove(),W.enter().append("text").classed("title",!0),W.attr("text-anchor",function(){return z?g.right:g[L.title.align]}).text(L.title.text).call(s.font,L.title.font).call(c.convertToTspans,t),W.attr("transform",function(){var t,e=D.l+D.w*v[L.title.align],r=l.titlePadding,n=s.bBox(W.node());if(P){if(O)if(L.gauge.axis.visible)t=s.bBox(H.node()).top-r-n.bottom;else t=D.t+D.h/2-B/2-n.bottom-r;z&&(t=M-(n.top+n.bottom)/2,e=D.l-l.bulletPadding*D.w)}else t=L._numbersTop-r-n.bottom;return _(e,t)})})}},{"../../components/color":591,"../../components/drawing":612,"../../constants/alignment":686,"../../lib":717,"../../lib/svg_text_utils":741,"../../plots/cartesian/axes":765,"../../plots/cartesian/axis_defaults":767,"../../plots/cartesian/layout_attributes":777,"../../plots/cartesian/position_defaults":780,"./constants":1052,d3:165}],1056:[function(t,e,r){"use strict";var n=t("../../components/colorscale/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../mesh3d/attributes"),o=t("../../plots/attributes"),s=t("../../lib/extend").extendFlat,l=t("../../plot_api/edit_types").overrideAll;var c=e.exports=l(s({x:{valType:"data_array"},y:{valType:"data_array"},z:{valType:"data_array"},value:{valType:"data_array"},isomin:{valType:"number"},isomax:{valType:"number"},surface:{show:{valType:"boolean",dflt:!0},count:{valType:"integer",dflt:2,min:1},fill:{valType:"number",min:0,max:1,dflt:1},pattern:{valType:"flaglist",flags:["A","B","C","D","E"],extras:["all","odd","even"],dflt:"all"}},spaceframe:{show:{valType:"boolean",dflt:!1},fill:{valType:"number",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:"boolean",dflt:!1},locations:{valType:"data_array",dflt:[]},fill:{valType:"number",min:0,max:1,dflt:1}},y:{show:{valType:"boolean",dflt:!1},locations:{valType:"data_array",dflt:[]},fill:{valType:"number",min:0,max:1,dflt:1}},z:{show:{valType:"boolean",dflt:!1},locations:{valType:"data_array",dflt:[]},fill:{valType:"number",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:"boolean",dflt:!0},fill:{valType:"number",min:0,max:1,dflt:1}},y:{show:{valType:"boolean",dflt:!0},fill:{valType:"number",min:0,max:1,dflt:1}},z:{show:{valType:"boolean",dflt:!0},fill:{valType:"number",min:0,max:1,dflt:1}}},text:{valType:"string",dflt:"",arrayOk:!0},hovertext:{valType:"string",dflt:"",arrayOk:!0},hovertemplate:a(),showlegend:s({},o.showlegend,{dflt:!1})},n("",{colorAttr:"`value`",showScaleDflt:!0,editTypeOverride:"calc"}),{opacity:i.opacity,lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:s({},o.hoverinfo)}),"calc","nested");c.flatshading.dflt=!0,c.lighting.facenormalsepsilon.dflt=0,c.x.editType=c.y.editType=c.z.editType=c.value.editType="calc+clearAxisTypes",c.transforms=void 0},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plot_api/edit_types":748,"../../plots/attributes":762,"../../plots/template_attributes":841,"../mesh3d/attributes":1061}],1057:[function(t,e,r){"use strict";var n=t("../../components/colorscale/calc"),a=t("../streamtube/calc").processGrid,i=t("../streamtube/calc").filter;e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length),e._x=i(e.x,e._len),e._y=i(e.y,e._len),e._z=i(e.z,e._len),e._value=i(e.value,e._len);var r=a(e);e._gridFill=r.fill,e._Xs=r.Xs,e._Ys=r.Ys,e._Zs=r.Zs,e._len=r.len;for(var o=1/0,s=-1/0,l=0;l<e._len;l++){var c=e._value[l];o=Math.min(o,c),s=Math.max(s,c)}e._minValues=o,e._maxValues=s,e._vMin=void 0===e.isomin||null===e.isomin?o:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?s:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:"",cLetter:"c"})}},{"../../components/colorscale/calc":599,"../streamtube/calc":1227}],1058:[function(t,e,r){"use strict";var n=t("gl-mesh3d"),a=t("../../lib/gl_format_color").parseColorScale,i=t("../../lib/str2rgbarray"),o=t("../../components/colorscale").extractOpts,s=t("../../plots/gl3d/zip3"),l=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),a=Math.max(e[r],e[r-1]);if(a>n&&n<t&&t<=a)return{id:r,distRatio:(a-t)/(a-n)}}return{id:0,distRatio:0}};function c(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name="",this.data=null,this.showContour=!1}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._meshX[e],n=this.data._meshY[e],a=this.data._meshZ[e],i=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(a,this.data._Zs).id,h=t.index=u+o*c+o*i*s;t.traceCoordinate=[this.data._meshX[h],this.data._meshY[h],this.data._meshZ[h],this.data._value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},u.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=f(t);var l={positions:s(n(r.xaxis,t._meshX,e.dataScale[0],t.xcalendar),n(r.yaxis,t._meshY,e.dataScale[1],t.ycalendar),n(r.zaxis,t._meshZ,e.dataScale[2],t.zcalendar)),cells:s(t._meshI,t._meshJ,t._meshK),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:i(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=o(t);l.vertexIntensity=t._meshIntensity,l.vertexIntensityBounds=[c.min,c.max],l.colormap=a(t),this.mesh.update(l)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()};var h=["xyz","xzy","yxz","yzx","zxy","zyx"];function f(t){t._meshI=[],t._meshJ=[],t._meshK=[];var e,r,n,a,i,o,s,c=t.surface.show,u=t.spaceframe.show,f=t.surface.fill,p=t.spaceframe.fill,d=!1,g=!1,v=0,m=t._Xs,y=t._Ys,x=t._Zs,b=m.length,_=y.length,w=x.length,k=h.indexOf(t._gridFill.replace(/-/g,"").replace(/\+/g,"")),T=function(t,e,r){switch(k){case 5:return r+w*e+w*_*t;case 4:return r+w*t+w*b*e;case 3:return e+_*r+_*w*t;case 2:return e+_*t+_*b*r;case 1:return t+b*r+b*w*e;default:return t+b*e+b*_*r}},M=t._minValues,A=t._maxValues,S=t._vMin,E=t._vMax;function L(t,e,s){for(var l=o.length,c=r;c<l;c++)if(t===n[c]&&e===a[c]&&s===i[c])return c;return-1}function C(){r=e}function P(){n=[],a=[],i=[],o=[],e=0,C()}function O(t,r,s,l){return n.push(t),a.push(r),i.push(s),o.push(l),++e-1}function z(t,e,r){for(var n=[],a=0;a<t.length;a++)n[a]=t[a]*(1-r)+r*e[a];return n}function I(t){s=t}function D(t,e){return"all"===t||null===t||t.indexOf(e)>-1}function R(t,e){return null===t?e:t}function F(e,r,n){C();var a,i,o,l=[r],c=[n];if(s>=1)l=[r],c=[n];else if(s>0){var u=function(t,e){var r=t[0],n=t[1],a=t[2],i=function(t,e,r){for(var n=[],a=0;a<t.length;a++)n[a]=(t[a]+e[a]+r[a])/3;return n}(r,n,a),o=Math.sqrt(1-s),l=z(i,r,o),c=z(i,n,o),u=z(i,a,o),h=e[0],f=e[1],p=e[2];return{xyzv:[[r,n,c],[c,l,r],[n,a,u],[u,c,n],[a,r,l],[l,u,a]],abc:[[h,f,-1],[-1,-1,h],[f,p,-1],[-1,-1,f],[p,h,-1],[-1,-1,p]]}}(r,n);l=u.xyzv,c=u.abc}for(var h=0;h<l.length;h++){r=l[h],n=c[h];for(var f=[],p=0;p<3;p++){var d=r[p][0],g=r[p][1],m=r[p][2],y=r[p][3],x=n[p]>-1?n[p]:L(d,g,m);f[p]=x>-1?x:O(d,g,m,R(e,y))}a=f[0],i=f[1],o=f[2],t._meshI.push(a),t._meshJ.push(i),t._meshK.push(o),++v}}function B(t,e,r,n){var a=t[3];a<r&&(a=r),a>n&&(a=n);for(var i=(t[3]-a)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-i)*t[s]+i*e[s];return o}function N(t,e,r){return t>=e&&t<=r}function j(t){var e=.001*(E-S);return t>=S-e&&t<=E+e}function V(e){for(var r=[],n=0;n<4;n++){var a=e[n];r.push([t._x[a],t._y[a],t._z[a],t._value[a]])}return r}var U=3;function q(t,e,r,n,a,i){i||(i=1),r=[-1,-1,-1];var o=!1,s=[N(e[0][3],n,a),N(e[1][3],n,a),N(e[2][3],n,a)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return j(e[0][3])&&j(e[1][3])&&j(e[2][3])?(F(t,e,r),!0):i<U&&q(t,e,r,S,E,++i)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach(function(i){if(s[i[0]]&&s[i[1]]&&!s[i[2]]){var u=e[i[0]],h=e[i[1]],f=e[i[2]],p=B(f,u,n,a),d=B(f,h,n,a);o=l(t,[d,p,u],[-1,-1,r[i[0]]])||o,o=l(t,[u,h,d],[r[i[0]],r[i[1]],-1])||o,c=!0}}),c?o:([[0,1,2],[1,2,0],[2,0,1]].forEach(function(i){if(s[i[0]]&&!s[i[1]]&&!s[i[2]]){var u=e[i[0]],h=e[i[1]],f=e[i[2]],p=B(h,u,n,a),d=B(f,u,n,a);o=l(t,[d,p,u],[-1,-1,r[i[0]]])||o,c=!0}}),o)}function H(t,e,r,n){var a=!1,i=V(e),o=[N(i[0][3],r,n),N(i[1][3],r,n),N(i[2][3],r,n),N(i[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return a;if(o[0]&&o[1]&&o[2]&&o[3])return g&&(a=function(t,e,r){var n=function(n,a,i){F(t,[e[n],e[a],e[i]],[r[n],r[a],r[i]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,i,e)||a),a;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach(function(l){if(o[l[0]]&&o[l[1]]&&o[l[2]]&&!o[l[3]]){var c=i[l[0]],u=i[l[1]],h=i[l[2]],f=i[l[3]];if(g)a=F(t,[c,u,h],[e[l[0]],e[l[1]],e[l[2]]])||a;else{var p=B(f,c,r,n),d=B(f,u,r,n),v=B(f,h,r,n);a=F(null,[p,d,v],[-1,-1,-1])||a}s=!0}}),s?a:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach(function(l){if(o[l[0]]&&o[l[1]]&&!o[l[2]]&&!o[l[3]]){var c=i[l[0]],u=i[l[1]],h=i[l[2]],f=i[l[3]],p=B(h,c,r,n),d=B(h,u,r,n),v=B(f,u,r,n),m=B(f,c,r,n);g?(a=F(t,[c,m,p],[e[l[0]],-1,-1])||a,a=F(t,[u,d,v],[e[l[1]],-1,-1])||a):a=function(t,e,r){var n=function(n,a,i){F(t,[e[n],e[a],e[i]],[r[n],r[a],r[i]])};n(0,1,2),n(2,3,0)}(null,[p,d,v,m],[-1,-1,-1,-1])||a,s=!0}}),s?a:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach(function(l){if(o[l[0]]&&!o[l[1]]&&!o[l[2]]&&!o[l[3]]){var c=i[l[0]],u=i[l[1]],h=i[l[2]],f=i[l[3]],p=B(u,c,r,n),d=B(h,c,r,n),v=B(f,c,r,n);g?(a=F(t,[c,p,d],[e[l[0]],-1,-1])||a,a=F(t,[c,d,v],[e[l[0]],-1,-1])||a,a=F(t,[c,v,p],[e[l[0]],-1,-1])||a):a=F(null,[p,d,v],[-1,-1,-1])||a,s=!0}}),a))}function G(t,e,r,n,a,i,o,s,l,c,u){var h=!1;return d&&(D(t,"A")&&(h=H(null,[e,r,n,i],c,u)||h),D(t,"B")&&(h=H(null,[r,n,a,l],c,u)||h),D(t,"C")&&(h=H(null,[r,i,o,l],c,u)||h),D(t,"D")&&(h=H(null,[n,i,s,l],c,u)||h),D(t,"E")&&(h=H(null,[r,n,i,l],c,u)||h)),g&&(h=H(t,[r,n,i,l],c,u)||h),h}function Y(t,e,r,n,a,i,o,s){return[!0===s[0]||q(t,V([e,r,n]),[e,r,n],i,o),!0===s[1]||q(t,V([n,a,e]),[n,a,e],i,o)]}function W(t,e,r,n,a,i,o,s,l){return s?Y(t,e,r,a,n,i,o,l):Y(t,r,a,n,e,i,o,l)}function X(t,e,r,n,a,i,o){var s,l,c,u,h=!1,f=function(){h=q(t,[s,l,c],[-1,-1,-1],a,i)||h,h=q(t,[c,u,s],[-1,-1,-1],a,i)||h},p=o[0],d=o[1],g=o[2];return p&&(s=z(V([T(e,r-0,n-0)])[0],V([T(e-1,r-0,n-0)])[0],p),l=z(V([T(e,r-0,n-1)])[0],V([T(e-1,r-0,n-1)])[0],p),c=z(V([T(e,r-1,n-1)])[0],V([T(e-1,r-1,n-1)])[0],p),u=z(V([T(e,r-1,n-0)])[0],V([T(e-1,r-1,n-0)])[0],p),f()),d&&(s=z(V([T(e-0,r,n-0)])[0],V([T(e-0,r-1,n-0)])[0],d),l=z(V([T(e-0,r,n-1)])[0],V([T(e-0,r-1,n-1)])[0],d),c=z(V([T(e-1,r,n-1)])[0],V([T(e-1,r-1,n-1)])[0],d),u=z(V([T(e-1,r,n-0)])[0],V([T(e-1,r-1,n-0)])[0],d),f()),g&&(s=z(V([T(e-0,r-0,n)])[0],V([T(e-0,r-0,n-1)])[0],g),l=z(V([T(e-0,r-1,n)])[0],V([T(e-0,r-1,n-1)])[0],g),c=z(V([T(e-1,r-1,n)])[0],V([T(e-1,r-1,n-1)])[0],g),u=z(V([T(e-1,r-0,n)])[0],V([T(e-1,r-0,n-1)])[0],g),f()),h}function Z(t,e,r,n,a,i,o,s,l,c,u,h){var f=t;return h?(d&&"even"===t&&(f=null),G(f,e,r,n,a,i,o,s,l,c,u)):(d&&"odd"===t&&(f=null),G(f,l,s,o,i,a,n,r,e,c,u))}function J(t,e,r,n,a){for(var i=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<w;c++)for(var u=1;u<_;u++)i.push(W(t,T(l,u-1,c-1),T(l,u-1,c),T(l,u,c-1),T(l,u,c),r,n,(l+u+c)%2,a&&a[o]?a[o]:[])),o++;return i}function K(t,e,r,n,a){for(var i=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<b;c++)for(var u=1;u<w;u++)i.push(W(t,T(c-1,l,u-1),T(c,l,u-1),T(c-1,l,u),T(c,l,u),r,n,(c+l+u)%2,a&&a[o]?a[o]:[])),o++;return i}function Q(t,e,r,n,a){for(var i=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<_;c++)for(var u=1;u<b;u++)i.push(W(t,T(u-1,c-1,l),T(u-1,c,l),T(u,c-1,l),T(u,c,l),r,n,(u+c+l)%2,a&&a[o]?a[o]:[])),o++;return i}function $(t,e,r){for(var n=1;n<w;n++)for(var a=1;a<_;a++)for(var i=1;i<b;i++)Z(t,T(i-1,a-1,n-1),T(i-1,a-1,n),T(i-1,a,n-1),T(i-1,a,n),T(i,a-1,n-1),T(i,a-1,n),T(i,a,n-1),T(i,a,n),e,r,(i+a+n)%2)}function tt(t,e,r){d=!0,$(t,e,r),d=!1}function et(t,e,r,n,a,i){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<w;u++)for(var h=1;h<_;h++)o.push(X(t,c,h,u,r,n,a[l],i&&i[s]&&i[s])),s++;return o}function rt(t,e,r,n,a,i){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<b;u++)for(var h=1;h<w;h++)o.push(X(t,u,c,h,r,n,a[l],i&&i[s]&&i[s])),s++;return o}function nt(t,e,r,n,a,i){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<_;u++)for(var h=1;h<b;h++)o.push(X(t,h,u,c,r,n,a[l],i&&i[s]&&i[s])),s++;return o}function at(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(P(),function(){for(var e=0;e<b;e++)for(var r=0;r<_;r++)for(var n=0;n<w;n++){var a=T(e,r,n);O(t._x[a],t._y[a],t._z[a],t._value[a])}}(),u&&p&&(I(p),g=!0,$(null,S,E),g=!1),c&&f){I(f);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var h=1===r?.5:s/(r-1),d=(1-h)*S+h*E,k=Math.abs(d-M)>Math.abs(d-A)?[M,d]:[d,A];tt(e,k[0],k[1])}}var L=[[Math.min(S,A),Math.max(S,A)],[Math.min(M,E),Math.max(M,E)]];["x","y","z"].forEach(function(e){for(var r=[],n=0;n<L.length;n++){var a=0,i=L[n][0],o=L[n][1],s=t.slices[e];if(s.show&&s.fill){I(s.fill);var c=[],u=[],h=[];if(s.locations.length)for(var f=0;f<s.locations.length;f++){var p=l(s.locations[f],"x"===e?m:"y"===e?y:x);0===p.distRatio?c.push(p.id):p.id>0&&(u.push(p.id),"x"===e?h.push([p.distRatio,0,0]):"y"===e?h.push([0,p.distRatio,0]):h.push([0,0,p.distRatio]))}else c=at(1,"x"===e?b-1:"y"===e?_-1:w-1);u.length>0&&(r[a]="x"===e?et(null,u,i,o,h,r[a]):"y"===e?rt(null,u,i,o,h,r[a]):nt(null,u,i,o,h,r[a]),a++),c.length>0&&(r[a]="x"===e?J(null,c,i,o,r[a]):"y"===e?K(null,c,i,o,r[a]):Q(null,c,i,o,r[a]),a++)}var d=t.caps[e];d.show&&d.fill&&(I(d.fill),r[a]="x"===e?J(null,[0,b-1],i,o,r[a]):"y"===e?K(null,[0,_-1],i,o,r[a]):Q(null,[0,w-1],i,o,r[a]),a++)}}),0===v&&P(),t._meshX=n,t._meshY=a,t._meshZ=i,t._meshIntensity=o,t._Xs=m,t._Ys=y,t._Zs=x}(),t}e.exports={findNearestOnAxis:l,generateIsoMeshes:f,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,a=n({gl:r}),i=new c(t,a,e.uid);return a._trace=i,i.update(e),t.glplot.add(a),i}}},{"../../components/colorscale":603,"../../lib/gl_format_color":714,"../../lib/str2rgbarray":740,"../../plots/gl3d/zip3":816,"gl-mesh3d":283}],1059:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../registry"),i=t("./attributes"),o=t("../../components/colorscale/defaults");function s(t,e,r,n,i){var s=i("isomin"),l=i("isomax");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=i("x"),u=i("y"),h=i("z"),f=i("value");c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length?(a.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x","y","z"],n),["x","y","z"].forEach(function(t){var e="caps."+t;i(e+".show")&&i(e+".fill");var r="slices."+t;i(r+".show")&&(i(r+".fill"),i(r+".locations"))}),i("spaceframe.show")&&i("spaceframe.fill"),i("surface.show")&&(i("surface.count"),i("surface.fill"),i("surface.pattern")),i("contour.show")&&(i("contour.color"),i("contour.width")),["text","hovertext","hovertemplate","lighting.ambient","lighting.diffuse","lighting.specular","lighting.roughness","lighting.fresnel","lighting.vertexnormalsepsilon","lighting.facenormalsepsilon","lightposition.x","lightposition.y","lightposition.z","flatshading","opacity"].forEach(function(t){i(t)}),o(t,e,n,i,{prefix:"",cLetter:"c"}),e._length=null):e.visible=!1}e.exports={supplyDefaults:function(t,e,r,a){s(t,e,0,a,function(r,a){return n.coerce(t,e,i,r,a)})},supplyIsoDefaults:s}},{"../../components/colorscale/defaults":601,"../../lib":717,"../../registry":846,"./attributes":1056}],1060:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults").supplyDefaults,calc:t("./calc"),colorbar:{min:"cmin",max:"cmax"},plot:t("./convert").createIsosurfaceTrace,moduleType:"trace",name:"isosurface",basePlotModule:t("../../plots/gl3d"),categories:["gl3d","showLegend"],meta:{}}},{"../../plots/gl3d":805,"./attributes":1056,"./calc":1057,"./convert":1058,"./defaults":1059}],1061:[function(t,e,r){"use strict";var n=t("../../components/colorscale/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../surface/attributes"),o=t("../../plots/attributes"),s=t("../../lib/extend").extendFlat;e.exports=s({x:{valType:"data_array",editType:"calc+clearAxisTypes"},y:{valType:"data_array",editType:"calc+clearAxisTypes"},z:{valType:"data_array",editType:"calc+clearAxisTypes"},i:{valType:"data_array",editType:"calc"},j:{valType:"data_array",editType:"calc"},k:{valType:"data_array",editType:"calc"},text:{valType:"string",dflt:"",arrayOk:!0,editType:"calc"},hovertext:{valType:"string",dflt:"",arrayOk:!0,editType:"calc"},hovertemplate:a({editType:"calc"}),delaunayaxis:{valType:"enumerated",values:["x","y","z"],dflt:"z",editType:"calc"},alphahull:{valType:"number",dflt:-1,editType:"calc"},intensity:{valType:"data_array",editType:"calc"},intensitymode:{valType:"enumerated",values:["vertex","cell"],dflt:"vertex",editType:"calc"},color:{valType:"color",editType:"calc"},vertexcolor:{valType:"data_array",editType:"calc"},facecolor:{valType:"data_array",editType:"calc"},transforms:void 0},n("",{colorAttr:"`intensity`",showScaleDflt:!0,editTypeOverride:"calc"}),{opacity:i.opacity,flatshading:{valType:"boolean",dflt:!1,editType:"calc"},contour:{show:s({},i.contours.x.show,{}),color:i.contours.x.color,width:i.contours.x.width,editType:"calc"},lightposition:{x:s({},i.lightposition.x,{dflt:1e5}),y:s({},i.lightposition.y,{dflt:1e5}),z:s({},i.lightposition.z,{dflt:0}),editType:"calc"},lighting:s({vertexnormalsepsilon:{valType:"number",min:0,max:1,dflt:1e-12,editType:"calc"},facenormalsepsilon:{valType:"number",min:0,max:1,dflt:1e-6,editType:"calc"},editType:"calc"},i.lighting),hoverinfo:s({},o.hoverinfo,{editType:"calc"}),showlegend:s({},o.showlegend,{dflt:!1})})},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plots/attributes":762,"../../plots/template_attributes":841,"../surface/attributes":1243}],1062:[function(t,e,r){"use strict";var n=t("../../components/colorscale/calc");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:"",cLetter:"c"})}},{"../../components/colorscale/calc":599}],1063:[function(t,e,r){"use strict";var n=t("gl-mesh3d"),a=t("delaunay-triangulate"),i=t("alpha-shape"),o=t("convex-hull"),s=t("../../lib/gl_format_color").parseColorScale,l=t("../../lib/str2rgbarray"),c=t("../../components/colorscale").extractOpts,u=t("../../plots/gl3d/zip3");function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name="",this.color="#fff",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function d(t,e,r,n){for(var a=[],i=e.length,o=0;o<i;o++)a[o]=t.d2l(e[o],0,n)*r;return a}function g(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function v(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}f.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.data._cellCenter?t.traceCoordinate=t.data.dataCoordinate:t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,h=t.x.length,f=u(d(r.xaxis,t.x,e.dataScale[0],t.xcalendar),d(r.yaxis,t.y,e.dataScale[1],t.ycalendar),d(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!v(t.i,h)||!v(t.j,h)||!v(t.k,h))return;n=u(g(t.i),g(t.j),g(t.k))}else n=0===t.alphahull?o(f):t.alphahull>0?i(t.alphahull,f):function(t,e){for(var r=["x","y","z"].indexOf(t),n=[],i=e.length,o=0;o<i;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return a(n)}(t.delaunayaxis,f);var m={positions:f,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var y=c(t);this.color="#fff";var x=t.intensitymode;m[x+"Intensity"]=t.intensity,m[x+"IntensityBounds"]=[y.min,y.max],m.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],m.vertexColors=p(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],m.cellColors=p(t.facecolor)):(this.color=t.color,m.meshColor=l(t.color));this.mesh.update(m)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,a=n({gl:r}),i=new h(t,a,e.uid);return a._trace=i,i.update(e),t.glplot.add(a),i}},{"../../components/colorscale":603,"../../lib/gl_format_color":714,"../../lib/str2rgbarray":740,"../../plots/gl3d/zip3":816,"alpha-shape":67,"convex-hull":132,"delaunay-triangulate":167,"gl-mesh3d":283}],1064:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("../../components/colorscale/defaults"),o=t("./attributes");e.exports=function(t,e,r,s){function l(r,n){return a.coerce(t,e,o,r,n)}function c(t){var e=t.map(function(t){var e=l(t);return e&&a.isArrayOrTypedArray(e)?e:null});return e.every(function(t){return t&&t.length===e[0].length})&&e}c(["x","y","z"])?(c(["i","j","k"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x","y","z"],s),["lighting.ambient","lighting.diffuse","lighting.specular","lighting.roughness","lighting.fresnel","lighting.vertexnormalsepsilon","lighting.facenormalsepsilon","lightposition.x","lightposition.y","lightposition.z","flatshading","alphahull","delaunayaxis","opacity"].forEach(function(t){l(t)}),l("contour.show")&&(l("contour.color"),l("contour.width")),"intensity"in t?(l("intensity"),l("intensitymode"),i(t,e,s,l,{prefix:"",cLetter:"c"})):(e.showscale=!1,"facecolor"in t?l("facecolor"):"vertexcolor"in t?l("vertexcolor"):l("color",r)),l("text"),l("hovertext"),l("hovertemplate"),e._length=null):e.visible=!1):e.visible=!1}},{"../../components/colorscale/defaults":601,"../../lib":717,"../../registry":846,"./attributes":1061}],1065:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc"),colorbar:{min:"cmin",max:"cmax"},plot:t("./convert"),moduleType:"trace",name:"mesh3d",basePlotModule:t("../../plots/gl3d"),categories:["gl3d","showLegend"],meta:{}}},{"../../plots/gl3d":805,"./attributes":1061,"./calc":1062,"./convert":1063,"./defaults":1064}],1066:[function(t,e,r){"use strict";var n=t("../../lib").extendFlat,a=t("../scatter/attributes"),i=t("../../components/drawing/attributes").dash,o=t("../../components/fx/attributes"),s=t("../../constants/delta.js"),l=s.INCREASING.COLOR,c=s.DECREASING.COLOR,u=a.line;function h(t){return{line:{color:n({},u.color,{dflt:t}),width:u.width,dash:i,editType:"style"},editType:"style"}}e.exports={x:{valType:"data_array",editType:"calc+clearAxisTypes"},open:{valType:"data_array",editType:"calc"},high:{valType:"data_array",editType:"calc"},low:{valType:"data_array",editType:"calc"},close:{valType:"data_array",editType:"calc"},line:{width:n({},u.width,{}),dash:n({},i,{}),editType:"style"},increasing:h(l),decreasing:h(c),text:{valType:"string",dflt:"",arrayOk:!0,editType:"calc"},hovertext:{valType:"string",dflt:"",arrayOk:!0,editType:"calc"},tickwidth:{valType:"number",min:0,max:.5,dflt:.3,editType:"calc"},hoverlabel:n({},o.hoverlabel,{split:{valType:"boolean",dflt:!1,editType:"style"}})}},{"../../components/drawing/attributes":611,"../../components/fx/attributes":621,"../../constants/delta.js":687,"../../lib":717,"../scatter/attributes":1120}],1067:[function(t,e,r){"use strict";var n=t("../../lib"),a=n._,i=t("../../plots/cartesian/axes"),o=t("../../constants/numerical").BADNUM;function s(t,e,r,n){return{o:t,h:e,l:r,c:n}}function l(t,e,r,s,l){for(var c=s.makeCalcdata(e,"open"),u=s.makeCalcdata(e,"high"),h=s.makeCalcdata(e,"low"),f=s.makeCalcdata(e,"close"),p=Array.isArray(e.text),d=Array.isArray(e.hovertext),g=!0,v=null,m=[],y=0;y<r.length;y++){var x=r[y],b=c[y],_=u[y],w=h[y],k=f[y];if(x!==o&&b!==o&&_!==o&&w!==o&&k!==o){k===b?null!==v&&k!==v&&(g=k>v):g=k>b,v=k;var T=l(b,_,w,k);T.pos=x,T.yc=(b+k)/2,T.i=y,T.dir=g?"increasing":"decreasing",T.x=T.pos,T.y=[w,_],p&&(T.tx=e.text[y]),d&&(T.htx=e.hovertext[y]),m.push(T)}else m.push({pos:x,empty:!0})}return e._extremes[s._id]=i.findExtremes(s,n.concat(h,u),{padded:!0}),m.length&&(m[0].t={labels:{open:a(t,"open:")+" ",high:a(t,"high:")+" ",low:a(t,"low:")+" ",close:a(t,"close:")+" "}}),m}e.exports={calc:function(t,e){var r=i.getFromId(t,e.xaxis),a=i.getFromId(t,e.yaxis),o=function(t,e,r){var a=r._minDiff;if(!a){var i,o=t._fullData,s=[];for(a=1/0,i=0;i<o.length;i++){var l=o[i];if("ohlc"===l.type&&!0===l.visible&&l.xaxis===e._id){s.push(l);var c=e.makeCalcdata(l,"x");l._xcalc=c;var u=n.distinctVals(c).minDiff;u&&isFinite(u)&&(a=Math.min(a,u))}}for(a===1/0&&(a=1),i=0;i<s.length;i++)s[i]._minDiff=a}return a*r.tickwidth}(t,r,e),c=e._minDiff;e._minDiff=null;var u=e._xcalc;e._xcalc=null;var h=l(t,e,u,a,s);return e._extremes[r._id]=i.findExtremes(r,u,{vpad:c/2}),h.length?(n.extendFlat(h[0].t,{wHover:c/2,tickLen:o}),h):[{t:{empty:!0}}]},calcCommon:l}},{"../../constants/numerical":693,"../../lib":717,"../../plots/cartesian/axes":765}],1068:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./ohlc_defaults"),i=t("./attributes");function o(t,e,r,n){r(n+".line.color"),r(n+".line.width",e.line.width),r(n+".line.dash",e.line.dash)}e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}a(t,e,l,s)?(l("line.width"),l("line.dash"),o(t,e,l,"increasing"),o(t,e,l,"decreasing"),l("text"),l("hovertext"),l("tickwidth"),s._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{"../../lib":717,"./attributes":1066,"./ohlc_defaults":1071}],1069:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../lib"),i=t("../../components/fx"),o=t("../../components/color"),s=t("../../lib").fillText,l=t("../../constants/delta.js"),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var a,s,l=t.cd,c=t.xa,u=l[0].trace,h=l[0].t,f=u.type,p="ohlc"===f?"l":"min",d="ohlc"===f?"h":"max",g=h.bPos||0,v=function(t){return t.pos+g-e},m=h.bdPos||h.tickLen,y=h.wHover,x=Math.min(1,m/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function b(t){var e=v(t);return i.inbox(e-y,e+y,a)}function _(t){var e=t[p],n=t[d];return e===n||i.inbox(e-r,n-r,a)}function w(t){return(b(t)+_(t))/2}a=t.maxHoverDistance-x,s=t.maxSpikeDistance-x;var k=i.getDistanceFunction(n,b,_,w);if(i.getClosest(l,k,t),!1===t.index)return null;var T=l[t.index];if(T.empty)return null;var M=u[T.dir],A=M.line.color;return o.opacity(A)&&M.line.width?t.color=A:t.color=M.fillcolor,t.x0=c.c2p(T.pos+g-m,!0),t.x1=c.c2p(T.pos+g+m,!0),t.xLabelVal=T.pos,t.spikeDistance=w(T)*s/a,t.xSpike=c.c2p(T.pos,!0),t}function h(t,e,r,i){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,h=[],f=u(t,e,r,i);if(!f)return[];var p=o[f.index].hi||l.hoverinfo,d=p.split("+");if(!("all"===p||-1!==d.indexOf("y")))return[];for(var g=["high","open","close","low"],v={},m=0;m<g.length;m++){var y,x=g[m],b=l[x][f.index],_=s.c2p(b,!0);b in v?(y=v[b]).yLabel+="<br>"+c.labels[x]+n.hoverLabelText(s,b):((y=a.extendFlat({},f)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=c.labels[x]+n.hoverLabelText(s,b),y.name="",h.push(y),v[b]=y)}return h}function f(t,e,r,a){var i=t.cd,o=t.ya,l=i[0].trace,h=i[0].t,f=u(t,e,r,a);if(!f)return[];var p=i[f.index],d=f.index=p.i,g=p.dir;function v(t){return h.labels[t]+n.hoverLabelText(o,l[t][d])}var m=p.hi||l.hoverinfo,y=m.split("+"),x="all"===m,b=x||-1!==y.indexOf("y"),_=x||-1!==y.indexOf("text"),w=b?[v("open"),v("high"),v("low"),v("close")+"  "+c[g]]:[];return _&&s(p,l,w),f.extraText=w.join("<br>"),f.y0=f.y1=o.c2p(p.yc,!0),[f]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?h(t,e,r,n):f(t,e,r,n)},hoverSplit:h,hoverOnPoints:f}},{"../../components/color":591,"../../components/fx":630,"../../constants/delta.js":687,"../../lib":717,"../../plots/cartesian/axes":765}],1070:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"ohlc",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","showLegend"],meta:{},attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc").calc,plot:t("./plot"),style:t("./style"),hoverPoints:t("./hover").hoverPoints,selectPoints:t("./select")}},{"../../plots/cartesian":776,"./attributes":1066,"./calc":1067,"./defaults":1068,"./hover":1069,"./plot":1072,"./select":1073,"./style":1074}],1071:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib");e.exports=function(t,e,r,i){var o=r("x"),s=r("open"),l=r("high"),c=r("low"),u=r("close");if(r("hoverlabel.split"),n.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x"],i),s&&l&&c&&u){var h=Math.min(s.length,l.length,c.length,u.length);return o&&(h=Math.min(h,a.minRowLength(o))),e._length=h,h}}},{"../../lib":717,"../../registry":846}],1072:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib");e.exports=function(t,e,r,i){var o=e.xaxis,s=e.yaxis;a.makeTraceGroups(i,r,"trace ohlc").each(function(t){var e=n.select(this),r=t[0],i=r.t;if(!0!==r.trace.visible||i.empty)e.remove();else{var l=i.tickLen,c=e.selectAll("path").data(a.identity);c.enter().append("path"),c.exit().remove(),c.attr("d",function(t){if(t.empty)return"M0,0Z";var e=o.c2p(t.pos,!0),r=o.c2p(t.pos-l,!0),n=o.c2p(t.pos+l,!0);return"M"+r+","+s.c2p(t.o,!0)+"H"+e+"M"+e+","+s.c2p(t.h,!0)+"V"+s.c2p(t.l,!0)+"M"+n+","+s.c2p(t.c,!0)+"H"+e})}})}},{"../../lib":717,d3:165}],1073:[function(t,e,r){"use strict";e.exports=function(t,e){var r,n=t.cd,a=t.xaxis,i=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([a.c2p(l.pos+s),i.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:a.c2d(l.pos),y:i.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1074:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/drawing"),i=t("../../components/color");e.exports=function(t,e,r){var o=r||n.select(t).selectAll("g.ohlclayer").selectAll("g.trace");o.style("opacity",function(t){return t[0].trace.opacity}),o.each(function(t){var e=t[0].trace;n.select(this).selectAll("path").each(function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style("fill","none").call(i.stroke,r.color).call(a.dashLine,r.dash,r.width).style("opacity",e.selectedpoints&&!t.selected?.3:1)}})})}},{"../../components/color":591,"../../components/drawing":612,d3:165}],1075:[function(t,e,r){"use strict";var n=t("../../lib/extend").extendFlat,a=t("../../plots/attributes"),i=t("../../plots/font_attributes"),o=t("../../components/colorscale/attributes"),s=t("../../plots/template_attributes").hovertemplateAttrs,l=t("../../plots/domain").attributes,c=n({editType:"calc"},o("line",{editTypeOverride:"calc"}),{shape:{valType:"enumerated",values:["linear","hspline"],dflt:"linear",editType:"plot"},hovertemplate:s({editType:"plot",arrayOk:!1},{keys:["count","probability"]})});e.exports={domain:l({name:"parcats",trace:!0,editType:"calc"}),hoverinfo:n({},a.hoverinfo,{flags:["count","probability"],editType:"plot",arrayOk:!1}),hoveron:{valType:"enumerated",values:["category","color","dimension"],dflt:"category",editType:"plot"},hovertemplate:s({editType:"plot",arrayOk:!1},{keys:["count","probability","category","categorycount","colorcount","bandcolorcount"]}),arrangement:{valType:"enumerated",values:["perpendicular","freeform","fixed"],dflt:"perpendicular",editType:"plot"},bundlecolors:{valType:"boolean",dflt:!0,editType:"plot"},sortpaths:{valType:"enumerated",values:["forward","backward"],dflt:"forward",editType:"plot"},labelfont:i({editType:"calc"}),tickfont:i({editType:"calc"}),dimensions:{_isLinkedToArray:"dimension",label:{valType:"string",editType:"calc"},categoryorder:{valType:"enumerated",values:["trace","category ascending","category descending","array"],dflt:"trace",editType:"calc"},categoryarray:{valType:"data_array",editType:"calc"},ticktext:{valType:"data_array",editType:"calc"},values:{valType:"data_array",dflt:[],editType:"calc"},displayindex:{valType:"integer",editType:"calc"},editType:"calc",visible:{valType:"boolean",dflt:!0,editType:"calc"}},line:c,counts:{valType:"number",min:0,dflt:1,arrayOk:!0,editType:"calc"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plots/attributes":762,"../../plots/domain":790,"../../plots/font_attributes":791,"../../plots/template_attributes":841}],1076:[function(t,e,r){"use strict";var n=t("../../plots/get_data").getModuleCalcData,a=t("./plot");r.name="parcats",r.plot=function(t,e,r,i){var o=n(t.calcdata,"parcats");if(o.length){var s=o[0];a(t,s,r,i)}},r.clean=function(t,e,r,n){var a=n._has&&n._has("parcats"),i=e._has&&e._has("parcats");a&&!i&&n._paperdiv.selectAll(".parcats").remove()}},{"../../plots/get_data":800,"./plot":1081}],1077:[function(t,e,r){"use strict";var n=t("../../lib/gup").wrap,a=t("../../components/colorscale/helpers").hasColorscale,i=t("../../components/colorscale/calc"),o=t("../../lib/filter_unique.js"),s=t("../../components/drawing"),l=t("../../lib");function c(t,e,r){t.valueInds.push(e),t.count+=r}function u(t,e,r){return{categoryInds:t,color:e,rawColor:r,valueInds:[],count:0}}function h(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var f,p,d,g=r.map(function(t){var e;return"trace"===t.categoryorder?e=null:"array"===t.categoryorder?e=t.categoryarray:(e=o(t.values).sort(),"category descending"===t.categoryorder&&(e=e.reverse())),function(t,e){e=null==e?[]:e.map(function(t){return t});var r={},n={},a=[];e.forEach(function(t,e){r[t]=0,n[t]=e});for(var i=0;i<t.length;i++){var o,s=t[i];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),a.push(o)}var l=e.map(function(t){return r[t]});return{uniqueValues:e,uniqueCounts:l,inds:a}}(t.values,e)});f=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map(function(t){return t.displayindex})))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach(function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,g[e])});var v,m=e.line;m?(a(e,"line")&&i(t,e,{vals:e.line.color,containerStr:"line",cLetter:"c"}),v=s.tryColorscale(m)):v=l.identity;var y,x,b,_,w,k=r[0].values.length,T={},M=g.map(function(t){return t.inds});for(d=0,y=0;y<k;y++){var A=[];for(x=0;x<M.length;x++)A.push(M[x][y]);p=f[y%f.length],d+=p;var S=(b=y,_=void 0,w=void 0,l.isArrayOrTypedArray(m.color)?w=_=m.color[b%m.color.length]:_=m.color,{color:v(_),rawColor:w}),E=A+"-"+S.rawColor;void 0===T[E]&&(T[E]=u(A,S.color,S.rawColor)),h(T[E],y,p)}var L,C=r.map(function(t,e){return r=e,n=t._index,a=t._displayindex,i=t.label,{dimensionInd:r,containerInd:n,displayInd:a,dimensionLabel:i,count:d,categories:[],dragX:null};var r,n,a,i});for(y=0;y<k;y++)for(p=f[y%f.length],x=0;x<C.length;x++){var P=C[x].containerInd,O=g[x].inds[y],z=C[x].categories;if(void 0===z[O]){var I=e.dimensions[P]._categoryarray[O],D=e.dimensions[P]._ticktext[O];z[O]={dimensionInd:x,categoryInd:L=O,categoryValue:I,displayInd:L,categoryLabel:D,valueInds:[],count:0,dragY:null}}c(z[O],y,p)}return n(function(t,e,r){var n=t.map(function(t){return t.categories.length}).reduce(function(t,e){return Math.max(t,e)});return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(C,T,d))}},{"../../components/colorscale/calc":599,"../../components/colorscale/helpers":602,"../../components/drawing":612,"../../lib":717,"../../lib/filter_unique.js":709,"../../lib/gup":715}],1078:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/colorscale/helpers").hasColorscale,i=t("../../components/colorscale/defaults"),o=t("../../plots/domain").defaults,s=t("../../plots/array_container_defaults"),l=t("./attributes"),c=t("../parcoords/merge_length");function u(t,e){function r(r,a){return n.coerce(t,e,l.dimensions,r,a)}var a=r("values"),i=r("visible");if(a&&a.length||(i=e.visible=!1),i){r("label"),r("displayindex",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o="array");var u=r("categoryorder",o);"array"===u?(r("categoryarray"),r("ticktext")):(delete t.categoryarray,delete t.ticktext),c||"array"!==u||(e.categoryorder="trace")}}e.exports=function(t,e,r,h){function f(r,a){return n.coerce(t,e,l,r,a)}var p=s(t,e,{name:"dimensions",handleItemDefaults:u}),d=function(t,e,r,o,s){s("line.shape"),s("line.hovertemplate");var l=s("line.color",o.colorway[0]);if(a(t,"line")&&n.isArrayOrTypedArray(l)){if(l.length)return s("line.colorscale"),i(t,e,o,s,{prefix:"line.",cLetter:"c"}),l.length;e.line.color=r}return 1/0}(t,e,r,h,f);o(e,h,f),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,"values",d),f("hoveron"),f("hovertemplate"),f("arrangement"),f("bundlecolors"),f("sortpaths"),f("counts");var g={family:h.font.family,size:Math.round(h.font.size),color:h.font.color};n.coerceFont(f,"labelfont",g);var v={family:h.font.family,size:Math.round(h.font.size/1.2),color:h.font.color};n.coerceFont(f,"tickfont",v)}},{"../../components/colorscale/defaults":601,"../../components/colorscale/helpers":602,"../../lib":717,"../../plots/array_container_defaults":761,"../../plots/domain":790,"../parcoords/merge_length":1091,"./attributes":1075}],1079:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc"),plot:t("./plot"),colorbar:{container:"line",min:"cmin",max:"cmax"},moduleType:"trace",name:"parcats",basePlotModule:t("./base_plot"),categories:["noOpacity"],meta:{}}},{"./attributes":1075,"./base_plot":1076,"./calc":1077,"./defaults":1078,"./plot":1081}],1080:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../plot_api/plot_api"),i=t("../../components/fx"),o=t("../../lib"),s=t("../../components/drawing"),l=t("tinycolor2"),c=t("../../lib/svg_text_utils");function u(t,e,r,a){var i=t.map(function(t,e,r){var n,a=r[0],i=e.margin||{l:80,r:80,t:100,b:80},o=a.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),h=Math.floor(c*(s.y[1]-s.y[0])),f=s.x[0]*l+i.l,p=e.height-s.y[1]*e.height+i.t,d=o.line.shape;n="all"===o.hoverinfo?["count","probability"]:(o.hoverinfo||"").split("+");var g={trace:o,key:o.uid,model:a,x:f,y:p,width:u,height:h,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:i,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};a.dimensions&&(F(g),R(g));return g}.bind(0,e,r)),l=a.selectAll("g.parcatslayer").data([null]);l.enter().append("g").attr("class","parcatslayer").style("pointer-events","all");var u=l.selectAll("g.trace.parcats").data(i,h),v=u.enter().append("g").attr("class","trace parcats");u.attr("transform",function(t){return"translate("+t.x+", "+t.y+")"}),v.append("g").attr("class","paths");var m=u.select("g.paths").selectAll("path.path").data(function(t){return t.paths},h);m.attr("fill",function(t){return t.model.color});var b=m.enter().append("path").attr("class","path").attr("stroke-opacity",0).attr("fill",function(t){return t.model.color}).attr("fill-opacity",0);x(b),m.attr("d",function(t){return t.svgD}),b.empty()||m.sort(p),m.exit().remove(),m.on("mouseover",d).on("mouseout",g).on("click",y),v.append("g").attr("class","dimensions");var k=u.select("g.dimensions").selectAll("g.dimension").data(function(t){return t.dimensions},h);k.enter().append("g").attr("class","dimension"),k.attr("transform",function(t){return"translate("+t.x+", 0)"}),k.exit().remove();var T=k.selectAll("g.category").data(function(t){return t.categories},h),M=T.enter().append("g").attr("class","category");T.attr("transform",function(t){return"translate(0, "+t.y+")"}),M.append("rect").attr("class","catrect").attr("pointer-events","none"),T.select("rect.catrect").attr("fill","none").attr("width",function(t){return t.width}).attr("height",function(t){return t.height}),_(M);var A=T.selectAll("rect.bandrect").data(function(t){return t.bands},h);A.each(function(){o.raiseToTop(this)}),A.attr("fill",function(t){return t.color});var O=A.enter().append("rect").attr("class","bandrect").attr("stroke-opacity",0).attr("fill",function(t){return t.color}).attr("fill-opacity",0);A.attr("fill",function(t){return t.color}).attr("width",function(t){return t.width}).attr("height",function(t){return t.height}).attr("y",function(t){return t.y}).attr("cursor",function(t){return"fixed"===t.parcatsViewModel.arrangement?"default":"perpendicular"===t.parcatsViewModel.arrangement?"ns-resize":"move"}),w(O),A.exit().remove(),M.append("text").attr("class","catlabel").attr("pointer-events","none");var z=e._fullLayout.paper_bgcolor;T.select("text.catlabel").attr("text-anchor",function(t){return f(t)?"start":"end"}).attr("alignment-baseline","middle").style("text-shadow",z+" -1px  1px 2px, "+z+" 1px  1px 2px, "+z+"  1px -1px 2px, "+z+" -1px -1px 2px").style("fill","rgb(0, 0, 0)").attr("x",function(t){return f(t)?t.width+5:-5}).attr("y",function(t){return t.height/2}).text(function(t){return t.model.categoryLabel}).each(function(t){s.font(n.select(this),t.parcatsViewModel.categorylabelfont),c.convertToTspans(n.select(this),e)}),M.append("text").attr("class","dimlabel"),T.select("text.dimlabel").attr("text-anchor","middle").attr("alignment-baseline","baseline").attr("cursor",function(t){return"fixed"===t.parcatsViewModel.arrangement?"default":"ew-resize"}).attr("x",function(t){return t.width/2}).attr("y",-5).text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}).each(function(t){s.font(n.select(this),t.parcatsViewModel.labelfont)}),T.selectAll("rect.bandrect").on("mouseover",S).on("mouseout",E),T.exit().remove(),k.call(n.behavior.drag().origin(function(t){return{x:t.x,y:0}}).on("dragstart",L).on("drag",C).on("dragend",P)),u.each(function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll("g.paths").selectAll("path.path"),t.dimensionSelection=n.select(this).selectAll("g.dimensions").selectAll("g.dimension")}),u.exit().remove()}function h(t){return t.key}function f(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function p(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function d(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf("skip")){o.raiseToTop(this),b(n.select(this));var e=v(t),r=m(t);if(t.parcatsViewModel.graphDiv.emit("plotly_hover",{points:e,event:n.event,constraints:r}),-1===t.parcatsViewModel.hoverinfoItems.indexOf("none")){var a,s,c,u=n.mouse(this)[0],h=t.parcatsViewModel.graphDiv,f=t.parcatsViewModel.trace,p=h._fullLayout,d=p._paperdiv.node().getBoundingClientRect(),g=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(c=0;c<t.leftXs.length-1;c++)if(t.leftXs[c]+t.dimWidths[c]-2<=u&&u<=t.leftXs[c+1]+2){var y=t.parcatsViewModel.dimensions[c],x=t.parcatsViewModel.dimensions[c+1];a=(y.x+y.width+x.x)/2,s=(t.topYs[c]+t.topYs[c+1]+t.height)/2;break}var _=t.parcatsViewModel.x+a,w=t.parcatsViewModel.y+s,k=l.mostReadable(t.model.color,["black","white"]),T=t.model.count,M=T/t.parcatsViewModel.model.count,A={countLabel:T,probabilityLabel:M.toFixed(3)},S=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf("count")&&S.push(["Count:",A.countLabel].join(" ")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf("probability")&&S.push(["P:",A.probabilityLabel].join(" "));var E=S.join("<br>"),L=n.mouse(h)[0];i.loneHover({trace:f,x:_-d.left+g.left,y:w-d.top+g.top,text:E,color:t.model.color,borderColor:"black",fontFamily:'Monaco, "Courier New", monospace',fontSize:10,fontColor:k,idealAlign:L<_?"right":"left",hovertemplate:(f.line||{}).hovertemplate,hovertemplateLabels:A,eventData:[{data:f._input,fullData:f,count:T,probability:M}]},{container:p._hoverlayer.node(),outerContainer:p._paper.node(),gd:h})}}}function g(t){if(!t.parcatsViewModel.dragDimension&&(x(n.select(this)),i.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(p),-1===t.parcatsViewModel.hoverinfoItems.indexOf("skip"))){var e=v(t),r=m(t);t.parcatsViewModel.graphDiv.emit("plotly_unhover",{points:e,event:n.event,constraints:r})}}function v(t){for(var e=[],r=O(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var a=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:a})}return e}function m(t){for(var e={},r=t.parcatsViewModel.model.dimensions,n=0;n<r.length;n++){var a=r[n],i=a.categories[t.model.categoryInds[n]];e[a.containerInd]=i.categoryValue}return void 0!==t.model.rawColor&&(e.color=t.model.rawColor),e}function y(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf("skip")){var e=v(t),r=m(t);t.parcatsViewModel.graphDiv.emit("plotly_click",{points:e,event:n.event,constraints:r})}}function x(t){t.attr("fill",function(t){return t.model.color}).attr("fill-opacity",.6).attr("stroke","lightgray").attr("stroke-width",.2).attr("stroke-opacity",1)}function b(t){t.attr("fill-opacity",.8).attr("stroke",function(t){return l.mostReadable(t.model.color,["black","white"])}).attr("stroke-width",.3)}function _(t){t.select("rect.catrect").attr("stroke","black").attr("stroke-width",1).attr("stroke-opacity",1)}function w(t){t.attr("stroke","black").attr("stroke-width",.2).attr("stroke-opacity",1).attr("fill-opacity",1)}function k(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter(function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color})}function T(t,e,r){var a=n.select(t).datum(),i=a.categoryViewModel.model,o=a.parcatsViewModel.graphDiv,s=n.select(t.parentNode).selectAll("rect.bandrect"),l=[];s.each(function(t){k(t).each(function(t){Array.prototype.push.apply(l,v(t))})});var c={};c[i.dimensionInd]=i.categoryValue,o.emit(e,{points:l,event:r,constraints:c})}function M(t,e,r){var a=n.select(t).datum(),i=a.categoryViewModel.model,o=a.parcatsViewModel.graphDiv,s=k(a),l=[];s.each(function(t){Array.prototype.push.apply(l,v(t))});var c={};c[i.dimensionInd]=i.categoryValue,void 0!==a.rawColor&&(c.color=a.rawColor),o.emit(e,{points:l,event:r,constraints:c})}function A(t,e){var r,a,i=n.select(e.parentNode).select("rect.catrect"),o=i.node().getBoundingClientRect(),s=i.datum(),l=s.parcatsViewModel,c=l.model.dimensions[s.model.dimensionInd],u=l.trace,h=o.top+o.height/2;l.dimensions.length>1&&c.displayInd===l.dimensions.length-1?(r=o.left,a="left"):(r=o.left+o.width,a="right");var f=s.model.count,p=s.model.categoryLabel,d=f/s.parcatsViewModel.model.count,g={countLabel:f,categoryLabel:p,probabilityLabel:d.toFixed(3)},v=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf("count")&&v.push(["Count:",g.countLabel].join(" ")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf("probability")&&v.push(["P("+g.categoryLabel+"):",g.probabilityLabel].join(" "));var m=v.join("<br>");return{trace:u,x:r-t.left,y:h-t.top,text:m,color:"lightgray",borderColor:"black",fontFamily:'Monaco, "Courier New", monospace',fontSize:12,fontColor:"black",idealAlign:a,hovertemplate:u.hovertemplate,hovertemplateLabels:g,eventData:[{data:u._input,fullData:u,count:f,category:p,probability:d}]}}function S(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf("skip")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,a=r._fullLayout,s=a._paperdiv.node().getBoundingClientRect(),c=t.parcatsViewModel.hoveron;if("color"===c?(!function(t){var e=n.select(t).datum(),r=k(e);b(r),r.each(function(){o.raiseToTop(this)}),n.select(t.parentNode).selectAll("rect.bandrect").filter(function(t){return t.color===e.color}).each(function(){o.raiseToTop(this),n.select(this).attr("stroke","black").attr("stroke-width",1.5)})}(this),M(this,"plotly_hover",n.event)):(!function(t){n.select(t.parentNode).selectAll("rect.bandrect").each(function(t){var e=k(t);b(e),e.each(function(){o.raiseToTop(this)})}),n.select(t.parentNode).select("rect.catrect").attr("stroke","black").attr("stroke-width",2.5)}(this),T(this,"plotly_hover",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf("none"))"category"===c?e=A(s,this):"color"===c?e=function(t,e){var r,a,i=e.getBoundingClientRect(),o=n.select(e).datum(),s=o.categoryViewModel,c=s.parcatsViewModel,u=c.model.dimensions[s.model.dimensionInd],h=c.trace,f=i.y+i.height/2;c.dimensions.length>1&&u.displayInd===c.dimensions.length-1?(r=i.left,a="left"):(r=i.left+i.width,a="right");var p=s.model.categoryLabel,d=o.parcatsViewModel.model.count,g=0;o.categoryViewModel.bands.forEach(function(t){t.color===o.color&&(g+=t.count)});var v=s.model.count,m=0;c.pathSelection.each(function(t){t.model.color===o.color&&(m+=t.model.count)});var y=g/d,x=g/m,b=g/v,_={countLabel:d,categoryLabel:p,probabilityLabel:y.toFixed(3)},w=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf("count")&&w.push(["Count:",_.countLabel].join(" ")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf("probability")&&(w.push("P(color \u2229 "+p+"): "+_.probabilityLabel),w.push("P("+p+" | color): "+x.toFixed(3)),w.push("P(color | "+p+"): "+b.toFixed(3)));var k=w.join("<br>"),T=l.mostReadable(o.color,["black","white"]);return{trace:h,x:r-t.left,y:f-t.top,text:k,color:o.color,borderColor:"black",fontFamily:'Monaco, "Courier New", monospace',fontColor:T,fontSize:10,idealAlign:a,hovertemplate:h.hovertemplate,hovertemplateLabels:_,eventData:[{data:h._input,fullData:h,category:p,count:d,probability:y,categorycount:v,colorcount:m,bandcolorcount:g}]}}(s,this):"dimension"===c&&(e=function(t,e){var r=[];return n.select(e.parentNode.parentNode).selectAll("g.category").select("rect.catrect").each(function(){r.push(A(t,this))}),r}(s,this)),e&&i.loneHover(e,{container:a._hoverlayer.node(),outerContainer:a._paper.node(),gd:r})}}function E(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(x(e.pathSelection),_(e.dimensionSelection.selectAll("g.category")),w(e.dimensionSelection.selectAll("g.category").selectAll("rect.bandrect")),i.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(p),-1===e.hoverinfoItems.indexOf("skip"))){"color"===t.parcatsViewModel.hoveron?M(this,"plotly_unhover",n.event):T(this,"plotly_unhover",n.event)}}function L(t){"fixed"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll("g.category").select("rect.catrect").each(function(e){var r=n.mouse(this)[0],a=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=a&&a<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map(function(t){return t.displayInd}),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll("rect.bandrect").each(function(e){e.y<a&&a<=e.y+e.height&&(t.potentialClickBand=this)}))}),t.parcatsViewModel.dragDimension=t,i.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function C(t){if("fixed"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,a=e+1,i=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=i.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=i.categories,u=c[l-1],h=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==h&&s+o.height>h.y+h.height/2&&(o.model.displayInd=h.model.displayInd,h.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||"freeform"===t.parcatsViewModel.arrangement){i.model.dragX=n.event.x;var f=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[a];void 0!==f&&i.model.dragX<f.x+f.width&&(i.model.displayInd=f.model.displayInd,f.model.displayInd=e),void 0!==p&&i.model.dragX+i.width>p.x&&(i.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=i.model.displayInd}F(t.parcatsViewModel),R(t.parcatsViewModel),I(t.parcatsViewModel),z(t.parcatsViewModel)}}function P(t){if("fixed"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll("text").attr("font-weight","normal");var e={},r=O(t.parcatsViewModel),i=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),o=t.initialDragDimensionDisplayInds.some(function(t,e){return t!==i[e]});o&&i.forEach(function(r,n){var a=t.parcatsViewModel.model.dimensions[n].containerInd;e["dimensions["+a+"].displayindex"]=r});var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map(function(t){return t.displayInd});if(s=t.initialDragCategoryDisplayInds.some(function(t,e){return t!==l[e]})){var c=t.model.categories.slice().sort(function(t,e){return t.displayInd-e.displayInd}),u=c.map(function(t){return t.categoryValue}),h=c.map(function(t){return t.categoryLabel});e["dimensions["+t.model.containerInd+"].categoryarray"]=[u],e["dimensions["+t.model.containerInd+"].ticktext"]=[h],e["dimensions["+t.model.containerInd+"].categoryorder"]="array"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf("skip")&&!t.dragHasMoved&&t.potentialClickBand&&("color"===t.parcatsViewModel.hoveron?M(t.potentialClickBand,"plotly_click",n.event.sourceEvent):T(t.potentialClickBand,"plotly_click",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,F(t.parcatsViewModel),R(t.parcatsViewModel),n.transition().duration(300).ease("cubic-in-out").each(function(){I(t.parcatsViewModel,!0),z(t.parcatsViewModel,!0)}).each("end",function(){(o||s)&&a.restyle(t.parcatsViewModel.graphDiv,e,[r])})}}function O(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function z(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data(function(t){return t.paths},h),(r=t.pathSelection,e?r.transition():r).attr("d",function(t){return t.svgD})}function I(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data(function(t){return t.dimensions},h);var a=t.dimensionSelection.selectAll("g.category").data(function(t){return t.categories},h);r(t.dimensionSelection).attr("transform",function(t){return"translate("+t.x+", 0)"}),r(a).attr("transform",function(t){return"translate(0, "+t.y+")"}),a.select(".dimlabel").text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}),a.select(".catlabel").attr("text-anchor",function(t){return f(t)?"start":"end"}).attr("x",function(t){return f(t)?t.width+5:-5}).each(function(t){var e,r;f(t)?(e=t.width+5,r="start"):(e=-5,r="end"),n.select(this).selectAll("tspan").attr("x",e).attr("text-anchor",r)});var i=a.selectAll("rect.bandrect").data(function(t){return t.bands},h),s=i.enter().append("rect").attr("class","bandrect").attr("cursor","move").attr("stroke-opacity",0).attr("fill",function(t){return t.color}).attr("fill-opacity",0);i.attr("fill",function(t){return t.color}).attr("width",function(t){return t.width}).attr("height",function(t){return t.height}).attr("y",function(t){return t.y}),w(s),i.each(function(){o.raiseToTop(this)}),i.exit().remove()}function D(t,e,r,a,i){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(i)),c.push(o(1-i));var u="M "+t[0]+","+e[0];for(u+="l"+r[0]+",0 ",s=1;s<r.length;s++)u+="C"+l[s-1]+","+e[s-1]+" "+c[s-1]+","+e[s]+" "+t[s]+","+e[s],u+="l"+r[s]+",0 ";for(u+="l0,"+a+" ",u+="l -"+r[r.length-1]+",0 ",s=r.length-2;s>=0;s--)u+="C"+c[s]+","+(e[s+1]+a)+" "+l[s]+","+(e[s]+a)+" "+(t[s]+r[s])+","+(e[s]+a),u+="l-"+r[s]+",0 ";return u+="Z"}function R(t){var e=t.dimensions,r=t.model,n=e.map(function(t){return t.categories.map(function(t){return t.y})}),a=t.model.dimensions.map(function(t){return t.categories.map(function(t){return t.displayInd})}),i=t.model.dimensions.map(function(t){return t.displayInd}),o=t.dimensions.map(function(t){return t.model.dimensionInd}),s=e.map(function(t){return t.x}),l=e.map(function(t){return t.width}),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function h(t){var e=t.categoryInds.map(function(t,e){return a[e][t]});return o.map(function(t){return e[t]})}c.sort(function(e,r){var n=h(e),a=h(r);return"backward"===t.sortpaths&&(n.reverse(),a.reverse()),n.push(e.valueInds[0]),a.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),a.unshift(r.rawColor)),n<a?-1:n>a?1:0});for(var f=new Array(c.length),p=e[0].model.count,d=e[0].categories.map(function(t){return t.height}).reduce(function(t,e){return t+e}),g=0;g<c.length;g++){var v,m=c[g];v=p>0?d*(m.count/p):0;for(var y,x=new Array(n.length),b=0;b<m.categoryInds.length;b++){var _=m.categoryInds[b],w=a[b][_],k=i[b];x[k]=n[k][w],n[k][w]+=v;var T=t.dimensions[k].categories[w],M=T.bands.length,A=T.bands[M-1];if(void 0===A||m.rawColor!==A.rawColor){var S=void 0===A?0:A.y+A.height;T.bands.push({key:S,color:m.color,rawColor:m.rawColor,height:v,width:T.width,count:m.count,y:S,categoryViewModel:T,parcatsViewModel:t})}else{var E=T.bands[M-1];E.height+=v,E.count+=m.count}}y="hspline"===t.pathShape?D(s,x,l,v,.5):D(s,x,l,v,0),f[g]={key:m.valueInds[0],model:m,height:v,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=f}function F(t){var e=t.model.dimensions.map(function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}});e.sort(function(t,e){return t.displayInd-e.displayInd});var r=[];for(var n in e){var a=e[n].dimensionInd,i=t.model.dimensions[a];r.push(B(t,i))}t.dimensions=r}function B(t,e){var r,n=t.model.dimensions.length,a=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*a;var i,o,s,l,c,u=[],h=t.model.maxCats,f=e.categories.length,p=e.count,d=t.height-8*(h-1),g=8*(h-f)/2,v=e.categories.map(function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}});for(v.sort(function(t,e){return t.displayInd-e.displayInd}),c=0;c<f;c++)l=v[c].categoryInd,o=e.categories[l],i=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:i,y:null!==o.dragY?o.dragY:g,bands:[],parcatsViewModel:t},g=g+i+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){u(r,t,n,e)}},{"../../components/drawing":612,"../../components/fx":630,"../../lib":717,"../../lib/svg_text_utils":741,"../../plot_api/plot_api":752,d3:165,tinycolor2:535}],1081:[function(t,e,r){"use strict";var n=t("./parcats");e.exports=function(t,e,r,a){var i=t._fullLayout,o=i._paper,s=i._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,a)}},{"./parcats":1080}],1082:[function(t,e,r){"use strict";var n=t("../../components/colorscale/attributes"),a=t("../../plots/cartesian/layout_attributes"),i=t("../../plots/font_attributes"),o=t("../../plots/domain").attributes,s=t("../../lib/extend").extendFlat,l=t("../../plot_api/plot_template").templatedArray;e.exports={domain:o({name:"parcoords",trace:!0,editType:"plot"}),labelangle:{valType:"angle",dflt:0,editType:"plot"},labelside:{valType:"enumerated",values:["top","bottom"],dflt:"top",editType:"plot"},labelfont:i({editType:"plot"}),tickfont:i({editType:"plot"}),rangefont:i({editType:"plot"}),dimensions:l("dimension",{label:{valType:"string",editType:"plot"},tickvals:s({},a.tickvals,{editType:"plot"}),ticktext:s({},a.ticktext,{editType:"plot"}),tickformat:s({},a.tickformat,{editType:"plot"}),visible:{valType:"boolean",dflt:!0,editType:"plot"},range:{valType:"info_array",items:[{valType:"number",editType:"plot"},{valType:"number",editType:"plot"}],editType:"plot"},constraintrange:{valType:"info_array",freeLength:!0,dimensions:"1-2",items:[{valType:"number",editType:"plot"},{valType:"number",editType:"plot"}],editType:"plot"},multiselect:{valType:"boolean",dflt:!0,editType:"plot"},values:{valType:"data_array",editType:"calc"},editType:"calc"}),line:s({editType:"calc"},n("line",{colorscaleDflt:"Viridis",autoColorDflt:!1,editTypeOverride:"calc"}))}},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plot_api/plot_template":755,"../../plots/cartesian/layout_attributes":777,"../../plots/domain":790,"../../plots/font_attributes":791}],1083:[function(t,e,r){"use strict";var n=t("./constants"),a=t("d3"),i=t("../../lib/gup").keyFun,o=t("../../lib/gup").repeat,s=t("../../lib").sorterAsc,l=n.bar.snapRatio;function c(t,e){return t*(1-l)+e*l}var u=n.bar.snapClose;function h(t,e){return t*(1-u)+e*u}function f(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var a=t?-1:1,i=0,o=e.length-1;if(a<0){var s=i;i=o,o=s}for(var l=e[i],u=l,f=i;a*f<a*o;f+=a){var p=f+a,d=e[p];if(a*r<a*h(l,d))return c(l,u);if(a*r<a*d||p===o)return c(d,l);u=l,l=d}}function p(t){t.attr("x",-n.bar.captureWidth/2).attr("width",n.bar.captureWidth)}function d(t){t.attr("visibility","visible").style("visibility","visible").attr("fill","yellow").attr("opacity",0)}function g(t){if(!t.brush.filterSpecified)return"0,"+t.height;for(var e,r,n,a=v(t.brush.filter.getConsolidated(),t.height),i=[0],o=a.length?a[0][0]:null,s=0;s<a.length;s++)r=(e=a[s])[1]-e[0],i.push(o),i.push(r),(n=s+1)<a.length&&(o=a[n][0]-e[1]);return i.push(t.height),i}function v(t,e){return t.map(function(t){return t.map(function(t){return Math.max(0,t*e)}).sort(s)})}function m(){a.select(document.body).style("cursor",null)}function y(t){t.attr("stroke-dasharray",g)}function x(t,e){var r=a.select(t).selectAll(".highlight, .highlight-shadow");y(e?r.transition().duration(n.bar.snapDuration).each("end",e):r)}function b(t,e){var r,a=t.brush,i=NaN,o={};if(a.filterSpecified){var s=t.height,l=a.filter.getConsolidated(),c=v(l,s),u=NaN,h=NaN,f=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(h=r?r-1:NaN,p&&p[0]>e){f=r;break}}if(i=u,isNaN(i)&&(i=isNaN(h)||isNaN(f)?isNaN(h)?f:h:e-c[h][1]<c[f][0]-e?h:f),!isNaN(i)){var d=c[i],g=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?"n":e<=.9*t[0]+.1*t[1]?"s":"ns"}(d,e);g&&(o.interval=l[i],o.intervalPix=d,o.region=g)}}if(t.ordinal&&!o.region){var m=t.unitTickvals,y=t.unitToPaddedPx.invert(e);for(r=0;r<m.length;r++){var x=[.25*m[Math.max(r-1,0)]+.75*m[r],.25*m[Math.min(r+1,m.length-1)]+.75*m[r]];if(y>=x[0]&&y<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function _(t,e){a.event.sourceEvent.stopPropagation();var r=e.height-a.mouse(t)[1]-2*n.verticalPadding,i=e.brush.svgBrush;i.wasDragged=!0,i._dragging=!0,i.grabbingBar?i.newExtent=[r-i.grabPoint,r+i.barLength-i.grabPoint].map(e.unitToPaddedPx.invert):i.newExtent=[i.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,i.extent=i.stayingIntervals.concat([i.newExtent]),i.brushCallback(e),x(t.parentNode)}function w(t,e){var r=b(e,e.height-a.mouse(t)[1]-2*n.verticalPadding),i="crosshair";r.clickableOrdinalRange?i="pointer":r.region&&(i=r.region+"-resize"),a.select(document.body).style("cursor",i)}function k(t){t.on("mousemove",function(t){a.event.preventDefault(),t.parent.inBrushDrag||w(this,t)}).on("mouseleave",function(t){t.parent.inBrushDrag||m()}).call(a.behavior.drag().on("dragstart",function(t){!function(t,e){a.event.sourceEvent.stopPropagation();var r=e.height-a.mouse(t)[1]-2*n.verticalPadding,i=e.unitToPaddedPx.invert(r),o=e.brush,s=b(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar="ns"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter(function(t){return t[0]!==l[0]&&t[1]!==l[1]})),c.startExtent=s.region?l["s"===s.region?1:0]:i,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)}).on("drag",function(t){_(this,t)}).on("dragend",function(t){!function(t,e){var r=e.brush,n=r.filter,i=r.svgBrush;i._dragging||(w(t,e),_(t,e),e.brush.svgBrush.wasDragged=!1),i._dragging=!1,a.event.sourceEvent.stopPropagation();var o=i.grabbingBar;if(i.grabbingBar=!1,i.grabLocation=void 0,e.parent.inBrushDrag=!1,m(),!i.wasDragged)return i.wasDragged=void 0,i.clickableOrdinalRange?r.filterSpecified&&e.multiselect?i.extent.push(i.clickableOrdinalRange):(i.extent=[i.clickableOrdinalRange],r.filterSpecified=!0):o?(i.extent=i.stayingIntervals,0===i.extent.length&&M(r)):M(r),i.brushCallback(e),x(t.parentNode),void i.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),i.newExtent=[f(0,l,i.newExtent[0],i.stayingIntervals),f(1,l,i.newExtent[1],i.stayingIntervals)];var c=i.newExtent[1]>i.newExtent[0];i.extent=i.stayingIntervals.concat(c?[i.newExtent]:[]),i.extent.length||M(r),i.brushCallback(e),c?x(t.parentNode,s):(s(),x(t.parentNode))}else s();i.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)}))}function T(t,e){return t[0]-e[0]}function M(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function A(t){for(var e,r=t.slice(),n=[],a=r.shift();a;){for(e=a.slice();(a=r.shift())&&a[0]<=e[1];)e[1]=Math.max(e[1],a[1]);n.push(e)}return n}e.exports={makeBrush:function(t,e,r,n,a,i){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map(function(t){return t.slice().sort(s)}).sort(T)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=A(r),e=r.reduce(function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]},[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=a,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map(function(t){return t.slice()})}(e).slice();e.filter.set(r),o()}),brushEndCallback:i}}},ensureAxisBrush:function(t){var e=t.selectAll("."+n.cn.axisBrush).data(o,i);e.enter().append("g").classed(n.cn.axisBrush,!0),function(t){var e=t.selectAll(".background").data(o);e.enter().append("rect").classed("background",!0).call(p).call(d).style("pointer-events","auto").attr("transform","translate(0 "+n.verticalPadding+")"),e.call(k).attr("height",function(t){return t.height-n.verticalPadding});var r=t.selectAll(".highlight-shadow").data(o);r.enter().append("line").classed("highlight-shadow",!0).attr("x",-n.bar.width/2).attr("stroke-width",n.bar.width+n.bar.strokeWidth).attr("stroke",n.bar.strokeColor).attr("opacity",n.bar.strokeOpacity).attr("stroke-linecap","butt"),r.attr("y1",function(t){return t.height}).call(y);var a=t.selectAll(".highlight").data(o);a.enter().append("line").classed("highlight",!0).attr("x",-n.bar.width/2).attr("stroke-width",n.bar.width-n.bar.strokeWidth).attr("stroke",n.bar.fillColor).attr("opacity",n.bar.fillOpacity).attr("stroke-linecap","butt"),a.attr("y1",function(t){return t.height}).call(y)}(e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map(function(t){return t.sort(s)}),t=e.multiselect?A(t.sort(T)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map(function(t){var e=[f(0,r,t[0],[]),f(1,r,t[1],[])];if(e[1]>e[0])return e}).filter(function(t){return t})).length)return}return t.length>1?t:t[0]}}},{"../../lib":717,"../../lib/gup":715,"./constants":1086,d3:165}],1084:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../plots/get_data").getModuleCalcData,i=t("./plot"),o=t("../../constants/xmlns_namespaces");r.name="parcoords",r.plot=function(t){var e=a(t.calcdata,"parcoords")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var a=n._has&&n._has("parcoords"),i=e._has&&e._has("parcoords");a&&!i&&(n._paperdiv.selectAll(".parcoords").remove(),n._glimages.selectAll("*").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(".svg-container");r.filter(function(t,e){return e===r.size()-1}).selectAll(".gl-canvas-context, .gl-canvas-focus").each(function(){var t=this.toDataURL("image/png");e.append("svg:image").attr({xmlns:o.svg,"xlink:href":t,preserveAspectRatio:"none",x:0,y:0,width:this.width,height:this.height})}),window.setTimeout(function(){n.selectAll("#filterBarPattern").attr("id","filterBarPattern")},60)}},{"../../constants/xmlns_namespaces":694,"../../plots/get_data":800,"./plot":1093,d3:165}],1085:[function(t,e,r){"use strict";var n=t("../../lib").isArrayOrTypedArray,a=t("../../components/colorscale"),i=t("../../lib/gup").wrap;e.exports=function(t,e){var r,o;return a.hasColorscale(e,"line")&&n(e.line.color)?(r=e.line.color,o=a.extractOpts(e.line).colorscale,a.calc(t,e,{vals:r,containerStr:"line",cLetter:"c"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),i({lineColor:r,cscale:o})}},{"../../components/colorscale":603,"../../lib":717,"../../lib/gup":715}],1086:[function(t,e,r){"use strict";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:["contextLineLayer","focusLineLayer","pickLineLayer"],axisTitleOffset:28,axisExtentOffset:10,deselectedLineColor:"#777",bar:{width:4,captureWidth:10,fillColor:"magenta",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeColor:"white",strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:"axis-extent-text",parcoordsLineLayers:"parcoords-line-layers",parcoordsLineLayer:"parcoords-lines",parcoords:"parcoords",parcoordsControlView:"parcoords-control-view",yAxis:"y-axis",axisOverlays:"axis-overlays",axis:"axis",axisHeading:"axis-heading",axisTitle:"axis-title",axisExtent:"axis-extent",axisExtentTop:"axis-extent-top",axisExtentTopText:"axis-extent-top-text",axisExtentBottom:"axis-extent-bottom",axisExtentBottomText:"axis-extent-bottom-text",axisBrush:"axis-brush"},id:{filterBarPattern:"filter-bar-pattern"}}},{}],1087:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/colorscale/helpers").hasColorscale,i=t("../../components/colorscale/defaults"),o=t("../../plots/domain").defaults,s=t("../../plots/array_container_defaults"),l=t("../../plots/cartesian/axes"),c=t("./attributes"),u=t("./axisbrush"),h=t("./constants").maxDimensionCount,f=t("./merge_length");function p(t,e,r,a){function i(r,a){return n.coerce(t,e,c.dimensions,r,a)}var o=i("values"),s=i("visible");if(o&&o.length||(s=e.visible=!1),s){i("label"),i("tickvals"),i("ticktext"),i("tickformat");var h=i("range");e._ax={_id:"y",type:"linear",showexponent:"all",exponentformat:"B",range:h},l.setConvert(e._ax,a.layout),i("multiselect");var f=i("constraintrange");f&&(e.constraintrange=u.cleanRanges(f,e))}}e.exports=function(t,e,r,l){function u(r,a){return n.coerce(t,e,c,r,a)}var d=t.dimensions;Array.isArray(d)&&d.length>h&&(n.log("parcoords traces support up to "+h+" dimensions at the moment"),d.splice(h));var g=s(t,e,{name:"dimensions",layout:l,handleItemDefaults:p}),v=function(t,e,r,o,s){var l=s("line.color",r);if(a(t,"line")&&n.isArrayOrTypedArray(l)){if(l.length)return s("line.colorscale"),i(t,e,o,s,{prefix:"line.",cLetter:"c"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(g)&&g.length||(e.visible=!1),f(e,g,"values",v);var m={family:l.font.family,size:Math.round(l.font.size/1.2),color:l.font.color};n.coerceFont(u,"labelfont",m),n.coerceFont(u,"tickfont",m),n.coerceFont(u,"rangefont",m),u("labelangle"),u("labelside")}},{"../../components/colorscale/defaults":601,"../../components/colorscale/helpers":602,"../../lib":717,"../../plots/array_container_defaults":761,"../../plots/cartesian/axes":765,"../../plots/domain":790,"./attributes":1082,"./axisbrush":1083,"./constants":1086,"./merge_length":1091}],1088:[function(t,e,r){"use strict";var n=t("../../lib").isTypedArray;r.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},r.isOrdinal=function(t){return!!t.tickvals},r.isVisible=function(t){return t.visible||!("visible"in t)}},{"../../lib":717}],1089:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc"),plot:t("./plot"),colorbar:{container:"line",min:"cmin",max:"cmax"},moduleType:"trace",name:"parcoords",basePlotModule:t("./base_plot"),categories:["gl","regl","noOpacity","noHover"],meta:{}}},{"./attributes":1082,"./base_plot":1084,"./calc":1085,"./defaults":1087,"./plot":1093}],1090:[function(t,e,r){"use strict";var n=t("glslify"),a=n(["precision highp float;\n#define GLSLIFY 1\n\nvarying vec4 fragColor;\n\nattribute vec4 p01_04, p05_08, p09_12, p13_16,\n               p17_20, p21_24, p25_28, p29_32,\n               p33_36, p37_40, p41_44, p45_48,\n               p49_52, p53_56, p57_60, colors;\n\nuniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\n\nuniform vec2 resolution, viewBoxPos, viewBoxSize;\nuniform sampler2D mask, palette;\nuniform float maskHeight;\nuniform float drwLayer; // 0: context, 1: focus, 2: pick\nuniform vec4 contextColor;\n\nbool isPick    = (drwLayer > 1.5);\nbool isContext = (drwLayer < 0.5);\n\nconst vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\nconst vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\n\nfloat val(mat4 p, mat4 v) {\n    return dot(matrixCompMult(p, v) * UNITS, UNITS);\n}\n\nfloat axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\n    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\n    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\n    return y1 * (1.0 - ratio) + y2 * ratio;\n}\n\nint iMod(int a, int b) {\n    return a - b * (a / b);\n}\n\nbool fOutside(float p, float lo, float hi) {\n    return (lo < hi) && (lo > p || p > hi);\n}\n\nbool vOutside(vec4 p, vec4 lo, vec4 hi) {\n    return (\n        fOutside(p[0], lo[0], hi[0]) ||\n        fOutside(p[1], lo[1], hi[1]) ||\n        fOutside(p[2], lo[2], hi[2]) ||\n        fOutside(p[3], lo[3], hi[3])\n    );\n}\n\nbool mOutside(mat4 p, mat4 lo, mat4 hi) {\n    return (\n        vOutside(p[0], lo[0], hi[0]) ||\n        vOutside(p[1], lo[1], hi[1]) ||\n        vOutside(p[2], lo[2], hi[2]) ||\n        vOutside(p[3], lo[3], hi[3])\n    );\n}\n\nbool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\n    return mOutside(A, loA, hiA) ||\n           mOutside(B, loB, hiB) ||\n           mOutside(C, loC, hiC) ||\n           mOutside(D, loD, hiD);\n}\n\nbool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\n    mat4 pnts[4];\n    pnts[0] = A;\n    pnts[1] = B;\n    pnts[2] = C;\n    pnts[3] = D;\n\n    for(int i = 0; i < 4; ++i) {\n        for(int j = 0; j < 4; ++j) {\n            for(int k = 0; k < 4; ++k) {\n                if(0 == iMod(\n                    int(255.0 * texture2D(mask,\n                        vec2(\n                            (float(i * 2 + j / 2) + 0.5) / 8.0,\n                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\n                        ))[3]\n                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\n                    2\n                )) return true;\n            }\n        }\n    }\n    return false;\n}\n\nvec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\n    float x = 0.5 * sign(v) + 0.5;\n    float y = axisY(x, A, B, C, D);\n    float z = 1.0 - abs(v);\n\n    z += isContext ? 0.0 : 2.0 * float(\n        outsideBoundingBox(A, B, C, D) ||\n        outsideRasterMask(A, B, C, D)\n    );\n\n    return vec4(\n        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\n        z,\n        1.0\n    );\n}\n\nvoid main() {\n    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\n    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\n    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\n    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\n\n    float v = colors[3];\n\n    gl_Position = position(isContext, v, A, B, C, D);\n\n    fragColor =\n        isContext ? vec4(contextColor) :\n        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\n}\n"]),i=n(["precision highp float;\n#define GLSLIFY 1\n\nvarying vec4 fragColor;\n\nvoid main() {\n    gl_FragColor = fragColor;\n}\n"]),o=t("./constants").maxDimensionCount,s=t("../../lib"),l=1e-6,c=2048,u=new Uint8Array(4),h=new Uint8Array(4),f={shape:[256,1],format:"rgba",type:"uint8",mag:"nearest",min:"nearest"};function p(t,e,r,n,a){var i=t._gl;i.enable(i.SCISSOR_TEST),i.scissor(e,r,n,a),t.clear({color:[0,0,0,0],depth:1})}function d(t,e,r,n,a,i){var o=i.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:u})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,a-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],p(t,i.scissorX,i.scissorY,i.scissorWidth,i.viewBoxSize[1])),r.clearOnly||(i.count=2*c,i.offset=2*l*n,e(i),l*n+c<a&&(r.currentRafs[o]=window.requestAnimationFrame(function(){s(l+1)})),r.drawCompleted=!1)}(0)}function g(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}function v(t,e){return(t>>>8*e)%256/255}function m(t,e,r){for(var n=new Array(8*e),a=0,i=0;i<e;i++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*i+l];63===l&&0===o&&(c*=-1),n[a++]=c}return n}function y(t){var e="0"+t;return e.substr(e.length-2)}function x(t){return t<o?"p"+y(t+1)+"_"+y(t+4):"colors"}function b(t,e,r,n,a,i,o,l,c,u,h,f,p){for(var d=[[],[]],g=0;g<64;g++)d[0][g]=g===a?1:0,d[1][g]=g===i?1:0;var v=t.lines.canvasOverdrag,m=t.domain,y=t.canvasWidth,x=t.canvasHeight,b=t.deselectedLines.color;return s.extendFlat({key:h,resolution:[y,x],viewBoxPos:[o+v,l],viewBoxSize:[c,u],i0:a,i1:i,dim0A:d[0].slice(0,16),dim0B:d[0].slice(16,32),dim0C:d[0].slice(32,48),dim0D:d[0].slice(48,64),dim1A:d[1].slice(0,16),dim1B:d[1].slice(16,32),dim1C:d[1].slice(32,48),dim1D:d[1].slice(48,64),drwLayer:f,contextColor:[b[0]/255,b[1]/255,b[2]/255,b[3]<1?b[3]:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:o+v)+(t.pad.l-v)+t.layoutWidth*m.x[0],scissorWidth:(n===r?y-o+v:c+.5)+(n===e?o+v:0),scissorY:l+t.pad.b+t.layoutHeight*m.y[0],scissorHeight:u,viewportX:t.pad.l-v+t.layoutWidth*m.x[0],viewportY:t.pad.b+t.layoutHeight*m.y[0],viewportWidth:y,viewportHeight:x},p)}function _(t){var e=c-1,r=Math.max(0,Math.floor(t[0]*e),0),n=Math.min(e,Math.ceil(t[1]*e),e);return[Math.min(r,n),Math.max(r,n)]}e.exports=function(t,e){var r,n,u,y,w,k=e.context,T=e.pick,M=e.regl,A={currentRafs:{},drawCompleted:!0,clearOnly:!1},S=function(t){for(var e={},r=0;r<=o;r+=4)e[x(r)]=t.buffer({usage:"dynamic",type:"float",data:new Uint8Array(0)});return e}(M),E=M.texture(f),L=[];P(e);var C=M({profile:!1,blend:{enable:k,func:{srcRGB:"src alpha",dstRGB:"one minus src alpha",srcAlpha:1,dstAlpha:1},equation:{rgb:"add",alpha:"add"},color:[0,0,0,0]},depth:{enable:!k,mask:!0,func:"less",range:[0,1]},cull:{enable:!0,face:"back"},scissor:{enable:!0,box:{x:M.prop("scissorX"),y:M.prop("scissorY"),width:M.prop("scissorWidth"),height:M.prop("scissorHeight")}},viewport:{x:M.prop("viewportX"),y:M.prop("viewportY"),width:M.prop("viewportWidth"),height:M.prop("viewportHeight")},dither:!1,vert:a,frag:i,primitive:"lines",lineWidth:1,attributes:S,uniforms:{resolution:M.prop("resolution"),viewBoxPos:M.prop("viewBoxPos"),viewBoxSize:M.prop("viewBoxSize"),dim0A:M.prop("dim0A"),dim1A:M.prop("dim1A"),dim0B:M.prop("dim0B"),dim1B:M.prop("dim1B"),dim0C:M.prop("dim0C"),dim1C:M.prop("dim1C"),dim0D:M.prop("dim0D"),dim1D:M.prop("dim1D"),loA:M.prop("loA"),hiA:M.prop("hiA"),loB:M.prop("loB"),hiB:M.prop("hiB"),loC:M.prop("loC"),hiC:M.prop("hiC"),loD:M.prop("loD"),hiD:M.prop("hiD"),palette:E,contextColor:M.prop("contextColor"),mask:M.prop("maskTexture"),drwLayer:M.prop("drwLayer"),maskHeight:M.prop("maskHeight")},offset:M.prop("offset"),count:M.prop("count")});function P(t){r=t.model,n=t.viewModel,u=n.dimensions.slice(),y=u[0]?u[0].values.length:0;var e=r.lines,a=T?e.color.map(function(t,r){return r/e.color.length}):e.color,i=function(t,e,r){for(var n,a=new Array(t*(o+4)),i=0,s=0;s<t;s++){for(var c=0;c<o;c++)a[i++]=c<e.length?e[c].paddedUnitValues[s]:.5;a[i++]=v(s,2),a[i++]=v(s,1),a[i++]=v(s,0),a[i++]=(n=r[s],Math.max(l,Math.min(1-l,n)))}return a}(y,u,a);!function(t,e,r){for(var n=0;n<=o;n+=4)t[x(n)](m(n/4,e,r))}(S,y,i),k||T||(E=M.texture(s.extendFlat({data:g(r.unitToColor,255)},f)))}return{render:function(t,e,n){var a,i,o,s=t.length,l=1/0,h=-1/0;for(a=0;a<s;a++)t[a].dim0.canvasX<l&&(l=t[a].dim0.canvasX,i=a),t[a].dim1.canvasX>h&&(h=t[a].dim1.canvasX,o=a);0===s&&p(M,0,0,r.canvasWidth,r.canvasHeight);var f=function(t){var e,r,n,a=[[],[]];for(n=0;n<64;n++){var i=!t&&n<u.length?u[n].brush.filter.getBounds():[-1/0,1/0];a[0][n]=i[0],a[1][n]=i[1]}var o=8*c,s=new Array(o);for(e=0;e<o;e++)s[e]=255;if(!t)for(e=0;e<u.length;e++){var l=e%8,h=(e-l)/8,f=Math.pow(2,l),p=u[e].brush.filter.get();if(!(p.length<2)){var d=_(p[0])[1];for(r=1;r<p.length;r++){var g=_(p[r]);for(n=d+1;n<g[0];n++)s[8*n+h]&=~f;d=Math.max(d,g[1])}}}var v={shape:[8,c],format:"alpha",type:"uint8",mag:"nearest",min:"nearest",data:s};return w?w(v):w=M.texture(v),{maskTexture:w,maskHeight:c,loA:a[0].slice(0,16),loB:a[0].slice(16,32),loC:a[0].slice(32,48),loD:a[0].slice(48,64),hiA:a[1].slice(0,16),hiB:a[1].slice(16,32),hiC:a[1].slice(32,48),hiD:a[1].slice(48,64)}}(k);for(a=0;a<s;a++){var g=t[a],v=g.dim0.crossfilterDimensionIndex,m=g.dim1.crossfilterDimensionIndex,x=g.canvasX,S=g.canvasY,E=x+g.panelSizeX;if(e||!L[v]||L[v][0]!==x||L[v][1]!==E){L[v]=[x,E];var P=b(r,i,o,a,v,m,x,S,g.panelSizeX,g.panelSizeY,g.dim0.crossfilterDimensionIndex,k?0:T?2:1,f);A.clearOnly=n;var O=e?r.lines.blockLineCount:y;d(M,C,A,O,y,P)}}},readPixel:function(t,e){return M.read({x:t,y:e,width:1,height:1,data:h}),h},readPixels:function(t,e,r,n){var a=new Uint8Array(4*r*n);return M.read({x:t,y:e,width:r,height:n,data:a}),a},destroy:function(){for(var e in t.style["pointer-events"]="none",E.destroy(),w&&w.destroy(),S)S[e].destroy()},update:P}}},{"../../lib":717,"./constants":1086,glslify:410}],1091:[function(t,e,r){"use strict";e.exports=function(t,e,r,n){var a,i;for(n||(n=1/0),a=0;a<e.length;a++)(i=e[a]).visible&&(n=Math.min(n,i[r].length));for(n===1/0&&(n=0),t._length=n,a=0;a<e.length;a++)(i=e[a]).visible&&(i._length=n);return n}},{}],1092:[function(t,e,r){"use strict";var n=t("d3"),a=t("color-rgba"),i=t("../../plots/cartesian/axes"),o=t("../../lib"),s=t("../../lib/svg_text_utils"),l=t("../../components/drawing"),c=t("../../components/colorscale"),u=t("../../lib/gup"),h=u.keyFun,f=u.repeat,p=u.unwrap,d=t("./helpers"),g=t("./constants"),v=t("./axisbrush"),m=t("./lines");function y(t,e,r){return o.aggNums(t,null,e,r)}function x(t,e){return _(y(Math.min,t,e),y(Math.max,t,e))}function b(t){var e=t.range;return e?_(e[0],e[1]):x(t.values,t._length)}function _(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function w(t,e,r,a,i){var o,s,l=b(r);return a?n.scale.ordinal().domain(a.map((o=n.format(r.tickformat),s=i,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(a.map(function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)})):n.scale.linear().domain(l).range([t-e,e])}function k(t){if(t.tickvals){var e=b(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map(function(t){return(t-e[0])/(e[1]-e[0])}))}}function T(t){var e=t.map(function(t){return t[0]}),r=t.map(function(t){var e=a(t[1]);return n.rgb("rgb("+e[0]+","+e[1]+","+e[2]+")")}),i="rgb".split("").map(function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((a=t,function(t){return t[a]})));var a});return function(t){return i.map(function(e){return e(t)})}}function M(t){return t.dimensions.some(function(t){return t.brush.filterSpecified})}function A(t,e,r){var a=r.width,i=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return a*t/Math.max(1,r.colCount-1)},u=g.verticalPadding/i,h=function(t,e){return n.scale.linear().range([e,t-e])}(i,g.verticalPadding),f={key:r.key,xScale:c,model:r,inBrushDrag:!1},p={};return f.dimensions=s.filter(d.isVisible).map(function(a,s){var m=function(t,e){return n.scale.linear().domain(b(t)).range([e,1-e])}(a,u),y=p[a.label];p[a.label]=(y||0)+1;var x=a.label+(y?"__"+y:""),_=a.constraintrange,T=_&&_.length;T&&!Array.isArray(_[0])&&(_=[_]);var A=T?_.map(function(t){return t.map(m)}):[[-1/0,1/0]],S=a.values;S.length>a._length&&(S=S.slice(0,a._length));var E,L=a.tickvals;function C(t,e){return{val:t,text:E[e]}}function P(t,e){return t.val-e.val}if(Array.isArray(L)&&L.length){E=a.ticktext,Array.isArray(E)&&E.length?E.length>L.length?E=E.slice(0,L.length):L.length>E.length&&(L=L.slice(0,E.length)):E=L.map(n.format(a.tickformat));for(var O=1;O<L.length;O++)if(L[O]<L[O-1]){for(var z=L.map(C).sort(P),I=0;I<L.length;I++)L[I]=z[I].val,E[I]=z[I].text;break}}else L=void 0;return S=d.convertTypedArray(S),{key:x,label:a.label,tickFormat:a.tickformat,tickvals:L,ticktext:E,ordinal:d.isOrdinal(a),multiselect:a.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:a._index,height:i,values:S,paddedUnitValues:S.map(m),unitTickvals:L&&L.map(m),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:h,domainScale:w(i,g.verticalPadding,a,L,E),ordinalScale:k(a),parent:f,model:r,brush:v.makeBrush(t,T,A,function(){t.linePickActive(!1)},function(){var e=f;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=M(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))},function(r){if(f.focusLayer.render(f.panels,!0),f.pickLayer&&f.pickLayer.render(f.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=m.invert,i=r.map(function(t){return t.map(n).sort(o.sorterAsc)}).sort(function(t,e){return t[0]-e[0]});e.filterChanged(f.key,a._index,i)}})}}),f}function S(t){t.classed(g.cn.axisExtentText,!0).attr("text-anchor","middle").style("cursor","default").style("user-select","none")}function E(t,e){var r="top"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function L(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),a=0;a<n.length-1;a++){var i=r[a]||(r[a]={}),o=n[a],s=n[a+1];i.dim0=o,i.dim1=s,i.canvasX=o.canvasX,i.panelSizeX=s.canvasX-o.canvasX,i.panelSizeY=e.model.canvasHeight,i.y=0,i.canvasY=0}}function C(t,e){return i.tickText(t._ax,e,!1).text}function P(t,e){if(t.ordinal)return"";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return C(t.model.dimensions[t.visibleIndex],n)}e.exports=function(t,e,r,u){var y=t._fullLayout,w=y._toppaper,k=y._glcontainer;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,a=n.dimensions,o=0;o<a.length;o++){var s=a[o].values,l=a[o]._ax;l&&(l.range?l.range=_(l.range[0],l.range[1]):l.range=x(s,n._length),l.dtick||(l.dtick=.01*(Math.abs(l.range[1]-l.range[0])||1)),l.tickformat=a[o].tickformat,i.calcTicks(l),l.cleanRange())}}(e);var O,z,I=(O=!0,z=!1,{linePickActive:function(t){return arguments.length?O=!!t:O},contextShown:function(t){return arguments.length?z=!!t:z}}),D=e.filter(function(t){return p(t).trace.visible}).map(function(t,e,r){var i=p(e),s=i.trace,l=d.convertTypedArray(i.lineColor),u=s.line,h={color:a(g.deselectedLineColor)},f=c.extractOpts(u),v=f.reversescale?c.flipScale(i.cscale):i.cscale,m=s.domain,y=s.dimensions,x=t.width,_=s.labelangle,w=s.labelside,k=s.labelfont,M=s.tickfont,A=s.rangefont,S=o.extendDeepNoArrays({},u,{color:l.map(n.scale.linear().domain(b({values:l,range:[f.min,f.max],_length:s._length}))),blockLineCount:g.blockLineCount,canvasOverdrag:g.overdrag*g.canvasPixelRatio}),E=Math.floor(x*(m.x[1]-m.x[0])),L=Math.floor(t.height*(m.y[1]-m.y[0])),C=t.margin||{l:80,r:80,t:100,b:80},P=E,O=L;return{key:r,colCount:y.filter(d.isVisible).length,dimensions:y,tickDistance:g.tickDistance,unitToColor:T(v),lines:S,deselectedLines:h,labelAngle:_,labelSide:w,labelFont:k,tickFont:M,rangeFont:A,layoutWidth:x,layoutHeight:t.height,domain:m,translateX:m.x[0]*x,translateY:t.height-m.y[1]*t.height,pad:C,canvasWidth:P*g.canvasPixelRatio+2*S.canvasOverdrag,canvasHeight:O*g.canvasPixelRatio,width:P,height:O,canvasPixelRatio:g.canvasPixelRatio}}.bind(0,r)).map(A.bind(0,I,u));k.each(function(t,e){return o.extendFlat(t,D[e])});var R=k.selectAll(".gl-canvas").each(function(t){t.viewModel=D[0],t.model=t.viewModel?t.viewModel.model:null}),F=null;R.filter(function(t){return t.pick}).style("pointer-events","auto").on("mousemove",function(t){if(I.linePickActive()&&t.lineLayer&&u&&u.hover){var e=n.event,r=this.width,a=this.height,i=n.mouse(this),o=i[0],s=i[1];if(o<0||s<0||o>=r||s>=a)return;var l=t.lineLayer.readPixel(o,a-1-s),c=0!==l[3],h=c?l[2]+256*(l[1]+256*l[0]):null,f={x:o,y:s,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:h};h!==F&&(c?u.hover(f):u.unhover&&u.unhover(f),F=h)}}),R.style("opacity",function(t){return t.pick?0:1}),w.style("background","rgba(255, 255, 255, 0)");var B=w.selectAll("."+g.cn.parcoords).data(D,h);B.exit().remove(),B.enter().append("g").classed(g.cn.parcoords,!0).style("shape-rendering","crispEdges").style("pointer-events","none"),B.attr("transform",function(t){return"translate("+t.model.translateX+","+t.model.translateY+")"});var N=B.selectAll("."+g.cn.parcoordsControlView).data(f,h);N.enter().append("g").classed(g.cn.parcoordsControlView,!0),N.attr("transform",function(t){return"translate("+t.model.pad.l+","+t.model.pad.t+")"});var j=N.selectAll("."+g.cn.yAxis).data(function(t){return t.dimensions},h);j.enter().append("g").classed(g.cn.yAxis,!0),N.each(function(t){L(j,t)}),R.each(function(t){if(t.viewModel){!t.lineLayer||u?t.lineLayer=m(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||u;t.lineLayer.render(t.viewModel.panels,e)}}),j.attr("transform",function(t){return"translate("+t.xScale(t.xIndex)+", 0)"}),j.call(n.behavior.drag().origin(function(t){return t}).on("drag",function(t){var e=t.parent;I.linePickActive(!1),t.x=Math.max(-g.overdrag,Math.min(t.model.width+g.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,j.sort(function(t,e){return t.x-e.x}).each(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio}),L(j,e),j.filter(function(e){return 0!==Math.abs(t.xIndex-e.xIndex)}).attr("transform",function(t){return"translate("+t.xScale(t.xIndex)+", 0)"}),n.select(this).attr("transform","translate("+t.x+", 0)"),j.each(function(r,n,a){a===t.parent.key&&(e.dimensions[n]=r)}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!M(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)}).on("dragend",function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,L(j,e),n.select(this).attr("transform",function(t){return"translate("+t.x+", 0)"}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!M(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),I.linePickActive(!0),u&&u.axesMoved&&u.axesMoved(e.key,e.dimensions.map(function(t){return t.crossfilterDimensionIndex}))})),j.exit().remove();var V=j.selectAll("."+g.cn.axisOverlays).data(f,h);V.enter().append("g").classed(g.cn.axisOverlays,!0),V.selectAll("."+g.cn.axis).remove();var U=V.selectAll("."+g.cn.axis).data(f,h);U.enter().append("g").classed(g.cn.axis,!0),U.each(function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,a=r.domain();n.select(this).call(n.svg.axis().orient("left").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?a:null).tickFormat(function(e){return d.isOrdinal(t)?e:C(t.model.dimensions[t.visibleIndex],e)}).scale(r)),l.font(U.selectAll("text"),t.model.tickFont)}),U.selectAll(".domain, .tick>line").attr("fill","none").attr("stroke","black").attr("stroke-opacity",.25).attr("stroke-width","1px"),U.selectAll("text").style("text-shadow","1px 1px 1px #fff, -1px -1px 1px #fff, 1px -1px 1px #fff, -1px 1px 1px #fff").style("cursor","default").style("user-select","none");var q=V.selectAll("."+g.cn.axisHeading).data(f,h);q.enter().append("g").classed(g.cn.axisHeading,!0);var H=q.selectAll("."+g.cn.axisTitle).data(f,h);H.enter().append("text").classed(g.cn.axisTitle,!0).attr("text-anchor","middle").style("cursor","ew-resize").style("user-select","none").style("pointer-events","auto"),H.text(function(t){return t.label}).each(function(e){var r=n.select(this);l.font(r,e.model.labelFont),s.convertToTspans(r,t)}).attr("transform",function(t){var e=E(t.model.labelAngle,t.model.labelSide),r=g.axisTitleOffset;return(e.dir>0?"":"translate(0,"+(2*r+t.model.height)+")")+"rotate("+e.degrees+")translate("+-r*e.dx+","+-r*e.dy+")"}).attr("text-anchor",function(t){var e=E(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?"start":"end":"middle"});var G=V.selectAll("."+g.cn.axisExtent).data(f,h);G.enter().append("g").classed(g.cn.axisExtent,!0);var Y=G.selectAll("."+g.cn.axisExtentTop).data(f,h);Y.enter().append("g").classed(g.cn.axisExtentTop,!0),Y.attr("transform","translate(0,"+-g.axisExtentOffset+")");var W=Y.selectAll("."+g.cn.axisExtentTopText).data(f,h);W.enter().append("text").classed(g.cn.axisExtentTopText,!0).call(S),W.text(function(t){return P(t,!0)}).each(function(t){l.font(n.select(this),t.model.rangeFont)});var X=G.selectAll("."+g.cn.axisExtentBottom).data(f,h);X.enter().append("g").classed(g.cn.axisExtentBottom,!0),X.attr("transform",function(t){return"translate(0,"+(t.model.height+g.axisExtentOffset)+")"});var Z=X.selectAll("."+g.cn.axisExtentBottomText).data(f,h);Z.enter().append("text").classed(g.cn.axisExtentBottomText,!0).attr("dy","0.75em").call(S),Z.text(function(t){return P(t,!1)}).each(function(t){l.font(n.select(this),t.model.rangeFont)}),v.ensureAxisBrush(V)}},{"../../components/colorscale":603,"../../components/drawing":612,"../../lib":717,"../../lib/gup":715,"../../lib/svg_text_utils":741,"../../plots/cartesian/axes":765,"./axisbrush":1083,"./constants":1086,"./helpers":1088,"./lines":1090,"color-rgba":124,d3:165}],1093:[function(t,e,r){"use strict";var n=t("./parcoords"),a=t("../../lib/prepare_regl"),i=t("./helpers").isVisible;function o(t,e,r){var n=e.indexOf(r),a=t.indexOf(n);return-1===a&&(a+=e.length),a}e.exports=function(t,e){var r=t._fullLayout;if(a(t)){var s={},l={},c={},u={},h=r._size;e.forEach(function(e,r){var n=e[0].trace;c[r]=n.index;var a=u[r]=n._fullInput.index;s[r]=t.data[a].dimensions,l[r]=t.data[a].dimensions.slice()});n(t,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{filterChanged:function(e,n,a){var i=l[e][n],o=a.map(function(t){return t.slice()}),s="dimensions["+n+"].constraintrange",h=r._tracePreGUI[t._fullData[c[e]]._fullInput.uid];if(void 0===h[s]){var f=i.constraintrange;h[s]=f||null}var p=t._fullData[c[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),i.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete i.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit("plotly_restyle",[d,[u[e]]])},hover:function(e){t.emit("plotly_hover",e)},unhover:function(e){t.emit("plotly_unhover",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return o(t,e,r)-o(t,e,n)}}(r,l[e].filter(i));s[e].sort(n),l[e].filter(function(t){return!i(t)}).sort(function(t){return l[e].indexOf(t)}).forEach(function(t){s[e].splice(s[e].indexOf(t),1),s[e].splice(l[e].indexOf(t),0,t)}),t.emit("plotly_restyle",[{dimensions:[s[e]]},[u[e]]])}})}}},{"../../lib/prepare_regl":730,"./helpers":1088,"./parcoords":1092}],1094:[function(t,e,r){"use strict";var n=t("../../plots/attributes"),a=t("../../plots/domain").attributes,i=t("../../plots/font_attributes"),o=t("../../components/color/attributes"),s=t("../../plots/template_attributes").hovertemplateAttrs,l=t("../../plots/template_attributes").texttemplateAttrs,c=t("../../lib/extend").extendFlat,u=i({editType:"plot",arrayOk:!0,colorEditType:"plot"});e.exports={labels:{valType:"data_array",editType:"calc"},label0:{valType:"number",dflt:0,editType:"calc"},dlabel:{valType:"number",dflt:1,editType:"calc"},values:{valType:"data_array",editType:"calc"},marker:{colors:{valType:"data_array",editType:"calc"},line:{color:{valType:"color",dflt:o.defaultLine,arrayOk:!0,editType:"style"},width:{valType:"number",min:0,dflt:0,arrayOk:!0,editType:"style"},editType:"calc"},editType:"calc"},text:{valType:"data_array",editType:"plot"},hovertext:{valType:"string",dflt:"",arrayOk:!0,editType:"style"},scalegroup:{valType:"string",dflt:"",editType:"calc"},textinfo:{valType:"flaglist",flags:["label","text","value","percent"],extras:["none"],editType:"calc"},hoverinfo:c({},n.hoverinfo,{flags:["label","text","value","percent","name"]}),hovertemplate:s({},{keys:["label","color","value","percent","text"]}),texttemplate:l({editType:"plot"},{keys:["label","color","value","percent","text"]}),textposition:{valType:"enumerated",values:["inside","outside","auto","none"],dflt:"auto",arrayOk:!0,editType:"plot"},textfont:c({},u,{}),insidetextorientation:{valType:"enumerated",values:["horizontal","radial","tangential","auto"],dflt:"auto",editType:"plot"},insidetextfont:c({},u,{}),outsidetextfont:c({},u,{}),automargin:{valType:"boolean",dflt:!1,editType:"plot"},title:{text:{valType:"string",dflt:"",editType:"plot"},font:c({},u,{}),position:{valType:"enumerated",values:["top left","top center","top right","middle center","bottom left","bottom center","bottom right"],editType:"plot"},editType:"plot"},domain:a({name:"pie",trace:!0,editType:"calc"}),hole:{valType:"number",min:0,max:1,dflt:0,editType:"calc"},sort:{valType:"boolean",dflt:!0,editType:"calc"},direction:{valType:"enumerated",values:["clockwise","counterclockwise"],dflt:"counterclockwise",editType:"calc"},rotation:{valType:"number",min:-360,max:360,dflt:0,editType:"calc"},pull:{valType:"number",min:0,max:1,dflt:0,arrayOk:!0,editType:"calc"},_deprecated:{title:{valType:"string",dflt:"",editType:"calc"},titlefont:c({},u,{}),titleposition:{valType:"enumerated",values:["top left","top center","top right","middle center","bottom left","bottom center","bottom right"],editType:"calc"}}}},{"../../components/color/attributes":590,"../../lib/extend":708,"../../plots/attributes":762,"../../plots/domain":790,"../../plots/font_attributes":791,"../../plots/template_attributes":841}],1095:[function(t,e,r){"use strict";var n=t("../../plots/plots");r.name="pie",r.plot=function(t,e,a,i){n.plotBasePlot(r.name,t,e,a,i)},r.clean=function(t,e,a,i){n.cleanBasePlot(r.name,t,e,a,i)}},{"../../plots/plots":826}],1096:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("tinycolor2"),i=t("../../components/color"),o={};function s(t){return function(e,r){return!!e&&(!!(e=a(e)).isValid()&&(e=i.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e))}}function l(t,e){var r,n=JSON.stringify(t),i=e[n];if(!i){for(i=t.slice(),r=0;r<t.length;r++)i.push(a(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)i.push(a(t[r]).darken(20).toHexString());e[n]=i}return i}e.exports={calc:function(t,e){var r,a,i=[],o=t._fullLayout,l=o.hiddenlabels||[],c=e.labels,u=e.marker.colors||[],h=e.values,f=e._length,p=e._hasValues&&f;if(e.dlabel)for(c=new Array(f),r=0;r<f;r++)c[r]=String(e.label0+r*e.dlabel);var d={},g=s(o["_"+e.type+"colormap"]),v=0,m=!1;for(r=0;r<f;r++){var y,x,b;if(p){if(y=h[r],!n(y))continue;if((y=+y)<0)continue}else y=1;void 0!==(x=c[r])&&""!==x||(x=r);var _=d[x=String(x)];void 0===_?(d[x]=i.length,(b=-1!==l.indexOf(x))||(v+=y),i.push({v:y,label:x,color:g(u[r],x),i:r,pts:[r],hidden:b})):(m=!0,(a=i[_]).v+=y,a.pts.push(r),a.hidden||(v+=y),!1===a.color&&u[r]&&(a.color=g(u[r],x)))}return("funnelarea"===e.type?m:e.sort)&&i.sort(function(t,e){return e.v-t.v}),i[0]&&(i[0].vTotal=v),i},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r="pie");var n=t._fullLayout,a=t.calcdata,i=n[r+"colorway"],s=n["_"+r+"colormap"];n["extend"+r+"colors"]&&(i=l(i,o));for(var c=0,u=0;u<a.length;u++){var h=a[u];if(h[0].trace.type===r)for(var f=0;f<h.length;f++){var p=h[f];!1===p.color&&(s[p.label]?p.color=s[p.label]:(s[p.label]=p.color=i[c%i.length],c++))}}},makePullColorFn:s,generateExtendedColors:l}},{"../../components/color":591,"fast-isnumeric":228,tinycolor2:535}],1097:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("./attributes"),o=t("../../plots/domain").defaults,s=t("../bar/defaults").handleText;function l(t,e){var r=Array.isArray(t),i=a.isArrayOrTypedArray(e),o=Math.min(r?t.length:1/0,i?e.length:1/0);if(isFinite(o)||(o=0),o&&i){for(var s,l=0;l<o;l++){var c=e[l];if(n(c)&&c>0){s=!0;break}}s||(o=0)}return{hasLabels:r,hasValues:i,len:o}}e.exports={handleLabelsAndValues:l,supplyDefaults:function(t,e,r,n){function c(r,n){return a.coerce(t,e,i,r,n)}var u=l(c("labels"),c("values")),h=u.len;if(e._hasLabels=u.hasLabels,e._hasValues=u.hasValues,!e._hasLabels&&e._hasValues&&(c("label0"),c("dlabel")),h){e._length=h,c("marker.line.width")&&c("marker.line.color"),c("marker.colors"),c("scalegroup");var f,p=c("text"),d=c("texttemplate");if(d||(f=c("textinfo",Array.isArray(p)?"text+percent":"percent")),c("hovertext"),c("hovertemplate"),d||f&&"none"!==f){var g=c("textposition");s(t,e,n,c,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),(Array.isArray(g)||"auto"===g||"outside"===g)&&c("automargin"),("inside"===g||"auto"===g||Array.isArray(g))&&c("insidetextorientation")}o(e,n,c);var v=c("hole");if(c("title.text")){var m=c("title.position",v?"middle center":"top center");v||"middle center"!==m||(e.title.position="top center"),a.coerceFont(c,"title.font",n.font)}c("sort"),c("direction"),c("rotation"),c("pull")}else e.visible=!1}}},{"../../lib":717,"../../plots/domain":790,"../bar/defaults":860,"./attributes":1094,"fast-isnumeric":228}],1098:[function(t,e,r){"use strict";var n=t("../../components/fx/helpers").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),"funnelarea"===e.type&&(delete r.v,delete r.i),r}},{"../../components/fx/helpers":626}],1099:[function(t,e,r){"use strict";var n=t("../../lib");r.formatPiePercent=function(t,e){var r=(100*t).toPrecision(3);return-1!==r.lastIndexOf(".")&&(r=r.replace(/[.]?0+$/,"")),n.numSeparate(r,e)+"%"},r.formatPieValue=function(t,e){var r=t.toPrecision(10);return-1!==r.lastIndexOf(".")&&(r=r.replace(/[.]?0+$/,"")),n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n||""===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0}},{"../../lib":717}],1100:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults").supplyDefaults,supplyLayoutDefaults:t("./layout_defaults"),layoutAttributes:t("./layout_attributes"),calc:t("./calc").calc,crossTraceCalc:t("./calc").crossTraceCalc,plot:t("./plot").plot,style:t("./style"),styleOne:t("./style_one"),moduleType:"trace",name:"pie",basePlotModule:t("./base_plot"),categories:["pie-like","pie","showLegend"],meta:{}}},{"./attributes":1094,"./base_plot":1095,"./calc":1096,"./defaults":1097,"./layout_attributes":1101,"./layout_defaults":1102,"./plot":1103,"./style":1104,"./style_one":1105}],1101:[function(t,e,r){"use strict";e.exports={hiddenlabels:{valType:"data_array",editType:"calc"},piecolorway:{valType:"colorlist",editType:"calc"},extendpiecolors:{valType:"boolean",dflt:!0,editType:"calc"}}},{}],1102:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r("hiddenlabels"),r("piecolorway",e.colorway),r("extendpiecolors")}},{"../../lib":717,"./layout_attributes":1101}],1103:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../plots/plots"),i=t("../../components/fx"),o=t("../../components/color"),s=t("../../components/drawing"),l=t("../../lib"),c=t("../../lib/svg_text_utils"),u=t("../bar/uniform_text"),h=u.recordMinTextSize,f=u.clearMinTextSize,p=t("../bar/constants").TEXTPAD,d=t("./helpers"),g=t("./event_data"),v=t("../../lib").isValidTextValue;function m(t,e,r){var a=r[0],o=a.trace,s=a.cx,c=a.cy;"_hasHoverLabel"in o||(o._hasHoverLabel=!1),"_hasHoverEvent"in o||(o._hasHoverEvent=!1),t.on("mouseover",function(t){var r=e._fullLayout,u=e._fullData[o.index];if(!e._dragging&&!1!==r.hovermode){var h=u.hoverinfo;if(Array.isArray(h)&&(h=i.castHoverinfo({hoverinfo:[d.castOption(h,t.pts)],_module:o._module},r,0)),"all"===h&&(h="label+text+value+percent+name"),u.hovertemplate||"none"!==h&&"skip"!==h&&h){var f=t.rInscribed||0,p=s+t.pxmid[0]*(1-f),v=c+t.pxmid[1]*(1-f),m=r.separators,y=[];if(h&&-1!==h.indexOf("label")&&y.push(t.label),t.text=d.castOption(u.hovertext||u.text,t.pts),h&&-1!==h.indexOf("text")){var x=t.text;l.isValidTextValue(x)&&y.push(x)}t.value=t.v,t.valueLabel=d.formatPieValue(t.v,m),h&&-1!==h.indexOf("value")&&y.push(t.valueLabel),t.percent=t.v/a.vTotal,t.percentLabel=d.formatPiePercent(t.percent,m),h&&-1!==h.indexOf("percent")&&y.push(t.percentLabel);var b=u.hoverlabel,_=b.font;i.loneHover({trace:o,x0:p-f*a.r,x1:p+f*a.r,y:v,text:y.join("<br>"),name:u.hovertemplate||-1!==h.indexOf("name")?u.name:void 0,idealAlign:t.pxmid[0]<0?"left":"right",color:d.castOption(b.bgcolor,t.pts)||t.color,borderColor:d.castOption(b.bordercolor,t.pts),fontFamily:d.castOption(_.family,t.pts),fontSize:d.castOption(_.size,t.pts),fontColor:d.castOption(_.color,t.pts),nameLength:d.castOption(b.namelength,t.pts),textAlign:d.castOption(b.align,t.pts),hovertemplate:d.castOption(u.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[g(t,u)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),o._hasHoverLabel=!0}o._hasHoverEvent=!0,e.emit("plotly_hover",{points:[g(t,u)],event:n.event})}}),t.on("mouseout",function(t){var r=e._fullLayout,a=e._fullData[o.index],s=n.select(this).datum();o._hasHoverEvent&&(t.originalEvent=n.event,e.emit("plotly_unhover",{points:[g(s,a)],event:n.event}),o._hasHoverEvent=!1),o._hasHoverLabel&&(i.loneUnhover(r._hoverlayer.node()),o._hasHoverLabel=!1)}),t.on("click",function(t){var r=e._fullLayout,a=e._fullData[o.index];e._dragging||!1===r.hovermode||(e._hoverdata=[g(t,a)],i.click(e,n.event))})}function y(t,e,r){var n=d.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=d.castOption(t._input.textfont.color,e.pts));var a=d.castOption(t.insidetextfont.family,e.pts)||d.castOption(t.textfont.family,e.pts)||r.family,i=d.castOption(t.insidetextfont.size,e.pts)||d.castOption(t.textfont.size,e.pts)||r.size;return{color:n||o.contrast(e.color),family:a,size:i}}function x(t,e){for(var r,n,a=0;a<t.length;a++)if((n=(r=t[a][0]).trace).title.text){var i=n.title.text;n._meta&&(i=l.templateString(i,n._meta));var o=s.tester.append("text").attr("data-notex",1).text(i).call(s.font,n.title.font).call(c.convertToTspans,e),u=s.bBox(o.node(),!0);r.titleBox={width:u.width,height:u.height},o.remove()}}function b(t,e,r){var n=r.r||e.rpx1,a=e.rInscribed;if(e.startangle===e.stopangle)return{rCenter:1-a,scale:0,rotate:0,textPosAngle:0};var i,o=e.ring,s=1===o&&Math.abs(e.startangle-e.stopangle)===2*Math.PI,l=e.halfangle,c=e.midangle,u=r.trace.insidetextorientation,h="horizontal"===u,f="tangential"===u,p="radial"===u,d="auto"===u,g=[];if(!d){var v,m=function(r,a){if(function(t,e){var r=t.startangle,n=t.stopangle;return r>e&&e>n||r<e&&e<n}(e,r)){var s=Math.abs(r-e.startangle),l=Math.abs(r-e.stopangle),c=s<l?s:l;(i="tan"===a?w(t,n,o,c,0):_(t,n,o,c,Math.PI/2)).textPosAngle=r,g.push(i)}};if(h||f){for(v=4;v>=-4;v-=2)m(Math.PI*v,"tan");for(v=4;v>=-4;v-=2)m(Math.PI*(v+1),"tan")}if(h||p){for(v=4;v>=-4;v-=2)m(Math.PI*(v+1.5),"rad");for(v=4;v>=-4;v-=2)m(Math.PI*(v+.5),"rad")}}if(s||d||h){var y=Math.sqrt(t.width*t.width+t.height*t.height);if((i={scale:a*n*2/y,rCenter:1-a,rotate:0}).textPosAngle=(e.startangle+e.stopangle)/2,i.scale>=1)return i;g.push(i)}(d||p)&&((i=_(t,n,o,l,c)).textPosAngle=(e.startangle+e.stopangle)/2,g.push(i)),(d||f)&&((i=w(t,n,o,l,c)).textPosAngle=(e.startangle+e.stopangle)/2,g.push(i));for(var x=0,b=0,k=0;k<g.length;k++){var T=g[k].scale;if(b<T&&(b=T,x=k),!d&&b>=1)break}return g[x]}function _(t,e,r,n,a){e=Math.max(0,e-2*p);var i=t.width/t.height,o=M(i,n,e,r);return{scale:2*o/t.height,rCenter:k(i,o/e),rotate:T(a)}}function w(t,e,r,n,a){e=Math.max(0,e-2*p);var i=t.height/t.width,o=M(i,n,e,r);return{scale:2*o/t.width,rCenter:k(i,o/e),rotate:T(a+Math.PI/2)}}function k(t,e){return Math.cos(e)-t*e}function T(t){return(180/Math.PI*t+720)%180-90}function M(t,e,r,n){var a=t+1/(2*Math.tan(e));return r*Math.min(1/(Math.sqrt(a*a+.5)+a),n/(Math.sqrt(t*t+n/2)+t))}function A(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function S(t,e){var r=e.pxmid[0],n=e.pxmid[1],a=t.width/2,i=t.height/2;return r<0&&(a*=-1),n<0&&(i*=-1),{scale:1,rCenter:1,rotate:0,x:a+Math.abs(i)*(a>0?1:-1)/2,y:i/(1+r*r/(n*n)),outside:!0}}function E(t,e){var r,n,a,i=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=i.title.font.size,a=C(i),-1!==i.title.position.indexOf("top")?(o.y-=(1+a)*t.r,s.ty-=t.titleBox.height):-1!==i.title.position.indexOf("bottom")&&(o.y+=(1+a)*t.r);var l,c,u=(l=t.r,c=t.trace.aspectratio,l/(void 0===c?1:c)),h=e.w*(i.domain.x[1]-i.domain.x[0])/2;return-1!==i.title.position.indexOf("left")?(h+=u,o.x-=(1+a)*u,s.tx+=t.titleBox.width/2):-1!==i.title.position.indexOf("center")?h*=2:-1!==i.title.position.indexOf("right")&&(h+=u,o.x+=(1+a)*u,s.tx-=t.titleBox.width/2),r=h/t.titleBox.width,n=L(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function L(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function C(t){var e,r=t.pull;if(!r)return 0;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function P(t,e){for(var r=[],n=0;n<t.length;n++){var a=t[n][0],i=a.trace,o=i.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);i.title.text&&"middle center"!==i.title.position&&(l-=L(a,e));var c=s/2,u=l/2;"funnelarea"!==i.type||i.scalegroup||(u/=i.aspectratio),a.r=Math.min(c,u)/(1+C(i)),a.cx=e.l+e.w*(i.domain.x[1]+i.domain.x[0])/2,a.cy=e.t+e.h*(1-i.domain.y[0])-l/2,i.title.text&&-1!==i.title.position.indexOf("bottom")&&(a.cy-=L(a,e)),i.scalegroup&&-1===r.indexOf(i.scalegroup)&&r.push(i.scalegroup)}!function(t,e){for(var r,n,a,i=0;i<e.length;i++){var o=1/0,s=e[i];for(n=0;n<t.length;n++)if(r=t[n][0],(a=r.trace).scalegroup===s){var l;if("pie"===a.type)l=r.r*r.r;else if("funnelarea"===a.type){var c,u;a.aspectratio>1?(c=r.r,u=c/a.aspectratio):(u=r.r,c=u*a.aspectratio),c*=(1+a.baseratio)/2,l=c*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if(r=t[n][0],(a=r.trace).scalegroup===s){var h=o*r.vTotal;"funnelarea"===a.type&&(h/=(1+a.baseratio)/2,h/=a.aspectratio),r.r=Math.sqrt(h)}}}(t,r)}function O(t,e){return[t*Math.sin(e),-t*Math.cos(e)]}function z(t,e,r){var n=t._fullLayout,a=r.trace,i=a.texttemplate,o=a.textinfo;if(!i&&o&&"none"!==o){var s,c=o.split("+"),u=function(t){return-1!==c.indexOf(t)},h=u("label"),f=u("text"),p=u("value"),g=u("percent"),m=n.separators;if(s=h?[e.label]:[],f){var y=d.getFirstFilled(a.text,e.pts);v(y)&&s.push(y)}p&&s.push(d.formatPieValue(e.v,m)),g&&s.push(d.formatPiePercent(e.v/r.vTotal,m)),e.text=s.join("<br>")}if(i){var x=l.castOption(a,e.i,"texttemplate");if(x){var b=function(t){return{label:t.label,value:t.v,valueLabel:d.formatPieValue(t.v,n.separators),percent:t.v/r.vTotal,percentLabel:d.formatPiePercent(t.v/r.vTotal,n.separators),color:t.color,text:t.text,customdata:l.castOption(a,t.i,"customdata")}}(e),_=d.getFirstFilled(a.text,e.pts);(v(_)||""===_)&&(b.text=_),e.text=l.texttemplateString(x,b,t._fullLayout._d3locale,b,a._meta||{})}else e.text=""}}function I(t,e){var r=t.rotate*Math.PI/180,n=Math.cos(r),a=Math.sin(r),i=(e.left+e.right)/2,o=(e.top+e.bottom)/2;t.textX=i*n-o*a,t.textY=i*a+o*n,t.noCenter=!0}e.exports={plot:function(t,e){var r=t._fullLayout,i=r._size;f("pie",r),x(e,t),P(e,i);var u=l.makeTraceGroups(r._pielayer,e,"trace").each(function(e){var u=n.select(this),f=e[0],p=f.trace;!function(t){var e,r,n,a=t[0],i=a.r,o=a.trace,s=o.rotation*Math.PI/180,l=2*Math.PI/a.vTotal,c="px0",u="px1";if("counterclockwise"===o.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;s+=l*t[e].v,l*=-1,c="px1",u="px0"}for(n=O(i,s),e=0;e<t.length;e++)(r=t[e]).hidden||(r[c]=n,r.startangle=s,s+=l*r.v/2,r.pxmid=O(i,s),r.midangle=s,s+=l*r.v/2,n=O(i,s),r.stopangle=s,r[u]=n,r.largeArc=r.v>a.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/a.vTotal,.5),r.ring=1-o.hole,r.rInscribed=A(r,a))}(e),u.attr("stroke-linejoin","round"),u.each(function(){var g=n.select(this).selectAll("g.slice").data(e);g.enter().append("g").classed("slice",!0),g.exit().remove();var v=[[[],[]],[[],[]]],x=!1;g.each(function(a,i){if(a.hidden)n.select(this).selectAll("path,g").remove();else{a.pointNumber=a.i,a.curveNumber=p.index,v[a.pxmid[1]<0?0:1][a.pxmid[0]<0?0:1].push(a);var o=f.cx,u=f.cy,g=n.select(this),_=g.selectAll("path.surface").data([a]);if(_.enter().append("path").classed("surface",!0).style({"pointer-events":"all"}),g.call(m,t,e),p.pull){var w=+d.castOption(p.pull,a.pts)||0;w>0&&(o+=w*a.pxmid[0],u+=w*a.pxmid[1])}a.cxFinal=o,a.cyFinal=u;var k=p.hole;if(a.v===f.vTotal){var T="M"+(o+a.px0[0])+","+(u+a.px0[1])+C(a.px0,a.pxmid,!0,1)+C(a.pxmid,a.px0,!0,1)+"Z";k?_.attr("d","M"+(o+k*a.px0[0])+","+(u+k*a.px0[1])+C(a.px0,a.pxmid,!1,k)+C(a.pxmid,a.px0,!1,k)+"Z"+T):_.attr("d",T)}else{var M=C(a.px0,a.px1,!0,1);if(k){var A=1-k;_.attr("d","M"+(o+k*a.px1[0])+","+(u+k*a.px1[1])+C(a.px1,a.px0,!1,k)+"l"+A*a.px0[0]+","+A*a.px0[1]+M+"Z")}else _.attr("d","M"+o+","+u+"l"+a.px0[0]+","+a.px0[1]+M+"Z")}z(t,a,f);var E=d.castOption(p.textposition,a.pts),L=g.selectAll("g.slicetext").data(a.text&&"none"!==E?[0]:[]);L.enter().append("g").classed("slicetext",!0),L.exit().remove(),L.each(function(){var g=l.ensureSingle(n.select(this),"text","",function(t){t.attr("data-notex",1)}),v=l.ensureUniformFontSize(t,"outside"===E?function(t,e,r){var n=d.castOption(t.outsidetextfont.color,e.pts)||d.castOption(t.textfont.color,e.pts)||r.color,a=d.castOption(t.outsidetextfont.family,e.pts)||d.castOption(t.textfont.family,e.pts)||r.family,i=d.castOption(t.outsidetextfont.size,e.pts)||d.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:a,size:i}}(p,a,r.font):y(p,a,r.font));g.text(a.text).attr({class:"slicetext",transform:"","text-anchor":"middle"}).call(s.font,v).call(c.convertToTspans,t);var m,_=s.bBox(g.node());if("outside"===E)m=S(_,a);else if(m=b(_,a,f),"auto"===E&&m.scale<1){var w=l.ensureUniformFontSize(t,p.outsidetextfont);g.call(s.font,w),m=S(_=s.bBox(g.node()),a)}var k=m.textPosAngle,T=void 0===k?a.pxmid:O(f.r,k);if(m.targetX=o+T[0]*m.rCenter+(m.x||0),m.targetY=u+T[1]*m.rCenter+(m.y||0),I(m,_),m.outside){var M=m.targetY;a.yLabelMin=M-_.height/2,a.yLabelMid=M,a.yLabelMax=M+_.height/2,a.labelExtraX=0,a.labelExtraY=0,x=!0}m.fontSize=v.size,h(p.type,m,r),e[i].transform=m,g.attr("transform",l.getTextTransform(m))})}function C(t,e,r,n){var i=n*(e[0]-t[0]),o=n*(e[1]-t[1]);return"a"+n*f.r+","+n*f.r+" 0 "+a.largeArc+(r?" 1 ":" 0 ")+i+","+o}});var _=n.select(this).selectAll("g.titletext").data(p.title.text?[0]:[]);if(_.enter().append("g").classed("titletext",!0),_.exit().remove(),_.each(function(){var e,r=l.ensureSingle(n.select(this),"text","",function(t){t.attr("data-notex",1)}),a=p.title.text;p._meta&&(a=l.templateString(a,p._meta)),r.text(a).attr({class:"titletext",transform:"","text-anchor":"middle"}).call(s.font,p.title.font).call(c.convertToTspans,t),e="middle center"===p.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(f):E(f,i),r.attr("transform","translate("+e.x+","+e.y+")"+(e.scale<1?"scale("+e.scale+")":"")+"translate("+e.tx+","+e.ty+")")}),x&&function(t,e){var r,n,a,i,o,s,l,c,u,h,f,p,g;function v(t,e){return t.pxmid[1]-e.pxmid[1]}function m(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var a,c,u,f,p,g,v=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),m=n?t.yLabelMin:t.yLabelMax,y=n?t.yLabelMax:t.yLabelMin,x=t.cyFinal+o(t.px0[1],t.px1[1]),b=v-m;if(b*l>0&&(t.labelExtraY=b),Array.isArray(e.pull))for(c=0;c<h.length;c++)(u=h[c])===t||(d.castOption(e.pull,t.pts)||0)>=(d.castOption(e.pull,u.pts)||0)||((t.pxmid[1]-u.pxmid[1])*l>0?(f=u.cyFinal+o(u.px0[1],u.px1[1]),(b=f-m-t.labelExtraY)*l>0&&(t.labelExtraY+=b)):(y+t.labelExtraY-x)*l>0&&(a=3*s*Math.abs(c-h.indexOf(t)),p=u.cxFinal+i(u.px0[0],u.px1[0]),(g=p+a-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=g)))}for(n=0;n<2;n++)for(a=n?v:m,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(i=r?Math.max:Math.min,s=r?1:-1,(c=t[n][r]).sort(a),u=t[1-n][r],h=u.concat(c),p=[],f=0;f<c.length;f++)void 0!==c[f].yLabelMid&&p.push(c[f]);for(g=!1,f=0;n&&f<u.length;f++)if(void 0!==u[f].yLabelMid){g=u[f];break}for(f=0;f<p.length;f++){var x=f&&p[f-1];g&&!f&&(x=g),y(p[f],x)}}}(v,p),function(t,e){t.each(function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var a=r.select("g.slicetext text");t.transform.targetX+=t.labelExtraX,t.transform.targetY+=t.labelExtraY,a.attr("transform",l.getTextTransform(t.transform));var i=t.cxFinal+t.pxmid[0],s=t.cyFinal+t.pxmid[1],c="M"+i+","+s,u=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var h=t.labelExtraX*t.pxmid[1]/t.pxmid[0],f=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(h)>Math.abs(f)?c+="l"+f*t.pxmid[0]/t.pxmid[1]+","+f+"H"+(i+t.labelExtraX+u):c+="l"+t.labelExtraX+","+h+"v"+(f-h)+"h"+u}else c+="V"+(t.yLabelMid+t.labelExtraY)+"h"+u;l.ensureSingle(r,"path","textline").call(o.stroke,e.outsidetextfont.color).attr({"stroke-width":Math.min(2,e.outsidetextfont.size/8),d:c,fill:"none"})}else r.select("path.textline").remove()})}(g,p),x&&p.automargin){var w=s.bBox(u.node()),k=p.domain,T=i.w*(k.x[1]-k.x[0]),M=i.h*(k.y[1]-k.y[0]),A=(.5*T-f.r)/i.w,L=(.5*M-f.r)/i.h;a.autoMargin(t,"pie."+p.uid+".automargin",{xl:k.x[0]-A,xr:k.x[1]+A,yb:k.y[0]-L,yt:k.y[1]+L,l:Math.max(f.cx-f.r-w.left,0),r:Math.max(w.right-(f.cx+f.r),0),b:Math.max(w.bottom-(f.cy+f.r),0),t:Math.max(f.cy-f.r-w.top,0),pad:5})}})});setTimeout(function(){u.selectAll("tspan").each(function(){var t=n.select(this);t.attr("dy")&&t.attr("dy",t.attr("dy"))})},0)},formatSliceLabel:z,transformInsideText:b,determineInsideTextFont:y,positionTitleOutside:E,prerenderTitles:x,layoutAreas:P,attachFxHandlers:m,computeTransform:I}},{"../../components/color":591,"../../components/drawing":612,"../../components/fx":630,"../../lib":717,"../../lib/svg_text_utils":741,"../../plots/plots":826,"../bar/constants":858,"../bar/uniform_text":872,"./event_data":1098,"./helpers":1099,d3:165}],1104:[function(t,e,r){"use strict";var n=t("d3"),a=t("./style_one"),i=t("../bar/uniform_text").resizeText;e.exports=function(t){var e=t._fullLayout._pielayer.selectAll(".trace");i(t,e,"pie"),e.each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll("path.surface").each(function(t){n.select(this).call(a,t,e)})})}},{"../bar/uniform_text":872,"./style_one":1105,d3:165}],1105:[function(t,e,r){"use strict";var n=t("../../components/color"),a=t("./helpers").castOption;e.exports=function(t,e,r){var i=r.marker.line,o=a(i.color,e.pts)||n.defaultLine,s=a(i.width,e.pts)||0;t.style("stroke-width",s).call(n.fill,e.color).call(n.stroke,o)}},{"../../components/color":591,"./helpers":1099}],1106:[function(t,e,r){"use strict";var n=t("../scatter/attributes");e.exports={x:n.x,y:n.y,xy:{valType:"data_array",editType:"calc"},indices:{valType:"data_array",editType:"calc"},xbounds:{valType:"data_array",editType:"calc"},ybounds:{valType:"data_array",editType:"calc"},text:n.text,marker:{color:{valType:"color",arrayOk:!1,editType:"calc"},opacity:{valType:"number",min:0,max:1,dflt:1,arrayOk:!1,editType:"calc"},blend:{valType:"boolean",dflt:null,editType:"calc"},sizemin:{valType:"number",min:.1,max:2,dflt:.5,editType:"calc"},sizemax:{valType:"number",min:.1,dflt:20,editType:"calc"},border:{color:{valType:"color",arrayOk:!1,editType:"calc"},arearatio:{valType:"number",min:0,max:1,dflt:0,editType:"calc"},editType:"calc"},editType:"calc"},transforms:void 0}},{"../scatter/attributes":1120}],1107:[function(t,e,r){"use strict";var n=t("gl-pointcloud2d"),a=t("../../lib/str2rgbarray"),i=t("../../plots/cartesian/autorange").findExtremes,o=t("../scatter/get_trace_color");function s(t,e){this.scene=t,this.uid=e,this.type="pointcloud",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color="rgb(0, 0, 0)",this.name="",this.hoverinfo="all",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,h=this.pickXYData=t.xy,f=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(h){if(n=h,e=h.length>>>1,f)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var g=a(t.marker.color),v=a(t.marker.border.color),m=t.opacity*t.marker.opacity;g[3]*=m,this.pointcloudOptions.color=g;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,v[3]*=m,this.pointcloudOptions.borderColor=v;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,k=b/2||.5;t._extremes[_._id]=i(_,[d[0],d[2]],{ppad:k}),t._extremes[w._id]=i(w,[d[1],d[3]],{ppad:k})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{"../../lib/str2rgbarray":740,"../../plots/cartesian/autorange":764,"../scatter/get_trace_color":1130,"gl-pointcloud2d":295}],1108:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes");e.exports=function(t,e,r){function i(r,i){return n.coerce(t,e,a,r,i)}i("x"),i("y"),i("xbounds"),i("ybounds"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),i("text"),i("marker.color",r),i("marker.opacity"),i("marker.blend"),i("marker.sizemin"),i("marker.sizemax"),i("marker.border.color",r),i("marker.border.arearatio"),e._length=null}},{"../../lib":717,"./attributes":1106}],1109:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("../scatter3d/calc"),plot:t("./convert"),moduleType:"trace",name:"pointcloud",basePlotModule:t("../../plots/gl2d"),categories:["gl","gl2d","showLegend"],meta:{}}},{"../../plots/gl2d":803,"../scatter3d/calc":1148,"./attributes":1106,"./convert":1107,"./defaults":1108}],1110:[function(t,e,r){"use strict";var n=t("../../plots/font_attributes"),a=t("../../plots/attributes"),i=t("../../components/color/attributes"),o=t("../../components/fx/attributes"),s=t("../../plots/domain").attributes,l=t("../../plots/template_attributes").hovertemplateAttrs,c=t("../../components/colorscale/attributes"),u=t("../../plot_api/plot_template").templatedArray,h=t("../../lib/extend").extendFlat,f=t("../../plot_api/edit_types").overrideAll;t("../../constants/docs").FORMAT_LINK;(e.exports=f({hoverinfo:h({},a.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:"sankey",trace:!0}),orientation:{valType:"enumerated",values:["v","h"],dflt:"h"},valueformat:{valType:"string",dflt:".3s"},valuesuffix:{valType:"string",dflt:""},arrangement:{valType:"enumerated",values:["snap","perpendicular","freeform","fixed"],dflt:"snap"},textfont:n({}),customdata:void 0,node:{label:{valType:"data_array",dflt:[]},groups:{valType:"info_array",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:"number",editType:"calc"}},x:{valType:"data_array",dflt:[]},y:{valType:"data_array",dflt:[]},color:{valType:"color",arrayOk:!0},customdata:{valType:"data_array",editType:"calc"},line:{color:{valType:"color",dflt:i.defaultLine,arrayOk:!0},width:{valType:"number",min:0,dflt:.5,arrayOk:!0}},pad:{valType:"number",arrayOk:!1,min:0,dflt:20},thickness:{valType:"number",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:"enumerated",values:["all","none","skip"],dflt:"all"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:["value","label"]})},link:{label:{valType:"data_array",dflt:[]},color:{valType:"color",arrayOk:!0},customdata:{valType:"data_array",editType:"calc"},line:{color:{valType:"color",dflt:i.defaultLine,arrayOk:!0},width:{valType:"number",min:0,dflt:0,arrayOk:!0}},source:{valType:"data_array",dflt:[]},target:{valType:"data_array",dflt:[]},value:{valType:"data_array",dflt:[]},hoverinfo:{valType:"enumerated",values:["all","none","skip"],dflt:"all"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:["value","label"]}),colorscales:u("concentrationscales",{editType:"calc",label:{valType:"string",editType:"calc",dflt:""},cmax:{valType:"number",editType:"calc",dflt:1},cmin:{valType:"number",editType:"calc",dflt:0},colorscale:h(c().colorscale,{dflt:[[0,"white"],[1,"black"]]})})}},"calc","nested")).transforms=void 0},{"../../components/color/attributes":590,"../../components/colorscale/attributes":598,"../../components/fx/attributes":621,"../../constants/docs":688,"../../lib/extend":708,"../../plot_api/edit_types":748,"../../plot_api/plot_template":755,"../../plots/attributes":762,"../../plots/domain":790,"../../plots/font_attributes":791,"../../plots/template_attributes":841}],1111:[function(t,e,r){"use strict";var n=t("../../plot_api/edit_types").overrideAll,a=t("../../plots/get_data").getModuleCalcData,i=t("./plot"),o=t("../../components/fx/layout_attributes"),s=t("../../lib/setcursor"),l=t("../../components/dragelement"),c=t("../../plots/cartesian/select").prepSelect,u=t("../../lib"),h=t("../../registry");function f(t,e){var r=t._fullData[e],n=t._fullLayout,a=n.dragmode,i="pan"===n.dragmode?"move":"crosshair",o=r._bgRect;if("pan"!==a&&"zoom"!==a){s(o,i);var f={_id:"x",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:"y",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:f,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[f],yaxes:[p],doneFnCompleted:function(r){var n,a=t._fullData[e],i=a.node.groups.slice(),o=[];function s(t){for(var e=a._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);i[c.pointNumber-a.node._count]=!1}else o.push(c.pointNumber)}n=i.filter(Boolean).concat([o]),h.call("_guiRestyle",t,{"node.groups":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,a)}};l.init(d)}}r.name="sankey",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},"plot","nested"),r.plot=function(t){var e=a(t.calcdata,"sankey")[0];i(t,e),r.updateFx(t)},r.clean=function(t,e,r,n){var a=n._has&&n._has("sankey"),i=e._has&&e._has("sankey");a&&!i&&(n._paperdiv.selectAll(".sankey").remove(),n._paperdiv.selectAll(".bgsankey").remove())},r.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)f(t,e)}},{"../../components/dragelement":609,"../../components/fx/layout_attributes":631,"../../lib":717,"../../lib/setcursor":737,"../../plot_api/edit_types":748,"../../plots/cartesian/select":782,"../../plots/get_data":800,"../../registry":846,"./plot":1116}],1112:[function(t,e,r){"use strict";var n=t("strongly-connected-components"),a=t("../../lib"),i=t("../../lib/gup").wrap,o=a.isArrayOrTypedArray,s=a.isIndex,l=t("../../components/colorscale");function c(t){var e,r=t.node,i=t.link,c=[],u=o(i.color),h=o(i.customdata),f={},p={},d=i.colorscales.length;for(e=0;e<d;e++){var g=i.colorscales[e],v=l.extractScale(g,{cLetter:"c"}),m=l.makeColorScaleFunc(v);p[g.label]=m}var y=0;for(e=0;e<i.value.length;e++)i.source[e]>y&&(y=i.source[e]),i.target[e]>y&&(y=i.target[e]);var x,b=y+1;t.node._count=b;var _=t.node.groups,w={};for(e=0;e<_.length;e++){var k=_[e];for(x=0;x<k.length;x++){var T=k[x],M=b+e;w.hasOwnProperty(T)?a.warn("Node "+T+" is already part of a group."):w[T]=M}}var A={source:[],target:[]};for(e=0;e<i.value.length;e++){var S=i.value[e],E=i.source[e],L=i.target[e];if(S>0&&s(E,b)&&s(L,b)&&(!w.hasOwnProperty(E)||!w.hasOwnProperty(L)||w[E]!==w[L])){w.hasOwnProperty(L)&&(L=w[L]),w.hasOwnProperty(E)&&(E=w[E]),L=+L,f[E=+E]=f[L]=!0;var C="";i.label&&i.label[e]&&(C=i.label[e]);var P=null;C&&p.hasOwnProperty(C)&&(P=p[C]),c.push({pointNumber:e,label:C,color:u?i.color[e]:i.color,customdata:h?i.customdata[e]:i.customdata,concentrationscale:P,source:E,target:L,value:+S}),A.source.push(E),A.target.push(L)}}var O=b+_.length,z=o(r.color),I=o(r.customdata),D=[];for(e=0;e<O;e++)if(f[e]){var R=r.label[e];D.push({group:e>b-1,childrenNodes:[],pointNumber:e,label:R,color:z?r.color[e]:r.color,customdata:I?r.customdata[e]:r.customdata})}var F=!1;return function(t,e,r){for(var i=a.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(a.isIndex(e[o],t)&&a.isIndex(r[o],t)){if(e[o]===r[o])return!0;i[e[o]].push(r[o])}return n(i).components.some(function(t){return t.length>1})}(O,A.source,A.target)&&(F=!0),{circular:F,links:c,nodes:D,groups:_,groupLookup:w}}e.exports=function(t,e){var r=c(e);return i({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},{"../../components/colorscale":603,"../../lib":717,"../../lib/gup":715,"strongly-connected-components":528}],1113:[function(t,e,r){"use strict";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:"linear",cn:{sankey:"sankey",sankeyLinks:"sankey-links",sankeyLink:"sankey-link",sankeyNodeSet:"sankey-node-set",sankeyNode:"sankey-node",nodeRect:"node-rect",nodeCapture:"node-capture",nodeCentered:"node-entered",nodeLabelGuide:"node-label-guide",nodeLabel:"node-label",nodeLabelTextPath:"node-label-text-path"}}},{}],1114:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("../../components/color"),o=t("tinycolor2"),s=t("../../plots/domain").defaults,l=t("../../components/fx/hoverlabel_defaults"),c=t("../../plot_api/plot_template"),u=t("../../plots/array_container_defaults");function h(t,e){function r(r,i){return n.coerce(t,e,a.link.colorscales,r,i)}r("label"),r("cmin"),r("cmax"),r("colorscale")}e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,a,r,i)}var d=n.extendDeep(f.hoverlabel,t.hoverlabel),g=t.node,v=c.newContainer(e,"node");function m(t,e){return n.coerce(g,v,a.node,t,e)}m("label"),m("groups"),m("x"),m("y"),m("pad"),m("thickness"),m("line.color"),m("line.width"),m("hoverinfo",t.hoverinfo),l(g,v,m,d),m("hovertemplate");var y=f.colorway;m("color",v.label.map(function(t,e){return i.addOpacity(function(t){return y[t%y.length]}(e),.8)})),m("customdata");var x=t.link||{},b=c.newContainer(e,"link");function _(t,e){return n.coerce(x,b,a.link,t,e)}_("label"),_("source"),_("target"),_("value"),_("line.color"),_("line.width"),_("hoverinfo",t.hoverinfo),l(x,b,_,d),_("hovertemplate");var w,k=o(f.paper_bgcolor).getLuminance()<.333?"rgba(255, 255, 255, 0.6)":"rgba(0, 0, 0, 0.2)";_("color",n.repeat(k,b.value.length)),_("customdata"),u(x,b,{name:"colorscales",handleItemDefaults:h}),s(e,f,p),p("orientation"),p("valueformat"),p("valuesuffix"),v.x.length&&v.y.length&&(w="freeform"),p("arrangement",w),n.coerceFont(p,"textfont",n.extendFlat({},f.font)),e._length=null}},{"../../components/color":591,"../../components/fx/hoverlabel_defaults":628,"../../lib":717,"../../plot_api/plot_template":755,"../../plots/array_container_defaults":761,"../../plots/domain":790,"./attributes":1110,tinycolor2:535}],1115:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc"),plot:t("./plot"),moduleType:"trace",name:"sankey",basePlotModule:t("./base_plot"),selectPoints:t("./select.js"),categories:["noOpacity"],meta:{}}},{"./attributes":1110,"./base_plot":1111,"./calc":1112,"./defaults":1114,"./plot":1116,"./select.js":1118}],1116:[function(t,e,r){"use strict";var n=t("d3"),a=t("./render"),i=t("../../components/fx"),o=t("../../components/color"),s=t("../../lib"),l=t("./constants").cn,c=s._;function u(t){return""!==t}function h(t,e){return t.filter(function(t){return t.key===e.traceId})}function f(t,e){n.select(t).select("path").style("fill-opacity",e),n.select(t).select("rect").style("fill-opacity",e)}function p(t){n.select(t).select("text.name").style("fill","black")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function v(t,e,r){e&&r&&h(r,e).selectAll("."+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function m(t,e,r){e&&r&&h(r,e).selectAll("."+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var a=n.datum().link.label;n.style("fill-opacity",function(t){if(!t.link.concentrationscale)return.4}),a&&h(e,t).selectAll("."+l.sankeyLink).filter(function(t){return t.link.label===a}).style("fill-opacity",function(t){if(!t.link.concentrationscale)return.4}),r&&h(e,t).selectAll("."+l.sankeyNode).filter(g(t)).call(v)}function x(t,e,r,n){var a=n.datum().link.label;n.style("fill-opacity",function(t){return t.tinyColorAlpha}),a&&h(e,t).selectAll("."+l.sankeyLink).filter(function(t){return t.link.label===a}).style("fill-opacity",function(t){return t.tinyColorAlpha}),r&&h(e,t).selectAll(l.sankeyNode).filter(g(t)).call(m)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){for(var r=t._fullLayout,s=r._paper,h=r._size,d=0;d<t._fullData.length;d++)if(t._fullData[d].visible&&t._fullData[d].type===l.sankey&&!t._fullData[d]._viewInitial){var g=t._fullData[d].node;t._fullData[d]._viewInitial={node:{groups:g.groups.slice(),x:g.x.slice(),y:g.y.slice()}}}var _=c(t,"source:")+" ",w=c(t,"target:")+" ",k=c(t,"concentration:")+" ",T=c(t,"incoming flow count:")+" ",M=c(t,"outgoing flow count:")+" ";a(t,s,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{linkEvents:{hover:function(e,r,a){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,a,!0)),"skip"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit("plotly_hover",{event:n.event,points:[r.link]})))},follow:function(e,a){if(!1!==t._fullLayout.hovermode){var s=a.link.trace.link;if("none"!==s.hoverinfo&&"skip"!==s.hoverinfo){for(var l=[],c=0,h=0;h<a.flow.links.length;h++){var d=a.flow.links[h];if("closest"!==t._fullLayout.hovermode||a.link.pointNumber===d.pointNumber){a.link.pointNumber===d.pointNumber&&(c=h),d.fullData=d.trace,s=a.link.trace.link;var g=m(d),v={valueLabel:n.format(a.valueFormat)(d.value)+a.valueSuffix};l.push({x:g[0],y:g[1],name:v.valueLabel,text:[d.label||"",_+d.source.label,w+d.target.label,d.concentrationscale?k+n.format("%0.2f")(d.flow.labelConcentration):""].filter(u).join("<br>"),color:b(s,"bgcolor")||o.addOpacity(d.color,1),borderColor:b(s,"bordercolor"),fontFamily:b(s,"font.family"),fontSize:b(s,"font.size"),fontColor:b(s,"font.color"),nameLength:b(s,"namelength"),textAlign:b(s,"align"),idealAlign:n.event.x<g[0]?"right":"left",hovertemplate:s.hovertemplate,hovertemplateLabels:v,eventData:[d]})}}i.loneHover(l,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:c}).each(function(){a.link.concentrationscale||f(this,.65),p(this)})}}function m(t){var e,r;t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2,r=t.circularPathData.verticalFullExtent):(e=(t.source.x1+t.target.x0)/2,r=(t.y0+t.y1)/2);var n=[e,r];return"v"===t.trace.orientation&&n.reverse(),n[0]+=a.parent.translateX,n[1]+=a.parent.translateY,n}},unhover:function(e,a,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,a,o,!0)),"skip"!==a.link.trace.link.hoverinfo&&(a.link.fullData=a.link.trace,t.emit("plotly_unhover",{event:n.event,points:[a.link]})),i.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var a=r.link;a.originalEvent=n.event,t._hoverdata=[a],i.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,a){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,r,a),"skip"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit("plotly_hover",{event:n.event,points:[r.node]})))},follow:function(e,a){if(!1!==t._fullLayout.hovermode){var o=a.node.trace.node;if("none"!==o.hoverinfo&&"skip"!==o.hoverinfo){var s=n.select(e).select("."+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),h=s.node().getBoundingClientRect(),d=h.left-2-c.left,g=h.right+2-c.left,v=h.top+h.height/4-c.top,m={valueLabel:n.format(a.valueFormat)(a.node.value)+a.valueSuffix};a.node.fullData=a.node.trace;var y=i.loneHover({x0:d,x1:g,y:v,name:n.format(a.valueFormat)(a.node.value)+a.valueSuffix,text:[a.node.label,T+a.node.targetLinks.length,M+a.node.sourceLinks.length].filter(u).join("<br>"),color:b(o,"bgcolor")||a.tinyColorHue,borderColor:b(o,"bordercolor"),fontFamily:b(o,"font.family"),fontSize:b(o,"font.size"),fontColor:b(o,"font.color"),nameLength:b(o,"namelength"),textAlign:b(o,"align"),idealAlign:"left",hovertemplate:o.hovertemplate,hovertemplateLabels:m,eventData:[a.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});f(y,.85),p(y)}}},unhover:function(e,a,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(m,a,o),"skip"!==a.node.trace.node.hoverinfo&&(a.node.fullData=a.node.trace,t.emit("plotly_unhover",{event:n.event,points:[a.node]})),i.loneUnhover(r._hoverlayer.node()))},select:function(e,r,a){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(m,r,a),i.click(t,{target:!0})}}})}},{"../../components/color":591,"../../components/fx":630,"../../lib":717,"./constants":1113,"./render":1117,d3:165}],1117:[function(t,e,r){"use strict";var n=t("./constants"),a=t("d3"),i=t("tinycolor2"),o=t("../../components/color"),s=t("../../components/drawing"),l=t("@plotly/d3-sankey"),c=t("@plotly/d3-sankey-circular"),u=t("d3-force"),h=t("../../lib"),f=t("../../lib/gup"),p=f.keyFun,d=f.repeat,g=f.unwrap,v=t("d3-interpolate").interpolateNumber,m=t("../../registry");function y(){var t=.5;return function(e){if(e.link.circular)return r=e.link,n=r.width/2,a=r.circularPathData,"top"===r.circularLinkType?"M "+a.targetX+" "+(a.targetY+n)+" L"+a.rightInnerExtent+" "+(a.targetY+n)+"A"+(a.rightLargeArcRadius+n)+" "+(a.rightSmallArcRadius+n)+" 0 0 1 "+(a.rightFullExtent-n)+" "+(a.targetY-a.rightSmallArcRadius)+"L"+(a.rightFullExtent-n)+" "+a.verticalRightInnerExtent+"A"+(a.rightLargeArcRadius+n)+" "+(a.rightLargeArcRadius+n)+" 0 0 1 "+a.rightInnerExtent+" "+(a.verticalFullExtent-n)+"L"+a.leftInnerExtent+" "+(a.verticalFullExtent-n)+"A"+(a.leftLargeArcRadius+n)+" "+(a.leftLargeArcRadius+n)+" 0 0 1 "+(a.leftFullExtent+n)+" "+a.verticalLeftInnerExtent+"L"+(a.leftFullExtent+n)+" "+(a.sourceY-a.leftSmallArcRadius)+"A"+(a.leftLargeArcRadius+n)+" "+(a.leftSmallArcRadius+n)+" 0 0 1 "+a.leftInnerExtent+" "+(a.sourceY+n)+"L"+a.sourceX+" "+(a.sourceY+n)+"L"+a.sourceX+" "+(a.sourceY-n)+"L"+a.leftInnerExtent+" "+(a.sourceY-n)+"A"+(a.leftLargeArcRadius-n)+" "+(a.leftSmallArcRadius-n)+" 0 0 0 "+(a.leftFullExtent-n)+" "+(a.sourceY-a.leftSmallArcRadius)+"L"+(a.leftFullExtent-n)+" "+a.verticalLeftInnerExtent+"A"+(a.leftLargeArcRadius-n)+" "+(a.leftLargeArcRadius-n)+" 0 0 0 "+a.leftInnerExtent+" "+(a.verticalFullExtent+n)+"L"+a.rightInnerExtent+" "+(a.verticalFullExtent+n)+"A"+(a.rightLargeArcRadius-n)+" "+(a.rightLargeArcRadius-n)+" 0 0 0 "+(a.rightFullExtent+n)+" "+a.verticalRightInnerExtent+"L"+(a.rightFullExtent+n)+" "+(a.targetY-a.rightSmallArcRadius)+"A"+(a.rightLargeArcRadius-n)+" "+(a.rightSmallArcRadius-n)+" 0 0 0 "+a.rightInnerExtent+" "+(a.targetY-n)+"L"+a.targetX+" "+(a.targetY-n)+"Z":"M "+a.targetX+" "+(a.targetY-n)+" L"+a.rightInnerExtent+" "+(a.targetY-n)+"A"+(a.rightLargeArcRadius+n)+" "+(a.rightSmallArcRadius+n)+" 0 0 0 "+(a.rightFullExtent-n)+" "+(a.targetY+a.rightSmallArcRadius)+"L"+(a.rightFullExtent-n)+" "+a.verticalRightInnerExtent+"A"+(a.rightLargeArcRadius+n)+" "+(a.rightLargeArcRadius+n)+" 0 0 0 "+a.rightInnerExtent+" "+(a.verticalFullExtent+n)+"L"+a.leftInnerExtent+" "+(a.verticalFullExtent+n)+"A"+(a.leftLargeArcRadius+n)+" "+(a.leftLargeArcRadius+n)+" 0 0 0 "+(a.leftFullExtent+n)+" "+a.verticalLeftInnerExtent+"L"+(a.leftFullExtent+n)+" "+(a.sourceY+a.leftSmallArcRadius)+"A"+(a.leftLargeArcRadius+n)+" "+(a.leftSmallArcRadius+n)+" 0 0 0 "+a.leftInnerExtent+" "+(a.sourceY-n)+"L"+a.sourceX+" "+(a.sourceY-n)+"L"+a.sourceX+" "+(a.sourceY+n)+"L"+a.leftInnerExtent+" "+(a.sourceY+n)+"A"+(a.leftLargeArcRadius-n)+" "+(a.leftSmallArcRadius-n)+" 0 0 1 "+(a.leftFullExtent-n)+" "+(a.sourceY+a.leftSmallArcRadius)+"L"+(a.leftFullExtent-n)+" "+a.verticalLeftInnerExtent+"A"+(a.leftLargeArcRadius-n)+" "+(a.leftLargeArcRadius-n)+" 0 0 1 "+a.leftInnerExtent+" "+(a.verticalFullExtent-n)+"L"+a.rightInnerExtent+" "+(a.verticalFullExtent-n)+"A"+(a.rightLargeArcRadius-n)+" "+(a.rightLargeArcRadius-n)+" 0 0 1 "+(a.rightFullExtent+n)+" "+a.verticalRightInnerExtent+"L"+(a.rightFullExtent+n)+" "+(a.targetY+a.rightSmallArcRadius)+"A"+(a.rightLargeArcRadius-n)+" "+(a.rightSmallArcRadius-n)+" 0 0 1 "+a.rightInnerExtent+" "+(a.targetY+n)+"L"+a.targetX+" "+(a.targetY+n)+"Z";var r,n,a,i=e.link.source.x1,o=e.link.target.x0,s=v(i,o),l=s(t),c=s(1-t),u=e.link.y0-e.link.width/2,h=e.link.y0+e.link.width/2,f=e.link.y1-e.link.width/2,p=e.link.y1+e.link.width/2;return"M"+i+","+u+"C"+l+","+u+" "+c+","+f+" "+o+","+f+"L"+o+","+p+"C"+c+","+p+" "+l+","+h+" "+i+","+h+"Z"}}function x(t){t.attr("transform",function(t){return"translate("+t.node.x0.toFixed(3)+", "+t.node.y0.toFixed(3)+")"})}function b(t){t.call(x)}function _(t,e){t.call(b),e.attr("d",y())}function w(t){t.attr("width",function(t){return t.node.x1-t.node.x0}).attr("height",function(t){return t.visibleHeight})}function k(t){return t.link.width>1||t.linkLineWidth>0}function T(t){return"translate("+t.translateX+","+t.translateY+")"+(t.horizontal?"matrix(1 0 0 1 0 0)":"matrix(0 1 1 0 0 0)")}function M(t){return"translate("+(t.horizontal?0:t.labelY)+" "+(t.horizontal?t.labelY:0)+")"}function A(t){return a.svg.line()([[t.horizontal?t.left?-t.sizeAcross:t.visibleWidth+n.nodeTextOffsetHorizontal:n.nodeTextOffsetHorizontal,0],[t.horizontal?t.left?-n.nodeTextOffsetHorizontal:t.sizeAcross:t.visibleHeight-n.nodeTextOffsetHorizontal,0]])}function S(t){return t.horizontal?"matrix(1 0 0 1 0 0)":"matrix(0 1 1 0 0 0)"}function E(t){return t.horizontal?"scale(1 1)":"scale(-1 1)"}function L(t){return t.darkBackground&&!t.horizontal?"rgb(255,255,255)":"rgb(0,0,0)"}function C(t){return t.horizontal&&t.left?"100%":"0%"}function P(t,e,r){t.on(".basic",null).on("mouseover.basic",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])}).on("mousemove.basic",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])}).on("mouseout.basic",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)}).on("click.basic",function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)})}function O(t,e,r,i){var o=a.behavior.drag().origin(function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}}).on("dragstart",function(a){if("fixed"!==a.arrangement&&(h.ensureSingle(i._fullLayout._infolayer,"g","dragcover",function(t){i._fullLayout._dragCover=t}),h.raiseToTop(this),a.interactionState.dragInProgress=a.node,I(a.node),a.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,a.interactionState.hovered),a.interactionState.hovered=!1),"snap"===a.arrangement)){var o=a.traceId+"|"+a.key;a.forceLayouts[o]?a.forceLayouts[o].alpha(1):function(t,e,r,a){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var i=r.graph.nodes.filter(function(t){return t.originalX===r.node.originalX}).filter(function(t){return!t.partOfGroup});r.forceLayouts[e]=u.forceSimulation(i).alphaDecay(0).force("collide",u.forceCollide().radius(function(t){return t.dy/2+r.nodePad/2}).strength(1).iterations(n.forceIterations)).force("constrain",function(t,e,r,a){return function(){for(var t=0,i=0;i<r.length;i++){var o=r[i];o===a.interactionState.dragInProgress?(o.x=o.lastDraggedX,o.y=o.lastDraggedY):(o.vx=(o.originalX-o.x)/n.forceTicksPerFrame,o.y=Math.min(a.size-o.dy/2,Math.max(o.dy/2,o.y))),t=Math.max(t,Math.abs(o.vx),Math.abs(o.vy))}!a.interactionState.dragInProgress&&t<.1&&a.forceLayouts[e].alpha()>0&&a.forceLayouts[e].alpha(0)}}(0,e,i,r)).stop()}(0,o,a),function(t,e,r,a,i){window.requestAnimationFrame(function o(){var s;for(s=0;s<n.forceTicksPerFrame;s++)r.forceLayouts[a].tick();var l=r.graph.nodes;if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(l),r.sankey.update(r.graph),_(t.filter(D(r)),e),r.forceLayouts[a].alpha()>0)window.requestAnimationFrame(o);else{var c=r.node.originalX;r.node.x0=c-r.visibleWidth/2,r.node.x1=c+r.visibleWidth/2,z(r,i)}})}(t,e,a,o,i)}}).on("drag",function(r){if("fixed"!==r.arrangement){var n=a.event.x,i=a.event.y;"snap"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=i-r.visibleHeight/2,r.node.y1=i+r.visibleHeight/2):("freeform"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),i=Math.max(0,Math.min(r.size-r.visibleHeight/2,i)),r.node.y0=i-r.visibleHeight/2,r.node.y1=i+r.visibleHeight/2),I(r.node),"snap"!==r.arrangement&&(r.sankey.update(r.graph),_(t.filter(D(r)),e))}}).on("dragend",function(t){if("fixed"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;"snap"!==t.arrangement&&z(t,i)}});t.on(".drag",null).call(o)}function z(t,e){for(var r=[],n=[],a=0;a<t.graph.nodes.length;a++){var i=(t.graph.nodes[a].x0+t.graph.nodes[a].x1)/2,o=(t.graph.nodes[a].y0+t.graph.nodes[a].y1)/2;r.push(i/t.figure.width),n.push(o/t.figure.height)}m.call("_guiRestyle",e,{"node.x":[r],"node.y":[n]},t.trace.index).then(function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()})}function I(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function D(t){return function(e){return e.node.originalX===t.node.originalX}}e.exports=function(t,e,r,u,f){var v=!1;h.ensureSingle(t._fullLayout._infolayer,"g","first-render",function(){v=!0});var m=t._fullLayout._dragCover,b=r.filter(function(t){return g(t).trace.visible}).map(function(t,e,r){var a,o=g(e),s=o.trace,u=s.domain,f="h"===s.orientation,p=s.node.pad,d=s.node.thickness,v=t.width*(u.x[1]-u.x[0]),m=t.height*(u.y[1]-u.y[0]),y=o._nodes,x=o._links,b=o.circular;(a=b?c.sankeyCircular().circularLinkGap(0):l.sankey()).iterations(n.sankeyIterations).size(f?[v,m]:[m,v]).nodeWidth(d).nodePadding(p).nodeId(function(t){return t.pointNumber}).nodes(y).links(x);var _,w,k,T=a();for(var M in a.nodePadding()<p&&h.warn("node.pad was reduced to ",a.nodePadding()," to fit within the figure."),o._groupLookup){var A,S=parseInt(o._groupLookup[M]);for(_=0;_<T.nodes.length;_++)if(T.nodes[_].pointNumber===S){A=T.nodes[_];break}if(A){var E={pointNumber:parseInt(M),x0:A.x0,x1:A.x1,y0:A.y0,y1:A.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};T.nodes.unshift(E),A.childrenNodes.unshift(E)}}if(function(){for(_=0;_<T.nodes.length;_++){var t,e,r=T.nodes[_],n={};for(w=0;w<r.targetLinks.length;w++)t=(e=r.targetLinks[w]).source.pointNumber+":"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var a=Object.keys(n);for(w=0;w<a.length;w++){var o=n[t=a[w]],s=0,l={};for(k=0;k<o.length;k++)l[(e=o[k]).label]||(l[e.label]=0),l[e.label]+=e.value,s+=e.value;for(k=0;k<o.length;k++)(e=o[k]).flow={value:s,labelConcentration:l[e.label]/s,concentration:e.value/s,links:o},e.concentrationscale&&(e.color=i(e.concentrationscale(e.flow.labelConcentration)))}var c=0;for(w=0;w<r.sourceLinks.length;w++)c+=r.sourceLinks[w].value;for(w=0;w<r.sourceLinks.length;w++)(e=r.sourceLinks[w]).concentrationOut=e.value/c;var u=0;for(w=0;w<r.targetLinks.length;w++)u+=r.targetLinks[w].value;for(w=0;w<r.targetLinks.length;w++)(e=r.targetLinks[w]).concenrationIn=e.value/u}}(),s.node.x.length&&s.node.y.length){for(_=0;_<Math.min(s.node.x.length,s.node.y.length,T.nodes.length);_++)if(s.node.x[_]&&s.node.y[_]){var L=[s.node.x[_]*v,s.node.y[_]*m];T.nodes[_].x0=L[0]-d/2,T.nodes[_].x1=L[0]+d/2;var C=T.nodes[_].y1-T.nodes[_].y0;T.nodes[_].y0=L[1]-C/2,T.nodes[_].y1=L[1]+C/2}"snap"===s.arrangement&&function(t){t.forEach(function(t){var e,r,n,a=0,i=t.length;for(t.sort(function(t,e){return t.y0-e.y0}),n=0;n<i;++n)(e=t[n]).y0>=a||(r=a-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),a=e.y1+p})}(function(t){var e,r,n=t.map(function(t,e){return{x0:t.x0,index:e}}).sort(function(t,e){return t.x0-e.x0}),a=[],i=-1,o=-1/0;for(_=0;_<n.length;_++){var s=t[n[_].index];s.x0>o+d&&(i+=1,e=s.x0),o=s.x0,a[i]||(a[i]=[]),a[i].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return a}(y=T.nodes)),a.update(T)}return{circular:b,key:r,trace:s,guid:h.randstr(),horizontal:f,width:v,height:m,nodePad:s.node.pad,nodeLineColor:s.node.line.color,nodeLineWidth:s.node.line.width,linkLineColor:s.link.line.color,linkLineWidth:s.link.line.width,valueFormat:s.valueformat,valueSuffix:s.valuesuffix,textFont:s.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:f?m:v,dragPerpendicular:f?v:m,arrangement:s.arrangement,sankey:a,graph:T,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}.bind(null,u)),_=e.selectAll("."+n.cn.sankey).data(b,p);_.exit().remove(),_.enter().append("g").classed(n.cn.sankey,!0).style("box-sizing","content-box").style("position","absolute").style("left",0).style("shape-rendering","geometricPrecision").style("pointer-events","auto").attr("transform",T),_.each(function(e,r){t._fullData[r]._sankey=e;var n="bgsankey-"+e.trace.uid+"-"+r;h.ensureSingle(t._fullLayout._draggers,"rect",n),t._fullData[r]._bgRect=a.select("."+n),t._fullData[r]._bgRect.style("pointer-events","all").attr("width",e.width).attr("height",e.height).attr("x",e.translateX).attr("y",e.translateY).classed("bgsankey",!0).style({fill:"transparent","stroke-width":0})}),_.transition().ease(n.ease).duration(n.duration).attr("transform",T);var z=_.selectAll("."+n.cn.sankeyLinks).data(d,p);z.enter().append("g").classed(n.cn.sankeyLinks,!0).style("fill","none");var I=z.selectAll("."+n.cn.sankeyLink).data(function(t){return t.graph.links.filter(function(t){return t.value}).map(function(t,e,r){var n=i(e.color),a=e.source.label+"|"+e.target.label+"__"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:a,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:o.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkPath:y,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}.bind(null,t))},p);I.enter().append("path").classed(n.cn.sankeyLink,!0).call(P,_,f.linkEvents),I.style("stroke",function(t){return k(t)?o.tinyRGB(i(t.linkLineColor)):t.tinyColorHue}).style("stroke-opacity",function(t){return k(t)?o.opacity(t.linkLineColor):t.tinyColorAlpha}).style("fill",function(t){return t.tinyColorHue}).style("fill-opacity",function(t){return t.tinyColorAlpha}).style("stroke-width",function(t){return k(t)?t.linkLineWidth:1}).attr("d",y()),I.style("opacity",function(){return t._context.staticPlot||v||m?1:0}).transition().ease(n.ease).duration(n.duration).style("opacity",1),I.exit().transition().ease(n.ease).duration(n.duration).style("opacity",0).remove();var D=_.selectAll("."+n.cn.sankeyNodeSet).data(d,p);D.enter().append("g").classed(n.cn.sankeyNodeSet,!0),D.style("cursor",function(t){switch(t.arrangement){case"fixed":return"default";case"perpendicular":return"ns-resize";default:return"move"}});var R=D.selectAll("."+n.cn.sankeyNode).data(function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort(function(t,e){return t-e}),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(function(t,e){var r=i(e.color),a=n.nodePadAcross,s=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var l=e.dx,c=Math.max(.5,e.dy),u="node_"+e.pointNumber;return e.group&&(u=h.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:u,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(l),visibleHeight:c,zoneX:-a,zoneY:-s,zoneWidth:l+2*a,zoneHeight:c+2*s,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:o.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,u].join("_"),interactionState:t.interactionState,figure:t}}.bind(null,t))},p);R.enter().append("g").classed(n.cn.sankeyNode,!0).call(x).style("opacity",function(e){return!t._context.staticPlot&&!v||e.partOfGroup?0:1}),R.call(P,_,f.nodeEvents).call(O,I,f,t),R.transition().ease(n.ease).duration(n.duration).call(x).style("opacity",function(t){return t.partOfGroup?0:1}),R.exit().transition().ease(n.ease).duration(n.duration).style("opacity",0).remove();var F=R.selectAll("."+n.cn.nodeRect).data(d);F.enter().append("rect").classed(n.cn.nodeRect,!0).call(w),F.style("stroke-width",function(t){return t.nodeLineWidth}).style("stroke",function(t){return o.tinyRGB(i(t.nodeLineColor))}).style("stroke-opacity",function(t){return o.opacity(t.nodeLineColor)}).style("fill",function(t){return t.tinyColorHue}).style("fill-opacity",function(t){return t.tinyColorAlpha}),F.transition().ease(n.ease).duration(n.duration).call(w);var B=R.selectAll("."+n.cn.nodeCapture).data(d);B.enter().append("rect").classed(n.cn.nodeCapture,!0).style("fill-opacity",0),B.attr("x",function(t){return t.zoneX}).attr("y",function(t){return t.zoneY}).attr("width",function(t){return t.zoneWidth}).attr("height",function(t){return t.zoneHeight});var N=R.selectAll("."+n.cn.nodeCentered).data(d);N.enter().append("g").classed(n.cn.nodeCentered,!0).attr("transform",M),N.transition().ease(n.ease).duration(n.duration).attr("transform",M);var j=N.selectAll("."+n.cn.nodeLabelGuide).data(d);j.enter().append("path").classed(n.cn.nodeLabelGuide,!0).attr("id",function(t){return t.uniqueNodeLabelPathId}).attr("d",A).attr("transform",S),j.transition().ease(n.ease).duration(n.duration).attr("d",A).attr("transform",S);var V=N.selectAll("."+n.cn.nodeLabel).data(d);V.enter().append("text").classed(n.cn.nodeLabel,!0).attr("transform",E).style("user-select","none").style("cursor","default").style("fill","black"),V.style("text-shadow",function(t){return t.horizontal?"-1px 1px 1px #fff, 1px 1px 1px #fff, 1px -1px 1px #fff, -1px -1px 1px #fff":"none"}).each(function(t){s.font(V,t.textFont)}),V.transition().ease(n.ease).duration(n.duration).attr("transform",E);var U=V.selectAll("."+n.cn.nodeLabelTextPath).data(d);U.enter().append("textPath").classed(n.cn.nodeLabelTextPath,!0).attr("alignment-baseline","middle").attr("xlink:href",function(t){return"#"+t.uniqueNodeLabelPathId}).attr("startOffset",C).style("fill",L),U.text(function(t){return t.horizontal||t.node.dy>5?t.node.label:""}).attr("text-anchor",function(t){return t.horizontal&&t.left?"end":"start"}),U.transition().ease(n.ease).duration(n.duration).attr("startOffset",C).style("fill",L)}},{"../../components/color":591,"../../components/drawing":612,"../../lib":717,"../../lib/gup":715,"../../registry":846,"./constants":1113,"@plotly/d3-sankey":56,"@plotly/d3-sankey-circular":55,d3:165,"d3-force":158,"d3-interpolate":160,tinycolor2:535}],1118:[function(t,e,r){"use strict";e.exports=function(t,e){for(var r=[],n=t.cd[0].trace,a=n._sankey.graph.nodes,i=0;i<a.length;i++){var o=a[i];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];"v"===n.orientation&&s.reverse(),e&&e.contains(s,!1,i,t)&&r.push({pointNumber:o.pointNumber})}}return r}},{}],1119:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,"tx"),n.mergeArray(e.texttemplate,t,"txt"),n.mergeArray(e.hovertext,t,"htx"),n.mergeArray(e.customdata,t,"data"),n.mergeArray(e.textposition,t,"tp"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,"ts"),n.mergeArray(e.textfont.color,t,"tc"),n.mergeArray(e.textfont.family,t,"tf"));var a=e.marker;if(a){n.mergeArrayCastPositive(a.size,t,"ms"),n.mergeArrayCastPositive(a.opacity,t,"mo"),n.mergeArray(a.symbol,t,"mx"),n.mergeArray(a.color,t,"mc");var i=a.line;a.line&&(n.mergeArray(i.color,t,"mlc"),n.mergeArrayCastPositive(i.width,t,"mlw"));var o=a.gradient;o&&"none"!==o.type&&(n.mergeArray(o.type,t,"mgt"),n.mergeArray(o.color,t,"mgc"))}}},{"../../lib":717}],1120:[function(t,e,r){"use strict";var n=t("../../plots/template_attributes").texttemplateAttrs,a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../../components/colorscale/attributes"),o=t("../../plots/font_attributes"),s=t("../../components/drawing/attributes").dash,l=t("../../components/drawing"),c=t("./constants"),u=t("../../lib/extend").extendFlat;e.exports={x:{valType:"data_array",editType:"calc+clearAxisTypes",anim:!0},x0:{valType:"any",dflt:0,editType:"calc+clearAxisTypes",anim:!0},dx:{valType:"number",dflt:1,editType:"calc",anim:!0},y:{valType:"data_array",editType:"calc+clearAxisTypes",anim:!0},y0:{valType:"any",dflt:0,editType:"calc+clearAxisTypes",anim:!0},dy:{valType:"number",dflt:1,editType:"calc",anim:!0},stackgroup:{valType:"string",dflt:"",editType:"calc"},orientation:{valType:"enumerated",values:["v","h"],editType:"calc"},groupnorm:{valType:"enumerated",values:["","fraction","percent"],dflt:"",editType:"calc"},stackgaps:{valType:"enumerated",values:["infer zero","interpolate"],dflt:"infer zero",editType:"calc"},text:{valType:"string",dflt:"",arrayOk:!0,editType:"calc"},texttemplate:n({},{}),hovertext:{valType:"string",dflt:"",arrayOk:!0,editType:"style"},mode:{valType:"flaglist",flags:["lines","markers","text"],extras:["none"],editType:"calc"},hoveron:{valType:"flaglist",flags:["points","fills"],editType:"style"},hovertemplate:a({},{keys:c.eventDataKeys}),line:{color:{valType:"color",editType:"style",anim:!0},width:{valType:"number",min:0,dflt:2,editType:"style",anim:!0},shape:{valType:"enumerated",values:["linear","spline","hv","vh","hvh","vhv"],dflt:"linear",editType:"plot"},smoothing:{valType:"number",min:0,max:1.3,dflt:1,editType:"plot"},dash:u({},s,{editType:"style"}),simplify:{valType:"boolean",dflt:!0,editType:"plot"},editType:"plot"},connectgaps:{valType:"boolean",dflt:!1,editType:"calc"},cliponaxis:{valType:"boolean",dflt:!0,editType:"plot"},fill:{valType:"enumerated",values:["none","tozeroy","tozerox","tonexty","tonextx","toself","tonext"],editType:"calc"},fillcolor:{valType:"color",editType:"style",anim:!0},marker:u({symbol:{valType:"enumerated",values:l.symbolList,dflt:"circle",arrayOk:!0,editType:"style"},opacity:{valType:"number",min:0,max:1,arrayOk:!0,editType:"style",anim:!0},size:{valType:"number",min:0,dflt:6,arrayOk:!0,editType:"calc",anim:!0},maxdisplayed:{valType:"number",min:0,dflt:0,editType:"plot"},sizeref:{valType:"number",dflt:1,editType:"calc"},sizemin:{valType:"number",min:0,dflt:0,editType:"calc"},sizemode:{valType:"enumerated",values:["diameter","area"],dflt:"diameter",editType:"calc"},line:u({width:{valType:"number",min:0,arrayOk:!0,editType:"style",anim:!0},editType:"calc"},i("marker.line",{anim:!0})),gradient:{type:{valType:"enumerated",values:["radial","horizontal","vertical","none"],arrayOk:!0,dflt:"none",editType:"calc"},color:{valType:"color",arrayOk:!0,editType:"calc"},editType:"calc"},editType:"calc"},i("marker",{anim:!0})),selected:{marker:{opacity:{valType:"number",min:0,max:1,editType:"style"},color:{valType:"color",editType:"style"},size:{valType:"number",min:0,editType:"style"},editType:"style"},textfont:{color:{valType:"color",editType:"style"},editType:"style"},editType:"style"},unselected:{marker:{opacity:{valType:"number",min:0,max:1,editType:"style"},color:{valType:"color",editType:"style"},size:{valType:"number",min:0,editType:"style"},editType:"style"},textfont:{color:{valType:"color",editType:"style"},editType:"style"},editType:"style"},textposition:{valType:"enumerated",values:["top left","top center","top right","middle left","middle center","middle right","bottom left","bottom center","bottom right"],dflt:"middle center",arrayOk:!0,editType:"calc"},textfont:o({editType:"calc",colorEditType:"style",arrayOk:!0}),r:{valType:"data_array",editType:"calc"},t:{valType:"data_array",editType:"calc"}}},{"../../components/colorscale/attributes":598,"../../components/drawing":612,"../../components/drawing/attributes":611,"../../lib/extend":708,"../../plots/font_attributes":791,"../../plots/template_attributes":841,"./constants":1124}],1121:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../plots/cartesian/axes"),o=t("../../constants/numerical").BADNUM,s=t("./subtypes"),l=t("./colorscale_calc"),c=t("./arrays_to_calcdata"),u=t("./calc_selection");function h(t,e,r,n,a,o,l){var c=e._length,u=t._fullLayout,h=r._id,f=n._id,p=u._firstScatter[d(e)]===e.uid,v=(g(e,u,r,n)||{}).orientation,m=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};l&&(y.ppad=x.ppad=l);var b=c<2||a[0]!==a[c-1]||o[0]!==o[c-1];b&&("tozerox"===m||"tonextx"===m&&(p||"h"===v))?y.tozero=!0:(e.error_y||{}).visible||"tonexty"!==m&&"tozeroy"!==m&&(s.hasMarkers(e)||s.hasText(e))||(y.padded=!1,y.ppad=0),b&&("tozeroy"===m||"tonexty"===m&&(p||"v"===v))?x.tozero=!0:"tonextx"!==m&&"tozerox"!==m||(x.padded=!1),h&&(e._extremes[h]=i.findExtremes(r,a,y)),f&&(e._extremes[f]=i.findExtremes(n,o,x))}function f(t,e){if(s.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r="area"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},a.isArrayOrTypedArray(n.size)){var l={type:"linear"};i.setConvert(l);for(var c=l.makeCalcdata(t.marker,"size"),u=new Array(e),h=0;h<e;h++)u[h]=r(c[h]);return u}return r(n.size)}}function p(t,e){var r=d(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function d(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?"-"+e:"")}function g(t,e,r,n){var a=t.stackgroup;if(a){var i=e._scatterStackOpts[r._id+n._id][a],o="v"===i.orientation?n:r;return"linear"===o.type||"log"===o.type?i:void 0}}e.exports={calc:function(t,e){var r,s,d,v,m,y,x=t._fullLayout,b=i.getFromId(t,e.xaxis||"x"),_=i.getFromId(t,e.yaxis||"y"),w=b.makeCalcdata(e,"x"),k=_.makeCalcdata(e,"y"),T=e._length,M=new Array(T),A=e.ids,S=g(e,x,b,_),E=!1;p(x,e);var L,C="x",P="y";for(S?(a.pushUnique(S.traceIndices,e._expandedIndex),(r="v"===S.orientation)?(P="s",L="x"):(C="s",L="y"),m="interpolate"===S.stackgaps):h(t,e,b,_,w,k,f(e,T)),s=0;s<T;s++){var O=M[s]={},z=n(w[s]),I=n(k[s]);z&&I?(O[C]=w[s],O[P]=k[s]):S&&(r?z:I)?(O[L]=r?w[s]:k[s],O.gap=!0,m?(O.s=o,E=!0):O.s=0):O[C]=O[P]=o,A&&(O.id=String(A[s]))}if(c(M,e),l(t,e),u(M,e),S){for(s=0;s<M.length;)M[s][L]===o?M.splice(s,1):s++;if(a.sort(M,function(t,e){return t[L]-e[L]||t.i-e.i}),E){for(s=0;s<M.length-1&&M[s].gap;)s++;for((y=M[s].s)||(y=M[s].s=0),d=0;d<s;d++)M[d].s=y;for(v=M.length-1;v>s&&M[v].gap;)v--;for(y=M[v].s,d=M.length-1;d>v;d--)M[d].s=y;for(;s<v;)if(M[++s].gap){for(d=s+1;M[d].gap;)d++;for(var D=M[s-1][L],R=M[s-1].s,F=(M[d].s-R)/(M[d][L]-D);s<d;)M[s].s=R+(M[s][L]-D)*F,s++}}}return M},calcMarkerSize:f,calcAxisExpansion:h,setFirstScatter:p,getStackOpts:g}},{"../../constants/numerical":693,"../../lib":717,"../../plots/cartesian/axes":765,"./arrays_to_calcdata":1119,"./calc_selection":1122,"./colorscale_calc":1123,"./subtypes":1144,"fast-isnumeric":228}],1122:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{"../../lib":717}],1123:[function(t,e,r){"use strict";var n=t("../../components/colorscale/helpers").hasColorscale,a=t("../../components/colorscale/calc"),i=t("./subtypes");e.exports=function(t,e){i.hasLines(e)&&n(e,"line")&&a(t,e,{vals:e.line.color,containerStr:"line",cLetter:"c"}),i.hasMarkers(e)&&(n(e,"marker")&&a(t,e,{vals:e.marker.color,containerStr:"marker",cLetter:"c"}),n(e,"marker.line")&&a(t,e,{vals:e.marker.line.color,containerStr:"marker.line",cLetter:"c"}))}},{"../../components/colorscale/calc":599,"../../components/colorscale/helpers":602,"./subtypes":1144}],1124:[function(t,e,r){"use strict";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1125:[function(t,e,r){"use strict";var n=t("./calc");function a(t,e,r,n,a,i,o){a[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else i&&(s.s=function(t,e,r,n){var a=t[e-1],i=t[e+1];return i?a?a.s+(i.s-a.s)*(r-a[n])/(i[n]-a[n]):i.s:a.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,i=e.yaxis,o=r._id+i._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k=t.calcdata;for(var T in s){var M=(m=s[T]).traceIndices;if(M.length){for(y="interpolate"===m.stackgaps,x=m.groupnorm,"v"===m.orientation?(b="x",_="y"):(b="y",_="x"),w=new Array(M.length),l=0;l<w.length;l++)w[l]=!1;p=k[M[0]];var A=new Array(p.length);for(l=0;l<p.length;l++)A[l]=p[l][b];for(l=1;l<M.length;l++){for(f=k[M[l]],c=u=0;c<f.length;c++){for(d=f[c][b];d>A[u]&&u<A.length;u++)a(f,c,A[u],l,w,y,b),c++;if(d!==A[u]){for(h=0;h<l;h++)a(k[M[h]],u,d,h,w,y,b);A.splice(u,0,d)}u++}for(;u<A.length;u++)a(f,c,A[u],l,w,y,b),c++}var S=A.length;for(c=0;c<p.length;c++){for(g=p[c][_]=p[c].s,l=1;l<M.length;l++)(f=k[M[l]])[0].trace._rawLength=f[0].trace._length,f[0].trace._length=S,g+=f[c].s,f[c][_]=g;if(x)for(v=("fraction"===x?g:g/100)||1,l=0;l<M.length;l++){var E=k[M[l]][c];E[_]/=v,E.sNorm=E.s/v}}for(l=0;l<M.length;l++){var L=(f=k[M[l]])[0].trace,C=n.calcMarkerSize(L,L._rawLength),P=Array.isArray(C);if(C&&w[l]||P){var O=C;for(C=new Array(S),c=0;c<S;c++)C[c]=f[c].gap?0:P?O[f[c].i]:O}var z=new Array(S),I=new Array(S);for(c=0;c<S;c++)z[c]=f[c].x,I[c]=f[c].y;n.calcAxisExpansion(t,L,r,i,z,I,C),f[0].t.orientation=m.orientation}}}}}},{"./calc":1121}],1126:[function(t,e,r){"use strict";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if("scatter"===r.type){var n=r.fill;if("none"!==n&&"toself"!==n&&(r.opacity=void 0,"tonexty"===n||"tonextx"===n))for(var a=e-1;a>=0;a--){var i=t[a];if("scatter"===i.type&&i.xaxis===r.xaxis&&i.yaxis===r.yaxis){i.opacity=void 0;break}}}}}},{}],1127:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../registry"),i=t("./attributes"),o=t("./constants"),s=t("./subtypes"),l=t("./xy_defaults"),c=t("./stack_defaults"),u=t("./marker_defaults"),h=t("./line_defaults"),f=t("./line_shape_defaults"),p=t("./text_defaults"),d=t("./fillcolor_defaults");e.exports=function(t,e,r,g){function v(r,a){return n.coerce(t,e,i,r,a)}var m=l(t,e,g,v);if(m||(e.visible=!1),e.visible){var y=c(t,e,g,v),x=!y&&m<o.PTS_LINESONLY?"lines+markers":"lines";v("text"),v("hovertext"),v("mode",x),s.hasLines(e)&&(h(t,e,r,g,v),f(t,e,v),v("connectgaps"),v("line.simplify")),s.hasMarkers(e)&&u(t,e,r,g,v,{gradient:!0}),s.hasText(e)&&(v("texttemplate"),p(t,e,g,v));var b=[];(s.hasMarkers(e)||s.hasText(e))&&(v("cliponaxis"),v("marker.maxdisplayed"),b.push("points")),v("fill",y?y.fillDflt:"none"),"none"!==e.fill&&(d(t,e,r,v),s.hasLines(e)||f(t,e,v));var _=(e.line||{}).color,w=(e.marker||{}).color;"tonext"!==e.fill&&"toself"!==e.fill||b.push("fills"),v("hoveron",b.join("+")||"points"),"fills"!==e.hoveron&&v("hovertemplate");var k=a.getComponentMethod("errorbars","supplyDefaults");k(t,e,_||w||r,{axis:"y"}),k(t,e,_||w||r,{axis:"x",inherit:"y"}),n.coerceSelectionMarkerOpacity(e,v)}}},{"../../lib":717,"../../registry":846,"./attributes":1120,"./constants":1124,"./fillcolor_defaults":1128,"./line_defaults":1133,"./line_shape_defaults":1135,"./marker_defaults":1139,"./stack_defaults":1142,"./subtypes":1144,"./text_defaults":1145,"./xy_defaults":1146}],1128:[function(t,e,r){"use strict";var n=t("../../components/color"),a=t("../../lib").isArrayOrTypedArray;e.exports=function(t,e,r,i){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!a(s)?o=s:l&&!a(l)&&(o=l)}i("fillcolor",n.addOpacity((e.line||{}).color||o||r,.5))}},{"../../components/color":591,"../../lib":717}],1129:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes");e.exports=function(t,e,r){var a={},i={_fullLayout:r},o=n.getFromTrace(i,e,"x"),s=n.getFromTrace(i,e,"y");return a.xLabel=n.tickText(o,t.x,!0).text,a.yLabel=n.tickText(s,t.y,!0).text,a}},{"../../plots/cartesian/axes":765}],1130:[function(t,e,r){"use strict";var n=t("../../components/color"),a=t("./subtypes");e.exports=function(t,e){var r,i;if("lines"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if("none"===t.mode)return t.fill?t.fillcolor:"";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(i=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:"")?n.opacity(i)<.3?n.addOpacity(i,.3):i:(r=(t.line||{}).color)&&n.opacity(r)&&a.hasLines(t)&&t.line.width?r:t.fillcolor}},{"../../components/color":591,"./subtypes":1144}],1131:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/fx"),i=t("../../registry"),o=t("./get_trace_color"),s=t("../../components/color"),l=n.fillText;e.exports=function(t,e,r,c){var u=t.cd,h=u[0].trace,f=t.xa,p=t.ya,d=f.c2p(e),g=p.c2p(r),v=[d,g],m=h.hoveron||"",y=-1!==h.mode.indexOf("markers")?3:.5;if(-1!==m.indexOf("points")){var x=function(t){var e=Math.max(y,t.mrc||0),r=f.c2p(t.x)-d,n=p.c2p(t.y)-g;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=a.getDistanceFunction(c,function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(f.c2p(t.x)-d);return n<e?r*n/e:n-e+r},function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-g);return n<e?r*n/e:n-e+r},x);if(a.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=f.c2p(_.x,!0),k=p.c2p(_.y,!0),T=_.mrc||1;t.index=_.i;var M=u[0].t.orientation,A=M&&(_.sNorm||_.s),S="h"===M?A:_.x,E="v"===M?A:_.y;return n.extendFlat(t,{color:o(h,_),x0:w-T,x1:w+T,xLabelVal:S,y0:k-T,y1:k+T,yLabelVal:E,spikeDistance:x(_),hovertemplate:h.hovertemplate}),l(_,h,t),i.getComponentMethod("errorbars","hoverInfo")(_,h,t),[t]}}if(-1!==m.indexOf("fills")&&h._polygons){var L,C,P,O,z,I,D,R,F,B=h._polygons,N=[],j=!1,V=1/0,U=-1/0,q=1/0,H=-1/0;for(L=0;L<B.length;L++)(P=B[L]).contains(v)&&(j=!j,N.push(P),q=Math.min(q,P.ymin),H=Math.max(H,P.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(L=0;L<N.length;L++)for(O=N[L].pts,C=1;C<O.length;C++)(R=O[C-1][1])>G!=(F=O[C][1])>=G&&(I=O[C-1][0],D=O[C][0],F-R&&(z=I+(D-I)*(G-R)/(F-R),V=Math.min(V,z),U=Math.max(U,z)));V=Math.max(V,0),U=Math.min(U,f._length);var Y=s.defaultLine;return s.opacity(h.fillcolor)?Y=h.fillcolor:s.opacity((h.line||{}).color)&&(Y=h.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:V,x1:U,y0:G,y1:G,color:Y,hovertemplate:!1}),delete t.index,h.text&&!Array.isArray(h.text)?t.text=String(h.text):t.text=h.name,[t]}}}},{"../../components/color":591,"../../components/fx":630,"../../lib":717,"../../registry":846,"./get_trace_color":1130}],1132:[function(t,e,r){"use strict";var n=t("./subtypes");e.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:t("./attributes"),supplyDefaults:t("./defaults"),crossTraceDefaults:t("./cross_trace_defaults"),calc:t("./calc").calc,crossTraceCalc:t("./cross_trace_calc"),arraysToCalcdata:t("./arrays_to_calcdata"),plot:t("./plot"),colorbar:t("./marker_colorbar"),formatLabels:t("./format_labels"),style:t("./style").style,styleOnSelect:t("./style").styleOnSelect,hoverPoints:t("./hover"),selectPoints:t("./select"),animatable:!0,moduleType:"trace",name:"scatter",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","symbols","errorBarsOK","showLegend","scatter-like","zoomScale"],meta:{}}},{"../../plots/cartesian":776,"./arrays_to_calcdata":1119,"./attributes":1120,"./calc":1121,"./cross_trace_calc":1125,"./cross_trace_defaults":1126,"./defaults":1127,"./format_labels":1129,"./hover":1131,"./marker_colorbar":1138,"./plot":1140,"./select":1141,"./style":1143,"./subtypes":1144}],1133:[function(t,e,r){"use strict";var n=t("../../lib").isArrayOrTypedArray,a=t("../../components/colorscale/helpers").hasColorscale,i=t("../../components/colorscale/defaults");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s("line.color",r),a(t,"line"))?i(t,e,o,s,{prefix:"line.",cLetter:"c"}):s("line.color",!n(c)&&c||r);s("line.width"),(l||{}).noDash||s("line.dash")}},{"../../components/colorscale/defaults":601,"../../components/colorscale/helpers":602,"../../lib":717}],1134:[function(t,e,r){"use strict";var n=t("../../constants/numerical"),a=n.BADNUM,i=n.LOG_CLIP,o=i+.5,s=i-.5,l=t("../../lib"),c=l.segmentsIntersect,u=l.constrain,h=t("./constants");e.exports=function(t,e){var r,n,i,f,p,d,g,v,m,y,x,b,_,w,k,T,M,A,S=e.xaxis,E=e.yaxis,L="log"===S.type,C="log"===E.type,P=S._length,O=E._length,z=e.connectGaps,I=e.baseTolerance,D=e.shape,R="linear"===D,F=e.fill&&"none"!==e.fill,B=[],N=h.minTolerance,j=t.length,V=new Array(j),U=0;function q(r){var n=t[r];if(!n)return!1;var i=e.linearized?S.l2p(n.x):S.c2p(n.x),l=e.linearized?E.l2p(n.y):E.c2p(n.y);if(i===a){if(L&&(i=S.c2p(n.x,!0)),i===a)return!1;C&&l===a&&(i*=Math.abs(S._m*O*(S._m>0?o:s)/(E._m*P*(E._m>0?o:s)))),i*=1e3}if(l===a){if(C&&(l=E.c2p(n.y,!0)),l===a)return!1;l*=1e3}return[i,l]}function H(t,e,r,n){var a=r-t,i=n-e,o=.5-t,s=.5-e,l=a*a+i*i,c=a*o+i*s;if(c>0&&c<l){var u=o*i-s*a;if(u*u<l)return!0}}function G(t,e){var r=t[0]/P,n=t[1]/O,a=Math.max(0,-r,r-1,-n,n-1);return a&&void 0!==M&&H(r,n,M,A)&&(a=0),a&&e&&H(r,n,e[0]/P,e[1]/O)&&(a=0),(1+h.toleranceGrowth*a)*I}function Y(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var W,X,Z,J,K,Q,$,tt=h.maxScreensAway,et=-P*tt,rt=P*(1+tt),nt=-O*tt,at=O*(1+tt),it=[[et,nt,rt,nt],[rt,nt,rt,at],[rt,at,et,at],[et,at,et,nt]];function ot(t){if(t[0]<et||t[0]>rt||t[1]<nt||t[1]>at)return[u(t[0],et,rt),u(t[1],nt,at)]}function st(t,e){return t[0]===e[0]&&(t[0]===et||t[0]===rt)||(t[1]===e[1]&&(t[1]===nt||t[1]===at)||void 0)}function lt(t,e,r){return function(n,a){var i=ot(n),o=ot(a),s=[];if(i&&o&&st(i,o))return s;i&&s.push(i),o&&s.push(o);var c=2*l.constrain((n[t]+a[t])/2,e,r)-((i||n)[t]+(o||a)[t]);c&&((i&&o?c>0==i[t]>o[t]?i:o:i||o)[t]+=c);return s}}function ct(t){var e=t[0],r=t[1],n=e===V[U-1][0],a=r===V[U-1][1];if(!n||!a)if(U>1){var i=e===V[U-2][0],o=r===V[U-2][1];n&&(e===et||e===rt)&&i?o?U--:V[U-1]=t:a&&(r===nt||r===at)&&o?i?U--:V[U-1]=t:V[U++]=t}else V[U++]=t}function ut(t){V[U-1][0]!==t[0]&&V[U-1][1]!==t[1]&&ct([Z,J]),ct(t),K=null,Z=J=0}function ht(t){if(M=t[0]/P,A=t[1]/O,W=t[0]<et?et:t[0]>rt?rt:0,X=t[1]<nt?nt:t[1]>at?at:0,W||X){if(U)if(K){var e=$(K,t);e.length>1&&(ut(e[0]),V[U++]=e[1])}else Q=$(V[U-1],t)[0],V[U++]=Q;else V[U++]=[W||t[0],X||t[1]];var r=V[U-1];W&&X&&(r[0]!==W||r[1]!==X)?(K&&(Z!==W&&J!==X?ct(Z&&J?(n=K,i=(a=t)[0]-n[0],o=(a[1]-n[1])/i,(n[1]*a[0]-a[1]*n[0])/i>0?[o>0?et:rt,at]:[o>0?rt:et,nt]):[Z||W,J||X]):Z&&J&&ct([Z,J])),ct([W,X])):Z-W&&J-X&&ct([W||Z,X||J]),K=t,Z=W,J=X}else K&&ut($(K,t)[0]),V[U++]=t;var n,a,i,o}for("linear"===D||"spline"===D?$=function(t,e){for(var r=[],n=0,a=0;a<4;a++){var i=it[a],o=c(t[0],t[1],e[0],e[1],i[0],i[1],i[2],i[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&Y(o,t)<Y(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:"hv"===D||"vh"===D?$=function(t,e){var r=[],n=ot(t),a=ot(e);return n&&a&&st(n,a)?r:(n&&r.push(n),a&&r.push(a),r)}:"hvh"===D?$=lt(0,et,rt):"vhv"===D&&($=lt(1,nt,at)),r=0;r<j;r++)if(n=q(r)){for(U=0,K=null,ht(n),r++;r<j;r++){if(!(f=q(r))){if(z)continue;break}if(R&&e.simplify){var ft=q(r+1);if(y=Y(f,n),F&&(0===U||U===j-1)||!(y<G(f,ft)*N)){for(v=[(f[0]-n[0])/y,(f[1]-n[1])/y],p=n,x=y,b=w=k=0,g=!1,i=f,r++;r<t.length;r++){if(d=ft,ft=q(r+1),!d){if(z)continue;break}if(T=(m=[d[0]-n[0],d[1]-n[1]])[0]*v[1]-m[1]*v[0],w=Math.min(w,T),(k=Math.max(k,T))-w>G(d,ft))break;i=d,(_=m[0]*v[0]+m[1]*v[1])>x?(x=_,f=d,g=!1):_<b&&(b=_,p=d,g=!0)}if(g?(ht(f),i!==p&&ht(p)):(p!==n&&ht(p),i!==f&&ht(f)),ht(i),r>=t.length||!d)break;ht(d),n=d}}else ht(f)}K&&ct([Z||K[0],J||K[1]]),B.push(V.slice(0,U))}return B}},{"../../constants/numerical":693,"../../lib":717,"./constants":1124}],1135:[function(t,e,r){"use strict";e.exports=function(t,e,r){"spline"===r("line.shape")&&r("line.smoothing")}},{}],1136:[function(t,e,r){"use strict";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var a,i,o,s,l,c={},u=!1,h=-1,f=0,p=-1;for(i=0;i<r.length;i++)(o=(a=r[i][0].trace).stackgroup||"")?o in c?l=c[o]:(l=c[o]=f,f++):a.fill in n&&p>=0?l=p:(l=p=f,f++),l<h&&(u=!0),a._groupIndex=h=l;var d=r.slice();u&&d.sort(function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index});var g={};for(i=0;i<d.length;i++)o=(a=d[i][0].trace).stackgroup||"",!0===a.visible?(a._nexttrace=null,a.fill in n&&(s=g[o],a._prevtrace=s||null,s&&(s._nexttrace=a)),a._ownfill=a.fill&&("tozero"===a.fill.substr(0,6)||"toself"===a.fill||"to"===a.fill.substr(0,2)&&!a._prevtrace),g[o]=a):a._prevtrace=a._nexttrace=a._ownfill=null;return d}},{}],1137:[function(t,e,r){"use strict";var n=t("fast-isnumeric");e.exports=function(t){var e=t.marker,r=e.sizeref||1,a=e.sizemin||0,i="area"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=i(t/2);return n(e)&&e>0?Math.max(e,a):0}}},{"fast-isnumeric":228}],1138:[function(t,e,r){"use strict";e.exports={container:"marker",min:"cmin",max:"cmax"}},{}],1139:[function(t,e,r){"use strict";var n=t("../../components/color"),a=t("../../components/colorscale/helpers").hasColorscale,i=t("../../components/colorscale/defaults"),o=t("./subtypes");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),h=(t.line||{}).color;(c=c||{},h&&(r=h),l("marker.symbol"),l("marker.opacity",u?.7:1),l("marker.size"),l("marker.color",r),a(t,"marker")&&i(t,e,s,l,{prefix:"marker.",cLetter:"c"}),c.noSelect||(l("selected.marker.color"),l("unselected.marker.color"),l("selected.marker.size"),l("unselected.marker.size")),c.noLine||(l("marker.line.color",h&&!Array.isArray(h)&&e.marker.color!==h?h:u?n.background:n.defaultLine),a(t,"marker.line")&&i(t,e,s,l,{prefix:"marker.line.",cLetter:"c"}),l("marker.line.width",u?1:0)),u&&(l("marker.sizeref"),l("marker.sizemin"),l("marker.sizemode")),c.gradient)&&("none"!==l("marker.gradient.type")&&l("marker.gradient.color"))}},{"../../components/color":591,"../../components/colorscale/defaults":601,"../../components/colorscale/helpers":602,"./subtypes":1144}],1140:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../lib"),o=i.ensureSingle,s=i.identity,l=t("../../components/drawing"),c=t("./subtypes"),u=t("./line_points"),h=t("./link_traces"),f=t("../../lib/polygon").tester;function p(t,e,r,h,p,d,g){var v;!function(t,e,r,a,o){var s=r.xaxis,l=r.yaxis,u=n.extent(i.simpleMap(s.range,s.r2c)),h=n.extent(i.simpleMap(l.range,l.r2c)),f=a[0].trace;if(!c.hasMarkers(f))return;var p=f.marker.maxdisplayed;if(0===p)return;var d=a.filter(function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=h[0]&&t.y<=h[1]}),g=Math.ceil(d.length/p),v=0;o.forEach(function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&v++});var m=Math.round(v*g/3+Math.floor(v/3)*g/7.1);a.forEach(function(t){delete t.vis}),d.forEach(function(t,e){0===Math.round((e+m)%g)&&(t.vis=!0)})}(0,e,r,h,p);var m=!!g&&g.duration>0;function y(t){return m?t.transition():t}var x=r.xaxis,b=r.yaxis,_=h[0].trace,w=_.line,k=n.select(d),T=o(k,"g","errorbars"),M=o(k,"g","lines"),A=o(k,"g","points"),S=o(k,"g","text");if(a.getComponentMethod("errorbars","plot")(t,T,r,g),!0===_.visible){var E,L;y(k).style("opacity",_.opacity);var C=_.fill.charAt(_.fill.length-1);"x"!==C&&"y"!==C&&(C=""),h[0][r.isRangePlot?"nodeRangePlot3":"node3"]=k;var P,O,z="",I=[],D=_._prevtrace;D&&(z=D._prevRevpath||"",L=D._nextFill,I=D._polygons);var R,F,B,N,j,V,U,q="",H="",G=[],Y=i.noop;if(E=_._ownFill,c.hasLines(_)||"none"!==_.fill){for(L&&L.datum(h),-1!==["hv","vh","hvh","vhv"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split("").reverse().join(""))):R=F="spline"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return"M"+t.join("L")},B=function(t){return F(t.reverse())},G=u(h,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify,fill:_.fill}),U=_._polygons=new Array(G.length),v=0;v<G.length;v++)_._polygons[v]=f(G[v]);G.length&&(N=G[0][0],V=(j=G[G.length-1])[j.length-1]),Y=function(t){return function(e){if(P=R(e),O=B(e),q?C?(q+="L"+P.substr(1),H=O+"L"+H.substr(1)):(q+="Z"+P,H=O+"Z"+H):(q=P,H=O),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(h),t)y(r.style("opacity",0).attr("d",P).call(l.lineGroupStyle)).style("opacity",1);else{var a=y(r);a.attr("d",P),l.singleLineStyle(h,a)}}}}}var W=M.selectAll(".js-line").data(G);y(W.exit()).style("opacity",0).remove(),W.each(Y(!1)),W.enter().append("path").classed("js-line",!0).style("vector-effect","non-scaling-stroke").call(l.lineGroupStyle).each(Y(!0)),l.setClipUrl(W,r.layerClipId,t),G.length?(E?(E.datum(h),N&&V&&(C?("y"===C?N[1]=V[1]=b.c2p(0,!0):"x"===C&&(N[0]=V[0]=x.c2p(0,!0)),y(E).attr("d","M"+V+"L"+N+"L"+q.substr(1)).call(l.singleFillStyle)):y(E).attr("d",q+"Z").call(l.singleFillStyle))):L&&("tonext"===_.fill.substr(0,6)&&q&&z?("tonext"===_.fill?y(L).attr("d",q+"Z"+z+"Z").call(l.singleFillStyle):y(L).attr("d",q+"L"+z.substr(1)+"Z").call(l.singleFillStyle),_._polygons=_._polygons.concat(I)):(Z(L),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=U):(E?Z(E):L&&Z(L),_._polygons=_._prevRevpath=_._prevPolygons=null),A.datum(h),S.datum(h),function(e,a,i){var o,u=i[0].trace,h=c.hasMarkers(u),f=c.hasText(u),p=tt(u),d=et,g=et;if(h||f){var v=s,_=u.stackgroup,w=_&&"infer zero"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?v=w?K:J:_&&!w&&(v=Q),h&&(d=v),f&&(g=v)}var k,T=(o=e.selectAll("path.point").data(d,p)).enter().append("path").classed("point",!0);m&&T.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style("opacity",0).transition().style("opacity",1),o.order(),h&&(k=l.makePointStyleFns(u)),o.each(function(e){var a=n.select(this),i=y(a);l.translatePoint(e,i,x,b)?(l.singlePointStyle(e,i,u,k,t),r.layerClipId&&l.hideOutsideRangePoint(e,i,x,b,u.xcalendar,u.ycalendar),u.customdata&&a.classed("plotly-customdata",null!==e.data&&void 0!==e.data)):i.remove()}),m?o.exit().transition().style("opacity",0).remove():o.exit().remove(),(o=a.selectAll("g").data(g,p)).enter().append("g").classed("textpoint",!0).append("text"),o.order(),o.each(function(t){var e=n.select(this),a=y(e.select("text"));l.translatePoint(t,a,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()}),o.selectAll("text").call(l.textPointStyle,u,t).each(function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll("tspan.line").each(function(){y(n.select(this)).attr({x:e,y:r})})}),o.exit().remove()}(A,S,h);var X=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(A,X,t),l.setClipUrl(S,X,t)}function Z(t){y(t).attr("d","M0,0Z")}function J(t){return t.filter(function(t){return!t.gap&&t.vis})}function K(t){return t.filter(function(t){return t.vis})}function Q(t){return t.filter(function(t){return!t.gap})}function $(t){return t.id}function tt(t){if(t.ids)return $}function et(){return!1}}e.exports=function(t,e,r,a,i,c){var u,f,d=!i,g=!!i&&i.duration>0,v=h(t,e,r);((u=a.selectAll("g.trace").data(v,function(t){return t[0].trace.uid})).enter().append("g").attr("class",function(t){return"trace scatter trace"+t[0].trace.uid}).style("stroke-miterlimit",2),u.order(),function(t,e,r){e.each(function(e){var a=o(n.select(this),"g","fills");l.setClipUrl(a,r.layerClipId,t);var i=e[0].trace,c=[];i._ownfill&&c.push("_ownFill"),i._nexttrace&&c.push("_nextFill");var u=a.selectAll("g").data(c,s);u.enter().append("g"),u.exit().each(function(t){i[t]=null}).remove(),u.order().each(function(t){i[t]=o(n.select(this),"path","js-fill")})})}(t,u,e),g)?(c&&(f=c()),n.transition().duration(i.duration).ease(i.easing).each("end",function(){f&&f()}).each("interrupt",function(){f&&f()}).each(function(){a.selectAll("g.trace").each(function(r,n){p(t,n,e,r,v,this,i)})})):u.each(function(r,n){p(t,n,e,r,v,this,i)});d&&u.exit().remove(),a.selectAll("path:not([d])").remove()}},{"../../components/drawing":612,"../../lib":717,"../../lib/polygon":729,"../../registry":846,"./line_points":1134,"./link_traces":1136,"./subtypes":1144,d3:165}],1141:[function(t,e,r){"use strict";var n=t("./subtypes");e.exports=function(t,e){var r,a,i,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],h=s[0].trace;if(!n.hasMarkers(h)&&!n.hasText(h))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)a=s[r],i=l.c2p(a.x),o=c.c2p(a.y),null!==a.i&&e.contains([i,o],!1,r,t)?(u.push({pointNumber:a.i,x:l.c2d(a.x),y:c.c2d(a.y)}),a.selected=1):a.selected=0;return u}},{"./subtypes":1144}],1142:[function(t,e,r){"use strict";var n=["orientation","groupnorm","stackgaps"];e.exports=function(t,e,r,a){var i=r._scatterStackOpts,o=a("stackgroup");if(o){var s=e.xaxis+e.yaxis,l=i[s];l||(l=i[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var h={orientation:e.x&&!e.y?"h":"v"},f=0;f<n.length;f++){var p=n[f],d=p+"Found";if(!c[d]){var g=void 0!==t[p],v="orientation"===p;if((g||u)&&(c[p]=a(p,h[p]),v&&(c.fillDflt="h"===c[p]?"tonextx":"tonexty"),g&&(c[d]=!0,!u&&(delete c.traces[0][p],v))))for(var m=0;m<c.traces.length-1;m++){var y=c.traces[m];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1143:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/drawing"),i=t("../../registry");function o(t,e,r){a.pointStyle(t.selectAll("path.point"),e,r)}function s(t,e,r){a.textPointStyle(t.selectAll("text"),e,r)}e.exports={style:function(t){var e=n.select(t).selectAll("g.trace.scatter");e.style("opacity",function(t){return t[0].trace.opacity}),e.selectAll("g.points").each(function(e){o(n.select(this),e.trace||e[0].trace,t)}),e.selectAll("g.text").each(function(e){s(n.select(this),e.trace||e[0].trace,t)}),e.selectAll("g.trace path.js-line").call(a.lineGroupStyle),e.selectAll("g.trace path.js-fill").call(a.fillGroupStyle),i.getComponentMethod("errorbars","style")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(a.selectedPointStyle(r.selectAll("path.point"),n),a.selectedTextStyle(r.selectAll("text"),n)):(o(r,n,t),s(r,n,t))}}},{"../../components/drawing":612,"../../registry":846,d3:165}],1144:[function(t,e,r){"use strict";var n=t("../../lib");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf("lines")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf("markers")||"splom"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf("text")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{"../../lib":717}],1145:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e,r,a,i){i=i||{},a("textposition"),n.coerceFont(a,"textfont",r.font),i.noSelect||(a("selected.textfont.color"),a("unselected.textfont.color"))}},{"../../lib":717}],1146:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../registry");e.exports=function(t,e,r,i){var o,s=i("x"),l=i("y");if(a.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x","y"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,i("y0"),i("dy"))}else{if(!l)return 0;o=n.minRowLength(l),i("x0"),i("dx")}return e._length=o,o}},{"../../lib":717,"../../registry":846}],1147:[function(t,e,r){"use strict";var n=t("../scatter/attributes"),a=t("../../components/colorscale/attributes"),i=t("../../plots/template_attributes").hovertemplateAttrs,o=t("../../plots/template_attributes").texttemplateAttrs,s=t("../../plots/attributes"),l=t("../../constants/gl3d_dashes"),c=t("../../constants/gl3d_markers"),u=t("../../lib/extend").extendFlat,h=t("../../plot_api/edit_types").overrideAll,f=n.line,p=n.marker,d=p.line,g=u({width:f.width,dash:{valType:"enumerated",values:Object.keys(l),dflt:"solid"}},a("line"));var v=e.exports=h({x:n.x,y:n.y,z:{valType:"data_array"},text:u({},n.text,{}),texttemplate:o({},{}),hovertext:u({},n.hovertext,{}),hovertemplate:i(),mode:u({},n.mode,{dflt:"lines+markers"}),surfaceaxis:{valType:"enumerated",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:"color"},projection:{x:{show:{valType:"boolean",dflt:!1},opacity:{valType:"number",min:0,max:1,dflt:1},scale:{valType:"number",min:0,max:10,dflt:2/3}},y:{show:{valType:"boolean",dflt:!1},opacity:{valType:"number",min:0,max:1,dflt:1},scale:{valType:"number",min:0,max:10,dflt:2/3}},z:{show:{valType:"boolean",dflt:!1},opacity:{valType:"number",min:0,max:1,dflt:1},scale:{valType:"number",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:g,marker:u({symbol:{valType:"enumerated",values:Object.keys(c),dflt:"circle",arrayOk:!0},size:u({},p.size,{dflt:8}),sizeref:p.sizeref,sizemin:p.sizemin,sizemode:p.sizemode,opacity:u({},p.opacity,{arrayOk:!1}),colorbar:p.colorbar,line:u({width:u({},d.width,{arrayOk:!1})},a("marker.line"))},a("marker")),textposition:u({},n.textposition,{dflt:"top center"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:u({},n.textfont.family,{arrayOk:!1})},hoverinfo:u({},s.hoverinfo)},"calc","nested");v.x.editType=v.y.editType=v.z.editType="calc+clearAxisTypes"},{"../../components/colorscale/attributes":598,"../../constants/gl3d_dashes":690,"../../constants/gl3d_markers":691,"../../lib/extend":708,"../../plot_api/edit_types":748,"../../plots/attributes":762,"../../plots/template_attributes":841,"../scatter/attributes":1120}],1148:[function(t,e,r){"use strict";var n=t("../scatter/arrays_to_calcdata"),a=t("../scatter/colorscale_calc");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),a(t,e),r}},{"../scatter/arrays_to_calcdata":1119,"../scatter/colorscale_calc":1123}],1149:[function(t,e,r){"use strict";var n=t("../../registry");function a(t,e,r,a){if(!e||!e.visible)return null;for(var i=n.getComponentMethod("errorbars","makeComputeError")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=i(+t[s],s);if("log"===a.type){var c=a.c2l(t[s]),u=t[s]-l[0],h=t[s]+l[1];if(o[s]=[(a.c2l(u,!0)-c)*r,(a.c2l(h,!0)-c)*r],u>0){var f=a.c2l(u);a._lowerLogErrorBound||(a._lowerLogErrorBound=f),a._lowerErrorBound=Math.min(a._lowerLogErrorBound,f)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[a(t.x,t.error_x,e[0],r.xaxis),a(t.y,t.error_y,e[1],r.yaxis),a(t.z,t.error_z,e[2],r.zaxis)],i=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===i)return null;for(var o=new Array(i),s=0;s<i;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{"../../registry":846}],1150:[function(t,e,r){"use strict";var n=t("gl-line3d"),a=t("gl-scatter3d"),i=t("gl-error3d"),o=t("gl-mesh3d"),s=t("delaunay-triangulate"),l=t("../../lib"),c=t("../../lib/str2rgbarray"),u=t("../../lib/gl_format_color").formatColor,h=t("../scatter/make_bubble_size_func"),f=t("../../constants/gl3d_dashes"),p=t("../../constants/gl3d_markers"),d=t("../../plots/cartesian/axes"),g=t("../../components/fx/helpers").appendArrayPointValue,v=t("./calc_errors");function m(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode="",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var y=m.prototype;function x(t){return null==t?0:t.indexOf("left")>-1?-1:t.indexOf("right")>-1?1:0}function b(t){return null==t?0:t.indexOf("top")>-1?-1:t.indexOf("bottom")>-1?1:0}function _(t,e){return e(4*t)}function w(t){return p[t]}function k(t,e,r,n,a){var i=null;if(l.isArrayOrTypedArray(t)){i=[];for(var o=0;o<e;o++)void 0===t[o]?i[o]=n:i[o]=r(t[o],a)}else i=r(t,l.identity);return i}function T(t,e){var r,n,a,i,o,s,f=[],p=t.fullSceneLayout,m=t.dataScale,y=p.xaxis,T=p.yaxis,M=p.zaxis,A=e.marker,S=e.line,E=e.x||[],L=e.y||[],C=e.z||[],P=E.length,O=e.xcalendar,z=e.ycalendar,I=e.zcalendar;for(o=0;o<P;o++)r=y.d2l(E[o],0,O)*m[0],n=T.d2l(L[o],0,z)*m[1],a=M.d2l(C[o],0,I)*m[2],f[o]=[r,n,a];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(P),o=0;o<P;o++)s[o]=e.text;function D(t,e){var r=p[t];return d.tickText(r,r.d2l(e),!0).text}var R=e.texttemplate;if(R){var F=t.fullLayout._d3locale,B=Array.isArray(R),N=B?Math.min(R.length,P):P,j=B?function(t){return R[t]}:function(){return R};for(s=new Array(N),o=0;o<N;o++){var V={x:E[o],y:L[o],z:C[o]},U={xLabel:D("xaxis",E[o]),yLabel:D("yaxis",L[o]),zLabel:D("zaxis",C[o])},q={};g(q,e,o);var H=e._meta||{};s[o]=l.texttemplateString(j(o),U,F,q,V,H)}}if(i={position:f,mode:e.mode,text:s},"line"in e&&(i.lineColor=u(S,1,P),i.lineWidth=S.width,i.lineDashes=S.dash),"marker"in e){var G=h(e);i.scatterColor=u(A,1,P),i.scatterSize=k(A.size,P,_,20,G),i.scatterMarker=k(A.symbol,P,w,"\u25cf"),i.scatterLineWidth=A.line.width,i.scatterLineColor=u(A.line,1,P),i.scatterAngle=0}"textposition"in e&&(i.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=x(t[r]),e[r][1]=b(t[r]));else e[0]=x(t),e[1]=b(t);return e}(e.textposition),i.textColor=u(e.textfont,1,P),i.textSize=k(e.textfont.size,P,l.identity,12),i.textFont=e.textfont.family,i.textAngle=0);var Y=["x","y","z"];for(i.project=[!1,!1,!1],i.projectScale=[1,1,1],i.projectOpacity=[1,1,1],o=0;o<3;++o){var W=e.projection[Y[o]];(i.project[o]=W.show)&&(i.projectOpacity[o]=W.opacity,i.projectScale[o]=W.scale)}i.errorBounds=v(e,m,p);var X=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],a=0;a<3;a++){var i=t[a];i&&!1!==i.copy_zstyle&&!1!==t[2].visible&&(i=t[2]),i&&i.visible&&(e[a]=i.width/2,r[a]=c(i.color),n[a]=i.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return i.errorColor=X.color,i.errorLineWidth=X.lineWidth,i.errorCapSize=X.capSize,i.delaunayAxis=e.surfaceaxis,i.delaunayColor=c(e.surfacecolor),i}function M(t){if(Array.isArray(t)){var e=t[0];return Array.isArray(e)&&(t=e),"rgb("+t.slice(0,3).map(function(t){return Math.round(255*t)})+")"}return null}y.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel="",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},y.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,h=f.solid;this.data=t;var p=T(this.scene,t);"mode"in p&&(this.mode=p.mode),"lineDashes"in p&&p.lineDashes in f&&(h=f[p.lineDashes]),this.color=M(p.scatterColor)||M(p.lineColor),this.dataPoints=p.position,e={gl:this.scene.glplot.gl,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:h[0],dashScale:h[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf("lines")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf("markers")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=a(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:this.scene.glplot.gl,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf("text")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=a(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:this.scene.glplot.gl,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=i(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var g=function(t,e,r){var n,a=(r+1)%3,i=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[a])&&isFinite(c[a])&&!isNaN(c[i])&&isFinite(c[i])&&(o.push([c[a],c[i]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var h=u[n],f=0;f<h.length;++f)h[f]=l[h[f]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);g.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(g):(g.gl=u,this.delaunayMesh=o(g),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},y.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new m(t,e.uid);return r.update(e),r}},{"../../components/fx/helpers":626,"../../constants/gl3d_dashes":690,"../../constants/gl3d_markers":691,"../../lib":717,"../../lib/gl_format_color":714,"../../lib/str2rgbarray":740,"../../plots/cartesian/axes":765,"../scatter/make_bubble_size_func":1137,"./calc_errors":1149,"delaunay-triangulate":167,"gl-error3d":250,"gl-line3d":258,"gl-mesh3d":283,"gl-scatter3d":300}],1151:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("../scatter/subtypes"),o=t("../scatter/marker_defaults"),s=t("../scatter/line_defaults"),l=t("../scatter/text_defaults"),c=t("./attributes");e.exports=function(t,e,r,u){function h(r,n){return a.coerce(t,e,c,r,n)}if(function(t,e,r,a){var i=0,o=r("x"),s=r("y"),l=r("z");n.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x","y","z"],a),o&&s&&l&&(i=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=i);return i}(t,e,h,u)){h("text"),h("hovertext"),h("hovertemplate"),h("mode"),i.hasLines(e)&&(h("connectgaps"),s(t,e,r,u,h)),i.hasMarkers(e)&&o(t,e,r,u,h,{noSelect:!0}),i.hasText(e)&&(h("texttemplate"),l(t,e,u,h,{noSelect:!0}));var f=(e.line||{}).color,p=(e.marker||{}).color;h("surfaceaxis")>=0&&h("surfacecolor",f||p);for(var d=["x","y","z"],g=0;g<3;++g){var v="projection."+d[g];h(v+".show")&&(h(v+".opacity"),h(v+".scale"))}var m=n.getComponentMethod("errorbars","supplyDefaults");m(t,e,f||p||r,{axis:"z"}),m(t,e,f||p||r,{axis:"y",inherit:"z"}),m(t,e,f||p||r,{axis:"x",inherit:"z"})}else e.visible=!1}},{"../../lib":717,"../../registry":846,"../scatter/line_defaults":1133,"../scatter/marker_defaults":1139,"../scatter/subtypes":1144,"../scatter/text_defaults":1145,"./attributes":1147}],1152:[function(t,e,r){"use strict";e.exports={plot:t("./convert"),attributes:t("./attributes"),markerSymbols:t("../../constants/gl3d_markers"),supplyDefaults:t("./defaults"),colorbar:[{container:"marker",min:"cmin",max:"cmax"},{container:"line",min:"cmin",max:"cmax"}],calc:t("./calc"),moduleType:"trace",name:"scatter3d",basePlotModule:t("../../plots/gl3d"),categories:["gl3d","symbols","showLegend","scatter-like"],meta:{}}},{"../../constants/gl3d_markers":691,"../../plots/gl3d":805,"./attributes":1147,"./calc":1148,"./convert":1150,"./defaults":1151}],1153:[function(t,e,r){"use strict";var n=t("../scatter/attributes"),a=t("../../plots/attributes"),i=t("../../plots/template_attributes").hovertemplateAttrs,o=t("../../plots/template_attributes").texttemplateAttrs,s=t("../../components/colorscale/attributes"),l=t("../../lib/extend").extendFlat,c=n.marker,u=n.line,h=c.line;e.exports={carpet:{valType:"string",editType:"calc"},a:{valType:"data_array",editType:"calc"},b:{valType:"data_array",editType:"calc"},mode:l({},n.mode,{dflt:"markers"}),text:l({},n.text,{}),texttemplate:o({editType:"plot"},{keys:["a","b","text"]}),hovertext:l({},n.hovertext,{}),line:{color:u.color,width:u.width,dash:u.dash,shape:l({},u.shape,{values:["linear","spline"]}),smoothing:u.smoothing,editType:"calc"},connectgaps:n.connectgaps,fill:l({},n.fill,{values:["none","toself","tonext"],dflt:"none"}),fillcolor:n.fillcolor,marker:l({symbol:c.symbol,opacity:c.opacity,maxdisplayed:c.maxdisplayed,size:c.size,sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,line:l({width:h.width,editType:"calc"},s("marker.line")),gradient:c.gradient,editType:"calc"},s("marker")),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:l({},a.hoverinfo,{flags:["a","b","text","name"]}),hoveron:n.hoveron,hovertemplate:i()}},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plots/attributes":762,"../../plots/template_attributes":841,"../scatter/attributes":1120}],1154:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../scatter/colorscale_calc"),i=t("../scatter/arrays_to_calcdata"),o=t("../scatter/calc_selection"),s=t("../scatter/calc").calcMarkerSize,l=t("../carpet/lookup_carpetid");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&"legendonly"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,h,f=e._length,p=new Array(f),d=!1;for(c=0;c<f;c++)if(u=e.a[c],h=e.b[c],n(u)&&n(h)){var g=r.ab2xy(+u,+h,!0),v=r.isVisible(+u,+h);v||(d=!0),p[c]={x:g[0],y:g[1],a:u,b:h,vis:v}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,f),a(t,e),i(p,e),o(p,e),p}}},{"../carpet/lookup_carpetid":916,"../scatter/arrays_to_calcdata":1119,"../scatter/calc":1121,"../scatter/calc_selection":1122,"../scatter/colorscale_calc":1123,"fast-isnumeric":228}],1155:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/constants"),i=t("../scatter/subtypes"),o=t("../scatter/marker_defaults"),s=t("../scatter/line_defaults"),l=t("../scatter/line_shape_defaults"),c=t("../scatter/text_defaults"),u=t("../scatter/fillcolor_defaults"),h=t("./attributes");e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,h,r,a)}p("carpet"),e.xaxis="x",e.yaxis="y";var d=p("a"),g=p("b"),v=Math.min(d.length,g.length);if(v){e._length=v,p("text"),p("texttemplate"),p("hovertext"),p("mode",v<a.PTS_LINESONLY?"lines+markers":"lines"),i.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p("connectgaps")),i.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),i.hasText(e)&&c(t,e,f,p);var m=[];(i.hasMarkers(e)||i.hasText(e))&&(p("marker.maxdisplayed"),m.push("points")),p("fill"),"none"!==e.fill&&(u(t,e,r,p),i.hasLines(e)||l(t,e,p)),"tonext"!==e.fill&&"toself"!==e.fill||m.push("fills"),"fills"!==p("hoveron",m.join("+")||"points")&&p("hovertemplate"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{"../../lib":717,"../scatter/constants":1124,"../scatter/fillcolor_defaults":1128,"../scatter/line_defaults":1133,"../scatter/line_shape_defaults":1135,"../scatter/marker_defaults":1139,"../scatter/subtypes":1144,"../scatter/text_defaults":1145,"./attributes":1153}],1156:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a){var i=n[a];return t.a=i.a,t.b=i.b,t.y=i.y,t}},{}],1157:[function(t,e,r){"use strict";e.exports=function(t,e){var r={},n=e._carpet,a=n.ab2ij([t.a,t.b]),i=Math.floor(a[0]),o=a[0]-i,s=Math.floor(a[1]),l=a[1]-s,c=n.evalxy([],i,s,o,l);return r.yLabel=c[1].toFixed(3),r}},{}],1158:[function(t,e,r){"use strict";var n=t("../scatter/hover"),a=t("../../lib").fillText;e.exports=function(t,e,r,i){var o=n(t,e,r,i);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,g=p._module.formatLabels(f,p);s.yLabel=g.yLabel,delete s.text;var v=[];if(!p.hovertemplate){var m=(f.hi||p.hoverinfo).split("+");-1!==m.indexOf("all")&&(m=["a","b","text"]),-1!==m.indexOf("a")&&y(d.aaxis,f.a),-1!==m.indexOf("b")&&y(d.baxis,f.b),v.push("y: "+s.yLabel),-1!==m.indexOf("text")&&a(f,p,v),s.extraText=v.join("<br>")}return o}function y(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,""):t._hovertitle,v.push(r+": "+e.toFixed(3)+t.labelsuffix)}}},{"../../lib":717,"../scatter/hover":1131}],1159:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../scatter/marker_colorbar"),formatLabels:t("./format_labels"),calc:t("./calc"),plot:t("./plot"),style:t("../scatter/style").style,styleOnSelect:t("../scatter/style").styleOnSelect,hoverPoints:t("./hover"),selectPoints:t("../scatter/select"),eventData:t("./event_data"),moduleType:"trace",name:"scattercarpet",basePlotModule:t("../../plots/cartesian"),categories:["svg","carpet","symbols","showLegend","carpetDependent","zoomScale"],meta:{}}},{"../../plots/cartesian":776,"../scatter/marker_colorbar":1138,"../scatter/select":1141,"../scatter/style":1143,"./attributes":1153,"./calc":1154,"./defaults":1155,"./event_data":1156,"./format_labels":1157,"./hover":1158,"./plot":1160}],1160:[function(t,e,r){"use strict";var n=t("../scatter/plot"),a=t("../../plots/cartesian/axes"),i=t("../../components/drawing");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,h={xaxis:a.getFromId(t,u.xaxis||"x"),yaxis:a.getFromId(t,u.yaxis||"y"),plot:e.plot};for(n(t,h,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll("g.trace"+l.uid+" .js-line"),i.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},{"../../components/drawing":612,"../../plots/cartesian/axes":765,"../scatter/plot":1140}],1161:[function(t,e,r){"use strict";var n=t("../../plots/template_attributes").hovertemplateAttrs,a=t("../../plots/template_attributes").texttemplateAttrs,i=t("../scatter/attributes"),o=t("../../plots/attributes"),s=t("../../components/colorscale/attributes"),l=t("../../components/drawing/attributes").dash,c=t("../../lib/extend").extendFlat,u=t("../../plot_api/edit_types").overrideAll,h=i.marker,f=i.line,p=h.line;e.exports=u({lon:{valType:"data_array"},lat:{valType:"data_array"},locations:{valType:"data_array"},locationmode:{valType:"enumerated",values:["ISO-3","USA-states","country names","geojson-id"],dflt:"ISO-3"},geojson:{valType:"any",editType:"calc"},featureidkey:{valType:"string",editType:"calc",dflt:"id"},mode:c({},i.mode,{dflt:"markers"}),text:c({},i.text,{}),texttemplate:a({editType:"plot"},{keys:["lat","lon","location","text"]}),hovertext:c({},i.hovertext,{}),textfont:i.textfont,textposition:i.textposition,line:{color:f.color,width:f.width,dash:l},connectgaps:i.connectgaps,marker:c({symbol:h.symbol,opacity:h.opacity,size:h.size,sizeref:h.sizeref,sizemin:h.sizemin,sizemode:h.sizemode,colorbar:h.colorbar,line:c({width:p.width},s("marker.line")),gradient:h.gradient},s("marker")),fill:{valType:"enumerated",values:["none","toself"],dflt:"none"},fillcolor:i.fillcolor,selected:i.selected,unselected:i.unselected,hoverinfo:c({},o.hoverinfo,{flags:["lon","lat","location","text","name"]}),hovertemplate:n()},"calc","nested")},{"../../components/colorscale/attributes":598,"../../components/drawing/attributes":611,"../../lib/extend":708,"../../plot_api/edit_types":748,"../../plots/attributes":762,"../../plots/template_attributes":841,"../scatter/attributes":1120}],1162:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../constants/numerical").BADNUM,i=t("../scatter/colorscale_calc"),o=t("../scatter/arrays_to_calcdata"),s=t("../scatter/calc_selection"),l=t("../../lib")._;function c(t){return t&&"string"==typeof t}e.exports=function(t,e){var r,u=Array.isArray(e.locations),h=u?e.locations.length:e._length,f=new Array(h);r=e.geojson?function(t){return c(t)||n(t)}:c;for(var p=0;p<h;p++){var d=f[p]={};if(u){var g=e.locations[p];d.loc=r(g)?g:null}else{var v=e.lon[p],m=e.lat[p];n(v)&&n(m)?d.lonlat=[+v,+m]:d.lonlat=[a,a]}}return o(f,e),i(t,e),s(f,e),h&&(f[0].t={labels:{lat:l(t,"lat:")+" ",lon:l(t,"lon:")+" "}}),f}},{"../../constants/numerical":693,"../../lib":717,"../scatter/arrays_to_calcdata":1119,"../scatter/calc_selection":1122,"../scatter/colorscale_calc":1123,"fast-isnumeric":228}],1163:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/subtypes"),i=t("../scatter/marker_defaults"),o=t("../scatter/line_defaults"),s=t("../scatter/text_defaults"),l=t("../scatter/fillcolor_defaults"),c=t("./attributes");e.exports=function(t,e,r,u){function h(r,a){return n.coerce(t,e,c,r,a)}var f,p=h("locations");if(p&&p.length){var d,g=h("geojson");("string"==typeof g&&""!==g||n.isPlainObject(g))&&(d="geojson-id"),"geojson-id"===h("locationmode",d)&&h("featureidkey"),f=p.length}else{var v=h("lon")||[],m=h("lat")||[];f=Math.min(v.length,m.length)}f?(e._length=f,h("text"),h("hovertext"),h("hovertemplate"),h("mode"),a.hasLines(e)&&(o(t,e,r,u,h),h("connectgaps")),a.hasMarkers(e)&&i(t,e,r,u,h,{gradient:!0}),a.hasText(e)&&(h("texttemplate"),s(t,e,u,h)),h("fill"),"none"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h)):e.visible=!1}},{"../../lib":717,"../scatter/fillcolor_defaults":1128,"../scatter/line_defaults":1133,"../scatter/marker_defaults":1139,"../scatter/subtypes":1144,"../scatter/text_defaults":1145,"./attributes":1161}],1164:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a){t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null;var i=n[a];return i.fIn&&i.fIn.properties&&(t.properties=i.fIn.properties),t}},{}],1165:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes");e.exports=function(t,e,r){var a={},i=r[e.geo]._subplot.mockAxis,o=t.lonlat;return a.lonLabel=n.tickText(i,i.c2l(o[0]),!0).text,a.latLabel=n.tickText(i,i.c2l(o[1]),!0).text,a}},{"../../plots/cartesian/axes":765}],1166:[function(t,e,r){"use strict";var n=t("../../components/fx"),a=t("../../constants/numerical").BADNUM,i=t("../scatter/get_trace_color"),o=t("../../lib").fillText,s=t("./attributes");e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,h=t.ya,f=t.subplot,p=f.projection.isLonLatOverEdges,d=f.project;if(n.getClosest(l,function(t){var n=t.lonlat;if(n[0]===a)return 1/0;if(p(n))return 1/0;var i=d(n),o=d([e,r]),s=Math.abs(i[0]-o[0]),l=Math.abs(i[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)},t),!1!==t.index){var g=l[t.index],v=g.lonlat,m=[u.c2p(v),h.c2p(v)],y=g.mrc||1;t.x0=m[0]-y,t.x1=m[0]+y,t.y0=m[1]-y,t.y1=m[1]+y,t.loc=g.loc,t.lon=v[0],t.lat=v[1];var x={};x[c.geo]={_subplot:f};var b=c._module.formatLabels(g,c,x);return t.lonLabel=b.lonLabel,t.latLabel=b.latLabel,t.color=i(c,g),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var a=e.hi||t.hoverinfo,i="all"===a?s.hoverinfo.flags:a.split("+"),l=-1!==i.indexOf("location")&&Array.isArray(t.locations),c=-1!==i.indexOf("lon"),u=-1!==i.indexOf("lat"),h=-1!==i.indexOf("text"),f=[];function p(t){return t+"\xb0"}l?f.push(e.loc):c&&u?f.push("("+p(r.lonLabel)+", "+p(r.latLabel)+")"):c?f.push(n.lon+p(r.lonLabel)):u&&f.push(n.lat+p(r.latLabel));h&&o(e,t,f);return f.join("<br>")}(c,g,t,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{"../../components/fx":630,"../../constants/numerical":693,"../../lib":717,"../scatter/get_trace_color":1130,"./attributes":1161}],1167:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../scatter/marker_colorbar"),formatLabels:t("./format_labels"),calc:t("./calc"),calcGeoJSON:t("./plot").calcGeoJSON,plot:t("./plot").plot,style:t("./style"),styleOnSelect:t("../scatter/style").styleOnSelect,hoverPoints:t("./hover"),eventData:t("./event_data"),selectPoints:t("./select"),moduleType:"trace",name:"scattergeo",basePlotModule:t("../../plots/geo"),categories:["geo","symbols","showLegend","scatter-like"],meta:{}}},{"../../plots/geo":795,"../scatter/marker_colorbar":1138,"../scatter/style":1143,"./attributes":1161,"./calc":1162,"./defaults":1163,"./event_data":1164,"./format_labels":1165,"./hover":1166,"./plot":1168,"./select":1169,"./style":1170}],1168:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../lib/topojson_utils").getTopojsonFeatures,o=t("../../lib/geojson_utils"),s=t("../../lib/geo_location_utils"),l=t("../../plots/cartesian/autorange").findExtremes,c=t("../../constants/numerical").BADNUM,u=t("../scatter/calc").calcMarkerSize,h=t("../scatter/subtypes"),f=t("./style");e.exports={calcGeoJSON:function(t,e){var r,n,a=t[0].trace,o=e[a.geo],h=o._subplot,f=a._length;if(Array.isArray(a.locations)){var p=a.locationmode,d="geojson-id"===p?s.extractTraceFeature(t):i(a,h.topojson);for(r=0;r<f;r++){n=t[r];var g="geojson-id"===p?n.fOut:s.locationToFeature(p,n.loc,d);n.lonlat=g?g.properties.ct:[c,c]}}var v,m,y={padded:!0};if("geojson"===o.fitbounds&&"geojson-id"===a.locationmode){var x=s.computeBbox(s.getTraceGeojson(a));v=[x[0],x[2]],m=[x[1],x[3]]}else{for(v=new Array(f),m=new Array(f),r=0;r<f;r++)n=t[r],v[r]=n.lonlat[0],m[r]=n.lonlat[1];y.ppad=u(a,f)}a._extremes.lon=l(o.lonaxis._ax,v,y),a._extremes.lat=l(o.lataxis._ax,m,y)},plot:function(t,e,r){var i=e.layers.frontplot.select(".scatterlayer"),s=a.makeTraceGroups(i,r,"trace scattergeo");function l(t,e){t.lonlat[0]===c&&n.select(e).remove()}s.selectAll("*").remove(),s.each(function(e){var r=n.select(this),i=e[0].trace;if(h.hasLines(i)||"none"!==i.fill){var s=o.calcTraceToLineCoords(e),c="none"!==i.fill?o.makePolygon(s):o.makeLine(s);r.selectAll("path.js-line").data([{geojson:c,trace:i}]).enter().append("path").classed("js-line",!0).style("stroke-miterlimit",2)}h.hasMarkers(i)&&r.selectAll("path.point").data(a.identity).enter().append("path").classed("point",!0).each(function(t){l(t,this)}),h.hasText(i)&&r.selectAll("g").data(a.identity).enter().append("g").append("text").each(function(t){l(t,this)}),f(t,e)})}}},{"../../constants/numerical":693,"../../lib":717,"../../lib/geo_location_utils":711,"../../lib/geojson_utils":712,"../../lib/topojson_utils":744,"../../plots/cartesian/autorange":764,"../scatter/calc":1121,"../scatter/subtypes":1144,"./style":1170,d3:165}],1169:[function(t,e,r){"use strict";var n=t("../scatter/subtypes"),a=t("../../constants/numerical").BADNUM;e.exports=function(t,e){var r,i,o,s,l,c=t.cd,u=t.xaxis,h=t.yaxis,f=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(i=(r=c[l]).lonlat)[0]!==a&&(o=u.c2p(i),s=h.c2p(i),e.contains([o,s],null,l,t)?(f.push({pointNumber:l,lon:i[0],lat:i[1]}),r.selected=1):r.selected=0);return f}},{"../../constants/numerical":693,"../scatter/subtypes":1144}],1170:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/drawing"),i=t("../../components/color"),o=t("../scatter/style"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style("opacity",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll("path.js-line").style("fill","none").each(function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(i.stroke,o.color).call(a.dashLine,o.dash||"",o.width||0),"none"!==r.fill&&e.call(i.fill,r.fillcolor)})}(t,e)}},{"../../components/color":591,"../../components/drawing":612,"../scatter/style":1143,d3:165}],1171:[function(t,e,r){"use strict";var n=t("../../plots/attributes"),a=t("../scatter/attributes"),i=t("../../components/colorscale/attributes"),o=t("../../lib/extend").extendFlat,s=t("../../plot_api/edit_types").overrideAll,l=t("./constants").DASHES,c=a.line,u=a.marker,h=u.line,f=e.exports=s({x:a.x,x0:a.x0,dx:a.dx,y:a.y,y0:a.y0,dy:a.dy,text:a.text,hovertext:a.hovertext,textposition:a.textposition,textfont:a.textfont,mode:{valType:"flaglist",flags:["lines","markers","text"],extras:["none"]},line:{color:c.color,width:c.width,shape:{valType:"enumerated",values:["linear","hv","vh","hvh","vhv"],dflt:"linear",editType:"plot"},dash:{valType:"enumerated",values:Object.keys(l),dflt:"solid"}},marker:o({},i("marker"),{symbol:u.symbol,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:o({},i("marker.line"),{width:h.width})}),connectgaps:a.connectgaps,fill:o({},a.fill,{dflt:"none"}),fillcolor:a.fillcolor,selected:{marker:a.selected.marker,textfont:a.selected.textfont},unselected:{marker:a.unselected.marker,textfont:a.unselected.textfont},opacity:n.opacity},"calc","nested");f.x.editType=f.y.editType=f.x0.editType=f.y0.editType="calc+clearAxisTypes",f.hovertemplate=a.hovertemplate,f.texttemplate=a.texttemplate},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plot_api/edit_types":748,"../../plots/attributes":762,"../scatter/attributes":1120,"./constants":1173}],1172:[function(t,e,r){"use strict";var n=t("point-cluster"),a=t("../../lib"),i=t("../../plots/cartesian/axis_ids"),o=t("../../plots/cartesian/autorange").findExtremes,s=t("../scatter/calc"),l=s.calcMarkerSize,c=s.calcAxisExpansion,u=s.setFirstScatter,h=t("../scatter/colorscale_calc"),f=t("./convert"),p=t("./scene_update"),d=t("../../constants/numerical").BADNUM,g=t("./constants").TOO_MANY_POINTS;function v(t,e,r){var n=t._extremes[e._id],a=o(e,r._bnds,{padded:!0});n.min=n.min.concat(a.min),n.max=n.max.concat(a.max)}e.exports=function(t,e){var r,o,s,m=t._fullLayout,y=i.getFromId(t,e.xaxis),x=i.getFromId(t,e.yaxis),b=m._plots[e.xaxis+e.yaxis],_=e._length,w=_>=g,k=2*_,T={},M=e._x=y.makeCalcdata(e,"x"),A=e._y=x.makeCalcdata(e,"y"),S=new Array(k);for(r=0;r<_;r++)o=M[r],s=A[r],S[2*r]=o===d?NaN:o,S[2*r+1]=s===d?NaN:s;if("log"===y.type)for(r=0;r<k;r+=2)S[r]=y.c2l(S[r]);if("log"===x.type)for(r=1;r<k;r+=2)S[r]=x.c2l(S[r]);if(w&&"log"!==y.type&&"log"!==x.type)T.tree=n(S);else{var E=T.ids=new Array(_);for(r=0;r<_;r++)E[r]=r}h(t,e);var L,C=function(t,e,r,n,i,o){var s=f.style(t,r);s.marker&&(s.marker.positions=n);s.line&&n.length>1&&a.extendFlat(s.line,f.linePositions(t,r,n));if(s.errorX||s.errorY){var l=f.errorBarPositions(t,r,n,i,o);s.errorX&&a.extendFlat(s.errorX,l.x),s.errorY&&a.extendFlat(s.errorY,l.y)}s.text&&(a.extendFlat(s.text,{positions:n},f.textPosition(t,r,s.text,s.marker)),a.extendFlat(s.textSel,{positions:n},f.textPosition(t,r,s.text,s.markerSel)),a.extendFlat(s.textUnsel,{positions:n},f.textPosition(t,r,s.text,s.markerUnsel)));return s}(t,0,e,S,M,A),P=p(t,b);return u(m,e),w?C.marker&&(L=2*(C.marker.sizeAvg||Math.max(C.marker.size,3))):L=l(e,_),c(t,e,y,x,M,A,L),C.errorX&&v(e,y,C.errorX),C.errorY&&v(e,x,C.errorY),C.fill&&!P.fill2d&&(P.fill2d=!0),C.marker&&!P.scatter2d&&(P.scatter2d=!0),C.line&&!P.line2d&&(P.line2d=!0),!C.errorX&&!C.errorY||P.error2d||(P.error2d=!0),C.text&&!P.glText&&(P.glText=!0),C.marker&&(C.marker.snap=_),P.lineOptions.push(C.line),P.errorXOptions.push(C.errorX),P.errorYOptions.push(C.errorY),P.fillOptions.push(C.fill),P.markerOptions.push(C.marker),P.markerSelectedOptions.push(C.markerSel),P.markerUnselectedOptions.push(C.markerUnsel),P.textOptions.push(C.text),P.textSelectedOptions.push(C.textSel),P.textUnselectedOptions.push(C.textUnsel),P.selectBatch.push([]),P.unselectBatch.push([]),T._scene=P,T.index=P.count,T.x=M,T.y=A,T.positions=S,P.count++,[{x:!1,y:!1,t:T,trace:e}]}},{"../../constants/numerical":693,"../../lib":717,"../../plots/cartesian/autorange":764,"../../plots/cartesian/axis_ids":768,"../scatter/calc":1121,"../scatter/colorscale_calc":1123,"./constants":1173,"./convert":1174,"./scene_update":1182,"point-cluster":470}],1173:[function(t,e,r){"use strict";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1174:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("svg-path-sdf"),i=t("color-normalize"),o=t("../../registry"),s=t("../../lib"),l=t("../../components/drawing"),c=t("../../plots/cartesian/axis_ids"),u=t("../../lib/gl_format_color").formatColor,h=t("../scatter/subtypes"),f=t("../scatter/make_bubble_size_func"),p=t("./helpers"),d=t("./constants"),g=t("../../constants/interactions").DESELECTDIM,v={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1},m=t("../../components/fx/helpers").appendArrayPointValue;function y(t,e){var r,a=t._fullLayout,i=e._length,o=e.textfont,l=e.textposition,c=Array.isArray(l)?l:[l],u=o.color,h=o.size,f=o.family,p={},d=e.texttemplate;if(d){p.text=[];var g=a._d3locale,v=Array.isArray(d),y=v?Math.min(d.length,i):i,x=v?function(t){return d[t]}:function(){return d};for(r=0;r<y;r++){var b={i:r},_=e._module.formatLabels(b,e,a),w={};m(w,e,r);var k=e._meta||{};p.text.push(s.texttemplateString(x(r),_,g,w,b,k))}}else Array.isArray(e.text)&&e.text.length<i?p.text=e.text.slice():p.text=e.text;if(Array.isArray(p.text))for(r=p.text.length;r<i;r++)p.text[r]="";for(p.opacity=e.opacity,p.font={},p.align=[],p.baseline=[],r=0;r<c.length;r++){var T=c[r].split(/\s+/);switch(T[1]){case"left":p.align.push("right");break;case"right":p.align.push("left");break;default:p.align.push(T[1])}switch(T[0]){case"top":p.baseline.push("bottom");break;case"bottom":p.baseline.push("top");break;default:p.baseline.push(T[0])}}if(Array.isArray(u))for(p.color=new Array(i),r=0;r<i;r++)p.color[r]=u[r];else p.color=u;if(s.isArrayOrTypedArray(h)||Array.isArray(f))for(p.font=new Array(i),r=0;r<i;r++){var M=p.font[r]={};M.size=s.isTypedArray(h)?h[r]:Array.isArray(h)?n(h[r])?h[r]:0:h,M.family=Array.isArray(f)?f[r]:f}else p.font={size:h,family:f};return p}function x(t){var e,r,n=t._length,a=t.marker,o={},l=s.isArrayOrTypedArray(a.symbol),c=s.isArrayOrTypedArray(a.color),h=s.isArrayOrTypedArray(a.line.color),d=s.isArrayOrTypedArray(a.opacity),g=s.isArrayOrTypedArray(a.size),v=s.isArrayOrTypedArray(a.line.width);if(l||(r=p.isOpenSymbol(a.symbol)),l||c||h||d){o.colors=new Array(n),o.borderColors=new Array(n);var m=u(a,a.opacity,n),y=u(a.line,a.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(m[0])){var b=m;for(m=Array(n),e=0;e<n;e++)m[e]=b}for(o.colors=m,o.borderColors=y,e=0;e<n;e++){if(l){var _=a.symbol[e];r=p.isOpenSymbol(_)}r&&(y[e]=m[e].slice(),m[e]=m[e].slice(),m[e][3]=0)}o.opacity=t.opacity}else r?(o.color=i(a.color,"uint8"),o.color[3]=0,o.borderColor=i(a.color,"uint8")):(o.color=i(a.color,"uint8"),o.borderColor=i(a.line.color,"uint8")),o.opacity=t.opacity*a.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=E(a.symbol[e]);else o.marker=E(a.symbol);var w,k=f(t);if(g||v){var T,M=o.sizes=new Array(n),A=o.borderSizes=new Array(n),S=0;if(g){for(e=0;e<n;e++)M[e]=k(a.size[e]),S+=M[e];T=S/n}else for(w=k(a.size),e=0;e<n;e++)M[e]=w;if(v)for(e=0;e<n;e++)A[e]=a.line.width[e]/2;else for(w=a.line.width/2,e=0;e<n;e++)A[e]=w;o.sizeAvg=T}else o.size=k(a&&a.size||10),o.borderSizes=k(a.line.width);return o}function b(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=x(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function _(t,e,r){var n={};if(!r)return n;if(r.textfont){var a={opacity:1,text:e.text,texttemplate:e.texttemplate,textposition:e.textposition,textfont:s.extendFlat({},e.textfont)};r.textfont&&s.extendFlat(a.textfont,r.textfont),n=y(t,a)}return n}function w(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var k=d.SYMBOL_SDF_SIZE,T=d.SYMBOL_SIZE,M=d.SYMBOL_STROKE,A={},S=l.symbolFuncs[0](.05*T);function E(t){if("circle"===t)return null;var e,r,n=l.symbolNumber(t),i=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.isDotSymbol(t);return A[t]?A[t]:(e=c&&!o?i(1.1*T)+S:i(T),r=a(e,{w:k,h:k,viewBox:[-T,-T,T,T],stroke:s?M:-M}),A[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(h.hasText(e)&&(n.text=y(t,e),n.textSel=_(t,e,e.selected),n.textUnsel=_(t,e,e.unselected)),h.hasMarkers(e)&&(n.marker=x(e),n.markerSel=b(e,e.selected),n.markerUnsel=b(e,e.unselected),!e.unselected&&s.isArrayOrTypedArray(e.marker.opacity))){var a=e.marker.opacity;for(n.markerUnsel.opacity=new Array(a.length),r=0;r<a.length;r++)n.markerUnsel.opacity[r]=g*a[r]}if(h.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var i=(d.DASHES[e.line.dash]||[1]).slice();for(r=0;r<i.length;++r)i[r]*=e.line.width;n.line.dashes=i}return e.error_x&&e.error_x.visible&&(n.errorX=w(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=w(e,e.error_y)),e.fill&&"none"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:x,markerSelection:b,linePositions:function(t,e,r){var n,a,i=r.length,o=i/2;if(h.hasLines(e)&&o)if("hv"===e.line.shape){for(n=[],a=0;a<o-1;a++)isNaN(r[2*a])||isNaN(r[2*a+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*a],r[2*a+1]),isNaN(r[2*a+2])||isNaN(r[2*a+3])?n.push(NaN,NaN):n.push(r[2*a+2],r[2*a+1]));n.push(r[i-2],r[i-1])}else if("hvh"===e.line.shape){for(n=[],a=0;a<o-1;a++)if(isNaN(r[2*a])||isNaN(r[2*a+1])||isNaN(r[2*a+2])||isNaN(r[2*a+3]))isNaN(r[2*a])||isNaN(r[2*a+1])?n.push(NaN,NaN):n.push(r[2*a],r[2*a+1]),n.push(NaN,NaN);else{var s=(r[2*a]+r[2*a+2])/2;n.push(r[2*a],r[2*a+1],s,r[2*a+1],s,r[2*a+3])}n.push(r[i-2],r[i-1])}else if("vhv"===e.line.shape){for(n=[],a=0;a<o-1;a++)if(isNaN(r[2*a])||isNaN(r[2*a+1])||isNaN(r[2*a+2])||isNaN(r[2*a+3]))isNaN(r[2*a])||isNaN(r[2*a+1])?n.push(NaN,NaN):n.push(r[2*a],r[2*a+1]),n.push(NaN,NaN);else{var l=(r[2*a+1]+r[2*a+3])/2;n.push(r[2*a],r[2*a+1],r[2*a],l,r[2*a+2],l)}n.push(r[i-2],r[i-1])}else if("vh"===e.line.shape){for(n=[],a=0;a<o-1;a++)isNaN(r[2*a])||isNaN(r[2*a+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*a],r[2*a+1]),isNaN(r[2*a+2])||isNaN(r[2*a+3])?n.push(NaN,NaN):n.push(r[2*a],r[2*a+3]));n.push(r[i-2],r[i-1])}else n=r;var c=!1;for(a=0;a<n.length;a++)if(isNaN(n[a])){c=!0;break}var u=c||n.length>d.TOO_MANY_POINTS?"rect":h.hasMarkers(e)?"rect":"round";if(c&&e.connectgaps){var f=n[0],p=n[1];for(a=0;a<n.length;a+=2)isNaN(n[a])||isNaN(n[a+1])?(n[a]=f,n[a+1]=p):(f=n[a],p=n[a+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,a,i){var s=o.getComponentMethod("errorbars","makeComputeError"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),h=r.length/2,f={};function p(t,a){var i=a._id.charAt(0),o=e["error_"+i];if(o&&o.visible&&("linear"===a.type||"log"===a.type)){for(var l=s(o),c={x:0,y:1}[i],u={x:[0,1,2,3],y:[2,3,0,1]}[i],p=new Float64Array(4*h),d=1/0,g=-1/0,v=0,m=0;v<h;v++,m+=4){var y=t[v];if(n(y)){var x=r[2*v+c],b=l(y,v),_=b[0],w=b[1];if(n(_)&&n(w)){var k=y-_,T=y+w;p[m+u[0]]=x-a.c2l(k),p[m+u[1]]=a.c2l(T)-x,p[m+u[2]]=0,p[m+u[3]]=0,d=Math.min(d,y-_),g=Math.max(g,y+w)}}}f[i]={positions:r,errors:p,_bnds:[d,g]}}}return p(a,l),p(i,u),f},textPosition:function(t,e,r,n){var a,i=e._length,o={};if(h.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(i),a=0;a<i;a++){var u=n.sizes?n.sizes[a]:n.size,f=Array.isArray(s)?s[a].size:s.size,p=Array.isArray(l)?l.length>1?l[a]:l[0]:l,d=Array.isArray(c)?c.length>1?c[a]:c[0]:c,g=v[p],m=v[d],y=u?u/.8+1:0,x=-m*y-.5*m;o.offset[a]=[g*y/f,x/f]}}return o}}},{"../../components/drawing":612,"../../components/fx/helpers":626,"../../constants/interactions":692,"../../lib":717,"../../lib/gl_format_color":714,"../../plots/cartesian/axis_ids":768,"../../registry":846,"../scatter/make_bubble_size_func":1137,"../scatter/subtypes":1144,"./constants":1173,"./helpers":1178,"color-normalize":122,"fast-isnumeric":228,"svg-path-sdf":533}],1175:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../registry"),i=t("./helpers"),o=t("./attributes"),s=t("../scatter/constants"),l=t("../scatter/subtypes"),c=t("../scatter/xy_defaults"),u=t("../scatter/marker_defaults"),h=t("../scatter/line_defaults"),f=t("../scatter/fillcolor_defaults"),p=t("../scatter/text_defaults");e.exports=function(t,e,r,d){function g(r,a){return n.coerce(t,e,o,r,a)}var v=!!t.marker&&i.isOpenSymbol(t.marker.symbol),m=l.isBubble(t),y=c(t,e,d,g);if(y){var x=y<s.PTS_LINESONLY?"lines+markers":"lines";g("text"),g("hovertext"),g("hovertemplate"),g("mode",x),l.hasLines(e)&&(g("connectgaps"),h(t,e,r,d,g),g("line.shape")),l.hasMarkers(e)&&(u(t,e,r,d,g),g("marker.line.width",v||m?1:0)),l.hasText(e)&&(g("texttemplate"),p(t,e,d,g));var b=(e.line||{}).color,_=(e.marker||{}).color;g("fill"),"none"!==e.fill&&f(t,e,r,g);var w=a.getComponentMethod("errorbars","supplyDefaults");w(t,e,b||_||r,{axis:"y"}),w(t,e,b||_||r,{axis:"x",inherit:"y"}),n.coerceSelectionMarkerOpacity(e,g)}else e.visible=!1}},{"../../lib":717,"../../registry":846,"../scatter/constants":1124,"../scatter/fillcolor_defaults":1128,"../scatter/line_defaults":1133,"../scatter/marker_defaults":1139,"../scatter/subtypes":1144,"../scatter/text_defaults":1145,"../scatter/xy_defaults":1146,"./attributes":1171,"./helpers":1178}],1176:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/color"),i=t("../../constants/interactions").DESELECTDIM;e.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,h=c.selectBatch[u],f=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},g=c.textUnselectedOptions[u]||{},v=n.extendFlat({},p);if(h.length||f.length){var m=d.color,y=g.color,x=p.color,b=Array.isArray(x);for(v.color=new Array(s._length),e=0;e<h.length;e++)r=h[e],v.color[r]=m||(b?x[r]:x);for(e=0;e<f.length;e++){r=f[e];var _=b?x[r]:x;v.color[r]=y||(m?_:a.addOpacity(_,i))}}c.glText[u].update(v)}}},{"../../components/color":591,"../../constants/interactions":692,"../../lib":717}],1177:[function(t,e,r){"use strict";var n=t("../scatter/format_labels");e.exports=function(t,e,r){var a=t.i;return"x"in t||(t.x=e._x[a]),"y"in t||(t.y=e._y[a]),n(t,e,r)}},{"../scatter/format_labels":1129}],1178:[function(t,e,r){"use strict";var n=t("./constants");r.isOpenSymbol=function(t){return"string"==typeof t?n.OPEN_RE.test(t):t%200>100},r.isDotSymbol=function(t){return"string"==typeof t?n.DOT_RE.test(t):t>200}},{"./constants":1173}],1179:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("../scatter/get_trace_color");function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,h=t.index,f={pointNumber:h,x:e[h],y:r[h]};f.tx=Array.isArray(o.text)?o.text[h]:o.text,f.htx=Array.isArray(o.hovertext)?o.hovertext[h]:o.hovertext,f.data=Array.isArray(o.customdata)?o.customdata[h]:o.customdata,f.tp=Array.isArray(o.textposition)?o.textposition[h]:o.textposition;var p=o.textfont;p&&(f.ts=a.isArrayOrTypedArray(p.size)?p.size[h]:p.size,f.tc=Array.isArray(p.color)?p.color[h]:p.color,f.tf=Array.isArray(p.family)?p.family[h]:p.family);var d=o.marker;d&&(f.ms=a.isArrayOrTypedArray(d.size)?d.size[h]:d.size,f.mo=a.isArrayOrTypedArray(d.opacity)?d.opacity[h]:d.opacity,f.mx=a.isArrayOrTypedArray(d.symbol)?d.symbol[h]:d.symbol,f.mc=a.isArrayOrTypedArray(d.color)?d.color[h]:d.color);var g=d&&d.line;g&&(f.mlc=Array.isArray(g.color)?g.color[h]:g.color,f.mlw=a.isArrayOrTypedArray(g.width)?g.width[h]:g.width);var v=d&&d.gradient;v&&"none"!==v.type&&(f.mgt=Array.isArray(v.type)?v.type[h]:v.type,f.mgc=Array.isArray(v.color)?v.color[h]:v.color);var m=s.c2p(f.x,!0),y=l.c2p(f.y,!0),x=f.mrc||1,b=o.hoverlabel;b&&(f.hbg=Array.isArray(b.bgcolor)?b.bgcolor[h]:b.bgcolor,f.hbc=Array.isArray(b.bordercolor)?b.bordercolor[h]:b.bordercolor,f.hts=a.isArrayOrTypedArray(b.font.size)?b.font.size[h]:b.font.size,f.htc=Array.isArray(b.font.color)?b.font.color[h]:b.font.color,f.htf=Array.isArray(b.font.family)?b.font.family[h]:b.font.family,f.hnl=a.isArrayOrTypedArray(b.namelength)?b.namelength[h]:b.namelength);var _=o.hoverinfo;_&&(f.hi=Array.isArray(_)?_[h]:_);var w=o.hovertemplate;w&&(f.ht=Array.isArray(w)?w[h]:w);var k={};k[t.index]=f;var T=a.extendFlat({},t,{color:i(o,f),x0:m-x,x1:m+x,xLabelVal:f.x,y0:y-x,y1:y+x,yLabelVal:f.y,cd:k,distance:c,spikeDistance:u,hovertemplate:f.ht});return f.htx?T.text=f.htx:f.tx?T.text=f.tx:o.text&&(T.text=o.text),a.fillText(f,o,T),n.getComponentMethod("errorbars","hoverInfo")(f,o,T),T}e.exports={hoverPoints:function(t,e,r,n){var a,i,s,l,c,u,h,f,p,d=t.cd,g=d[0].t,v=d[0].trace,m=t.xa,y=t.ya,x=g.x,b=g.y,_=m.c2p(e),w=y.c2p(r),k=t.distance;if(g.tree){var T=m.p2c(_-k),M=m.p2c(_+k),A=y.p2c(w-k),S=y.p2c(w+k);a="x"===n?g.tree.range(Math.min(T,M),Math.min(y._rl[0],y._rl[1]),Math.max(T,M),Math.max(y._rl[0],y._rl[1])):g.tree.range(Math.min(T,M),Math.min(A,S),Math.max(T,M),Math.max(A,S))}else a=g.ids;var E=k;if("x"===n)for(c=0;c<a.length;c++)s=x[a[c]],(u=Math.abs(m.c2p(s)-_))<E&&(E=u,h=y.c2p(b[a[c]])-w,p=Math.sqrt(u*u+h*h),i=a[c]);else for(c=a.length-1;c>-1;c--)s=x[a[c]],l=b[a[c]],u=m.c2p(s)-_,h=y.c2p(l)-w,(f=Math.sqrt(u*u+h*h))<E&&(E=p=f,i=a[c]);return t.index=i,t.distance=E,t.dxy=p,void 0===i?[t]:[o(t,x,b,v)]},calcHover:o}},{"../../lib":717,"../../registry":846,"../scatter/get_trace_color":1130}],1180:[function(t,e,r){"use strict";var n=t("./hover");e.exports={moduleType:"trace",name:"scattergl",basePlotModule:t("../../plots/cartesian"),categories:["gl","regl","cartesian","symbols","errorBarsOK","showLegend","scatter-like"],attributes:t("./attributes"),supplyDefaults:t("./defaults"),crossTraceDefaults:t("../scatter/cross_trace_defaults"),colorbar:t("../scatter/marker_colorbar"),formatLabels:t("./format_labels"),calc:t("./calc"),plot:t("./plot"),hoverPoints:n.hoverPoints,selectPoints:t("./select"),meta:{}}},{"../../plots/cartesian":776,"../scatter/cross_trace_defaults":1126,"../scatter/marker_colorbar":1138,"./attributes":1171,"./calc":1172,"./defaults":1175,"./format_labels":1177,"./hover":1179,"./plot":1181,"./select":1183}],1181:[function(t,e,r){"use strict";var n=t("regl-scatter2d"),a=t("regl-line2d"),i=t("regl-error2d"),o=t("gl-text"),s=t("../../lib"),l=t("../../lib/prepare_regl"),c=t("../scatter/subtypes"),u=t("../scatter/link_traces"),h=t("./edit_style").styleTextSelection;function f(t,e,r){var n=t._size,a=t.width,i=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,a-n.r-(1-e.domain[1])*n.w,i-n.t-(1-r.domain[1])*n.h]}e.exports=function(t,e,r){if(r.length){var p,d,g=t._fullLayout,v=e._scene,m=e.xaxis,y=e.yaxis;if(v)if(l(t,["ANGLE_instanced_arrays","OES_element_index_uint"])){var x=v.count,b=g._glcanvas.data()[0].regl;if(u(t,e,r),v.dirty){if(!0===v.error2d&&(v.error2d=i(b)),!0===v.line2d&&(v.line2d=a(b)),!0===v.scatter2d&&(v.scatter2d=n(b)),!0===v.fill2d&&(v.fill2d=a(b)),!0===v.glText)for(v.glText=new Array(x),p=0;p<x;p++)v.glText[p]=new o(b);if(v.glText){if(x>v.glText.length){var _=x-v.glText.length;for(p=0;p<_;p++)v.glText.push(new o(b))}else if(x<v.glText.length){var w=v.glText.length-x;v.glText.splice(x,w).forEach(function(t){t.destroy()})}for(p=0;p<x;p++)v.glText[p].update(v.textOptions[p])}if(v.line2d&&(v.line2d.update(v.lineOptions),v.lineOptions=v.lineOptions.map(function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t}),v.line2d.update(v.lineOptions)),v.error2d){var k=(v.errorXOptions||[]).concat(v.errorYOptions||[]);v.error2d.update(k)}v.scatter2d&&v.scatter2d.update(v.markerOptions),v.fillOrder=s.repeat(null,x),v.fill2d&&(v.fillOptions=v.fillOptions.map(function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var a,i,o=n[0],s=o.trace,l=o.t,c=v.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(v.fillOrder[e]=u);var h,f,p=[],d=c&&c.positions||l.positions;if("tozeroy"===s.fill){for(h=0;h<d.length&&isNaN(d[h+1]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f+1]);)f-=2;0!==d[h+1]&&(p=[d[h],0]),p=p.concat(d.slice(h,f+2)),0!==d[f+1]&&(p=p.concat([d[f],0]))}else if("tozerox"===s.fill){for(h=0;h<d.length&&isNaN(d[h]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f]);)f-=2;0!==d[h]&&(p=[0,d[h+1]]),p=p.concat(d.slice(h,f+2)),0!==d[f]&&(p=p.concat([0,d[f+1]]))}else if("toself"===s.fill||"tonext"===s.fill){for(p=[],a=0,i=0;i<d.length;i+=2)(isNaN(d[i])||isNaN(d[i+1]))&&((p=p.concat(d.slice(a,i))).push(d[a],d[a+1]),a=i+2);p=p.concat(d.slice(a)),a&&p.push(d[a],d[a+1])}else{var g=s._nexttrace;if(g){var m=v.lineOptions[e+1];if(m){var y=m.positions;if("tonexty"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||p.push(x,b)}t.fill=g.fillcolor}}}}if(s._prevtrace&&"tonext"===s._prevtrace.fill){var _=v.lineOptions[e-1].positions,w=p.length/2,k=[a=w];for(i=0;i<_.length;i+=2)(isNaN(_[i])||isNaN(_[i+1]))&&(k.push(i/2+w+1),a=i+2);p=p.concat(_),t.hole=k}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}}),v.fill2d.update(v.fillOptions))}var T=g.dragmode,M="lasso"===T||"select"===T,A=g.clickmode.indexOf("select")>-1;for(p=0;p<x;p++){var S=r[p][0],E=S.trace,L=S.t,C=L.index,P=E._length,O=L.x,z=L.y;if(E.selectedpoints||M||A){if(M||(M=!0),E.selectedpoints){var I=v.selectBatch[C]=s.selIndices2selPoints(E),D={};for(d=0;d<I.length;d++)D[I[d]]=1;var R=[];for(d=0;d<P;d++)D[d]||R.push(d);v.unselectBatch[C]=R}var F=L.xpx=new Array(P),B=L.ypx=new Array(P);for(d=0;d<P;d++)F[d]=m.c2p(O[d]),B[d]=y.c2p(z[d])}else L.xpx=L.ypx=null}if(M){if(v.select2d||(v.select2d=n(g._glcanvas.data()[1].regl)),v.scatter2d){var N=new Array(x);for(p=0;p<x;p++)N[p]=v.selectBatch[p].length||v.unselectBatch[p].length?v.markerUnselectedOptions[p]:{};v.scatter2d.update(N)}v.select2d&&(v.select2d.update(v.markerOptions),v.select2d.update(v.markerSelectedOptions)),v.glText&&r.forEach(function(t){var e=((t||[])[0]||{}).trace||{};c.hasText(e)&&h(t)})}else v.scatter2d&&v.scatter2d.update(v.markerOptions);var j={viewport:f(g,m,y),range:[(m._rl||m.range)[0],(y._rl||y.range)[0],(m._rl||m.range)[1],(y._rl||y.range)[1]]},V=s.repeat(j,v.count);v.fill2d&&v.fill2d.update(V),v.line2d&&v.line2d.update(V),v.error2d&&v.error2d.update(V.concat(V)),v.scatter2d&&v.scatter2d.update(V),v.select2d&&v.select2d.update(V),v.glText&&v.glText.forEach(function(t){t.update(j)})}else v.init()}}},{"../../lib":717,"../../lib/prepare_regl":730,"../scatter/link_traces":1136,"../scatter/subtypes":1144,"./edit_style":1176,"gl-text":319,"regl-error2d":491,"regl-line2d":492,"regl-scatter2d":498}],1182:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e){var r=e._scene,a={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},i={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,i,a)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var a=0;a<r.count;a++)r.glText[a].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,a=r.error2d,i=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,h=0;h<t;h++){if(e&&r.fillOrder[h]&&e.draw(r.fillOrder[h]),i&&r.lineOptions[h]&&i.draw(h),a&&(r.errorXOptions[h]&&a.draw(h),r.errorYOptions[h]&&a.draw(h+t)),o&&r.markerOptions[h])if(u[h].length){var f=n.repeat([],r.count);f[h]=u[h],o.draw(f)}else c[h].length||o.draw(h);s[h]&&r.textOptions[h]&&s[h].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach(function(t){t.destroy&&t.destroy()}),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,a),r}},{"../../lib":717}],1183:[function(t,e,r){"use strict";var n=t("../scatter/subtypes"),a=t("./edit_style").styleTextSelection;e.exports=function(t,e){var r=t.cd,i=[],o=r[0].trace,s=r[0].t,l=o._length,c=s.x,u=s.y,h=s._scene,f=s.index;if(!h)return i;var p=n.hasText(o),d=n.hasMarkers(o),g=!d&&!p;if(!0!==o.visible||g)return i;var v=[],m=[];if(!1!==e&&!e.degenerate)for(var y=0;y<l;y++)e.contains([s.xpx[y],s.ypx[y]],!1,y,t)?(v.push(y),i.push({pointNumber:y,x:c[y],y:u[y]})):m.push(y);if(d){var x=h.scatter2d;if(v.length||m.length){if(!h.selectBatch[f].length&&!h.unselectBatch[f].length){var b=new Array(h.count);b[f]=h.markerUnselectedOptions[f],x.update.apply(x,b)}}else{var _=new Array(h.count);_[f]=h.markerOptions[f],x.update.apply(x,_)}}return h.selectBatch[f]=v,h.unselectBatch[f]=m,p&&a(r),i}},{"../scatter/subtypes":1144,"./edit_style":1176}],1184:[function(t,e,r){"use strict";var n=t("../../plots/template_attributes").hovertemplateAttrs,a=t("../../plots/template_attributes").texttemplateAttrs,i=t("../scattergeo/attributes"),o=t("../scatter/attributes"),s=t("../../plots/mapbox/layout_attributes"),l=t("../../plots/attributes"),c=t("../../components/colorscale/attributes"),u=t("../../lib/extend").extendFlat,h=t("../../plot_api/edit_types").overrideAll,f=i.line,p=i.marker;e.exports=h({lon:i.lon,lat:i.lat,mode:u({},o.mode,{dflt:"markers"}),text:u({},o.text,{}),texttemplate:a({editType:"plot"},{keys:["lat","lon","text"]}),hovertext:u({},o.hovertext,{}),line:{color:f.color,width:f.width},connectgaps:o.connectgaps,marker:u({symbol:{valType:"string",dflt:"circle",arrayOk:!0},opacity:p.opacity,size:p.size,sizeref:p.sizeref,sizemin:p.sizemin,sizemode:p.sizemode},c("marker")),fill:i.fill,fillcolor:o.fillcolor,textfont:s.layers.symbol.textfont,textposition:s.layers.symbol.textposition,below:{valType:"string"},selected:{marker:o.selected.marker},unselected:{marker:o.unselected.marker},hoverinfo:u({},l.hoverinfo,{flags:["lon","lat","text","name"]}),hovertemplate:n()},"calc","nested")},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plot_api/edit_types":748,"../../plots/attributes":762,"../../plots/mapbox/layout_attributes":822,"../../plots/template_attributes":841,"../scatter/attributes":1120,"../scattergeo/attributes":1161}],1185:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../constants/numerical").BADNUM,o=t("../../lib/geojson_utils"),s=t("../../components/colorscale"),l=t("../../components/drawing"),c=t("../scatter/make_bubble_size_func"),u=t("../scatter/subtypes"),h=t("../../plots/mapbox/convert_text_opts"),f=t("../../components/fx/helpers").appendArrayPointValue,p=t("../../lib/svg_text_utils").NEWLINES,d=t("../../lib/svg_text_utils").BR_TAG_ALL;function g(){return{geojson:o.makeBlank(),layout:{visibility:"none"},paint:{}}}function v(t){return a.isArrayOrTypedArray(t)?function(t){return t}:t?function(){return t}:m}function m(){return""}function y(t){return t[0]===i}e.exports=function(t,e){var r,i=e[0].trace,x=!0===i.visible&&0!==i._length,b="none"!==i.fill,_=u.hasLines(i),w=u.hasMarkers(i),k=u.hasText(i),T=w&&"circle"===i.marker.symbol,M=w&&"circle"!==i.marker.symbol,A=g(),S=g(),E=g(),L=g(),C={fill:A,line:S,circle:E,symbol:L};if(!x)return C;if((b||_)&&(r=o.calcTraceToLineCoords(e)),b&&(A.geojson=o.makePolygon(r),A.layout.visibility="visible",a.extendFlat(A.paint,{"fill-color":i.fillcolor})),_&&(S.geojson=o.makeLine(r),S.layout.visibility="visible",a.extendFlat(S.paint,{"line-width":i.line.width,"line-color":i.line.color,"line-opacity":i.opacity})),T){var P=function(t){var e,r,i,o,u=t[0].trace,h=u.marker,f=u.selectedpoints,p=a.isArrayOrTypedArray(h.color),d=a.isArrayOrTypedArray(h.size),g=a.isArrayOrTypedArray(h.opacity);function v(t){return u.opacity*t}p&&(r=s.hasColorscale(u,"marker")?s.makeColorScaleFuncFromTrace(h):a.identity);d&&(i=c(u));g&&(o=function(t){var e=n(t)?+a.constrain(t,0,1):0;return v(e)});var m,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!y(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),i&&(w.mrc=b.mrc=i(b.ms)),o&&(w.mo=o(b.mo)),f&&(w.selected=b.selected||0),x.push({type:"Feature",geometry:{type:"Point",coordinates:_},properties:w})}}if(f)for(m=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var k=x[e].properties;m.selectedOpacityFn&&(k.mo=v(m.selectedOpacityFn(k))),m.selectedColorFn&&(k.mcc=m.selectedColorFn(k)),m.selectedSizeFn&&(k.mrc=m.selectedSizeFn(k))}return{geojson:{type:"FeatureCollection",features:x},mcc:p||m&&m.selectedColorFn?{type:"identity",property:"mcc"}:h.color,mrc:d||m&&m.selectedSizeFn?{type:"identity",property:"mrc"}:(T=h.size,T/2),mo:g||m&&m.selectedOpacityFn?{type:"identity",property:"mo"}:v(h.opacity)};var T}(e);E.geojson=P.geojson,E.layout.visibility="visible",a.extendFlat(E.paint,{"circle-color":P.mcc,"circle-radius":P.mrc,"circle-opacity":P.mo})}if((M||k)&&(L.geojson=function(t,e){for(var r=e._fullLayout,n=t[0].trace,i=(n.marker||{}).symbol,o="circle"!==i?v(i):m,s=u.hasText(n)?v(n.text):m,l=[],c=0;c<t.length;c++){var h=t[c];if(!y(h.lonlat)){var g,x=n.texttemplate;if(x){var b=Array.isArray(x)?x[c]||"":x,_=n._module.formatLabels(h,n,r),w={};f(w,n,h.i);var k=n._meta||{};g=a.texttemplateString(b,_,r._d3locale,w,h,k)}else g=s(h.tx);g&&(g=g.replace(p,"").replace(d,"\n")),l.push({type:"Feature",geometry:{type:"Point",coordinates:h.lonlat},properties:{symbol:o(h.mx),text:g}})}}return{type:"FeatureCollection",features:l}}(e,t),a.extendFlat(L.layout,{visibility:"visible","icon-image":"{symbol}-15","text-field":"{text}"}),M&&(a.extendFlat(L.layout,{"icon-size":i.marker.size/10}),a.extendFlat(L.paint,{"icon-opacity":i.opacity*i.marker.opacity,"icon-color":i.marker.color})),k)){var O=(i.marker||{}).size,z=h(i.textposition,O);a.extendFlat(L.layout,{"text-size":i.textfont.size,"text-anchor":z.anchor,"text-offset":z.offset}),a.extendFlat(L.paint,{"text-color":i.textfont.color,"text-opacity":i.opacity})}return C}},{"../../components/colorscale":603,"../../components/drawing":612,"../../components/fx/helpers":626,"../../constants/numerical":693,"../../lib":717,"../../lib/geojson_utils":712,"../../lib/svg_text_utils":741,"../../plots/mapbox/convert_text_opts":819,"../scatter/make_bubble_size_func":1137,"../scatter/subtypes":1144,"fast-isnumeric":228}],1186:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/subtypes"),i=t("../scatter/marker_defaults"),o=t("../scatter/line_defaults"),s=t("../scatter/text_defaults"),l=t("../scatter/fillcolor_defaults"),c=t("./attributes");e.exports=function(t,e,r,u){function h(r,a){return n.coerce(t,e,c,r,a)}if(function(t,e,r){var n=r("lon")||[],a=r("lat")||[],i=Math.min(n.length,a.length);return e._length=i,i}(0,e,h)){if(h("text"),h("texttemplate"),h("hovertext"),h("hovertemplate"),h("mode"),h("below"),a.hasLines(e)&&(o(t,e,r,u,h,{noDash:!0}),h("connectgaps")),a.hasMarkers(e)){i(t,e,r,u,h,{noLine:!0});var f=e.marker;"circle"!==f.symbol&&(n.isArrayOrTypedArray(f.size)&&(f.size=f.size[0]),n.isArrayOrTypedArray(f.color)&&(f.color=f.color[0]))}a.hasText(e)&&s(t,e,u,h,{noSelect:!0}),h("fill"),"none"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{"../../lib":717,"../scatter/fillcolor_defaults":1128,"../scatter/line_defaults":1133,"../scatter/marker_defaults":1139,"../scatter/subtypes":1144,"../scatter/text_defaults":1145,"./attributes":1184}],1187:[function(t,e,r){"use strict";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1188:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes");e.exports=function(t,e,r){var a={},i=r[e.subplot]._subplot.mockAxis,o=t.lonlat;return a.lonLabel=n.tickText(i,i.c2l(o[0]),!0).text,a.latLabel=n.tickText(i,i.c2l(o[1]),!0).text,a}},{"../../plots/cartesian/axes":765}],1189:[function(t,e,r){"use strict";var n=t("../../components/fx"),a=t("../../lib"),i=t("../scatter/get_trace_color"),o=a.fillText,s=t("../../constants/numerical").BADNUM;e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,h=t.ya,f=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(l,function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=a.modHalf(e[0],360),i=e[1],o=f.project([n,i]),l=o.x-u.c2p([d,i]),c=o.y-h.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)},t),!1!==t.index){var g=l[t.index],v=g.lonlat,m=[a.modHalf(v[0],360)+p,v[1]],y=u.c2p(m),x=h.c2p(m),b=g.mrc||1;t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b;var _={};_[c.subplot]={_subplot:f};var w=c._module.formatLabels(g,c,_);return t.lonLabel=w.lonLabel,t.latLabel=w.latLabel,t.color=i(c,g),t.extraText=function(t,e,r){if(t.hovertemplate)return;var n=(e.hi||t.hoverinfo).split("+"),a=-1!==n.indexOf("all"),i=-1!==n.indexOf("lon"),s=-1!==n.indexOf("lat"),l=e.lonlat,c=[];function u(t){return t+"\xb0"}a||i&&s?c.push("("+u(l[0])+", "+u(l[1])+")"):i?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(a||-1!==n.indexOf("text"))&&o(e,t,c);return c.join("<br>")}(c,g,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{"../../components/fx":630,"../../constants/numerical":693,"../../lib":717,"../scatter/get_trace_color":1130}],1190:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../scatter/marker_colorbar"),formatLabels:t("./format_labels"),calc:t("../scattergeo/calc"),plot:t("./plot"),hoverPoints:t("./hover"),eventData:t("./event_data"),selectPoints:t("./select"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:"trace",name:"scattermapbox",basePlotModule:t("../../plots/mapbox"),categories:["mapbox","gl","symbols","showLegend","scatter-like"],meta:{}}},{"../../plots/mapbox":820,"../scatter/marker_colorbar":1138,"../scattergeo/calc":1162,"./attributes":1184,"./defaults":1186,"./event_data":1187,"./format_labels":1188,"./hover":1189,"./plot":1191,"./select":1192}],1191:[function(t,e,r){"use strict";var n=t("./convert"),a=t("../../plots/mapbox/constants").traceLayerPrefix,i=["fill","line","circle","symbol"];function o(t,e){this.type="scattermapbox",this.subplot=t,this.uid=e,this.sourceIds={fill:"source-"+e+"-fill",line:"source-"+e+"-line",circle:"source-"+e+"-circle",symbol:"source-"+e+"-symbol"},this.layerIds={fill:a+e+"-fill",line:a+e+"-line",circle:a+e+"-circle",symbol:a+e+"-symbol"},this.below=null}var s=o.prototype;s.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:"geojson",data:e.geojson})},s.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},s.addLayer=function(t,e,r){this.subplot.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint},r)},s.update=function(t){var e,r,a,o=this.subplot,s=o.map,l=n(o.gd,t),c=o.belowLookup["trace-"+this.uid];if(c!==this.below){for(e=i.length-1;e>=0;e--)r=i[e],s.removeLayer(this.layerIds[r]);for(e=0;e<i.length;e++)a=l[r=i[e]],this.addLayer(r,a,c);this.below=c}for(e=0;e<i.length;e++)a=l[r=i[e]],o.setOptions(this.layerIds[r],"setLayoutProperty",a.layout),"visible"===a.layout.visibility&&(this.setSourceData(r,a),o.setOptions(this.layerIds[r],"setPaintProperty",a.paint));t[0].trace._glTrace=this},s.dispose=function(){for(var t=this.subplot.map,e=i.length-1;e>=0;e--){var r=i[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=e[0].trace,a=new o(t,r.uid),s=n(t.gd,e),l=a.below=t.belowLookup["trace-"+r.uid],c=0;c<i.length;c++){var u=i[c],h=s[u];a.addSource(u,h),a.addLayer(u,h,l)}return e[0].trace._glTrace=a,a}},{"../../plots/mapbox/constants":818,"./convert":1185}],1192:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/subtypes"),i=t("../../constants/numerical").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!a.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var h=o[r],f=h.lonlat;if(f[0]!==i){var p=[n.modHalf(f[0],360),f[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:f[0],lat:f[1]}),h.selected=1):h.selected=0}}return c}},{"../../constants/numerical":693,"../../lib":717,"../scatter/subtypes":1144}],1193:[function(t,e,r){"use strict";var n=t("../../plots/template_attributes").hovertemplateAttrs,a=t("../../plots/template_attributes").texttemplateAttrs,i=t("../../lib/extend").extendFlat,o=t("../scatter/attributes"),s=t("../../plots/attributes"),l=o.line;e.exports={mode:o.mode,r:{valType:"data_array",editType:"calc+clearAxisTypes"},theta:{valType:"data_array",editType:"calc+clearAxisTypes"},r0:{valType:"any",dflt:0,editType:"calc+clearAxisTypes"},dr:{valType:"number",dflt:1,editType:"calc"},theta0:{valType:"any",dflt:0,editType:"calc+clearAxisTypes"},dtheta:{valType:"number",editType:"calc"},thetaunit:{valType:"enumerated",values:["radians","degrees","gradians"],dflt:"degrees",editType:"calc+clearAxisTypes"},text:o.text,texttemplate:a({editType:"plot"},{keys:["r","theta","text"]}),hovertext:o.hovertext,line:{color:l.color,width:l.width,dash:l.dash,shape:i({},l.shape,{values:["linear","spline"]}),smoothing:l.smoothing,editType:"calc"},connectgaps:o.connectgaps,marker:o.marker,cliponaxis:i({},o.cliponaxis,{dflt:!1}),textposition:o.textposition,textfont:o.textfont,fill:i({},o.fill,{values:["none","toself","tonext"],dflt:"none"}),fillcolor:o.fillcolor,hoverinfo:i({},s.hoverinfo,{flags:["r","theta","text","name"]}),hoveron:o.hoveron,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{"../../lib/extend":708,"../../plots/attributes":762,"../../plots/template_attributes":841,"../scatter/attributes":1120}],1194:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../constants/numerical").BADNUM,i=t("../../plots/cartesian/axes"),o=t("../scatter/colorscale_calc"),s=t("../scatter/arrays_to_calcdata"),l=t("../scatter/calc_selection"),c=t("../scatter/calc").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,h=r[u].radialaxis,f=r[u].angularaxis,p=h.makeCalcdata(e,"r"),d=f.makeCalcdata(e,"theta"),g=e._length,v=new Array(g),m=0;m<g;m++){var y=p[m],x=d[m],b=v[m]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=a}var _=c(e,g);return e._extremes.x=i.findExtremes(h,p,{ppad:_}),o(t,e),s(v,e),l(v,e),v}},{"../../constants/numerical":693,"../../plots/cartesian/axes":765,"../scatter/arrays_to_calcdata":1119,"../scatter/calc":1121,"../scatter/calc_selection":1122,"../scatter/colorscale_calc":1123,"fast-isnumeric":228}],1195:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/subtypes"),i=t("../scatter/marker_defaults"),o=t("../scatter/line_defaults"),s=t("../scatter/line_shape_defaults"),l=t("../scatter/text_defaults"),c=t("../scatter/fillcolor_defaults"),u=t("../scatter/constants").PTS_LINESONLY,h=t("./attributes");function f(t,e,r,n){var a,i=n("r"),o=n("theta");if(i)o?a=Math.min(i.length,o.length):(a=i.length,n("theta0"),n("dtheta"));else{if(!o)return 0;a=e.theta.length,n("r0"),n("dr")}return e._length=a,a}e.exports={handleRThetaDefaults:f,supplyDefaults:function(t,e,r,p){function d(r,a){return n.coerce(t,e,h,r,a)}var g=f(0,e,0,d);if(g){d("thetaunit"),d("mode",g<u?"lines+markers":"lines"),d("text"),d("hovertext"),"fills"!==e.hoveron&&d("hovertemplate"),a.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d("connectgaps")),a.hasMarkers(e)&&i(t,e,r,p,d,{gradient:!0}),a.hasText(e)&&(d("texttemplate"),l(t,e,p,d));var v=[];(a.hasMarkers(e)||a.hasText(e))&&(d("cliponaxis"),d("marker.maxdisplayed"),v.push("points")),d("fill"),"none"!==e.fill&&(c(t,e,r,d),a.hasLines(e)||s(t,e,d)),"tonext"!==e.fill&&"toself"!==e.fill||v.push("fills"),d("hoveron",v.join("+")||"points"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{"../../lib":717,"../scatter/constants":1124,"../scatter/fillcolor_defaults":1128,"../scatter/line_defaults":1133,"../scatter/line_shape_defaults":1135,"../scatter/marker_defaults":1139,"../scatter/subtypes":1144,"../scatter/text_defaults":1145,"./attributes":1193}],1196:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes");e.exports=function(t,e,r){var i,o,s={},l=r[e.subplot]._subplot;l?(i=l.radialAxis,o=l.angularAxis):(i=(l=r[e.subplot]).radialaxis,o=l.angularaxis);var c=i.c2l(t.r);s.rLabel=a.tickText(i,c,!0).text;var u="degrees"===o.thetaunit?n.rad2deg(t.theta):t.theta;return s.thetaLabel=a.tickText(o,u,!0).text,s}},{"../../lib":717,"../../plots/cartesian/axes":765}],1197:[function(t,e,r){"use strict";var n=t("../scatter/hover");function a(t,e,r,n){var a=r.radialAxis,i=r.angularAxis;a._hovertitle="r",i._hovertitle="\u03b8";var o={};o[e.subplot]={_subplot:r};var s=e._module.formatLabels(t,e,o);n.rLabel=s.rLabel,n.thetaLabel=s.thetaLabel;var l=t.hi||e.hoverinfo,c=[];function u(t,e){c.push(t._hovertitle+": "+e)}if(!e.hovertemplate){var h=l.split("+");-1!==h.indexOf("all")&&(h=["r","theta","text"]),-1!==h.indexOf("r")&&u(a,n.rLabel),-1!==h.indexOf("theta")&&u(i,n.thetaLabel),-1!==h.indexOf("text")&&n.text&&(c.push(n.text),delete n.text),n.extraText=c.join("<br>")}}e.exports={hoverPoints:function(t,e,r,i){var o=n(t,e,r,i);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index)return o;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,a(c,u,l,s),s.hovertemplate=u.hovertemplate,o}},makeHoverPointText:a}},{"../scatter/hover":1131}],1198:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"scatterpolar",basePlotModule:t("../../plots/polar"),categories:["polar","symbols","showLegend","scatter-like"],attributes:t("./attributes"),supplyDefaults:t("./defaults").supplyDefaults,colorbar:t("../scatter/marker_colorbar"),formatLabels:t("./format_labels"),calc:t("./calc"),plot:t("./plot"),style:t("../scatter/style").style,styleOnSelect:t("../scatter/style").styleOnSelect,hoverPoints:t("./hover").hoverPoints,selectPoints:t("../scatter/select"),meta:{}}},{"../../plots/polar":829,"../scatter/marker_colorbar":1138,"../scatter/select":1141,"../scatter/style":1143,"./attributes":1193,"./calc":1194,"./defaults":1195,"./format_labels":1196,"./hover":1197,"./plot":1199}],1199:[function(t,e,r){"use strict";var n=t("../scatter/plot"),a=t("../../constants/numerical").BADNUM;e.exports=function(t,e,r){for(var i=e.layers.frontplot.select("g.scatterlayer"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],h=0;h<u.length;h++){var f=u[h],p=f.r;if(p===a)f.x=f.y=a;else{var d=s.c2g(p),g=l.c2g(f.theta);f.x=d*Math.cos(g),f.y=d*Math.sin(g)}}n(t,o,r,i)}},{"../../constants/numerical":693,"../scatter/plot":1140}],1200:[function(t,e,r){"use strict";var n=t("../scatterpolar/attributes"),a=t("../scattergl/attributes"),i=t("../../plots/template_attributes").texttemplateAttrs;e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,texttemplate:i({editType:"plot"},{keys:["r","theta","text"]}),hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:a.line,connectgaps:a.connectgaps,marker:a.marker,fill:a.fill,fillcolor:a.fillcolor,textposition:a.textposition,textfont:a.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{"../../plots/template_attributes":841,"../scattergl/attributes":1171,"../scatterpolar/attributes":1193}],1201:[function(t,e,r){"use strict";var n=t("../scatter/colorscale_calc"),a=t("../scatter/calc").calcMarkerSize,i=t("../scattergl/convert"),o=t("../../plots/cartesian/axes"),s=t("../scattergl/constants").TOO_MANY_POINTS;e.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,h=e._r=c.makeCalcdata(e,"r"),f=e._theta=u.makeCalcdata(e,"theta"),p=e._length,d={};p<h.length&&(h=h.slice(0,p)),p<f.length&&(f=f.slice(0,p)),d.r=h,d.theta=f,n(t,e);var g,v=d.opts=i.style(t,e);return p<s?g=a(e,p):v.marker&&(g=2*(v.marker.sizeAvg||Math.max(v.marker.size,3))),e._extremes.x=o.findExtremes(c,h,{ppad:g}),[{x:!1,y:!1,t:d,trace:e}]}},{"../../plots/cartesian/axes":765,"../scatter/calc":1121,"../scatter/colorscale_calc":1123,"../scattergl/constants":1173,"../scattergl/convert":1174}],1202:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/subtypes"),i=t("../scatterpolar/defaults").handleRThetaDefaults,o=t("../scatter/marker_defaults"),s=t("../scatter/line_defaults"),l=t("../scatter/text_defaults"),c=t("../scatter/fillcolor_defaults"),u=t("../scatter/constants").PTS_LINESONLY,h=t("./attributes");e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,h,r,a)}var d=i(t,e,f,p);d?(p("thetaunit"),p("mode",d<u?"lines+markers":"lines"),p("text"),p("hovertext"),"fills"!==e.hoveron&&p("hovertemplate"),a.hasLines(e)&&(s(t,e,r,f,p),p("connectgaps")),a.hasMarkers(e)&&o(t,e,r,f,p),a.hasText(e)&&(p("texttemplate"),l(t,e,f,p)),p("fill"),"none"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{"../../lib":717,"../scatter/constants":1124,"../scatter/fillcolor_defaults":1128,"../scatter/line_defaults":1133,"../scatter/marker_defaults":1139,"../scatter/subtypes":1144,"../scatter/text_defaults":1145,"../scatterpolar/defaults":1195,"./attributes":1200}],1203:[function(t,e,r){"use strict";var n=t("../scatterpolar/format_labels");e.exports=function(t,e,r){var a=t.i;return"r"in t||(t.r=e._r[a]),"theta"in t||(t.theta=e._theta[a]),n(t,e,r)}},{"../scatterpolar/format_labels":1196}],1204:[function(t,e,r){"use strict";var n=t("../scattergl/hover"),a=t("../scatterpolar/hover").makeHoverPointText;e.exports={hoverPoints:function(t,e,r,i){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,i);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var h=t.subplot,f=u.cd[u.index],p=u.trace;if(f.r=s[u.index],f.theta=l[u.index],h.isPtInside(f))return u.xLabelVal=void 0,u.yLabelVal=void 0,a(f,p,h,u),c}}}},{"../scattergl/hover":1179,"../scatterpolar/hover":1197}],1205:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"scatterpolargl",basePlotModule:t("../../plots/polar"),categories:["gl","regl","polar","symbols","showLegend","scatter-like"],attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../scatter/marker_colorbar"),formatLabels:t("./format_labels"),calc:t("./calc"),plot:t("./plot"),hoverPoints:t("./hover").hoverPoints,selectPoints:t("../scattergl/select"),meta:{}}},{"../../plots/polar":829,"../scatter/marker_colorbar":1138,"../scattergl/select":1183,"./attributes":1200,"./calc":1201,"./defaults":1202,"./format_labels":1203,"./hover":1204,"./plot":1206}],1206:[function(t,e,r){"use strict";var n=t("point-cluster"),a=t("fast-isnumeric"),i=t("../scattergl/plot"),o=t("../scattergl/scene_update"),s=t("../scattergl/convert"),l=t("../../lib"),c=t("../scattergl/constants").TOO_MANY_POINTS;e.exports=function(t,e,r){if(r.length){var u=e.radialAxis,h=e.angularAxis,f=o(t,e);return r.forEach(function(r){if(r&&r[0]&&r[0].trace){var i,o=r[0],p=o.trace,d=o.t,g=p._length,v=d.r,m=d.theta,y=d.opts,x=v.slice(),b=m.slice();for(i=0;i<v.length;i++)e.isPtInside({r:v[i],theta:m[i]})||(x[i]=NaN,b[i]=NaN);var _=new Array(2*g),w=Array(g),k=Array(g);for(i=0;i<g;i++){var T,M,A=x[i];if(a(A)){var S=u.c2g(A),E=h.c2g(b[i],p.thetaunit);T=S*Math.cos(E),M=S*Math.sin(E)}else T=M=NaN;w[i]=_[2*i]=T,k[i]=_[2*i+1]=M}d.tree=n(_),y.marker&&g>=c&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&l.extendFlat(y.line,s.linePositions(t,p,_)),y.text&&(l.extendFlat(y.text,{positions:_},s.textPosition(t,p,y.text,y.marker)),l.extendFlat(y.textSel,{positions:_},s.textPosition(t,p,y.text,y.markerSel)),l.extendFlat(y.textUnsel,{positions:_},s.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!f.fill2d&&(f.fill2d=!0),y.marker&&!f.scatter2d&&(f.scatter2d=!0),y.line&&!f.line2d&&(f.line2d=!0),y.text&&!f.glText&&(f.glText=!0),f.lineOptions.push(y.line),f.fillOptions.push(y.fill),f.markerOptions.push(y.marker),f.markerSelectedOptions.push(y.markerSel),f.markerUnselectedOptions.push(y.markerUnsel),f.textOptions.push(y.text),f.textSelectedOptions.push(y.textSel),f.textUnselectedOptions.push(y.textUnsel),f.selectBatch.push([]),f.unselectBatch.push([]),d.x=w,d.y=k,d.rawx=w,d.rawy=k,d.r=v,d.theta=m,d.positions=_,d._scene=f,d.index=f.count,f.count++}}),i(t,e,r)}}},{"../../lib":717,"../scattergl/constants":1173,"../scattergl/convert":1174,"../scattergl/plot":1181,"../scattergl/scene_update":1182,"fast-isnumeric":228,"point-cluster":470}],1207:[function(t,e,r){"use strict";var n=t("../../plots/template_attributes").hovertemplateAttrs,a=t("../../plots/template_attributes").texttemplateAttrs,i=t("../scatter/attributes"),o=t("../../plots/attributes"),s=t("../../components/colorscale/attributes"),l=t("../../components/drawing/attributes").dash,c=t("../../lib/extend").extendFlat,u=i.marker,h=i.line,f=u.line;e.exports={a:{valType:"data_array",editType:"calc"},b:{valType:"data_array",editType:"calc"},c:{valType:"data_array",editType:"calc"},sum:{valType:"number",dflt:0,min:0,editType:"calc"},mode:c({},i.mode,{dflt:"markers"}),text:c({},i.text,{}),texttemplate:a({editType:"plot"},{keys:["a","b","c","text"]}),hovertext:c({},i.hovertext,{}),line:{color:h.color,width:h.width,dash:l,shape:c({},h.shape,{values:["linear","spline"]}),smoothing:h.smoothing,editType:"calc"},connectgaps:i.connectgaps,cliponaxis:i.cliponaxis,fill:c({},i.fill,{values:["none","toself","tonext"],dflt:"none"}),fillcolor:i.fillcolor,marker:c({symbol:u.symbol,opacity:u.opacity,maxdisplayed:u.maxdisplayed,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,line:c({width:f.width,editType:"calc"},s("marker.line")),gradient:u.gradient,editType:"calc"},s("marker")),textfont:i.textfont,textposition:i.textposition,selected:i.selected,unselected:i.unselected,hoverinfo:c({},o.hoverinfo,{flags:["a","b","c","text","name"]}),hoveron:i.hoveron,hovertemplate:n()}},{"../../components/colorscale/attributes":598,"../../components/drawing/attributes":611,"../../lib/extend":708,"../../plots/attributes":762,"../../plots/template_attributes":841,"../scatter/attributes":1120}],1208:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../scatter/colorscale_calc"),i=t("../scatter/arrays_to_calcdata"),o=t("../scatter/calc_selection"),s=t("../scatter/calc").calcMarkerSize,l=["a","b","c"],c={a:["b","c"],b:["a","c"],c:["a","b"]};e.exports=function(t,e){var r,u,h,f,p,d,g=t._fullLayout[e.subplot].sum,v=e.sum||g,m={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!m[h=l[r]]){for(p=m[c[h][0]],d=m[c[h][1]],f=new Array(p.length),u=0;u<p.length;u++)f[u]=v-p[u]-d[u];m[h]=f}var y,x,b,_,w,k,T=e._length,M=new Array(T);for(r=0;r<T;r++)y=m.a[r],x=m.b[r],b=m.c[r],n(y)&&n(x)&&n(b)?(1!==(_=g/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),k=y,w=b-x,M[r]={x:w,y:k,a:y,b:x,c:b}):M[r]={x:!1,y:!1};return s(e,T),a(t,e),i(M,e),o(M,e),M}},{"../scatter/arrays_to_calcdata":1119,"../scatter/calc":1121,"../scatter/calc_selection":1122,"../scatter/colorscale_calc":1123,"fast-isnumeric":228}],1209:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/constants"),i=t("../scatter/subtypes"),o=t("../scatter/marker_defaults"),s=t("../scatter/line_defaults"),l=t("../scatter/line_shape_defaults"),c=t("../scatter/text_defaults"),u=t("../scatter/fillcolor_defaults"),h=t("./attributes");e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,h,r,a)}var d,g=p("a"),v=p("b"),m=p("c");if(g?(d=g.length,v?(d=Math.min(d,v.length),m&&(d=Math.min(d,m.length))):d=m?Math.min(d,m.length):0):v&&m&&(d=Math.min(v.length,m.length)),d){e._length=d,p("sum"),p("text"),p("hovertext"),"fills"!==e.hoveron&&p("hovertemplate"),p("mode",d<a.PTS_LINESONLY?"lines+markers":"lines"),i.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p("connectgaps")),i.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),i.hasText(e)&&(p("texttemplate"),c(t,e,f,p));var y=[];(i.hasMarkers(e)||i.hasText(e))&&(p("cliponaxis"),p("marker.maxdisplayed"),y.push("points")),p("fill"),"none"!==e.fill&&(u(t,e,r,p),i.hasLines(e)||l(t,e,p)),"tonext"!==e.fill&&"toself"!==e.fill||y.push("fills"),p("hoveron",y.join("+")||"points"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{"../../lib":717,"../scatter/constants":1124,"../scatter/fillcolor_defaults":1128,"../scatter/line_defaults":1133,"../scatter/line_shape_defaults":1135,"../scatter/marker_defaults":1139,"../scatter/subtypes":1144,"../scatter/text_defaults":1145,"./attributes":1207}],1210:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[a]){var i=n[a];t.a=i.a,t.b=i.b,t.c=i.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1211:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes");e.exports=function(t,e,r){var a={},i=r[e.subplot]._subplot;return a.aLabel=n.tickText(i.aaxis,t.a,!0).text,a.bLabel=n.tickText(i.baxis,t.b,!0).text,a.cLabel=n.tickText(i.caxis,t.c,!0).text,a}},{"../../plots/cartesian/axes":765}],1212:[function(t,e,r){"use strict";var n=t("../scatter/hover");e.exports=function(t,e,r,a){var i=n(t,e,r,a);if(i&&!1!==i[0].index){var o=i[0];if(void 0===o.index){var s=1-o.y0/t.ya._length,l=t.xa._length,c=l*s/2,u=l-c;return o.x0=Math.max(Math.min(o.x0,u),c),o.x1=Math.max(Math.min(o.x1,u),c),i}var h=o.cd[o.index],f=o.trace,p=o.subplot;o.a=h.a,o.b=h.b,o.c=h.c,o.xLabelVal=void 0,o.yLabelVal=void 0;var d={};d[f.subplot]={_subplot:p};var g=f._module.formatLabels(h,f,d);o.aLabel=g.aLabel,o.bLabel=g.bLabel,o.cLabel=g.cLabel;var v=h.hi||f.hoverinfo,m=[];if(!f.hovertemplate){var y=v.split("+");-1!==y.indexOf("all")&&(y=["a","b","c"]),-1!==y.indexOf("a")&&x(p.aaxis,o.aLabel),-1!==y.indexOf("b")&&x(p.baxis,o.bLabel),-1!==y.indexOf("c")&&x(p.caxis,o.cLabel)}return o.extraText=m.join("<br>"),o.hovertemplate=f.hovertemplate,i}function x(t,e){m.push(t._hovertitle+": "+e)}}},{"../scatter/hover":1131}],1213:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../scatter/marker_colorbar"),formatLabels:t("./format_labels"),calc:t("./calc"),plot:t("./plot"),style:t("../scatter/style").style,styleOnSelect:t("../scatter/style").styleOnSelect,hoverPoints:t("./hover"),selectPoints:t("../scatter/select"),eventData:t("./event_data"),moduleType:"trace",name:"scatterternary",basePlotModule:t("../../plots/ternary"),categories:["ternary","symbols","showLegend","scatter-like"],meta:{}}},{"../../plots/ternary":842,"../scatter/marker_colorbar":1138,"../scatter/select":1141,"../scatter/style":1143,"./attributes":1207,"./calc":1208,"./defaults":1209,"./event_data":1210,"./format_labels":1211,"./hover":1212,"./plot":1214}],1214:[function(t,e,r){"use strict";var n=t("../scatter/plot");e.exports=function(t,e,r){var a=e.plotContainer;a.select(".scatterlayer").selectAll("*").remove();var i={xaxis:e.xaxis,yaxis:e.yaxis,plot:a,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select("g.scatterlayer");n(t,i,r,o)}},{"../scatter/plot":1140}],1215:[function(t,e,r){"use strict";var n=t("../scatter/attributes"),a=t("../../components/colorscale/attributes"),i=t("../../plots/template_attributes").hovertemplateAttrs,o=t("../scattergl/attributes"),s=t("../../plots/cartesian/constants").idRegex,l=t("../../plot_api/plot_template").templatedArray,c=t("../../lib/extend").extendFlat,u=n.marker,h=u.line,f=c(a("marker.line",{editTypeOverride:"calc"}),{width:c({},h.width,{editType:"calc"}),editType:"calc"}),p=c(a("marker"),{symbol:u.symbol,size:c({},u.size,{editType:"markerSize"}),sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:f,editType:"calc"});function d(t){return{valType:"info_array",freeLength:!0,editType:"calc",items:{valType:"subplotid",regex:s[t],editType:"plot"}}}p.color.editType=p.cmin.editType=p.cmax.editType="style",e.exports={dimensions:l("dimension",{visible:{valType:"boolean",dflt:!0,editType:"calc"},label:{valType:"string",editType:"calc"},values:{valType:"data_array",editType:"calc+clearAxisTypes"},axis:{type:{valType:"enumerated",values:["linear","log","date","category"],editType:"calc+clearAxisTypes"},matches:{valType:"boolean",dflt:!1,editType:"calc"},editType:"calc+clearAxisTypes"},editType:"calc+clearAxisTypes"}),text:c({},o.text,{}),hovertext:c({},o.hovertext,{}),hovertemplate:i(),marker:p,xaxes:d("x"),yaxes:d("y"),diagonal:{visible:{valType:"boolean",dflt:!0,editType:"calc"},editType:"calc"},showupperhalf:{valType:"boolean",dflt:!0,editType:"calc"},showlowerhalf:{valType:"boolean",dflt:!0,editType:"calc"},selected:{marker:o.selected.marker,editType:"calc"},unselected:{marker:o.unselected.marker,editType:"calc"},opacity:o.opacity}},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plot_api/plot_template":755,"../../plots/cartesian/constants":771,"../../plots/template_attributes":841,"../scatter/attributes":1120,"../scattergl/attributes":1171}],1216:[function(t,e,r){"use strict";var n=t("regl-line2d"),a=t("../../registry"),i=t("../../lib/prepare_regl"),o=t("../../plots/get_data").getModuleCalcData,s=t("../../plots/cartesian"),l=t("../../plots/cartesian/axis_ids").getFromId,c=t("../../plots/cartesian/axes").shouldShowZeroLine,u="splom";function h(t,e,r){for(var n=r.matrixOptions.data.length,a=e._visibleDims,i=r.viewOpts.ranges=new Array(n),o=0;o<a.length;o++){var s=a[o],c=i[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var h=l(t,e._diag[s][1]);h&&(c[1]=h.r2l(h.range[0]),c[3]=h.r2l(h.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:i},{ranges:i}):r.matrix.update({ranges:i})}function f(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,a=e._splomGrid;a||(a=e._splomGrid=n(r)),a.update(function(t){var e,r=t._fullLayout,n=r._size,a=[0,0,r.width,r.height],i={};function o(t,e,r,n,o,s){var l=e[t+"color"],c=e[t+"width"],u=String(l+c);u in i?i[u].data.push(NaN,NaN,r,n,o,s):i[u]={data:[r,n,o,s],join:"rect",thickness:c,color:l,viewport:a,range:a,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],h=u.xaxis,f=u.yaxis,p=h._gridVals,d=f._gridVals,g=n.b+f.domain[0]*n.h,v=-f._m,m=-v*f.r2l(f.range[0],f.calendar);if(h.showgrid)for(e=0;e<p.length;e++)s=h._offset+h.l2p(p[e].x),o("grid",h,s,g,s,g+f._length);if(f.showgrid)for(e=0;e<d.length;e++)l=g+m+v*d[e].x,o("grid",f,h._offset,l,h._offset+h._length,l);c(t,h,f)&&(s=h._offset+h.l2p(0),o("zeroline",h,s,g,s,g+f._length)),c(t,f,h)&&(l=g+m+0,o("zeroline",f,h._offset,l,h._offset+h._length,l))}var y=[];for(e in i)y.push(i[e]);return y}(t))}e.exports={name:u,attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=a.getModule(u),n=o(t.calcdata,r)[0];i(t,["ANGLE_instanced_arrays","OES_element_index_uint"])&&(e._hasOnlyLargeSploms&&f(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&f(t);for(var n=0;n<e.length;n++){var a=e[n][0].trace,i=r._splomScenes[a.uid];"splom"===a.type&&i&&i.matrix&&h(t,a,i)}},updateGrid:f,clean:function(t,e,r,n){var a,i={};if(n._splomScenes){for(a=0;a<t.length;a++){var o=t[a];"splom"===o.type&&(i[o.uid]=1)}for(a=0;a<r.length;a++){var l=r[a];if(!i[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG}},{"../../lib/prepare_regl":730,"../../plots/cartesian":776,"../../plots/cartesian/axes":765,"../../plots/cartesian/axis_ids":768,"../../plots/get_data":800,"../../registry":846,"regl-line2d":492}],1217:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axis_ids"),i=t("../scatter/calc").calcMarkerSize,o=t("../scatter/calc").calcAxisExpansion,s=t("../scatter/colorscale_calc"),l=t("../scattergl/convert").markerSelection,c=t("../scattergl/convert").markerStyle,u=t("./scene_update"),h=t("../../constants/numerical").BADNUM,f=t("../scattergl/constants").TOO_MANY_POINTS;e.exports=function(t,e){var r,p,d,g,v,m,y=e.dimensions,x=e._length,b={},_=b.cdata=[],w=b.data=[],k=e._visibleDims=[];function T(t,r){for(var a=t.makeCalcdata({v:r.values,vcalendar:e.calendar},"v"),i=0;i<a.length;i++)a[i]=a[i]===h?NaN:a[i];_.push(a),w.push("log"===t.type?n.simpleMap(a,t.c2l):a)}for(r=0;r<y.length;r++)if((d=y[r]).visible){if(g=a.getFromId(t,e._diag[r][0]),v=a.getFromId(t,e._diag[r][1]),g&&v&&g.type!==v.type){n.log("Skipping splom dimension "+r+" with conflicting axis types");continue}g?(T(g,d),v&&"category"===v.type&&(v._categories=g._categories.slice())):T(v,d),k.push(r)}for(s(t,e),n.extendFlat(b,c(e)),m=_.length*x>f?2*(b.sizeAvg||Math.max(b.size,3)):i(e,x),p=0;p<k.length;p++)d=y[r=k[p]],g=a.getFromId(t,e._diag[r][0])||{},v=a.getFromId(t,e._diag[r][1])||{},o(t,e,g,v,_[p],_[p],m);var M=u(t,e);return M.matrix||(M.matrix=!0),M.matrixOptions=b,M.selectedOptions=l(e,e.selected),M.unselectedOptions=l(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},{"../../constants/numerical":693,"../../lib":717,"../../plots/cartesian/axis_ids":768,"../scatter/calc":1121,"../scatter/colorscale_calc":1123,"../scattergl/constants":1173,"../scattergl/convert":1174,"./scene_update":1224}],1218:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/array_container_defaults"),i=t("./attributes"),o=t("../scatter/subtypes"),s=t("../scatter/marker_defaults"),l=t("../parcoords/merge_length"),c=t("../scattergl/helpers").isOpenSymbol;function u(t,e){function r(r,a){return n.coerce(t,e,i.dimensions,r,a)}r("label");var a=r("values");a&&a.length?r("visible"):e.visible=!1,r("axis.type"),r("axis.matches")}e.exports=function(t,e,r,h){function f(r,a){return n.coerce(t,e,i,r,a)}var p=a(t,e,{name:"dimensions",handleItemDefaults:u}),d=f("diagonal.visible"),g=f("showupperhalf"),v=f("showlowerhalf");if(l(e,p,"values")&&(d||g||v)){f("text"),f("hovertext"),f("hovertemplate"),s(t,e,r,h,f);var m=c(e.marker.symbol),y=o.isBubble(e);f("marker.line.width",m||y?1:0),function(t,e,r,n){var a,i,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,h=new Array(s),f=new Array(s);for(a=0;a<s;a++){var p=a?a+1:"";h[a]="x"+p,f[a]="y"+p}var d=n("xaxes",h),g=n("yaxes",f),v=e._diag=new Array(s);e._xaxes={},e._yaxes={};var m=[],y=[];function x(t,n,a,i){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e["_"+o+"axes"][t]=1,i.push(t),!(t in s)){var l=s[t]={};a&&(l.label=a.label||"",a.visible&&a.axis&&(a.axis.type&&(l.type=a.axis.type),a.axis.matches&&(l.matches=n)))}}}var b=!u&&!c,_=!u&&!l;for(e._axesDim={},a=0;a<s;a++){var w=o[a],k=0===a,T=a===s-1,M=k&&b||T&&_?void 0:d[a],A=k&&_||T&&b?void 0:g[a];x(M,A,w,m),x(A,M,w,y),v[a]=[M,A],e._axesDim[M]=a,e._axesDim[A]=a}for(a=0;a<m.length;a++)for(i=0;i<y.length;i++){var S=m[a]+y[i];a>i&&l?r._splomSubplots[S]=1:a<i&&c?r._splomSubplots[S]=1:a!==i||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside="bottom",r._splomGridDflt.yside="left")}(0,e,h,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{"../../lib":717,"../../plots/array_container_defaults":761,"../parcoords/merge_length":1091,"../scatter/marker_defaults":1139,"../scatter/subtypes":1144,"../scattergl/helpers":1178,"./attributes":1215}],1219:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/colorscale_calc"),i=t("../scattergl/convert").markerStyle;e.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){a(t,r),n.extendFlat(o.matrixOptions,i(r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},{"../../lib":717,"../scatter/colorscale_calc":1123,"../scattergl/convert":1174}],1220:[function(t,e,r){"use strict";r.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],a=t._visibleDims,i=0;i<a.length;i++){var o=a[i];if(t._diag[o][n]===r)return i}return!1}},{}],1221:[function(t,e,r){"use strict";var n=t("./helpers"),a=t("../scattergl/hover").calcHover;e.exports={hoverPoints:function(t,e,r){var i=t.cd[0].trace,o=t.scene.matrixOptions.cdata,s=t.xa,l=t.ya,c=s.c2p(e),u=l.c2p(r),h=t.distance,f=n.getDimIndex(i,s),p=n.getDimIndex(i,l);if(!1===f||!1===p)return[t];for(var d,g,v=o[f],m=o[p],y=h,x=0;x<v.length;x++){var b=v[x],_=m[x],w=s.c2p(b)-c,k=l.c2p(_)-u,T=Math.sqrt(w*w+k*k);T<y&&(y=g=T,d=x)}return t.index=d,t.distance=y,t.dxy=g,void 0===d?[t]:[a(t,v,m,i)]}}},{"../scattergl/hover":1179,"./helpers":1220}],1222:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../components/grid");e.exports={moduleType:"trace",name:"splom",basePlotModule:t("./base_plot"),categories:["gl","regl","cartesian","symbols","showLegend","scatter-like"],attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../scatter/marker_colorbar"),calc:t("./calc"),plot:t("./plot"),hoverPoints:t("./hover").hoverPoints,selectPoints:t("./select"),editStyle:t("./edit_style"),meta:{}},n.register(a)},{"../../components/grid":634,"../../registry":846,"../scatter/marker_colorbar":1138,"./attributes":1215,"./base_plot":1216,"./calc":1217,"./defaults":1218,"./edit_style":1219,"./hover":1221,"./plot":1223,"./select":1225}],1223:[function(t,e,r){"use strict";var n=t("regl-splom"),a=t("../../lib"),i=t("../../plots/cartesian/axis_ids");function o(t,e){var r,o,s,l,c,u=t._fullLayout,h=u._size,f=e.trace,p=e.t,d=u._splomScenes[f.uid],g=d.matrixOptions,v=g.cdata,m=u._glcanvas.data()[0].regl,y=u.dragmode;if(0!==v.length){g.lower=f.showupperhalf,g.upper=f.showlowerhalf,g.diagonal=f.diagonal.visible;var x=f._visibleDims,b=v.length,_=d.viewOpts={};for(_.ranges=new Array(b),_.domains=new Array(b),c=0;c<x.length;c++){s=x[c];var w=_.ranges[c]=new Array(4),k=_.domains[c]=new Array(4);(r=i.getFromId(t,f._diag[s][0]))&&(w[0]=r._rl[0],w[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(o=i.getFromId(t,f._diag[s][1]))&&(w[1]=o._rl[0],w[3]=o._rl[1],k[1]=o.domain[0],k[3]=o.domain[1])}_.viewport=[h.l,h.b,h.w+h.l,h.h+h.b],!0===d.matrix&&(d.matrix=n(m));var T=u.clickmode.indexOf("select")>-1,M=!0;if("lasso"===y||"select"===y||!!f.selectedpoints||T){var A=f._length;if(f.selectedpoints){d.selectBatch=f.selectedpoints;var S=f.selectedpoints,E={};for(s=0;s<S.length;s++)E[S[s]]=!0;var L=[];for(s=0;s<A;s++)E[s]||L.push(s);d.unselectBatch=L}var C=p.xpx=new Array(b),P=p.ypx=new Array(b);for(c=0;c<x.length;c++){if(s=x[c],r=i.getFromId(t,f._diag[s][0]))for(C[c]=new Array(A),l=0;l<A;l++)C[c][l]=r.c2p(v[c][l]);if(o=i.getFromId(t,f._diag[s][1]))for(P[c]=new Array(A),l=0;l<A;l++)P[c][l]=o.c2p(v[c][l])}if(d.selectBatch.length||d.unselectBatch.length){var O=a.extendFlat({},g,d.unselectedOptions,_),z=a.extendFlat({},g,d.selectedOptions,_);d.matrix.update(O,z),M=!1}}else p.xpx=p.ypx=null;if(M){var I=a.extendFlat({},g,_);d.matrix.update(I,null)}}}e.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)o(t,r[n][0])}},{"../../lib":717,"../../plots/cartesian/axis_ids":768,"regl-splom":499}],1224:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e){var r=t._fullLayout,a=e.uid,i=r._splomScenes;i||(i=r._splomScenes={});var o={dirty:!0,selectBatch:[],unselectBatch:[]},s=i[e.uid];return s||((s=i[a]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},{"../../lib":717}],1225:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/subtypes"),i=t("./helpers");e.exports=function(t,e){var r=t.cd,o=r[0].trace,s=r[0].t,l=t.scene,c=l.matrixOptions.cdata,u=t.xaxis,h=t.yaxis,f=[];if(!l)return f;var p=!a.hasMarkers(o)&&!a.hasText(o);if(!0!==o.visible||p)return f;var d=i.getDimIndex(o,u),g=i.getDimIndex(o,h);if(!1===d||!1===g)return f;var v=s.xpx[d],m=s.ypx[g],y=c[d],x=c[g],b=[],_=[];if(!1!==e&&!e.degenerate)for(var w=0;w<y.length;w++)e.contains([v[w],m[w]],null,w,t)?(b.push(w),f.push({pointNumber:w,x:y[w],y:x[w]})):_.push(w);var k=l.matrixOptions;return b.length||_.length?l.selectBatch.length||l.unselectBatch.length||l.matrix.update(l.unselectedOptions,n.extendFlat({},k,l.selectedOptions,l.viewOpts)):l.matrix.update(k,null),l.selectBatch=b,l.unselectBatch=_,f}},{"../../lib":717,"../scatter/subtypes":1144,"./helpers":1220}],1226:[function(t,e,r){"use strict";var n=t("../../components/colorscale/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../mesh3d/attributes"),o=t("../../plots/attributes"),s=t("../../lib/extend").extendFlat,l={x:{valType:"data_array",editType:"calc+clearAxisTypes"},y:{valType:"data_array",editType:"calc+clearAxisTypes"},z:{valType:"data_array",editType:"calc+clearAxisTypes"},u:{valType:"data_array",editType:"calc"},v:{valType:"data_array",editType:"calc"},w:{valType:"data_array",editType:"calc"},starts:{x:{valType:"data_array",editType:"calc"},y:{valType:"data_array",editType:"calc"},z:{valType:"data_array",editType:"calc"},editType:"calc"},maxdisplayed:{valType:"integer",min:0,dflt:1e3,editType:"calc"},sizeref:{valType:"number",editType:"calc",min:0,dflt:1},text:{valType:"string",dflt:"",editType:"calc"},hovertext:{valType:"string",dflt:"",editType:"calc"},hovertemplate:a({editType:"calc"},{keys:["tubex","tubey","tubez","tubeu","tubev","tubew","norm","divergence"]}),showlegend:s({},o.showlegend,{dflt:!1})};s(l,n("",{colorAttr:"u/v/w norm",showScaleDflt:!0,editTypeOverride:"calc"}));["opacity","lightposition","lighting"].forEach(function(t){l[t]=i[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:"calc",flags:["x","y","z","u","v","w","norm","divergence","text","name"],dflt:"x+y+z+norm+text+name"}),l.transforms=void 0,e.exports=l},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plots/attributes":762,"../../plots/template_attributes":841,"../mesh3d/attributes":1061}],1227:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/colorscale/calc");function i(t){var e,r,a,i,s,l,c,u,h,f,p,d,g=t._x,v=t._y,m=t._z,y=t._len,x=-1/0,b=1/0,_=-1/0,w=1/0,k=-1/0,T=1/0,M="";for(y&&(c=g[0],h=v[0],p=m[0]),y>1&&(u=g[y-1],f=v[y-1],d=m[y-1]),e=0;e<y;e++)x=Math.max(x,g[e]),b=Math.min(b,g[e]),_=Math.max(_,v[e]),w=Math.min(w,v[e]),k=Math.max(k,m[e]),T=Math.min(T,m[e]),i||g[e]===c||(i=!0,M+="x"),s||v[e]===h||(s=!0,M+="y"),l||m[e]===p||(l=!0,M+="z");i||(M+="x"),s||(M+="y"),l||(M+="z");var A=o(t._x),S=o(t._y),E=o(t._z);M=(M=(M=M.replace("x",(c>u?"-":"+")+"x")).replace("y",(h>f?"-":"+")+"y")).replace("z",(p>d?"-":"+")+"z");var L=function(){y=0,A=[],S=[],E=[]};(!y||y<A.length*S.length*E.length)&&L();var C=function(t){return"x"===t?g:"y"===t?v:m},P=function(t){return"x"===t?A:"y"===t?S:E},O=function(t){return t[y-1]<t[0]?-1:1},z=C(M[1]),I=C(M[3]),D=C(M[5]),R=P(M[1]).length,F=P(M[3]).length,B=P(M[5]).length,N=!1,j=function(t,e,r){return R*(F*t+e)+r},V=O(C(M[1])),U=O(C(M[3])),q=O(C(M[5]));for(e=0;e<B-1;e++){for(r=0;r<F-1;r++){for(a=0;a<R-1;a++){var H=j(e,r,a),G=j(e,r,a+1),Y=j(e,r+1,a),W=j(e+1,r,a);if(z[H]*V<z[G]*V&&I[H]*U<I[Y]*U&&D[H]*q<D[W]*q||(N=!0),N)break}if(N)break}if(N)break}return N&&(n.warn("Encountered arbitrary coordinates! Unable to input data grid."),L()),{xMin:b,yMin:w,zMin:T,xMax:x,yMax:_,zMax:k,Xs:A,Ys:S,Zs:E,len:y,fill:M}}function o(t){return n.distinctVals(t).vals}function s(t,e){if(void 0===e&&(e=t.length),n.isTypedArray(t))return t.subarray(0,e);for(var r=[],a=0;a<e;a++)r[a]=+t[a];return r}e.exports={calc:function(t,e){e._len=Math.min(e.u.length,e.v.length,e.w.length,e.x.length,e.y.length,e.z.length),e._u=s(e.u,e._len),e._v=s(e.v,e._len),e._w=s(e.w,e._len),e._x=s(e.x,e._len),e._y=s(e.y,e._len),e._z=s(e.z,e._len);var r=i(e);e._gridFill=r.fill,e._Xs=r.Xs,e._Ys=r.Ys,e._Zs=r.Zs,e._len=r.len;var n,o,l,c=0;e.starts&&(n=s(e.starts.x||[]),o=s(e.starts.y||[]),l=s(e.starts.z||[]),c=Math.min(n.length,o.length,l.length)),e._startsX=n||[],e._startsY=o||[],e._startsZ=l||[];var u,h=0,f=1/0;for(u=0;u<e._len;u++){var p=e._u[u],d=e._v[u],g=e._w[u],v=Math.sqrt(p*p+d*d+g*g);h=Math.max(h,v),f=Math.min(f,v)}for(a(t,e,{vals:[f,h],containerStr:"",cLetter:"c"}),u=0;u<c;u++){var m=n[u];r.xMax=Math.max(r.xMax,m),r.xMin=Math.min(r.xMin,m);var y=o[u];r.yMax=Math.max(r.yMax,y),r.yMin=Math.min(r.yMin,y);var x=l[u];r.zMax=Math.max(r.zMax,x),r.zMin=Math.min(r.zMin,x)}e._slen=c,e._normMax=h,e._xbnds=[r.xMin,r.xMax],e._ybnds=[r.yMin,r.yMax],e._zbnds=[r.zMin,r.zMax]},filter:s,processGrid:i}},{"../../components/colorscale/calc":599,"../../lib":717}],1228:[function(t,e,r){"use strict";var n=t("gl-streamtube3d"),a=n.createTubeMesh,i=t("../../lib"),o=t("../../lib/gl_format_color").parseColorScale,s=t("../../components/colorscale").extractOpts,l=t("../../plots/gl3d/zip3"),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var h=u.prototype;function f(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function p(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function d(t,e){var r=t.fullSceneLayout,a=t.dataScale,u=e._len,h={};function d(t,e){var n=r[e],o=a[c[e]];return i.simpleMap(t,function(t){return n.d2l(t)*o})}if(h.vectors=l(d(e._u,"xaxis"),d(e._v,"yaxis"),d(e._w,"zaxis"),u),!u)return{positions:[],cells:[]};var g=d(e._Xs,"xaxis"),v=d(e._Ys,"yaxis"),m=d(e._Zs,"zaxis");if(h.meshgrid=[g,v,m],h.gridFill=e._gridFill,e._slen)h.startingPositions=l(d(e._startsX,"xaxis"),d(e._startsY,"yaxis"),d(e._startsZ,"zaxis"));else{for(var y=v[0],x=f(g),b=f(m),_=new Array(x.length*b.length),w=0,k=0;k<x.length;k++)for(var T=0;T<b.length;T++)_[w++]=[x[k],y,b[T]];h.startingPositions=_}h.colormap=o(e),h.tubeSize=e.sizeref,h.maxLength=e.maxdisplayed;var M=d(e._xbnds,"xaxis"),A=d(e._ybnds,"yaxis"),S=d(e._zbnds,"zaxis"),E=p(g),L=p(v),C=p(m),P=[[M[0]-E[0],A[0]-L[0],S[0]-C[0]],[M[1]+E[1],A[1]+L[1],S[1]+C[1]]],O=n(h,P),z=s(e);O.vertexIntensityBounds=[z.min/e._normMax,z.max/e._normMax];var I=e.lightposition;return O.lightPosition=[I.x,I.y,I.z],O.ambient=e.lighting.ambient,O.diffuse=e.lighting.diffuse,O.specular=e.lighting.specular,O.roughness=e.lighting.roughness,O.fresnel=e.lighting.fresnel,O.opacity=e.opacity,e._pad=O.tubeScale*e.sizeref*2,O}h.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var a=e[n],i=r[c[n]];return a.l2c(t)/i}if(t.object===this.mesh){var a=t.data.position,i=t.data.velocity;return t.traceCoordinate=[n(a[0],"xaxis"),n(a[1],"yaxis"),n(a[2],"zaxis"),n(i[0],"xaxis"),n(i[1],"yaxis"),n(i[2],"zaxis"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},h.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),i=a(r,n),o=new u(t,e.uid);return o.mesh=i,o.data=e,i._trace=o,t.glplot.add(i),o}},{"../../components/colorscale":603,"../../lib":717,"../../lib/gl_format_color":714,"../../plots/gl3d/zip3":816,"gl-streamtube3d":315}],1229:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/colorscale/defaults"),i=t("./attributes");e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}var l=s("u"),c=s("v"),u=s("w"),h=s("x"),f=s("y"),p=s("z");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s("starts.x"),s("starts.y"),s("starts.z"),s("maxdisplayed"),s("sizeref"),s("lighting.ambient"),s("lighting.diffuse"),s("lighting.specular"),s("lighting.roughness"),s("lighting.fresnel"),s("lightposition.x"),s("lightposition.y"),s("lightposition.z"),a(t,e,o,s,{prefix:"",cLetter:"c"}),s("text"),s("hovertext"),s("hovertemplate"),e._length=null):e.visible=!1}},{"../../components/colorscale/defaults":601,"../../lib":717,"./attributes":1226}],1230:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"streamtube",basePlotModule:t("../../plots/gl3d"),categories:["gl3d","showLegend"],attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:{min:"cmin",max:"cmax"},calc:t("./calc").calc,plot:t("./convert"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{"../../plots/gl3d":805,"./attributes":1226,"./calc":1227,"./convert":1228,"./defaults":1229}],1231:[function(t,e,r){"use strict";var n=t("../../plots/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../../plots/template_attributes").texttemplateAttrs,o=t("../../components/colorscale/attributes"),s=t("../../plots/domain").attributes,l=t("../pie/attributes"),c=t("./constants"),u=t("../../lib/extend").extendFlat;e.exports={labels:{valType:"data_array",editType:"calc"},parents:{valType:"data_array",editType:"calc"},values:{valType:"data_array",editType:"calc"},branchvalues:{valType:"enumerated",values:["remainder","total"],dflt:"remainder",editType:"calc"},count:{valType:"flaglist",flags:["branches","leaves"],dflt:"leaves",editType:"calc"},level:{valType:"any",editType:"plot",anim:!0},maxdepth:{valType:"integer",editType:"plot",dflt:-1},marker:u({colors:{valType:"data_array",editType:"calc"},line:{color:u({},l.marker.line.color,{dflt:null}),width:u({},l.marker.line.width,{dflt:1}),editType:"calc"},editType:"calc"},o("marker",{colorAttr:"colors",anim:!1})),leaf:{opacity:{valType:"number",editType:"style",min:0,max:1},editType:"plot"},text:l.text,textinfo:{valType:"flaglist",flags:["label","text","value","current path","percent root","percent entry","percent parent"],extras:["none"],editType:"plot"},texttemplate:i({editType:"plot"},{keys:c.eventDataKeys.concat(["label","value"])}),hovertext:l.hovertext,hoverinfo:u({},n.hoverinfo,{flags:["label","text","value","name","current path","percent root","percent entry","percent parent"],dflt:"label+text+value+name"}),hovertemplate:a({},{keys:c.eventDataKeys}),textfont:l.textfont,insidetextorientation:l.insidetextorientation,insidetextfont:l.insidetextfont,outsidetextfont:u({},l.outsidetextfont,{}),domain:s({name:"sunburst",trace:!0,editType:"calc"})}},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plots/attributes":762,"../../plots/domain":790,"../../plots/template_attributes":841,"../pie/attributes":1094,"./constants":1234}],1232:[function(t,e,r){"use strict";var n=t("../../plots/plots");r.name="sunburst",r.plot=function(t,e,a,i){n.plotBasePlot(r.name,t,e,a,i)},r.clean=function(t,e,a,i){n.cleanBasePlot(r.name,t,e,a,i)}},{"../../plots/plots":826}],1233:[function(t,e,r){"use strict";var n=t("d3-hierarchy"),a=t("fast-isnumeric"),i=t("../../lib"),o=t("../../components/colorscale").makeColorScaleFuncFromTrace,s=t("../pie/calc").makePullColorFn,l=t("../pie/calc").generateExtendedColors,c=t("../../components/colorscale").calc,u=t("../../constants/numerical").ALMOST_EQUAL,h={},f={};r.calc=function(t,e){var r,l,h,f,p,d,g=t._fullLayout,v=e.ids,m=i.isArrayOrTypedArray(v),y=e.labels,x=e.parents,b=e.values,_=i.isArrayOrTypedArray(b),w=[],k={},T={},M=function(t){return t||"number"==typeof t},A=function(t){return!_||a(b[t])&&b[t]>=0};m?(r=Math.min(v.length,x.length),l=function(t){return M(v[t])&&A(t)},h=function(t){return String(v[t])}):(r=Math.min(y.length,x.length),l=function(t){return M(y[t])&&A(t)},h=function(t){return String(y[t])}),_&&(r=Math.min(r,b.length));for(var S=0;S<r;S++)if(l(S)){var E=h(S),L=M(x[S])?String(x[S]):"",C={i:S,id:E,pid:L,label:M(y[S])?String(y[S]):""};_&&(C.v=+b[S]),w.push(C),p=E,k[f=L]?k[f].push(p):k[f]=[p],T[p]=1}if(k[""]){if(k[""].length>1){for(var P=i.randstr(),O=0;O<w.length;O++)""===w[O].pid&&(w[O].pid=P);w.unshift({hasMultipleRoots:!0,id:P,pid:"",label:""})}}else{var z,I=[];for(z in k)T[z]||I.push(z);if(1!==I.length)return i.warn("Multiple implied roots, cannot build "+e.type+" hierarchy.");z=I[0],w.unshift({hasImpliedRoot:!0,id:z,pid:"",label:z})}try{d=n.stratify().id(function(t){return t.id}).parentId(function(t){return t.pid})(w)}catch(t){return i.warn("Failed to build "+e.type+" hierarchy. Error: "+t.message)}var D=n.hierarchy(d),R=!1;if(_)switch(e.branchvalues){case"remainder":D.sum(function(t){return t.data.v});break;case"total":D.each(function(t){var e=t.data.data,r=e.v;if(t.children){var n=t.children.reduce(function(t,e){return t+e.data.data.v},0);if((e.hasImpliedRoot||e.hasMultipleRoots)&&(r=n),r<n*u)return R=!0,i.warn(["Total value for node",t.data.data.id,"is smaller than the sum of its children.","\nparent value =",r,"\nchildren sum =",n].join(" "))}t.value=r})}else!function t(e,r,n){var a=0;var i=e.children;if(i){for(var o=i.length,s=0;s<o;s++)a+=t(i[s],r,n);n.branches&&a++}else n.leaves&&a++;e.value=e.data.data.value=a;r._values||(r._values=[]);r._values[e.data.data.i]=a;return a}(D,e,{branches:-1!==e.count.indexOf("branches"),leaves:-1!==e.count.indexOf("leaves")});if(!R){var F,B;D.sort(function(t,e){return e.value-t.value});var N=e.marker.colors||[],j=!!N.length;return e._hasColorscale?(j||(N=_?e.values:e._values),c(t,e,{vals:N,containerStr:"marker",cLetter:"c"}),B=o(e.marker)):F=s(g["_"+e.type+"colormap"]),D.each(function(t){var r=t.data.data;r.color=e._hasColorscale?B(N[r.i]):F(N[r.i],r.id)}),w[0].hierarchy=D,w}},r._runCrossTraceCalc=function(t,e){var r=e._fullLayout,n=e.calcdata,a=r[t+"colorway"],i=r["_"+t+"colormap"];r["extend"+t+"colors"]&&(a=l(a,"treemap"===t?f:h));var o=0;function s(t){var e=t.data.data,r=e.id;!1===e.color&&(i[r]?e.color=i[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(i[r]=e.color=a[o%a.length],o++):e.color="rgba(0,0,0,0)")}for(var c=0;c<n.length;c++){var u=n[c][0];u.trace.type===t&&u.hierarchy&&u.hierarchy.each(s)}},r.crossTraceCalc=function(t){return r._runCrossTraceCalc("sunburst",t)}},{"../../components/colorscale":603,"../../constants/numerical":693,"../../lib":717,"../pie/calc":1096,"d3-hierarchy":159,"fast-isnumeric":228}],1234:[function(t,e,r){"use strict";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:"linear",eventDataKeys:["currentPath","root","entry","percentRoot","percentEntry","percentParent"]}},{}],1235:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("../../plots/domain").defaults,o=t("../bar/defaults").handleText,s=t("../../components/colorscale"),l=s.hasColorscale,c=s.handleDefaults;e.exports=function(t,e,r,s){function u(r,i){return n.coerce(t,e,a,r,i)}var h=u("labels"),f=u("parents");if(h&&h.length&&f&&f.length){var p=u("values");p&&p.length?u("branchvalues"):u("count"),u("level"),u("maxdepth"),u("marker.line.width")&&u("marker.line.color",s.paper_bgcolor),u("marker.colors");var d=e._hasColorscale=l(t,"marker","colors")||(t.marker||{}).coloraxis;d&&c(t,e,s,u,{prefix:"marker.",cLetter:"c"}),u("leaf.opacity",d?1:.7);var g=u("text");u("texttemplate"),e.texttemplate||u("textinfo",Array.isArray(g)?"text+label":"label"),u("hovertext"),u("hovertemplate");o(t,e,s,u,"auto",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),u("insidetextorientation"),i(e,s,u),e._length=null}else e.visible=!1}},{"../../components/colorscale":603,"../../lib":717,"../../plots/domain":790,"../bar/defaults":860,"./attributes":1231}],1236:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../components/fx/helpers").appendArrayPointValue,o=t("../../components/fx"),s=t("../../lib"),l=t("../../lib/events"),c=t("./helpers"),u=t("../pie/helpers").formatPieValue;function h(t,e,r){for(var n=t.data.data,a={curveNumber:e.index,pointNumber:n.i,data:e._input,fullData:e},o=0;o<r.length;o++){var s=r[o];s in t&&(a[s]=t[s])}return"parentString"in t&&!c.isHierarchyRoot(t)&&(a.parent=t.parentString),i(a,e,n.i),a}e.exports=function(t,e,r,i,f){var p=i[0],d=p.trace,g=p.hierarchy,v="sunburst"===d.type,m="treemap"===d.type;"_hasHoverLabel"in d||(d._hasHoverLabel=!1),"_hasHoverEvent"in d||(d._hasHoverEvent=!1);t.on("mouseover",function(a){var i=r._fullLayout;if(!r._dragging&&!1!==i.hovermode){var l=r._fullData[d.index],y=a.data.data,x=y.i,b=c.isHierarchyRoot(a),_=c.getParent(g,a),w=c.getValue(a),k=function(t){return s.castOption(l,x,t)},T=k("hovertemplate"),M=o.castHoverinfo(l,i,x),A=i.separators;if(T||M&&"none"!==M&&"skip"!==M){var S,E;v&&(S=p.cx+a.pxmid[0]*(1-a.rInscribed),E=p.cy+a.pxmid[1]*(1-a.rInscribed)),m&&(S=a._hoverX,E=a._hoverY);var L,C={},P=[],O=[],z=function(t){return-1!==P.indexOf(t)};M&&(P="all"===M?l._module.attributes.hoverinfo.flags:M.split("+")),C.label=y.label,z("label")&&C.label&&O.push(C.label),y.hasOwnProperty("v")&&(C.value=y.v,C.valueLabel=u(C.value,A),z("value")&&O.push(C.valueLabel)),C.currentPath=a.currentPath=c.getPath(a.data),z("current path")&&!b&&O.push(C.currentPath);var I=[],D=function(){-1===I.indexOf(L)&&(O.push(L),I.push(L))};C.percentParent=a.percentParent=w/c.getValue(_),C.parent=a.parentString=c.getPtLabel(_),z("percent parent")&&(L=c.formatPercent(C.percentParent,A)+" of "+C.parent,D()),C.percentEntry=a.percentEntry=w/c.getValue(e),C.entry=a.entry=c.getPtLabel(e),!z("percent entry")||b||a.onPathbar||(L=c.formatPercent(C.percentEntry,A)+" of "+C.entry,D()),C.percentRoot=a.percentRoot=w/c.getValue(g),C.root=a.root=c.getPtLabel(g),z("percent root")&&!b&&(L=c.formatPercent(C.percentRoot,A)+" of "+C.root,D()),C.text=k("hovertext")||k("text"),z("text")&&(L=C.text,s.isValidTextValue(L)&&O.push(L));var R={trace:l,y:E,text:O.join("<br>"),name:T||z("name")?l.name:void 0,color:k("hoverlabel.bgcolor")||y.color,borderColor:k("hoverlabel.bordercolor"),fontFamily:k("hoverlabel.font.family"),fontSize:k("hoverlabel.font.size"),fontColor:k("hoverlabel.font.color"),nameLength:k("hoverlabel.namelength"),textAlign:k("hoverlabel.align"),hovertemplate:T,hovertemplateLabels:C,eventData:[h(a,l,f.eventDataKeys)]};v&&(R.x0=S-a.rInscribed*a.rpx1,R.x1=S+a.rInscribed*a.rpx1,R.idealAlign=a.pxmid[0]<0?"left":"right"),m&&(R.x=S,R.idealAlign=S<0?"left":"right"),o.loneHover(R,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r}),d._hasHoverLabel=!0}if(m){var F=t.select("path.surface");f.styleOne(F,a,l,{hovered:!0})}d._hasHoverEvent=!0,r.emit("plotly_hover",{points:[h(a,l,f.eventDataKeys)],event:n.event})}}),t.on("mouseout",function(e){var a=r._fullLayout,i=r._fullData[d.index],s=n.select(this).datum();if(d._hasHoverEvent&&(e.originalEvent=n.event,r.emit("plotly_unhover",{points:[h(s,i,f.eventDataKeys)],event:n.event}),d._hasHoverEvent=!1),d._hasHoverLabel&&(o.loneUnhover(a._hoverlayer.node()),d._hasHoverLabel=!1),m){var l=t.select("path.surface");f.styleOne(l,s,i,{hovered:!1})}}),t.on("click",function(t){var e=r._fullLayout,i=r._fullData[d.index],s=v&&(c.isHierarchyRoot(t)||c.isLeaf(t)),u=c.getPtId(t),p=c.isEntry(t)?c.findEntryWithChild(g,u):c.findEntryWithLevel(g,u),m=c.getPtId(p),y={points:[h(t,i,f.eventDataKeys)],event:n.event};s||(y.nextLevel=m);var x=l.triggerHandler(r,"plotly_"+d.type+"click",y);if(!1!==x&&e.hovermode&&(r._hoverdata=[h(t,i,f.eventDataKeys)],o.click(r,n.event)),!s&&!1!==x&&!r._dragging&&!r._transitioning){a.call("_storeDirectGUIEdit",i,e._tracePreGUI[i.uid],{level:i.level});var b={data:[{level:m}],traces:[d.index]},_={frame:{redraw:!1,duration:f.transitionTime},transition:{duration:f.transitionTime,easing:f.transitionEasing},mode:"immediate",fromcurrent:!0};o.loneUnhover(e._hoverlayer.node()),a.call("animate",r,b,_)}})}},{"../../components/fx":630,"../../components/fx/helpers":626,"../../lib":717,"../../lib/events":707,"../../registry":846,"../pie/helpers":1099,"./helpers":1237,d3:165}],1237:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/color"),i=t("../../lib/setcursor"),o=t("../pie/helpers");function s(t){return t.data.data.pid}r.findEntryWithLevel=function(t,e){var n;return e&&t.eachAfter(function(t){if(r.getPtId(t)===e)return n=t.copy()}),n||t},r.findEntryWithChild=function(t,e){var n;return t.eachAfter(function(t){for(var a=t.children||[],i=0;i<a.length;i++){var o=a[i];if(r.getPtId(o)===e)return n=t.copy()}}),n||t},r.isEntry=function(t){return!t.parent},r.isLeaf=function(t){return!t.children},r.getPtId=function(t){return t.data.data.id},r.getPtLabel=function(t){return t.data.data.label},r.getValue=function(t){return t.value},r.isHierarchyRoot=function(t){return""===s(t)},r.setSliceCursor=function(t,e,n){var a=n.isTransitioning;if(!a){var o=t.datum();a=n.hideOnRoot&&r.isHierarchyRoot(o)||n.hideOnLeaves&&r.isLeaf(o)}i(t,a?null:"pointer")},r.getInsideTextFontKey=function(t,e,r,a,i){var o=(i||{}).onPathbar?"pathbar.textfont":"insidetextfont",s=r.data.data.i;return n.castOption(e,s,o+"."+t)||n.castOption(e,s,"textfont."+t)||a.size},r.getOutsideTextFontKey=function(t,e,r,a){var i=r.data.data.i;return n.castOption(e,i,"outsidetextfont."+t)||n.castOption(e,i,"textfont."+t)||a.size},r.isOutsideText=function(t,e){return!t._hasColorscale&&r.isHierarchyRoot(e)},r.determineTextFont=function(t,e,i,o){return r.isOutsideText(t,e)?function(t,e,n){return{color:r.getOutsideTextFontKey("color",t,e,n),family:r.getOutsideTextFontKey("family",t,e,n),size:r.getOutsideTextFontKey("size",t,e,n)}}(t,e,i):function(t,e,i,o){var s=(o||{}).onPathbar,l=e.data.data,c=l.i,u=n.castOption(t,c,(s?"pathbar.textfont":"insidetextfont")+".color");return!u&&t._input.textfont&&(u=n.castOption(t._input,c,"textfont.color")),{color:u||a.contrast(l.color),family:r.getInsideTextFontKey("family",t,e,i,o),size:r.getInsideTextFontKey("size",t,e,i,o)}}(t,e,i,o)},r.hasTransition=function(t){return!!(t&&t.duration>0)},r.getMaxDepth=function(t){return t.maxdepth>=0?t.maxdepth:1/0},r.isHeader=function(t,e){return!(r.isLeaf(t)||t.depth===e._maxDepth-1)},r.getParent=function(t,e){return r.findEntryWithLevel(t,s(e))},r.listPath=function(t,e){var n=t.parent;if(!n)return[];var a=e?[n.data[e]]:[n];return r.listPath(n,e).concat(a)},r.getPath=function(t){return r.listPath(t,"label").join("/")+"/"},r.formatValue=o.formatPieValue,r.formatPercent=function(t,e){var r=n.formatPercent(t,0);return"0%"===r&&(r=o.formatPiePercent(t,e)),r}},{"../../components/color":591,"../../lib":717,"../../lib/setcursor":737,"../pie/helpers":1099}],1238:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"sunburst",basePlotModule:t("./base_plot"),categories:[],animatable:!0,attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults"),supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc").calc,crossTraceCalc:t("./calc").crossTraceCalc,plot:t("./plot").plot,style:t("./style").style,colorbar:t("../scatter/marker_colorbar"),meta:{}}},{"../scatter/marker_colorbar":1138,"./attributes":1231,"./base_plot":1232,"./calc":1233,"./defaults":1235,"./layout_attributes":1239,"./layout_defaults":1240,"./plot":1241,"./style":1242}],1239:[function(t,e,r){"use strict";e.exports={sunburstcolorway:{valType:"colorlist",editType:"calc"},extendsunburstcolors:{valType:"boolean",dflt:!0,editType:"calc"}}},{}],1240:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r("sunburstcolorway",e.colorway),r("extendsunburstcolors")}},{"../../lib":717,"./layout_attributes":1239}],1241:[function(t,e,r){"use strict";var n=t("d3"),a=t("d3-hierarchy"),i=t("../../components/drawing"),o=t("../../lib"),s=t("../../lib/svg_text_utils"),l=t("../bar/uniform_text"),c=l.recordMinTextSize,u=l.clearMinTextSize,h=t("../pie/plot"),f=h.computeTransform,p=h.transformInsideText,d=t("./style").styleOne,g=t("../bar/style").resizeText,v=t("./fx"),m=t("./constants"),y=t("./helpers");function x(t,e,l,u){var h=t._fullLayout,g=!h.uniformtext.mode&&y.hasTransition(u),x=n.select(l).selectAll("g.slice"),_=e[0],w=_.trace,k=_.hierarchy,T=y.findEntryWithLevel(k,w.level),M=y.getMaxDepth(w),A=h._size,S=w.domain,E=A.w*(S.x[1]-S.x[0]),L=A.h*(S.y[1]-S.y[0]),C=.5*Math.min(E,L),P=_.cx=A.l+A.w*(S.x[1]+S.x[0])/2,O=_.cy=A.t+A.h*(1-S.y[0])-L/2;if(!T)return x.remove();var z=null,I={};g&&x.each(function(t){I[y.getPtId(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!z&&y.isEntry(t)&&(z=t)});var D=function(t){return a.partition().size([2*Math.PI,t.height+1])(t)}(T).descendants(),R=T.height+1,F=0,B=M;_.hasMultipleRoots&&y.isHierarchyRoot(T)&&(D=D.slice(1),R-=1,F=1,B+=1),D=D.filter(function(t){return t.y1<=B});var N=Math.min(R,M),j=function(t){return(t-F)/N*C},V=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},U=function(t){return o.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,P,O)},q=function(t){return P+b(t)[0]*(t.transform.rCenter||0)+(t.transform.x||0)},H=function(t){return O+b(t)[1]*(t.transform.rCenter||0)+(t.transform.y||0)};(x=x.data(D,y.getPtId)).enter().append("g").classed("slice",!0),g?x.exit().transition().each(function(){var t=n.select(this);t.select("path.surface").transition().attrTween("d",function(t){var e=function(t){var e,r=y.getPtId(t),a=I[r],i=I[y.getPtId(T)];if(i){var o=t.x1>i.x1?2*Math.PI:0;e=t.rpx1<i.rpx1?{rpx0:0,rpx1:0}:{x0:o,x1:o}}else{var s,l=y.getPtId(t.parent);x.each(function(t){if(y.getPtId(t)===l)return s=t});var c,u=s.children;u.forEach(function(t,e){if(y.getPtId(t)===r)return c=e});var h=u.length,f=n.interpolate(s.x0,s.x1);e={rpx0:C,rpx1:C,x0:f(c/h),x1:f((c+1)/h)}}return n.interpolate(a,e)}(t);return function(t){return U(e(t))}}),t.select("g.slicetext").attr("opacity",0)}).remove():x.exit().remove(),x.order();var G=null;if(g&&z){var Y=y.getPtId(z);x.each(function(t){null===G&&y.getPtId(t)===Y&&(G=t.x1)})}var W=x;function X(t){var e=t.parent,r=I[y.getPtId(e)],a={};if(r){var i=e.children,o=i.indexOf(t),s=i.length,l=n.interpolate(r.x0,r.x1);a.x0=l(o/s),a.x1=l(o/s)}else a.x0=a.x1=0;return a}g&&(W=W.transition().each("end",function(){var e=n.select(this);y.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:!1})})),W.each(function(a){var l=n.select(this),u=o.ensureSingle(l,"path","surface",function(t){t.style("pointer-events","all")});a.rpx0=j(a.y0),a.rpx1=j(a.y1),a.xmid=(a.x0+a.x1)/2,a.pxmid=V(a.rpx1,a.xmid),a.midangle=-(a.xmid-Math.PI/2),a.startangle=-(a.x0-Math.PI/2),a.stopangle=-(a.x1-Math.PI/2),a.halfangle=.5*Math.min(o.angleDelta(a.x0,a.x1)||Math.PI,Math.PI),a.ring=1-a.rpx0/a.rpx1,a.rInscribed=function(t){return 0===t.rpx0&&o.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(a),g?u.transition().attrTween("d",function(t){var e=function(t){var e,r=I[y.getPtId(t)],a={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(z)if(t.parent)if(G){var i=t.x1>G?2*Math.PI:0;e={x0:i,x1:i}}else e={rpx0:C,rpx1:C},o.extendFlat(e,X(t));else e={rpx0:0,rpx1:0};else e={x0:0,x1:0};return n.interpolate(e,a)}(t);return function(t){return U(e(t))}}):u.attr("d",U),l.call(v,T,t,e,{eventDataKeys:m.eventDataKeys,transitionTime:m.CLICK_TRANSITION_TIME,transitionEasing:m.CLICK_TRANSITION_EASING}).call(y.setSliceCursor,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:t._transitioning}),u.call(d,a,w);var x=o.ensureSingle(l,"g","slicetext"),b=o.ensureSingle(x,"text","",function(t){t.attr("data-notex",1)}),k=o.ensureUniformFontSize(t,y.determineTextFont(w,a,h.font));b.text(r.formatSliceLabel(a,T,w,e,h)).classed("slicetext",!0).attr("text-anchor","middle").call(i.font,k).call(s.convertToTspans,t);var M=i.bBox(b.node());a.transform=p(M,a,_),a.transform.targetX=q(a),a.transform.targetY=H(a);var A=function(t,e){var r=t.transform;return f(r,e),r.fontSize=k.size,c(w.type,r,h),o.getTextTransform(r)};g?b.transition().attrTween("transform",function(t){var e=function(t){var e,r=I[y.getPtId(t)],a=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{textPosAngle:a.textPosAngle,scale:0,rotate:a.rotate,rCenter:a.rCenter,x:a.x,y:a.y}},z)if(t.parent)if(G){var i=t.x1>G?2*Math.PI:0;e.x0=e.x1=i}else o.extendFlat(e,X(t));else e.x0=e.x1=0;else e.x0=e.x1=0;var s=n.interpolate(e.transform.textPosAngle,t.transform.textPosAngle),l=n.interpolate(e.rpx1,t.rpx1),u=n.interpolate(e.x0,t.x0),f=n.interpolate(e.x1,t.x1),p=n.interpolate(e.transform.scale,a.scale),d=n.interpolate(e.transform.rotate,a.rotate),g=0===a.rCenter?3:0===e.transform.rCenter?1/3:1,v=n.interpolate(e.transform.rCenter,a.rCenter);return function(t){var e=l(t),r=u(t),n=f(t),i=function(t){return v(Math.pow(t,g))}(t),o=V(e,(r+n)/2),m=s(t),y={pxmid:o,rpx1:e,transform:{textPosAngle:m,rCenter:i,x:a.x,y:a.y}};return c(w.type,a,h),{transform:{targetX:q(y),targetY:H(y),scale:p(t),rotate:d(t),rCenter:i}}}}(t);return function(t){return A(e(t),M)}}):b.attr("transform",A(a,M))})}function b(t){return e=t.rpx1,r=t.transform.textPosAngle,[e*Math.sin(r),-e*Math.cos(r)];var e,r}r.plot=function(t,e,r,a){var i,o,s=t._fullLayout,l=s._sunburstlayer,c=!r,h=!s.uniformtext.mode&&y.hasTransition(r);(u("sunburst",s),(i=l.selectAll("g.trace.sunburst").data(e,function(t){return t[0].trace.uid})).enter().append("g").classed("trace",!0).classed("sunburst",!0).attr("stroke-linejoin","round"),i.order(),h)?(a&&(o=a()),n.transition().duration(r.duration).ease(r.easing).each("end",function(){o&&o()}).each("interrupt",function(){o&&o()}).each(function(){l.selectAll("g.trace").each(function(e){x(t,e,this,r)})})):(i.each(function(e){x(t,e,this,r)}),s.uniformtext.mode&&g(t,s._sunburstlayer.selectAll(".trace"),"sunburst"));c&&i.exit().remove()},r.formatSliceLabel=function(t,e,r,n,a){var i=r.texttemplate,s=r.textinfo;if(!(i||s&&"none"!==s))return"";var l=a.separators,c=n[0],u=t.data.data,h=c.hierarchy,f=y.isHierarchyRoot(t),p=y.getParent(h,t),d=y.getValue(t);if(!i){var g,v=s.split("+"),m=function(t){return-1!==v.indexOf(t)},x=[];if(m("label")&&u.label&&x.push(u.label),u.hasOwnProperty("v")&&m("value")&&x.push(y.formatValue(u.v,l)),!f){m("current path")&&x.push(y.getPath(t.data));var b=0;m("percent parent")&&b++,m("percent entry")&&b++,m("percent root")&&b++;var _=b>1;if(b){var w,k=function(t){g=y.formatPercent(w,l),_&&(g+=" of "+t),x.push(g)};m("percent parent")&&!f&&(w=d/y.getValue(p),k("parent")),m("percent entry")&&(w=d/y.getValue(e),k("entry")),m("percent root")&&(w=d/y.getValue(h),k("root"))}}return m("text")&&(g=o.castOption(r,u.i,"text"),o.isValidTextValue(g)&&x.push(g)),x.join("<br>")}var T=o.castOption(r,u.i,"texttemplate");if(!T)return"";var M={};u.label&&(M.label=u.label),u.hasOwnProperty("v")&&(M.value=u.v,M.valueLabel=y.formatValue(u.v,l)),M.currentPath=y.getPath(t.data),f||(M.percentParent=d/y.getValue(p),M.percentParentLabel=y.formatPercent(M.percentParent,l),M.parent=y.getPtLabel(p)),M.percentEntry=d/y.getValue(e),M.percentEntryLabel=y.formatPercent(M.percentEntry,l),M.entry=y.getPtLabel(e),M.percentRoot=d/y.getValue(h),M.percentRootLabel=y.formatPercent(M.percentRoot,l),M.root=y.getPtLabel(h),u.hasOwnProperty("color")&&(M.color=u.color);var A=o.castOption(r,u.i,"text");return(o.isValidTextValue(A)||""===A)&&(M.text=A),M.customdata=o.castOption(r,u.i,"customdata"),o.texttemplateString(T,M,a._d3locale,M,r._meta||{})}},{"../../components/drawing":612,"../../lib":717,"../../lib/svg_text_utils":741,"../bar/style":870,"../bar/uniform_text":872,"../pie/plot":1103,"./constants":1234,"./fx":1236,"./helpers":1237,"./style":1242,d3:165,"d3-hierarchy":159}],1242:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/color"),i=t("../../lib"),o=t("../bar/uniform_text").resizeText;function s(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=i.castOption(r,s,"marker.line.color")||a.defaultLine,c=i.castOption(r,s,"marker.line.width")||0;t.style("stroke-width",c).call(a.fill,n.color).call(a.stroke,l).style("opacity",o?r.leaf.opacity:null)}e.exports={style:function(t){var e=t._fullLayout._sunburstlayer.selectAll(".trace");o(t,e,"sunburst"),e.each(function(t){var e=n.select(this),r=t[0].trace;e.style("opacity",r.opacity),e.selectAll("path.surface").each(function(t){n.select(this).call(s,t,r)})})},styleOne:s}},{"../../components/color":591,"../../lib":717,"../bar/uniform_text":872,d3:165}],1243:[function(t,e,r){"use strict";var n=t("../../components/color"),a=t("../../components/colorscale/attributes"),i=t("../../plots/template_attributes").hovertemplateAttrs,o=t("../../plots/attributes"),s=t("../../lib/extend").extendFlat,l=t("../../plot_api/edit_types").overrideAll;function c(t){return{show:{valType:"boolean",dflt:!1},start:{valType:"number",dflt:null,editType:"plot"},end:{valType:"number",dflt:null,editType:"plot"},size:{valType:"number",dflt:null,min:0,editType:"plot"},project:{x:{valType:"boolean",dflt:!1},y:{valType:"boolean",dflt:!1},z:{valType:"boolean",dflt:!1}},color:{valType:"color",dflt:n.defaultLine},usecolormap:{valType:"boolean",dflt:!1},width:{valType:"number",min:1,max:16,dflt:2},highlight:{valType:"boolean",dflt:!0},highlightcolor:{valType:"color",dflt:n.defaultLine},highlightwidth:{valType:"number",min:1,max:16,dflt:2}}}var u=e.exports=l(s({z:{valType:"data_array"},x:{valType:"data_array"},y:{valType:"data_array"},text:{valType:"string",dflt:"",arrayOk:!0},hovertext:{valType:"string",dflt:"",arrayOk:!0},hovertemplate:i(),connectgaps:{valType:"boolean",dflt:!1,editType:"calc"},surfacecolor:{valType:"data_array"}},a("",{colorAttr:"z or surfacecolor",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:"calc"}),{contours:{x:c(),y:c(),z:c()},hidesurface:{valType:"boolean",dflt:!1},lightposition:{x:{valType:"number",min:-1e5,max:1e5,dflt:10},y:{valType:"number",min:-1e5,max:1e5,dflt:1e4},z:{valType:"number",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:"number",min:0,max:1,dflt:.8},diffuse:{valType:"number",min:0,max:1,dflt:.8},specular:{valType:"number",min:0,max:2,dflt:.05},roughness:{valType:"number",min:0,max:1,dflt:.5},fresnel:{valType:"number",min:0,max:5,dflt:.2}},opacity:{valType:"number",min:0,max:1,dflt:1},opacityscale:{valType:"any",editType:"calc"},_deprecated:{zauto:s({},a.zauto,{}),zmin:s({},a.zmin,{}),zmax:s({},a.zmax,{})},hoverinfo:s({},o.hoverinfo),showlegend:s({},o.showlegend,{dflt:!1})}),"calc","nested");u.x.editType=u.y.editType=u.z.editType="calc+clearAxisTypes",u.transforms=void 0},{"../../components/color":591,"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plot_api/edit_types":748,"../../plots/attributes":762,"../../plots/template_attributes":841}],1244:[function(t,e,r){"use strict";var n=t("../../components/colorscale/calc");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:"",cLetter:"c"}):n(t,e,{vals:e.z,containerStr:"",cLetter:"c"})}},{"../../components/colorscale/calc":599}],1245:[function(t,e,r){"use strict";var n=t("gl-surface3d"),a=t("ndarray"),i=t("ndarray-homography"),o=t("ndarray-fill"),s=t("../../lib").isArrayOrTypedArray,l=t("../../lib/gl_format_color").parseColorScale,c=t("../../lib/str2rgbarray"),u=t("../../components/colorscale").extractOpts,h=t("../heatmap/interp2d"),f=t("../heatmap/find_empties");function p(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var d=p.prototype;d.getXat=function(t,e,r,n){var a=s(this.data.x)?s(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?a:n.d2l(a,0,r)},d.getYat=function(t,e,r,n){var a=s(this.data.y)?s(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?a:n.d2l(a,0,r)},d.getZat=function(t,e,r,n){var a=this.data.z[e][t];return null===a&&this.data.connectgaps&&this.data._interpolatedZ&&(a=this.data._interpolatedZ[e][t]),void 0===r?a:n.d2l(a,0,r)},d.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),a=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,a],t.traceCoordinate=[this.getXat(n,a),this.getYat(n,a),this.getZat(n,a)],t.dataCoordinate=[this.getXat(n,a,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,a,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,a,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var i=0;i<3;i++){var o=t.dataCoordinate[i];null!=o&&(t.dataCoordinate[i]*=this.scene.dataScale[i])}var s=this.data.hovertext||this.data.text;return Array.isArray(s)&&s[a]&&void 0!==s[a][n]?t.textLabel=s[a][n]:t.textLabel=s||"",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var g=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function v(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function m(t){for(var e=[],r=0;r<g.length;r++){var n=g[r];e.push(v(t,n))}return e}function y(t){for(var e=m(t),r=t,n=0;n<g.length;n++)if(e[n]>0){r=g[n];break}return r}function x(t,e){if(!(t<1||e<1)){for(var r=m(t),n=m(e),a=1,i=0;i<g.length;i++)a*=Math.pow(g[i],Math.max(r[i],n[i]));return a}}d.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),a=this.getXat(e,0);r[e-1]=a!==n&&null!=n&&null!=a?Math.abs(a-n):0}var i=0;for(e=1;e<t;e++)i+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(i/r[e-1]);return r},d.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),a=this.getYat(0,e);r[e-1]=a!==n&&null!=n&&null!=a?Math.abs(a-n):0}var i=0;for(e=1;e<t;e++)i+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(i/r[e-1]);return r};var b=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],_=b[9],w=b[13];function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}d.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=x(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<_;)r*=2;for(;r>w;)r--,r/=y(r),++r<_&&(r=w);var n=Math.round(r/t);return n>1?n:1},d.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],o=t[0].shape[1],s=0|Math.floor(t[0].shape[0]*e+1),l=0|Math.floor(t[0].shape[1]*r+1),c=1+n+1,u=1+o+1,h=a(new Float32Array(c*u),[c,u]),f=0;f<t.length;++f){this.surface.padField(h,t[f]);var p=a(new Float32Array(s*l),[s,l]);i(p,h,[e,0,0,0,r,0,0,0,1]),t[f]=p}},d.setContourLevels=function(){var t,e,r,n=[[],[],[]],a=[!1,!1,!1],i=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(i=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(a[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(i){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=a[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},d.update=function(t){var e,r,n,i,s=this.scene,p=s.fullSceneLayout,d=this.surface,g=t.opacity,v=l(t,g),m=s.dataScale,y=t.z[0].length,x=t._ylength,b=s.contourLevels;this.data=t;var _=[];for(e=0;e<3;e++)for(_[e]=[],r=0;r<y;r++)_[e][r]=[];for(r=0;r<y;r++)for(n=0;n<x;n++)_[0][r][n]=this.getXat(r,n,t.xcalendar,p.xaxis),_[1][r][n]=this.getYat(r,n,t.ycalendar,p.yaxis),_[2][r][n]=this.getZat(r,n,t.zcalendar,p.zaxis);if(t.connectgaps)for(t._emptypoints=f(_[2]),h(_[2],t._emptypoints),t._interpolatedZ=[],r=0;r<y;r++)for(t._interpolatedZ[r]=[],n=0;n<x;n++)t._interpolatedZ[r][n]=_[2][r][n];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null==(i=_[e][r][n])?_[e][r][n]=NaN:i=_[e][r][n]*=m[e];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(i=_[e][r][n])&&(this.minValues[e]>i&&(this.minValues[e]=i),this.maxValues[e]<i&&(this.maxValues[e]=i));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(i=_[e][r][n])&&(_[e][r][n]-=this.objectOffset[e]);var k=[a(new Float32Array(y*x),[y,x]),a(new Float32Array(y*x),[y,x]),a(new Float32Array(y*x),[y,x])];o(k[0],function(t,e){return _[0][t][e]}),o(k[1],function(t,e){return _[1][t][e]}),o(k[2],function(t,e){return _[2][t][e]}),_=[];var T={colormap:v,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacityscale:t.opacityscale,opacity:t.opacity},M=u(t);if(T.intensityBounds=[M.min,M.max],t.surfacecolor){var A=a(new Float32Array(y*x),[y,x]);o(A,function(e,r){return t.surfacecolor[r][e]}),k.push(A)}else T.intensityBounds[0]*=m[2],T.intensityBounds[1]*=m[2];(w<k[0].shape[0]||w<k[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(k[0].shape[0],0),this.dataScaleY=this.estimateScale(k[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(k)),t.surfacecolor&&(T.intensity=k.pop());var S=[!0,!0,!0],E=["x","y","z"];for(e=0;e<3;++e){var L=t.contours[E[e]];S[e]=L.highlight,T.showContour[e]=L.show||L.highlight,T.showContour[e]&&(T.contourProject[e]=[L.project.x,L.project.y,L.project.z],L.show?(this.showContour[e]=!0,T.levels[e]=b[e],d.highlightColor[e]=T.contourColor[e]=c(L.color),L.usecolormap?d.highlightTint[e]=T.contourTint[e]=0:d.highlightTint[e]=T.contourTint[e]=1,T.contourWidth[e]=L.width,this.contourStart[e]=L.start,this.contourEnd[e]=L.end,this.contourSize[e]=L.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),L.highlight&&(T.dynamicColor[e]=c(L.highlightcolor),T.dynamicWidth[e]=L.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(v)&&(T.vertexColor=!0),T.objectOffset=this.objectOffset,T.coords=k,d.update(T),d.visible=t.visible,d.enableDynamic=S,d.enableHighlight=S,d.snapToData=!0,"lighting"in t&&(d.ambientLight=t.lighting.ambient,d.diffuseLight=t.lighting.diffuse,d.specularLight=t.lighting.specular,d.roughness=t.lighting.roughness,d.fresnel=t.lighting.fresnel),"lightposition"in t&&(d.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z]),g&&g<1&&(d.supportsTransparency=!0)},d.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,a=n({gl:r}),i=new p(t,a,e.uid);return a._trace=i,i.update(e),t.glplot.add(a),i}},{"../../components/colorscale":603,"../../lib":717,"../../lib/gl_format_color":714,"../../lib/str2rgbarray":740,"../heatmap/find_empties":1006,"../heatmap/interp2d":1009,"gl-surface3d":318,ndarray:451,"ndarray-fill":441,"ndarray-homography":443}],1246:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("../../components/colorscale/defaults"),o=t("./attributes"),s=.1;function l(t,e,r,n){var a=n("opacityscale");"max"===a?e.opacityscale=[[0,s],[1,1]]:"min"===a?e.opacityscale=[[0,1],[1,s]]:"extremes"===a?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var a=n/31,i=e+(1-e)*(1-Math.pow(Math.sin(t*a*Math.PI),2));r.push([a,Math.max(1,Math.min(0,i))])}return r}(1,s):function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(a)||(e.opacityscale=void 0)}function c(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports={supplyDefaults:function(t,e,r,s){var u,h;function f(r,n){return a.coerce(t,e,o,r,n)}var p=f("x"),d=f("y"),g=f("z");if(!g||!g.length||p&&p.length<1||d&&d.length<1)e.visible=!1;else{e._xlength=Array.isArray(p)&&a.isArrayOrTypedArray(p[0])?g.length:g[0].length,e._ylength=g.length,n.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x","y","z"],s),f("text"),f("hovertext"),f("hovertemplate"),["lighting.ambient","lighting.diffuse","lighting.specular","lighting.roughness","lighting.fresnel","lightposition.x","lightposition.y","lightposition.z","hidesurface","connectgaps","opacity"].forEach(function(t){f(t)});var v=f("surfacecolor"),m=["x","y","z"];for(u=0;u<3;++u){var y="contours."+m[u],x=f(y+".show"),b=f(y+".highlight");if(x||b)for(h=0;h<3;++h)f(y+".project."+m[h]);x&&(f(y+".color"),f(y+".width"),f(y+".usecolormap")),b&&(f(y+".highlightcolor"),f(y+".highlightwidth")),f(y+".start"),f(y+".end"),f(y+".size")}v||(c(t,"zmin","cmin"),c(t,"zmax","cmax"),c(t,"zauto","cauto")),i(t,e,s,f,{prefix:"",cLetter:"c"}),l(0,e,0,f),e._length=null}},opacityscaleDefaults:l}},{"../../components/colorscale/defaults":601,"../../lib":717,"../../registry":846,"./attributes":1243}],1247:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults").supplyDefaults,colorbar:{min:"cmin",max:"cmax"},calc:t("./calc"),plot:t("./convert"),moduleType:"trace",name:"surface",basePlotModule:t("../../plots/gl3d"),categories:["gl3d","2dMap","showLegend"],meta:{}}},{"../../plots/gl3d":805,"./attributes":1243,"./calc":1244,"./convert":1245,"./defaults":1246}],1248:[function(t,e,r){"use strict";var n=t("../../components/annotations/attributes"),a=t("../../lib/extend").extendFlat,i=t("../../plot_api/edit_types").overrideAll,o=t("../../plots/font_attributes"),s=t("../../plots/domain").attributes;t("../../constants/docs").FORMAT_LINK;(e.exports=i({domain:s({name:"table",trace:!0}),columnwidth:{valType:"number",arrayOk:!0,dflt:null},columnorder:{valType:"data_array"},header:{values:{valType:"data_array",dflt:[]},format:{valType:"data_array",dflt:[]},prefix:{valType:"string",arrayOk:!0,dflt:null},suffix:{valType:"string",arrayOk:!0,dflt:null},height:{valType:"number",dflt:28},align:a({},n.align,{arrayOk:!0}),line:{width:{valType:"number",arrayOk:!0,dflt:1},color:{valType:"color",arrayOk:!0,dflt:"grey"}},fill:{color:{valType:"color",arrayOk:!0,dflt:"white"}},font:a({},o({arrayOk:!0}))},cells:{values:{valType:"data_array",dflt:[]},format:{valType:"data_array",dflt:[]},prefix:{valType:"string",arrayOk:!0,dflt:null},suffix:{valType:"string",arrayOk:!0,dflt:null},height:{valType:"number",dflt:20},align:a({},n.align,{arrayOk:!0}),line:{width:{valType:"number",arrayOk:!0,dflt:1},color:{valType:"color",arrayOk:!0,dflt:"grey"}},fill:{color:{valType:"color",arrayOk:!0,dflt:"white"}},font:a({},o({arrayOk:!0}))}},"calc","from-root")).transforms=void 0},{"../../components/annotations/attributes":574,"../../constants/docs":688,"../../lib/extend":708,"../../plot_api/edit_types":748,"../../plots/domain":790,"../../plots/font_attributes":791}],1249:[function(t,e,r){"use strict";var n=t("../../plots/get_data").getModuleCalcData,a=t("./plot");r.name="table",r.plot=function(t){var e=n(t.calcdata,"table")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var a=n._has&&n._has("table"),i=e._has&&e._has("table");a&&!i&&n._paperdiv.selectAll(".table").remove()}},{"../../plots/get_data":800,"./plot":1256}],1250:[function(t,e,r){"use strict";var n=t("../../lib/gup").wrap;e.exports=function(){return n({})}},{"../../lib/gup":715}],1251:[function(t,e,r){"use strict";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\$.*\$$/,goldenRatio:1.618,lineBreaker:"<br>",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:"cubic-out",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:"cubic-out",uplift:5,wrapSpacer:" ",wrapSplitCharacter:" ",cn:{table:"table",tableControlView:"table-control-view",scrollBackground:"scroll-background",yColumn:"y-column",columnBlock:"column-block",scrollAreaClip:"scroll-area-clip",scrollAreaClipRect:"scroll-area-clip-rect",columnBoundary:"column-boundary",columnBoundaryClippath:"column-boundary-clippath",columnBoundaryRect:"column-boundary-rect",columnCells:"column-cells",columnCell:"column-cell",cellRect:"cell-rect",cellText:"cell-text",cellTextHolder:"cell-text-holder",scrollbarKit:"scrollbar-kit",scrollbar:"scrollbar",scrollbarSlider:"scrollbar-slider",scrollbarGlyph:"scrollbar-glyph",scrollbarCaptureZone:"scrollbar-capture-zone"}}},{}],1252:[function(t,e,r){"use strict";var n=t("./constants"),a=t("../../lib/extend").extendFlat,i=t("fast-isnumeric");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,a=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),a=Math.max(a,r[e].length);if(n!==a)for(e=0;e<r.length;e++){var i=a-r[e].length;i&&(r[e]=r[e].concat(c(i)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]="";return e}function u(t){return t.calcdata.columns.reduce(function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e},0)}function h(t,e){return Object.keys(t).map(function(r){return a({},t[r],{auxiliaryBlocks:e})})}function f(t,e){for(var r,n={},a=0,i=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((i+=r)>=e||c===t.length-1)&&(n[a]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},a+=i,s=c+1,i=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[""],d=l(d));var g=d.concat(p(r).map(function(){return c((d[0]||[""]).length)})),v=e.domain,m=Math.floor(t._fullLayout._size.w*(v.x[1]-v.x[0])),y=Math.floor(t._fullLayout._size.h*(v.y[1]-v.y[0])),x=e.header.values.length?g[0].map(function(){return e.header.height}):[n.emptyHeaderHeight],b=r.length?r[0].map(function(){return e.cells.height}):[],_=x.reduce(s,0),w=f(b,y-_+n.uplift),k=h(f(x,_),[]),T=h(w,k),M={},A=e._fullInput.columnorder.concat(p(r.map(function(t,e){return e}))),S=g.map(function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return i(n)?Number(n):1}),E=S.reduce(s,0);S=S.map(function(t){return t/E*m});var L=Math.max(o(e.header.line.width),o(e.cells.line.width)),C={key:e.uid+t._context.staticPlot,translateX:v.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-v.y[1]),size:t._fullLayout._size,width:m,maxLineWidth:L,height:y,columnOrder:A,groupHeight:y,rowBlocks:T,headerRowBlocks:k,scrollY:0,cells:a({},e.cells,{values:r}),headerCells:a({},e.header,{values:g}),gdColumns:g.map(function(t){return t[0]}),gdColumnsOriginalOrder:g.map(function(t){return t[0]}),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map(function(t,e){var r=M[t];return M[t]=(r||0)+1,{key:t+"__"+M[t],label:t,specIndex:e,xIndex:A[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}})};return C.columns.forEach(function(t){t.calcdata=C,t.x=u(t)}),C}},{"../../lib/extend":708,"./constants":1251,"fast-isnumeric":228}],1253:[function(t,e,r){"use strict";var n=t("../../lib/extend").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:"header",type:"header",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:"cells1",type:"cells",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:"cells2",type:"cells",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map(function(r,n){return{keyWithinBlock:n+("string"==typeof r&&r.match(/[<$&> ]/)?"_keybuster_"+Math.random():""),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}})}},{"../../lib/extend":708}],1254:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("../../plots/domain").defaults;e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}i(e,o,s),s("columnwidth"),s("header.values"),s("header.format"),s("header.align"),s("header.prefix"),s("header.suffix"),s("header.height"),s("header.line.width"),s("header.line.color"),s("header.fill.color"),n.coerceFont(s,"header.font",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,a=r.slice(0,n),i=a.slice().sort(function(t,e){return t-e}),o=a.map(function(t){return i.indexOf(t)}),s=o.length;s<n;s++)o.push(s);e("columnorder",o)}(e,s),s("cells.values"),s("cells.format"),s("cells.align"),s("cells.prefix"),s("cells.suffix"),s("cells.height"),s("cells.line.width"),s("cells.line.color"),s("cells.fill.color"),n.coerceFont(s,"cells.font",n.extendFlat({},o.font)),e._length=null}},{"../../lib":717,"../../plots/domain":790,"./attributes":1248}],1255:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc"),plot:t("./plot"),moduleType:"trace",name:"table",basePlotModule:t("./base_plot"),categories:["noOpacity"],meta:{}}},{"./attributes":1248,"./base_plot":1249,"./calc":1250,"./defaults":1254,"./plot":1256}],1256:[function(t,e,r){"use strict";var n=t("./constants"),a=t("d3"),i=t("../../lib/gup"),o=t("../../components/drawing"),s=t("../../lib/svg_text_utils"),l=t("../../lib").raiseToTop,c=t("../../lib").cancelTransition,u=t("./data_preparation_helper"),h=t("./data_split_helpers"),f=t("../../components/color");function p(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function d(t,e){return"clip"+t._fullLayout._uid+"_scrollAreaBottomClip_"+e.key}function g(t,e){return"clip"+t._fullLayout._uid+"_columnBoundaryClippath_"+e.calcdata.key+"_"+e.specIndex}function v(t){return[].concat.apply([],t.map(function(t){return t})).map(function(t){return t.__data__})}function m(t,e,r){var o=t.selectAll("."+n.cn.scrollbarKit).data(i.repeat,i.keyFun);o.enter().append("g").classed(n.cn.scrollbarKit,!0).style("shape-rendering","geometricPrecision"),o.each(function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return z(e,e.length-1)+(e.length?I(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-M(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom}).attr("transform",function(t){return"translate("+(t.width+n.scrollbarWidth/2+n.scrollbarOffset)+" "+M(t)+")"});var s=o.selectAll("."+n.cn.scrollbar).data(i.repeat,i.keyFun);s.enter().append("g").classed(n.cn.scrollbar,!0);var l=s.selectAll("."+n.cn.scrollbarSlider).data(i.repeat,i.keyFun);l.enter().append("g").classed(n.cn.scrollbarSlider,!0),l.attr("transform",function(t){return"translate(0 "+(t.scrollbarState.topY||0)+")"});var c=l.selectAll("."+n.cn.scrollbarGlyph).data(i.repeat,i.keyFun);c.enter().append("line").classed(n.cn.scrollbarGlyph,!0).attr("stroke","black").attr("stroke-width",n.scrollbarWidth).attr("stroke-linecap","round").attr("y1",n.scrollbarWidth/2),c.attr("y2",function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2}).attr("stroke-opacity",function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4}),c.transition().delay(0).duration(0),c.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr("stroke-opacity",0);var u=s.selectAll("."+n.cn.scrollbarCaptureZone).data(i.repeat,i.keyFun);u.enter().append("line").classed(n.cn.scrollbarCaptureZone,!0).attr("stroke","white").attr("stroke-opacity",.01).attr("stroke-width",n.scrollbarCaptureWidth).attr("stroke-linecap","butt").attr("y1",0).on("mousedown",function(r){var n=a.event.y,i=this.getBoundingClientRect(),o=r.scrollbarState,s=n-i.top,l=a.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||S(e,t,null,l(s-o.barLength/2))(r)}).call(a.behavior.drag().origin(function(t){return a.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t}).on("drag",S(e,t)).on("dragend",function(){})),u.attr("y2",function(t){return t.scrollbarState.scrollableAreaHeight}),e._context.staticPlot&&(c.remove(),u.remove())}function y(t,e,r,s){var l=function(t){var e=t.selectAll("."+n.cn.columnCell).data(h.splitToCells,function(t){return t.keyWithinBlock});return e.enter().append("g").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll("."+n.cn.columnCells).data(i.repeat,i.keyFun);return e.enter().append("g").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each(function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,a={size:_(r.size,n,e),color:_(r.color,n,e),family:_(r.family,n,e)};t.rowNumber=t.key,t.align=_(t.calcdata.cells.align,n,e),t.cellBorderWidth=_(t.calcdata.cells.line.width,n,e),t.font=a})}(l),function(t){t.attr("width",function(t){return t.column.columnWidth}).attr("stroke-width",function(t){return t.cellBorderWidth}).each(function(t){var e=a.select(this);f.stroke(e,_(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),f.fill(e,_(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))})}(function(t){var e=t.selectAll("."+n.cn.cellRect).data(i.repeat,function(t){return t.keyWithinBlock});return e.enter().append("rect").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll("."+n.cn.cellText).data(i.repeat,function(t){return t.keyWithinBlock});return e.enter().append("text").classed(n.cn.cellText,!0).style("cursor",function(){return"auto"}).on("mousedown",function(){a.event.stopPropagation()}),e}(function(t){var e=t.selectAll("."+n.cn.cellTextHolder).data(i.repeat,function(t){return t.keyWithinBlock});return e.enter().append("g").classed(n.cn.cellTextHolder,!0).style("shape-rendering","geometricPrecision"),e}(l));!function(t){t.each(function(t){o.font(a.select(this),t.font)})}(c),x(c,e,s,t),O(l)}function x(t,e,r,i){t.text(function(t){var e=t.column.specIndex,r=t.rowNumber,i=t.value,o="string"==typeof i,s=o&&i.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&i.match(/[<&>]/);var c,u="string"==typeof(c=i)&&c.match(n.latexCheck);t.latex=u;var h,f,p=u?"":_(t.calcdata.cells.prefix,e,r)||"",d=u?"":_(t.calcdata.cells.suffix,e,r)||"",g=u?null:_(t.calcdata.cells.format,e,r)||null,v=p+(g?a.format(g)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(h=b(v)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===h?b(v):h),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var m=(" "===n.wrapSplitCharacter?v.replace(/<a href=/gi,"<a_href="):v).split(n.wrapSplitCharacter),y=" "===n.wrapSplitCharacter?m.map(function(t){return t.replace(/<a_href=/gi,"<a href=")}):m;t.fragments=y.map(function(t){return{text:t,width:null}}),t.fragments.push({fragment:n.wrapSpacer,width:null}),f=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,f=v;return f}).attr("dy",function(t){return t.needsConvertToTspans?0:"0.75em"}).each(function(t){var o=a.select(this),l=t.wrappingNeeded?L:C;t.needsConvertToTspans?s.convertToTspans(o,i,l(r,this,e,i,t)):a.select(this.parentNode).attr("transform",function(t){return"translate("+P(t)+" "+n.cellPad+")"}).attr("text-anchor",function(t){return{left:"start",center:"middle",right:"end"}[t.align]})})}function b(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function _(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function w(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr("transform","translate("+e.x+" "+r+")")}function k(t){return"cells"===t.type}function T(t){return"header"===t.type}function M(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce(function(t,e){return t+I(e,1/0)},0)}function A(t,e,r){var n=v(e)[0];if(void 0!==n){var a=n.rowBlocks,i=n.calcdata,o=z(a,a.length),s=n.calcdata.groupHeight-M(n),l=i.scrollY=Math.max(0,Math.min(o-s,i.scrollY)),c=function(t,e,r){for(var n=[],a=0,i=0;i<t.length;i++){for(var o=t[i],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l,e<a+l&&e+r>a&&n.push(i),a+=l}return n}(a,l,s);1===c.length&&(c[0]===a.length-1?c.unshift(c[0]-1):c.push(c[0]+1)),c[0]%2&&c.reverse(),e.each(function(t,e){t.page=c[e],t.scrollY=l}),e.attr("transform",function(t){return"translate(0 "+(z(t.rowBlocks,t.page)-t.scrollY)+")"}),t&&(E(t,r,e,c,n.prevPages,n,0),E(t,r,e,c,n.prevPages,n,1),m(r,t))}}function S(t,e,r,i){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter(function(t){return s.key===t.key}),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===i?s.scrollY+c*a.event.dy:i;var h=l.selectAll("."+n.cn.yColumn).selectAll("."+n.cn.columnBlock).filter(k);return A(t,h,l),s.scrollY===u}}function E(t,e,r,n,a,i,o){n[o]!==a[o]&&(clearTimeout(i.currentRepaint[o]),i.currentRepaint[o]=setTimeout(function(){var i=r.filter(function(t,e){return e===o&&n[e]!==a[e]});y(t,e,i,r),a[o]=n[o]}))}function L(t,e,r,i){return function(){var o=a.select(e.parentNode);o.each(function(t){var e=t.fragments;o.selectAll("tspan.line").each(function(t,r){e[r].width=this.getComputedTextLength()});var r,a,i=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value="";s.length;)c+(a=(r=s.shift()).width+i)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=a;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0}),o.selectAll("tspan.line").remove(),x(o.select("."+n.cn.cellText),r,t,i),a.select(e.parentNode.parentNode).call(O)}}function C(t,e,r,i,o){return function(){if(!o.settledY){var s=a.select(e.parentNode),l=R(o),c=o.key-l.firstRowIndex,u=l.rows[c].rowHeight,h=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:u,f=Math.max(h,u);f-l.rows[c].rowHeight&&(l.rows[c].rowHeight=f,t.selectAll("."+n.cn.columnCell).call(O),A(null,t.filter(k),0),m(r,i,!0)),s.attr("transform",function(){var t=this.parentNode.getBoundingClientRect(),e=a.select(this.parentNode).select("."+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),i=e.top-t.top+(r?r.matrix.f:n.cellPad);return"translate("+P(o,a.select(this.parentNode).select("."+n.cn.cellTextHolder).node().getBoundingClientRect().width)+" "+i+")"}),o.settledY=!0}}}function P(t,e){switch(t.align){case"left":return n.cellPad;case"right":return t.column.columnWidth-(e||0)-n.cellPad;case"center":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function O(t){t.attr("transform",function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce(function(t,e){return t+I(e,1/0)},0);return"translate(0 "+(I(R(t),t.key)+e)+")"}).selectAll("."+n.cn.cellRect).attr("height",function(t){return(e=R(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r})}function z(t,e){for(var r=0,n=e-1;n>=0;n--)r+=D(t[n]);return r}function I(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function D(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function R(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll("."+n.cn.table).data(e.map(function(e){var r=i.unwrap(e).trace;return u(t,r)}),i.keyFun);s.exit().remove(),s.enter().append("g").classed(n.cn.table,!0).attr("overflow","visible").style("box-sizing","content-box").style("position","absolute").style("left",0).style("overflow","visible").style("shape-rendering","crispEdges").style("pointer-events","all"),s.attr("width",function(t){return t.width+t.size.l+t.size.r}).attr("height",function(t){return t.height+t.size.t+t.size.b}).attr("transform",function(t){return"translate("+t.translateX+","+t.translateY+")"});var f=s.selectAll("."+n.cn.tableControlView).data(i.repeat,i.keyFun),x=f.enter().append("g").classed(n.cn.tableControlView,!0).style("box-sizing","content-box");r&&x.on("mousemove",function(e){f.filter(function(t){return e===t}).call(m,t)}).on("mousewheel",function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+a.event.deltaY;S(t,f,null,r)(e)||(a.event.stopPropagation(),a.event.preventDefault()),e.scrollbarState.wheeling=!1}}).call(m,t,!0),f.attr("transform",function(t){return"translate("+t.size.l+" "+t.size.t+")"});var b=f.selectAll("."+n.cn.scrollBackground).data(i.repeat,i.keyFun);b.enter().append("rect").classed(n.cn.scrollBackground,!0).attr("fill","none"),b.attr("width",function(t){return t.width}).attr("height",function(t){return t.height}),f.each(function(e){o.setClipUrl(a.select(this),d(t,e),t)});var _=f.selectAll("."+n.cn.yColumn).data(function(t){return t.columns},i.keyFun);_.enter().append("g").classed(n.cn.yColumn,!0),_.exit().remove(),_.attr("transform",function(t){return"translate("+t.x+" 0)"}),r&&_.call(a.behavior.drag().origin(function(e){return w(a.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,m(f.filter(function(t){return e.calcdata.key===t.key}),t),e}).on("drag",function(t){var e=a.select(this),r=function(e){return(t===e?a.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,a.event.x)),v(_).filter(function(e){return e.calcdata.key===t.calcdata.key}).sort(function(t,e){return r(t)-r(e)}).forEach(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)}),_.filter(function(e){return t!==e}).transition().ease(n.transitionEase).duration(n.transitionDuration).attr("transform",function(t){return"translate("+t.x+" 0)"}),e.call(c).attr("transform","translate("+t.x+" -"+n.uplift+" )")}).on("dragend",function(e){var r=a.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,w(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort(function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]}),e.columnorder=r,t.emit("plotly_restyle")}(t,n,n.columns.map(function(t){return t.xIndex}))})),_.each(function(e){o.setClipUrl(a.select(this),g(t,e),t)});var M=_.selectAll("."+n.cn.columnBlock).data(h.splitToPanels,i.keyFun);M.enter().append("g").classed(n.cn.columnBlock,!0).attr("id",function(t){return t.key}),M.style("cursor",function(t){return t.dragHandle?"ew-resize":t.calcdata.scrollbarState.barWiggleRoom?"ns-resize":"default"});var E=M.filter(T),L=M.filter(k);r&&L.call(a.behavior.drag().origin(function(t){return a.event.stopPropagation(),t}).on("drag",S(t,f,-1)).on("dragend",function(){})),y(t,f,E,M),y(t,f,L,M);var C=f.selectAll("."+n.cn.scrollAreaClip).data(i.repeat,i.keyFun);C.enter().append("clipPath").classed(n.cn.scrollAreaClip,!0).attr("id",function(e){return d(t,e)});var P=C.selectAll("."+n.cn.scrollAreaClipRect).data(i.repeat,i.keyFun);P.enter().append("rect").classed(n.cn.scrollAreaClipRect,!0).attr("x",-n.overdrag).attr("y",-n.uplift).attr("fill","none"),P.attr("width",function(t){return t.width+2*n.overdrag}).attr("height",function(t){return t.height+n.uplift}),_.selectAll("."+n.cn.columnBoundary).data(i.repeat,i.keyFun).enter().append("g").classed(n.cn.columnBoundary,!0);var O=_.selectAll("."+n.cn.columnBoundaryClippath).data(i.repeat,i.keyFun);O.enter().append("clipPath").classed(n.cn.columnBoundaryClippath,!0),O.attr("id",function(e){return g(t,e)});var z=O.selectAll("."+n.cn.columnBoundaryRect).data(i.repeat,i.keyFun);z.enter().append("rect").classed(n.cn.columnBoundaryRect,!0).attr("fill","none"),z.attr("width",function(t){return t.columnWidth+2*p(t)}).attr("height",function(t){return t.calcdata.height+2*p(t)+n.uplift}).attr("x",function(t){return-p(t)}).attr("y",function(t){return-p(t)}),A(null,L,f)}},{"../../components/color":591,"../../components/drawing":612,"../../lib":717,"../../lib/gup":715,"../../lib/svg_text_utils":741,"./constants":1251,"./data_preparation_helper":1252,"./data_split_helpers":1253,d3:165}],1257:[function(t,e,r){"use strict";var n=t("../../plots/template_attributes").hovertemplateAttrs,a=t("../../plots/template_attributes").texttemplateAttrs,i=t("../../components/colorscale/attributes"),o=t("../../plots/domain").attributes,s=t("../pie/attributes"),l=t("../sunburst/attributes"),c=t("./constants"),u=t("../../lib/extend").extendFlat;e.exports={labels:l.labels,parents:l.parents,values:l.values,branchvalues:l.branchvalues,count:l.count,level:l.level,maxdepth:l.maxdepth,tiling:{packing:{valType:"enumerated",values:["squarify","binary","dice","slice","slice-dice","dice-slice"],dflt:"squarify",editType:"plot"},squarifyratio:{valType:"number",min:1,dflt:1,editType:"plot"},flip:{valType:"flaglist",flags:["x","y"],dflt:"",editType:"plot"},pad:{valType:"number",min:0,dflt:3,editType:"plot"},editType:"calc"},marker:u({pad:{t:{valType:"number",min:0,editType:"plot"},l:{valType:"number",min:0,editType:"plot"},r:{valType:"number",min:0,editType:"plot"},b:{valType:"number",min:0,editType:"plot"},editType:"calc"},colors:l.marker.colors,depthfade:{valType:"enumerated",values:[!0,!1,"reversed"],editType:"style"},line:l.marker.line,editType:"calc"},i("marker",{colorAttr:"colors",anim:!1})),pathbar:{visible:{valType:"boolean",dflt:!0,editType:"plot"},side:{valType:"enumerated",values:["top","bottom"],dflt:"top",editType:"plot"},edgeshape:{valType:"enumerated",values:[">","<","|","/","\\"],dflt:">",editType:"plot"},thickness:{valType:"number",min:12,editType:"plot"},textfont:u({},s.textfont,{}),editType:"calc"},text:s.text,textinfo:l.textinfo,texttemplate:a({editType:"plot"},{keys:c.eventDataKeys.concat(["label","value"])}),hovertext:s.hovertext,hoverinfo:l.hoverinfo,hovertemplate:n({},{keys:c.eventDataKeys}),textfont:s.textfont,insidetextfont:s.insidetextfont,outsidetextfont:u({},s.outsidetextfont,{}),textposition:{valType:"enumerated",values:["top left","top center","top right","middle left","middle center","middle right","bottom left","bottom center","bottom right"],dflt:"top left",editType:"plot"},domain:o({name:"treemap",trace:!0,editType:"calc"})}},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plots/domain":790,"../../plots/template_attributes":841,"../pie/attributes":1094,"../sunburst/attributes":1231,"./constants":1260}],1258:[function(t,e,r){"use strict";var n=t("../../plots/plots");r.name="treemap",r.plot=function(t,e,a,i){n.plotBasePlot(r.name,t,e,a,i)},r.clean=function(t,e,a,i){n.cleanBasePlot(r.name,t,e,a,i)}},{"../../plots/plots":826}],1259:[function(t,e,r){"use strict";var n=t("../sunburst/calc");r.calc=function(t,e){return n.calc(t,e)},r.crossTraceCalc=function(t){return n._runCrossTraceCalc("treemap",t)}},{"../sunburst/calc":1233}],1260:[function(t,e,r){"use strict";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:"poly",eventDataKeys:["currentPath","root","entry","percentRoot","percentEntry","percentParent"],gapWithPathbar:1}},{}],1261:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("../../components/color"),o=t("../../plots/domain").defaults,s=t("../bar/defaults").handleText,l=t("../bar/constants").TEXTPAD,c=t("../../components/colorscale"),u=c.hasColorscale,h=c.handleDefaults;e.exports=function(t,e,r,c){function f(r,i){return n.coerce(t,e,a,r,i)}var p=f("labels"),d=f("parents");if(p&&p.length&&d&&d.length){var g=f("values");g&&g.length?f("branchvalues"):f("count"),f("level"),f("maxdepth"),"squarify"===f("tiling.packing")&&f("tiling.squarifyratio"),f("tiling.flip"),f("tiling.pad");var v=f("text");f("texttemplate"),e.texttemplate||f("textinfo",Array.isArray(v)?"text+label":"label"),f("hovertext"),f("hovertemplate");var m=f("pathbar.visible");s(t,e,c,f,"auto",{hasPathbar:m,moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),f("textposition");var y=-1!==e.textposition.indexOf("bottom");f("marker.line.width")&&f("marker.line.color",c.paper_bgcolor);var x=f("marker.colors"),b=e._hasColorscale=u(t,"marker","colors")||(t.marker||{}).coloraxis;b?h(t,e,c,f,{prefix:"marker.",cLetter:"c"}):f("marker.depthfade",!(x||[]).length);var _=2*e.textfont.size;f("marker.pad.t",y?_/4:_),f("marker.pad.l",_/4),f("marker.pad.r",_/4),f("marker.pad.b",y?_:_/4),b&&h(t,e,c,f,{prefix:"marker.",cLetter:"c"}),e._hovered={marker:{line:{width:2,color:i.contrast(c.paper_bgcolor)}}},m&&(f("pathbar.thickness",e.pathbar.textfont.size+2*l),f("pathbar.side"),f("pathbar.edgeshape")),o(e,c,f),e._length=null}else e.visible=!1}},{"../../components/color":591,"../../components/colorscale":603,"../../lib":717,"../../plots/domain":790,"../bar/constants":858,"../bar/defaults":860,"./attributes":1257}],1262:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../components/drawing"),o=t("../../lib/svg_text_utils"),s=t("./partition"),l=t("./style").styleOne,c=t("./constants"),u=t("../sunburst/helpers"),h=t("../sunburst/fx");e.exports=function(t,e,r,f,p){var d=p.barDifY,g=p.width,v=p.height,m=p.viewX,y=p.viewY,x=p.pathSlice,b=p.toMoveInsideSlice,_=p.strTransform,w=p.hasTransition,k=p.handleSlicesExit,T=p.makeUpdateSliceInterpolator,M=p.makeUpdateTextInterpolator,A={},S=t._fullLayout,E=e[0],L=E.trace,C=E.hierarchy,P=g/L._entryDepth,O=u.listPath(r.data,"id"),z=s(C.copy(),[g,v],{packing:"dice",pad:{inner:0,top:0,left:0,right:0,bottom:0}}).descendants();(z=z.filter(function(t){var e=O.indexOf(t.data.id);return-1!==e&&(t.x0=P*e,t.x1=P*(e+1),t.y0=d,t.y1=d+v,t.onPathbar=!0,!0)})).reverse(),(f=f.data(z,u.getPtId)).enter().append("g").classed("pathbar",!0),k(f,!0,A,[g,v],x),f.order();var I=f;w&&(I=I.transition().each("end",function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:!1})})),I.each(function(s){s._hoverX=m(s.x1-Math.min(g,v)/2),s._hoverY=y(s.y1-v/2);var f=n.select(this),p=a.ensureSingle(f,"path","surface",function(t){t.style("pointer-events","all")});w?p.transition().attrTween("d",function(t){var e=T(t,!0,A,[g,v]);return function(t){return x(e(t))}}):p.attr("d",x),f.call(h,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:t._transitioning}),p.call(l,s,L,{hovered:!1}),s._text=(u.getPtLabel(s)||"").split("<br>").join(" ")||"";var d=a.ensureSingle(f,"g","slicetext"),k=a.ensureSingle(d,"text","",function(t){t.attr("data-notex",1)}),E=a.ensureUniformFontSize(t,u.determineTextFont(L,s,S.font,{onPathbar:!0}));k.text(s._text||" ").classed("slicetext",!0).attr("text-anchor","start").call(i.font,E).call(o.convertToTspans,t),s.textBB=i.bBox(k.node()),s.transform=b(s,{fontSize:E.size,onPathbar:!0}),s.transform.fontSize=E.size,w?k.transition().attrTween("transform",function(t){var e=M(t,!0,A,[g,v]);return function(t){return _(e(t))}}):k.attr("transform",_(s))})}},{"../../components/drawing":612,"../../lib":717,"../../lib/svg_text_utils":741,"../sunburst/fx":1236,"../sunburst/helpers":1237,"./constants":1260,"./partition":1267,"./style":1269,d3:165}],1263:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../components/drawing"),o=t("../../lib/svg_text_utils"),s=t("./partition"),l=t("./style").styleOne,c=t("./constants"),u=t("../sunburst/helpers"),h=t("../sunburst/fx"),f=t("../sunburst/plot").formatSliceLabel;e.exports=function(t,e,r,p,d){var g=d.width,v=d.height,m=d.viewX,y=d.viewY,x=d.pathSlice,b=d.toMoveInsideSlice,_=d.strTransform,w=d.hasTransition,k=d.handleSlicesExit,T=d.makeUpdateSliceInterpolator,M=d.makeUpdateTextInterpolator,A=d.prevEntry,S=t._fullLayout,E=e[0].trace,L=-1!==E.textposition.indexOf("left"),C=-1!==E.textposition.indexOf("right"),P=-1!==E.textposition.indexOf("bottom"),O=!P&&!E.marker.pad.t||P&&!E.marker.pad.b,z=s(r,[g,v],{packing:E.tiling.packing,squarifyratio:E.tiling.squarifyratio,flipX:E.tiling.flip.indexOf("x")>-1,flipY:E.tiling.flip.indexOf("y")>-1,pad:{inner:E.tiling.pad,top:E.marker.pad.t,left:E.marker.pad.l,right:E.marker.pad.r,bottom:E.marker.pad.b}}).descendants(),I=1/0,D=-1/0;z.forEach(function(t){var e=t.depth;e>=E._maxDepth?(t.x0=t.x1=(t.x0+t.x1)/2,t.y0=t.y1=(t.y0+t.y1)/2):(I=Math.min(I,e),D=Math.max(D,e))}),p=p.data(z,u.getPtId),E._maxVisibleLayers=isFinite(D)?D-I+1:0,p.enter().append("g").classed("slice",!0),k(p,!1,{},[g,v],x),p.order();var R=null;if(w&&A){var F=u.getPtId(A);p.each(function(t){null===R&&u.getPtId(t)===F&&(R={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})})}var B=function(){return R||{x0:0,x1:g,y0:0,y1:v}},N=p;return w&&(N=N.transition().each("end",function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!1,isTransitioning:!1})})),N.each(function(s){var p=u.isHeader(s,E);s._hoverX=m(s.x1-E.marker.pad.r),s._hoverY=y(P?s.y1-E.marker.pad.b/2:s.y0+E.marker.pad.t/2);var d=n.select(this),k=a.ensureSingle(d,"path","surface",function(t){t.style("pointer-events","all")});w?k.transition().attrTween("d",function(t){var e=T(t,!1,B(),[g,v]);return function(t){return x(e(t))}}):k.attr("d",x),d.call(h,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{isTransitioning:t._transitioning}),k.call(l,s,E,{hovered:!1}),s.x0===s.x1||s.y0===s.y1?s._text="":s._text=p?O?"":u.getPtLabel(s)||"":f(s,r,E,e,S)||"";var A=a.ensureSingle(d,"g","slicetext"),z=a.ensureSingle(A,"text","",function(t){t.attr("data-notex",1)}),I=a.ensureUniformFontSize(t,u.determineTextFont(E,s,S.font));z.text(s._text||" ").classed("slicetext",!0).attr("text-anchor",C?"end":L||p?"start":"middle").call(i.font,I).call(o.convertToTspans,t),s.textBB=i.bBox(z.node()),s.transform=b(s,{fontSize:I.size,isHeader:p}),s.transform.fontSize=I.size,w?z.transition().attrTween("transform",function(t){var e=M(t,!1,B(),[g,v]);return function(t){return _(e(t))}}):z.attr("transform",_(s))}),R}},{"../../components/drawing":612,"../../lib":717,"../../lib/svg_text_utils":741,"../sunburst/fx":1236,"../sunburst/helpers":1237,"../sunburst/plot":1241,"./constants":1260,"./partition":1267,"./style":1269,d3:165}],1264:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"treemap",basePlotModule:t("./base_plot"),categories:[],animatable:!0,attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults"),supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc").calc,crossTraceCalc:t("./calc").crossTraceCalc,plot:t("./plot"),style:t("./style").style,colorbar:t("../scatter/marker_colorbar"),meta:{}}},{"../scatter/marker_colorbar":1138,"./attributes":1257,"./base_plot":1258,"./calc":1259,"./defaults":1261,"./layout_attributes":1265,"./layout_defaults":1266,"./plot":1268,"./style":1269}],1265:[function(t,e,r){"use strict";e.exports={treemapcolorway:{valType:"colorlist",editType:"calc"},extendtreemapcolors:{valType:"boolean",dflt:!0,editType:"calc"}}},{}],1266:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r("treemapcolorway",e.colorway),r("extendtreemapcolors")}},{"../../lib":717,"./layout_attributes":1265}],1267:[function(t,e,r){"use strict";var n=t("d3-hierarchy");e.exports=function(t,e,r){var a,i=r.flipX,o=r.flipY,s="dice-slice"===r.packing,l=r.pad[o?"bottom":"top"],c=r.pad[i?"right":"left"],u=r.pad[i?"left":"right"],h=r.pad[o?"top":"bottom"];s&&(a=c,c=l,l=a,a=u,u=h,h=a);var f=n.treemap().tile(function(t,e){switch(t){case"squarify":return n.treemapSquarify.ratio(e);case"binary":return n.treemapBinary;case"dice":return n.treemapDice;case"slice":return n.treemapSlice;default:return n.treemapSliceDice}}(r.packing,r.squarifyratio)).paddingInner(r.pad.inner).paddingLeft(c).paddingRight(u).paddingTop(l).paddingBottom(h).size(s?[e[1],e[0]]:e)(t);return(s||i||o)&&function t(e,r,n){var a;n.swapXY&&(a=e.x0,e.x0=e.y0,e.y0=a,a=e.x1,e.x1=e.y1,e.y1=a);n.flipX&&(a=e.x0,e.x0=r[0]-e.x1,e.x1=r[0]-a);n.flipY&&(a=e.y0,e.y0=r[1]-e.y1,e.y1=r[1]-a);var i=e.children;if(i)for(var o=0;o<i.length;o++)t(i[o],r,n)}(f,e,{swapXY:s,flipX:i,flipY:o}),f}},{"d3-hierarchy":159}],1268:[function(t,e,r){"use strict";var n=t("d3"),a=t("../sunburst/helpers"),i=t("../../lib"),o=t("../bar/constants").TEXTPAD,s=t("../bar/plot").toMoveInsideBar,l=t("../bar/uniform_text"),c=l.recordMinTextSize,u=l.clearMinTextSize,h=t("../bar/style").resizeText,f=t("./constants"),p=t("./draw_descendants"),d=t("./draw_ancestors");function g(t){return a.isHierarchyRoot(t)?"":a.getPtId(t)}function v(t,e,r,l){var u=t._fullLayout,h=e[0],v=h.trace,m=h.hierarchy,y=a.findEntryWithLevel(m,v.level),x=n.select(r),b=x.selectAll("g.pathbar"),_=x.selectAll("g.slice");if(!y)return b.remove(),void _.remove();var w=a.isHierarchyRoot(y),k=!u.uniformtext.mode&&a.hasTransition(l),T=a.getMaxDepth(v),M=u._size,A=v.domain,S=M.w*(A.x[1]-A.x[0]),E=M.h*(A.y[1]-A.y[0]),L=S,C=v.pathbar.thickness,P=v.marker.line.width+f.gapWithPathbar,O=v.pathbar.visible?v.pathbar.side.indexOf("bottom")>-1?E+P:-(C+P):0,z={x0:L,x1:L,y0:O,y1:O+C},I=function(t,e,r){var n=v.tiling.pad,a=function(t){return t-n<=e.x0},i=function(t){return t+n>=e.x1},o=function(t){return t-n<=e.y0},s=function(t){return t+n>=e.y1};return{x0:a(t.x0-n)?0:i(t.x0-n)?r[0]:t.x0,x1:a(t.x1+n)?0:i(t.x1+n)?r[0]:t.x1,y0:o(t.y0-n)?0:s(t.y0-n)?r[1]:t.y0,y1:o(t.y1+n)?0:s(t.y1+n)?r[1]:t.y1}},D=null,R={},F={},B=null,N=function(t,e){return e?R[g(t)]:F[g(t)]},j=function(t,e,r,n){if(e)return R[g(m)]||z;var a=F[v.level]||r;return function(t){return t.data.depth-y.data.depth<T}(t)?I(t,a,n):{}};h.hasMultipleRoots&&w&&T++,v._maxDepth=T,v._backgroundColor=u.paper_bgcolor,v._entryDepth=y.data.depth,v._atRootLevel=w;var V=-S/2+M.l+M.w*(A.x[1]+A.x[0])/2,U=-E/2+M.t+M.h*(1-(A.y[1]+A.y[0])/2),q=function(t){return V+t},H=function(t){return U+t},G=H(0),Y=q(0),W=function(t){return Y+t},X=function(t){return G+t};function Z(t,e){return t+","+e}var J=W(0),K=function(t){t.x=Math.max(J,t.x)},Q=v.pathbar.edgeshape,$=function(t,e){var r=t.x0,n=t.x1,a=t.y0,i=t.y1,l=t.textBB,h=function(t){return-1!==v.textposition.indexOf(t)},f=h("bottom"),p=h("top")||e.isHeader&&!f?"start":f?"end":"middle",d=h("right"),g=h("left")||e.onPathbar?-1:d?1:0,m=v.marker.pad;if(e.isHeader){if((r+=m.l-o)>=(n-=m.r-o)){var y=(r+n)/2;r=y,n=y}var x;f?a<(x=i-m.b)&&x<i&&(a=x):a<(x=a+m.t)&&x<i&&(i=x)}var b=s(r,n,a,i,l,{isHorizontal:!1,constrained:!0,angle:0,anchor:p,leftToRight:g});return b.fontSize=e.fontSize,b.targetX=q(b.targetX),b.targetY=H(b.targetY),isNaN(b.targetX)||isNaN(b.targetY)?{}:(r!==n&&a!==i&&c(v.type,b,u),{scale:b.scale,rotate:b.rotate,textX:b.textX,textY:b.textY,anchorX:b.anchorX,anchorY:b.anchorY,targetX:b.targetX,targetY:b.targetY})},tt=function(t,e){for(var r,n=0,a=t;!r&&n<T;)n++,(a=a.parent)?r=N(a,e):n=T;return r||{}},et=function(t,e,r,a){var o,s=N(t,e);if(s)o=s;else if(e)o=z;else if(D)if(t.parent){var l=B||r;l&&!e?o=I(t,l,a):(o={},i.extendFlat(o,tt(t,e)))}else o=t;else o={};return n.interpolate(o,{x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})},rt=function(t,e,r,o){var s=N(t,e),l={},h=j(t,e,r,o);i.extendFlat(l,{transform:$({x0:h.x0,x1:h.x1,y0:h.y0,y1:h.y1,textBB:t.textBB,_text:t._text},{isHeader:a.isHeader(t,v)})}),s?l=s:t.parent&&i.extendFlat(l,tt(t,e));var f=t.transform;return t.x0!==t.x1&&t.y0!==t.y1&&c(v.type,f,u),n.interpolate(l,{transform:{scale:f.scale,rotate:f.rotate,textX:f.textX,textY:f.textY,anchorX:f.anchorX,anchorY:f.anchorY,targetX:f.targetX,targetY:f.targetY}})},nt=function(t,e,r,a,i){var o=a[0],s=a[1];k?t.exit().transition().each(function(){var t=n.select(this);t.select("path.surface").transition().attrTween("d",function(t){var r=function(t,e,r,a){var i,o=N(t,e);if(e)i=z;else{var s=N(y,e);i=s?I(t,s,a):{}}return n.interpolate(o,i)}(t,e,0,[o,s]);return function(t){return i(r(t))}}),t.select("g.slicetext").attr("opacity",0)}).remove():t.exit().remove()},at=function(t){var e=t.transform;return t.x0!==t.x1&&t.y0!==t.y1&&c(v.type,e,u),i.getTextTransform({textX:e.textX,textY:e.textY,anchorX:e.anchorX,anchorY:e.anchorY,targetX:e.targetX,targetY:e.targetY,scale:e.scale,rotate:e.rotate})};k&&(b.each(function(t){R[g(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(R[g(t)].transform={textX:t.transform.textX,textY:t.transform.textY,anchorX:t.transform.anchorX,anchorY:t.transform.anchorY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate})}),_.each(function(t){F[g(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(F[g(t)].transform={textX:t.transform.textX,textY:t.transform.textY,anchorX:t.transform.anchorX,anchorY:t.transform.anchorY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate}),!D&&a.isEntry(t)&&(D=t)})),B=p(t,e,y,_,{width:S,height:E,viewX:q,viewY:H,pathSlice:function(t){var e=q(t.x0),r=q(t.x1),n=H(t.y0),a=H(t.y1),i=r-e,o=a-n;if(!i||!o)return"";return"M"+Z(e,n+0)+"L"+Z(r-0,n)+"L"+Z(r,a-0)+"L"+Z(e+0,a)+"Z"},toMoveInsideSlice:$,prevEntry:D,makeUpdateSliceInterpolator:et,makeUpdateTextInterpolator:rt,handleSlicesExit:nt,hasTransition:k,strTransform:at}),v.pathbar.visible?d(t,e,y,b,{barDifY:O,width:L,height:C,viewX:W,viewY:X,pathSlice:function(t){var e=W(Math.max(Math.min(t.x0,t.x0),0)),r=W(Math.min(Math.max(t.x1,t.x1),L)),n=X(t.y0),a=X(t.y1),i=C/2,o={},s={};o.x=e,s.x=r,o.y=s.y=(n+a)/2;var l={x:e,y:n},c={x:r,y:n},u={x:r,y:a},h={x:e,y:a};return">"===Q?(l.x-=i,c.x-=i,u.x-=i,h.x-=i):"/"===Q?(u.x-=i,h.x-=i,o.x-=i/2,s.x-=i/2):"\\"===Q?(l.x-=i,c.x-=i,o.x-=i/2,s.x-=i/2):"<"===Q&&(o.x-=i,s.x-=i),K(l),K(h),K(o),K(c),K(u),K(s),"M"+Z(l.x,l.y)+"L"+Z(c.x,c.y)+"L"+Z(s.x,s.y)+"L"+Z(u.x,u.y)+"L"+Z(h.x,h.y)+"L"+Z(o.x,o.y)+"Z"},toMoveInsideSlice:$,makeUpdateSliceInterpolator:et,makeUpdateTextInterpolator:rt,handleSlicesExit:nt,hasTransition:k,strTransform:at}):b.remove()}e.exports=function(t,e,r,i){var o,s,l=t._fullLayout,c=l._treemaplayer,f=!r;(u("treemap",l),(o=c.selectAll("g.trace.treemap").data(e,function(t){return t[0].trace.uid})).enter().append("g").classed("trace",!0).classed("treemap",!0),o.order(),!l.uniformtext.mode&&a.hasTransition(r))?(i&&(s=i()),n.transition().duration(r.duration).ease(r.easing).each("end",function(){s&&s()}).each("interrupt",function(){s&&s()}).each(function(){c.selectAll("g.trace").each(function(e){v(t,e,this,r)})})):(o.each(function(e){v(t,e,this,r)}),l.uniformtext.mode&&h(t,l._treemaplayer.selectAll(".trace"),"treemap"));f&&o.exit().remove()}},{"../../lib":717,"../bar/constants":858,"../bar/plot":867,"../bar/style":870,"../bar/uniform_text":872,"../sunburst/helpers":1237,"./constants":1260,"./draw_ancestors":1262,"./draw_descendants":1263,d3:165}],1269:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/color"),i=t("../../lib"),o=t("../sunburst/helpers"),s=t("../bar/uniform_text").resizeText;function l(t,e,r,n){var s,l,c=(n||{}).hovered,u=e.data.data,h=u.i,f=u.color,p=o.isHierarchyRoot(e),d=1;if(c)s=r._hovered.marker.line.color,l=r._hovered.marker.line.width;else if(p&&"rgba(0,0,0,0)"===f)d=0,s="rgba(0,0,0,0)",l=0;else if(s=i.castOption(r,h,"marker.line.color")||a.defaultLine,l=i.castOption(r,h,"marker.line.width")||0,!r._hasColorscale&&!e.onPathbar){var g=r.marker.depthfade;if(g){var v,m=a.combine(a.addOpacity(r._backgroundColor,.75),f);if(!0===g){var y=o.getMaxDepth(r);v=isFinite(y)?o.isLeaf(e)?0:r._maxVisibleLayers-(e.data.depth-r._entryDepth):e.data.height+1}else v=e.data.depth-r._entryDepth,r._atRootLevel||v++;if(v>0)for(var x=0;x<v;x++){var b=.5*x/v;f=a.combine(a.addOpacity(m,b),f)}}}t.style("stroke-width",l).call(a.fill,f).call(a.stroke,s).style("opacity",d)}e.exports={style:function(t){var e=t._fullLayout._treemaplayer.selectAll(".trace");s(t,e,"treemap"),e.each(function(t){var e=n.select(this),r=t[0].trace;e.style("opacity",r.opacity),e.selectAll("path.surface").each(function(t){n.select(this).call(l,t,r,{hovered:!1})})})},styleOne:l}},{"../../components/color":591,"../../lib":717,"../bar/uniform_text":872,"../sunburst/helpers":1237,d3:165}],1270:[function(t,e,r){"use strict";var n=t("../box/attributes"),a=t("../../lib/extend").extendFlat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,name:a({},n.name,{}),orientation:a({},n.orientation,{}),bandwidth:{valType:"number",min:0,editType:"calc"},scalegroup:{valType:"string",dflt:"",editType:"calc"},scalemode:{valType:"enumerated",values:["width","count"],dflt:"width",editType:"calc"},spanmode:{valType:"enumerated",values:["soft","hard","manual"],dflt:"soft",editType:"calc"},span:{valType:"info_array",items:[{valType:"any",editType:"calc"},{valType:"any",editType:"calc"}],editType:"calc"},line:{color:{valType:"color",editType:"style"},width:{valType:"number",min:0,dflt:2,editType:"style"},editType:"plot"},fillcolor:n.fillcolor,points:a({},n.boxpoints,{}),jitter:a({},n.jitter,{}),pointpos:a({},n.pointpos,{}),width:a({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,box:{visible:{valType:"boolean",dflt:!1,editType:"plot"},width:{valType:"number",min:0,max:1,dflt:.25,editType:"plot"},fillcolor:{valType:"color",editType:"style"},line:{color:{valType:"color",editType:"style"},width:{valType:"number",min:0,editType:"style"},editType:"style"},editType:"plot"},meanline:{visible:{valType:"boolean",dflt:!1,editType:"plot"},color:{valType:"color",editType:"style"},width:{valType:"number",min:0,editType:"style"},editType:"plot"},side:{valType:"enumerated",values:["both","positive","negative"],dflt:"both",editType:"calc"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:"flaglist",flags:["violins","points","kde"],dflt:"violins+points+kde",extras:["all"],editType:"style"}}},{"../../lib/extend":708,"../box/attributes":881}],1271:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../box/calc"),o=t("./helpers"),s=t("../../constants/numerical").BADNUM;function l(t,e,r){var a=e.max-e.min;if(!a)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,a/1e4);var i=r.length,o=n.stdev(r,i-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(i,o,e.q3-e.q1),a/100)}function c(t,e,r,n){var i,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function h(n){var a=l[n],i="multicategory"===r.type?r.r2c(a):r.d2c(a,0,t[e.valLetter+"calendar"]);return i===s?u[n]:i}var f={type:"linear",range:i="soft"===o?u:"hard"===o?c:[h(0),h(1)]};return a.setConvert(f),f.cleanRange(),i}e.exports=function(t,e){var r=i(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=a.getFromId(t,e["h"===e.orientation?"xaxis":"yaxis"]),h=1/0,f=-1/0,p=0,d=0,g=0;g<r.length;g++){var v=r[g],m=v.pts.map(o.extractVal),y=v.bandwidth=l(e,v,m),x=v.span=c(e,v,u,y);if(v.min===v.max&&0===y)x=v.span=[v.min,v.max],v.density=[{v:1,t:x[0]}],v.bandwidth=y,p=Math.max(p,1);else{var b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error("Something went wrong with computing the violin span"),r[0].t.empty=!0,r;var k=o.makeKDE(v,e,m);v.density=new Array(_);for(var T=0,M=x[0];M<x[1]+w/2;T++,M+=w){var A=k(M);v.density[T]={v:A,t:M},p=Math.max(p,A)}}d=Math.max(d,m.length),h=Math.min(h,x[0]),f=Math.max(f,x[1])}var S=a.findExtremes(u,[h,f],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,L=e.scalegroup,C=E[L];C?(C.maxKDE=Math.max(C.maxKDE,p),C.maxCount=Math.max(C.maxCount,d)):E[L]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,"kde:"),r}},{"../../constants/numerical":693,"../../lib":717,"../../plots/cartesian/axes":765,"../box/calc":882,"./helpers":1274}],1272:[function(t,e,r){"use strict";var n=t("../box/cross_trace_calc").setPositionOffset,a=["v","h"];e.exports=function(t,e){for(var r=t.calcdata,i=e.xaxis,o=e.yaxis,s=0;s<a.length;s++){for(var l=a[s],c="h"===l?o:i,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||"violin"!==d.type||p.empty||d.orientation!==l||d.xaxis!==i._id||d.yaxis!==o._id||u.push(h)}n("violin",t,u,c)}}},{"../box/cross_trace_calc":883}],1273:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/color"),i=t("../box/defaults"),o=t("./attributes");e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,o,r,a)}function c(r,a){return n.coerce2(t,e,o,r,a)}if(i.handleSampleDefaults(t,e,l,s),!1!==e.visible){l("bandwidth"),l("side"),l("width")||(l("scalegroup",e.name),l("scalemode"));var u,h=l("span");Array.isArray(h)&&(u="manual"),l("spanmode",u);var f=l("line.color",(t.marker||{}).color||r),p=l("line.width"),d=l("fillcolor",a.addOpacity(e.line.color,.5));i.handlePointsDefaults(t,e,l,{prefix:""});var g=c("box.width"),v=c("box.fillcolor",d),m=c("box.line.color",f),y=c("box.line.width",p);l("box.visible",Boolean(g||v||m||y))||(e.box={visible:!1});var x=c("meanline.color",f),b=c("meanline.width",p);l("meanline.visible",Boolean(x||b))||(e.meanline={visible:!1})}}},{"../../components/color":591,"../../lib":717,"../box/defaults":884,"./attributes":1270}],1274:[function(t,e,r){"use strict";var n=t("../../lib"),a=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,i=a,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,a=0;a<n;a++)e+=i((t-r[a])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var a,i;"h"===e.orientation?(a="y",i="x"):(a="x",i="y");var o=n.findPointOnPath(t.path,r,i,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[a];return[l,"both"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var a=t.pts.map(r.extractVal);return r.makeKDE(t,e,a)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{"../../lib":717}],1275:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../box/hover"),o=t("./helpers");e.exports=function(t,e,r,s,l){var c,u,h=t.cd,f=h[0].trace,p=f.hoveron,d=-1!==p.indexOf("violins"),g=-1!==p.indexOf("kde"),v=[];if(d||g){var m=i.hoverOnBoxes(t,e,r,s);if(g&&m.length>0){var y,x,b,_,w,k=t.xa,T=t.ya;"h"===f.orientation?(w=e,y="y",b=T,x="x",_=k):(w=r,y="x",b=k,x="y",_=T);var M=h[t.index];if(w>=M.span[0]&&w<=M.span[1]){var A=n.extendFlat({},t),S=_.c2p(w,!0),E=o.getKdeValue(M,f,w),L=o.getPositionOnKdePath(M,f,S),C=b._offset,P=b._length;A[y+"0"]=L[0],A[y+"1"]=L[1],A[x+"0"]=A[x+"1"]=S,A[x+"Label"]=x+": "+a.hoverLabelText(_,w)+", "+h[0].t.labels.kde+" "+E.toFixed(3),A.spikeDistance=m[0].spikeDistance;var O=y+"Spike";A[O]=m[0][O],m[0].spikeDistance=void 0,m[0][O]=void 0,A.hovertemplate=!1,v.push(A),(u={stroke:t.color})[y+"1"]=n.constrain(C+L[0],C,C+P),u[y+"2"]=n.constrain(C+L[1],C,C+P),u[x+"1"]=u[x+"2"]=_._offset+S}}d&&(v=v.concat(m))}-1!==p.indexOf("points")&&(c=i.hoverOnPoints(t,e,r));var z=l.selectAll(".violinline-"+f.uid).data(u?[0]:[]);return z.enter().append("line").classed("violinline-"+f.uid,!0).attr("stroke-width",1.5),z.exit().remove(),z.attr(u),"closest"===s?c?[c]:v:c?(v.push(c),v):v}},{"../../lib":717,"../../plots/cartesian/axes":765,"../box/hover":886,"./helpers":1274}],1276:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults"),crossTraceDefaults:t("../box/defaults").crossTraceDefaults,supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc"),crossTraceCalc:t("./cross_trace_calc"),plot:t("./plot"),style:t("./style"),styleOnSelect:t("../scatter/style").styleOnSelect,hoverPoints:t("./hover"),selectPoints:t("../box/select"),moduleType:"trace",name:"violin",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","symbols","oriented","box-violin","showLegend","violinLayout","zoomScale"],meta:{}}},{"../../plots/cartesian":776,"../box/defaults":884,"../box/select":891,"../scatter/style":1143,"./attributes":1270,"./calc":1271,"./cross_trace_calc":1272,"./defaults":1273,"./hover":1275,"./layout_attributes":1277,"./layout_defaults":1278,"./plot":1279,"./style":1280}],1277:[function(t,e,r){"use strict";var n=t("../box/layout_attributes"),a=t("../../lib").extendFlat;e.exports={violinmode:a({},n.boxmode,{}),violingap:a({},n.boxgap,{}),violingroupgap:a({},n.boxgroupgap,{})}},{"../../lib":717,"../box/layout_attributes":888}],1278:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes"),i=t("../box/layout_defaults");e.exports=function(t,e,r){i._supply(t,e,r,function(r,i){return n.coerce(t,e,a,r,i)},"violin")}},{"../../lib":717,"../box/layout_defaults":889,"./layout_attributes":1277}],1279:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../components/drawing"),o=t("../box/plot"),s=t("../scatter/line_points"),l=t("./helpers");e.exports=function(t,e,r,c){var u=t._fullLayout,h=e.xaxis,f=e.yaxis;function p(t){var e=s(t,{xaxis:h,yaxis:f,connectGaps:!0,baseTolerance:.75,shape:"spline",simplify:!0,linearized:!0});return i.smoothopen(e[0],1)}a.makeTraceGroups(c,r,"trace violins").each(function(t){var r=n.select(this),i=t[0],s=i.t,c=i.trace;if(!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,g=s.bdPos,v=e[s.valLetter+"axis"],m=e[s.posLetter+"axis"],y="both"===c.side,x=y||"positive"===c.side,b=y||"negative"===c.side,_=r.selectAll("path.violin").data(a.identity);_.enter().append("path").style("vector-effect","non-scaling-stroke").attr("class","violin"),_.exit().remove(),_.each(function(t){var e,r,a,i,o,l,h,f,_=n.select(this),w=t.density,k=w.length,T=m.c2l(t.pos+d,!0),M=m.l2p(T);if(c.width)e=s.maxKDE/g;else{var A=u._violinScaleGroupStats[c.scalegroup];e="count"===c.scalemode?A.maxKDE/g*(A.maxCount/t.pts.length):A.maxKDE/g}if(x){for(h=new Array(k),o=0;o<k;o++)(f=h[o]={})[s.posLetter]=T+w[o].v/e,f[s.valLetter]=v.c2l(w[o].t,!0);r=p(h)}if(b){for(h=new Array(k),l=0,o=k-1;l<k;l++,o--)(f=h[l]={})[s.posLetter]=T-w[o].v/e,f[s.valLetter]=v.c2l(w[o].t,!0);a=p(h)}if(y)i=r+"L"+a.substr(1)+"Z";else{var S=[M,v.c2p(w[0].t)],E=[M,v.c2p(w[k-1].t)];"h"===c.orientation&&(S.reverse(),E.reverse()),i=x?"M"+S+"L"+r.substr(1)+"L"+E:"M"+E+"L"+a.substr(1)+"L"+S}_.attr("d",i),t.posCenterPx=M,t.posDensityScale=e*g,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)});var w,k,T,M=c.box,A=M.width,S=(M.line||{}).width;y?(w=g*A,k=0):x?(w=[0,g*A/2],k=S*{x:1,y:-1}[s.posLetter]):(w=[g*A/2,0],k=S*{x:-1,y:1}[s.posLetter]),o.plotBoxAndWhiskers(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),o.plotBoxMean(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),!c.box.visible&&c.meanline.visible&&(T=a.identity);var E=r.selectAll("path.meanline").data(T||[]);E.enter().append("path").attr("class","meanline").style("fill","none").style("vector-effect","non-scaling-stroke"),E.exit().remove(),E.each(function(t){var e=v.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr("d","h"===c.orientation?"M"+e+","+r[0]+"V"+r[1]:"M"+r[0]+","+e+"H"+r[1])}),o.plotPoints(r,{x:h,y:f},c,s)}})}},{"../../components/drawing":612,"../../lib":717,"../box/plot":890,"../scatter/line_points":1134,"./helpers":1274,d3:165}],1280:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/color"),i=t("../scatter/style").stylePoints;e.exports=function(t){var e=n.select(t).selectAll("g.trace.violins");e.style("opacity",function(t){return t[0].trace.opacity}),e.each(function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll("path.violin").style("stroke-width",r.line.width+"px").call(a.stroke,r.line.color).call(a.fill,r.fillcolor),o.selectAll("path.box").style("stroke-width",l.width+"px").call(a.stroke,l.color).call(a.fill,s.fillcolor);var h={"stroke-width":u+"px","stroke-dasharray":2*u+"px,"+u+"px"};o.selectAll("path.mean").style(h).call(a.stroke,c.color),o.selectAll("path.meanline").style(h).call(a.stroke,c.color),i(o,r,t)})}},{"../../components/color":591,"../scatter/style":1143,d3:165}],1281:[function(t,e,r){"use strict";var n=t("../../components/colorscale/attributes"),a=t("../isosurface/attributes"),i=t("../surface/attributes"),o=t("../../plots/attributes"),s=t("../../lib/extend").extendFlat,l=t("../../plot_api/edit_types").overrideAll,c=e.exports=l(s({x:a.x,y:a.y,z:a.z,value:a.value,isomin:a.isomin,isomax:a.isomax,surface:a.surface,spaceframe:{show:{valType:"boolean",dflt:!1},fill:{valType:"number",min:0,max:1,dflt:1}},slices:a.slices,caps:a.caps,text:a.text,hovertext:a.hovertext,hovertemplate:a.hovertemplate},n("",{colorAttr:"`value`",showScaleDflt:!0,editTypeOverride:"calc"}),{colorbar:a.colorbar,opacity:a.opacity,opacityscale:i.opacityscale,lightposition:a.lightposition,lighting:a.lighting,flatshading:a.flatshading,contour:a.contour,hoverinfo:s({},o.hoverinfo),showlegend:s({},o.showlegend,{dflt:!1})}),"calc","nested");c.x.editType=c.y.editType=c.z.editType=c.value.editType="calc+clearAxisTypes",c.transforms=void 0},{"../../components/colorscale/attributes":598,"../../lib/extend":708,"../../plot_api/edit_types":748,"../../plots/attributes":762,"../isosurface/attributes":1056,"../surface/attributes":1243}],1282:[function(t,e,r){"use strict";var n=t("gl-mesh3d"),a=t("../../lib/gl_format_color").parseColorScale,i=t("../../lib/str2rgbarray"),o=t("../../components/colorscale").extractOpts,s=t("../../plots/gl3d/zip3"),l=t("../isosurface/convert").findNearestOnAxis,c=t("../isosurface/convert").generateIsoMeshes;function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name="",this.data=null,this.showContour=!1}var h=u.prototype;h.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._meshX[e],n=this.data._meshY[e],a=this.data._meshZ[e],i=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(a,this.data._Zs).id,h=t.index=u+o*c+o*i*s;t.traceCoordinate=[this.data._meshX[h],this.data._meshY[h],this.data._meshZ[h],this.data._value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=c(t);var l={positions:s(n(r.xaxis,t._meshX,e.dataScale[0],t.xcalendar),n(r.yaxis,t._meshY,e.dataScale[1],t.ycalendar),n(r.zaxis,t._meshZ,e.dataScale[2],t.zcalendar)),cells:s(t._meshI,t._meshJ,t._meshK),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:i(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},u=o(t);l.vertexIntensity=t._meshIntensity,l.vertexIntensityBounds=[u.min,u.max],l.colormap=a(t),this.mesh.update(l)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,a=n({gl:r}),i=new u(t,a,e.uid);return a._trace=i,i.update(e),t.glplot.add(a),i}},{"../../components/colorscale":603,"../../lib/gl_format_color":714,"../../lib/str2rgbarray":740,"../../plots/gl3d/zip3":816,"../isosurface/convert":1058,"gl-mesh3d":283}],1283:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("../isosurface/defaults").supplyIsoDefaults,o=t("../surface/defaults").opacityscaleDefaults;e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,a,r,i)}i(t,e,r,s,l),o(t,e,s,l)}},{"../../lib":717,"../isosurface/defaults":1059,"../surface/defaults":1246,"./attributes":1281}],1284:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("../isosurface/calc"),colorbar:{min:"cmin",max:"cmax"},plot:t("./convert"),moduleType:"trace",name:"volume",basePlotModule:t("../../plots/gl3d"),categories:["gl3d","showLegend"],meta:{}}},{"../../plots/gl3d":805,"../isosurface/calc":1057,"./attributes":1281,"./convert":1282,"./defaults":1283}],1285:[function(t,e,r){"use strict";var n=t("../bar/attributes"),a=t("../scatter/attributes").line,i=t("../../plots/attributes"),o=t("../../plots/template_attributes").hovertemplateAttrs,s=t("../../plots/template_attributes").texttemplateAttrs,l=t("./constants"),c=t("../../lib/extend").extendFlat,u=t("../../components/color");function h(t){return{marker:{color:c({},n.marker.color,{arrayOk:!1,editType:"style"}),line:{color:c({},n.marker.line.color,{arrayOk:!1,editType:"style"}),width:c({},n.marker.line.width,{arrayOk:!1,editType:"style"}),editType:"style"},editType:"style"},editType:"style"}}e.exports={measure:{valType:"data_array",dflt:[],editType:"calc"},base:{valType:"number",dflt:null,arrayOk:!1,editType:"calc"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:l.eventDataKeys}),hoverinfo:c({},i.hoverinfo,{flags:["name","x","y","text","initial","delta","final"]}),textinfo:{valType:"flaglist",flags:["label","text","initial","delta","final"],extras:["none"],editType:"plot",arrayOk:!1},texttemplate:s({editType:"plot"},{keys:l.eventDataKeys.concat(["label"])}),text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:h(),decreasing:h(),totals:h(),connector:{line:{color:c({},a.color,{dflt:u.defaultLine}),width:c({},a.width,{editType:"plot"}),dash:a.dash,editType:"plot"},mode:{valType:"enumerated",values:["spanning","between"],dflt:"between",editType:"plot"},visible:{valType:"boolean",dflt:!0,editType:"plot"},editType:"plot"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{"../../components/color":591,"../../lib/extend":708,"../../plots/attributes":762,"../../plots/template_attributes":841,"../bar/attributes":856,"../scatter/attributes":1120,"./constants":1287}],1286:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../lib").mergeArray,i=t("../scatter/calc_selection"),o=t("../../constants/numerical").BADNUM;function s(t){return"a"===t||"absolute"===t}function l(t){return"t"===t||"total"===t}e.exports=function(t,e){var r,c,u=n.getFromId(t,e.xaxis||"x"),h=n.getFromId(t,e.yaxis||"y");"h"===e.orientation?(r=u.makeCalcdata(e,"x"),c=h.makeCalcdata(e,"y")):(r=h.makeCalcdata(e,"y"),c=u.makeCalcdata(e,"x"));for(var f,p=Math.min(c.length,r.length),d=new Array(p),g=0,v=!1,m=0;m<p;m++){var y=r[m]||0,x=!1;(r[m]!==o||l(e.measure[m])||s(e.measure[m]))&&m+1<p&&(r[m+1]!==o||l(e.measure[m+1])||s(e.measure[m+1]))&&(x=!0);var b=d[m]={i:m,p:c[m],s:y,rawS:y,cNext:x};s(e.measure[m])?(g=b.s,b.isSum=!0,b.dir="totals",b.s=g):l(e.measure[m])?(b.isSum=!0,b.dir="totals",b.s=g):(b.isSum=!1,b.dir=b.rawS<0?"decreasing":"increasing",f=b.s,b.s=g+f,g+=f),"totals"===b.dir&&(v=!0),e.ids&&(b.id=String(e.ids[m])),b.v=(e.base||0)+g}return d.length&&(d[0].hasTotals=v),a(e.text,d,"tx"),a(e.hovertext,d,"htx"),i(d,e),d}},{"../../constants/numerical":693,"../../lib":717,"../../plots/cartesian/axes":765,"../scatter/calc_selection":1122}],1287:[function(t,e,r){"use strict";e.exports={eventDataKeys:["initial","delta","final"]}},{}],1288:[function(t,e,r){"use strict";var n=t("../bar/cross_trace_calc").setGroupPositions;e.exports=function(t,e){var r,a,i=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(a=0;a<o.length;a++){var p=o[a];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&"waterfall"===p.type&&(r=s[a],"h"===p.orientation?f.push(r):h.push(r),u.push(r))}var d={mode:i.waterfallmode,norm:i.waterfallnorm,gap:i.waterfallgap,groupgap:i.waterfallgroupgap};for(n(t,l,c,h,d),n(t,c,l,f,d),a=0;a<u.length;a++){r=u[a];for(var g=0;g<r.length;g++){var v=r[g];!1===v.isSum&&(v.s0+=0===g?0:r[g-1].s),g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0)}}}},{"../bar/cross_trace_calc":859}],1289:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../bar/defaults").handleGroupingDefaults,i=t("../bar/defaults").handleText,o=t("../scatter/xy_defaults"),s=t("./attributes"),l=t("../../components/color"),c=t("../../constants/delta.js"),u=c.INCREASING.COLOR,h=c.DECREASING.COLOR,f="#4499FF";function p(t,e,r){t(e+".marker.color",r),t(e+".marker.line.color",l.defaultLine),t(e+".marker.line.width")}e.exports={supplyDefaults:function(t,e,r,a){function l(r,a){return n.coerce(t,e,s,r,a)}if(o(t,e,a,l)){l("measure"),l("orientation",e.x&&!e.y?"h":"v"),l("base"),l("offset"),l("width"),l("text"),l("hovertext"),l("hovertemplate");var c=l("textposition");i(t,e,a,l,c,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),"none"!==e.textposition&&(l("texttemplate"),e.texttemplate||l("textinfo")),p(l,"increasing",u),p(l,"decreasing",h),p(l,"totals",f),l("connector.visible")&&(l("connector.mode"),l("connector.line.width")&&(l("connector.line.color"),l("connector.line.dash")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,i;function o(t){return n.coerce(i._input,i,s,t)}if("group"===e.waterfallmode)for(var l=0;l<t.length;l++)r=(i=t[l])._input,a(r,i,e,o)}}},{"../../components/color":591,"../../constants/delta.js":687,"../../lib":717,"../bar/defaults":860,"../scatter/xy_defaults":1146,"./attributes":1285}],1290:[function(t,e,r){"use strict";e.exports=function(t,e){return t.x="xVal"in e?e.xVal:e.x,t.y="yVal"in e?e.yVal:e.y,"initial"in e&&(t.initial=e.initial),"delta"in e&&(t.delta=e.delta),"final"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1291:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes").hoverLabelText,a=t("../../components/color").opacity,i=t("../bar/hover").hoverOnBars,o=t("../../constants/delta.js"),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;e.exports=function(t,e,r,o){var c=i(t,e,r,o);if(c){var u=c.cd,h=u[0].trace,f="h"===h.orientation,p=f?t.xa:t.ya,d=u[c.index],g=d.isSum?d.b+d.s:d.rawS;if(!d.isSum){c.initial=d.b+d.s-g,c.delta=g,c.final=c.initial+c.delta;var v=w(Math.abs(c.delta));c.deltaLabel=g<0?"("+v+")":v,c.finalLabel=w(c.final),c.initialLabel=w(c.initial)}var m=d.hi||h.hoverinfo,y=[];if(m&&"none"!==m&&"skip"!==m){var x="all"===m,b=m.split("+"),_=function(t){return x||-1!==b.indexOf(t)};d.isSum||(!_("final")||_(f?"x":"y")||y.push(c.finalLabel),_("delta")&&(g<0?y.push(c.deltaLabel+" "+l):y.push(c.deltaLabel+" "+s)),_("initial")&&y.push("Initial: "+c.initialLabel))}return y.length&&(c.extraText=y.join("<br>")),c.color=function(t,e){var r=t[e.dir].marker,n=r.color,i=r.line.color,o=r.line.width;if(a(n))return n;if(a(i)&&o)return i}(h,d),[c]}function w(t){return n(p,t)}}},{"../../components/color":591,"../../constants/delta.js":687,"../../plots/cartesian/axes":765,"../bar/hover":863}],1292:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults").supplyDefaults,crossTraceDefaults:t("./defaults").crossTraceDefaults,supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc"),crossTraceCalc:t("./cross_trace_calc"),plot:t("./plot"),style:t("./style").style,hoverPoints:t("./hover"),eventData:t("./event_data"),selectPoints:t("../bar/select"),moduleType:"trace",name:"waterfall",basePlotModule:t("../../plots/cartesian"),categories:["bar-like","cartesian","svg","oriented","showLegend","zoomScale"],meta:{}}},{"../../plots/cartesian":776,"../bar/select":868,"./attributes":1285,"./calc":1286,"./cross_trace_calc":1288,"./defaults":1289,"./event_data":1290,"./hover":1291,"./layout_attributes":1293,"./layout_defaults":1294,"./plot":1295,"./style":1296}],1293:[function(t,e,r){"use strict";e.exports={waterfallmode:{valType:"enumerated",values:["group","overlay"],dflt:"group",editType:"calc"},waterfallgap:{valType:"number",min:0,max:1,editType:"calc"},waterfallgroupgap:{valType:"number",min:0,max:1,dflt:0,editType:"calc"}}},{}],1294:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e,r){var i=!1;function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&"waterfall"===l.type){i=!0;break}}i&&(o("waterfallmode"),o("waterfallgap",.2),o("waterfallgroupgap"))}},{"../../lib":717,"./layout_attributes":1293}],1295:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../components/drawing"),o=t("../../constants/numerical").BADNUM,s=t("../bar/plot"),l=t("../bar/uniform_text").clearMinTextSize;e.exports=function(t,e,r,c){var u=t._fullLayout;l("waterfall",u),s.plot(t,e,r,c,{mode:u.waterfallmode,norm:u.waterfallmode,gap:u.waterfallgap,groupgap:u.waterfallgroupgap}),function(t,e,r,s){var l=e.xaxis,c=e.yaxis;a.makeTraceGroups(s,r,"trace bars").each(function(r){var s=n.select(this),u=r[0].trace,h=a.ensureSingle(s,"g","lines");if(u.connector&&u.connector.visible){var f="h"===u.orientation,p=u.connector.mode,d=h.selectAll("g.line").data(a.identity);d.enter().append("g").classed("line",!0),d.exit().remove();var g=d.size();d.each(function(r,s){if(s===g-1||r.cNext){var u=function(t,e,r,n){var a=[],i=[],o=n?e:r,s=n?r:e;return a[0]=o.c2p(t.s0,!0),i[0]=s.c2p(t.p0,!0),a[1]=o.c2p(t.s1,!0),i[1]=s.c2p(t.p1,!0),a[2]=o.c2p(t.nextS0,!0),i[2]=s.c2p(t.nextP0,!0),n?[a,i]:[i,a]}(r,l,c,f),h=u[0],d=u[1],v="";h[0]!==o&&d[0]!==o&&h[1]!==o&&d[1]!==o&&("spanning"===p&&!r.isSum&&s>0&&(v+=f?"M"+h[0]+","+d[1]+"V"+d[0]:"M"+h[1]+","+d[0]+"H"+h[0]),"between"!==p&&(r.isSum||s<g-1)&&(v+=f?"M"+h[1]+","+d[0]+"V"+d[1]:"M"+h[0]+","+d[1]+"H"+h[1]),h[2]!==o&&d[2]!==o&&(v+=f?"M"+h[1]+","+d[1]+"V"+d[2]:"M"+h[1]+","+d[1]+"H"+h[2])),""===v&&(v="M0,0Z"),a.ensureSingle(n.select(this),"path").attr("d",v).call(i.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,c)}},{"../../components/drawing":612,"../../constants/numerical":693,"../../lib":717,"../bar/plot":867,"../bar/uniform_text":872,d3:165}],1296:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/drawing"),i=t("../../components/color"),o=t("../../constants/interactions").DESELECTDIM,s=t("../bar/style"),l=t("../bar/uniform_text").resizeText,c=s.styleTextPoints;e.exports={style:function(t,e,r){var s=r||n.select(t).selectAll("g.waterfalllayer").selectAll("g.trace");l(t,s,"waterfall"),s.style("opacity",function(t){return t[0].trace.opacity}),s.each(function(e){var r=n.select(this),s=e[0].trace;r.selectAll(".point > path").each(function(t){if(!t.isBlank){var e=s[t.dir].marker;n.select(this).call(i.fill,e.color).call(i.stroke,e.line.color).call(a.dashLine,e.line.dash,e.line.width).style("opacity",s.selectedpoints&&!t.selected?o:1)}}),c(r,s,t),r.selectAll(".lines").each(function(){var t=s.connector.line;a.lineGroupStyle(n.select(this).selectAll("path"),t.width,t.color,t.dash)})})}}},{"../../components/color":591,"../../components/drawing":612,"../../constants/interactions":692,"../bar/style":870,"../bar/uniform_text":872,d3:165}],1297:[function(t,e,r){"use strict";var n=t("../plots/cartesian/axes"),a=t("../lib"),i=t("../plot_api/plot_schema"),o=t("./helpers").pointsAccessorFunction,s=t("../constants/numerical").BADNUM;r.moduleType="transform",r.name="aggregate";var l=r.attributes={enabled:{valType:"boolean",dflt:!0,editType:"calc"},groups:{valType:"string",strict:!0,noBlank:!0,arrayOk:!0,dflt:"x",editType:"calc"},aggregations:{_isLinkedToArray:"aggregation",target:{valType:"string",editType:"calc"},func:{valType:"enumerated",values:["count","sum","avg","median","mode","rms","stddev","min","max","first","last","change","range"],dflt:"first",editType:"calc"},funcmode:{valType:"enumerated",values:["sample","population"],dflt:"sample",editType:"calc"},enabled:{valType:"boolean",dflt:!0,editType:"calc"},editType:"calc"},editType:"calc"},c=l.aggregations;function u(t,e,r,i){if(i.enabled){for(var o=i.target,l=a.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,a=e.c2d;switch(r){case"count":return h;case"first":return f;case"last":return p;case"sum":return function(t,e){for(var r=0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r+=o)}return a(r)};case"avg":return function(t,e){for(var r=0,i=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,i++)}return i?a(r/i):s};case"min":return function(t,e){for(var r=1/0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:a(r)};case"max":return function(t,e){for(var r=-1/0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:a(r)};case"range":return function(t,e){for(var r=1/0,i=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),i=Math.max(i,l))}return i===-1/0||r===1/0?s:a(i-r)};case"change":return function(t,e){var r=n(t[e[0]]),i=n(t[e[e.length-1]]);return r===s||i===s?s:a(i-r)};case"median":return function(t,e){for(var r=[],i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&r.push(o)}if(!r.length)return s;r.sort();var l=(r.length-1)/2;return a((r[Math.floor(l)]+r[Math.ceil(l)])/2)};case"mode":return function(t,e){for(var r={},i=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>i&&(i=u,o=c)}}return i?a(o):s};case"rms":return function(t,e){for(var r=0,i=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,i++)}return i?a(Math.sqrt(r/i)):s};case"stddev":return function(e,r){var a,i=0,o=0,l=1,c=s;for(a=0;a<r.length&&c===s;a++)c=n(e[r[a]]);if(c===s)return s;for(;a<r.length;a++){var u=n(e[r[a]]);if(u!==s){var h=u-c;i+=h,o+=h*h,l++}}var f="sample"===t.funcmode?l-1:l;return f?Math.sqrt((o-i*i/l)/f):0}}}(i,n.getDataConversions(t,e,o,c)),d=new Array(r.length),g=0;g<r.length;g++)d[g]=u(c,r[g]);l.set(d),"count"===i.func&&a.pushUnique(e._arrayAttrs,o)}}function h(t,e){return e.length}function f(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return a.coerce(t,n,l,e,r)}if(!o("enabled"))return n;var s=i.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var h=o("groups");if(!Array.isArray(h)){if(!u[h])return n.enabled=!1,n;u[h]=0}var f,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function g(t,e){return a.coerce(p[r],f,c,t,e)}for(r=0;r<p.length;r++){f={_index:r};var v=g("target"),m=g("func");g("enabled")&&v&&(u[v]||"count"===m&&void 0===u[v])?("stddev"===m&&g("funcmode"),u[v]=0,d[r]=f):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,i=a.getTargetArray(e,{target:n});if(i){var s,l,c,h,f={},p={},d=[],g=o(e.transforms,r),v=i.length;for(e._length&&(v=Math.min(v,e._length)),s=0;s<v;s++)void 0===(c=f[l=i[s]])?(f[l]=d.length,h=[s],d.push(h),p[f[l]]=g(s)):(d[c].push(s),p[f[l]]=(p[f[l]]||[]).concat(g(s)));r._indexToPoints=p;var m=r.aggregations;for(s=0;s<m.length;s++)u(t,e,d,m[s]);"string"==typeof n&&u(t,e,d,{target:n,func:"first",enabled:!0}),e._length=d.length}}}},{"../constants/numerical":693,"../lib":717,"../plot_api/plot_schema":754,"../plots/cartesian/axes":765,"./helpers":1300}],1298:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../registry"),i=t("../plots/cartesian/axes"),o=t("./helpers").pointsAccessorFunction,s=t("../constants/filter_ops"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType="transform",r.name="filter",r.attributes={enabled:{valType:"boolean",dflt:!0,editType:"calc"},target:{valType:"string",strict:!0,noBlank:!0,arrayOk:!0,dflt:"x",editType:"calc"},operation:{valType:"enumerated",values:[].concat(l).concat(c).concat(u),dflt:"=",editType:"calc"},value:{valType:"any",dflt:0,editType:"calc"},preservegaps:{valType:"boolean",dflt:!1,editType:"calc"},editType:"calc"},r.supplyDefaults=function(t){var e={};function i(a,i){return n.coerce(t,e,r.attributes,a,i)}if(i("enabled")){var o=i("target");if(n.isArrayOrTypedArray(o)&&0===o.length)return e.enabled=!1,e;i("preservegaps"),i("operation"),i("value");var s=a.getComponentMethod("calendars","handleDefaults");s(t,e,"valuecalendar",null),s(t,e,"targetcalendar",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var a=n.getTargetArray(e,r);if(a){var s=r.target,h=a.length;e._length&&(h=Math.min(h,e._length));var f=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if("string"==typeof s){var g=n.nestedProperty(e,s+"calendar").get();g&&(f=g)}var v,m,y=function(t,e,r){var n=t.operation,a=t.value,i=Array.isArray(a);function o(t){return-1!==t.indexOf(n)}var s,h=function(r){return e(r,0,t.valuecalendar)},f=function(t){return e(t,0,r)};o(l)?s=h(i?a[0]:a):o(c)?s=i?[h(a[0]),h(a[1])]:[h(a),h(a)]:o(u)&&(s=i?a.map(h):[h(a)]);switch(n){case"=":return function(t){return f(t)===s};case"!=":return function(t){return f(t)!==s};case"<":return function(t){return f(t)<s};case"<=":return function(t){return f(t)<=s};case">":return function(t){return f(t)>s};case">=":return function(t){return f(t)>=s};case"[]":return function(t){var e=f(t);return e>=s[0]&&e<=s[1]};case"()":return function(t){var e=f(t);return e>s[0]&&e<s[1]};case"[)":return function(t){var e=f(t);return e>=s[0]&&e<s[1]};case"(]":return function(t){var e=f(t);return e>s[0]&&e<=s[1]};case"][":return function(t){var e=f(t);return e<=s[0]||e>=s[1]};case")(":return function(t){var e=f(t);return e<s[0]||e>s[1]};case"](":return function(t){var e=f(t);return e<=s[0]||e>s[1]};case")[":return function(t){var e=f(t);return e<s[0]||e>=s[1]};case"{}":return function(t){return-1!==s.indexOf(f(t))};case"}{":return function(t){return-1===s.indexOf(f(t))}}}(r,i.getDataToCoordFunc(t,e,s,a),f),x={},b={},_=0;d?(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(h))},m=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},m=function(t,e){var r=x[t.astr][e];t.get().push(r)}),T(v);for(var w=o(e.transforms,r),k=0;k<h;k++){y(a[k])?(T(m,k),b[_++]=w(k)):d&&_++}r._indexToPoints=b,e._length=_}}function T(t,r){for(var a=0;a<p.length;a++){t(n.nestedProperty(e,p[a]),r)}}}},{"../constants/filter_ops":689,"../lib":717,"../plots/cartesian/axes":765,"../registry":846,"./helpers":1300}],1299:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../plot_api/plot_schema"),i=t("../plots/plots"),o=t("./helpers").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,h,f,p,d,g,v=e.transform,m=e.transformIndex,y=t.transforms[m].groups,x=o(t.transforms,v);if(!n.isArrayOrTypedArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,k=a.findArrayAttributes(t),T=v.styles||[],M={};for(r=0;r<T.length;r++)M[T[r].target]=T[r].value;v.styles&&(g=n.keyedContainer(v,"styles","target","value.name"));var A={},S={};for(r=0;r<b.length;r++){A[h=b[r]]=r,S[h]=0,(f=_[r]=n.extendDeepNoArrays({},t))._group=h,f.transforms[m]._indexToPoints={};var E=null;for(g&&(E=g.get(h)),f.name=E||""===E?E:n.templateString(v.nameformat,{trace:t.name,group:h}),p=f.transforms,f.transforms=[],s=0;s<p.length;s++)f.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<k.length;s++)n.nestedProperty(f,k[s]).set([])}for(l=0;l<k.length;l++){for(c=k[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[A[y[s]]].push(u[s])}for(s=0;s<w;s++){(f=_[A[y[s]]]).transforms[m]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)h=b[r],f=_[r],i.clearExpandedTraceDefaultColors(f),f=n.extendDeepNoArrays(f,M[h]||{});return _}r.moduleType="transform",r.name="groupby",r.attributes={enabled:{valType:"boolean",dflt:!0,editType:"calc"},groups:{valType:"data_array",dflt:[],editType:"calc"},nameformat:{valType:"string",editType:"calc"},styles:{_isLinkedToArray:"style",target:{valType:"string",editType:"calc"},value:{valType:"any",dflt:{},editType:"calc",_compareAsJSON:!0},editType:"calc"},editType:"calc"},r.supplyDefaults=function(t,e,a){var i,o={};function s(e,a){return n.coerce(t,o,r.attributes,e,a)}if(!s("enabled"))return o;s("groups"),s("nameformat",a._dataLength>1?"%{group} (%{trace})":"%{group}");var l=t.styles,c=o.styles=[];if(l)for(i=0;i<l.length;i++){var u=c[i]={};n.coerce(l[i],c[i],r.attributes.styles,"target");var h=n.coerce(l[i],c[i],r.attributes.styles,"value");n.isPlainObject(h)?u.value=n.extendDeep({},h):h&&delete u.value}return o},r.transform=function(t,e){var r,n,a,i=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),a=0;a<r.length;a++)i.push(r[a]);return i}},{"../lib":717,"../plot_api/plot_schema":754,"../plots/plots":826,"./helpers":1300}],1300:[function(t,e,r){"use strict";r.pointsAccessorFunction=function(t,e){for(var r,n,a=0;a<t.length&&(r=t[a])!==e;a++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1301:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../plots/cartesian/axes"),i=t("./helpers").pointsAccessorFunction;r.moduleType="transform",r.name="sort",r.attributes={enabled:{valType:"boolean",dflt:!0,editType:"calc"},target:{valType:"string",strict:!0,noBlank:!0,arrayOk:!0,dflt:"x",editType:"calc"},order:{valType:"enumerated",values:["ascending","descending"],dflt:"ascending",editType:"calc"},editType:"calc"},r.supplyDefaults=function(t){var e={};function a(a,i){return n.coerce(t,e,r.attributes,a,i)}return a("enabled")&&(a("target"),a("order")),e},r.calcTransform=function(t,e,r){if(r.enabled){var o=n.getTargetArray(e,r);if(o){var s=r.target,l=o.length;e._length&&(l=Math.min(l,e._length));var c,u,h=e._arrayAttrs,f=function(t,e,r,n){var a,i=new Array(n),o=new Array(n);for(a=0;a<n;a++)i[a]={v:e[a],i:a};for(i.sort(function(t,e){switch(t.order){case"ascending":return function(t,r){return e(t.v)-e(r.v)};case"descending":return function(t,r){return e(r.v)-e(t.v)}}}(t,r)),a=0;a<n;a++)o[a]=i[a].i;return o}(r,o,a.getDataToCoordFunc(t,e,s,o),l),p=i(e.transforms,r),d={};for(c=0;c<h.length;c++){var g=n.nestedProperty(e,h[c]),v=g.get(),m=new Array(l);for(u=0;u<l;u++)m[u]=v[f[u]];g.set(m)}for(u=0;u<l;u++)d[u]=p(f[u]);r._indexToPoints=d,e._length=l}}}},{"../lib":717,"../plots/cartesian/axes":765,"./helpers":1300}],1302:[function(t,e,r){"use strict";r.version="1.53.0"},{}]},{},[26])(26)});
            });
            require(['plotly'], function(Plotly) {
                window._Plotly = Plotly;
            });
            }
            </script>




.. raw:: html

    <div>
    
    
                <div id="0e2424aa-7e60-41c5-9c9c-f5ddf3ef4b65" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("0e2424aa-7e60-41c5-9c9c-f5ddf3ef4b65")) {
                        Plotly.newPlot(
                            '0e2424aa-7e60-41c5-9c9c-f5ddf3ef4b65',
                            [{"marker": {"color": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 291, 292, 293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 304, 305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316, 317, 318, 319, 320, 321, 322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 370, 371, 372, 373, 374, 375, 376, 377, 378, 379, 380, 381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 391, 392, 393, 394, 395, 396, 397, 398, 399], "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "opacity": 0.8, "size": 4}, "mode": "markers", "type": "scatter3d", "x": [0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.9129452507276277, 0.836655638536056, -0.008851309290403876, -0.8462204041751706, -0.9055783620066239, -0.13235175009777303, 0.7625584504796028, 0.956375928404503, 0.27090578830786904, -0.6636338842129675, -0.9880316240928618, -0.404037645323065, 0.5514266812416906, 0.9999118601072672, 0.5290826861200238, -0.428182669496151, -0.9917788534431158, -0.6435381333569994, 0.2963685787093853, 0.9637953862840878, 0.7451131604793488, -0.158622668804709, -0.9165215479156338, -0.8317747426285983, 0.017701925105413577, 0.8509035245341184, 0.9017883476488092, 0.123573122745224, -0.7682546613236668, -0.9537526527594719, -0.26237485370392877, 0.6702291758433747, 0.9866275920404853, 0.3959251501818342, -0.5587890488516162, -0.9997551733586199, -0.5215510020869119, 0.43616475524782494, 0.9928726480845371, 0.6367380071391379, -0.3048106211022167, -0.9661177700083929, -0.7391806966492229, 0.16735570030280694, 0.9200260381967907, 0.8268286794901035, -0.026551154023966794, -0.8555199789753223, -0.8979276806892913, -0.11478481378318722, 0.7738906815578891, 0.9510546532543747, 0.25382336276203626, -0.6767719568873076, -0.9851462604682474, -0.38778163540943045, 0.5661076368981803, 0.9995201585807313, 0.5139784559875352, -0.4441126687075084, -0.9938886539233752, -0.629887994274454, 0.31322878243308516, 0.9683644611001854, 0.7331903200732921, -0.1760756199485871, -0.9234584470040598, -0.8218178366308225, 0.03539830273366069, 0.8600694058124533, 0.8939966636005579, 0.10598751175115685, -0.7794660696158047, -0.9482821412699473, -0.2452519854676543, 0.683261714736121, 0.9835877454343449, 0.37960773902752165, -0.5733818719904229, -0.9992068341863537, -0.5063656411097588, 0.45202578717835057, 0.9948267913584063, 0.6229886314423488, -0.32162240316253093, -0.9705352835374847, -0.7271425000808527, 0.18478174456066745, 0.926818505417785, 0.8167426066363169, -0.044242678085070965, -0.8645514486106083, -0.8899956043668333, -0.09718190589320902, 0.7849803886813105, 0.9454353340247703, 0.23666139336428602, -0.689697940935389, -0.9819521690440836, -0.3714041014380903, 0.5806111842123143, 0.9988152247235795, 0.4987131538963941, -0.45990349068959124, -0.9956869868891794, -0.6160404591886565, 0.3299908256737821, 0.972630067242408, 0.7210377105017316, -0.19347339203846847, -0.9301059501867618, -0.8116033871367005, 0.05308358714605824, 0.8689657562142357, 0.8859248164599484, 0.08836868610400142, -0.7904332067228887, -0.9425144545582509, -0.2280522595008612, 0.6960801312247415, 0.9802396594403116, 0.363171365373259, -0.5877950071674065, -0.9983453608739179, -0.49102159389846933, 0.4677451620451334, 0.9964691731217737, 0.6090440218832924, -0.3383333943242765, -0.9746486480944947, -0.7148764296291645, 0.2021498814156536, 0.933320523748862, 0.8064005807754863, -0.06192033725605731, -0.8733119827746476, -0.8817846188147811, -0.0795485428747221, 0.7958240965274552, 0.9395197317131483, 0.21942525837900473, -0.702407785577371, -0.9784503507933796, -0.35491017584493534, 0.5949327780232087, 0.9977972794498907, 0.4832915637282565, -0.47555018687189876, -0.9971732887740798, -0.6019998676776046, 0.3466494554970303, 0.9765908679435658, 0.7086591401823227, -0.21081053291348129, -0.9364619742512132, -0.8011345951780408, 0.07075223608034517, 0.8775897877771157, 0.8775753358042688, 0.07072216723899125, -0.8011526357338306, -0.936451400117644, -0.21078106590019152, 0.7086804082392084, 0.9765843832906294, 0.346621180094276, -0.6020239375552833, -0.997171023392149, -0.47552366901205834, 0.4833179536679627, 0.9977992786806003, 0.5949085484614269, -0.3549383576518463, -0.9784565746221131, -0.7023863292684921, 0.2194546679940636, 0.9395300555699313, 0.7958058429196471, -0.07957859166428352, -0.8817988360675502, -0.8732972972139945, -0.06189025071872073, 0.8064184068658304, 0.9333097001669604, 0.20212035931279124, -0.7148975077677644, -0.97464190312541, -0.33830502754097785, 0.6090679301910603, 0.9964666417661079, 0.46771851834275896, -0.491047853850463, -0.9983470937967718, -0.5877706198198406, 0.36319945137636067, 0.9802456219572225, 0.6960584883449115, -0.22808160941352787, -0.9425245273294025, -0.7904147414931815, 0.08839871248753149, 0.8859387978787574, 0.8689508382163493, 0.05305348526993529, -0.8116209973649744, -0.9300948780045254, -0.19344381715900788, 0.7210585970706318, 0.9726230624856244, 0.3299623697323973, -0.6160642040533644, -0.9956841897581032, -0.4598767232321427, 0.49873928180328125, 0.9988166912028082, 0.5805866409896447, -0.37143208943692263, -0.9819578697820255, -0.6896761131802671, 0.2366906812750767, 0.9454451549211168, 0.7849617132764033, -0.09721190751822434, -0.8900093488562771, -0.8645362993442719, -0.04421256322855966, 0.8167599996228085, 0.9268071855026884, 0.184752119221718, -0.727163193443649, -0.9705280195418053, -0.3215938602925038, 0.623012211003653, 0.9948237286710673, 0.45199889806298343, -0.5063916349244909, -0.9992080341070627, -0.5733571748155426, 0.37963562682930313, 0.9835931839466808, 0.6832397038158509, -0.24528120908194287, -0.9482917095220488, -0.7794471854988634, 0.10601748626711378, 0.8940101700837942, 0.8600540264645697, 0.035368177256176046, -0.8218350110128398, -0.9234468802429867, -0.17604594647121138, 0.7332108186087175, 0.9683569384347241, 0.3132001548706699, -0.6299114066849614, -0.9938853259197261, -0.4440856600409099, 0.5140043136735694, 0.99952109184891, 0.5660827877060441, -0.3878094208292295, -0.9851514363288851, -0.6767497645263834, 0.253852519790234, 0.9510639681125854, 0.7738715902084317, -0.11481475884166603, -0.8979409481081247, -0.8555043707508208, -0.026521020285755953, 0.8268456339220814, 0.9200142254959646, 0.1673259810118392, -0.739200998751274, -0.9661099892625297, -0.3047819110903029, 0.6367612505645516, 0.992869055025318, 0.4361376291460488, -0.5215767216183704, -0.9997558399011495, -0.5587640495890891, 0.39595283104274065, 0.9866325048439105, 0.6702068037805061, -0.2624039418616639, -0.9537617134939987, -0.7682353642374472, 0.12360303600011291, 0.9018013749637745, 0.8508876886558596, 0.017671785467370874, -0.8317914757822045, -0.9165094902005468, -0.15859290602857282, 0.7451332645574127, 0.9637873480674222, 0.29633978849732245, -0.6435612059762619, -0.9917749956098326, -0.42815542808445156, 0.5291082654818533, 0.9999122598719259, 0.551401533867395, -0.4040652194563607, -0.9880362734541701, -0.6636113342009432, 0.2709348053161655, 0.9563847343054627, 0.7625389491684937, -0.13238162920545193, -0.9055911481970673, -0.8462043418838514, -0.008821166113885877, 0.8366721491002946, 0.9129329489429682, 0.14984740573347818, -0.7510071512506542, -0.9613891968218607, -0.28787444850848604, 0.6503107401625526, 0.9906032333897737, 0.4201396822393068, -0.5365983551885637, -0.9999903395061709, -0.5439958173735323, 0.412145950487085, 0.9893626321783087, 0.6569638725243396, -0.279444441784382, -0.9589328250406132, -0.7567827912998033, 0.1411498506793914, 0.9093099708898409, 0.8414546973619527, -3.014435335948845e-05, -0.8414872714892108, -0.9092848819352602, -0.14109016531210986, 0.7568221986283603, 0.9589157234143065, 0.2793865543595699, -0.6570093243162466, -0.9893538601694428, -0.41209101962194344, 0.5440464039108651, 0.9999900726865629, 0.5365474803247321, -0.42019439103217676, -0.9906114770998198, -0.6502649395607762, 0.28793218456003195, 0.9614057860636483, 0.7509673416102893, -0.14990701345623575, -0.9129575516827102, -0.8366391272115635, 0.008881452458878848, 0.8462364656975445, 0.9055655749932976, 0.13232187086982847, -0.7625779510977886, -0.9563671216345017, -0.27087677105340535, 0.6636564336219596, 0.9880269738337468, 0.4040100708226276, -0.5514518281149146, -0.9999114594340064, -0.5290571062774264, 0.42820991051876856, 0.9917827103751873, 0.6435150601529656, -0.2963973686521434, -0.9638034236249698, -0.7450930557242139, 0.15865243143670757, 0.916533604797894, 0.8317580087191734, -0.017732064727370864], "y": [1.0, 0.5403023058681398, -0.4161468365471424, -0.9899924966004454, -0.6536436208636119, 0.2836621854632263, 0.9601702866503661, 0.7539022543433046, -0.14550003380861354, -0.9111302618846769, -0.8390715290764524, 0.004425697988050786, 0.8438539587324921, 0.9074467814501962, 0.1367372182078336, -0.7596879128588212, -0.9576594803233847, -0.27516333805159693, 0.6603167082440802, 0.9887046181866692, 0.40808206181339196, -0.5477292602242685, -0.9999608263946371, -0.5328330203333975, 0.4241790073369969, 0.9912028118634736, 0.6469193223286404, -0.2921388087338362, -0.9626058663135666, -0.7480575296890004, 0.15425144988758405, 0.9147423578045313, 0.8342233605065102, -0.013276747223059479, -0.8485702747846052, -0.9036922050915067, -0.12796368962740468, 0.7654140519453434, 0.9550736440472949, 0.2666429323599373, -0.6669380616522619, -0.9873392775238264, -0.3999853149883513, 0.5551133015206257, 0.9998433086476912, 0.5253219888177297, -0.4321779448847783, -0.9923354691509287, -0.6401443394691997, 0.3005925437436371, 0.9649660284921133, 0.7421541968137826, -0.16299078079570548, -0.9182827862121189, -0.8293098328631502, 0.022126756261955732, 0.853220107722584, 0.8998668269691938, 0.11918013544881928, -0.7710802229758452, -0.9524129804151563, -0.25810163593826746, 0.6735071623235862, 0.9858965815825497, 0.39185723042955, -0.562453851238172, -0.99964745596635, -0.5177697997895051, 0.4401430224960407, 0.9933903797222716, 0.6333192030862999, -0.3090227281660707, -0.9672505882738824, -0.7361927182273159, 0.17171734183077755, 0.9217512697247493, 0.8243313311075577, -0.030975031731216456, -0.8578030932449878, -0.8959709467909631, -0.11038724383904756, 0.7766859820216312, 0.9496776978825432, 0.2495401179733381, -0.6800234955873388, -0.9843766433940419, -0.38369844494974187, 0.569750334265312, 0.9993732836951247, 0.5101770449416688, -0.4480736161291701, -0.9943674609282015, -0.6264444479103392, 0.31742870151970165, 0.9694593666699876, 0.7301735609948197, -0.18043044929108393, -0.9251475365964139, -0.8192882452914593, 0.0398208803931389, 0.862318872287684, 0.8920048697881602, 0.10158570369662134, -0.782230889887116, -0.9468680107512126, -0.24095904923620143, 0.6864865509069841, 0.9827795820412206, 0.37550959776701204, -0.577002178942952, -0.999020813314648, -0.5025443191453852, 0.4559691044442761, 0.9952666362171313, 0.6195206125592099, -0.3258098052199642, -0.9715921906288022, -0.7240971967004738, 0.1891294205289584, 0.9284713207390763, 0.8141809705265618, -0.0486636092001539, -0.8667670910519801, -0.8879689066918555, -0.09277620459766088, 0.7877145121442345, 0.9439841391523142, 0.23235910202965793, -0.6928958219201651, -0.9811055226493881, -0.36729133045469653, 0.5842088171092893, 0.9985900724399912, 0.4948722204034305, -0.4638288688518717, -0.9960878351411849, -0.6125482394960996, 0.33416538263076073, 0.9736488930495181, 0.7179641014104721, -0.19781357400426822, -0.9317223617435201, -0.8090099069535975, 0.05750252534912421, 0.8711474010323434, 0.8838633737085002, 0.08395943674184846, -0.7931364191664784, -0.9410263090291437, -0.22374095013558368, 0.6992508064783751, 0.9793545963764285, 0.35904428689111606, -0.5913696841443248, -0.9980810948185003, -0.4871613498033415, 0.47165229356133864, 0.9968309933617175, 0.6055278749869899, -0.34249477911590703, -0.9756293127952373, -0.7117747556357235, 0.20648222933781113, 0.9349004048997503, 0.803775459710974, -0.06633693633562374, -0.875459459043705, -0.8796885924951523, -0.07513609089835323, 0.7984961861625555, 0.9379947521194415, 0.21510526876214114, -0.7055510066862999, -0.9775269404025313, -0.3507691132091306, 0.5984842190140996, 0.9974939203271522, 0.479412311470322, -0.47943876562917276, -0.9974960526543551, -0.5984600690578581, 0.3507973420904214, 0.9775332947055968, 0.7055296442942061, -0.21513470736462095, -0.9380052012169503, -0.7984780389030324, 0.07516615000819327, 0.879702927248347, 0.8754448901342752, 0.06630685835171127, -0.8037933932096717, -0.9348897059372352, -0.20645273449087873, 0.711795928940826, 0.9756226979194443, 0.3424664577455166, -0.6055518643146514, -0.9968285949694307, -0.47162571251991114, 0.48718767500700594, 0.9980829609135574, 0.591345375451585, -0.35907242107165305, -0.9793606896089245, -0.6992292566729736, 0.22377033018717848, 0.9410365074429887, 0.7931180595679168, -0.08398947462256867, -0.8838774731823718, -0.8711325991081119, -0.05747243084766546, 0.8090276252864301, 0.9317114137542325, 0.19778402522372224, -0.7179850839697137, -0.9736420181192547, -0.33413697099017103, 0.6125720663156843, 0.9960851708717215, 0.46380216301041793, -0.4948984145894023, -0.9985916721566993, -0.5841843515845697, 0.36731936773024515, 0.9811113543339269, 0.6928740863898233, -0.23238842122852268, -0.9439940860834779, -0.787695941645058, 0.09280621889587706, 0.8879827697817493, 0.8667520572726362, 0.048633500538969116, -0.8141984723053473, -0.9284601245807608, -0.18909982012986334, 0.7241179868699296, 0.9715850561826999, 0.3257813055351481, -0.619544275003953, -0.9952637062792294, -0.4559422758951242, 0.5025703802614232, 0.9990221465276736, 0.5769775585030581, -0.3755375359409301, -0.982785151720906, -0.68646463135462, 0.24098830528525864, 0.9468777054203809, 0.7822121099422712, -0.10161569206079699, -0.892018495407942, -0.8623036078310824, -0.03979075993115771, 0.8193055291449822, 0.9251360931462582, 0.18040079959254857, -0.7301941571456378, -0.9694519732670104, -0.3174001160235298, 0.6264679441263539, 0.9943642655514137, 0.44804666697426215, -0.510202970945957, -0.9993743503000143, -0.5697255608391865, 0.38372628183315116, 0.9843819506325049, 0.6800013937302881, -0.24956930858045798, -0.9496871395301657, -0.7766669941024745, 0.11041720391967796, 0.8959843338731037, 0.8577875993070563, 0.030944901828293042, -0.8243483956816764, -0.9217395798793158, -0.171687645155773, 0.7362131187458456, 0.9672429364932829, 0.30899405909813715, -0.6333425312327234, -0.9933869191569467, -0.44011595484676774, 0.5177955886508133, 0.9996482558795381, 0.5624289267667438, -0.3918849638415085, -0.9859016259639831, -0.6734848798934681, 0.2581307588164473, 0.9524221683015063, 0.7710610285700272, -0.11921006489861569, -0.8998799744648525, -0.8532043855172293, -0.022096619278683942, 0.8293266768209027, 0.9182708508872743, 0.1629610394708834, -0.7421744001016999, -0.9649581189333869, -0.3005637933500832, 0.6401674977183369, 0.9923317436681922, 0.43215076086181514, -0.5253476385155728, -0.9998438418065069, -0.5550882279566577, 0.4000129427560235, 0.987344058653017, 0.6669156003948422, -0.2666719852274808, -0.955082577452527, -0.7653946525566921, 0.12799358610147818, 0.903705111970614, 0.8485543255436181, 0.01324660552058789, -0.8342399825282195, -0.9147301779353751, -0.1542216662430943, 0.7480775341634341, 0.9625976995964054, 0.29210997926717525, -0.6469423088661069, -0.9911988217552068, -0.42415170907013605, 0.5328585288581932, 0.9999610927573088, 0.5477040395322043, -0.40810958177221934, -0.9887091356890289, -0.6602940699191361, 0.2751923186322931, 0.9576681585475916, 0.7596683100072248, -0.13676707936387883, -0.907459446701534, -0.8438377837054513, -0.004395553927897718, 0.8390879278598296, 0.911117838425468, 0.14547021017792156, -0.7539220584369601, -0.9601618634146094, -0.28363327918216646, 0.6536664338884767, 0.9899882421792622, 0.4161194261751267, -0.540327671221366, -0.999999999545659, -0.5402769400239504, 0.4161742465410129, 0.9899967501220404, 0.6536208072447929, -0.2836910914865273, -0.9601787090136331, -0.7538824495645917, 0.14552985730709223, 0.9111426845159583, 0.8390551295306261, -0.004455842044182302, -0.8438701329927379, -0.9074341153742778, -0.1367073569275377, 0.759707515020103, 0.9576508012289697, 0.27513435722086477, -0.6603393459690063, -0.9887000997858916, -0.40805454148374776, 0.5477544804186207, 0.9999605591233189, 0.5328075113244262, -0.42420630521841407, -0.9912068010710522, -0.6468963352033299, 0.29216763793503586, 0.9626140321560251, 0.7480375245348201, -0.15428123339190827, -0.9147545368424774, -0.8342067377267572, 0.013306888913466723, 0.8485862232545117, 0.9036792973912307, 0.12793379303705285, -0.7654334506384766, -0.9550647097742044, -0.26661387925010005, 0.6669605223036469, 0.9873344954974584, 0.3999576868572196, -0.5551383745801722, -0.9998427745803359], "z": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]}],
                            {"scene": {"xaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "0th"}, "type": "linear"}, "yaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "1st"}, "type": "linear"}, "zaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "2nd"}, "type": "linear"}}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('0e2424aa-7e60-41c5-9c9c-f5ddf3ef4b65');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Representing the sphere in 3d with parametric equations
    sphere = np.asarray([[np.cos(s)*np.cos(t),np.cos(s)*np.sin(t),np.sin(s)] for t in range(20) for s in range(20)])
    plot_point_cloud(sphere)



.. raw:: html

    <div>
    
    
                <div id="b3b45914-3a26-4958-9637-1913c4f71bd5" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("b3b45914-3a26-4958-9637-1913c4f71bd5")) {
                        Plotly.newPlot(
                            'b3b45914-3a26-4958-9637-1913c4f71bd5',
                            [{"marker": {"color": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 291, 292, 293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 304, 305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316, 317, 318, 319, 320, 321, 322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 370, 371, 372, 373, 374, 375, 376, 377, 378, 379, 380, 381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 391, 392, 393, 394, 395, 396, 397, 398, 399], "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "opacity": 0.8, "size": 4}, "mode": "markers", "type": "scatter3d", "x": [1.0, 0.5403023058681398, -0.4161468365471424, -0.9899924966004454, -0.6536436208636119, 0.2836621854632263, 0.9601702866503661, 0.7539022543433046, -0.14550003380861354, -0.9111302618846769, -0.8390715290764524, 0.004425697988050786, 0.8438539587324921, 0.9074467814501962, 0.1367372182078336, -0.7596879128588212, -0.9576594803233847, -0.27516333805159693, 0.6603167082440802, 0.9887046181866692, 0.5403023058681398, 0.2919265817264289, -0.2248450953661529, -0.5348952287053772, -0.35316515556860967, 0.1532633328933771, 0.5187822199032656, 0.40733512642087627, -0.07861400377068618, -0.492285781442533, -0.4533522819483131, 0.0023912148280198268, 0.45593623971912356, 0.49029558847016286, 0.07387943429568748, -0.41046113105777554, -0.5174256254552092, -0.14867138603965227, 0.3567706400675362, 0.5341993850287361, -0.4161468365471424, -0.2248450953661529, 0.17317818956819406, 0.411982245665683, 0.27201172505161186, -0.11804512112857043, -0.39957182733611274, -0.3137340382107254, 0.06054937878695679, 0.3791639761656777, 0.3491769624619393, -0.0018417402172403875, -0.3511671554343095, -0.37763110743538525, -0.056902760795446275, 0.3161417216992996, 0.3985269632259569, 0.11450835266392399, -0.2747887092549964, -0.4114462991379327, -0.9899924966004454, -0.5348952287053772, 0.411982245665683, 0.9800851433251829, 0.6471022801057221, -0.280823435177878, -0.9505613792425612, -0.7463575749700321, 0.14404394172563853, 0.9020121226914289, 0.8306745178967504, -0.0043814078003899665, -0.8354090873717491, -0.8983655046999185, -0.13536882003177308, 0.752085333488286, 0.9480756998184328, 0.2724096400106128, -0.6537085865415448, -0.9788101533590108, -0.6536436208636119, -0.35316515556860967, 0.27201172505161186, 0.6471022801057221, 0.4272499830956933, -0.18541397800826867, -0.6276091828117975, -0.49278339930619736, 0.09510516893444011, 0.5955544834567112, 0.5484537524290998, -0.002892829257758318, -0.5515797570659992, -0.593146799968137, -0.08937741041618616, 0.49656515808736, 0.6259680102729421, 0.1798587606129639, -0.43161180409340183, -0.6462604665961094, 0.2836621854632263, 0.1532633328933771, -0.11804512112857043, -0.280823435177878, -0.18541397800826867, 0.0804642354617738, 0.2723640019280953, 0.21385356109267487, -0.04127285757512463, -0.2584532013278892, -0.23801286369779753, 0.0012554031634906897, 0.2393694581458539, 0.2574083372177333, 0.03878717815099614, -0.21549473363153024, -0.27165178111810884, -0.07805343383107252, 0.18730688055839936, 0.28045811277241534, 0.9601702866503661, 0.5187822199032656, -0.39957182733611274, -0.9505613792425612, -0.6276091828117975, 0.2723640019280953, 0.9219269793662461, 0.7238745436591679, -0.13970480916965441, -0.8748402047296334, -0.8056515505934984, 0.004249423705814672, 0.8102434974472231, 0.871303436264987, 0.13129101400238924, -0.7294297610544727, -0.9195161777355448, -0.2642036611726734, 0.6340164830347446, 0.9493247966568349, 0.7539022543433046, 0.40733512642087627, -0.3137340382107254, -0.7463575749700321, -0.49278339930619736, 0.21385356109267487, 0.7238745436591679, 0.5683686091039167, -0.10969280349534079, -0.6869031584352634, -0.6325779173260212, 0.0033365436902341155, 0.6361834018249477, 0.6841261742318789, 0.10308649705951811, -0.5727304301016253, -0.7219816411090373, -0.20744626086972773, 0.4978142549257622, 0.7453866405305661, -0.14550003380861354, -0.07861400377068618, 0.06054937878695679, 0.14404394172563853, 0.09510516893444011, -0.04127285757512463, -0.13970480916965441, -0.10969280349534079, 0.021170259838307684, 0.1325694839082714, 0.12208493584846888, -0.0006439392068881023, -0.12278077952510998, -0.1320335373805211, -0.019895269872135555, 0.11053461700495354, 0.13933948676419175, 0.04003627498939831, -0.09607610337390607, -0.1438565553728927, -0.9111302618846769, -0.492285781442533, 0.3791639761656777, 0.9020121226914289, 0.5955544834567112, -0.2584532013278892, -0.8748402047296334, -0.6869031584352634, 0.1325694839082714, 0.83015835412204, 0.7645034620274044, -0.0040323873668752005, -0.768860878412357, -0.8268022236291245, -0.12458541743508565, 0.6921746469936814, 0.8725525331033891, 0.2507096442600134, -0.6016345353092566, -0.9008386976950095, -0.8390715290764524, -0.4533522819483131, 0.3491769624619393, 0.8306745178967504, 0.5484537524290998, -0.23801286369779753, -0.8056515505934984, -0.6325779173260212, 0.12208493584846888, 0.7645034620274044, 0.704041030906696, -0.0037134771780643525, -0.7080538314708897, -0.7614127584669215, -0.11473230676330748, 0.6374324986633498, 0.8035448044895032, 0.23088172280473424, -0.5540529500610901, -0.8295938957868386, 0.004425697988050786, 0.0023912148280198268, -0.0018417402172403875, -0.0043814078003899665, -0.002892829257758318, 0.0012554031634906897, 0.004249423705814672, 0.0033365436902341155, -0.0006439392068881023, -0.0040323873668752005, -0.0037134771780643525, 1.958680268143678e-05, 0.003734642767371082, 0.004016085394927295, 0.0006051576315140706, -0.003362149267485786, -0.004238311635304965, -0.001217789831600291, 0.002922362327152144, 0.004375708039485263, 0.8438539587324921, 0.45593623971912356, -0.3511671554343095, -0.8354090873717491, -0.5515797570659992, 0.2393694581458539, 0.8102434974472231, 0.6361834018249477, -0.12278077952510998, -0.768860878412357, -0.7080538314708897, 0.003734642767371082, 0.7120895036684985, 0.7657525588658066, 0.11538624289074899, -0.6410656526671408, -0.8081247435885893, -0.23219767211288705, 0.557210868268975, 0.834322306073918, 0.9074467814501962, 0.49029558847016286, -0.37763110743538525, -0.8983655046999185, -0.593146799968137, 0.2574083372177333, 0.871303436264987, 0.6841261742318789, -0.1320335373805211, -0.8268022236291245, -0.7614127584669215, 0.004016085394927295, 0.7657525588658066, 0.8234596611643201, 0.12408174856715178, -0.6893763514303544, -0.8690250131447229, -0.24969608548801392, 0.5992022716338787, 0.8971968235784381, 0.1367372182078336, 0.07387943429568748, -0.056902760795446275, -0.13536882003177308, -0.08937741041618616, 0.03878717815099614, 0.13129101400238924, 0.10308649705951811, -0.019895269872135555, -0.12458541743508565, -0.11473230676330748, 0.0006051576315140706, 0.11538624289074899, 0.12408174856715178, 0.018697066843216703, -0.10387761191043031, -0.13094769332977918, -0.037625069397957095, 0.0902898698214492, 0.1351927191200834, -0.7596879128588212, -0.41046113105777554, 0.3161417216992996, 0.752085333488286, 0.49656515808736, -0.21549473363153024, -0.7294297610544727, -0.5727304301016253, 0.11053461700495354, 0.6921746469936814, 0.6374324986633498, -0.003362149267485786, -0.6410656526671408, -0.6893763514303544, -0.10387761191043031, 0.5771257249437919, 0.7275223318363354, 0.20903826197968392, -0.5016346219117525, -0.7511069478241085, -0.9576594803233847, -0.5174256254552092, 0.3985269632259569, 0.9480756998184328, 0.6259680102729421, -0.27165178111810884, -0.9195161777355448, -0.7219816411090373, 0.13933948676419175, 0.8725525331033891, 0.8035448044895032, -0.004238311635304965, -0.8081247435885893, -0.8690250131447229, -0.13094769332977918, 0.7275223318363354, 0.9171116802532552, 0.26351277932254014, -0.6323585556658738, -0.9468423508459761, -0.27516333805159693, -0.14867138603965227, 0.11450835266392399, 0.2724096400106128, 0.1798587606129639, -0.07805343383107252, -0.2642036611726734, -0.20744626086972773, 0.04003627498939831, 0.2507096442600134, 0.23088172280473424, -0.001217789831600291, -0.23219767211288705, -0.24969608548801392, -0.037625069397957095, 0.20903826197968392, 0.26351277932254014, 0.07571486260769741, -0.18169494961168353, -0.2720552630872735, 0.6603167082440802, 0.3567706400675362, -0.2747887092549964, -0.6537085865415448, -0.43161180409340183, 0.18730688055839936, 0.6340164830347446, 0.4978142549257622, -0.09607610337390607, -0.6016345353092566, -0.5540529500610901, 0.002922362327152144, 0.557210868268975, 0.5992022716338787, 0.0902898698214492, -0.5016346219117525, -0.6323585556658738, -0.18169494961168353, 0.4360181551862977, 0.6528581789067416, 0.9887046181866692, 0.5341993850287361, -0.4114462991379327, -0.9788101533590108, -0.6462604665961094, 0.28045811277241534, 0.9493247966568349, 0.7453866405305661, -0.1438565553728927, -0.9008386976950095, -0.8295938957868386, 0.004375708039485263, 0.834322306073918, 0.8971968235784381, 0.1351927191200834, -0.7511069478241085, -0.9468423508459761, -0.2720552630872735, 0.6528581789067416, 0.9775368220236473], "y": [0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.8414709848078965, 0.4546487134128409, -0.35017548837401463, -0.833049961066805, -0.5500221413615028, 0.23869349855450123, 0.8079554366909638, 0.6343868724111538, -0.12243405673851628, -0.7666896787563757, -0.70605434589623, 0.0037240964444674213, 0.7100786216886722, 0.7635901368476526, 0.11506040166523798, -0.6392553361799678, -0.8058426660183369, -0.2315419650533054, 0.5556373507712546, 0.8319662487496519, 0.9092974268256817, 0.49129549643388193, -0.37840124765396416, -0.9001976297355174, -0.5943564625123038, 0.25793329532946097, 0.873080370965655, 0.6855213799524474, -0.13230280634522198, -0.8284884026347462, -0.7629655823119084, 0.004024275792442177, 0.7673142332921201, 0.8251390233539102, 0.12433480066768485, -0.6907822643530989, -0.8707973012332733, -0.2502053152470823, 0.6004242836963465, 0.8990265652078064, 0.1411200080598672, 0.07624746575887673, -0.05872664492762098, -0.13970774909946293, -0.09224219304455371, 0.040030409898850046, 0.13549923859094468, 0.10639069220927921, -0.020532965943782493, -0.12857870990075454, -0.11840978094607407, 0.0006245545357442651, 0.11908467745768014, 0.12805889711215224, 0.019296357335573302, -0.10720716438562054, -0.1351449135818443, -0.03883105248362133, 0.09318389918946958, 0.1395260036873307, -0.7568024953079282, -0.4089021333016356, 0.3149409643133779, 0.7492287917633427, 0.4946791233116909, -0.21467624978306998, -0.7266592688575257, -0.5705551073052852, 0.11011478865374665, 0.6895456557448896, 0.635011426946898, -0.0033493792808361126, -0.6386307816442235, -0.6867579885606566, -0.10348306794115315, 0.5749337081068278, 0.7247590843640312, 0.20824430085470755, -0.49972933249263707, -0.7482541221661436, -0.9589242746631385, -0.5181089967534271, 0.39905330338932815, 0.9493278367245317, 0.6267947350248265, -0.27201055544468494, -0.9207305956793, -0.7229351724130583, 0.13952351438338687, 0.8737049255013992, 0.8046060574101277, -0.004243909233069712, -0.809192045299173, -0.8701727466975289, -0.13112063778940214, 0.7284831808084986, 0.9183229225433798, 0.2638608043550156, -0.6331937205009058, -0.948092858850747, -0.27941549819892586, -0.1509688379721747, 0.11627787565772676, 0.2766192466508119, 0.18263815796815594, -0.07925961087140349, -0.26828645900021747, -0.21065197399062777, 0.04065496443459431, 0.2545839160486248, 0.23444958932143145, -0.0012366086082091943, -0.23578587428637512, -0.25355469452791835, -0.03820649794787706, 0.2122685766471497, 0.26758490079948294, 0.0768849011877664, -0.18450272200309445, -0.27625939346220696, 0.6569865987187891, 0.35497137421222796, -0.27340289471069096, -0.650411803098649, -0.4294350992454181, 0.18636225441262338, 0.6308190108172688, 0.4953036778474351, -0.09559157232538983, -0.5986003717453734, -0.551258749969712, 0.002907624268126074, 0.5544007421630454, 0.5961803744632768, 0.08983451990863348, -0.49910477795689273, -0.6291694447084636, -0.180778625558627, 0.43381922822646524, 0.6495656842400188, 0.9893582466233818, 0.5345525419802729, -0.4117183045441479, -0.979457240606921, -0.6466877066541816, 0.28064352244325413, 0.9499523912602761, 0.7458794124825067, -0.14395165833253265, -0.9014342383437266, -0.8301423367986789, 0.004378600801542554, 0.834873873017778, 0.8977899565995973, 0.135282094454261, -0.7516035014469798, -0.9474683043150028, -0.2722351176697648, 0.6532897806844863, 0.9781830674776032, 0.4121184852417566, 0.222668567867006, -0.1715018039159572, -0.40799420809968046, -0.2693786189182488, 0.11690243019347105, 0.3957039241084921, 0.3106970550803082, -0.05996325353583019, -0.375493623385838, -0.3457968875724721, 0.0018239119509729797, 0.3477678152380944, 0.3739755930087622, 0.05635193524398392, -0.31308143190384896, -0.3946691744082811, -0.11339989807188953, 0.27212872158137325, 0.4074634495986194, -0.5440211108893699, -0.2939358606544735, 0.22639266431147345, 0.538576817772715, 0.3555959287479723, -0.15431821725301084, -0.5223529059864969, -0.41013874190984484, 0.07915509002700281, 0.49567409723542444, 0.4564726253638139, -0.002407673135920238, -0.45907436805804286, -0.493670206117519, -0.07438793334934782, 0.4132862622826827, 0.5209869743392643, 0.14969466484285698, -0.3592262291577564, -0.5378761847273621, -0.9999902065507035, -0.5402970144449024, 0.4161427610341988, 0.9899828011591261, 0.653637219437953, -0.28365940743199564, -0.9601608832713477, -0.7538948710398021, 0.14549860886140978, 0.9111213387766547, 0.8390633116719762, -0.004425654645201939, -0.8438456944915336, -0.9074378944161527, -0.13673587907882015, 0.7596804728937654, 0.9576501015338208, 0.27516064325339745, -0.6603102414658784, -0.9886949353581218, -0.5365729180004349, -0.2899115848620313, 0.22329312240275023, 0.5312031626994367, 0.35072746497915824, -0.1522054465803839, -0.515201372485301, -0.40452353250009304, 0.0780713777098497, 0.4888878232979616, 0.45022305876763885, -0.0023747096836370645, -0.4527891810033119, -0.48691136745283475, -0.07336948817303948, 0.40762796017231784, 0.5138541418078986, 0.14764519522508548, -0.3543080629469679, -0.530512122020927, 0.4201670368266409, 0.22701721884721768, -0.1748511831967933, -0.41596221377721754, -0.27463950331890014, 0.11918549992585285, 0.4034319041908707, 0.31676487626435085, -0.06113431806354122, -0.38282690229916605, -0.3525501980576517, 0.0018595324095289254, 0.35455961735506175, 0.38127922523980134, 0.057452471798303255, -0.3191958192589063, -0.4023769461364174, -0.11561456439246677, 0.27744331467003674, 0.41542108972030817, 0.9906073556948704, 0.5352274384918789, -0.4122381173327502, -0.9806938492151301, -0.647504178830523, 0.2809978474523545, 0.9511517486755048, 0.7468211186274225, -0.1441334037446649, -0.9025723394191545, -0.8311904286572761, 0.004384128981047097, 0.8359279386526423, 0.8989234566061998, 0.13545289415393452, -0.752552434510432, -0.9486645254592718, -0.27257882669146616, 0.6541145882748095, 0.9794180673852028, 0.6502878401571169, 0.3513520195149026, -0.270615227526458, -0.6437800823860556, -0.4250564984438756, 0.18446206991912897, 0.6243870618889064, 0.490253468666489, -0.09461690272819079, -0.5924969301027749, -0.5456380123804558, 0.0028779775858372436, 0.5487479682321852, 0.5901016075667754, 0.08891855029746452, -0.4940158120464309, -0.6227543150654808, -0.1789353727919956, 0.4293959260237, 0.6429425907139761, -0.2879033166650653, -0.15555482586122002, 0.1198100544615971, 0.28502212324479664, 0.18818616636359636, -0.08166728400732373, -0.2764362100898869, -0.21705095946670702, 0.04188994230837897, 0.26231742431050803, 0.24157147614033844, -0.001274173129317728, -0.24294835350002963, -0.26125693807655015, -0.03936709863359005, 0.21871666974241574, 0.2757133406208453, 0.07922043764968532, -0.19010737035282896, -0.28465133877800913, -0.9613974918795568, -0.5194452817183707, 0.4000825249100346, 0.9517763032112488, 0.6284113376813485, -0.2727121136454194, -0.923105305362937, -0.7247997364479968, 0.13988336757199177, 0.8759583485514921, 0.806681263561646, -0.004254854945528427, -0.811279079438053, -0.872417059700395, -0.1314588186315989, 0.730362054033686, 0.9206914224575818, 0.2645413430600119, -0.6348268271520238, -0.9505381401343986, -0.750987246771676, -0.4057601411083023, 0.3125209670312812, 0.7434717393465864, 0.4908780232022332, -0.21302668367426486, -0.7210756400035294, -0.5661709783242381, 0.10926866979511646, 0.6842472068231297, 0.6301320174656253, -0.003323642747089206, -0.6337235611458938, -0.6814809599931017, -0.10268790703311885, 0.570515934083567, 0.7191900564728527, 0.20664415765587274, -0.49588942672155784, -0.742504559082448, 0.14987720966295234, 0.08097900197797579, -0.06237092667175042, -0.1483773129777346, -0.09796628200902689, 0.04251449684412324, 0.14390764336443396, 0.11299276623958389, -0.021807139073100227, -0.1365576612907504, -0.12575769948560547, 0.0006633112652599941, 0.12647447669786205, 0.13600559152138234, 0.020493792722064343, -0.11385990459395222, -0.14353133071814192, -0.04124071330871702, 0.09896642572544853, 0.14818428935469266], "z": [0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234]}],
                            {"scene": {"xaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "0th"}, "type": "linear"}, "yaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "1st"}, "type": "linear"}, "zaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "2nd"}, "type": "linear"}}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('b3b45914-3a26-4958-9637-1913c4f71bd5');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Representing the torus in 3d with parametric equations
    torus = np.asarray([[(2+np.cos(s))*np.cos(t),(2+np.cos(s))*np.sin(t),np.sin(s)] for t in range(20) for s in range(20)])
    plot_point_cloud(torus)



.. raw:: html

    <div>
    
    
                <div id="faabaefa-6334-4b5a-9a74-3e4bd3a00e01" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("faabaefa-6334-4b5a-9a74-3e4bd3a00e01")) {
                        Plotly.newPlot(
                            'faabaefa-6334-4b5a-9a74-3e4bd3a00e01',
                            [{"marker": {"color": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 291, 292, 293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 304, 305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316, 317, 318, 319, 320, 321, 322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 370, 371, 372, 373, 374, 375, 376, 377, 378, 379, 380, 381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 391, 392, 393, 394, 395, 396, 397, 398, 399], "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "opacity": 0.8, "size": 4}, "mode": "markers", "type": "scatter3d", "x": [3.0, 2.5403023058681398, 1.5838531634528576, 1.0100075033995546, 1.3463563791363882, 2.283662185463226, 2.9601702866503663, 2.7539022543433047, 1.8544999661913866, 1.088869738115323, 1.1609284709235475, 2.004425697988051, 2.8438539587324922, 2.9074467814501963, 2.1367372182078337, 1.2403120871411788, 1.0423405196766153, 1.724836661948403, 2.66031670824408, 2.988704618186669, 1.6209069176044193, 1.3725311934627085, 0.8557595163701267, 0.5457093830309023, 0.7274394561676699, 1.2338679446296565, 1.5993868316395452, 1.4879397381571557, 1.0019906079655934, 0.5883188302937464, 0.6272523297879663, 1.0829958265642994, 1.536540851455403, 1.5709002002064425, 1.154484046031967, 0.670143480678504, 0.5631789862810703, 0.9319332256966273, 1.4373752518038156, 1.6148039967650156, -1.2484405096414273, -1.0571387684604376, -0.6591154835260907, -0.42031142742860184, -0.5602819480426731, -0.9503387942228552, -1.2318655004303978, -1.1460277113050101, -0.771744294307328, -0.45312969692860705, -0.48311671063234546, -0.8341354133115252, -1.1834608285285944, -1.20992478052967, -0.8891964338897311, -0.5161519513949852, -0.43376670986832794, -0.7177853204303608, -1.1070823823492812, -1.2437399722322175, -2.9699774898013365, -2.514880221906268, -1.5680027475352079, -0.9998998498757079, -1.3328827130951688, -2.260808428378769, -2.930546372443452, -2.726342568170923, -1.8359410514752523, -1.0779728705094618, -1.1493104753041403, -1.984366401001281, -2.81539408057264, -2.878350497900809, -2.115353813232664, -1.2278996597126048, -1.031909293382458, -1.707575353190278, -2.633693579742436, -2.958795146559902, -1.960930862590836, -1.6604523972958336, -1.035275516675612, -0.6601849616215018, -0.8800372586315307, -1.4927012197354925, -1.9348964245390214, -1.8000706410334213, -1.212182072792784, -0.7117327582705125, -0.758833489298124, -1.3101800709849822, -1.8588669987932231, -1.900434041695361, -1.39666465214341, -0.8107220836398639, -0.6813192314542817, -1.1274284811142599, -1.7388990458206257, -1.9535477083233332, 0.8509865563896789, 0.7205877038198297, 0.4492792497978822, 0.2865009357485746, 0.38191039291818396, 0.6477886063882263, 0.839688372854548, 0.7811779320191276, 0.526051513351328, 0.30887116959856337, 0.32931150722865504, 0.5685797740899433, 0.8066938290723066, 0.824732708144186, 0.6061115490774488, 0.35182963729492234, 0.29567258980834377, 0.48927093709538005, 0.754631251484852, 0.8477824836988679, 2.880510859951098, 2.439122793203998, 1.5207687459646195, 0.9697791940581709, 1.2927313904889348, 2.1927045752288272, 2.8422675526669785, 2.6442151169599004, 1.780635764131078, 1.0455003685710986, 1.1146890227072337, 1.9245899970065468, 2.7305840707479554, 2.791644009565719, 2.0516315873031217, 1.1909108122462595, 1.0008243955651872, 1.6561369121280587, 2.5543570563354767, 2.869665369957567, 2.2617067630299137, 1.9151396351074854, 1.1940704704758838, 0.7614469337165771, 1.015021109380412, 1.721658069779284, 2.2316790523457772, 2.076173117790526, 1.3981117051912686, 0.8209013502513457, 0.875226591360588, 1.5111410523768434, 2.143987910511557, 2.191930682918488, 1.6108910057461274, 0.9350740785849839, 0.7858228675775719, 1.3003582478168814, 2.0056187636123712, 2.2531911492171752, -0.4365001014258406, -0.36961407138791325, -0.23045068883027028, -0.14695612589158855, -0.19589489868278698, -0.3322729251923517, -0.4307048767868815, -0.40069287111256785, -0.2698298077789194, -0.15843058370895566, -0.16891513176875816, -0.2916440068241152, -0.4137808471423371, -0.42303360499774817, -0.31089533748936266, -0.18046545061227354, -0.15166058085303533, -0.25096379262782875, -0.3870761709911331, -0.4348566229901198, -2.7333907856540307, -2.314546305211887, -1.4430965476036761, -0.9202484010779249, -1.2267060403126429, -2.080713725097243, -2.6971007284989876, -2.5091636822046173, -1.6896910398610825, -0.9921021696473138, -1.0577570617419494, -1.8262929111362292, -2.591121402181711, -2.6490627473984785, -1.9468459412044397, -1.1300858767756725, -0.9497079906659648, -1.5715508795093405, -2.4238950590786104, -2.7230992214643632, -2.517214587229357, -2.131495340101218, -1.3289660956909657, -0.8474685402561545, -1.129689305723805, -1.9161559218507023, -2.4837946087464036, -2.310720975478926, -1.556058122304436, -0.9136395961255004, -0.9741020272462089, -1.6818565353309693, -2.3861968896237946, -2.4395558166198263, -1.7928753649162124, -1.040710559489555, -0.8745982536634017, -1.4472613353481707, -2.232196008213995, -2.5077369539397436, 0.013277093964152359, 0.0112426108041214, 0.007009655758861185, 0.004469988175711606, 0.005958566718343255, 0.010106799139592261, 0.013100819681916245, 0.012187939666335688, 0.00820745676921347, 0.004819008609226371, 0.00513791879803722, 0.00887098277878301, 0.012586038743472654, 0.012867481371028867, 0.009456553607615643, 0.005489246708615786, 0.004613084340796608, 0.007633606144501282, 0.011773758303253716, 0.013227104015586836, 2.5315618761974763, 2.1436441571841076, 1.3365407620306748, 0.8522988300932351, 1.1361281603989852, 1.9270773756108381, 2.4979514149122077, 2.323891319289932, 1.5649271379398744, 0.9188470390526272, 0.9796540859940944, 1.6914425602323553, 2.3997974211334827, 2.453460476330791, 1.8030941603557333, 1.0466422647978435, 0.879583173876395, 1.4555102453520972, 2.2449187857339594, 2.522030223538902, 2.7223403443505885, 2.305189151370555, 1.437262455465007, 0.9165280582004739, 1.2217467629322556, 2.0723019001181258, 2.6861969991653796, 2.4990197371322713, 1.6828600255198713, 0.9880913392712678, 1.053480804433471, 1.8189096482953198, 2.580646121766199, 2.6383532240647125, 1.9389753114675443, 1.125517211470038, 0.9458685497556695, 1.5651974774123785, 2.414095834534271, 2.7120903864788306, 0.41021165462350084, 0.3473538707113547, 0.21657167562022095, 0.13810561638389413, 0.18409702599948105, 0.31226161456666335, 0.4047654504180565, 0.3765609334751853, 0.2535791665435317, 0.14888901898058154, 0.15874212965235973, 0.2740795940471813, 0.3888606793064162, 0.39755618498281897, 0.2921715032588839, 0.1695968245052369, 0.14252674308588803, 0.23584936701771012, 0.3637643062371164, 0.4086671555357506, -2.279063738576464, -1.9298369567754179, -1.2032341040183427, -0.7672904922293564, -1.0228106676302824, -1.7348705593491727, -2.2488055867721153, -2.092106255819268, -1.408841208712689, -0.8272011787239609, -0.8819433270542925, -1.5227379749851282, -2.1604414783847834, -2.2087521771479968, -1.6232534376280727, -0.9422501007738505, -0.791853493881307, -1.3103375637379584, -2.021010447629395, -2.270482773541751, -2.872978440970154, -2.4327445861019785, -1.5167919974208124, -0.9672432608283366, -1.2893509503738274, -2.186970741764878, -2.8348351383823145, -2.6373006017558067, -1.7759794738825776, -1.0427664275433801, -1.111774156157266, -1.9195572722820744, -2.7234437042353585, -2.784343973791492, -2.0462666539765486, -1.1877966288104338, -0.9982072803935141, -1.651806181324229, -2.547677516312643, -2.8621613114927453, -0.8254900141547907, -0.6989980621428461, -0.43581832343926985, -0.27791703609258106, -0.37046791549023, -0.6283801099342663, -0.8145303372758673, -0.7577729369729216, -0.5102904011137955, -0.29961703184318045, -0.3194449532984596, -0.5515444659347941, -0.782524348216081, -0.8000227615912078, -0.5879517455011509, -0.3412884141235099, -0.2868138967806537, -0.4746118134954964, -0.7320216257148774, -0.8223819391904674, 1.9809501247322405, 1.6774040565556965, 1.045844707233164, 0.6669248299466155, 0.8890216123947586, 1.5079402970465596, 1.9546498995229051, 1.8184476714139226, 1.2245573131142544, 0.7189988811789036, 0.7665804664270702, 1.3235557788153125, 1.8778442847571355, 1.9198356881220393, 1.4109232863096095, 0.8189987945764079, 0.6882748608222865, 1.1389384668764768, 1.756651571674458, 1.973491595394902, 2.9661138545600076, 2.5116086214020745, 1.5659629372354058, 0.9985990830143276, 1.331148769777229, 2.2578673491457537, 2.9267340330301734, 2.7227958769039047, 1.8335526810004459, 1.0765705386783289, 1.1478153405864997, 1.9817849444128237, 2.8117315424472564, 2.8746060599517764, 2.112601955493422, 1.22630228854923, 1.0305668855273624, 1.7053539732860648, 2.63026741528008, 2.954946058396986], "y": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.5244129544236893, 2.137590683028634, 1.3327664812417783, 0.849892008548988, 1.1329198282542903, 1.921635468170294, 2.490897406306757, 2.317328842026947, 1.5605079128772767, 0.9162522908594172, 0.976887623719563, 1.6866660660602604, 2.3930205913044653, 2.4465321064634455, 1.7980023712810311, 1.0436866334358252, 0.8770993035974561, 1.4514000045624875, 2.2385793203870477, 2.514908218365445, 2.727892280477045, 2.3098903500852455, 1.4401936059973994, 0.918397223915846, 1.2242383911390597, 2.0765281489808243, 2.691675224617019, 2.504116233603811, 1.6862920473061416, 0.9901064510166171, 1.0556292713394548, 1.8226191294438057, 2.5859090869434835, 2.643733877005274, 1.9429296543190484, 1.1278125892982647, 0.9477975524180902, 1.5683895384042812, 2.41901913734771, 2.71762141885917, 0.4233600241796016, 0.3584874818786111, 0.22351337119211345, 0.1425322670202715, 0.18999782307518073, 0.32227042601858447, 0.41773925471067913, 0.38863070832901364, 0.26170705017595197, 0.1536613062189799, 0.16383023517366033, 0.2828645706554787, 0.40132469357741457, 0.41029891323188666, 0.30153637345530776, 0.17503285173411387, 0.14709510253789013, 0.24340896363611308, 0.375423915309204, 0.42176601980706513, -2.2704074859237844, -1.922507123917492, -1.1986640263024786, -0.7643761988525137, -1.0189258673041657, -1.7282812403989263, -2.240264259473382, -2.0841600979211417, -1.4034902019621098, -0.8240593348709667, -0.8785935636689582, -1.5169543698966925, -2.15223577226008, -2.2003629791765134, -1.6170880585570095, -0.9386712825090286, -0.7888459062518252, -1.3053606897611487, -2.0133343231084937, -2.261859112782, -2.8767728239894153, -2.435957546079704, -1.5187952459369487, -0.9685207126017452, -1.2910538143014505, -2.189859104770962, -2.838579145005577, -2.6407837217393353, -1.77832503494289, -1.0441436238248776, -1.1132424919161492, -1.9220924585593466, -2.72704059462545, -2.788021296023806, -2.048969187115679, -1.1893653685177783, -0.9995256267828971, -1.6539877449712612, -2.5510422698271826, -2.865941408177024, -0.8382464945967776, -0.7097998343700264, -0.442553120740125, -0.28221174974703983, -0.3761928384296958, -0.6380906072692552, -0.8271174553980692, -0.7694829703884796, -0.5181760319632575, -0.3042470803492269, -0.3243814070764202, -0.5600676050060609, -0.7946168706842268, -0.8123856909257701, -0.5970374943457288, -0.346562419750702, -0.2912460955983688, -0.4819460952100853, -0.7433337184009462, -0.8350903898600587, 1.9709597961563672, 1.6689445716498061, 1.040570302726887, 0.6635613943389291, 0.8845380981921601, 1.5003354518502015, 1.944792208254847, 1.8092768752850132, 1.2183816251121884, 0.7153728256922046, 0.7627144474678661, 1.3168808217057042, 1.8683739396006236, 1.9101535719008549, 1.4038077173462116, 0.8148684194806853, 0.6848037527291145, 1.1331945718789511, 1.7477924256640434, 1.963538881677597, 2.9680747398701453, 2.5132690352270366, 1.5669981887026159, 0.9992592526398426, 1.332028786592582, 2.2593600156900178, 2.9286688845070397, 2.72459590572927, 1.834764834914231, 1.0772822549030368, 1.1485741564480845, 1.983095094048306, 2.813590366264542, 2.876506449846361, 2.113998587701025, 1.2271129917997838, 1.0312481889317608, 1.7064813755769987, 2.6320062739312498, 2.956899560724367, 1.2363554557252698, 1.0469055383505192, 0.652735166567556, 0.41624276238383273, 0.5548583515652644, 0.9411394006769842, 1.2199408945920054, 1.1349340255638214, 0.7642737169476831, 0.4487433470976751, 0.47844008291104106, 0.8260608824344862, 1.1720047857216076, 1.1982125634922753, 0.8805889057274972, 0.5111555385796642, 0.4295677960752321, 0.7108370724116236, 1.0963656920648865, 1.2317004200821327, -1.6320633326681095, -1.3819780824332133, -0.8616495574672663, -0.5494654040060247, -0.7324462930307676, -1.2423604390317506, -1.6103951277652369, -1.4981809636885848, -1.008887131751737, -0.5923681245433152, -0.6315695964149258, -1.09044989491466, -1.5471165898367827, -1.5817124278962589, -1.1624301551280876, -0.674755959496057, -0.5670552474394754, -0.9383475569358828, -1.4472684509364961, -1.6259184065061019, -2.9999706196521103, -2.5402774275463096, -1.5838376520672082, -1.0099976119422809, -1.346343193663454, -2.2836398205334025, -2.960141296372755, -2.753875284141209, -1.8544818042399973, -1.0888590743247522, -1.1609171014294306, -2.004406067746609, -2.8438261075929407, -2.9074183075175597, -2.136716292180227, -1.2402999402076416, -1.0423303115675862, -1.7248197698480094, -2.660290654567285, -2.9886753484595285, -1.609718754001305, -1.3630574208629012, -0.8498527135981196, -0.5419426733014332, -0.7224183710217117, -1.2253512825812538, -1.588347208486171, -1.477669368500963, -0.9950744582910203, -0.5842580127029082, -0.622922777233231, -1.075520545684507, -1.5259350170041819, -1.5600572034537046, -1.1465153241739094, -0.665517875828552, -0.5592916941929713, -0.9255006407757844, -1.4274538989478378, -1.603657958021797, 1.2605011104799226, 1.0673512925004995, 0.6654828904564886, 0.4243718598760643, 0.5656945703343818, 0.9595195735791346, 1.2437659778441525, 1.1570989499176327, 0.7791997555897406, 0.4575071713541157, 0.4877838755956301, 0.8421936060628108, 1.1948936910083436, 1.2216132988930832, 0.8977865454515851, 0.5211382543943756, 0.43795712751686444, 0.7247195092608151, 1.1177773883233186, 1.25575516337359, 2.971822067084611, 2.5164421498816196, 1.5689765940569906, 1.0005208621746104, 1.3337105325592178, 2.262212558842095, 2.932366460065246, 2.728035830017163, 1.8370813076450758, 1.078642371970586, 1.1500242827324645, 1.9855988403707878, 2.817142650042383, 2.880138167995941, 2.1166676055436753, 1.2286622768793087, 1.0325501859304689, 1.7086358846982745, 2.63532929966455, 2.9606327787749436, 1.950863520471351, 1.6519276998291363, 1.029960452787776, 0.6567955979281783, 0.8755191818703583, 1.4850377502333627, 1.9249627422031403, 1.7908291489807229, 1.2059587775860432, 0.7080787502114589, 0.754937667933778, 1.303453657900071, 1.849323648546419, 1.8906772878810094, 1.3894942306116984, 0.806559868267803, 0.677821365248753, 1.1216403075222383, 1.729971606337934, 1.94351827102821, -0.8637099499951959, -0.7313614591913506, -0.4559965788685335, -0.29078451008533396, -0.3876204669665343, -0.6574739173374543, -0.8522428434200175, -0.7928575927968377, -0.5339166910217517, -0.31348920901962257, -0.33423515718979213, -0.5770808064594484, -0.8187549868301602, -0.8370635714066808, -0.6151737319637207, -0.3570899635877149, -0.3000932927092853, -0.49658619568044526, -0.7659140036829596, -0.8604579721081397, -2.8841924756386703, -2.4422402654774844, -1.522712458849079, -0.9710186805478648, -1.2943836460777653, -2.195507097404533, -2.845900289122051, -2.6475947202071106, -1.782911616187122, -1.0468366352076213, -1.1161137201974676, -1.927049838704642, -2.7340740631971667, -2.7952120434595087, -2.0542538023907126, -1.1924329297254277, -1.0021035613015319, -1.6582536406991017, -2.5576218109111375, -2.873333123893512, -2.252961740315028, -1.9077346346516544, -1.189453526512071, -0.7585027541967657, -1.011096470341119, -1.7150011772176168, -2.2230501335468817, -2.0681454718675902, -1.3927058237482357, -0.8177272867202223, -0.8718424760777267, -1.5052981362904414, -2.135698054689246, -2.1834554535364536, -1.604662400576471, -0.9314585594597851, -0.7827844370704994, -1.2953303358874793, -1.99786392026491, -2.2444790526258, 0.449631628988857, 0.3807334213038805, 0.23738349265415426, 0.1513771063481701, 0.2017881373168778, 0.3422689161700279, 0.4436620626903387, 0.4127471855654886, 0.27794728025280446, 0.16319675803515427, 0.17399671984029919, 0.30041773059116467, 0.42622889602376673, 0.43576001084728705, 0.32024821204796905, 0.18589451473195248, 0.15622308860776277, 0.25851370601718765, 0.39872084505135325, 0.4479387086805974], "z": [0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234]}],
                            {"scene": {"xaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "0th"}, "type": "linear"}, "yaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "1st"}, "type": "linear"}, "zaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "2nd"}, "type": "linear"}}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('faabaefa-6334-4b5a-9a74-3e4bd3a00e01');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Saving the results into an array
    topological_spaces = np.asarray([circle,sphere,torus])

Computing persistent homology
-----------------------------

In the next section we will use giotto-tda to compute the persistent
homology groups of the topological spaces we just constructed.

We will use the Vietoris–Rips technique to generate a filtration out of
a point cloud:

.. figure:: https://miro.medium.com/max/1200/1*w3BiQI1OX93KXcezctRQTQ.gif
   :alt: segment

   SegmentLocal

.. code:: ipython3

    # The homology ranks we choose to consider
    homology_dimensions = (0, 1, 2)
    VR = VietorisRipsPersistence(
        metric='euclidean', max_edge_length=10, homology_dimensions=homology_dimensions)
    
    # Array of persistence diagrams, one per point cloud in the input
    diagrams = VR.fit_transform(topological_spaces)
    print(f'diagrams.shape = {diagrams.shape}')


.. parsed-literal::

    diagrams.shape = (3, 865, 3)


Persistence diagrams
--------------------

The topological information of the point cloud is synthesised in the
persistence diagram. The horizontal axis corresponds to the moment in
which an homological generator is born, while the vertical axis
corresponds to the moments in which a homological generator dies.

The generators of the homology groups (at given rank) are colored
differently.

.. code:: ipython3

    # Plotting the persistence diagram of the circle
    plot_diagram(diagrams[0])



.. raw:: html

    <div>
    
    
                <div id="b509615c-5666-4b48-be53-5dd294253b70" class="plotly-graph-div" style="height:500px; width:500px;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("b509615c-5666-4b48-be53-5dd294253b70")) {
                        Plotly.newPlot(
                            'b509615c-5666-4b48-be53-5dd294253b70',
                            [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-200.0, 200.0], "y": [-200.0, 200.0]}, {"mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915]}, {"mode": "markers", "name": "H1", "type": "scatter", "x": [0.01770261861383915], "y": [1.733519196510315]}, {"mode": "markers", "name": "H2", "type": "scatter", "x": [1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315], "y": [1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458]}],
                            {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 2.2], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 2.2], "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('b509615c-5666-4b48-be53-5dd294253b70');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Plotting the persistence diagram of the sphere
    plot_diagram(diagrams[1])



.. raw:: html

    <div>
    
    
                <div id="c88d8afe-5bf8-4c98-9832-aeb25e01009b" class="plotly-graph-div" style="height:500px; width:500px;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("c88d8afe-5bf8-4c98-9832-aeb25e01009b")) {
                        Plotly.newPlot(
                            'c88d8afe-5bf8-4c98-9832-aeb25e01009b',
                            [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-200.0, 200.0], "y": [-200.0, 200.0]}, {"mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [0.0006651923176832497, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0019041121704503894, 0.0019041121704503894, 0.0019041121704503894, 0.0019041121704503894, 0.020551910623908043, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021868981420993805, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04135766625404358, 0.0419892780482769, 0.0419892780482769, 0.0419892780482769, 0.04263506084680557, 0.06254780292510986, 0.08120864629745483, 0.08178015053272247, 0.08178015053272247, 0.08178015053272247, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09824410080909729, 0.09924708306789398, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.11331319808959961, 0.11418279260396957, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.12611432373523712, 0.12683314085006714, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.136391282081604, 0.13694491982460022, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.1439383625984192, 0.14431574940681458, 0.14860452711582184, 0.14879809319972992, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.1565735638141632, 0.1565735638141632, 0.1565735638141632, 0.1565735638141632, 0.1565735638141632, 0.1565735638141632, 0.1790430098772049, 0.1790430098772049, 0.1790430098772049, 0.19138360023498535, 0.19138360023498535, 0.19138360023498535, 0.22040361166000366, 0.22040361166000366, 0.22040361166000366, 0.2450246512889862, 0.2450246512889862, 0.2450246512889862, 0.26475048065185547, 0.26475048065185547, 0.26475048065185547, 0.27351900935173035, 0.27918440103530884, 0.27918440103530884, 0.27918440103530884, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.4259701073169708]}, {"mode": "markers", "name": "H1", "type": "scatter", "x": [0.4259701073169708, 0.4259701073169708, 0.4259701073169708, 0.4259701073169708, 0.4259701073169708, 0.2880364656448364, 0.2880364656448364, 0.2880364656448364, 0.2880364656448364, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.27918440103530884, 0.27351900935173035, 0.27351900935173035, 0.27351900935173035, 0.27351900935173035, 0.27351900935173035, 0.26475048065185547, 0.2450246512889862, 0.22040361166000366, 0.19138360023498535, 0.1790430098772049, 0.1790430098772049, 0.1503022462129593, 0.08178015053272247, 0.0419892780482769, 0.0019041121704503894], "y": [0.43981873989105225, 0.43981873989105225, 0.4349362850189209, 0.43512967228889465, 0.43981873989105225, 0.388680100440979, 0.388680100440979, 0.388680100440979, 0.388680100440979, 0.3183557987213135, 0.29809635877609253, 0.2846529185771942, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.4302399754524231, 0.3455999195575714, 0.29916489124298096, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.4302399754524231, 0.3455999195575714, 0.29916489124298096, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.4302399754524231, 0.3455999195575714, 0.29916489124298096, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.4302399754524231, 0.3455999195575714, 0.29916489124298096, 0.3488639295101166, 0.37844565510749817, 0.3649183213710785, 0.3649183213710785, 0.37844565510749817, 0.3488639295101166, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3162855803966522, 0.30339646339416504, 0.3129911422729492, 0.30840617418289185, 0.3087007999420166, 0.31274929642677307, 0.3037223219871521, 0.31611356139183044, 0.3488639295101166, 0.37844565510749817, 0.3649183213710785, 0.37844565510749817, 0.2736629247665405, 0.2736629247665405, 0.2736629247665405, 0.2736629247665405, 0.2736629247665405, 0.3649183213710785, 0.3488639295101166, 0.3455999195575714, 0.4302399754524231, 0.29916489124298096, 0.19762368500232697, 0.2119583785533905, 0.2736629247665405, 0.24772526323795319, 0.00804855115711689]}, {"mode": "markers", "name": "H2", "type": "scatter", "x": [0.43981873989105225, 0.24772526323795319, 0.00804855115711689], "y": [1.6589692831039429, 0.25651901960372925, 0.00830260943621397]}],
                            {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 2.2], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 2.2], "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('c88d8afe-5bf8-4c98-9832-aeb25e01009b');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # plotting the persistence diagram of the torus
    plot_diagram(diagrams[2])



.. raw:: html

    <div>
    
    
                <div id="7e74d136-0b66-4240-8b42-098de061dc07" class="plotly-graph-div" style="height:500px; width:500px;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("7e74d136-0b66-4240-8b42-098de061dc07")) {
                        Plotly.newPlot(
                            '7e74d136-0b66-4240-8b42-098de061dc07',
                            [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-200.0, 200.0], "y": [-200.0, 200.0]}, {"mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.15180638432502747, 0.1566661149263382, 0.16365955770015717, 0.17449015378952026, 0.1864216923713684, 0.2023603767156601, 0.23805667459964752, 0.259246826171875, 0.278735488653183, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.3818131387233734, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4345456063747406, 0.4345456063747406, 0.4345456063747406, 0.4345456063747406]}, {"mode": "markers", "name": "H1", "type": "scatter", "x": [1.290719985961914, 1.290719985961914, 1.290719985961914, 1.290719985961914, 1.290719985961914, 1.2858601808547974, 1.2858601808547974, 1.2858601808547974, 1.2858601808547974, 1.2858601808547974, 1.2735836505889893, 1.2735836505889893, 1.2735836505889893, 1.2735836505889893, 1.2735836505889893, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7420936822891235, 0.7420936822891235, 0.7420936822891235, 0.7420936822891235, 0.7420936822891235, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.6814369559288025, 0.6814369559288025, 0.6814369559288025, 0.6814369559288025, 0.6814369559288025, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.5792563557624817, 0.5792563557624817, 0.5792563557624817, 0.5792563557624817, 0.5792563557624817, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5336318612098694, 0.5336318612098694, 0.5336318612098694, 0.5336318612098694, 0.5336318612098694, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.4994778335094452, 0.4994778335094452, 0.4994778335094452, 0.4994778335094452, 0.4994778335094452, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4684752821922302, 0.4684752821922302, 0.4684752821922302, 0.4684752821922302, 0.4684752821922302, 0.4509067237377167, 0.4492090046405792, 0.4484565556049347, 0.4484565556049347, 0.4484565556049347, 0.4484565556049347, 0.4484565556049347, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44492024183273315, 0.4369957745075226, 0.4345456063747406, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4274376332759857, 0.4139176905155182, 0.39985156059265137, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.34323954582214355, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.32115638256073, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30126968026161194, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685], "y": [1.2970259189605713, 1.2970259189605713, 1.2970259189605713, 1.2970259189605713, 1.2970259189605713, 1.2992850542068481, 1.2992850542068481, 1.2992850542068481, 1.2992850542068481, 1.2992850542068481, 1.2798200845718384, 1.2798200845718384, 1.2798200845718384, 1.2798200845718384, 1.2798200845718384, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.7841995358467102, 0.7841995358467102, 0.7841995358467102, 0.7841995358467102, 0.7841995358467102, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7407718300819397, 0.7407718300819397, 0.7407718300819397, 0.7407718300819397, 0.7407718300819397, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6074414849281311, 0.6074414849281311, 0.6074414849281311, 0.6074414849281311, 0.6074414849281311, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5741539597511292, 0.5741539597511292, 0.5741539597511292, 0.5741539597511292, 0.5741539597511292, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.551047682762146, 0.551047682762146, 0.551047682762146, 0.551047682762146, 0.551047682762146, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.5321967005729675, 0.5321967005729675, 0.5321967005729675, 0.5321967005729675, 0.5321967005729675, 0.4744914472103119, 0.5253207087516785, 0.6164262294769287, 0.6164262294769287, 0.6164262294769287, 0.6164262294769287, 0.6164262294769287, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5194565057754517, 0.5104308724403381, 1.8367944955825806, 0.5547325015068054, 0.4790463149547577, 0.45704415440559387, 0.48740920424461365, 0.5677598714828491, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 1.3128210306167603, 1.3128210306167603, 1.3128210306167603, 1.3128210306167603, 0.8871729373931885, 0.5186228156089783, 1.8185948133468628, 0.5005707144737244, 0.4875434637069702, 0.5294119119644165, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.42786338925361633, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.41131144762039185, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.39719343185424805, 0.3821181356906891, 0.3232707679271698, 0.33907127380371094, 0.33191734552383423, 0.3271026015281677]}, {"mode": "markers", "name": "H2", "type": "scatter", "x": [1.8367944955825806, 1.8185948133468628, 1.8185948133468628, 1.8185948133468628, 1.8185948133468628, 1.8185948133468628, 1.8185948133468628, 1.8185948133468628, 1.8185948133468628, 1.8185948133468628, 1.3128210306167603], "y": [1.894774079322815, 1.875999927520752, 1.875999927520752, 1.875999927520752, 1.875999927520752, 1.875999927520752, 1.875999927520752, 1.875999927520752, 1.875999927520752, 1.875999927520752, 1.875999927520752]}],
                            {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 2.2], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 2.2], "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('7e74d136-0b66-4240-8b42-098de061dc07');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


Conclusion of the first part
----------------------------

As you can see from the persistence diagrams, all the betti numbers were
found. Some other persistent generators are also appearing, depending on
how dense the sampling is and how much noise there is. For example, we
see a rather neat persistence diagram over the Torus bottle (we see two
persistent generators for :math:`H_1` and one persistent generator for
:math:`H_2`). Notice though that there are other persistent :math:`H_1`
generators, possibly due to the non-uniform sampling method we used for
the torus.

On the other hand, the persistence diagram for the circle is as perfect
as it could be: one unique generator of :math:`H_1` and no other
persistent generator, as expected.

Classification of noisy orientable surfaces
-------------------------------------------

In the next section we generate hundreds of noisy spheres and noisy
tori. The effect of noise is to displace the points sampling the
aforementioned surfaces by a random amount in a random direction.

The Vietoris–Rips algorithm is used to compute persistence diagrams.
Afterwards, from each diagram, the *persistence entropy* is computed.

A simple linear classifier is then applied to the 3D-space of entropies
to classify shapes.

.. code:: ipython3

    # Building dataset
    n_train = 10
    n_range = 15
    eps = 0.3
    
    train_Xs = [np.asarray([[np.cos(s)*np.cos(t) + eps*(np.random.rand(1)[0]-0.5),np.cos(s)*np.sin(t) + eps*(np.random.rand(1)[0]-0.5),np.sin(s) + eps*(np.random.rand(1)[0] - 0.5)] for t in range(n_range) for s in range(n_range)]) for kk in range(n_train)]
    train_ys = np.zeros(n_train)
    train_Xt = [np.asarray([[(2+np.cos(s))*np.cos(t) + eps*(np.random.rand(1)[0]-0.5),(2+np.cos(s))*np.sin(t) + eps*(np.random.rand(1)[0]-0.5),np.sin(s) + eps*(np.random.rand(1)[0] - 0.5)] for t in range(n_range) for s in range(n_range)]) for kk in range(n_train)]
    train_yt = np.ones(n_train)
    
    # Training set
    train_X = np.concatenate((train_Xs, train_Xt))
    train_y = np.concatenate((train_ys, train_yt))
    
    test_Xs = [np.asarray([[np.cos(s)*np.cos(t) + eps*(np.random.rand(1)[0]-0.5),np.cos(s)*np.sin(t) + eps*(np.random.rand(1)[0]-0.5),np.sin(s) + eps*(np.random.rand(1)[0] - 0.5)] for t in range(n_range) for s in range(n_range)]) for kk in range(n_train)]
    test_ys = np.zeros(n_train)
    test_Xt = [np.asarray([[(2+np.cos(s))*np.cos(t) + eps*(np.random.rand(1)[0]-0.5),(2+np.cos(s))*np.sin(t) + eps*(np.random.rand(1)[0]-0.5),np.sin(s) + eps*(np.random.rand(1)[0] - 0.5)] for t in range(n_range) for s in range(n_range)]) for kk in range(n_train)]
    test_yt = np.ones(n_train)
    
    
    # Test set
    test_X = np.concatenate((test_Xs, test_Xt))
    test_y = np.concatenate((test_ys, test_yt))

.. code:: ipython3

    # Build persistence diagrams
    
    # The homology ranks we choose to consider
    homology_dimensions = (0, 1, 2)
    VR = VietorisRipsPersistence(
        metric='euclidean', max_edge_length=10, homology_dimensions=homology_dimensions)
    
    # List of all the time-ordered persistence diagrams obtained from the list of correlation matrices
    train_diagrams = VR.fit_transform(train_X)
    test_diagrams = VR.transform(test_X)

Extract and plot persistent entropies
-------------------------------------

.. code:: ipython3

    # Extract vector features from diagrams: persistence entropy
    PE = PersistenceEntropy()
    X_train = PE.fit_transform(train_diagrams)
    X_test = PE.transform(test_diagrams)

.. code:: ipython3

    plot_point_cloud(X_train)



.. raw:: html

    <div>
    
    
                <div id="ce6e3d90-e193-4659-b3e3-6f74198cd5d0" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("ce6e3d90-e193-4659-b3e3-6f74198cd5d0")) {
                        Plotly.newPlot(
                            'ce6e3d90-e193-4659-b3e3-6f74198cd5d0',
                            [{"marker": {"color": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19], "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "opacity": 0.8, "size": 4}, "mode": "markers", "type": "scatter3d", "x": [5.310123388735926, 5.305905553971682, 5.305891114609297, 5.312101061270031, 5.307741211331733, 5.313543456735291, 5.321851094016148, 5.320593943848525, 5.311143510698635, 5.307565107149561, 5.351098254743611, 5.345394913313965, 5.3558755848590645, 5.349266846729817, 5.35851721295147, 5.352520638015032, 5.339784116109601, 5.3526306116020805, 5.345719177101808, 5.344988431368202], "y": [3.8078406433242082, 3.7452805007276018, 3.6195833597878475, 3.7496073512467043, 3.679174525123968, 3.6566530983441963, 3.763093118274753, 3.7364897938036834, 3.8795458638024307, 3.6771566747443027, 3.845018741743772, 3.7208341714906115, 3.6928362707220073, 3.721677136337628, 3.636618456097536, 3.710682033410147, 3.6536267742556405, 3.7495544583706812, 3.7452934696609237, 3.7504877868046824], "z": [0.09664633268319332, 0.0031157322427660477, 0.08197860930435277, -0.0, 0.10018925745800361, 0.07857386492742924, 0.137894748717077, 0.022945463417145047, 0.1425220776478816, -0.0, 2.6866929363069767, 2.680141389785959, 2.517398915861782, 2.7822246939790305, 2.4082526361021195, 2.6435828875435488, 2.415235152005233, 2.861204655121478, 2.6199391193106156, 2.787866636443535]}],
                            {"scene": {"xaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "0th"}, "type": "linear"}, "yaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "1st"}, "type": "linear"}, "zaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "2nd"}, "type": "linear"}}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('ce6e3d90-e193-4659-b3e3-6f74198cd5d0');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Training logistic regression
    LR = LogisticRegression(solver='lbfgs')
    LR.fit(X_train, train_y)
    # Score
    LR.score(X_test, test_y)




.. parsed-literal::

    1.0



Generating non-orientable surfaces
----------------------------------

We are going to consider different classical shapes: the real projective
space and the Klein bottle. The purpose of the second part of the
tutorial is to define shapes via a distance matrix. We also add noise to
the distance matrix: the main reason is not to have overlapping points
in the persistence diagram.

Each of the topological spaces we are going to encounter will be sampled
discretely. Afterwards, the Vietoris–Rips technique will be applied to
the surface and the persistent homology groups will be computed.

.. code:: ipython3

    # Compute the adjacency matrix of the grid points, with boundaries identified as in the real projective space
    from sklearn.utils.graph_shortest_path import graph_shortest_path
    
    # This functions prepares the grid matrix with boundary identification
    def make_matrix(rows, cols):
        n = rows*cols
        M = np.zeros((n,n))
        for r in range(rows):
            for c in range(cols):
                i = r*cols + c
                # Two inner diagonals
                if c > 0: M[i-1,i] = M[i,i-1] = 1 + 0.15*(np.random.rand(1)[0]-0.5)
                # Two outer diagonals
                if r > 0: M[i-cols,i] = M[i,i-cols] = 1 + 0.15*(np.random.rand(1)[0]-0.5)
                # vertical twisted boundary identification
                if c == 0: M[n-i-1,i] = M[i,n-i-1] = 1 + 0.15*(np.random.rand(1)[0]-0.5)
                # horizontal twisted boundary identification
                if r == 0: M[n-i-1,i] = M[i,n-i-1] = 1 + 0.15*(np.random.rand(1)[0]-0.5)
                    
        return M
    
    M = make_matrix(20,20)
    
    # Compute the distance matrix of the points over the Klein bottle
    
    rp2 = graph_shortest_path(M)
    
    # Plot of the distance matrix
    plot_heatmap(rp2, colorscale='viridis')



.. raw:: html

    <div>
    
    
                <div id="6c240d93-5bf7-46a8-887c-bd096f60f7ca" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("6c240d93-5bf7-46a8-887c-bd096f60f7ca")) {
                        Plotly.newPlot(
                            '6c240d93-5bf7-46a8-887c-bd096f60f7ca',
                            [{"colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmap", "z": [[0.0, 0.9787558937438292, 2.0168229366946147, 2.971819486210914, 4.041400291479432, 5.100894528060527, 6.055177414668459, 7.072245963743692, 8.081281192244422, 9.033690274266927, 10.076753222038858, 11.120353886209834, 12.05033357143088, 13.06079513107288, 14.004151351723113, 15.013474346756475, 16.065260680086837, 16.99446485295821, 18.012933224746618, 18.970873170204726, 1.0716857573530227, 1.921626227422138, 2.877961538557999, 3.867953509799721, 4.901291854190303, 5.974130094019197, 6.9865635302609865, 8.021071176026462, 8.966372398370687, 9.926937726149811, 10.859367307190938, 11.792185441004198, 12.844924119842203, 13.89169892657519, 14.93822783303839, 15.950826108454592, 17.015218611075863, 17.981297451546553, 19.005031911600447, 18.712785786466398, 2.077467544569669, 2.9266999669097764, 3.930346143785846, 4.895775166482012, 5.8710801094105936, 6.852737235490386, 7.876188894087853, 8.851617385314206, 9.8358444683819, 10.833769959158428, 11.76813826860931, 12.757593055647298, 13.79471636009422, 14.84430092108431, 15.837418274353379, 16.851697016882262, 17.899111373709598, 18.8867120627713, 18.639229391353286, 17.76454937214947, 3.0454868521647533, 3.9895013117427798, 4.940271531653046, 5.910393989688966, 6.932653263693604, 7.85111379058925, 8.808004903528927, 9.837039279167698, 10.875331965763086, 11.811681621998458, 12.793607277767565, 13.719739592522592, 14.768555744801697, 15.815223704570256, 16.889410684512114, 17.815453680479457, 18.746139060026064, 18.53898693857646, 17.673737210130902, 16.723948599428354, 3.9769225340888603, 4.9471755562386495, 5.882870820512381, 6.857929418529196, 7.8935087934452035, 8.891088774972912, 9.774942011909081, 10.704510270693197, 11.715176748034056, 12.768126133587197, 13.723173106844376, 14.672542706807944, 15.699940337053398, 16.73060924895832, 17.696672791909258, 18.678398812343442, 18.411689952818076, 17.464823912562633, 16.660594433177454, 15.740655815781942, 4.961271287960237, 5.950623118341126, 6.822619112292468, 7.778512752604557, 8.800200381393248, 9.825087414493066, 10.727855421002094, 11.703727553754625, 12.67031537652307, 13.613042325425493, 14.575449240050066, 15.510347273694713, 16.578927833494628, 17.59150743732176, 18.540600076270017, 18.528393392571214, 17.529410021076167, 16.528985252544448, 15.69775939468103, 14.743213258104541, 5.916443568902048, 6.956077776819835, 7.817818858662699, 8.767517905920881, 9.744939911970325, 10.750157729368938, 11.675245680873637, 12.64210428173942, 13.614866493110029, 14.539425329859936, 15.571659742393182, 16.504826505509804, 17.525534377535728, 18.470615808137257, 18.49773428420973, 17.574067436007237, 16.603019198479945, 15.603966447664764, 14.708767967884928, 13.754774639883356, 6.900997782920749, 7.9127157625869415, 8.76819340188275, 9.730628697912278, 10.69571190417058, 11.6790111341922, 12.61510173812819, 13.5911857273153, 14.604948098174876, 15.524392698039653, 16.531279196236728, 17.444160720699983, 18.41476837293331, 18.47165479114193, 17.57164487403759, 16.60623969994174, 15.640105147386596, 14.660948916822566, 13.71790235179958, 12.736704755194753, 7.879648516822433, 8.883395032577967, 9.698237580032263, 10.668887982826991, 11.70667217074905, 12.61160999893987, 13.62623983681058, 14.596484957866208, 15.583475898004478, 16.46441534421717, 17.419543910084773, 18.35503476212328, 18.422261759039692, 17.514717896129593, 16.545770611046215, 15.58655878381935, 14.663013042376413, 13.69371738916526, 12.759210984303136, 11.725392520559602, 8.948613214342624, 9.89779645839317, 10.711199862432954, 11.623969798580754, 12.672652895534284, 13.65806732805067, 14.598346872248525, 15.600962049808787, 16.566772752389024, 17.492621132411095, 18.35274552624942, 18.415503198942705, 17.419295879387967, 16.44317340295828, 15.56128258434641, 14.629614552452008, 13.661450184444114, 12.726837152410297, 11.717928634698975, 10.732746876773039, 9.892750212702673, 10.910367328052052, 11.783994370422919, 12.596642704794048, 13.607943441419264, 14.5420793905972, 15.51296343192553, 16.48082918499949, 17.47733796037223, 18.480688259473208, 18.356507598641056, 17.408031546892506, 16.422839385216754, 15.457075092232767, 14.53946042984581, 13.652866226585266, 12.712305021324962, 11.76293519248563, 10.847053818105149, 9.805487438045942, 10.8488009818833, 11.814445959101482, 12.71171087358041, 13.644805555303478, 14.575691206631504, 15.469577843002439, 16.508988563901653, 17.453903742065904, 18.41971321436296, 18.532016542020045, 17.49864707807023, 16.53329929520953, 15.558164327927951, 14.485187610570089, 13.543562109635902, 12.659146879615257, 11.727232361358949, 10.754327159611016, 9.77270179450827, 8.8461742159969, 11.84295720934858, 12.74060615585962, 13.699138445442058, 14.626048004927702, 15.568835989998524, 16.4766263628869, 17.45082067585333, 18.41036927037407, 18.45830704672962, 17.49739776528344, 16.544851678280047, 15.609381548424436, 14.665114411010327, 13.642564292259035, 12.616824287655286, 11.66778856254808, 10.70976968930935, 9.7677131871519, 8.768155796392236, 7.8507753922144925, 12.89515920437894, 13.79726551320298, 14.651709174382358, 15.60147452241054, 16.59194051845387, 17.415063041019952, 18.38897157074957, 18.501504498029714, 17.509110850260942, 16.53800078650677, 15.60814977328967, 14.667230683111068, 13.674085884267834, 12.726795240194624, 11.756593144876703, 10.812025466232617, 9.846362914033731, 8.831110554911072, 7.807436136743038, 6.802941355046756, 13.848985091596544, 14.852157514302002, 15.663810466715335, 16.56126516849633, 17.557627787729313, 18.430771071983354, 18.57823668560013, 17.60487884343665, 16.57172937273158, 15.729085844246796, 14.664904759137595, 13.62884349791598, 12.633420893869433, 11.880157839014851, 10.82271391874944, 9.866208378477477, 8.85784971553481, 7.8935876659175985, 6.911544421183019, 5.866837646108139, 14.895148220988883, 15.871138467931285, 16.6081272459116, 17.488799357706164, 18.44903896425216, 18.530730859388935, 17.566852230906854, 16.621029136581033, 15.628170399755398, 14.683121107982453, 13.676324065523358, 12.636638516690134, 11.691469802110166, 10.856407975838506, 9.897310824251331, 8.898514080030623, 7.88135150822284, 6.871888466951826, 5.940201364721988, 4.921624116870625, 15.938959460913523, 16.820564105630222, 17.57745348417103, 18.49144792424649, 18.583805847648307, 17.599129003798456, 16.618036520869406, 15.658852289652192, 14.686458398272103, 13.706040962228656, 12.709030014512354, 11.729873526269385, 10.76011575611812, 9.896122970052136, 8.923519966874204, 7.858122450244375, 6.9129122163309145, 5.943843682726861, 4.942656198185489, 3.9451745300599863, 16.89059323208304, 17.84771935233515, 18.648882856204924, 18.626270652701233, 17.643574990196917, 16.65975940213292, 15.692930715548993, 14.723788852196183, 13.70800548622831, 12.684053560391051, 11.752332611857257, 10.773341650928149, 9.825067444140686, 8.96070736042425, 8.006827323060488, 6.97277649639047, 5.954496173180446, 4.994346480302532, 3.933387752217489, 3.016119951463775, 17.860545070624433, 18.896347263181465, 18.694125854313572, 17.743516718625376, 16.798708908886415, 15.725024609183441, 14.759182035637142, 13.78969078570925, 12.791865730161367, 11.757449207545497, 10.778449956419944, 9.852418229519616, 8.832635556363673, 7.888819851695647, 6.94903472383421, 5.969818597633534, 4.973651897088116, 3.9939071980525935, 2.978192154755248, 2.0370217435620126, 18.78823070425861, 18.90005895488447, 17.889963197537, 16.907845590565657, 15.971239158073796, 14.917016983786864, 13.947371461577323, 12.921011006674377, 11.926040581286069, 10.896394494943884, 9.890129830671116, 8.885798643493453, 7.954877384365693, 6.928611220779798, 5.9768125687715745, 4.973263160673877, 3.959646297211348, 2.942701148023942, 1.9915088128727372, 0.9753748803403247], [0.9787558937438292, 0.0, 1.0380670429507857, 1.9930635924670854, 3.0626443977356037, 4.122138634316699, 5.076421520924631, 6.093490069999863, 7.102525298500594, 8.0549343805231, 9.097997328295031, 10.141597992466007, 11.071577677687053, 12.082039237329052, 13.025395457979286, 14.034718453012648, 15.08650478634301, 16.015708959214383, 17.03417733100279, 17.9921172764609, 1.9001641680483217, 0.9428703336783089, 1.8992056448141699, 2.889197616055892, 3.922535960446474, 4.995374200275368, 6.007807636517158, 7.042315282282633, 7.987616504626859, 8.948181832405982, 9.88061141344711, 10.81342954726037, 11.866168226098374, 12.912943032831361, 13.959471939294561, 14.972070214710763, 16.036462717332032, 17.002541557802722, 18.026276017856617, 19.051359152760686, 2.8936720789928985, 1.9479440731659472, 2.951590250042017, 3.9170192727381825, 4.892324215666765, 5.873981341746557, 6.897433000344024, 7.872861491570378, 8.857088574638071, 9.855014065414599, 10.789382374865479, 11.77883716190347, 12.815960466350392, 13.865545027340481, 14.85866238060955, 15.872941123138432, 16.920355479965767, 17.907956169027468, 17.97294332602794, 18.5807539065727, 3.861691386587983, 3.01074541799895, 3.9615156379092165, 4.931638095945138, 5.953897369949775, 6.872357896845421, 7.829249009785097, 8.858283385423867, 9.896576072019256, 10.83292572825463, 11.814851384023735, 12.740983698778763, 13.789799851057868, 14.836467810826427, 15.910654790768287, 16.83669778673563, 17.767383166282237, 17.71211632018841, 17.007451144805557, 17.540153133851582, 4.79312706851209, 4.021736742835618, 4.957432007109349, 5.879173524785367, 6.914752899701375, 7.912332881229084, 8.79618611816525, 9.725754376949366, 10.736420854290225, 11.789370239843366, 12.744417213100546, 13.693786813064115, 14.721184443309568, 15.751853355214491, 16.71791689816543, 17.699642918599615, 17.584819334430026, 16.637953294174583, 15.994308367852112, 16.55686035020517, 5.777475822383467, 5.025184304938094, 5.897180298889436, 6.853073939201526, 7.8541590907684276, 8.879046123868246, 9.749099527258263, 10.724971660010794, 11.691559482779239, 12.634286431681662, 13.596693346306235, 14.531591379950882, 15.600171939750796, 16.61275154357793, 17.561844182526187, 17.654497942948097, 16.702539402688117, 15.702114634156398, 15.031473329355688, 15.559417792527771, 6.732648103325278, 6.084375043742481, 6.892380045259667, 7.84207909251785, 8.798898621345504, 9.804116438744117, 10.7053679881946, 11.672226589060383, 12.636110599366198, 13.560669436116106, 14.592903848649351, 15.526070611765975, 16.546778483791893, 17.491859914393423, 17.623838834586614, 16.70017198638412, 15.776148580091897, 14.777095829276714, 14.042481902559585, 14.570979174306586, 7.717202317343979, 7.041013029509588, 7.842754588479718, 8.805189884509247, 9.749670613545758, 10.732969843567378, 11.66906044750337, 12.64514443669048, 13.641617203126478, 14.545636804295823, 15.552523302492895, 16.465404826956153, 17.43601247918948, 17.597759341518813, 16.697749424414475, 15.73234425031862, 14.813234528998546, 13.834078298434516, 13.034941362518287, 13.552909289617983, 8.695853051245663, 8.011692299500615, 8.772798766629231, 9.743449169423958, 10.781233357346016, 11.665568708315048, 12.680198546185759, 13.650443667241387, 14.637434607379657, 15.485659450473339, 16.440788016340942, 17.37627886837945, 17.548366309416576, 16.640822446506476, 15.6718751614231, 14.712663334196233, 13.836142423988363, 12.86684677077721, 12.076249995021843, 12.541597054982832, 9.764817748765854, 9.074736605096376, 9.785761049029922, 10.69853098517772, 11.74721408213125, 12.71297743045358, 13.652305581623704, 14.654920759183966, 15.620731461764201, 16.513865238667265, 17.37398963250559, 17.541607749319585, 16.54540042976485, 15.569277953335163, 14.687387134723291, 13.755719102828891, 12.787554734820995, 11.899966534022248, 11.01373457881571, 11.548951411196269, 10.708954747125903, 10.087307474755258, 10.858555557019887, 11.671203891391015, 12.68250462801623, 13.616640577194167, 14.587524618522496, 15.555390371596456, 16.551899146969195, 17.501932365729377, 17.478002407098145, 16.534136097269386, 15.548943935593636, 14.583179642609648, 13.665564980222692, 12.778970776962147, 11.838409571701844, 10.889039742862511, 10.016905879673674, 10.621691972469172, 11.66500551630653, 11.161172664666086, 11.786272060177378, 12.719366741900444, 13.65025239322847, 14.544139029599405, 15.58354975049862, 16.52846492866287, 17.494274400959927, 17.553260648276215, 16.532052334644284, 15.566704551783584, 14.676385540269822, 13.61129216094697, 12.669666660012783, 11.785251429992138, 10.85333691173583, 9.880431709987898, 8.942553856076795, 9.66237875042013, 12.65916174377181, 12.087332861424224, 12.773699632039026, 13.700609191524668, 14.64339717659549, 15.551187549483867, 16.525381862450296, 17.484930456971036, 17.47955115298579, 16.51864187153961, 15.566095784536216, 14.630625654680605, 13.686358517266497, 12.768668842635917, 11.742928838032167, 10.793893112924962, 9.835874239686232, 8.893817737528781, 7.8942603467691175, 8.66697992663772, 13.71136373880217, 13.143992218767584, 13.726270360979326, 14.676035709007506, 15.666501705050838, 16.48962422761692, 17.463532757346535, 17.522748604285884, 16.53035495651711, 15.559244892762939, 14.62939387954584, 13.688474789367238, 12.695329990524003, 11.797045416728883, 10.826843321410962, 9.882275642766876, 8.972467464410615, 7.957215105287955, 6.93354068711992, 7.619145889469985, 14.665189626019774, 14.198884219866606, 14.738371653312303, 15.635826355093297, 16.63218897432628, 17.50533225858032, 17.5994807918563, 16.62612294969282, 15.592973478987748, 14.750329950502966, 13.686148865393765, 12.65008760417215, 11.654665000125602, 10.917745828679463, 9.860301908414051, 8.918519238589411, 7.910160575646744, 6.9458985260295325, 5.963855281294953, 6.683042180531368, 15.711352755412113, 15.254029789919022, 15.682688432508568, 16.56336054430313, 17.523600150849127, 17.55197496564511, 16.588096337163023, 15.642273242837202, 14.649414506011569, 13.704365214238624, 12.697568171779528, 11.657882622946303, 10.712713908366336, 9.877652082094677, 8.918554930507502, 7.919758186286794, 6.9025956144790115, 5.924199327063761, 4.992512224833922, 5.737828651293854, 16.755163995336755, 16.203455427617957, 16.652014670767997, 17.566009110843456, 17.60504995390448, 16.62037311005463, 15.63928062712558, 14.680096395908363, 13.707702504528275, 12.727285068484827, 11.730274120768524, 10.751117632525554, 9.78135986237429, 8.917367076308308, 7.944764073130376, 6.879366556500546, 5.934156322587086, 4.996154542838796, 3.9949670582974233, 4.761379064483215, 17.706797766506273, 17.230610674322886, 17.72344404280189, 17.647514758957403, 16.664819096453087, 15.681003508389091, 14.714174821805162, 13.745032958452354, 12.72924959248448, 11.705297666647223, 10.773576718113427, 9.794585757184318, 8.846311550396855, 7.98195146668042, 7.028071429316659, 5.994020602646641, 4.975740279436617, 4.018859178583247, 2.9856986123294234, 3.8323244858870043, 18.67674960504766, 18.2792385851692, 17.715369960569745, 16.76476082488155, 15.819953015142588, 14.746268715439612, 13.780426141893313, 12.810934891965422, 11.813109836417539, 10.778693313801668, 9.799694062676116, 8.873662335775787, 7.8538796626198435, 6.9100639579518175, 5.97027883009038, 4.991062703889705, 3.994896003344287, 3.0151513043087643, 2.0305030148671825, 2.8870959315767504, 18.874671357973327, 17.921303061140645, 16.911207303793173, 15.929089696821832, 14.99248326432997, 13.938261090043033, 12.968615567833492, 11.942255112930546, 10.947284687542238, 9.917638601200053, 8.911373936927285, 7.907042749749623, 6.976121490621862, 5.9498553270359675, 4.998056675027745, 3.994507266930048, 2.980890403467519, 1.9639452542801128, 1.012752919128908, 1.9541307740841538], [2.0168229366946147, 1.0380670429507857, 0.0, 0.9549965495162998, 2.0245773547848183, 3.0840715913659134, 4.038354477973845, 5.055423027049077, 6.064458255549808, 7.0168673375723145, 8.059930285344246, 9.103530949515221, 10.033510634736267, 11.043972194378266, 11.9873284150285, 12.996651410061862, 14.048437743392224, 14.977641916263595, 15.996110288052003, 16.95405023351011, 2.938231210999107, 1.9809373766290945, 1.0401656526807757, 1.9274777386585837, 2.9608160830491657, 4.033654322878059, 5.046087759119849, 6.080595404885324, 6.992911694527568, 7.953477022306692, 8.885906603347818, 9.818724737161078, 10.871463415999083, 11.91823822273207, 12.96476712919527, 13.977365404611472, 15.041757907232741, 16.00783674770343, 17.031571207757324, 18.013292109809896, 3.931739121943684, 2.9860111161167326, 2.1064815774494288, 2.9552993953408744, 3.9306043382694567, 4.912261464349249, 5.935713122946716, 6.9111416141730695, 7.895368697240762, 8.89329418801729, 9.827662497468172, 10.784132351804178, 11.8212556562511, 12.87084021724119, 13.863957570510259, 14.878236313039142, 15.92565066986648, 16.913251358928182, 17.91309455012807, 18.91024289250698, 4.899758429538768, 4.048812460949736, 3.1164069653166284, 3.969918218547829, 4.992177492552467, 5.910638019448113, 6.867529132387789, 7.896563508026559, 8.934856194621947, 9.87120585085732, 10.853131506626427, 11.746278888679472, 12.795095040958577, 13.841763000727136, 14.915949980668996, 15.841992976636341, 16.772678356182947, 16.882590795303752, 17.79200563354135, 18.57822017680237, 5.831194111462875, 5.0598037857864036, 4.148096276445562, 4.917453647388058, 5.953033022304067, 6.9506130038317755, 7.834466240767943, 8.764034499552059, 9.774700976892918, 10.82765036244606, 11.782697335703238, 12.699082002964824, 13.726479633210278, 14.757148545115202, 15.723212088066141, 16.704938108500325, 16.755293809545368, 15.808427769289924, 16.778862856587903, 17.594927393155956, 6.815542865334252, 6.06325134788888, 5.087844568225649, 5.918713585998388, 6.892439213371119, 7.917326246470937, 8.787379649860956, 9.763251782613487, 10.729839605381931, 11.672566554284355, 12.634973468908928, 13.569871502553575, 14.638452062353489, 15.65103166618062, 16.600124305128876, 16.73941333822261, 15.8648961918353, 14.872589109271738, 15.816027818091479, 16.597484835478557, 7.770715146276064, 7.0828093053729955, 6.08304431459588, 6.907718739314713, 7.837178743948197, 8.84239656134681, 9.743648110797293, 10.710506711663076, 11.67439072196889, 12.598949558718799, 13.631183971252044, 14.564350734368668, 15.585058606394586, 16.530140036996116, 16.700642702318063, 15.785087381658633, 14.881019514277913, 13.947570304392054, 14.899915755021828, 15.609046217257372, 8.755269360294765, 8.016285659862941, 7.0334188578159305, 7.95435672688906, 8.787950736148451, 9.771249966170071, 10.707340570106062, 11.683424559293172, 12.67989732572917, 13.583916926898516, 14.590803425095588, 15.503684949558847, 16.474292601792172, 16.664829992513482, 15.774553292145924, 14.817259645593134, 13.918105463184562, 13.004552773549856, 13.91278283797316, 14.590976332568768, 9.73392009419645, 8.941486961382319, 7.963463035965444, 8.934113438760171, 9.822282383720744, 10.70384883091774, 11.718478668788451, 12.68872378984408, 13.67571472998235, 14.523939573076031, 15.479068138943635, 16.414558990982144, 16.615436960411245, 15.707893097501145, 14.74867902915455, 13.797578729470747, 12.941013358174379, 12.03732124589255, 12.954091470476715, 13.579664097933618, 10.80288479171664, 9.99067246394592, 8.976425318366136, 9.889195254513934, 10.839182543600687, 11.751257553056274, 12.690585704226397, 13.693200881786659, 14.659011584366894, 15.552145361269956, 16.412269755108284, 16.52512585052405, 15.612471080759518, 14.636348604329832, 13.75445778571796, 12.840634498103405, 11.881267271042542, 11.070441009137587, 11.891576054270582, 12.587018454147055, 11.747021790076689, 11.003243333604802, 10.0492198263561, 10.861868160727228, 11.774473089485667, 12.708609038663603, 13.679493079991932, 14.647358833065892, 15.619866477769897, 16.540212488332067, 16.44014124105612, 15.51765419847385, 14.616014586588305, 13.650250293604318, 12.732635631217361, 11.863886172236661, 10.93212210792339, 10.059514217977851, 10.894747355128546, 11.659759015419958, 12.703072559257317, 11.9647948125308, 10.976936329513592, 11.910031011236658, 12.742220854697907, 13.636107491068842, 14.675518211968056, 15.620433390132307, 16.58473316232155, 16.515399482234194, 15.49419116860226, 14.528843385741562, 13.6385243742278, 12.67836281194164, 11.736737311007452, 10.870166825266653, 9.938252307010345, 9.050906185103237, 9.820395331531667, 10.700445793370916, 13.697228786722595, 12.890955009288938, 11.96436390137524, 12.891273460860882, 13.735365638064927, 14.643156010953305, 15.617350323919734, 16.576898918440474, 16.441689986943764, 15.480780705497589, 14.528234618494194, 13.592764488638583, 12.648497351224474, 11.802264163869284, 10.809999489026836, 9.860963763919631, 8.902944890680901, 8.064292212644121, 8.77210182222399, 9.684750517631215, 14.749430781752956, 13.863105219931398, 12.91693463031554, 13.86669997834372, 14.758470166520274, 15.581592689086358, 16.555501218815973, 16.48488743824386, 15.492493790475088, 14.521383726720915, 13.591532713503815, 12.650613623325214, 11.657468824481981, 10.773156080613182, 9.802953985295261, 8.858386306651177, 7.950071151943514, 7.079071540242124, 7.811382162574792, 8.63691648046348, 15.70325666897056, 14.91799722103042, 13.929035922648517, 14.82649062442951, 15.760250972505725, 16.59730072004976, 16.561619625814277, 15.588261783650797, 14.555112312945724, 13.712468784460942, 12.64828769935174, 11.612226438130126, 10.61680383408358, 9.886849820795415, 8.829405900530004, 7.894629902473711, 6.886271239531045, 6.055228453505904, 6.841696756749825, 7.7008127715248635, 16.749419798362897, 15.882419250724194, 14.873352701844782, 15.754024813639344, 16.71426442018534, 16.51411379960308, 15.550235171121, 14.604412076795178, 13.611553339969545, 12.6665040481966, 11.659707005737507, 10.620021456904283, 9.674852742324314, 8.84675607421063, 7.887658922623455, 6.888862178402746, 5.871699606594965, 4.9848215908179645, 5.870353700288794, 6.755599242287349, 17.793231038287537, 16.793646266664286, 15.84267894010421, 16.75667338017967, 16.567188787862452, 15.582511944012603, 14.601419461083555, 13.642235229866339, 12.66984133848625, 11.689423902442803, 10.692412954726501, 9.713256466483532, 8.743498696332267, 7.88647106842426, 6.913868065246328, 5.848470548616499, 4.903260314703039, 4.056776806593, 4.872808533752295, 5.779149655476711, 18.744864809457056, 17.820801513369215, 16.914108312138104, 16.60965359291538, 15.626957930411063, 14.643142342347067, 13.676313655763138, 12.70717179241033, 11.691388426442456, 10.667436500605199, 9.735715552071404, 8.756724591142296, 7.808450384354833, 6.944090300638398, 5.990210263274637, 4.956159436604619, 3.9448442715525704, 2.9943159837357087, 3.8635400877842945, 4.8500950768805, 18.696313396411746, 17.63904607582112, 16.67750879452772, 15.726899658839525, 14.782091849100564, 13.708407549397588, 12.74256497585129, 11.773073725923398, 10.775248670375515, 9.740832147759644, 8.761832896634091, 7.835801169733764, 6.816018496577821, 5.872202791909795, 4.932417664048358, 3.9532015378476824, 2.9639999954602407, 1.990608109461226, 2.9083444903220537, 3.849514901515289, 17.83660431502254, 16.88323601818986, 15.873140260842387, 14.891022653871046, 13.954416221379184, 12.900399924001013, 11.930754401791472, 10.904393946888524, 9.909423521500216, 8.879777435158031, 7.873512770885263, 6.869181583707601, 5.93826032457984, 4.911994160993945, 3.9601955089857226, 2.9566461008880256, 1.9430292374254967, 0.9394020594325745, 1.8905943945837793, 2.9583650623486664], [2.9718194862109146, 1.9930635924670854, 0.9549965495162998, 0.0, 1.0695808052685183, 2.129075041849614, 3.083357928457546, 4.100426477532778, 5.1094617060335095, 6.061870788056016, 7.104933735827947, 8.148534399998923, 9.078514085219968, 10.088975644861968, 11.032331865512202, 12.041654860545563, 13.093441193875925, 14.022645366747296, 15.041113738535705, 15.999053683993811, 3.87610230588988, 2.918808471519867, 1.9624731603840062, 0.9724811891422841, 2.005819533532866, 3.0786577733617597, 4.09109120960355, 5.1255988553690255, 6.03791514501127, 6.998480472790393, 7.9309100538315205, 8.863728187644782, 9.916466866482786, 10.963241673215773, 12.009770579678973, 13.022368855095175, 14.086761357716444, 15.052840198187132, 16.076574658241025, 17.058295560293598, 4.869610216834457, 3.9238822110075056, 3.0287890851526593, 2.000302845824575, 2.975607788753157, 3.9572649148329493, 4.980716573430416, 5.95614506465677, 6.940372147724464, 7.938297638500991, 8.872665947951873, 9.829135802287881, 10.866259106734804, 11.915843667724893, 12.908961020993962, 13.923239763522844, 14.970654120350181, 15.958254809411883, 16.95809800061177, 17.95524634299068, 5.837629524429541, 4.986683555840509, 4.0387144730198585, 3.0149216690315295, 4.037180943036168, 4.955641469931813, 5.912532582871489, 6.9415669585102595, 7.979859645105648, 8.916209301341022, 9.898134957110129, 10.791282339163175, 11.84009849144228, 12.886766451210839, 13.9609534311527, 14.886996427120042, 15.817681806666647, 16.80916987131126, 17.736542029201843, 18.71520281102403, 6.769065206353648, 5.926763380894095, 4.991068116620363, 3.9624570978717584, 4.998036472787767, 5.995616454315476, 6.879469691251644, 7.809037950035759, 8.819704427376617, 9.872653812929759, 10.82770078618694, 11.744085453448527, 12.77148308369398, 13.802151995598903, 14.768215538549843, 15.749941558984029, 15.942651710460654, 16.617191302910467, 17.58762639020844, 18.518370709662307, 7.753413960225025, 6.9016349791467455, 5.919610676794178, 4.963717036482088, 5.93744266385482, 6.962329696954638, 7.832383100344655, 8.808255233097187, 9.774843055865631, 10.717570004768055, 11.679976919392628, 12.614874953037274, 13.683455512837188, 14.69603511666432, 15.645127755612577, 15.784416788706313, 14.909899642319001, 15.68135264289228, 16.62479135171202, 17.535355930369327, 8.708586241166836, 7.914575413941524, 6.9148104231644085, 5.952722189798413, 6.8821821944318975, 7.88740001183051, 8.788651561280993, 9.755510162146775, 10.71939417245259, 11.643953009202498, 12.676187421735744, 13.609354184852368, 14.630062056878286, 15.575143487479815, 15.745646152801765, 14.830090832142334, 13.926022964761614, 14.756333838012596, 15.70867928864237, 16.546917312148143, 9.693140455185537, 8.848051768431471, 7.865184966384459, 6.99936017737276, 7.8329541866321515, 8.816253416653772, 9.752344020589764, 10.728428009776874, 11.72490077621287, 12.628920377382215, 13.635806875579288, 14.548688400042547, 15.519296052275871, 15.709833442997182, 14.819556742629626, 13.862263096076836, 12.963108913668263, 13.813316307170398, 14.757424001250325, 15.52884742745954, 10.671791189087221, 9.773253069950846, 8.795229144533971, 7.984251876895966, 8.867285834204443, 9.748852281401442, 10.763482119272153, 11.73372724032778, 12.72071818046605, 13.568943023559731, 14.524071589427335, 15.459562441465842, 15.660440410894944, 14.752896547984847, 13.793682479638251, 12.842582179954448, 11.98601680865808, 12.846084779513092, 13.80274857921221, 14.51753519282439, 11.740755886607412, 10.822438572514447, 9.808191426934663, 8.939333692649729, 9.884185994084387, 10.796261003539975, 11.735589154710098, 12.73820433227036, 13.704015034850595, 14.597148811753655, 15.457273205591983, 15.57012930100775, 14.657474531243219, 13.681352054813534, 12.799461236201662, 11.885637948587107, 10.926270721526244, 11.87920454275813, 12.846572603786882, 13.524889549037827, 12.68489288496746, 11.835009442173329, 10.880985934924627, 9.912006598863023, 10.819476539969367, 11.753612489147303, 12.724496530475632, 13.692362283549592, 14.664869928253598, 15.585215938815766, 15.485144691539823, 14.56265764895755, 13.661018037072006, 12.695253744088019, 11.777639081701063, 10.908889622720363, 9.977125558407092, 10.885226848655781, 11.849743904644846, 12.59763011031073, 13.640943654148089, 12.796560921099326, 11.808702438082118, 10.96016944937245, 11.787224305181606, 12.681110941552541, 13.720521662451755, 14.665436840616007, 15.629736612805255, 15.560402932717894, 14.539194619085961, 13.573846836225263, 12.6835278247115, 11.72336626242534, 10.781740761491154, 9.915170275750354, 8.983255757494046, 9.876618815781168, 10.775391881047968, 11.638316888261688, 14.635099881613368, 13.722721117857464, 12.796130009943766, 11.941411898996675, 12.780369088548627, 13.688159461437003, 14.662353774403432, 15.62190236892417, 15.486693437427466, 14.52578415598129, 13.573238068977895, 12.637767939122284, 11.693500801708176, 10.847267614352985, 9.855002939510538, 8.905967214403333, 7.947948341164602, 8.890004843322052, 9.72709837174029, 10.639747067147518, 15.687301876643728, 14.694871328499925, 13.748700738884066, 12.916838416479512, 13.803473617003974, 14.626596139570056, 15.600504669299672, 15.52989088872756, 14.537497240958789, 13.566387177204616, 12.636536163987516, 11.695617073808915, 10.702472274965682, 9.818159531096883, 8.847957435778962, 7.903389757134876, 6.995074602427215, 7.919379826368175, 8.766378712091091, 9.591913029979782, 16.641127763861334, 15.749763329598947, 14.760802031217043, 13.876629062565303, 14.805254422989425, 15.642304170533457, 15.606623076297979, 14.633265234134498, 13.600115763429425, 12.757472234944643, 11.693291149835442, 10.657229888613827, 9.661807284567281, 8.931853271279115, 7.874409351013704, 6.9396333529574115, 5.931274690014745, 6.8955367396319565, 7.796693306266125, 8.655809321041165, 17.68729089325367, 16.71418535929272, 15.705118810413309, 14.804163251775137, 15.764402858321134, 15.559117250086782, 14.595238621604702, 13.64941552727888, 12.656556790453246, 11.711507498680302, 10.704710456221209, 9.665024907387984, 8.719856192808015, 7.891759524694331, 6.9326623731071555, 5.933865628886447, 4.916703057078665, 5.932991886054914, 6.825350249805093, 7.71059579180365, 18.639550798353746, 17.625412375232813, 16.674445048672737, 15.806811818315465, 15.612192238346156, 14.627515394496305, 13.646422911567257, 12.68723868035004, 11.714844788969952, 10.734427352926504, 9.737416405210201, 8.758259916967232, 7.788502146815968, 6.931474518907961, 5.958871515730029, 4.893473999100199, 3.948263765186739, 5.004947101829949, 5.827805083268594, 6.734146204993011, 18.495133960229285, 17.521547059630677, 16.582261865417838, 15.65465704339908, 14.671961380894764, 13.688145792830769, 12.72131710624684, 11.752175242894031, 10.736391876926158, 9.7124399510889, 8.780719002555104, 7.801728041625996, 6.853453834838533, 5.989093751122098, 5.035213713758337, 4.001162887088318, 2.989847722036271, 3.9493125332520087, 4.8185366373005944, 5.8050916263968, 17.741316846895447, 16.684049526304822, 15.722512245011423, 14.771903109323226, 13.827095299584265, 12.75341099988129, 11.78756842633499, 10.8180771764071, 9.820252120859216, 8.785835598243345, 7.806836347117793, 6.880804620217464, 5.861021947061522, 4.917206242393496, 3.977421114532058, 2.9982049883313824, 2.009003445943941, 2.9456046589775258, 3.863341039838353, 4.804511451031589, 16.881607765506246, 15.928239468673562, 14.918143711326088, 13.936026104354747, 12.999419671862885, 11.945403374484714, 10.975757852275173, 9.949397397372225, 8.954426971983917, 7.9247808856417326, 6.918516221368964, 5.914185034191302, 4.983263775063541, 3.956997611477646, 3.005198959469423, 2.0016495513717256, 0.988032687909197, 1.8943986089488742, 2.845590944100079, 3.913361611864966], [4.041400291479434, 3.062644397735604, 2.0245773547848183, 1.0695808052685183, 0.0, 1.0594942365810953, 2.013777123189027, 3.030845672264259, 4.03988090076499, 4.992289982787496, 6.0353529305594265, 7.078953594730403, 8.00893327995145, 9.01939483959345, 9.962751060243683, 10.972074055277044, 12.023860388607407, 12.953064561478778, 13.971532933267186, 14.929472878725292, 4.945683111158399, 3.9883892767883857, 3.0320539656525245, 2.0420619944108025, 1.0231252994006954, 2.033323380151144, 3.0457568163929345, 4.059971016651099, 4.96833433974275, 5.928899667521874, 6.861329248563001, 7.794147382376262, 8.846886061214267, 9.893660867947254, 10.940189774410454, 11.952788049826657, 13.017180552447925, 13.983259392918614, 15.006993852972506, 15.988714755025077, 5.939191022102976, 4.993463016276024, 4.07833956374925, 3.047848506159469, 1.9929135546209862, 2.9745706807007783, 3.9980223392982452, 4.973450830524599, 5.950242962451304, 6.946705892466716, 7.881074201917597, 8.759554997019361, 9.796678301466283, 10.846262862456372, 11.839380215725441, 12.853658958254325, 13.901073315081662, 14.888674004143365, 15.888517195343253, 16.88566553772216, 6.90721032969806, 6.056264361109028, 5.088264951616449, 4.062467329366424, 3.0544867089039967, 3.9729472357996425, 4.9298383487393185, 5.958872724378089, 6.997165410973477, 7.924617555306746, 8.906543211075853, 9.721701533894654, 10.77051768617376, 11.817185645942319, 12.891372625884179, 13.817415621851524, 14.748101001398128, 15.73958906604274, 16.666961223933324, 17.645622005755513, 7.838646011622167, 6.97430904122899, 6.038613776955258, 5.010002758206653, 4.015342238655596, 5.012922220183305, 5.896775457119473, 6.8263437159035885, 7.8370101932444465, 8.889959578797589, 9.836109040152664, 10.674504648180006, 11.701902278425461, 12.732571190330384, 13.698634733281324, 14.68036075371551, 15.685596725153632, 16.632462765409077, 17.66851096460333, 18.599255284057193, 8.822994765493544, 7.914354001175996, 6.932329698823428, 5.9764360585113385, 4.954748429722649, 5.979635462822467, 6.849688866212484, 7.825560998965017, 8.792148821733461, 9.734875770635885, 10.697282685260458, 11.632180718905104, 12.650902096223643, 13.663481700050774, 14.612574338999032, 14.924498937969737, 15.849613819729694, 16.62106682030297, 17.564505529122712, 18.536233509056668, 9.778167046435355, 8.863376022349547, 7.863611031572431, 6.888885280973313, 5.8994879602997266, 6.904705777698339, 7.805957327148822, 8.772815928014605, 9.73669993832042, 10.661258775070328, 11.693493187603574, 12.626659950720198, 13.59750864026474, 14.54259007086627, 14.827291887827391, 13.970172981405758, 14.865737142172305, 15.696048015423287, 16.64839346605306, 17.547794890835483, 10.762721260454056, 9.764188298723289, 8.781321496676277, 7.818886200646748, 6.8502599524999805, 7.8335591825216015, 8.769649786457594, 9.745733775644704, 10.7422065420807, 11.646226143250045, 12.653112641447118, 13.565994165910377, 14.536601818143701, 14.791479178022808, 13.901202477655252, 13.00234524534026, 13.902823091078954, 14.753030484581089, 15.697138178661016, 16.52972500614688, 11.74137199435574, 10.689389600242665, 9.71136567482579, 8.803777900169953, 7.884591600072272, 8.76615804726927, 9.780787885139983, 10.75103300619561, 11.73802394633388, 12.586248789427561, 13.541377355295165, 14.476868207333672, 14.650561116668953, 13.834542283010473, 12.875328214663877, 11.982664329217872, 12.925730986068771, 13.785798956923783, 14.742462756622901, 15.539930485027051, 12.687758346856812, 11.738575102806266, 10.724327957226482, 9.758859715923716, 8.901491759952217, 9.813566769407803, 10.752894920577928, 11.75551009813819, 12.721320800718425, 13.614454577621485, 14.474578971459813, 14.520726079331197, 13.647595237017228, 12.76299778983916, 11.881106971227288, 11.025720097850531, 11.865984898936935, 12.81891872016882, 13.811663694999657, 14.593623154707329, 13.631895345216861, 12.751145972465148, 11.797122465216447, 10.73153262213701, 9.836782305837197, 10.770918255015133, 11.741802296343462, 12.709668049417422, 13.682175694121428, 14.602521704683596, 14.43574146986327, 13.513254427280998, 12.631831734917393, 11.776899479113645, 10.859284816726689, 10.048971771983789, 10.916839735817783, 11.824941026066474, 12.814834995857622, 13.666363715980232, 14.58794611439749, 13.712697451391145, 12.724838968373938, 11.779695472646438, 10.804530071049436, 11.698416707420371, 12.737827428319585, 13.682742606483837, 14.647042378673085, 14.510999711041341, 13.489791397409409, 12.52444361454871, 11.634124603034948, 10.805011997450967, 9.86338649651678, 9.05525242501378, 9.922969934904737, 10.81633299319186, 11.79599273655907, 12.70705049393119, 15.582102341862768, 14.638857648149283, 13.708814166367675, 12.760937922270662, 11.797674854416456, 12.705465227304835, 13.679659540271263, 14.639208134792002, 14.437290215750913, 13.476380934304737, 12.523834847301343, 11.588364717445732, 10.644097580031623, 9.927760036189675, 8.936648674536164, 7.98761294942896, 8.887662518575294, 9.829719020732744, 10.747699227251392, 11.679896901843053, 16.634304336893127, 15.607555484923834, 14.661384895307975, 13.7363644397535, 12.820779382871804, 13.643901905437888, 14.617810435167504, 14.480487667051008, 13.488094019282237, 12.516983955528064, 11.587132942310964, 10.646213852132362, 9.65306905328913, 8.898651952933573, 7.928449857615653, 6.983882178971568, 7.934788779837907, 8.859094003778868, 9.786979567602195, 10.6614938352483, 17.58813022411073, 16.662447486022856, 15.673486187640952, 14.69615508583929, 13.822560188857254, 14.659609936401289, 14.557219854621426, 13.583862012457946, 12.550712541752873, 11.70806901326809, 10.64388792815889, 9.607826666937274, 8.612404062890729, 7.981146980862889, 6.923703060597478, 6.020125774794103, 6.870988867425438, 7.835250917042649, 8.817294161777228, 9.725390126309684, 18.602859762659033, 17.62686951571663, 16.617802966837218, 15.623689275049124, 14.862205863965533, 14.50971402841023, 13.54583539992815, 12.600012305602327, 11.607153568776694, 10.662104277003749, 9.655307234544656, 8.615621685711432, 7.670452971131462, 6.941053234278105, 5.981956082690929, 4.98315933847022, 5.856417234489358, 6.872706063465608, 7.894931055073612, 8.780176597072169, 18.39736450972225, 17.472024064789068, 16.521056738228992, 15.575102765715819, 14.562789016669603, 13.578112172819752, 12.597019689890704, 11.637835458673488, 10.6654415672934, 9.685024131249952, 8.68801318353365, 7.70885669529068, 6.739098925139416, 5.980768228491734, 5.008165225313802, 3.9427677086839727, 4.887977942597432, 5.944661279240643, 6.897385888537113, 7.80372701026153, 17.445730738552733, 16.472143837954125, 15.532858643741283, 14.605253821722528, 13.622558159218212, 12.638742571154216, 11.671913884570287, 10.702772021217479, 9.686988655249605, 8.663036729412347, 7.731315780878553, 6.752324819949444, 5.804050613161982, 4.939690529445547, 3.9858104920817845, 2.9517596654117666, 3.939340513323458, 4.941948810541134, 5.888117442569113, 6.874672431665319, 16.6919136252189, 15.634646304628271, 14.67310902333487, 13.722499887646673, 12.777692077907712, 11.704007778204737, 10.738165204658438, 9.768673954730547, 8.770848899182663, 7.736432376566793, 6.757433125441241, 5.831401398540913, 4.81161872538497, 3.867803020716944, 2.9280178928555065, 1.9488017666548307, 2.9584962372311283, 3.938240936266651, 4.932921845106872, 5.8740922563001075, 15.812026960237727, 14.858658663405043, 13.84856290605757, 12.866445299086228, 11.929838866594366, 10.896000152808162, 9.92635463059862, 8.899994175695673, 7.9050237503073655, 6.875377663965182, 5.869112999692414, 4.86478181251475, 3.9338605533869897, 2.9075943898010945, 1.9557957377928714, 0.9522463296951741, 1.9658631931577029, 2.963979414217393, 3.915171749368598, 4.982942417133485], [5.100894528060529, 4.122138634316699, 3.0840715913659134, 2.129075041849614, 1.0594942365810953, 0.0, 0.9542828866079318, 1.9713514356831638, 2.9803866641838948, 3.932795746206401, 4.975858693978331, 6.019459358149308, 6.949439043370354, 7.959900603012354, 8.903256823662588, 9.91257981869595, 10.964366152026312, 11.893570324897683, 12.912038696686091, 13.869978642144197, 5.983626844537121, 5.026333010167108, 4.069997699031247, 3.0800057277895245, 2.0466673833989426, 0.9738291435700489, 1.986262579811839, 3.0004767800700036, 3.908840103161655, 4.869405430940779, 5.801835011981906, 6.734653145795167, 7.787391824633172, 8.834166631366159, 9.880695537829359, 10.893293813245561, 11.95768631586683, 12.923765156337518, 13.947499616391411, 14.929220518443982, 6.977134755481698, 6.031406749654747, 5.038930088757139, 4.008439031167359, 2.953504079628876, 1.9718469535490837, 2.9814011392500035, 3.956829630476357, 4.890748725870209, 5.887211655885621, 6.821579965336502, 7.700060760438266, 8.737184064885188, 9.786768625875277, 10.779885979144346, 11.79416472167323, 12.841579078500567, 13.82917976756227, 14.829022958762158, 15.826171301141066, 7.9451540630767825, 7.093160913429246, 6.048855476624339, 5.01676495511832, 3.963396640862686, 2.970223508647948, 3.927114621587624, 4.956148997226395, 5.942274254055887, 6.865123318725651, 7.847048974494758, 8.662207297313559, 9.711023449592664, 10.757691409361223, 11.831878389303084, 12.757921385270429, 13.688606764817033, 14.680094829461645, 15.60746698735223, 16.58612776917442, 8.87658974500089, 7.928606666980886, 6.992911402707154, 5.964300383958549, 4.924252170614285, 4.01019849303161, 4.894051729967778, 5.823619988751894, 6.834286466092752, 7.8796179287601396, 8.776614803571569, 9.615010411598911, 10.642408041844366, 11.67307695374929, 12.639140496700229, 13.620866517134415, 14.626102488572537, 15.572968528827982, 16.609016728022233, 17.539761047476098, 9.837104263498567, 8.823263933134685, 7.841239630782117, 6.885345990470028, 5.863658361681338, 4.999275469419824, 5.8469651390607895, 6.822837271813322, 7.789425094581766, 8.73215204348419, 9.694558958108763, 10.62945699175341, 11.591407859642548, 12.603987463469679, 13.553080102417937, 14.516350177490361, 15.52023468574447, 16.508807188846166, 17.452245897665907, 18.519069123250283, 10.792276544440378, 9.772285954308236, 8.77252096353112, 7.7977952129320025, 6.808397892258416, 5.944104633138659, 6.803233599997127, 7.77009220086291, 8.733976211168725, 9.658535047918633, 10.690769460451879, 11.623936223568503, 12.538014403683645, 13.483095834285175, 13.967984943367117, 14.906500863380588, 15.812449249635138, 16.647131848730663, 17.599477299360437, 18.456704822794173, 11.707300973540374, 10.673098230681978, 9.690231428634966, 8.727796132605437, 7.75916988445867, 7.0073416932399715, 7.805759989824258, 8.781843979011368, 9.739482814929005, 10.64350241609835, 11.650388914295423, 12.563270438758682, 13.518218237163836, 13.932172233562534, 13.041895533194978, 13.93867312731509, 14.849535198541787, 15.704114317888465, 16.648222011968393, 17.43863493810557, 12.671012957062262, 11.598299532201354, 10.62027560678448, 9.712687832128642, 8.793501532030962, 7.93994055798764, 8.816898088506647, 9.787143209562275, 10.774134149700545, 11.583525062275866, 12.53865362814347, 13.474144480181977, 13.67832214903477, 12.975235338550199, 12.016021270203604, 12.918992211192702, 13.872443093531604, 14.736882790231158, 15.693546589930277, 16.448840416985743, 13.596668278815502, 12.647485034764955, 11.633237889185171, 10.667769647882405, 9.810401691910906, 8.987349280126173, 9.789005123944593, 10.791620301504855, 11.75743100408509, 12.61173085046979, 13.471855244308118, 13.548487111697014, 12.675356269383045, 11.903690845378886, 11.021800026767014, 11.96204797982536, 12.81706873224431, 13.770002553476196, 14.762747528307033, 15.524111317012867, 14.54080527717555, 13.660055904423837, 12.706032397175136, 11.6404425540957, 10.745692237795886, 9.98859384381519, 10.85343900866902, 11.82130476174298, 12.718285897488093, 13.599797977531901, 13.463502502229087, 12.541015459646815, 11.65959276728321, 10.917592534653371, 9.999977872266415, 10.985299653958617, 11.867923569125159, 12.77602485937385, 13.765918829164997, 14.59685187828577, 15.496856046356179, 14.621607383349835, 13.633748900332627, 12.688605404605127, 11.713440003008126, 10.916092296220429, 11.849464140645143, 12.794379318809394, 13.68315258203975, 13.538760743407158, 12.517552429775225, 11.552204646914527, 10.661885635400765, 9.945705052990693, 9.004079552056506, 9.991580306988608, 10.874053768212113, 11.767416826499236, 12.80255536105586, 13.637538656236728, 16.491012273821458, 15.547767580107973, 14.617724098326365, 13.669847854229351, 12.706584786375146, 11.92314081610489, 12.849325983457069, 13.808874577977807, 13.46505124811673, 12.504141966670554, 11.55159587966716, 10.616125749811548, 9.67185861239744, 9.010574307789023, 8.07734173007589, 8.923940831403788, 9.83874635188267, 10.78080285404012, 11.754261851748183, 12.686459526339844, 17.543214268851816, 16.516465416882525, 15.570294827266665, 14.645274371712189, 13.729689314830493, 12.861577494237943, 13.78747687835331, 13.508248699416821, 12.51585505164805, 11.54474498789388, 10.61489397467678, 9.673974884498179, 8.680830085654947, 7.98146622453292, 7.011264129214999, 7.9202100609463955, 8.885872613145281, 9.86565662827566, 10.793542192098986, 11.702608565958784, 18.49704015606942, 17.57135741798155, 16.582396119599643, 15.60506501779798, 14.731470120815944, 13.877285525201344, 13.58498088698724, 12.61162304482376, 11.578473574118687, 10.735830045633907, 9.671648960524706, 8.635587699303091, 7.640165095256545, 7.05739203676238, 5.999948116496968, 6.956453656768931, 7.8775514919222305, 8.841813541539441, 9.82385678627402, 10.766504857020166, 18.425200981796223, 17.44921073485382, 16.51814400885424, 15.527489067520147, 14.56724946097415, 13.537475060776046, 12.573596432293964, 11.627773337968142, 10.634914601142508, 9.689865309369564, 8.683068266910471, 7.6433827180772465, 6.698214003497278, 6.017298290177595, 5.0582011385904195, 5.989721962967013, 6.862979858986151, 7.8792686879624005, 8.941678807487165, 9.821291327782653, 17.425125542088068, 16.499785097154884, 15.548817770594809, 14.602863798081636, 13.59055004903542, 12.605873205185569, 11.624780722256519, 10.665596491039302, 9.693202599659214, 8.712785163615766, 7.715774215899465, 6.736617727656496, 5.766859957505232, 5.0329986066066725, 4.084410281213293, 4.949330333180765, 5.894540567094225, 6.951223903737436, 7.944133640950665, 8.844841740972015, 16.47349177091855, 15.499904870319941, 14.5606196761071, 13.633014854088344, 12.650319191584028, 11.666503603520033, 10.699674916936104, 9.730533053583294, 8.71474968761542, 7.690797761778163, 6.759076813244368, 5.78008585231526, 4.8318116455277975, 3.9674515618113615, 3.0163710335218634, 3.9583222899085593, 4.945903137820251, 5.948511435037926, 6.934865194982665, 7.915787162375804, 15.680218357290808, 14.662407336994088, 13.700870055700687, 12.75026092001249, 11.805453110273529, 10.731768810570554, 9.765926237024255, 8.796434987096363, 7.79860993154848, 6.764193408932608, 5.785194157807057, 4.8591624309067285, 3.8393797577507853, 2.8955640530827593, 1.9557789252213218, 2.955364391151623, 3.965058861727921, 4.944803560763443, 5.979669597520424, 6.920840008713659, 14.752532723656632, 13.799164426823948, 12.789068669476475, 11.806951062505133, 10.870344630013271, 9.844505885521784, 8.900646783995317, 7.904349779137437, 6.90937935374913, 5.879733267406946, 4.873468603134178, 3.8691374159565157, 2.938216156828755, 1.9353554221669098, 0.9835567701586866, 1.9871061782563837, 3.0007230417189126, 4.017668190906319, 4.968860526057524, 6.03663119382241], [6.05517741466846, 5.076421520924631, 4.038354477973845, 3.0833579284575454, 2.013777123189027, 0.9542828866079318, 0.0, 1.017068549075232, 2.0261037775759627, 2.978512859598469, 4.0215758073704, 5.065176471541377, 5.995156156762423, 7.005617716404423, 7.948973937054657, 8.958296932088018, 10.01008326541838, 10.939287438289751, 11.95775581007816, 12.915695755536266, 6.937909731145052, 5.980615896775039, 5.024280585639178, 4.034288614397456, 3.000950270006874, 1.9281120301779806, 1.042466018526681, 2.046193893462072, 2.954557216553723, 3.9151225443328466, 4.847552125373974, 5.780370259187235, 6.83310893802524, 7.879883744758227, 8.926412651221426, 9.939010926637629, 11.003403429258897, 11.969482269729586, 12.993216729783478, 13.97493763183605, 7.931417642089629, 6.985689636262678, 5.993212975365072, 4.962721917775291, 3.9077869662368077, 2.9261298401570155, 2.0376045779648457, 3.013033069191199, 3.9364658392622762, 4.932928769277689, 5.86729707872857, 6.745777873830334, 7.782901178277255, 8.832485739267344, 9.825603092536413, 10.839881835065295, 11.887296191892633, 12.874896880954335, 13.874740072154223, 14.871888414533132, 8.899436949684715, 8.047443800037179, 7.003138363232272, 5.971047841726251, 4.917679527470617, 3.9245063952558796, 3.036798160521168, 4.061417764225479, 4.987991367447954, 5.91084043211772, 6.892766087886826, 7.707924410705628, 8.756740562984733, 9.803408522753292, 10.877595502695153, 11.803638498662497, 12.734323878209102, 13.725811942853714, 14.6531841007443, 15.63184488256649, 9.830872631608822, 8.882889553588818, 7.947194289315085, 6.91858327056648, 5.878535057222217, 4.964481379639542, 4.003735268901322, 4.933303527685438, 5.943970005026296, 6.925335042152208, 7.822331916963636, 8.66072752499098, 9.688125155236435, 10.718794067141358, 11.684857610092298, 12.666583630526484, 13.671819601964605, 14.61868564222005, 15.654733841414304, 16.58547816086817, 10.791387150106496, 9.777546819742614, 8.795522517390047, 7.839628877077959, 6.817941248289269, 5.953558356027756, 4.956648677994334, 5.932520810746866, 6.8991086335153105, 7.841835582417733, 8.804242497042306, 9.692691966146128, 10.637124973034616, 11.649704576861748, 12.598797215810006, 13.56206729088243, 14.565951799136538, 15.554524302238237, 16.497963011057976, 17.56478623664235, 11.746559431048308, 10.726568840916169, 9.726803850139053, 8.752078099539935, 7.762680778866347, 6.83800509043537, 5.912917138930672, 6.879775739796455, 7.843659750102269, 8.768218586852177, 9.800452999385422, 10.733619762502046, 11.583731517075714, 12.528812947677244, 13.489047842561135, 14.454262385663183, 15.4839030213133, 16.47954310711792, 17.431888557747694, 18.385881885749267, 12.661583860148305, 11.627381117289909, 10.644514315242898, 9.682079019213369, 8.713452771066601, 7.851534132693795, 6.915443528757803, 7.891527517944913, 8.849166353862548, 9.753185955031894, 10.760072453228966, 11.672953977692226, 12.563935350555905, 13.282462180253715, 13.996178419802911, 14.89295601392302, 15.803818085149718, 16.658397204496396, 17.60250489857632, 18.3929178247135, 13.625295843670193, 12.552582418809285, 11.574558493392411, 10.666970718736573, 9.747784418638894, 8.784132997441464, 7.926581627440192, 8.896826748495819, 9.883817688634089, 10.69320860120941, 11.648337167077013, 12.58382801911552, 12.843804498644097, 12.32552528524138, 12.970304156811537, 13.873275097800633, 14.826725980139535, 15.69116567683909, 16.647829476538206, 17.403123303593674, 14.550951165423433, 13.601767921372886, 12.587520775793102, 11.622052534490336, 10.764684578518837, 9.831541719579997, 8.898688662878136, 9.901303840438398, 10.867114543018634, 11.721414389403334, 12.581538783241662, 12.713969461306341, 11.840838618992372, 11.253980792070067, 11.976082913374947, 12.916330866433292, 13.771351618852242, 14.724285440084127, 15.717030414914964, 16.478394203620798, 15.495088163783482, 14.614338791031768, 13.660315283783067, 12.59472544070363, 11.699975124403817, 10.832786283269014, 9.963122547602563, 10.930988300676523, 11.827969436421636, 12.709481516465445, 12.628984851838414, 11.706497809256142, 10.825075116892537, 10.267882481344552, 10.954260758874348, 11.93958254056655, 12.82220645573309, 13.730307745981781, 14.720201715772928, 15.551134764893702, 16.45113893296411, 15.575890269957766, 14.588031786940558, 13.642888291213058, 12.667722889616057, 11.760284735674253, 10.959147679578686, 11.904062857742938, 12.792836120973293, 12.704243093016485, 11.683034779384553, 10.717686996523854, 9.827367985010092, 9.295994999681874, 9.95836243866444, 10.94586319359654, 11.828336654820044, 12.721699713107167, 13.756838247663792, 14.59182154284466, 17.44529516042939, 16.502050466715904, 15.572006984934296, 14.624130740837282, 13.660867672983077, 12.767333255558714, 11.959009522390613, 12.91855811691135, 12.531347717130455, 11.669624316279881, 10.717078229276487, 9.781608099420875, 8.837340962006767, 8.331402589440367, 9.031624616683823, 9.878223718011721, 10.7930292384906, 11.735085740648051, 12.708544738356114, 13.640742412947775, 18.497497155459747, 17.470748303490456, 16.524577713874596, 15.59955725832012, 14.683972201438424, 13.705769933691768, 12.897160417286853, 12.566628175722823, 11.57423452795405, 10.710227337503209, 9.78037632428611, 8.839457234107506, 7.846312435264275, 7.302294506184266, 7.965547015822931, 8.874492947554328, 9.840155499753214, 10.819939514883592, 11.747825078706917, 12.656891452566715, 18.529743587494554, 17.56221950777779, 16.5208402643565, 15.513402733035978, 14.564048737364015, 13.598193613206234, 12.643360363293242, 11.670002521129762, 10.636853050424689, 9.81914910401003, 8.837131310134035, 7.801070048912419, 6.805647444865873, 6.302244639964352, 6.9542310031049, 7.910736543376863, 8.83183437853016, 9.796096428147372, 10.77813967288195, 11.720787743628097, 17.483580458102217, 16.507590211159815, 15.576523485160235, 14.585868543826145, 13.625628937280148, 12.595854537082044, 11.631975908599964, 10.686152814274143, 9.69329407744851, 8.748244785675565, 7.836002170990861, 6.808865067686574, 5.863696353106605, 5.253091046641409, 6.012484025198352, 6.944004849574944, 7.817262745594082, 8.83355157457033, 9.895961694095094, 10.775574214390584, 16.483505018394066, 15.55816457346088, 14.607197246900807, 13.661243274387633, 12.648929525341417, 11.664252681491567, 10.683160198562518, 9.723975967345302, 8.751582075965214, 7.771164639921767, 6.796766498659929, 5.902100077265823, 4.932342307114559, 4.198480956216, 5.038693167821225, 5.903613219788697, 6.848823453702156, 7.905506790345367, 8.898416527558595, 9.799124627579946, 15.531871247224545, 14.558284346625939, 13.618999152413098, 12.691394330394342, 11.708698667890026, 10.72488307982603, 9.758054393242102, 8.788912529889293, 7.77312916392142, 6.749177238084163, 5.840069096004832, 4.936191593658283, 3.9972939951371242, 3.1329339114206887, 3.970653920129795, 4.91260517651649, 5.900186024428182, 6.902794321645857, 7.889148081590596, 8.870070048983735, 14.725935470682877, 13.720786813300085, 12.759249532006685, 11.808640396318488, 10.863832586579527, 9.790148286876553, 8.824305713330254, 7.854814463402363, 6.8569894078544795, 5.822572885238608, 4.843573634113056, 3.9175419072127284, 3.004862107360112, 2.061046402692086, 2.9100618118292534, 3.9096472777595546, 4.919341748335852, 5.899086447371374, 6.933952484128355, 7.87512289532159, 13.7982498370487, 12.844881540216017, 11.834785782868543, 10.852668175897202, 9.91606174340534, 8.890222998913853, 7.946363897387386, 6.950066892529506, 5.955096467141199, 4.925450380799015, 3.919185716526247, 2.914854529348584, 1.9839332702208234, 1.0540736638582422, 1.9378396567666183, 2.9413890648643157, 3.9550059283268446, 4.971951077514251, 5.923143412665455, 6.990914080430342], [7.072245963743692, 6.093490069999863, 5.055423027049077, 4.1004264775327774, 3.030845672264259, 1.9713514356831638, 1.017068549075232, 0.0, 1.009035228500731, 1.961444310523237, 3.0045072582951677, 4.048107922466144, 4.978087607687191, 5.98854916732919, 6.931905387979424, 7.941228383012785, 8.993014716343147, 9.922218889214518, 10.940687261002926, 11.898627206461033, 7.954978280220286, 6.997684445850273, 6.0413491347144115, 5.051357163472689, 4.018018819082107, 2.9451805792532126, 2.0595345676019132, 1.0291253443868398, 1.937488667478491, 2.8980539952576145, 3.8304835762987417, 4.763301710112002, 5.816040388950007, 6.862815195682995, 7.9093441021461945, 8.921942377562397, 9.986334880183666, 10.952413720654354, 11.976148180708247, 12.957869082760817, 8.94848619116486, 8.00275818533791, 7.010281524440304, 5.979790466850523, 4.92485551531204, 3.9431983892322475, 3.0193715062585214, 2.043943015032168, 2.9193972901870446, 3.915860220202457, 4.850228529653338, 5.728709324755101, 6.7658326292020226, 7.815417190192112, 8.80853454346118, 9.822813285990062, 10.8702276428174, 11.857828331879102, 12.85767152307899, 13.854819865457898, 9.916505498759946, 9.064512349112412, 8.020206912307504, 6.988116390801483, 5.93474807654585, 4.941574944331112, 4.018565088814843, 3.092327710066448, 3.9709228183727223, 4.893771883042487, 5.875697538811593, 6.690855861630395, 7.739672013909501, 8.78633997367806, 9.860526953619921, 10.786569949587264, 11.717255329133868, 12.70874339377848, 13.636115551669066, 14.614776333491257, 10.847941180684053, 9.899958102664051, 8.964262838390319, 7.935651819641713, 6.895603606297449, 5.981549928714775, 4.971080048300183, 4.0415117895160675, 4.980285513915033, 5.908266493076976, 6.805263367888403, 7.643658975915747, 8.671056606161201, 9.701725518066125, 10.667789061017064, 11.64951508145125, 12.654751052889372, 13.601617093144817, 14.63766529233907, 15.568409611792935, 11.80845569918173, 10.794615368817848, 9.81259106646528, 8.856697426153191, 7.835009797364502, 6.970626905102988, 5.923993457393195, 5.072535073862631, 6.021448390918766, 6.846045711709441, 7.804210924169396, 8.675623417070895, 9.620056423959383, 10.632636027786514, 11.581728666734772, 12.544998741807197, 13.548883250061305, 14.537455753163004, 15.480894461982745, 16.54771768756712, 12.763627980123541, 11.7436373899914, 10.743872399214284, 9.769146648615166, 8.779749327941579, 7.805349869834231, 6.880261918329532, 6.071099826050556, 6.965999507505725, 7.772428716143884, 8.804663128677129, 9.73419882082871, 10.56666296800048, 11.51174439860201, 12.471979293485902, 13.43719383658795, 14.466834472238066, 15.462474558042688, 16.41482000867246, 17.368813336674034, 13.678652409223538, 12.64444966636514, 11.66158286431813, 10.6991475682886, 9.730521320141833, 8.818878912092655, 7.882788308156663, 7.105053687768729, 7.971506111266005, 8.757396084323602, 9.764282582520675, 10.673533036018888, 11.546866801480672, 12.506722531725375, 13.39806870365804, 14.405021572653448, 15.429748523331417, 16.405492088884884, 17.34959978296481, 18.358351891092777, 14.642364392745424, 13.569650967884517, 12.591627042467643, 11.684039267811805, 10.763808804484768, 9.751477776840325, 8.893926406839054, 8.155694247988475, 9.033942494563956, 9.697418730501118, 10.652547296368722, 11.588038148407229, 11.853209396515895, 12.765533901068572, 13.663306860300459, 14.57527160486367, 15.528722487202572, 16.473745625258225, 17.430409424957343, 18.355792651069354, 15.568019714498664, 14.618836470448118, 13.604589324868334, 12.639121083565568, 11.780708964364711, 10.798886498978858, 9.866033442276999, 9.160171339931054, 10.0172393489485, 10.725624518695042, 11.58574891253337, 11.72337435917814, 10.85024351686417, 11.69398940789726, 12.66908561686387, 13.618327373496328, 14.553931567271379, 15.506865388503265, 16.4996103633341, 17.36314700728279, 16.51215671285871, 15.631407340107, 14.677383832858299, 13.611793989778862, 12.715999510249691, 11.800131062667875, 10.930467327001425, 10.20428601933021, 10.978094242351503, 11.713691645757153, 11.638389749710212, 10.71590270712794, 9.834480014764335, 10.707891097171744, 11.64726346236327, 12.641579047629586, 13.604786404152227, 14.512887694400918, 15.502781664192065, 16.435887568555692, 17.46820748203934, 16.592958819032997, 15.60510033601579, 14.659956840288292, 13.683747275461931, 12.727629515073113, 11.926492458977549, 11.177360576396625, 11.94296092690316, 11.713647990888283, 10.69243967725635, 9.727091894395652, 8.83677288288189, 9.736003615509066, 10.677629116443253, 11.721277279494668, 12.61091660323918, 13.504279661526304, 14.56551658913453, 15.47657434650665, 18.46236370950462, 17.519119015791134, 16.58907553400953, 15.641199289912516, 14.676892058828951, 13.734678034957575, 12.926354301789475, 12.246347358312233, 11.514279168055225, 10.67902921415168, 9.726483127148285, 8.791012997292674, 7.846745859878565, 8.77141120526756, 9.778582818190271, 10.660803666430857, 11.575609186909738, 12.517665689067188, 13.517223079826852, 14.449420754418513, 18.390877742568133, 17.399858244324577, 16.453687654708716, 15.456124830046539, 14.545927505772159, 13.55070662662327, 12.560883629653427, 11.549559626647593, 10.557165978878821, 9.719632235375006, 8.789781222157906, 7.8488621319793035, 6.855717333136072, 7.742303122011458, 8.71250521732938, 9.657072895973464, 10.62273544817235, 11.637987807295008, 12.642337055096238, 13.64683183679252, 17.512675038419324, 16.54515095870256, 15.503771715281271, 14.496334183960748, 13.546980188288785, 12.581125064131003, 11.62629181421801, 10.65293397205453, 9.619784501349457, 8.802080554934797, 7.846536208005832, 6.8104749467842165, 5.81505234273767, 6.742253255791544, 7.761482151704852, 8.717987691976814, 9.726346354919482, 10.690608404536693, 11.672651649271272, 12.714226791263282, 16.466511909026988, 15.490521662084586, 14.559454936085006, 13.568799994750915, 12.608560388204918, 11.578785988006814, 10.614907359524734, 9.669084265198912, 8.676225528373278, 7.731176236600334, 6.818933621915629, 5.818269965558371, 4.873101250978403, 5.904811699248624, 6.819735173798303, 7.859457732561884, 8.805068771526201, 9.82135760050245, 10.883767720027214, 11.76901326202577, 15.466436469318834, 14.54109602438565, 13.590128697825577, 12.644174725312403, 11.631860976266188, 10.647184132416337, 9.666091649487289, 8.706907418270072, 7.734513526889983, 6.754096090846535, 5.779697949584697, 4.91150497513762, 3.941747204986356, 4.873341313243245, 5.845944316421177, 6.891419245720815, 7.836629479634276, 8.893312816277486, 9.886222553490715, 10.792563675215131, 14.514802698149316, 13.54121579755071, 12.601930603337868, 11.674325781319112, 10.691630118814796, 9.7078145307508, 8.740985844166872, 7.771843980814062, 6.756060614846189, 5.732108689008931, 4.8230005469296, 3.919123044583052, 3.006698893008921, 3.992336167686784, 4.9584599460619145, 5.900411202448609, 6.8879920503603005, 7.890600347577975, 8.876954107522714, 9.86350909661892, 13.708866921607644, 12.703718264224856, 11.742180982931455, 10.791571847243258, 9.846764037504297, 8.773079737801321, 7.807237164255023, 6.837745914327131, 5.839920858779248, 4.805504336163376, 3.8265050850378244, 2.9004733581374964, 2.014267005231909, 2.958082709899935, 3.8978678377613725, 4.897453303691673, 5.907147774267971, 6.886892473303493, 7.9217585100604735, 8.862928921253708, 12.781181287973467, 11.827812991140783, 10.81771723379331, 9.835599626821969, 8.898993194330107, 7.873154449838619, 6.929295348312153, 5.932998343454274, 4.938027918065967, 3.9083818317237835, 2.902117167451015, 1.897785980273352, 0.9668647211455913, 1.9931308847314861, 2.9449295367397093, 3.9484789448374062, 4.962095808299935, 5.979040957487341, 6.930233292638546, 7.998003960403432], [8.081281192244424, 7.102525298500594, 6.064458255549808, 5.109461706033509, 4.03988090076499, 2.9803866641838948, 2.0261037775759627, 1.009035228500731, 0.0, 0.9524090820225062, 1.9954720297944368, 3.039072693965413, 3.969052379186459, 4.979513938828458, 5.922870159478692, 6.932193154512053, 7.983979487842416, 8.913183660713788, 9.931652032502196, 10.889591977960302, 8.930493444296323, 7.9731996099263105, 7.016864298790449, 6.026872327548727, 4.993533983158145, 3.9206957433292517, 2.9082623070874614, 1.873754661321986, 0.9284534389777601, 1.8890187667568838, 2.821448347798011, 3.754266481611272, 4.807005160449277, 5.853779967182264, 6.900308873645464, 7.912907149061667, 8.977299651682936, 9.943378492153624, 10.967112952207517, 11.948833854260087, 9.90390979970221, 8.95818179387526, 7.954535616999191, 6.92404455940941, 5.869109607870927, 4.887452481791135, 3.8640008231936678, 2.8885723319673144, 1.9103620616863135, 2.9068249917017264, 3.8411933011526074, 4.719674096254371, 5.756797400701292, 6.806381961691382, 7.79949931496045, 8.813778057489333, 9.86119241431667, 10.848793103378373, 11.848636294578261, 12.84578463695717, 10.871929107297296, 9.97053166834539, 8.926226231540483, 7.866626965160037, 6.8132586509044035, 5.820085518689666, 4.86319440574999, 3.9369570270015943, 2.961887589871991, 3.8847366545417565, 4.866662310310863, 5.681820633129664, 6.7306367854087705, 7.7773047451773305, 8.85149172511919, 9.777534721086536, 10.70822010063314, 11.699708165277752, 12.627080323168338, 13.605741104990528, 11.748721699172394, 10.778468677022605, 9.842773412748873, 8.814162394000267, 7.774114180656003, 6.860060503073329, 5.815709365235329, 4.8861411064512135, 3.9712502854143015, 4.899231264576246, 5.796228139387673, 6.6346237474150165, 7.66202137766047, 8.692690289565393, 9.658753832516332, 10.640479852950518, 11.645715824388644, 12.592581864644089, 13.628630063838342, 14.559374383292207, 12.686966273540287, 11.673125943176405, 10.691101640823836, 9.735208000511747, 8.713520371723057, 7.816155509167384, 6.768622774328341, 5.917164390797777, 5.012413162418035, 5.837010483208711, 6.795175695668666, 7.666588188570166, 8.611021195458651, 9.623600799285782, 10.57269343823404, 11.535963513306465, 12.539848021560573, 13.528420524662275, 14.471859233482016, 15.53868245906639, 13.642138554482099, 12.619085066217812, 11.619320075440696, 10.644594324841577, 9.65519700416799, 8.649979186769377, 7.724891235264678, 6.915729142985702, 5.9569642790049935, 6.763393487643154, 7.795627900176399, 8.725163592327979, 9.557627739499749, 10.502709170101278, 11.46294406498517, 12.428158608087218, 13.457799243737334, 14.45343932954196, 15.405784780171734, 16.359778108173305, 14.55410008544995, 13.519897342591552, 12.53703054054454, 11.574595244515011, 10.605968996368244, 9.6635082290278, 8.727417625091809, 7.949683004703875, 6.962470882765274, 7.748360855822871, 8.755247354019945, 9.664497807518158, 10.53783157297994, 11.497687303224643, 12.389033475157309, 13.395986344152716, 14.420713294830685, 15.396456860384157, 16.340564554464084, 17.349316662592052, 15.517812068971836, 14.445098644110928, 13.467074718694054, 12.559486944038216, 11.608438121419912, 10.596107093775469, 9.738555723774198, 9.00032356492362, 8.024907266063225, 8.688383502000388, 9.643512067867992, 10.579002919906499, 11.499396867068086, 12.454624198236978, 13.414907738148683, 14.374119565375551, 15.327570447714454, 16.29686610092561, 17.253529900624727, 18.28734836436826, 16.443467390725075, 15.494284146674529, 14.480037001094745, 13.51456875979198, 12.625338281299856, 11.643515815914002, 10.710662759212143, 10.0048006568662, 9.00820412044777, 9.716589290194312, 10.57671368403264, 11.037041712400724, 11.79595015450289, 12.639696045535981, 13.614792254502591, 14.56403401113505, 15.4996382049101, 16.452572026141986, 17.44531700097282, 18.308853644921513, 17.387604389085123, 16.50685501633341, 15.55283150908471, 14.487241666005273, 13.560628827184836, 12.644760379603019, 11.77509664393657, 10.965567789223511, 9.969059013850773, 10.704656417256423, 10.844078266883962, 10.029570060350524, 10.780186652403055, 11.653597734810466, 12.592970100001992, 13.587285685268307, 14.550493041790949, 15.45859433203964, 16.448488301830785, 17.381594206194414, 18.34365515826575, 17.468406495259412, 16.480548012242203, 15.533383152135091, 14.528376592397075, 13.572258832008258, 12.771121775912693, 11.899735170699486, 10.93392569840243, 10.83481377630521, 9.8981281944301, 9.040759247618237, 9.78247952052061, 10.681710253147788, 11.623335754081975, 12.66698391713339, 13.556623240877903, 14.449986299165026, 15.511223226773252, 16.422280984145374, 18.296939326876164, 17.46015883363762, 16.43316222561383, 15.485285981516817, 14.43361876685125, 13.48942188080348, 12.515227567837051, 11.555678973316313, 10.599287447332355, 9.800194999568607, 8.907569840838287, 8.104680350515258, 8.792452497517285, 9.717117842906282, 10.724289455828993, 11.606510304069579, 12.52131582454846, 13.46337232670591, 14.462929717465574, 15.395127392057235, 17.381842514067404, 16.484866523601703, 15.538695933985842, 14.541133109323665, 13.630935785049289, 12.6357149059004, 11.645891908930556, 10.634567905924722, 9.64217425815595, 8.824730250234412, 7.894879237017312, 7.143387406429963, 7.801423970774793, 8.68800975965018, 9.658211854968101, 10.602779533612186, 11.568442085811071, 12.58369444493373, 13.58804369273496, 14.587497205400371, 16.565742312808904, 15.630159237979688, 14.588779994558399, 13.581342463237874, 12.631988467565915, 11.666133343408132, 10.71130009349514, 9.73794225133166, 8.704792780626587, 7.8870888342119265, 6.951634222865239, 6.105000221234876, 6.760758980376391, 7.687959893430265, 8.707188789343574, 9.663694329615536, 10.672052992558203, 11.636315042175415, 12.618358286909993, 13.651393496461754, 15.551520188304115, 14.575529941361713, 13.644463215362133, 12.65380827402804, 11.693568667482044, 10.663794267283942, 9.699915638801862, 8.754092544476041, 7.761233807650407, 6.816184515877462, 5.903941901192757, 5.077590487770099, 5.8188078886171235, 6.850518336887345, 7.765441811437025, 8.805164370200606, 9.751919569058852, 10.768208398035101, 11.830618517559865, 12.715864059558422, 14.551444748595962, 13.626104303662778, 12.675136977102705, 11.729183004589531, 10.716869255543315, 9.732192411693465, 8.751099928764416, 7.791915697547201, 6.819521806167112, 5.839104370123664, 4.8647062288618255, 4.023344249397598, 4.887453842625077, 5.819047950881966, 6.791650954059898, 7.838270043253466, 8.783480277166927, 9.840163613810137, 10.833073351023366, 11.739414472747784, 13.599810977426444, 12.626224076827837, 11.686938882614996, 10.75933406059624, 9.776638398091924, 8.792822810027928, 7.8259941234440005, 6.856852260091191, 5.8410688941233175, 4.81711696828606, 3.908008826206729, 3.0041313238601806, 3.952405530647643, 4.938042805325506, 5.905310743594565, 6.84726199998126, 7.8348428478929515, 8.837451145110627, 9.823804905055367, 10.810359894151572, 12.699831693106912, 11.743902326084092, 10.78236504479069, 9.831755909102494, 8.886948099363533, 7.813263799660557, 6.877932660500597, 5.922754193604259, 4.924929138056376, 3.890512615440505, 2.9115133643149536, 1.9854816374146256, 2.9611178027645595, 3.9049335074325855, 4.844718635294023, 5.844304101224324, 6.853998571800622, 7.833743270836144, 8.868609307593125, 9.809779718786361, 11.772146059472735, 10.818777762640051, 9.808682005292578, 8.826564398321237, 7.889957965829375, 6.864119221337887, 5.920260119811421, 4.967658677193727, 3.9900562150221583, 2.971077905175645, 1.9648132409028765, 0.9827942595504812, 1.913715518678242, 2.939981682264137, 3.8917803342723603, 4.895329742370057, 5.908946605832586, 6.925891755019992, 7.877084090171197, 8.944854757936083], [9.033690274266927, 8.054934380523099, 7.016867337572314, 6.061870788056014, 4.992289982787496, 3.932795746206401, 2.978512859598469, 1.961444310523237, 0.9524090820225062, 0.0, 1.0430629477719306, 2.0866636119429067, 3.0166432971639527, 4.027104856805952, 4.970461077456186, 5.979784072489546, 7.0315704058199096, 7.9607745786912805, 8.979242950479689, 9.937182895937795, 9.882902526318828, 8.925608691948815, 7.969273380812955, 6.979281409571232, 5.945943065180651, 4.873104825351757, 3.8606713891099673, 2.826163743344492, 1.8808625210002663, 1.0390508520987778, 1.971480433139905, 2.904298566953166, 3.957037245791171, 5.003812052524158, 6.018116618397627, 6.985887445162272, 8.050279947783542, 9.01635878825423, 10.028743815363985, 10.99642477223758, 10.856318881724716, 9.910590875897766, 8.906944699021697, 7.876453641431916, 6.821518689893433, 5.839861563813641, 4.816409905216174, 3.8409814139898204, 2.86277114370882, 2.0568570770436203, 2.9912253864945013, 3.869706181596265, 4.906829486043186, 5.956414047033276, 6.949531400302344, 7.925286033597452, 8.972700390424789, 9.960301079486491, 10.96014427068638, 11.944661186554505, 11.824338189319802, 10.922940750367896, 9.878635313562988, 8.819036047182543, 7.76566773292691, 6.7724946007121725, 5.8156034877724965, 4.889366109024101, 3.9142966718944976, 3.0347687398836505, 4.016694395652757, 4.831852718471559, 5.880668870750665, 6.927336830519225, 8.001523810461086, 8.92756680642843, 9.858252185975035, 10.849740250619647, 11.777112408510233, 12.755773190332423, 12.7011307811949, 11.73087775904511, 10.795182494771378, 9.766571476022772, 8.72652326267851, 7.812469585095835, 6.7681184472578355, 5.83855018847372, 4.923659367436808, 4.049263349918139, 4.946260224729567, 5.784655832756911, 6.812053463002365, 7.842722374907288, 8.808785917858227, 9.790511938292413, 10.795747909730538, 11.742613949985984, 12.778662149180237, 13.709406468634102, 13.639375355562793, 12.62553502519891, 11.643510722846344, 10.687617082534254, 9.665929453745564, 8.768564591189891, 7.721031856350847, 6.869573472820283, 5.9297695174530265, 4.987042568550604, 5.94520778101056, 6.8166202739120605, 7.761053280800547, 8.773632884627679, 9.722725523575937, 10.685995598648361, 11.689880106902471, 12.67845261000417, 13.621891318823911, 14.688714544408285, 14.594547636504604, 13.571494148240317, 12.571729157463201, 11.597003406864083, 10.607606086190495, 9.602388268791882, 8.677300317287184, 7.8681382250082095, 6.874320634039985, 5.913425572985047, 6.945659985518292, 7.875195677669874, 8.707659824841645, 9.652741255443175, 10.612976150327066, 11.578190693429114, 12.60783132907923, 13.603471414883854, 14.555816865513629, 15.5098101935152, 15.506509167472455, 14.472306424614057, 13.489439622567046, 12.527004326537517, 11.55837807839075, 10.615917311050305, 9.679826707114314, 8.853300271464162, 7.839537900604586, 6.898392941164764, 7.905279439361838, 8.814529892860053, 9.687863658321836, 10.64771938856654, 11.539065560499205, 12.546018429494612, 13.570745380172582, 14.546488945726052, 15.490596639805979, 16.499348747933947, 16.47022115099434, 15.397507726133433, 14.41948380071656, 13.511896026060722, 12.560847203442417, 11.548516175797975, 10.690964805796703, 9.818458346543617, 8.831467406405347, 7.83841558734228, 8.793544153209883, 9.72903500524839, 10.64942895240998, 11.604656283578874, 12.56493982349058, 13.524151650717448, 14.47760253305635, 15.446898186267504, 16.403561985966622, 17.437380449710155, 17.39587647274758, 16.446693228697033, 15.43244608311725, 14.466977841814485, 13.577747363322361, 12.595924897936507, 11.663071841234649, 10.822935438486196, 9.808687079076256, 8.866621375536205, 9.726745769374531, 10.753234449243168, 11.652394832061706, 12.628517308491391, 13.55916106692717, 14.48109588208479, 15.531349127846967, 16.413778423022464, 17.422686940733787, 18.407868698659723, 18.34001347110763, 17.459264098355916, 16.505240591107217, 15.439650748027779, 14.513037909207341, 13.597169461625525, 12.727505725959075, 11.766050747851997, 10.769541972479258, 9.854688502598316, 9.992694173882798, 10.916545587528, 11.732595734425562, 12.606006816832972, 13.545379182024497, 14.539694767290813, 15.502902123813454, 16.411003414062147, 17.400897383853295, 18.334003288216916, 18.38936482033972, 17.48410597976655, 16.518376746846272, 15.564315380511836, 14.575379457217105, 13.645086307686778, 12.663705317647812, 11.770879687091059, 10.805070214794002, 9.983429683304047, 9.046744101428937, 9.927734774795713, 10.734888602543117, 11.634119335170293, 12.57574483610448, 13.619392999155895, 14.509032322900408, 15.402395381187532, 16.46363230879576, 17.374690066167876, 17.44697141221806, 16.557945783008414, 15.530949174984626, 14.583072930887612, 13.582234673850085, 12.638037787802315, 11.663843474835886, 10.704294880315148, 9.74790335433119, 8.948810906567443, 8.056185747837123, 8.991655877692734, 9.744861579539792, 10.669526924928787, 11.676698537851498, 12.558919386092084, 13.473724906570965, 14.415781408728416, 15.41533879948808, 16.34753647407974, 16.5318745994093, 15.55137982768281, 14.605209238066951, 13.607646413404774, 12.75121011935978, 11.784330812899235, 10.794507815929391, 9.783183812923557, 8.790790165154785, 7.973346157233248, 7.043495144016148, 8.070457858954889, 8.7538330527973, 9.640418841672686, 10.610620936990607, 11.555188615634691, 12.520851167833577, 13.536103526956236, 14.540452774757467, 15.539906287422877, 15.664196621777563, 14.696672542060798, 13.655293298639508, 12.647855767318983, 11.749429313374328, 10.783574189216548, 9.839898717637592, 8.886558158330494, 7.853408687625421, 7.035704741210762, 6.100250129864075, 7.057409303257383, 7.713168062398897, 8.640368975452771, 9.659597871366081, 10.616103411638043, 11.62446207458071, 12.588724124197922, 13.5707673689325, 14.60380257848426, 14.618033492385225, 13.642043245442823, 12.710976519443243, 11.72032157810915, 10.760081971563153, 9.730307571365051, 8.813417386781392, 7.902708451474876, 6.909849714649242, 5.964800422876298, 5.052557808191594, 6.029999569792605, 6.77121697063963, 7.802927418909851, 8.717850893459532, 9.757573452223113, 10.70432865108136, 11.720617480057609, 12.78302759958237, 13.668273141580928, 13.617958052677071, 12.692617607743887, 11.741650281183814, 10.79569630867064, 9.783382559624425, 8.798705715774574, 7.8646016767439475, 6.940531604546036, 5.968137713165947, 4.9877202771224995, 4.013322135860662, 4.975753331420105, 5.8398629246475835, 6.771457032904473, 7.744060036082405, 8.790679125275974, 9.735889359189434, 10.792572695832645, 11.785482433045871, 12.69182355477029, 12.666324281507553, 11.692737380908946, 10.753452186696105, 9.82584736467735, 8.843151702173033, 7.859336114109038, 6.926593836137486, 6.005468167090026, 4.989684801122153, 3.9657328752848953, 3.0566247332055645, 3.956540405882687, 4.904814612670149, 5.8904518873480125, 6.857719825617071, 7.7996710820037665, 8.787251929915458, 9.789860227133133, 10.776213987077872, 11.762768976174078, 11.747422611084406, 10.791493244061584, 9.829955962768183, 8.879346827079987, 7.9345390173410255, 6.860854717638051, 5.92552357847809, 4.980509691595799, 4.0509024237697915, 3.0391285224393405, 2.060129271313789, 2.9378907194371315, 3.913526884787066, 4.857342589455092, 5.797127717316529, 6.796713183246831, 7.806407653823128, 8.78615235285865, 9.821018389615631, 10.762188800808866, 10.81973697745023, 9.866368680617546, 8.856272923270073, 7.87415531629873, 6.937548883806868, 5.911710139315381, 4.967851037788915, 4.015249595171221, 3.037647132999652, 2.0186688231531384, 1.0124041588803703, 1.9352033415729872, 2.866124600700748, 3.8923907642866427, 4.844189416294865, 5.847738824392563, 6.861355687855092, 7.878300837042498, 8.829493172193702, 9.897263839958589], [10.07675322203886, 9.097997328295031, 8.059930285344246, 7.104933735827945, 6.035352930559427, 4.975858693978332, 4.0215758073704, 3.0045072582951677, 1.9954720297944368, 1.0430629477719306, 0.0, 1.0436006641709763, 1.9735803493920225, 2.9840419090340218, 3.9273981296842555, 4.936721124717616, 5.988507458047979, 6.91771163091935, 7.936180002707758, 8.894119948165864, 10.92596547409076, 9.968671639720746, 9.012336328584885, 8.022344357343163, 6.989006012952582, 5.916167773123688, 4.903734336881898, 3.8692266911164226, 2.9239254687721967, 2.001788510393905, 1.0693589293527779, 2.0021770631660387, 2.967937414993643, 3.981233215031795, 4.975053670625696, 5.942824497390342, 7.007217000011611, 7.9732958404823, 8.985680867592054, 9.953361824465649, 11.899381829496647, 10.953653823669697, 9.950007646793628, 8.919516589203846, 7.8645816376653634, 6.882924511585571, 5.859472852988104, 4.884044361761751, 3.90583409148075, 3.0195947353387473, 2.095992652160346, 2.967584677809138, 3.9971980598866645, 4.966194686092224, 5.959312039361292, 6.882223085825522, 7.929637442652858, 8.917238131714559, 9.917081322914447, 10.901598238782574, 12.867401137091733, 11.966003698139827, 10.92169826133492, 9.862098994954474, 8.80873068069884, 7.815557548484103, 6.858666435544427, 5.93242905679603, 4.95568745830973, 3.9975063981787775, 3.1214616613186017, 3.929731214684432, 4.97646231862549, 5.94795036443268, 7.02213734437454, 7.9372467788883325, 8.866908537529229, 9.85839660217384, 10.785768760064427, 11.764429541886617, 13.74419372896683, 12.77394070681704, 11.83824544254331, 10.809634423794703, 9.76958621045044, 8.855532532867764, 7.811181395029765, 6.881613136245649, 5.96505015385204, 5.012001008213266, 4.051027490395412, 4.8825343289697845, 5.909931959215238, 6.903107644736494, 7.869171187687433, 8.85089720812162, 9.804404261284732, 10.751270301540178, 11.78731850073443, 12.718062820188296, 14.682438303334722, 13.66859797297084, 12.686573670618273, 11.730680030306184, 10.708992401517493, 9.81162753896182, 8.764094804122777, 7.859094998516598, 6.892507175748154, 5.949780226845731, 5.049975046676405, 5.914498770124934, 6.85893177701342, 7.863334894812954, 8.796608055655089, 9.759878130727513, 10.763762638981621, 11.687108961558364, 12.630547670378105, 13.697370895962479, 15.637610584276533, 14.614557096012248, 13.614792105235132, 12.640066354636014, 11.650669033962426, 10.645451216563814, 9.720363265059115, 8.832096542415576, 7.837058292335112, 6.876163231280175, 6.11232891405512, 6.973074173882747, 7.8055383210545175, 8.750619751656046, 9.710854646539937, 10.676069189641986, 11.705709825292102, 12.612127766438048, 13.564473217067823, 14.518466545069394, 16.549572115244384, 15.515369372385988, 14.532502570338977, 13.570067274309448, 12.60144102616268, 11.658980258822236, 10.722889654886245, 9.81603792975929, 8.802275558899714, 7.861130599459892, 7.179799658259532, 7.912408389072926, 8.785742154534708, 9.74559788477941, 10.636944056712077, 11.643896925707484, 12.668623876385453, 13.555145297280246, 14.499252991360173, 15.508005099488143, 17.513284098766274, 16.440570673905366, 15.46254674848849, 14.554958973832653, 13.603910151214349, 12.591579123569906, 11.734027753568634, 10.781196004838744, 9.794205064700474, 8.801153245637408, 8.158901349441779, 8.925293489218344, 9.747307448622852, 10.702534779791746, 11.662818319703451, 12.622030146930319, 13.575481029269222, 14.522376824937552, 15.457944358856617, 16.49176282260015, 18.438939420519514, 17.489756176468966, 16.47550903088918, 15.510040789586416, 14.620810311094292, 13.638987845708439, 12.70613478900658, 11.785673096781323, 10.771424737371383, 9.829359033831333, 9.092102965606427, 9.949492933213122, 10.750273328274577, 11.726395804704262, 12.65703956314004, 13.578974378297662, 14.629227624059839, 15.489257061692514, 16.49816557940384, 17.483347337329775, 18.362738778393428, 17.43566880588262, 16.403030302231837, 15.569415283249334, 14.547254480163915, 13.613118530985979, 12.7002642205179, 11.815782923002242, 10.841765578190428, 10.148824396269228, 10.115008725777212, 10.956964585263322, 11.766036830374413, 12.712494115429777, 13.651866480621303, 14.555722704164406, 15.57837278717899, 16.50018385285225, 17.490077822643396, 18.410606776056873, 17.4066880092128, 16.44104303199462, 15.475313799074344, 14.521252432739907, 13.615913228111069, 12.68562007858074, 11.704239088541776, 10.842708365935827, 9.87689889363877, 9.192366410059392, 9.97045169042083, 10.851442363787607, 11.737671479786997, 12.636902212414174, 13.578527713348361, 14.622175876399776, 15.511815200144289, 16.405178258431413, 17.46641518603964, 18.377472943411757, 16.455627763772256, 15.514882835236484, 14.487886227212696, 13.540009983115683, 12.622768444744048, 11.678571558696278, 10.70437724572985, 9.776123559159917, 8.819732033175958, 8.157747633322789, 8.979893336829017, 9.915363466684628, 10.747644456783672, 11.672309802172668, 12.67948141509538, 13.561702263335965, 14.476507783814846, 15.418564285972296, 16.41812167673196, 17.35031935132362, 15.540530950963493, 14.50831687991088, 13.562146290295022, 12.564583465632845, 11.70814717158785, 10.756049347803453, 9.766226350833609, 8.855012491768328, 7.862618843999555, 7.182282883988594, 7.967202733008042, 8.994165447946783, 9.756615930041178, 10.643201718916567, 11.613403814234488, 12.557971492878572, 13.523634045077458, 14.538886404200117, 15.543235652001346, 16.54773043369763, 14.621133674005632, 13.653609594288866, 12.612230350867577, 11.604792819547054, 10.706366365602399, 9.740511241444619, 8.796835769865663, 7.958386837175266, 6.925237366470192, 6.107533420055533, 7.023957718855968, 8.043360679481488, 8.715950939642777, 9.643151852696652, 10.66238074860996, 11.618886288881923, 12.62724495182459, 13.591507001441801, 14.57355024617638, 15.632261786185726, 13.574970544613294, 12.598980297670892, 11.667913571671312, 10.67725863033722, 9.717019023791224, 8.687244623593122, 7.770354439009462, 6.974537130319646, 5.981678393494013, 5.0366291017210685, 5.976265397183487, 7.015950946016711, 7.77399984788351, 8.805710296153732, 9.720633770703412, 10.760356329466992, 11.7258899557615, 12.74217878473775, 13.809702114034424, 14.711336089352859, 12.57489510490514, 11.649554659971956, 10.698587333411883, 9.75263336089871, 8.740319611852494, 7.755642768002644, 6.821538728972016, 5.990413547188057, 5.038938926487432, 4.05954895596727, 4.937029724852555, 5.978536208663985, 6.8426458018914635, 7.774239910148353, 8.746842913326285, 9.812240429956114, 10.757450663869575, 11.814134000512786, 12.815321485054158, 13.73488650254222, 11.623261333735622, 10.649674433137015, 9.710389238924174, 8.782784416905418, 7.800088754401103, 6.8162731663371074, 5.883530888365555, 5.007214662095467, 4.005697119347605, 3.037561554129666, 3.980332322197458, 4.959323283126567, 5.907597489914029, 6.8932347645918925, 7.900782773389001, 8.842734029775697, 9.830314877687389, 10.832923174905064, 11.819276934849803, 12.805831923946009, 10.704359663312475, 9.748430296289653, 8.786893014996252, 7.8362838793080565, 6.891476069569095, 5.817791769866121, 4.882460630706159, 3.9374467438238687, 3.0078394759978613, 2.110957201284111, 3.0899564524096625, 3.980953667209062, 4.956589832558996, 5.900405537227022, 6.84019066508846, 7.839776131018761, 8.849470601595058, 9.829215300630581, 10.864081337387562, 11.805251748580798, 9.776674029678299, 8.823305732845615, 7.8132099754981414, 6.8310923685268, 5.894485936034938, 4.868647191543451, 3.924788090016984, 2.9721866473992904, 1.9945841852277213, 1.0392599209035083, 2.0455245851762767, 2.978266289344918, 3.9091875484726786, 4.935453712058574, 5.887252364066796, 6.890801772164494, 7.904418635627023, 8.921363784814428, 9.872556119965633, 10.94032678773052], [11.120353886209836, 10.141597992466007, 9.103530949515221, 8.14853439999892, 7.078953594730403, 6.019459358149308, 5.065176471541376, 4.048107922466144, 3.039072693965413, 2.0866636119429067, 1.0436006641709763, 0.0, 0.9299796852210461, 1.9404412448630457, 2.8837974655132794, 3.8931204605466405, 4.944906793877004, 5.874110966748375, 6.892579338536782, 7.850519283994888, 11.865684479184173, 10.90839064481416, 9.952055333678299, 8.962063362436577, 7.928725018045996, 6.855886778217102, 5.843453341975312, 4.808945696209837, 3.863644473865611, 2.9030791460864873, 1.9706495650453602, 1.037831431232099, 1.924336750822667, 2.937632550860819, 3.9314530064547206, 4.8992238332193665, 5.963616335840635, 6.929695176311324, 7.942080203421077, 8.909761160294673, 12.839100834590063, 11.893372828763113, 10.889726651887043, 9.859235594297262, 8.804300642758779, 7.822643516678986, 6.799191858081519, 5.823763366855165, 4.845553096574164, 3.92088537103133, 2.997283287852928, 2.0032390458751985, 2.953597395715689, 3.922594021921248, 4.915711375190316, 5.838622421654546, 6.886036778481882, 7.873637467543584, 8.873480658743471, 9.857997574611598, 13.807120142185148, 12.905722703233243, 11.861417266428335, 10.80181800004789, 9.748449685792256, 8.755276553577518, 7.7983854406378414, 6.872148061889446, 5.856978094002312, 4.89879703387136, 4.014543905026815, 2.9653855827504922, 3.9328616544545145, 4.9043497002617045, 5.978536680203565, 6.893646114717357, 7.823307873358253, 8.814795938002865, 9.742168095893451, 10.720828877715642, 14.683912734060245, 13.713659711910456, 12.777964447636725, 11.749353428888119, 10.709305215543855, 9.79525153796118, 8.75090040012318, 7.821332141339065, 6.866340789544623, 5.913291643905849, 4.944109734103625, 3.9181886970358444, 4.945586327281298, 5.859506980565518, 6.825570523516458, 7.807296543950643, 8.760803597113757, 9.707669637369202, 10.743717836563455, 11.67446215601732, 15.622157308428138, 14.608316978064256, 13.626292675711689, 12.6703990353996, 11.648711406610909, 10.751346544055236, 9.703813809216193, 8.756772858131079, 7.790185035362635, 6.847458086460212, 5.88505117183564, 4.950153138190993, 5.894586145079479, 6.819734230641978, 7.753007391484112, 8.716277466556535, 9.720161974810644, 10.643508297387388, 11.58694700620713, 12.653770231791503, 16.57732958936995, 15.554276101105664, 14.554511110328548, 13.57978535972943, 12.590388039055842, 11.58517022165723, 10.66008227015253, 9.729774402030056, 8.734736151949594, 7.773841090894655, 6.94189530506543, 6.008728541948806, 6.841192689120577, 7.786274119722107, 8.746509014605998, 9.670603423120514, 10.70024405877063, 11.568527102267073, 12.520872552896847, 13.474865880898419, 17.489291120337803, 16.455088377479406, 15.472221575432393, 14.509786279402864, 13.541160031256096, 12.598699263915652, 11.66260865997966, 10.71371578937377, 9.699953418514195, 8.758808459074373, 7.9248364354699685, 6.948062757138985, 7.821396522600767, 8.781252252845471, 9.672598424778137, 10.638431159186013, 11.663158109863982, 12.51154463310927, 13.455652327189197, 14.464404435317167, 18.453003103859686, 17.38028967899878, 16.402265753581904, 15.494677978926068, 14.543629156307764, 13.531298128663321, 12.649118985508855, 11.678873864453227, 10.691882924314957, 9.69883110525189, 8.896438709322911, 7.9609478572844035, 8.782961816688912, 9.738189147857806, 10.698472687769511, 11.65768451499638, 12.611135397335282, 13.478776160766577, 14.414343694685641, 15.448162158429176, 18.2632751125825, 17.404639011370524, 16.432224146050824, 15.48762745883145, 14.43894436187792, 13.570762430504022, 12.72109744107135, 11.905351299133507, 10.848074168325539, 10.727036893445813, 9.82964032548756, 8.985147301279182, 9.785927696340638, 10.762050172770323, 11.692693931206101, 12.61462874636372, 13.664881992125897, 14.445656397521539, 15.454564915232861, 16.439746673158798, 17.319138114222454, 16.39206814171164, 15.359429638060858, 14.525814619078357, 13.50365381599294, 12.569517866815005, 11.656663556346924, 10.86123661973435, 9.887219274922536, 10.817171774300682, 10.852546085658345, 9.992618953329382, 10.801691198440473, 11.748148483495838, 12.687520848687363, 13.591377072230465, 14.614027155245049, 15.456583188681275, 16.446477158472423, 17.367006111885896, 16.363087345041826, 15.397442367823645, 14.431713134903367, 13.47765176856893, 12.572312563940093, 11.642019414409766, 10.6606384243708, 9.888162062667936, 8.92235259037088, 9.860713788090846, 10.76919945194945, 10.98142976606167, 11.799398330322918, 12.720035965158516, 13.661661466092703, 14.585096419200474, 15.517010937456782, 16.46519122155589, 17.520829182069303, 18.326319333934936, 15.412027099601278, 14.471282171065507, 13.444285563041719, 12.496409318944705, 11.579167780573073, 10.634970894525303, 9.660776581558874, 8.821577255892024, 7.865185729908066, 8.826095011354242, 9.778641098357637, 10.714111228213248, 11.635342589942317, 12.560007935331313, 13.567179548254025, 14.449400396494612, 15.364205916973493, 16.30626241913094, 17.305819809890604, 18.238017484482263, 14.496930286792518, 13.464716215739903, 12.518545626124045, 11.520982801461868, 10.664546507416873, 9.712448683632477, 8.722625686662633, 7.900466188500434, 6.908072540731662, 7.941607397030987, 8.854900866166687, 9.881863581105428, 10.644314063199824, 11.530899852075212, 12.501101947393133, 13.445669626037219, 14.411332178236105, 15.426584537358764, 16.43093378515999, 17.435428566856274, 13.577533009834656, 12.61000893011789, 11.568629686696601, 10.561192155376077, 9.662765701431422, 8.696910577273641, 7.753235105694687, 6.989244283375147, 5.970691063202299, 6.995231553214178, 7.911655852014613, 8.931058812640135, 9.603649072801423, 10.530849985855298, 11.550078881768606, 12.506584422040568, 13.514943084983235, 14.479205134600447, 15.461248379335025, 16.51995991934437, 12.531369880442318, 11.555379633499916, 10.624312907500336, 9.633657966166243, 8.673418359620246, 7.643643959422144, 6.726753774838486, 6.005394576519527, 5.027132090226119, 5.924327234879714, 6.863963530342132, 7.903649079175357, 8.661697981042156, 9.693408429312377, 10.608331903862057, 11.648054462625637, 12.613588088920146, 13.629876917896395, 14.69740024719307, 15.67821524241844, 11.531294440734165, 10.60595399580098, 9.654986669240907, 8.709032696727734, 7.696718947681518, 6.712042103831667, 5.777938064801041, 4.94681288301708, 3.995338262316455, 4.9472470891259155, 5.8247278580112, 6.86623434182263, 7.730343935050109, 8.661938043306998, 9.63454104648493, 10.69993856311476, 11.64514879702822, 12.70183213367143, 13.703019618212803, 14.701765655607803, 10.579660669564646, 9.60607376896604, 8.666788574753198, 7.739183752734442, 6.7564880902301265, 5.772672502166131, 4.839930224194579, 3.96361399792449, 2.962096455176629, 3.925259687288311, 4.868030455356103, 5.847021416285212, 6.795295623072675, 7.780932897750538, 8.835788363087946, 9.809613182841279, 10.797194030752971, 11.799802327970646, 12.786156087915385, 13.772711077011591, 9.660758999141498, 8.704829632118678, 7.743292350825277, 6.79268321513708, 5.847875405398119, 4.774191105695144, 3.8388599665351837, 2.893846079652892, 1.9642388118268852, 2.9986553344427564, 3.977654585568308, 4.903686312468636, 5.923468985624579, 6.867284690292605, 7.8070698181540426, 8.806655284084343, 9.81634975466064, 10.796094453696163, 11.830960490453144, 12.77213090164638, 8.733073365507321, 7.779705068674638, 6.769609311327166, 5.7874917043558245, 4.850885271863962, 3.8250465273724745, 2.881187425846008, 1.9285859832283139, 0.9509835210567451, 1.980629607398929, 2.986894271671697, 3.99122545884936, 4.922146717977121, 5.948412881563016, 6.900211533571239, 7.903760941668937, 8.917377805131466, 9.934322954318873, 10.885515289470078, 11.953285957234964], [12.050333571430885, 11.071577677687056, 10.03351063473627, 9.07851408521997, 8.008933279951451, 6.949439043370355, 5.995156156762423, 4.978087607687191, 3.9690523791864596, 3.016643297163953, 1.9735803493920225, 0.9299796852210461, 0.0, 1.0104615596419995, 1.9538177802922332, 2.963140775325594, 4.014927108655957, 4.944131281527328, 5.962599653315737, 6.920539598773843, 12.79566416440522, 11.838370330035207, 10.882035018899346, 9.892043047657625, 8.858704703267042, 7.785866463438149, 6.773433027196359, 5.738925381430883, 4.793624159086657, 3.8330588313075333, 2.900629250266406, 1.967811116453145, 0.9943570656016207, 2.0076528656397725, 3.001473321233674, 3.96924414799832, 5.033636650619589, 5.999715491090278, 7.0121005182000316, 7.9797814750736284, 13.769080519811109, 12.823352513984158, 11.819706337108089, 10.789215279518308, 9.734280327979825, 8.752623201900033, 7.729171543302566, 6.753743052076212, 5.775532781795211, 4.850865056252376, 3.927262973073974, 2.933218731096244, 2.0236177104946425, 2.9926143367002016, 3.9857316899692696, 4.9086427364334995, 5.956057093260837, 6.943657782322538, 7.9435009735224265, 8.928017889390555, 14.737099827406194, 13.835702388454289, 12.79139695164938, 11.731797685268935, 10.678429371013301, 9.685256238798564, 8.728365125858888, 7.802127747110491, 6.786957779223359, 5.8287767190924065, 4.944523590247861, 3.895365267971538, 3.002881969233468, 3.974370015040658, 5.048556994982517, 5.96366642949631, 6.8933281881372075, 7.88481625278182, 8.812188410672405, 9.790849192494596, 15.61389241928129, 14.643639397131501, 13.70794413285777, 12.679333114109165, 11.6392849007649, 10.725231223182226, 9.680880085344226, 8.75131182656011, 7.796320474765669, 6.843271329126895, 5.874089419324671, 4.84816838225689, 4.075502088842338, 4.929527295344472, 5.895590838295411, 6.877316858729596, 7.83082391189271, 8.777689952148155, 9.813738151342408, 10.744482470796273, 16.55213699364918, 15.538296663285301, 14.556272360932734, 13.600378720620645, 12.578691091831955, 11.681326229276282, 10.633793494437239, 9.686752543352126, 8.720164720583682, 7.777437771681258, 6.815030857056686, 5.88013282341204, 5.02450190664052, 5.8897545454209315, 6.8230277062630655, 7.78629778133549, 8.790182289589598, 9.713528612166341, 10.656967320986082, 11.723790546570456, 17.507309274590995, 16.48425578632671, 15.484490795549593, 14.509765044950475, 13.520367724276888, 12.515149906878275, 11.590061955373576, 10.659754087251105, 9.664715837170641, 8.703820776115702, 7.871874990286477, 6.938708227169853, 5.971108450681617, 6.885036639469302, 7.816897019513915, 8.740623737899469, 9.770264373549585, 10.638547417046025, 11.5908928676758, 12.544886195677371, 18.419270805558845, 17.385068062700448, 16.402201260653438, 15.43976596462391, 14.471139716477142, 13.528678949136697, 12.592588345200706, 11.643695474594816, 10.62993310373524, 9.688788144295419, 8.854816120691016, 7.878042442360032, 6.951312284161808, 7.9111680144065115, 8.742986429686054, 9.708451473964967, 10.733178424642936, 11.581564947888223, 12.52567264196815, 13.53442475009612, 18.362865347888352, 17.46140391757577, 16.483379992158895, 15.512729589364168, 14.525864836536819, 13.68819146742151, 12.76322479128825, 12.131900969311483, 11.621862609536002, 10.628810790472935, 9.782388052685883, 8.846897200647376, 7.912877578249953, 8.868104909418847, 9.768860692677428, 10.728072519904297, 11.681523402243199, 12.54879647554553, 13.484364009464594, 14.518182473208128, 17.333295427361456, 16.474659326149478, 15.502244460829777, 14.557647773610405, 13.508964676656875, 12.640782745282976, 11.791117755850305, 11.127423877368903, 11.778053853546583, 11.657016578666859, 10.715589668850532, 9.871096644642154, 8.915843457901678, 9.891965934331363, 10.763081936114018, 11.68501675127164, 12.735269997033816, 13.515676712300492, 14.524585230011814, 15.50976698793775, 16.38915842900141, 15.462088456490594, 14.429449952839812, 13.595834933857311, 12.573674130771895, 11.63953818159396, 10.726683871125879, 10.083309197969747, 10.81719896014358, 11.747151459521726, 11.738495429021317, 10.878568296692354, 9.931606960001513, 10.878064245056878, 11.784904090614617, 12.661765077138384, 13.684415160152968, 14.526603503460228, 15.516497473251375, 16.437026426664847, 15.43310765982078, 14.4674626826026, 13.501733449682321, 12.547672083347884, 11.642332878719047, 10.71203972918872, 9.730658739149755, 9.110234640903332, 9.852332275591923, 10.79069347331189, 11.699179137170495, 11.867379109424641, 10.929314091883958, 11.849951726719556, 12.780802410824526, 13.655484424108392, 14.5873989423647, 15.535211536334842, 16.590849496848254, 17.396339648713887, 14.482047414380231, 13.541302485844462, 12.514305877820673, 11.56642963372366, 10.649188095352027, 9.704991209304257, 8.730796896337829, 8.041247858987724, 8.79516541512911, 9.756074696575286, 10.70862078357868, 11.644090913434292, 11.919341114887283, 12.814544136961063, 13.707540232805142, 14.656575957912347, 15.614594831151077, 16.52182550879396, 17.521382899553622, 18.423493240802024, 13.56695060157147, 12.534736530518858, 11.588565940902999, 10.591003116240822, 9.734566822195827, 8.782468998411431, 7.792646001441588, 6.99836343402328, 7.8380522259527075, 8.871587082252033, 9.784880551387733, 10.811843266326473, 11.57429374842087, 12.460879537296258, 13.431081632614179, 14.375649311258265, 15.34131186345715, 16.35656422257981, 17.360913470381035, 18.365408252077316, 12.647553324613611, 11.680029244896845, 10.638650001475556, 9.631212470155031, 8.732786016210376, 7.766930892052596, 6.82325542047364, 6.0592645981541, 6.9006707484233445, 7.925211238435224, 8.841635537235659, 9.861038497861179, 10.533628758022468, 11.460829671076343, 12.480058566989651, 13.436564107261614, 14.44492277020428, 15.409184819821492, 16.39122806455607, 17.449939604565415, 11.601390195221272, 10.62539994827887, 9.69433322227929, 8.703678280945198, 7.743438674399202, 6.713664274201099, 5.79677408961744, 5.075414891298481, 5.957111775447165, 6.854306920100759, 7.793943215563178, 8.833628764396401, 9.591677666263202, 10.623388114533423, 11.538311589083103, 12.578034147846683, 13.543567774141192, 14.55985660311744, 15.627379932414115, 16.608194927639488, 10.601314755513117, 9.675974310579935, 8.725006984019862, 7.779053011506688, 6.766739262460472, 5.7820624186106215, 4.847958379579994, 4.016833197796034, 4.9253179475375015, 5.877226774346961, 6.754707543232246, 7.796214027043676, 8.660323620271155, 9.591917728528044, 10.564520731705976, 11.629918248335805, 12.575128482249266, 13.631811818892476, 14.632999303433849, 15.63174534082885, 9.649680984343599, 8.676094083744992, 7.736808889532152, 6.809204067513396, 5.826508405009081, 4.842692816945085, 3.9099505389735327, 3.0336343127034437, 3.892076140397675, 4.855239372509357, 5.798010140577149, 6.777001101506258, 7.72527530829372, 8.710912582971583, 9.76576804830899, 10.739592868062326, 11.727173715974018, 12.729782013191693, 13.716135773136433, 14.702690762232638, 8.73077931392045, 7.774849946897631, 6.813312665604231, 5.862703529916034, 4.917895720177073, 3.8442114204740987, 2.9088802813141372, 1.9638663944318457, 2.894218497047931, 3.9286350196638025, 4.907634270789354, 5.833665997689683, 6.8534486708456255, 7.7972643755136515, 8.73704950337509, 9.73663496930539, 10.746329439881688, 11.72607413891721, 12.760940175674191, 13.702110586867427, 7.803093680286275, 6.849725383453592, 5.839629626106119, 4.857512019134778, 3.920905586642916, 2.8950668421514285, 1.951207740624962, 0.9986062980072676, 1.8809632062777912, 2.9106092926199754, 3.9168739568927435, 4.921205144070406, 5.852126403198167, 6.878392566784061, 7.830191218792285, 8.833740626889982, 9.847357490352511, 10.864302639539918, 11.815494974691124, 12.88326564245601], [13.060795131072883, 12.082039237329054, 11.043972194378268, 10.088975644861968, 9.01939483959345, 7.959900603012353, 7.005617716404421, 5.9885491673291895, 4.979513938828458, 4.027104856805952, 2.9840419090340218, 1.9404412448630457, 1.0104615596419995, 0.0, 0.9433562206502337, 1.9526792156835946, 3.0044655490139576, 3.9336697218853285, 4.952138093673737, 5.910078039131843, 13.80612572404722, 12.848831889677207, 11.892496578541346, 10.902504607299624, 9.869166262909042, 8.796328023080148, 7.783894586838358, 6.749386941072883, 5.804085718728657, 4.843520390949533, 3.911090809908406, 2.978272676095145, 2.00481862524362, 0.9971913059977732, 1.991011761591675, 2.958782588356321, 4.02317509097759, 4.989253931448279, 6.001638958558032, 6.969319915431629, 14.779542079453108, 13.833814073626158, 12.830167896750089, 11.799676839160307, 10.744741887621824, 9.763084761542032, 8.739633102944564, 7.7642046117182115, 6.785994341437211, 5.8613266158943755, 4.937724532715974, 3.9436802907382438, 3.0317373380482913, 1.9821527770582021, 2.9752701303272704, 3.8981811767915, 4.945595533618837, 5.933196222680539, 6.933039413880427, 7.917556329748555, 15.747561387048194, 14.846163948096287, 13.801858511291378, 12.742259244910933, 11.6888909306553, 10.695717798440562, 9.738826685500886, 8.812589306752491, 7.7974193388653585, 6.839238278734406, 5.954985149889861, 4.905826827613538, 4.010576415167218, 2.9639084553986583, 4.038095435340518, 4.953204869854311, 5.882866628495208, 6.8743546931398205, 7.801726851030406, 8.780387632852596, 16.624353978923292, 15.654100956773501, 14.718405692499768, 13.689794673751162, 12.649746460406899, 11.735692782824223, 10.691341644986226, 9.76177338620211, 8.806782034407668, 7.853732888768895, 6.884550978966671, 5.85862994189889, 4.949734647607395, 3.919065735702472, 4.8851292786534115, 5.866855299087597, 6.820362352250711, 7.767228392506156, 8.803276591700408, 9.734020911154273, 17.56259855329118, 16.5487582229273, 15.566733920574732, 14.610840280262643, 13.589152651473952, 12.691787788918282, 11.644255054079238, 10.697214102994126, 9.730626280225682, 8.787899331323258, 7.825492416698686, 6.890594383054039, 5.891872589606063, 4.879292985778932, 5.812566146621066, 6.77583622169349, 7.7797207299475994, 8.703067052524341, 9.646505761344082, 10.713328986928456, 18.517770834232994, 17.49471734596871, 16.494952355191593, 15.520226604592475, 14.530829283918887, 13.525611466520274, 12.600523515015576, 11.670215646893105, 10.675177396812641, 9.714282335757702, 8.818737343949753, 7.885570580833129, 6.819656510428832, 5.874575079827302, 6.806435459871915, 7.730162178257469, 8.759802813907585, 9.628085857404026, 10.5804313080338, 11.534424636035371, 18.331054522148037, 17.38582941271342, 16.402962610666407, 15.487159729245374, 14.549734924467112, 13.610328772527179, 12.763901330328638, 12.654157034236816, 11.64039466337724, 10.699249703937419, 9.747241674473331, 8.770467996142347, 7.799860343909022, 6.904244719392736, 7.732524870044054, 8.697989914322967, 9.722716865000937, 10.571103388246224, 11.51521108232615, 12.52396319045412, 17.352403788246352, 16.45094235793377, 15.472918432516895, 14.502268029722169, 13.51540327689482, 12.67772990777951, 11.752763231646249, 12.723008352701877, 12.579116497363767, 11.586064678300701, 10.630936112433098, 9.69544526039459, 8.761425637997167, 7.861181614405072, 8.758399133035429, 9.717610960262297, 10.6710618426012, 11.53833491590353, 12.473902449822594, 13.507720913566128, 16.322833867719456, 15.464197766507477, 14.491782901187777, 13.547186213968406, 12.498503117014875, 11.630321185640977, 10.780656196208303, 11.728202743956993, 12.619163895617998, 12.546760178393551, 11.564137728597746, 10.719644704389369, 9.764391517648892, 8.932726107576384, 9.752620376472018, 10.67455519162964, 11.724808437391816, 12.505215152658492, 13.514123670369814, 14.49930542829575, 15.378696869359409, 14.451626896848595, 13.418988393197813, 12.585373374215312, 11.563212571129895, 10.62907662195196, 9.716222311483877, 10.684088064557837, 11.658309002214995, 12.588261501593141, 12.587043488768531, 11.727116356439568, 10.780155019748728, 9.918824418301899, 10.774442530972618, 11.651303517496384, 12.673953600510968, 13.516141943818228, 14.506035913609375, 15.426564867022847, 14.422646100178781, 13.4570011229606, 12.491271890040322, 11.537210523705884, 10.631871319077048, 9.701578169546721, 8.720197179507753, 9.734539796483288, 10.693442317663338, 11.631803515383305, 12.54028917924191, 12.715927169171856, 11.777862151631172, 10.890711899964577, 11.770340851182526, 12.645022864466393, 13.5769373827227, 14.524749976692842, 15.580387937206254, 16.385878089071888, 13.471585854738231, 12.530840926202462, 11.503844318178674, 10.55596807408166, 9.638726535710028, 8.694529649662257, 7.720335336695828, 8.679883931216567, 9.636275457200526, 10.597184738646702, 11.549730825650096, 12.485200955505707, 12.767889174634497, 11.855304310206083, 12.697078673163142, 13.646114398270347, 14.604133271509077, 15.511363949151958, 16.510921339911622, 17.413031681160025, 12.55648904192947, 11.524274970876858, 10.578104381261, 9.580541556598822, 8.724105262553827, 7.772007438769431, 6.782184441799588, 7.725250538864302, 8.681809220950505, 9.715344077249831, 10.645195090466931, 11.672157805405671, 12.54581027852085, 12.884412393462185, 13.763156274024034, 14.64984516872774, 15.557007010246465, 16.496584621553957, 17.47164099956082, 18.46086571832776, 11.637091764971611, 10.669567685254846, 9.628188441833556, 8.620750910513031, 7.722324456568377, 6.756469332410596, 5.812793860831641, 6.786151702995122, 7.744427743421143, 8.77178850582975, 9.813152067335642, 10.832555027961162, 11.50514528812245, 12.432346201176324, 13.451575097089632, 14.408080637361595, 15.416439300304262, 16.380701349921473, 17.362744594656053, 18.421456134665398, 10.590928635579273, 9.61493838863687, 8.68387166263729, 7.693216721303199, 6.732977114757202, 5.703202714559099, 4.78631252997544, 5.833091566833235, 6.800868770444964, 7.726572524332546, 8.76545974566316, 9.805145294496384, 10.563194196363183, 11.594904644633404, 12.509828119183084, 13.549550677946664, 14.515084304241173, 15.531373133217421, 16.598896462514098, 17.579711457739467, 9.590853195871118, 8.665512750937935, 7.714545424377862, 6.768591451864689, 5.756277702818473, 4.771600858968622, 3.837496819937995, 4.796681051155211, 5.7690749425353, 6.749492378578748, 7.726224073332228, 8.767730557143658, 9.631840150371136, 10.563434258628025, 11.536037261805957, 12.601434778435786, 13.546645012349247, 14.603328348992457, 15.60451583353383, 16.60326187092883, 8.639219424701599, 7.665632524102993, 6.726347329890152, 5.798742507871396, 4.816046845367081, 3.8322312573030852, 2.899488979331533, 3.8686308426843423, 4.863592670497657, 5.826755902609339, 6.769526670677131, 7.748517631606239, 8.696791838393702, 9.682429113071565, 10.737284578408973, 11.711109398162305, 12.698690246073998, 13.701298543291673, 14.687652303236412, 15.674207292332618, 7.720317754278451, 6.764388387255631, 5.802851105962231, 4.852241970274035, 3.9074341605350735, 2.833749860832099, 1.898418721672138, 2.8679099716000294, 3.8657350271479127, 4.900151549763784, 5.879150800889335, 6.805182527789664, 7.8249652009456065, 8.768780905613632, 9.70856603347507, 10.70815149940537, 11.717845969981667, 12.69759066901719, 13.73245670577417, 14.673627116967406, 6.792632120644275, 5.839263823811592, 4.82916806646412, 3.8470504594927784, 2.910444027000916, 1.8846052825094288, 0.9407461809829624, 1.967106635885909, 2.891424765919791, 3.921070852261975, 4.927335516534743, 5.931666703712406, 6.862587962840166, 7.888854126426061, 8.840652778434285, 9.844202186531982, 10.85781904999451, 11.874764199181918, 12.825956534333123, 13.89372720209801], [14.004151351723115, 13.025395457979286, 11.9873284150285, 11.0323318655122, 9.962751060243681, 8.903256823662586, 7.948973937054655, 6.931905387979423, 5.922870159478692, 4.970461077456186, 3.9273981296842555, 2.8837974655132794, 1.9538177802922332, 0.9433562206502337, 0.0, 1.0093229950333609, 2.061109328363724, 2.9903135012350948, 4.008781873023503, 4.966721818481609, 14.749481944697454, 13.79218811032744, 12.83585279919158, 11.845860827949858, 10.812522483559276, 9.739684243730382, 8.727250807488591, 7.692743161723117, 6.7474419393788905, 5.786876611599767, 4.85444703055864, 3.9216288967453785, 2.948174845893854, 1.940547526648007, 1.0476555409414412, 2.015426367706087, 3.0798188703273564, 4.045897710798045, 5.058282737907798, 6.025963694781395, 15.722898300103342, 14.777170294276392, 13.773524117400322, 12.743033059810541, 11.688098108272058, 10.706440982192266, 9.682989323594798, 8.707560832368445, 7.729350562087444, 6.804682836544609, 5.8810807533662075, 4.8870365113884775, 3.9750935586985254, 2.925508997708436, 2.072738819857567, 2.954824956141266, 4.002239312968603, 4.989840002030305, 5.989683193230193, 6.974200109098321, 16.690917607698427, 15.78952016874652, 14.745214731941612, 13.685615465561167, 12.632247151305533, 11.639074019090796, 10.68218290615112, 9.755945527402725, 8.740775559515592, 7.78259449938464, 6.898341370540095, 5.849183048263772, 4.953932635817452, 3.9072646760488925, 3.1365530097772742, 4.009848649204077, 4.939510407844974, 5.930998472489587, 6.858370630380172, 7.837031412202362, 17.567710199573526, 16.597457177423735, 15.661761913150002, 14.633150894401396, 13.593102681057132, 12.679049003474457, 11.63469786563646, 10.705129606852344, 9.750138255057902, 8.79708910941913, 7.827907199616905, 6.801986162549124, 5.893090868257629, 4.862421956352707, 4.187580879088189, 4.966482349290651, 5.877006131600477, 6.823872171855922, 7.859920371050174, 8.79066469050404, 18.50595477394141, 17.49211444357753, 16.510090141224964, 15.554196500912877, 14.532508872124186, 13.635144009568515, 12.587611274729472, 11.640570323644361, 10.673982500875917, 9.731255551973494, 8.76884863734892, 7.833950603704273, 6.835228810256298, 5.822649206429166, 5.115017747055844, 6.039652343383703, 6.9097581997421305, 7.7597108318741075, 8.703149540693849, 9.769972766278222, 18.372252515516507, 17.409971244290492, 16.420840999696424, 15.56263240853551, 14.573235087861923, 13.74629400382305, 13.54387973566581, 12.613571867543339, 11.618533617462877, 10.657638556407937, 9.762093564599986, 8.828926801483362, 7.763012731079066, 6.817931300477537, 6.108887060306693, 6.993978299947682, 7.893634877299518, 8.684729636753792, 9.637075087383566, 10.591068415385138, 17.387698301497807, 16.453333258523386, 15.470466456476375, 14.55466357505534, 13.622463095661669, 12.683056943721736, 13.619147547657727, 13.597513254887051, 12.583750884027475, 11.642605924587654, 10.690597895123565, 9.713824216792581, 8.743216564559257, 7.847600940042971, 7.034976470478832, 7.961806036013181, 8.856548928392868, 9.62774716759599, 10.571854861675916, 11.580606969803886, 16.409047567596122, 15.518446203743736, 14.540422278326862, 13.569771875532135, 12.588131448089376, 11.750458078974066, 12.696119452296484, 13.666364573352112, 13.522472718014, 12.529420898950935, 11.574292333083331, 10.638801481044824, 9.7047818586474, 8.804537835055307, 8.060850733470208, 8.981486952135569, 9.833641033403051, 10.594978695253296, 11.53054622917236, 12.564364692915895, 15.379477647069224, 14.520841545857243, 13.548426680537544, 12.614690059778372, 11.571231288209432, 10.703049356835534, 11.724012416858539, 12.671558964607229, 13.562520116268232, 13.490116399043785, 12.50749394924798, 11.663000925039603, 10.707747738299126, 9.87608232822662, 9.055071976906797, 9.93843118350291, 10.893387120534888, 11.561858932008258, 12.57076744971958, 13.555949207645517, 14.435340648709175, 13.50827067619836, 12.475632172547579, 11.642017153565078, 10.635940742324452, 9.701804793146517, 10.659578532134113, 11.627444285208073, 12.601665222865229, 13.531617722243375, 13.530399709418765, 12.670472577089802, 11.723511240398961, 10.862180638952134, 10.076894131407396, 10.915179509369654, 11.84253228365404, 12.572785723167994, 13.562679692959142, 14.483208646372614, 13.479289879528547, 12.513644902310366, 11.547915669390088, 10.59385430305565, 9.704599490271606, 8.774306340741278, 9.663553400157989, 10.677896017133524, 11.636798538313572, 12.57515973603354, 13.483645399892144, 13.65928338982209, 12.721218372281406, 11.834068120614813, 11.072792451617305, 11.908898856339663, 12.836402084567085, 13.581393756042608, 14.63703171655602, 15.442521868421656, 12.528229634087998, 11.587484705552228, 10.56048809752844, 9.612611853431426, 8.711454706904586, 7.767257820856815, 8.663691557346063, 9.623240151866801, 10.57963167785076, 11.540540959296935, 12.49308704630033, 13.428557176155941, 13.711245395284731, 12.798660530856319, 11.999530273597921, 12.948565998705126, 13.871709500896529, 14.568007728501724, 15.567565119261388, 16.469675460509794, 11.613132821279237, 10.580918750226624, 9.634748160610766, 8.637185335948589, 7.7807490419035945, 6.828821142723763, 7.725540662449822, 8.668606759514535, 9.625165441600739, 10.658700297900065, 11.588551311117165, 12.615514026055905, 13.489166499171084, 13.82776861411242, 13.065607874458813, 13.952296769162519, 14.824583239633917, 15.553228400903722, 16.528284778910585, 17.51750949767753, 10.693735544321378, 9.726211464604612, 8.684832221183322, 7.677394689862798, 6.778968235918144, 5.813113111760362, 6.7561500814818745, 7.729507923645356, 8.687783964071377, 9.715144726479984, 10.756508287985875, 11.775911248611395, 12.448501508772683, 13.375702421826558, 14.076923887176843, 14.916053173339984, 15.888383152046385, 16.57707148763994, 17.49797018473555, 18.453613206616147, 9.647572414929039, 8.671582167986637, 7.740515441987056, 6.749860500652965, 5.789620894106968, 4.759846493908865, 5.729668750625674, 6.776447787483469, 7.744224991095197, 8.669928744982778, 9.708815966313393, 10.748501515146618, 11.506550417013417, 12.538260865283638, 13.453184339833317, 14.492906898596898, 15.458440524891406, 16.474729353867655, 17.54225268316433, 18.5230676783897, 8.647496975220884, 7.722156530287702, 6.771189203727627, 5.825235231214454, 4.812921482168238, 3.8282446383183877, 4.780853040588228, 5.740037271805444, 6.712431163185533, 7.692848599228981, 8.669580293982461, 9.711086777793891, 10.57519637102137, 11.506790479278258, 12.47939348245619, 13.54479099908602, 14.49000123299948, 15.546684569642691, 16.547872054184065, 17.546618091579063, 7.695863204051365, 6.722276303452759, 5.782991109239918, 4.855386287221163, 3.8726906247168476, 2.8888750366528515, 3.8428451999817668, 4.811987063334576, 5.80694889114789, 6.7701121232595725, 7.712882891327364, 8.691873852256473, 9.640148059043936, 10.6257853337218, 11.680640799059207, 12.654465618812539, 13.642046466724231, 14.644654763941906, 15.631008523886646, 16.61756351298285, 6.776961533628217, 5.821032166605397, 4.859494885311997, 3.9088857496238005, 2.96407793988484, 1.8903936401818653, 2.8417749423223713, 3.8112661922502626, 4.809091247798146, 5.843507770414018, 6.822507021539569, 7.7485387484398975, 8.76832142159584, 9.712137126263865, 10.651922254125303, 11.651507720055603, 12.6612021906319, 13.640946889667424, 14.675812926424404, 15.61698333761764, 5.8492758999940415, 4.895907603161358, 3.885811845813886, 2.9036942388425446, 1.9670878063506825, 0.9412490618591951, 1.884102401633196, 2.910462856536143, 3.8347809865700246, 4.864427072912209, 5.870691737184977, 6.875022924362639, 7.8059441834904, 8.832210347076295, 9.784008999084518, 10.787558407182216, 11.801175270644745, 12.818120419832152, 13.769312754983357, 14.837083422748243], [15.013474346756476, 14.034718453012648, 12.996651410061862, 12.041654860545561, 10.972074055277043, 9.912579818695948, 8.958296932088016, 7.941228383012785, 6.932193154512054, 5.979784072489547, 4.936721124717616, 3.89312046054664, 2.963140775325594, 1.9526792156835946, 1.0093229950333609, 0.0, 1.051786333330363, 1.9809905062017341, 2.999458877990142, 3.9573988234482487, 15.758804939730815, 14.801511105360802, 13.845175794224941, 12.85518382298322, 11.821845478592637, 10.749007238763744, 9.736573802521953, 8.702066156756477, 7.756764934412251, 6.796199606633127, 5.863770025592, 4.930951891778739, 3.957497840927215, 2.9498705216813677, 2.0187016480889284, 1.0061033726727262, 2.0704958752939953, 3.036574715764684, 4.0489597428744375, 5.016640699748034, 16.732221295136704, 15.786493289309751, 14.782847112433682, 13.7523560548439, 12.697421103305418, 11.715763977225626, 10.692312318628158, 9.716883827401805, 8.738673557120805, 7.81400583157797, 6.890403748399568, 5.896359506421838, 4.9844165537318865, 3.9348319927417967, 2.9597807036367882, 1.9455019611079054, 2.9929163179352423, 3.9805170069969438, 4.9803601981968315, 5.964877114064961, 17.70024060273179, 16.79884316377988, 15.754537726974972, 14.694938460594527, 13.641570146338893, 12.648397014124155, 11.69150590118448, 10.765268522436084, 9.750098554548952, 8.791917494418, 7.907664365573455, 6.858506043297131, 5.963255630850813, 4.916587671082253, 3.9265686501380603, 3.0005256541707164, 3.930187412811613, 4.921675477456225, 5.84904763534681, 6.827708417169, 18.577033194606884, 17.606780172457093, 16.67108490818336, 15.642473889434756, 14.602425676090492, 13.688371998507817, 12.64402086066982, 11.714452601885704, 10.759461250091261, 9.806412104452487, 8.837230194650266, 7.811309157582484, 6.902413863290989, 5.8717449513860664, 4.938885374691475, 3.9571593542572896, 4.867683136567116, 5.8145491768225614, 6.850597376016815, 7.7813416954706796, 18.31810180142496, 17.642205948771494, 16.660181646418927, 15.83444761629828, 15.063572040172351, 14.644467004601875, 13.596934269762832, 12.64989331867772, 11.683305495909275, 10.740578547006852, 9.778171632382278, 8.843273598737632, 7.82799448543452, 6.815414881607388, 5.8663222426591295, 5.0303293483503415, 5.90043520470877, 6.750387836840747, 7.693826545660488, 8.760649771244863, 17.362929520483146, 16.654112144642763, 15.664981900048696, 14.845442462981957, 14.118832509595274, 14.75561699885641, 14.55320273069917, 13.622894862576697, 12.627856612496235, 11.666961551441295, 10.75485923977821, 9.821692476661585, 8.755778406257289, 7.810696975655758, 6.860191555909979, 5.9846553049143205, 6.884311882266157, 7.67540664172043, 8.627752092350205, 9.581745420351776, 16.378375306464445, 15.697474158875657, 14.714607356828646, 13.79880447540761, 13.16806051739502, 13.6923799387551, 14.62847054269109, 14.60683624992041, 13.593073879060833, 12.651928919621012, 11.654531987136048, 10.677758308805064, 9.70715065657174, 8.747294926327037, 7.786280966082118, 6.9524830409798195, 7.847225933359508, 8.618424172562628, 9.562531866642555, 10.571283974770525, 15.39972457256276, 14.762587104096006, 13.784563178679132, 12.813912775884406, 12.133728869822727, 12.75978107400743, 13.705442447329846, 14.675687568385474, 14.486406810026484, 13.493354990963418, 12.538226425095814, 11.602735573057307, 10.668715950659884, 9.704231821339372, 8.812155229073493, 7.972163957102208, 8.82431803836969, 9.585655700219935, 10.521223234138999, 11.555041697882533, 14.407213836052772, 13.764982446209512, 12.792567580889813, 11.858830960130643, 11.116828709942784, 11.712372351868897, 12.7333354118919, 13.68088195964059, 14.571843111301593, 14.454050491056268, 13.471428041260463, 12.626935017052086, 11.67168183031161, 10.775776314510685, 9.806376472510083, 8.92910818846955, 9.884064125501526, 10.552535936974897, 11.56144445468622, 12.546626212612155, 13.463076837692723, 12.75241157655063, 11.719773072899848, 10.886158053917349, 10.181538164057804, 10.71112778817988, 11.668901527167474, 12.636767280241434, 13.61098821789859, 14.540940717276737, 14.494333801431248, 13.634406669102285, 12.687445332411444, 11.7618746252362, 10.828198627010682, 9.905856514336293, 10.833209288620678, 11.563462728134633, 12.55335669792578, 13.473885651339252, 12.507026068512095, 11.757785802662635, 10.792056569742357, 9.83799520340792, 9.213790398845564, 9.783629335774641, 10.67287639519135, 11.687219012166885, 12.646121533346934, 13.5844827310669, 14.492968394925505, 14.623217481834573, 13.685152464293889, 12.733762106898878, 11.82409694722059, 10.899575861306301, 11.827079089533724, 12.572070761009247, 13.627708721522659, 14.433198873388294, 11.518906639054636, 10.831625605904497, 9.804628997880709, 8.856752753783695, 8.220645615478544, 8.776580815890178, 9.673014552379424, 10.632563146900162, 11.588954672884121, 12.549863954330297, 13.502410041333691, 14.437880171189303, 14.675179487297214, 13.698354517140384, 12.750834769201207, 11.96721533689112, 12.862386505863167, 13.558684733468363, 14.558242124228027, 15.460352465476431, 10.603809826245875, 9.807309833786578, 8.861139244170719, 7.881326236300858, 7.197541087023196, 7.838144137757125, 8.734863657483183, 9.677929754547897, 10.6344884366341, 11.668023292933427, 12.597874306150526, 13.624837021089267, 14.498489494204446, 14.727462600396485, 13.816912370062099, 12.970946107348514, 13.815260244600555, 14.54390540587036, 15.518961783877224, 16.50818650264417, 9.779198517622744, 8.834977211017277, 7.849037951837742, 6.921535590215066, 6.195760281037745, 6.822436106793724, 7.765473076515236, 8.738830918678717, 9.697106959104737, 10.724467721513346, 11.765831283019237, 12.785234243644757, 13.457824503806044, 14.38502541685992, 14.828228382780129, 13.934702511525979, 14.879060157013024, 15.56774849260658, 16.48864718970219, 17.444290211582786, 8.733035388230405, 7.779831640964861, 6.904721172641477, 5.994001401005233, 5.156114605929465, 5.769169488942227, 6.738991745659035, 7.78577078251683, 8.753547986128558, 9.67925174001614, 10.718138961346755, 11.75782451017998, 12.515873412046778, 13.547583860317, 14.462507334866679, 14.97166894784986, 15.893631789949104, 16.63815535529452, 17.45999024616322, 18.3895037408203, 7.689224148305764, 6.830406003265925, 5.935394934382048, 4.991352834464905, 4.117579223628321, 4.837567633351749, 5.79017603562159, 6.7493602668388055, 7.721754158218895, 8.702171594262342, 9.678903289015823, 10.720409772827253, 11.584519366054732, 12.51611347431162, 13.488716477489552, 14.554113994119382, 15.499324228032842, 16.55600756467605, 17.557195049217423, 18.555941086612425, 6.737590377136246, 5.803250756560995, 4.863965562348155, 3.936360740329399, 3.0664824512701836, 3.898198031686212, 4.852168195015128, 5.821310058367938, 6.8162718861812515, 7.779435118292934, 8.722205886360726, 9.701196847289834, 10.649471054077297, 11.63510832875516, 12.689963794092568, 13.6637886138459, 14.651369461757593, 15.653977758975268, 16.640331518920007, 17.626886508016213, 5.7676385385948565, 4.82563105868695, 3.86409377739355, 2.9134846417053537, 2.005864467023552, 2.899716635215226, 3.851097937355733, 4.820589187283624, 5.8184142428315075, 6.852830765447379, 7.831830016572931, 8.757861743473258, 9.777644416629201, 10.721460121297227, 11.661245249158664, 12.660830715088965, 13.670525185665262, 14.650269884700785, 15.685135921457766, 16.626306332651, 4.839952904960681, 3.8865846081279978, 2.876488850780525, 1.8943712438091835, 0.9577648113173216, 1.950572056892556, 2.893425396666557, 3.919785851569504, 4.844103981603385, 5.8737500679455685, 6.880014732218337, 7.884345919395999, 8.81526717852376, 9.841533342109654, 10.793331994117878, 11.796881402215575, 12.810498265678104, 13.82744341486551, 14.778635750016715, 15.846406417781601], [16.06526068008684, 15.086504786343012, 14.048437743392226, 13.093441193875925, 12.023860388607407, 10.964366152026312, 10.01008326541838, 8.993014716343149, 7.983979487842418, 7.031570405819911, 5.98850745804798, 4.944906793877004, 4.014927108655957, 3.0044655490139576, 2.061109328363724, 1.051786333330363, 0.0, 0.929204172871371, 1.947672544659779, 2.9056124901178855, 16.810591273061178, 15.853297438691165, 14.896962127555303, 13.906970156313582, 12.873631811923, 11.800793572094106, 10.788360135852315, 9.753852490086839, 8.808551267742613, 7.847985939963491, 6.915556358922363, 5.982738225109102, 5.009284174257578, 4.00165685501173, 3.0704879814192916, 2.057889706003089, 1.0366998108283523, 1.9868621549717815, 2.9971734095440743, 3.964854366417671, 17.784007628467066, 16.838279622640115, 15.834633445764045, 14.804142388174263, 13.74920743663578, 12.767550310555988, 11.74409865195852, 10.768670160732167, 9.790459890451167, 8.865792164908333, 7.942190081729931, 6.948145839752201, 6.036202887062249, 4.9866183260721595, 4.0115670369671514, 2.9972882944382686, 2.007973435471035, 2.9955741245327365, 3.9954173157326247, 4.913090780734597, 18.75202693606215, 17.850629497110244, 16.806324060305336, 15.746724793924889, 14.693356479669255, 13.700183347454518, 12.743292234514842, 11.817054855766447, 10.801884887879316, 9.843703827748364, 8.959450698903819, 7.9102923766274955, 6.922827845571775, 5.876159885803215, 4.801972905861355, 3.875929909894011, 2.9452445303474057, 3.9367325949920184, 4.864104752882604, 5.842765534704793, 18.31750767283213, 17.636566319599428, 16.700871055325695, 15.936648672035291, 15.654212009420855, 14.74015833183818, 13.695807194000182, 12.766238935216066, 11.811247583421626, 10.858198437782853, 9.88901652798063, 8.838419715516086, 7.811022085270632, 6.780353173365709, 5.81428963041477, 4.832563609980585, 3.882740254102909, 4.829606294358354, 5.865654493552606, 6.796398813006471, 17.333158918960752, 16.743147065898174, 15.761122763545607, 14.935388733424961, 15.76388336345839, 15.60200388848939, 14.554471153650347, 13.578599020897816, 12.612011198129371, 11.669284249226948, 10.706877334602375, 9.771979300957728, 8.703398741157814, 7.690819137330682, 6.741726498382424, 5.905733604073637, 4.915492322244562, 5.765444954376539, 6.70888366319628, 7.775706888780655, 16.37798663801894, 15.755053261769445, 14.765923017175377, 13.946383580108638, 14.819143832881313, 15.807403332186773, 15.510739614586685, 14.551600564796793, 13.55656231471633, 12.595667253661391, 11.630263495501502, 10.697096732384878, 9.631182661980581, 8.686101231379052, 7.7355958116332735, 6.860059560637616, 5.89936899980195, 6.6904637592562235, 7.642809209885997, 8.59680253788757, 15.393432424000238, 14.798415276002338, 13.815548473955326, 12.899745592534291, 13.868371840681059, 14.744166272085462, 15.680256876021453, 15.491730071355814, 14.477967700496238, 13.536822741056417, 12.529936242859344, 11.55316256452836, 10.582554912295036, 9.622699182050333, 8.661685221805413, 7.827887296703114, 6.8622830508953, 7.6334812900984215, 8.577588984178348, 9.586341092306318, 14.414781690098554, 13.863528221222687, 12.885504295805813, 11.914853893011086, 12.863881351249779, 13.811567407337792, 14.757228780660206, 15.727473901715834, 15.36181106574978, 14.368759246686714, 13.41363068081911, 12.478139828780604, 11.54412020638318, 10.579636077062668, 9.687559484796788, 8.792826038244385, 7.839375155905483, 8.600712817755728, 9.536280351674792, 10.570098815418326, 13.422270953588566, 12.865923563336194, 11.893508698016495, 10.959772077257323, 11.846981191369835, 12.76415868519926, 13.785121745222261, 14.732668292970951, 15.623629444631954, 15.329454746779565, 14.34683229698376, 13.502339272775382, 12.547086086034906, 11.651180570233981, 10.681780728233377, 9.749770269611727, 8.89912124303732, 9.56759305451069, 10.576501572222012, 11.561683330147948, 12.478133955228516, 11.853352693677312, 10.82071419002653, 9.98709917104403, 10.911690645484855, 11.762914121510242, 12.720687860497835, 13.688553613571795, 14.662774551228951, 15.592727050607097, 15.369738057154544, 14.509810924825581, 13.56284958813474, 12.637278880959496, 11.703602882733977, 10.72651859547847, 9.84826640615647, 10.578519845670426, 11.568413815461573, 12.488942768875045, 11.522083186047889, 10.858726919789317, 9.89299768686904, 8.9389363205346, 9.943942880272616, 10.835415669105004, 11.72466272852171, 12.739005345497246, 13.697907866677294, 14.636269064397261, 15.544754728255866, 15.498621737557869, 14.560556720017185, 13.609166362622174, 12.699501202943885, 11.72023794244848, 10.842136207069517, 11.58712787854504, 12.642765839058452, 13.448255990924087, 10.53396375659043, 9.93256672303118, 8.905570115007391, 7.957693870910377, 9.000194623265896, 9.82836714922054, 10.724800885709785, 11.684349480230523, 12.640741006214482, 13.601650287660657, 14.554196374664052, 15.489666504519663, 15.55058374302051, 14.57375877286368, 13.626239024924502, 12.787877418033299, 11.87744362339896, 12.573741851004156, 13.57329924176382, 14.475409583012224, 9.618866943781669, 8.90825095091326, 7.962080361297401, 6.982267353427539, 7.977090094810548, 8.889930471087487, 9.786649990813544, 10.729716087878257, 11.686274769964463, 12.719809626263789, 13.649660639480889, 14.676623354419629, 15.550275827534808, 15.602866856119782, 14.692316625785393, 13.791608188490692, 12.830317362136348, 13.558962523406153, 14.534018901413017, 15.52324362017996, 8.802766742523168, 7.935918328143959, 6.949979068964424, 6.022476707341747, 7.018839326574731, 7.874222440124086, 8.817259409845597, 9.790617252009078, 10.748893292435099, 11.776254054843708, 12.8176176163496, 13.83702057697512, 14.509610837136407, 15.436811750190282, 15.703632638503425, 14.755364592668156, 13.894117274548817, 14.582805610142373, 15.503704307237983, 16.45934732911858, 7.78296719889414, 6.880772758091544, 6.005662289768158, 5.094942518131915, 6.055182124677912, 6.820955822272589, 7.790778078989398, 8.837557115847194, 9.80533431945892, 10.731038073346502, 11.769925294677117, 12.809610843510342, 13.56765974537714, 14.599370193647362, 15.514293668197041, 15.792331028992038, 14.908688907484898, 15.653212472830313, 16.475047363699016, 17.404560858356092, 6.7391559589695, 5.931347120392608, 5.036336051508729, 4.092293951591587, 5.070948325175765, 5.889353966682112, 6.841962368951952, 7.801146600169168, 8.773540491549257, 9.753957927592705, 10.730689622346185, 11.772196106157615, 12.636305699385094, 13.567899807641982, 14.540502810819914, 15.605900327449744, 15.877128199376823, 16.581257257055277, 17.472592530235517, 18.38101044516673, 5.787522187799981, 4.904191873687678, 3.964906679474837, 3.0373018574560806, 4.019851552817627, 4.949984365016576, 5.903954528345491, 6.8730963916983, 7.868058219511614, 8.831221451623296, 9.773992219691088, 10.752983180620197, 11.70125738740766, 12.686894662085523, 13.74175012742293, 14.715574947176265, 15.703155795087957, 16.705764092305632, 17.69211785225037, 18.678672841346575, 4.817570349258592, 3.9265721758136314, 2.965034894520231, 2.0144257588320347, 2.9592335685709954, 3.951502968545589, 4.902884270686095, 5.8723755206139865, 6.87020057616187, 7.9046170987777415, 8.883616349903294, 9.809648076803622, 10.829430749959565, 11.773246454627591, 12.713031582489029, 13.712617048419329, 14.722311518995626, 15.70205621803115, 16.73692225478813, 17.678092665981364, 3.889884715624416, 2.974463069444993, 1.972300445024199, 0.9953123609358646, 1.9319187934277267, 3.002358390222919, 3.94521172999692, 4.971572184899866, 5.895890314933749, 6.925536401275933, 7.931801065548701, 8.936132252726363, 9.867053511854124, 10.893319675440019, 11.845118327448242, 12.84866773554594, 13.862284599008468, 14.879229748195876, 15.83042208334708, 16.898192751111967], [16.99446485295821, 16.01570895921438, 14.977641916263595, 14.022645366747295, 12.953064561478776, 11.89357032489768, 10.93928743828975, 9.922218889214518, 8.913183660713788, 7.960774578691282, 6.917711630919351, 5.874110966748375, 4.944131281527328, 3.9336697218853285, 2.9903135012350948, 1.9809905062017341, 0.929204172871371, 0.0, 1.018468371788408, 1.9764083172465143, 17.739795445932547, 16.782501611562534, 15.826166300426673, 14.836174329184951, 13.802835984794369, 12.729997744965475, 11.717564308723684, 10.68305666295821, 9.737755440613984, 8.77719011283486, 7.844760531793734, 6.911942397980473, 5.938488347128949, 4.930861027883101, 3.9996921542906625, 2.98709387887446, 1.9659039836997234, 1.0576579821004106, 2.0679692366727034, 3.0356501935463, 18.713211801338435, 17.767483795511485, 16.763837618635414, 15.733346561045634, 14.678411609507151, 13.696754483427359, 12.673302824829891, 11.697874333603538, 10.719664063322538, 9.794996337779704, 8.871394254601302, 7.877350012623572, 6.96540705993362, 5.91582249894353, 4.940771209838522, 3.9264924673096395, 2.937177608342406, 2.1251758102682397, 3.106637244620263, 3.983886607863226, 18.65653042915361, 17.86293290410568, 16.947935626124213, 16.67592896679626, 15.622560652540626, 14.629387520325889, 13.672496407386213, 12.746259028637818, 11.731089060750687, 10.772908000619735, 9.88865487177519, 8.839496549498866, 7.852032018443146, 6.805364058674586, 5.731177078732726, 4.805134082765382, 3.8744487032187767, 3.1630303427419006, 4.072129425842647, 5.0244873805843415, 17.7250947472295, 16.851941579269013, 15.91624631499528, 16.865852844906662, 16.583416182292225, 15.66936250470955, 14.625011366871552, 13.695443108087437, 12.740451756292996, 11.787402610654222, 10.818220700852, 9.767623888387458, 8.740226258142004, 7.70955734623708, 6.743493803286141, 5.761767782851956, 4.8119444269742795, 4.237193368755728, 5.085272202796093, 6.007780164230755, 16.740745993358125, 15.95852232556776, 14.976498023215193, 15.864592906296334, 16.693087536329763, 16.53120806136076, 15.483675326521716, 14.507803193769185, 13.54121537100074, 12.598488422098317, 11.636081507473744, 10.701183473829097, 9.632602914029183, 8.620023310202052, 7.670930671253795, 6.834937776945008, 5.844696495115933, 5.173032028773913, 6.048107241292516, 7.005222721908154, 15.785573712416312, 14.97042852143903, 13.981298276844962, 14.87558775298001, 15.748348005752685, 16.736607505058142, 16.439943787458056, 15.480804737668162, 14.4857664875877, 13.52487142653276, 12.559467668372873, 11.62630090525625, 10.560386834851952, 9.615305404250423, 8.664799984504644, 7.789263733508987, 6.8285731726733205, 6.098050833653597, 7.037098668088619, 7.991091996090192, 14.801019498397611, 14.013790535671923, 13.030923733624912, 13.828949765405664, 14.797576013552431, 15.67337044495683, 16.609461048892822, 16.420934244227183, 15.407171873367608, 14.466026913927786, 13.459140415730714, 12.48236673739973, 11.511759085166405, 10.551903354921702, 9.590889394676783, 8.757091469574485, 7.791487223766671, 7.0410683644957945, 7.985176058575721, 8.993928166703691, 13.822368764495927, 13.078903480892272, 12.100879555475398, 12.844058065882459, 13.793085524121151, 14.740771580209161, 15.686432953531579, 16.656678074587205, 16.29101523862115, 15.297963419558084, 14.34283485369048, 13.407344001651973, 12.47332437925455, 11.508840249934037, 10.616763657668157, 9.722030211115756, 8.768579328776854, 8.0082998921531, 8.943867426072165, 9.9776858898157, 12.800298032669028, 12.060332138394406, 11.087917273074707, 11.888976250128696, 12.776185364241208, 13.693362858070628, 14.714325918093634, 15.661872465842324, 16.552833617503325, 16.258658919650934, 15.276036469855129, 14.431543445646751, 13.476290258906275, 12.58038474310535, 11.610984901104747, 10.6789744424831, 9.82832541590869, 8.975180128908063, 9.984088646619385, 10.969270404545322, 11.856161034308979, 11.047761268735524, 10.015122765084742, 10.916303343915402, 11.840894818356228, 12.692118294381611, 13.649892033369207, 14.617757786443168, 15.591978724100324, 16.52193122347847, 16.298942230025915, 15.43901509769695, 14.49205376100611, 13.566483053830865, 12.632807055605346, 11.655722768349843, 10.777470579027842, 9.9861069200678, 10.976000889858947, 11.896529843272418, 10.900110265128351, 10.05313549484753, 9.087406261927251, 9.868140493405972, 10.873147053143988, 11.764619841976373, 12.653866901393084, 13.668209518368618, 14.627112039548667, 15.565473237268634, 16.47395890112724, 16.427825910429238, 15.489760892888555, 14.538370535493543, 13.628705375815255, 12.649442115319852, 11.771340379940888, 10.994714952942413, 12.050352913455825, 12.85584306532146, 9.905954037663072, 9.126975298089391, 8.099978690065603, 8.886898043781748, 9.929398796137267, 10.757571322091911, 11.654005058581157, 12.613553653101896, 13.569945179085854, 14.53085446053203, 15.483400547535425, 16.418870677391034, 16.47978791589188, 15.50296294573505, 14.55544319779587, 13.717081590904671, 12.806647796270331, 11.98132892540153, 12.980886316161193, 13.882996657409597, 8.853752042632712, 8.093578550741162, 7.147407961125303, 7.91147152629891, 8.90629426768192, 9.819134643958858, 10.715854163684917, 11.65892026074963, 12.615478942835832, 13.649013799135158, 14.578864812352258, 15.605827527290998, 16.47948000040618, 16.53207102899115, 15.621520798656762, 14.720812361362064, 13.759521535007718, 12.966549597803526, 13.94160597581039, 14.930830694577333, 7.899926155415107, 7.0953345291167125, 6.135306668792326, 6.951680880213118, 7.948043499446102, 8.803426612995457, 9.74646358271697, 10.71982142488045, 11.67809746530647, 12.705458227715077, 13.74682178922097, 14.76622474984649, 15.438815010007778, 16.366015923061653, 16.632836811374794, 15.68456876553953, 14.823321447420186, 13.990392684539746, 14.911291381635357, 15.86693440351595, 6.853763026022769, 6.040188959064297, 5.19098988959606, 6.024146691003286, 6.984386297549283, 7.75015999514396, 8.71998225186077, 9.766761288718566, 10.734538492330291, 11.660242246217873, 12.699129467548488, 13.738815016381713, 14.496863918248511, 15.528574366518733, 16.443497841068414, 16.72153520186341, 15.837893080356267, 15.060799547227687, 15.882634438096387, 16.812147932753465, 5.809951786098129, 5.090763321365361, 4.221663651336631, 5.0214981244629575, 6.000152498047136, 6.818558139553483, 7.771166541823324, 8.73035077304054, 9.702744664420628, 10.683162100464076, 11.659893795217556, 12.701400279028986, 13.565509872256465, 14.497103980513353, 15.469706983691285, 16.535104500321115, 16.806332372248193, 15.98884433145265, 16.880179604632886, 17.788597519564103, 4.85831801492861, 4.063608074660431, 3.150234279302739, 3.9665060303274515, 4.949055725688998, 5.879188537887947, 6.833158701216862, 7.802300564569672, 8.797262392382986, 9.760425624494667, 10.70319639256246, 11.682187353491567, 12.63046156027903, 13.616098834956894, 14.670954300294301, 15.644779120047636, 16.632359967959328, 17.05130515430994, 17.889448050600887, 18.717652098160315, 3.888366176387221, 3.0149801638141174, 2.103968355953902, 2.9436299317034056, 3.8884377414423663, 4.88070714141696, 5.832088443557467, 6.801579693485358, 7.799404749033242, 8.833821271649112, 9.812820522774665, 10.738852249674993, 11.758634922830936, 12.702450627498962, 13.6422357553604, 14.6418212212907, 15.651515691866997, 16.63126039090252, 17.6661264276595, 18.607296838852733, 2.960680542753045, 2.045258896573622, 1.043096272152828, 1.9245165338072356, 2.8611229662990976, 3.93156256309429, 4.874415902868291, 5.900776357771238, 6.82509448780512, 7.8547405741473035, 8.861005238420072, 9.865336425597734, 10.796257684725495, 11.82252384831139, 12.774322500319613, 13.77787190841731, 14.79148877187984, 15.808433921067245, 16.75962625621845, 17.827396923983336], [18.012933224746618, 17.034177331002788, 15.996110288052002, 15.041113738535701, 13.971532933267182, 12.912038696686087, 11.957755810078156, 10.940687261002925, 9.931652032502194, 8.979242950479689, 7.936180002707759, 6.892579338536782, 5.962599653315736, 4.952138093673736, 4.008781873023502, 2.9994588779901417, 1.947672544659779, 1.018468371788408, 0.0, 0.9579399454581063, 18.758263817720955, 17.800969983350942, 16.844634672215083, 15.85464270097336, 14.821304356582777, 13.748466116753884, 12.736032680512093, 11.701525034746618, 10.756223812402393, 9.795658484623269, 8.863228903582142, 7.930410769768882, 6.956956718917357, 5.949329399671509, 5.01816052607907, 4.005562250662868, 2.984372355488131, 2.0732353249381887, 1.0495008648842952, 2.017181821757892, 18.64993071961547, 18.327806304028957, 17.782305990423822, 16.75181493283404, 15.69687998129556, 14.715222855215767, 13.6917711966183, 12.716342705391947, 11.738132435110947, 10.813464709568112, 9.88986262638971, 8.895818384411982, 7.983875431722027, 6.934290870731938, 5.95923958162693, 4.944960839098047, 3.9556459801308135, 3.0880120640317426, 2.0881688728318544, 2.965418236074818, 17.681911412020384, 17.265004959195956, 17.749534250924608, 17.694397338584672, 16.641029024329036, 15.647855892114297, 14.690964779174621, 13.764727400426226, 12.749557432539095, 11.791376372408143, 10.907123243563598, 9.857964921287275, 8.870500390231552, 7.823832430462993, 6.749645450521133, 5.823602454553789, 4.892917075007184, 3.9810332119448235, 3.0536610540542384, 4.006019008795933, 16.750475730096277, 16.25401363435929, 16.717844939795675, 17.735250226938003, 17.601884554080637, 16.68783087649796, 15.64347973865996, 14.713911479875845, 13.758920128081405, 12.805870982442631, 11.836689072640409, 10.786092260175867, 9.758694629930412, 8.728025718025489, 7.761962175074548, 6.780236154640363, 5.830412798762687, 5.055196237958651, 4.066803831007684, 4.989311792442346, 15.766126976224902, 15.250566072256815, 15.778096648015588, 16.733990288327675, 17.63861122510593, 17.54967643314917, 16.502143698310125, 15.526271565557593, 14.559683742789149, 13.616956793886725, 12.654549879262152, 11.719651845617506, 10.651071285817592, 9.63849168199046, 8.689399043042203, 7.8534061487334155, 6.863164866904341, 5.973077578323848, 5.029638869504107, 5.986754350119746, 14.81095469528309, 14.191375333452427, 14.782896901645357, 15.757622652244475, 16.693871694528852, 17.699089511927465, 17.458412159246464, 16.49927310945657, 15.504234859376108, 14.543339798321169, 13.577936040161282, 12.644769277044658, 11.57885520664036, 10.633773776038831, 9.683268356293052, 8.807732105297394, 7.847041544461728, 6.898096383203532, 6.018630296300211, 6.972623624301783, 13.82640048126439, 13.23473734768532, 13.832522358425306, 14.77447345418183, 15.743099702328598, 16.672722876740814, 17.608813480676805, 17.43940261601559, 16.425640245156018, 15.484495285716195, 14.477608787519122, 13.500835109188138, 12.530227456954814, 11.57037172671011, 10.609357766465191, 9.775559841362892, 8.80995559555508, 7.84111391404573, 7.0261708363415085, 7.990693508990386, 12.847749747362705, 12.264058077694294, 12.902478180275793, 13.789581754658625, 14.738609212897318, 15.740124011993144, 16.69758166550704, 17.66782678656267, 17.309483610409558, 16.316431791346492, 15.361303225478888, 14.425812373440381, 13.491792751042958, 12.527308621722446, 11.635232029456565, 10.731091977253094, 9.777641094914191, 8.808345441703036, 7.9848622038379515, 9.002005743625537, 11.781829660880621, 11.201013772098534, 11.889515897875102, 12.834499938904862, 13.721709053017374, 14.692715289854611, 15.725474630069096, 16.673021177817787, 17.563982329478787, 17.277127291439342, 16.294504841643537, 15.45001181743516, 14.494758630694683, 13.598853114893759, 12.629453272893155, 11.688036208620435, 10.728159499689884, 9.775225678457998, 9.047377620044086, 9.9946513874121, 10.837692662520572, 10.188442902439652, 10.816721389885137, 11.861827032691568, 12.786418507132394, 13.691470726165594, 14.66104074534467, 15.62890649841863, 16.603127436075784, 17.533079935453934, 17.317410601814323, 16.45748346948536, 15.510522132794518, 14.584951425619273, 13.651275427393754, 12.664784534487179, 11.677304662809036, 10.786152469617734, 10.044206319186122, 10.921910826139197, 9.881641893339944, 9.114577712528824, 9.889004886727646, 10.813664182182139, 11.818670741920155, 12.763972273760356, 13.665015613368546, 14.67935823034408, 15.638260751524129, 16.576621949244096, 17.4851076131027, 17.446294282217647, 16.508229264676963, 15.556838907281952, 14.646737145029805, 13.60308898197839, 12.671174463722082, 11.794760502492348, 11.118558342783, 11.881224048188239, 8.887485665874665, 8.188417515770686, 8.901577314865998, 9.832421732557915, 10.874922484913434, 11.756923753875894, 12.66515377055662, 13.624702365077358, 14.581093891061316, 15.542003172507492, 16.494549259510887, 17.430019389366496, 17.498256287680288, 16.521431317523458, 15.573474967010421, 14.664500753290255, 13.706481880051525, 12.781374474951464, 12.166851852090678, 12.908377640276376, 7.835283670844305, 7.131758158427326, 7.949006585925698, 8.856995215075077, 9.851817956458087, 10.81848707574284, 11.727002875660379, 12.670068972725092, 13.62768989787483, 14.661224754174157, 15.591075767391256, 16.618038482329997, 17.49794837219459, 17.5397879449498, 16.56958584963188, 15.625018170987797, 14.659355618788911, 13.766595147353462, 13.127571511739877, 13.956211677444111, 6.881457783626701, 6.076866157328304, 6.936905293592721, 7.897204568989285, 8.893567188222269, 9.80277904477944, 10.757612294692432, 11.730970136855913, 12.690308420345467, 13.717669182754076, 14.765290161009379, 15.784693121634898, 16.457283381796188, 17.38448429485006, 17.545280115437226, 16.588774575165264, 15.72315553120138, 14.790438234089681, 14.097256917564843, 14.892315386382728, 5.835294654234362, 5.0217205872758885, 5.992588514396456, 6.969670379779453, 7.92990998632545, 8.749512426927943, 9.732193206899765, 10.778972243757561, 11.746749447369288, 12.67245320125687, 13.717597839336896, 14.757283388170121, 15.51533229003692, 16.54704273830714, 17.461966212856822, 17.625741011489147, 16.73772716413746, 15.860845096777622, 15.068599974025874, 15.837528915620243, 4.791483414309721, 4.0722949495769525, 5.023262276137027, 5.967021813239125, 6.945822153966072, 7.817910571337466, 8.78337749686232, 9.742561728079536, 10.714955619459625, 11.695373055503072, 12.678362167005965, 13.719868650817395, 14.583978244044873, 15.515572352301762, 16.488175355479694, 17.553572872109523, 17.706166456029386, 16.788889881002586, 16.066145140562373, 16.81397850243088, 3.839849643140202, 3.0451397028720226, 3.984424897084863, 4.912029719103619, 5.894725381607934, 6.8785409696719295, 7.845369656255858, 8.814511519608669, 9.815730764171395, 10.778893996283076, 11.721664764350868, 12.700655725279976, 13.648929932067439, 14.634567206745302, 15.68942267208271, 16.663247491836046, 17.650828339747736, 17.851350703859875, 17.075413586530374, 17.743033081027093, 2.869897804598813, 1.9965117920257094, 2.95804907331911, 3.908658209007306, 4.853466018746267, 5.899175513205368, 6.8505568153458745, 7.820048065273766, 8.81787312082165, 9.852289643437521, 10.831288894563073, 11.757320621463402, 12.777103294619344, 13.72091899928737, 14.660704127148808, 15.660289593079108, 16.669984063655406, 17.649728762690927, 18.030609183992613, 18.807566218324997, 1.942212170964637, 1.026790524785214, 2.036886282132687, 2.9429849055956434, 3.8795913380875056, 4.950030934882697, 5.892884274656699, 6.9192447295596455, 7.843562859593527, 8.873208945935712, 9.87947361020848, 10.883804797386142, 11.814726056513903, 12.840992220099798, 13.792790872108021, 14.796340280205719, 15.809957143668248, 16.826902292855653, 17.77809462800686, 18.845865295771745], [18.970873170204726, 17.992117276460895, 16.95405023351011, 15.99905368399381, 14.92947287872529, 13.869978642144195, 12.915695755536264, 11.898627206461033, 10.889591977960302, 9.937182895937797, 8.894119948165866, 7.850519283994889, 6.920539598773843, 5.910078039131843, 4.966721818481609, 3.9573988234482487, 2.9056124901178855, 1.9764083172465143, 0.9579399454581063, 0.0, 18.700341905413158, 18.758909928809047, 17.802574617673187, 16.812582646431466, 15.779244302040885, 14.706406062211991, 13.6939726259702, 12.659464980204724, 11.714163757860499, 10.753598430081375, 9.821168849040248, 8.888350715226988, 7.914896664375464, 6.907269345129616, 5.976100471537177, 4.963502196120975, 3.942312300946238, 3.031175270396295, 2.0074408103424015, 1.0592418762997855, 17.694560118196513, 18.640288124023463, 18.74024593588193, 17.70975487829215, 16.654819926753667, 15.673162800673873, 14.649711142076406, 13.674282650850053, 12.696072380569053, 11.771404655026217, 10.847802571847815, 9.853758329870088, 8.941815377180134, 7.892230816190045, 6.917179527085037, 5.902900784556154, 4.9135859255889205, 4.004469824195509, 3.0046266329956204, 2.0074782906167115, 16.726540810601428, 17.69562414575254, 18.524921193320203, 18.65233728404278, 17.598968969787144, 16.605795837572405, 15.648904724632727, 14.722667345884332, 13.7074973779972, 12.749316317866247, 11.865063189021704, 10.815904866745381, 9.82844033568966, 8.7817723759211, 7.70758539597924, 6.7815424000118965, 5.850857020465291, 4.8974909721085895, 3.9701188142180044, 3.048079063337827, 15.79510512867732, 16.76535815082711, 17.49323188219127, 18.510637169333602, 18.559824499538745, 17.645770821956066, 16.601419684118067, 15.671851425333951, 14.71686007353951, 13.763810927900735, 12.794629018098515, 11.744032205633971, 10.716634575388518, 9.685965663483595, 8.719902120532655, 7.73817610009847, 6.788352744220794, 5.971653998122417, 4.962116166438106, 4.03137184698424, 14.810756374805944, 15.822625259631343, 16.553483590411183, 17.509377230723274, 18.4161926029126, 18.507616378607278, 17.460083643768233, 16.4842115110157, 15.517623688247255, 14.574896739344831, 13.612489824720258, 12.677591791075612, 11.609011231275698, 10.596431627448567, 9.647338988500309, 8.811346094191522, 7.821104812362448, 6.86838991375427, 5.924951204934529, 5.02881440466164, 13.855584093864133, 14.763434520826955, 15.558283844040952, 16.53300959464007, 17.47145307233552, 18.476670889734134, 18.416352104704572, 17.457213054914675, 16.462174804834213, 15.501279743779275, 14.535875985619388, 13.602709222502764, 12.536795152098467, 11.591713721496937, 10.641208301751158, 9.765672050755501, 8.804981489919836, 7.793408718633954, 6.913942631730633, 6.017253022882826, 12.871029879845432, 13.806796535059847, 14.607909300820902, 15.5520548319885, 16.520681080135265, 17.4611204830961, 18.39721108703209, 18.397342561473696, 17.383580190614122, 16.4424352311743, 15.435548732977228, 14.458775054646244, 13.48816740241292, 12.528311672168217, 11.567297711923297, 10.733499786821, 9.738762953284507, 8.736426249476152, 7.92148317177193, 7.0353229075714285, 11.892379145943748, 12.836117265068822, 13.677865122671388, 14.567163132465295, 15.516190590703989, 16.52852161834843, 17.5050288253271, 18.47527394638273, 18.267423555867666, 17.2743717368046, 16.319243170936996, 15.38375231889849, 14.449732696501066, 13.485248567180552, 12.585616139910384, 11.626404312683515, 10.672953430344613, 9.703657777133458, 8.880174539268374, 8.04663514220658, 10.823889715422514, 11.77307295947306, 12.664902840270697, 13.612081316711532, 14.499290430824045, 15.484704863340431, 16.532921789889155, 17.480468337637845, 18.374339224887468, 18.23506723689745, 17.252444787101645, 16.40795176289327, 15.452698576152791, 14.556793060351865, 13.571528640945791, 12.583348544050857, 11.623471835120306, 10.67053801388842, 9.942689955474508, 9.039280785993142, 9.879752717062464, 10.89988597344918, 11.592108332280732, 12.639408410498238, 13.563999884939065, 14.4976038638364, 15.468487905164729, 16.436353658238687, 17.413484331484465, 18.343436830862615, 18.27535054727243, 17.41542341494347, 16.45954911335943, 15.493784820375442, 14.554412455183916, 13.5600968699176, 12.572616998239457, 11.681464805048156, 10.939518654616544, 9.966540224720239, 8.923701947881836, 9.826020783538352, 10.664391829123241, 11.59124555998881, 12.596252119726826, 13.570105411431161, 14.475372508777227, 15.489715125752761, 16.44861764693281, 17.386978844652777, 18.29546450851138, 18.404234227675754, 17.457256245241876, 16.465672302038122, 15.542049480460227, 14.498401317408812, 13.566486799152504, 12.69007283792277, 11.852381025280652, 10.925853446769281, 7.929545720416557, 8.899860586780214, 9.676964257261593, 10.610003110364586, 11.652503862720105, 12.5630568915467, 13.4755106659653, 14.435059260486039, 15.391450786469997, 16.352360067916173, 17.304906154919568, 18.240376284775177, 18.4472832682452, 17.43026471227963, 16.468787302440845, 15.559813088720677, 14.601794215481947, 13.676686810381886, 12.88520471344908, 11.953007038857418, 6.877343725386197, 7.907145100822921, 8.724393528321293, 9.634576592881748, 10.629399334264757, 11.624620213413646, 12.53735977106906, 13.480425868133773, 14.438046793283508, 15.471581649582834, 16.401432662799934, 17.428395377738674, 18.38365808273399, 18.435100280380222, 17.464898185062303, 16.52033050641822, 15.554667954219333, 14.661907482783883, 13.845924373098278, 13.000841076025154, 5.923517838168593, 6.8522530997238995, 7.712292235988317, 8.674785946795957, 9.67114856602894, 10.613135940188121, 11.567969190101113, 12.541327032264594, 13.500665315754146, 14.528026078162753, 15.578141657866228, 16.597544618491746, 17.34299309233559, 18.270194005389463, 18.440592450867648, 17.484086910595686, 16.618467866631804, 15.685750569520103, 14.815609778923244, 13.93694478496377, 4.877354708776254, 5.797107529671484, 6.767975456792051, 7.747251757586124, 8.707491364132121, 9.559869322336624, 10.542550102308445, 11.589329139166239, 12.557106342777967, 13.482810096665549, 14.530449336193746, 15.57013488502697, 16.40104200057632, 17.432752448846543, 18.347675923396228, 18.52105334691957, 17.633039499567882, 16.75615743220804, 15.786952835384275, 14.882158314201284, 3.833543468851614, 4.847681891972548, 5.798649218532622, 6.744603191045796, 7.756179049374752, 8.628267466746147, 9.593734392271, 10.552918623488216, 11.525312514868304, 12.505729950911752, 13.564071877545366, 14.605578361356796, 15.469687954584275, 16.401282062841165, 17.3738850660191, 18.43928258264893, 18.601478791459808, 17.684202216433007, 16.784498001920774, 15.858607901011922, 2.8819096976820955, 3.8554965982807023, 4.794781792493543, 5.722386614512299, 6.705082277016614, 7.68889786508061, 8.655726551664538, 9.624868415017346, 10.64065178098522, 11.664603706822477, 12.60737447489027, 13.586365435819378, 14.534639642606841, 15.520276917284704, 16.57513238262211, 17.60918320929213, 18.604114413951404, 18.746663039290297, 17.77421746870434, 16.787662479608134, 1.9119578591407065, 2.907361789579709, 3.8688990708731095, 4.819508206561306, 5.764316016300267, 6.838000316003241, 7.803842889549539, 8.77333413947743, 9.771159195025314, 10.805575717641185, 11.784574968766737, 12.710606695667066, 13.730389368823008, 14.674205073491034, 15.613990201352472, 16.613575667282774, 17.623270137859073, 18.603014836894594, 18.72941306616658, 17.852195616906037, 0.9842722255065306, 1.937640522339214, 2.9477362796866866, 3.90092485105375, 4.837531283545612, 5.907970880340804, 6.850824220114806, 7.8771846750177525, 8.801502805051634, 9.831148891393818, 10.837413555666586, 11.841744742844249, 12.77266600197201, 13.798932165557904, 14.750730817566128, 15.754280225663825, 16.767897089126354, 17.78484223831376, 18.736034573464966, 18.913842480127727], [1.0716857573530227, 1.9001641680483217, 2.938231210999107, 3.87610230588988, 4.945683111158399, 5.98362684453712, 6.937909731145052, 7.954978280220285, 8.930493444296323, 9.882902526318828, 10.92596547409076, 11.865684479184173, 12.795664164405219, 13.806125724047218, 14.749481944697452, 15.758804939730814, 16.810591273061178, 17.73979544593255, 18.75826381772096, 18.70034190541316, 0.0, 0.9572938343700128, 1.9136291455058738, 2.903621116747596, 3.9369594611381777, 5.009797700967072, 6.022231137208862, 7.056738782974337, 8.002040005318563, 8.962605333097686, 9.895034914138813, 10.827853047952074, 11.880591726790078, 12.927366533523065, 13.973895439986265, 14.986493715402467, 16.050886218023738, 17.016965058494428, 18.040699518548323, 17.641100029113375, 1.005781787216646, 1.9515097930435972, 2.955155969919667, 3.9314427734298865, 4.906747716358469, 5.888404842438261, 6.911856501035728, 7.887284992262082, 8.871512075329775, 9.869437566106303, 10.803805875557185, 11.793260662595173, 12.830383967042096, 13.879968528032185, 14.873085881301254, 15.887364623830138, 16.934778980657473, 17.922379669719174, 17.567543634000263, 16.692863614796448, 1.9738010948117304, 2.9428844299628416, 3.9650813577868664, 4.9460615966368415, 5.968320870641479, 6.886781397537125, 7.843672510476801, 8.872706886115571, 9.91099957271096, 10.847349228946333, 11.82927488471544, 12.755407199470467, 13.804223351749572, 14.850891311518131, 15.925078291459991, 16.851121287427336, 17.781806666973942, 17.467301181223437, 16.60205145277788, 15.65226284207533, 2.9052367767358374, 3.875489798885627, 4.811185063159359, 5.839796081907964, 6.898949595362098, 7.926756381920788, 8.810609618856954, 9.74017787764107, 10.750844354981929, 11.80379374053507, 12.758840713792251, 13.708210313755819, 14.735607944001273, 15.766276855906197, 16.732340398857136, 17.71406641929132, 17.340004195465053, 16.39313815520961, 15.588908675824431, 14.668970058428918, 3.889585530607214, 4.878937360988102, 5.750933354939446, 6.706826995251535, 7.7285146240402245, 8.753401657140042, 9.763523027949967, 10.739395160702498, 11.705982983470943, 12.648709932373366, 13.61111684699794, 14.546014880642586, 15.6145954404425, 16.62717504426963, 17.57626768321789, 17.45670763521819, 16.457724263723144, 15.457299495191425, 14.626073637328007, 13.671527500751518, 4.844757811549026, 5.884392019466812, 6.746133101309677, 7.69583214856786, 8.673254154617302, 9.678471972015915, 10.603559923520613, 11.570418524386396, 12.56545677446686, 13.57509293680781, 14.607327349341055, 15.54049411245768, 16.5612019844836, 17.50628341508513, 17.426048526856707, 16.502381678654213, 15.531333441126923, 14.53228069031174, 13.637082210531904, 12.683088882530333, 5.829312025567726, 6.841030005233919, 7.696507644529727, 8.658942940559257, 9.624026146817556, 10.607325376839176, 11.543415980775167, 12.519499969962277, 13.533262340821853, 14.474407300261674, 15.481293798458747, 16.45806747678973, 17.428675129023055, 17.399969033788906, 16.49995911668457, 15.534553942588714, 14.568419390033572, 13.589263159469542, 12.646216594446557, 11.66501899784173, 6.807962759469411, 7.811709275224945, 8.62655182267924, 9.597202225473968, 10.634986413396026, 11.539924241586846, 12.554554079457557, 13.524799200513185, 14.511790140651454, 15.41442994643919, 16.369558512306792, 17.3050493643453, 17.35057600168667, 16.44303213877657, 15.474084853693194, 14.514873026466326, 13.59132728502339, 12.622031631812236, 11.687525226950113, 10.653706763206579, 7.8769274569896, 8.826110701040147, 9.63951410507993, 10.55228404122773, 11.600967138181261, 12.586381570697647, 13.526661114895502, 14.529276292455764, 15.495086995035999, 16.43715269857605, 17.30276012847144, 17.34381744158968, 16.347610122034943, 15.371487645605258, 14.489596826993386, 13.557928795098984, 12.58976442709109, 11.655151395057274, 10.646242877345951, 9.661061119420015, 8.82106445534965, 9.838681570699029, 10.712308613069895, 11.524956947441025, 12.536257684066241, 13.470393633244177, 14.441277674572506, 15.409143427646466, 16.405652203019205, 17.425219825638163, 17.284821841288032, 16.336345789539482, 15.35115362786373, 14.385389334879743, 13.467774672492787, 12.581180469232242, 11.640619263971939, 10.691249435132606, 9.775368060752125, 8.733801680692919, 9.777115224530277, 10.742760201748458, 11.640025116227386, 12.573119797950454, 13.50400544927848, 14.397892085649415, 15.43730280654863, 16.38221798471288, 17.348027457009938, 17.461901089647277, 16.426961320717208, 15.46161353785651, 14.486478570574928, 13.413501853217065, 12.471876352282878, 11.587461122262233, 10.655546604005925, 9.682641402257993, 8.701016037155247, 7.774488458643877, 10.771271451995556, 11.668920398506597, 12.627452688089035, 13.554362247574678, 14.4971502326455, 15.404940605533877, 16.379134918500306, 17.338683513021046, 17.38819159435685, 16.427282312910673, 15.47473622590728, 14.53926609605167, 13.59499895863756, 12.570878534906011, 11.545138530302262, 10.596102805195057, 9.638083931956327, 8.696027429798876, 7.6964700390392125, 6.779089634861469, 11.823473447025917, 12.725579755849957, 13.580023417029334, 14.529788765057516, 15.520254761100848, 16.34337728366693, 17.317285813396545, 17.50446262121627, 16.512068973447498, 15.540958909693325, 14.611107896476225, 13.670188806297624, 12.67704400745439, 11.6551094828416, 10.68490738752368, 9.740339708879596, 8.77467715668071, 7.75942479755805, 6.735750379390015, 5.731255597693733, 12.777299334243521, 13.780471756948979, 14.592124709362311, 15.489579411143307, 16.48594203037629, 17.35908531463033, 17.581194808786687, 16.607836966623207, 15.574687495918134, 14.732043967433352, 13.667862882324151, 12.631801621102536, 11.636379017055988, 10.822398860271235, 9.764954940005824, 8.808449399733862, 7.800090736791194, 6.835828687173983, 5.853785442439404, 4.795151888755115, 13.82346246363586, 14.799452710578262, 15.536441488558577, 16.41711360035314, 17.377353206899137, 17.533688982575494, 16.569810354093413, 15.623987259767588, 14.631128522941955, 13.68607923116901, 12.679282188709914, 11.63959663987669, 10.694427925296722, 9.825468989264557, 8.866371837677383, 7.867575093456674, 6.84909121425542, 5.821798486918242, 4.882442385978372, 3.8499383595176013, 14.8672737035605, 15.748878348277197, 16.505767726818007, 17.419762166893467, 17.586763970834866, 16.602087126985015, 15.620994644055965, 14.661810412838749, 13.68941652145866, 12.708999085415213, 11.71198813769891, 10.73283164945594, 9.763073879304676, 8.865183983478188, 7.892580980300256, 6.827183463670426, 5.881973229756966, 4.893753702693277, 3.8925662181519045, 2.873488772706963, 15.818907474730018, 16.776033594982128, 17.5771970988519, 17.62922877588779, 16.646533113383473, 15.662717525319477, 14.695888838735549, 13.72674697538274, 12.710963609414867, 11.687011683577609, 10.755290735043813, 9.776299774114705, 8.828025567327241, 7.963665483610806, 6.989416106517419, 5.955365279847401, 4.923557186606497, 3.9442565002689483, 2.8832977721839046, 1.944434194110752, 16.78885931327141, 17.82466150582844, 17.69708397750013, 16.746474841811935, 15.801667032072974, 14.727982732369998, 13.7621401588237, 12.792648908895808, 11.794823853347925, 10.760407330732054, 9.781408079606502, 8.855376352706173, 7.83559367955023, 6.891777974882204, 5.951992847020766, 4.952407381090465, 3.942712910514167, 2.9629682114786444, 1.9281021747216638, 0.9869317635284285, 17.716544946905586, 18.669913243738268, 18.635293790511334, 17.653176183539994, 16.716569751048134, 15.677127310692669, 14.719812699512875, 13.757909005320386, 12.808079144118064, 11.800883191531613, 10.794618527258844, 9.790287340081182, 8.859366080953421, 7.833099917367527, 6.881301265359303, 5.877751857261606, 4.864134993799077, 3.8641094223284345, 2.9129170871772296, 2.0470606376933476], [1.921626227422138, 0.9428703336783089, 1.9809373766290945, 2.9188084715198674, 3.9883892767883857, 5.026333010167107, 5.980615896775039, 6.997684445850272, 7.97319960992631, 8.925608691948815, 9.968671639720746, 10.90839064481416, 11.838370330035206, 12.848831889677205, 13.792188110327439, 14.8015111053608, 15.853297438691163, 16.782501611562534, 17.800969983350942, 18.75890992880905, 0.9572938343700128, 0.0, 0.956335311135861, 1.9463272823775832, 2.979665626768165, 4.052503866597059, 5.064937302838849, 6.099444948604324, 7.0447461709485495, 8.005311498727673, 8.9377410797688, 9.87055921358206, 10.923297892420065, 11.970072699153052, 13.016601605616252, 14.029199881032454, 15.093592383653723, 16.05967122412441, 17.083405684178306, 18.150134677541633, 1.9508017453145894, 1.0050737394876383, 2.0087199163637077, 2.974148939059874, 3.949453881988456, 4.931111008068249, 5.954562666665716, 6.929991157892069, 7.914218240959762, 8.91214373173629, 9.846512041187172, 10.83596682822516, 11.873090132672083, 12.922674693662172, 13.91579204693124, 14.930070789460125, 15.977485146287462, 16.965085835349164, 17.96492902654905, 17.637883572894392, 2.918821052909674, 2.0678750843206415, 3.0186453042309074, 3.9887677622668285, 5.011027036271466, 5.929487563167113, 6.886378676106789, 7.915413051745559, 8.953705738340947, 9.89005539457632, 10.871981050345427, 11.798113365100454, 12.846929517379559, 13.893597477148118, 14.967784457089978, 15.893827453057323, 16.82451283260393, 17.816000897248543, 17.547071410875823, 16.597282800173275, 3.850256734833781, 3.0788664091573095, 4.014561673431041, 4.936303191107058, 5.971882566023066, 6.969462547550775, 7.853315784486943, 8.782884043271059, 9.793550520611918, 10.846499906165059, 11.801546879422238, 12.750916479385806, 13.77831410963126, 14.808983021536184, 15.775046564487123, 16.756772584921308, 17.762008556359433, 17.338158113307554, 16.533928633922375, 15.613990016526863, 4.834605488705158, 4.082313971259785, 4.954309965211128, 5.910203605523217, 6.9112887570901185, 7.936175790189937, 8.806229193579956, 9.782101326332487, 10.748689149100931, 11.691416098003355, 12.653823012627928, 13.588721046272575, 14.657301606072489, 15.66988120989962, 16.618973848847876, 17.5822439239203, 17.402744221821088, 16.40231945328937, 15.571093595425952, 14.616547458849462, 5.789777769646969, 5.141504710064172, 5.949509711581359, 6.899208758839542, 7.856028287667196, 8.86124610506581, 9.762497654516293, 10.729356255382076, 11.69324026568789, 12.617799102437798, 13.650033514971044, 14.583200278087668, 15.603908150113586, 16.548989580715116, 17.509224475599005, 17.447401636752158, 16.476353399224866, 15.477300648409685, 14.582102168629849, 13.628108840628277, 6.77433198366567, 6.098142695831279, 6.899884254801409, 7.862319550830939, 8.806800279867451, 9.790099509889071, 10.726190113825062, 11.702274103012172, 12.69874686944817, 13.602766470617516, 14.609652968814588, 15.522534493277847, 16.49314214551117, 17.452997875755877, 17.444979074782513, 16.47957390068666, 15.513439348131516, 14.534283117567487, 13.591236552544501, 12.610038955939673, 7.752982717567354, 7.068821965822305, 7.829928432950923, 8.80057883574565, 9.838363023667709, 10.72269837463674, 11.737328212507451, 12.70757333356308, 13.69456427370135, 14.542789116795031, 15.497917682662635, 16.433408534701144, 17.367428157098566, 17.388052096874514, 16.419104811791136, 15.45989298456427, 14.536347243121334, 13.56705158991018, 12.632545185048057, 11.598726721304523, 8.821947415087545, 8.131866271418065, 8.842890715351615, 9.755660651499413, 10.804343748452943, 11.770107096775273, 12.709435247945397, 13.712050425505659, 14.677861128085894, 15.570994904988956, 16.431119298827284, 17.457607978695922, 17.292630080132888, 16.3165076037032, 15.43461678509133, 14.502948753196929, 13.534784385189035, 12.600171353155218, 11.591262835443896, 10.60608107751796, 9.766084413447594, 9.144437141076947, 9.91568522334158, 10.728333557712707, 11.739634294337923, 12.67377024351586, 13.644654284844188, 14.612520037918149, 15.609028813290887, 16.559062032051067, 17.45402505899807, 17.281365747637427, 16.296173585961675, 15.330409292977688, 14.412794630590732, 13.526200427330187, 12.585639222069883, 11.63626939323055, 10.72038801885007, 9.678821638790863, 10.722135182628222, 10.218302330987775, 10.84340172649907, 11.776496408222137, 12.707382059550163, 13.601268695921098, 14.640679416820312, 15.585594594984563, 16.55140406728162, 17.515520018260904, 17.371981278815152, 16.406633495954452, 15.431498528672872, 14.35852181131501, 13.416896310380823, 12.532481080360178, 11.60056656210387, 10.627661360355937, 9.646035995253191, 8.71950841674182, 11.7162914100935, 11.144462527745914, 11.830829298360719, 12.75773885784636, 13.700526842917183, 14.60831721580556, 15.582511528771988, 16.54206012329273, 17.498451649276685, 17.372302271008618, 16.419756184005223, 15.484286054149614, 14.540018916735505, 13.515898493003956, 12.490158488400207, 11.541122763293002, 10.583103890054272, 9.64104738789682, 8.641489997137157, 7.724109592959413, 12.768493405123861, 12.201121885089274, 12.783400027301019, 13.733165375329198, 14.72363137137253, 15.546753893938613, 16.520662423668227, 17.53198642667406, 17.456305712478656, 16.485195648724485, 15.555344635507383, 14.614425545328782, 13.62128074648555, 12.600129440939545, 11.629927345621624, 10.685359666977538, 9.719697114778652, 8.704444755655993, 7.680770337487958, 6.676275555791676, 13.722319292341465, 13.256013886188295, 13.795501319633996, 14.69295602141499, 15.689318640647972, 16.562461924902014, 17.490053004636174, 17.552073705654365, 16.518924234949292, 15.67628070646451, 14.61209962135531, 13.576038360133694, 12.580615756087148, 11.767418818369178, 10.709974898103766, 9.753469357831804, 8.745110694889137, 7.780848645271925, 6.798805400537347, 5.740171846853059, 14.768482421733804, 14.311159456240711, 14.739818098830261, 15.620490210624823, 16.58072981717082, 17.610504217368923, 17.514047093124567, 16.568223998798747, 15.575365261973113, 14.630315970200169, 13.623518927741076, 12.583833378907851, 11.638664664327882, 10.782762823634569, 9.823665672047394, 8.824868927826685, 7.806385048625431, 6.779092321288254, 5.827462344076316, 4.794958317615545, 15.812293661658444, 15.260585093939646, 15.70914433708969, 16.62313877716515, 17.619265199471965, 17.54632386601617, 16.565231383087124, 15.606047151869907, 14.633653260489819, 13.653235824446371, 12.65622487673007, 11.6770683884871, 10.707310618335836, 9.822477817848199, 8.849874814670267, 7.7844772980404375, 6.839267064126978, 5.851047537063289, 4.849860052521917, 3.8185087308049064, 16.763927432827963, 16.287740340644575, 16.780573709123583, 17.678130871300656, 17.59076985241463, 16.606954264350634, 15.640125577766707, 14.670983714413898, 13.655200348446025, 12.631248422608767, 11.699527474074973, 10.720536513145865, 9.772262306358401, 8.907902222641965, 7.94670994088743, 6.912659114217413, 5.880851020976509, 4.901550334638961, 3.8405916065539176, 2.889454152208695, 17.733879271369354, 17.33636825149089, 17.82683963247242, 17.690711580843093, 16.745903771104132, 15.672219471401156, 14.706376897854858, 13.736885647926966, 12.739060592379083, 11.704644069763212, 10.72564481863766, 9.799613091737331, 8.779830418581389, 7.836014713913364, 6.896229586051926, 5.909701215460477, 4.9000067448841795, 3.9202620458486575, 2.885396009091677, 1.9442255978984413, 18.66156490500353, 18.306089518731383, 17.677999956141328, 16.695882349169985, 15.759275916678122, 14.733437172186633, 13.789578070660168, 12.836976628042473, 11.859374165870905, 10.8435893571616, 9.837324692888831, 8.832993505711169, 7.902072246583408, 6.875806082997514, 5.924007430989291, 4.9204580228915935, 3.9068411594290646, 2.9068155879584214, 1.9556232528072168, 2.897001107762463], [2.877961538557999, 1.8992056448141699, 1.0401656526807757, 1.9624731603840062, 3.0320539656525245, 4.069997699031246, 5.024280585639178, 6.041349134714411, 7.016864298790448, 7.969273380812955, 9.012336328584885, 9.952055333678299, 10.882035018899344, 11.892496578541344, 12.835852799191578, 13.84517579422494, 14.896962127555302, 15.826166300426673, 16.84463467221508, 17.802574617673187, 1.9136291455058738, 0.956335311135861, 0.0, 0.9899919712417221, 2.023330315632304, 3.0961685554611975, 4.1086019917029875, 5.143109637468463, 6.088410859812688, 7.048976187591812, 7.981405768632939, 8.9142239024462, 9.966962581284204, 11.01373738801719, 12.06026629448039, 13.072864569896593, 14.137257072517862, 15.10333591298855, 16.127070373042443, 17.19379936640577, 2.9071370564504506, 1.9614090506234994, 1.0663159247686531, 2.0178136279240126, 2.993118570852595, 3.974775696932387, 4.998227355529854, 5.973655846756208, 6.957882929823901, 7.9558084206004285, 8.890176730051309, 9.8796315170893, 10.916754821536221, 11.96633938252631, 12.95945673579538, 13.973735478324262, 15.021149835151599, 16.0087505242133, 17.008593715413188, 18.005742057792098, 3.875156364045535, 3.0242103954565023, 2.0762413126358528, 3.0324324511309673, 4.054691725135605, 4.973152252031252, 5.930043364970928, 6.959077740609698, 7.9973704272050865, 8.933720083440459, 9.915645739209564, 10.841778053964592, 11.890594206243698, 12.937262166012257, 14.011449145954117, 14.93749214192146, 15.868177521468064, 16.859665586112676, 17.78703774400326, 17.553618111309135, 4.8065920459696425, 4.03520172029317, 3.107930623764786, 3.9799678799711966, 5.015547254887204, 6.013127236414914, 6.896980473351082, 7.826548732135198, 8.837215209476057, 9.890164595029198, 10.845211568286375, 11.794581168249945, 12.821978798495397, 13.852647710400321, 14.81871125335126, 15.800437273785446, 16.805673245223566, 16.848593421970698, 17.490263945058235, 16.570325327662722, 5.790940799841019, 5.029703217897441, 4.047678915544873, 4.981227818581527, 5.954953445954257, 6.979840479054076, 7.849893882444094, 8.825766015196626, 9.79235383796507, 10.735080786867494, 11.697487701492067, 12.632385735136713, 13.700966294936627, 14.713545898763758, 15.662638537712017, 16.62590861278444, 16.87237280270301, 15.912754761952513, 16.527428906561813, 15.572882769985323, 6.7461130807828305, 6.042643652692219, 5.042878661915104, 5.970232971897851, 6.899692976531335, 7.904910793929948, 8.806162343380432, 9.773020944246214, 10.73690495455203, 11.661463791301937, 12.693698203835183, 13.626864966951807, 14.647572838977725, 15.592654269579254, 16.552889164463146, 16.79256399252634, 15.88849612514562, 14.987735957072829, 15.53843747976571, 14.584444151764139, 7.730667294801531, 6.976120007182166, 5.993253205135154, 6.955688501164684, 7.850464968731589, 8.83376419875321, 9.769854802689201, 10.745938791876311, 11.742411558312309, 12.646431159481654, 13.653317657678727, 14.566199182141986, 15.53680683437531, 16.496662564620014, 16.782029903013633, 15.82473625646084, 14.925582074052269, 14.04471842623063, 14.547571863680362, 13.566374267075535, 8.709318028703215, 7.901321308701542, 6.923297383284668, 7.893947786079395, 8.88479661630388, 9.76636306350088, 10.78099290137159, 11.751238022427218, 12.738228962565488, 13.58645380565917, 14.541582371526774, 15.47707322356528, 16.411092845962703, 16.71536970836885, 15.756155640022257, 14.805055340338452, 13.948489969042086, 13.077486898573325, 13.588880496183918, 12.555062032440384, 9.778282726223406, 8.950506811265143, 7.936259665685359, 8.84902960183316, 9.89771269878669, 10.813771785639412, 11.753099936809535, 12.755715114369798, 13.721525816950033, 14.614659593853094, 15.474783987691422, 16.50127266756006, 16.619947691627225, 15.64382521519754, 14.761934396585668, 13.84811110897111, 12.88874388191025, 12.110606661818363, 12.547598146579757, 11.562416388653821, 10.722419724583455, 9.963077680924025, 9.009054173675324, 9.821702508046453, 10.83300324467167, 11.767139193849605, 12.738023235177934, 13.705888988251894, 14.682380710353035, 15.602726720915205, 16.497689747862207, 16.525130809341555, 15.623491197456012, 14.657726904472025, 13.740112242085068, 12.871362783104368, 11.939598718791098, 11.099679870658626, 11.676723329985931, 10.635156949926724, 11.678470493764083, 10.924629159850022, 9.936770676832815, 10.86986535855588, 11.800751009883909, 12.694637646254844, 13.734048367154058, 14.67896354531831, 15.644773017615366, 16.55918470712504, 16.50166777946997, 15.536319996609269, 14.646000985095506, 13.685839422809346, 12.74421392187516, 11.87764343613436, 10.945728917878052, 10.091071837784012, 10.602371306389053, 9.675843727877682, 12.672626721229362, 11.85078935660816, 10.924198248694463, 11.851107808180105, 12.793895793250929, 13.701686166139307, 14.675880479105736, 15.635429073626474, 16.591820599610433, 16.488257316365296, 15.535711229361901, 14.60024109950629, 13.655973962092181, 12.809740774736992, 11.817476099894543, 10.868440374787339, 9.910421501548608, 9.104457865324896, 9.597825308273016, 8.680444904095273, 13.724828716259722, 12.822939567250621, 11.876768977634763, 12.826534325662942, 13.817000321706276, 14.64012284427236, 15.614031374001977, 16.62535537700781, 16.499970401342797, 15.528860337588624, 14.599009324371524, 13.658090234192922, 12.664945435349688, 11.780632691480891, 10.81043059616297, 9.865862917518884, 8.95754776281122, 8.119237192922899, 8.63710564862382, 7.632610866927537, 14.678654603477327, 13.877831568349643, 12.88887026996774, 13.786324971748734, 14.782687590981716, 15.655830875235761, 16.583421954969925, 16.595738394518506, 15.562588923813433, 14.71994539532865, 13.65576431021945, 12.619703048997835, 11.624280444951287, 10.894326431663123, 9.836882511397711, 8.902106513341419, 7.893747850398752, 7.0953941061866805, 7.755140711673208, 6.69650715798892, 15.724817732869665, 14.842253598043417, 13.833187049164005, 14.713859160958567, 15.674098767504564, 16.703873167702668, 16.557711781988708, 15.611888687662887, 14.619029950837254, 13.67398065906431, 12.667183616605213, 11.627498067771988, 10.68232935319202, 9.854232685078337, 8.895135533491162, 7.8963387892704535, 6.879176217462672, 6.024987243498741, 6.783797655212177, 5.751293628751406, 16.767619037104442, 15.753480613983507, 14.802513287423434, 15.716507727498895, 16.71263414980571, 16.589988554880314, 15.608896071951264, 14.649711840734048, 13.67731794935396, 12.696900513310512, 11.699889565594209, 10.72073307735124, 9.750975307199974, 8.893947679291967, 7.921344676114035, 6.855947159484206, 5.910736925570746, 5.096942459273776, 5.806195363657779, 4.774844041940767, 17.71925280827396, 16.780635860688438, 15.873942659457326, 16.7714998216344, 16.63443454127877, 15.650618953214776, 14.683790266630847, 13.714648403278039, 12.698865037310165, 11.674913111472907, 10.743192162939112, 9.764201202010003, 8.81592699522254, 7.951566911506105, 6.997686874142342, 5.963636047472325, 4.952320882420278, 4.034481636416484, 4.796926917689779, 3.8457894633445564, 18.15000049461014, 17.82926377153475, 16.92020858280616, 16.734376269707234, 15.789568459968272, 14.715884160265297, 13.750041586718998, 12.780550336791107, 11.782725281243223, 10.748308758627353, 9.7693095075018, 8.843277780601472, 7.823495107445528, 6.879679402777502, 5.939894274916065, 4.960678148715389, 3.971476606327948, 3.030773762142002, 3.841731320227538, 2.9005609090343025, 18.68512869918562, 17.731760402352936, 16.721664645005465, 15.739547038034123, 14.802940605542261, 13.777101861050774, 12.833242759524307, 11.880641316906612, 10.903038854735044, 9.887254046025738, 8.88098938175297, 7.876658194575308, 6.945736935447547, 5.919470771861652, 4.96767211985343, 3.9641227117557323, 2.9505058482932034, 1.9795677121133501, 2.911958563943078, 3.8533364188983237], [3.867953509799721, 2.889197616055892, 1.9274777386585837, 0.9724811891422841, 2.0420619944108025, 3.0800057277895245, 4.034288614397457, 5.051357163472689, 6.026872327548727, 6.979281409571233, 8.022344357343163, 8.962063362436577, 9.892043047657623, 10.902504607299623, 11.845860827949856, 12.855183822983218, 13.90697015631358, 14.836174329184951, 15.85464270097336, 16.812582646431466, 2.903621116747596, 1.9463272823775832, 0.9899919712417221, 0.0, 1.033338344390582, 2.1061765842194755, 3.118610020461266, 4.153117666226741, 5.098418888570967, 6.05898421635009, 6.991413797391218, 7.924231931204479, 8.976970610042484, 10.023745416775471, 11.070274323238671, 12.082872598654873, 13.147265101276142, 14.11334394174683, 15.137078401800723, 16.20380739516405, 3.8971290276921726, 2.9514010218652214, 2.056307896010375, 1.0278216566822906, 2.003126599610873, 2.984783725690665, 4.008235384288132, 4.983663875514486, 5.9678909585821796, 6.965816449358707, 7.900184758809588, 8.889639545847578, 9.9267628502945, 10.97634741128459, 11.969464764553658, 12.98374350708254, 14.031157863909877, 15.01875855297158, 16.018601744171466, 17.015750086550376, 4.865148335287257, 4.014202366698225, 3.0662332838775748, 2.0424404798892453, 3.0646997538938834, 3.983160280789529, 4.940051393729205, 5.969085769367975, 7.007378455963364, 7.9437281121987375, 8.925653767967844, 9.851786082722871, 10.900602235001976, 11.947270194770535, 13.021457174712395, 13.947500170679739, 14.878185550226343, 15.869673614870955, 16.79704577276154, 17.775706554583728, 5.796584017211364, 4.954282191751811, 4.018586927478079, 2.989975908729474, 4.025555283645483, 5.023135265173192, 5.9069885021093596, 6.836556760893475, 7.847223238234333, 8.900172623787475, 9.855219597044655, 10.804589197008223, 11.831986827253676, 12.8626557391586, 13.828719282109539, 14.810445302543725, 15.815681273981847, 16.762547314237292, 17.798595513431543, 17.560317298904444, 6.780932771082741, 5.929153790004461, 4.947129487651893, 3.991235847339804, 4.964961474712536, 5.989848507812354, 6.859901911202371, 7.8357740439549035, 8.802361866723349, 9.745088815625772, 10.707495730250345, 11.642393763894992, 12.710974323694906, 13.723553927522037, 14.672646566470295, 15.63591664154272, 15.882380831461287, 16.653833832034564, 17.517420877803538, 16.562874741227045, 7.736105052024552, 6.94209422479924, 5.942329234022124, 4.980241000656129, 5.909701005289613, 6.914918822688226, 7.816170372138709, 8.783028973004491, 9.746912983310308, 10.671471820060216, 11.703706232593461, 12.636872995710085, 13.657580867736003, 14.602662298337533, 15.562897193221424, 15.802572021284616, 14.898504153903898, 15.72881502715488, 16.528429451007433, 15.57443612300586, 8.720659266043253, 7.875570579289186, 6.892703777242175, 6.026878988230476, 6.860472997489867, 7.843772227511488, 8.77986283144748, 9.75594682063459, 10.752419587070587, 11.656439188239933, 12.663325686437005, 13.576207210900264, 14.546814863133589, 15.506670593378292, 15.79203793177191, 14.834744285219118, 13.935590102810547, 14.785797496312682, 15.537563834922084, 14.556366238317256, 9.699309999944937, 8.800771880808563, 7.822747955391688, 7.011770687753682, 7.894804645062159, 8.776371092259158, 9.791000930129869, 10.761246051185497, 11.748236991323767, 12.596461834417449, 13.551590400285052, 14.48708125232356, 15.421100874720983, 15.72537773712713, 14.766163668780536, 13.81506336909673, 12.958497997800364, 13.818565968655376, 14.57887246742564, 13.545054003682106, 10.768274697465127, 9.849957383372164, 8.83571023779238, 7.966852503507445, 8.911704804942103, 9.82377981439769, 10.763107965567814, 11.765723143128076, 12.731533845708311, 13.624667622611373, 14.4847920164497, 15.511280696318337, 15.629955720385503, 14.653833243955818, 13.771942425343946, 12.858119137729389, 11.898751910668528, 12.851685731900414, 13.537590117821479, 12.552408359895542, 11.712411695825176, 10.862528253031046, 9.908504745782345, 8.939525409720739, 9.846995350827083, 10.781131300005018, 11.752015341333347, 12.719881094407308, 13.692388739111314, 14.612734749673484, 15.507697776620486, 15.535138838099835, 14.63349922621429, 13.667734933230303, 12.750120270843347, 11.881370811862647, 10.949606747549376, 11.857708037798067, 12.666715301227653, 11.625148921168446, 12.668462465005804, 11.824079731957044, 10.836221248939836, 9.987688260230168, 10.814743116039322, 11.708629752410257, 12.748040473309471, 13.692955651473723, 14.65725542366297, 15.56919273588332, 15.511675808228246, 14.546328025367547, 13.656009013853785, 12.695847451567625, 11.754221950633438, 10.887651464892638, 9.95573694663633, 10.849100004923454, 11.592363277630774, 10.665835699119404, 13.662618692471083, 12.750239928715182, 11.823648820801484, 10.968930709854392, 11.807887899406342, 12.71567827229472, 13.68987258526115, 14.649421179781887, 15.605812705765846, 15.498265345123574, 14.54571925812018, 13.610249128264568, 12.66598199085046, 11.819748803495267, 10.827484128652822, 9.878448403545617, 8.920429530306887, 9.862486032464338, 10.587817279514741, 9.670436875336996, 14.714820687501444, 13.722390139357643, 12.776219549741784, 11.94435722733723, 12.83099242786169, 13.654114950427774, 14.62802348015739, 15.639347483163224, 15.509978430101071, 14.538868366346902, 13.609017353129802, 12.668098262951201, 11.674953464107967, 10.790640720239166, 9.820438624921245, 8.87587094627716, 7.967555791569499, 8.89186101551046, 9.627097619865543, 8.62260283816926, 15.668646574719048, 14.777282140456665, 13.78832084207476, 12.904147873423021, 13.83277323384714, 14.669822981391174, 15.597414061125336, 15.605746423276782, 14.57259695257171, 13.72995342408693, 12.665772338977728, 11.629711077756113, 10.634288473709566, 9.904334460421401, 8.84689054015599, 7.912114542099696, 6.903755879157029, 7.868017928774241, 8.74513268291493, 7.686499129230643, 16.714809704111385, 15.741704170150438, 14.732637621271026, 13.831682062632854, 14.791921669178851, 15.723089599242671, 15.567719810746986, 14.621896716421164, 13.62903797959553, 12.683988687822586, 11.677191645363491, 10.637506096530267, 9.6923373819503, 8.864240713836615, 7.905143562249441, 6.906346818028732, 5.88918424622095, 6.905473075197199, 7.773789626453899, 6.7412855999931285, 17.667069609211463, 16.65293118609053, 15.701963859530455, 14.834330629173182, 15.830457051479994, 15.59999658363859, 14.61890410070954, 13.659719869492324, 12.687325978112236, 11.706908542068788, 10.709897594352485, 9.730741106109518, 8.760983335958253, 7.903955708050246, 6.931352704872314, 5.865955188242484, 4.920744954329024, 5.9774282909722345, 6.796187334899501, 5.76483601318249, 18.04251956649345, 17.68008643279546, 16.77339323156435, 15.88932272330869, 15.64444257003705, 14.660626981973055, 13.693798295389126, 12.724656432036316, 11.708873066068442, 10.684921140231184, 9.753200191697388, 8.77420923076828, 7.825935023980818, 6.9615749402643825, 6.007694902900621, 4.9736440762306025, 3.962328911178555, 4.921793722394293, 5.786918888931501, 4.835781434586279, 17.16000852336842, 17.656530715447104, 16.694993434153705, 15.744384298465508, 14.799576488726547, 13.725892189023574, 12.760049615477275, 11.790558365549384, 10.7927333100015, 9.75831678738563, 8.779317536260077, 7.853285809359749, 6.833503136203806, 5.88968743153578, 4.949902303674342, 3.9706861774736666, 2.9814846350862254, 3.91808584811981, 4.83172329146926, 3.890552880276024, 17.695136727943897, 16.741768431111215, 15.731672673763743, 14.749555066792402, 13.81294863430054, 12.787109889809052, 11.843250788282585, 10.89064934566489, 9.913046883493323, 8.897262074784017, 7.890997410511249, 6.886666223333586, 5.9557449642058256, 4.929478800619931, 3.9776801486117073, 2.97413074051401, 1.960513877051481, 2.8668797980911584, 3.8180721332423633, 4.843328390140046], [4.901291854190303, 3.9225359604464742, 2.960816083049166, 2.005819533532866, 1.0231252994006954, 2.0466673833989426, 3.000950270006874, 4.018018819082107, 4.9935339831581445, 5.945943065180651, 6.989006012952581, 7.928725018045995, 8.85870470326704, 9.86916626290904, 10.812522483559274, 11.821845478592635, 12.873631811922998, 13.802835984794369, 14.821304356582777, 15.779244302040883, 3.936959461138178, 2.979665626768165, 2.023330315632304, 1.033338344390582, 0.0, 1.0728382398288936, 2.0852716760706835, 3.119779321836159, 4.065080544180384, 5.025645871959508, 5.958075453000635, 6.890893586813896, 7.943632265651901, 8.990407072384889, 10.036935978848089, 11.049534254264291, 12.11392675688556, 13.080005597356248, 14.10374005741014, 15.170469050773466, 4.930467372082755, 3.9847393662558037, 3.0552142643485545, 2.0247232067587735, 0.9697882552202909, 1.9514453813000832, 2.9748970398975505, 3.950325531123904, 4.934552614191597, 5.9324781049681246, 6.866846414419006, 7.856301201456995, 8.893424505903917, 9.943009066894007, 10.936126420163076, 11.950405162691958, 12.997819519519295, 13.985420208580997, 14.985263399780886, 15.982411742159794, 5.8984866796778395, 5.047540711088807, 4.065139652215754, 3.039342029965728, 2.0313614095033015, 2.9498219363989473, 3.9067130493386233, 4.935747424977394, 5.974040111572783, 6.910389767808155, 7.892315423577261, 8.818447738332289, 9.867263890611394, 10.913931850379953, 11.988118830321813, 12.914161826289156, 13.84484720583576, 14.836335270480372, 15.763707428370958, 16.74236821019315, 6.829922361601946, 5.951183741828294, 5.0154884775545625, 3.9868774588059575, 2.9922169392549014, 3.9897969207826094, 4.873650157718777, 5.803218416502893, 6.813884893843751, 7.866834279396892, 8.821881252654071, 9.77125085261764, 10.798648482863094, 11.829317394768017, 12.795380937718956, 13.777106958153142, 14.782342929591264, 15.72920896984671, 16.76525716904096, 17.696001488494826, 7.814271115473323, 6.891228701775302, 5.909204399422734, 4.953310759110645, 3.9316231303219547, 4.956510163421773, 5.826563566811789, 6.802435699564321, 7.769023522332765, 8.711750471235188, 9.674157385859761, 10.609055419504408, 11.677635979304322, 12.690215583131453, 13.63930822207971, 14.602578297152135, 15.606462805406245, 16.606887573937964, 17.550326282757705, 17.51310820965597, 8.769443396415134, 7.840250722948851, 6.840485732171736, 5.8657599815726185, 4.876362660899032, 5.881580478297645, 6.782832027748126, 7.74969062861391, 8.713574638919724, 9.638133475669632, 10.670367888202877, 11.603534651319501, 12.62424252334542, 13.569323953946949, 14.52955884883084, 14.993298280806455, 15.888862441573002, 16.719173314823983, 17.47866291943636, 16.524669591434787, 9.753997610433835, 8.741062999322594, 7.758196197275583, 6.795760901246053, 5.827134653099286, 6.810433883120907, 7.746524487056899, 8.722608476244009, 9.719081242680003, 10.623100843849349, 11.629987342046421, 12.54286886650968, 13.513476518743005, 14.473332248987708, 14.92432777705595, 14.025470544740957, 14.92594839047965, 15.776155783981785, 16.509315016866335, 15.506599706746185, 10.73264834433552, 9.66626430084197, 8.688240375425096, 7.780652600769259, 6.8614663006715775, 7.743032747868575, 8.757662585739288, 9.727907706794916, 10.714898646933186, 11.563123490026864, 12.518252055894468, 13.453742907932975, 14.387762530330399, 14.857667582411171, 13.898453514064576, 13.005789628618569, 13.948856285469468, 14.80892425632448, 15.550623649369891, 14.516805185626357, 11.664633047456118, 10.715449803405571, 9.701202657825787, 8.735734416523023, 7.878366460551521, 8.790441470007108, 9.729769621177233, 10.732384798737495, 11.69819550131773, 12.591329278220789, 13.451453672059117, 14.477942351927753, 14.670720536417925, 13.786123089239858, 12.904232270627986, 12.048845397251227, 12.889110198337631, 13.842044019569517, 14.570928462212061, 13.585746704286125, 12.608770045816167, 11.728020673064453, 10.773997165815752, 9.708407322736317, 8.813657006436502, 9.747792955614438, 10.718676996942767, 11.686542750016727, 12.659050394720733, 13.5793964052829, 14.474359432229901, 14.536379726681695, 13.65495703431809, 12.800024778514343, 11.882410116127387, 11.072097071384485, 11.93996503521848, 12.84806632546717, 13.700053645618235, 12.658487265559028, 13.564820814996795, 12.68957215199045, 11.701713668973243, 10.756570173245745, 9.781404771648742, 10.675291408019676, 11.71470212891889, 12.659617307083142, 13.62391707927239, 14.535854391492736, 14.512916696810105, 13.547568913949407, 12.657249902435645, 11.828137296851665, 10.886511795917478, 10.078377724414477, 10.946095234305433, 11.839458292592557, 12.625701622021356, 11.699174043509986, 14.558977042462073, 13.615732348748589, 12.685688866966983, 11.737812622869969, 10.774549555015762, 11.682339927904138, 12.656534240870567, 13.616082835391305, 14.572474361375264, 14.499506233705434, 13.54696014670204, 12.611490016846428, 11.66722287943232, 10.950885335590373, 9.959773973936862, 9.010738248829657, 9.91078781797599, 10.85284432013344, 11.621155623905324, 10.703775219727579, 15.611179037492434, 14.584430185523141, 13.638259595907282, 12.713239140352806, 11.797654083471109, 12.620776606037191, 13.594685135766808, 14.606009138772642, 14.511219318682933, 13.54010925492876, 12.61025824171166, 11.669339151533059, 10.676194352689826, 9.921777252334271, 8.95157515701635, 8.007007478372264, 8.957914079238604, 9.882219303179564, 10.660435964256125, 9.655941182559843, 16.56500492471004, 15.639322186622163, 14.65036088824026, 13.673029786438597, 12.79943488945656, 13.636484637000592, 14.564075716734754, 14.606987311858642, 13.57383784115357, 12.731194312668787, 11.667013227559586, 10.630951966337971, 9.635529362291425, 9.004272280263585, 7.9468283599981735, 7.0432510741947985, 7.894114166826134, 8.858376216443345, 9.778471027305512, 8.719837473621226, 17.57973446325834, 16.60374421631594, 15.594677667436525, 14.60056397564843, 13.839080564564838, 14.689751254852089, 14.568960699328846, 13.623137605003024, 12.63027886817739, 11.685229576404446, 10.678432533945353, 9.638746985112128, 8.693578270532159, 7.9641785336788, 7.005081382091625, 6.006284637870916, 6.879542533890055, 7.895831362866304, 8.807127970844482, 7.774623944383711, 17.77727839167524, 17.500133841262006, 16.54916651470193, 15.603212542188759, 14.877615946865982, 14.601237472220449, 13.6201449892914, 12.660960758074184, 11.688566866694096, 10.708149430650648, 9.711138482934345, 8.731981994691376, 7.762224224540112, 7.00389352789243, 6.031290524714498, 4.965893008084668, 5.911103241998129, 6.9677865786413395, 7.829525679290083, 6.798174357573072, 17.009181222102868, 17.49526913735482, 16.55598394314198, 15.628379121123224, 14.645683458618908, 13.661867870554913, 12.695039183970984, 11.725897320618175, 10.710113954650302, 9.686162028813044, 8.754441080279248, 7.77545011935014, 6.827175912562677, 5.962815828846242, 5.008935791482481, 3.9748849648124622, 4.962465812724154, 5.955132066784875, 6.820257233322083, 5.869119778976861, 16.126670178977836, 16.633554650164672, 15.672017368871273, 14.721408233183077, 13.776600423444116, 12.70291612374114, 11.761290504059135, 10.791799254131243, 9.79397419858336, 8.75955767596749, 7.780558424841937, 6.854526697941608, 5.834744024785666, 4.89092832011764, 3.951143192256202, 2.9719270660555264, 3.981621536631824, 4.951424192510393, 5.865061635859842, 4.9238912246666064, 16.661798383553318, 15.708430086720634, 14.69833432937316, 13.71621672240182, 12.779610289909957, 11.75377154541847, 10.809912443892003, 9.857311001274308, 8.87970853910274, 7.8985029633658765, 6.892238299093108, 5.887907111915446, 4.956985852787685, 3.93071968920179, 2.978921037193567, 1.9753716290958696, 2.9889884925583985, 3.900218142481741, 4.851410477632946, 5.876666734530628], [5.974130094019197, 4.995374200275368, 4.03365432287806, 3.0786577733617597, 2.033323380151144, 0.9738291435700489, 1.9281120301779806, 2.9451805792532126, 3.9206957433292513, 4.873104825351757, 5.9161677731236875, 6.855886778217101, 7.785866463438148, 8.796328023080147, 9.73968424373038, 10.749007238763742, 11.800793572094104, 12.729997744965475, 13.748466116753884, 14.70640606221199, 5.009797700967072, 4.052503866597059, 3.0961685554611975, 2.1061765842194755, 1.0728382398288936, 0.0, 1.0124334362417902, 2.0469410820072653, 2.992242304351491, 3.952807632130615, 4.885237213171742, 5.818055346985003, 6.870794025823008, 7.917568832555995, 8.964097739019195, 9.976696014435397, 11.041088517056666, 12.007167357527354, 13.030901817581247, 14.097630810944572, 6.003305611911649, 5.057577606084697, 4.0651009451870905, 3.03460988759731, 1.979674936058827, 0.9980178099790348, 2.007571995679955, 2.9830004869063083, 3.9672275699740016, 4.965153060750529, 5.89952137020141, 6.783462961628102, 7.820586266075023, 8.870170827065113, 9.863288180334182, 10.877566922863064, 11.924981279690401, 12.912581968752104, 13.912425159951992, 14.9095735023309, 6.971324919506733, 6.119331769859198, 5.07502633305429, 4.04293581154827, 2.9895674972926365, 1.996394365077899, 2.953285478017575, 3.982319853656345, 5.01875309815968, 5.94306472359056, 6.924990379359666, 7.745609498503395, 8.7944256507825, 9.84109361055106, 10.91528059049292, 11.841323586460263, 12.772008966006867, 13.763497030651479, 14.690869188542065, 15.669529970364255, 7.90276060143084, 6.954777523410836, 6.019082259137105, 4.9904712403885, 3.950423027044236, 3.0363693494615616, 3.9202225863977294, 4.849790845181845, 5.860457322522703, 6.913406708075844, 7.854556208436476, 8.698412612788747, 9.7258102430342, 10.756479154939123, 11.722542697890063, 12.704268718324249, 13.70950468976237, 14.656370730017816, 15.692418929212069, 16.623163248665936, 8.863275119928517, 7.8494347895646355, 6.867410487212068, 5.911516846899978, 4.889829218111289, 4.025446325849775, 4.873135995490741, 5.849008128243273, 6.8155959510117174, 7.75832289991414, 8.720729814538712, 9.655627848183359, 10.674810060832382, 11.687389664659513, 12.636482303607771, 13.599752378680195, 14.603636886934304, 15.592209390036002, 16.53564809885574, 17.602471324440117, 9.818447400870328, 8.798456810738186, 7.79869181996107, 6.823966069361953, 5.834568748688366, 4.9702754895686105, 5.829404456427079, 6.796263057292862, 7.760147067598676, 8.684705904348583, 9.716940316881828, 10.650107079998453, 11.62141660487348, 12.566498035475009, 13.5267329303589, 14.491947473460948, 15.521588109111065, 16.517228194915685, 17.46957364554546, 17.482875679224126, 10.733471829970327, 9.69926908711193, 8.716402285064918, 7.753966989035388, 6.78534074088862, 6.033512549669923, 6.83193084625421, 7.80801483544132, 8.765653671358956, 9.6696732725283, 10.676559770725373, 11.589441295188632, 12.560048947421956, 13.51990467766666, 14.015724676765029, 14.91250227088514, 15.823364342111837, 16.677943461458515, 17.467521104655667, 16.464805794535522, 11.697183813492213, 10.624470388631305, 9.646446463214431, 8.738858688558594, 7.819672388460912, 6.9661114144175915, 7.843068944936599, 8.813314065992227, 9.800305006130497, 10.609695918705816, 11.56482448457342, 12.500315336611926, 13.43433495900935, 13.94906448212025, 12.989850413773654, 13.892821354762752, 14.846272237101655, 15.710711933801209, 16.508829737159225, 15.475011273415692, 12.622839135245453, 11.673655891194906, 10.659408745615123, 9.693940504312357, 8.836572548340856, 8.013520136556124, 8.815175980374544, 9.817791157934806, 10.783601860515041, 11.63790170689974, 12.498026100738068, 13.524514780606705, 13.649185412953093, 12.877519988948936, 11.995629170337065, 12.93587712339541, 13.79089787581436, 14.743831697046247, 15.535463931368755, 14.550282173442818, 13.566976133605502, 12.686226760853788, 11.732203253605087, 10.66661341052565, 9.771863094225836, 9.014764700245141, 9.87960986509897, 10.84747561817293, 11.744456753918044, 12.625968833961851, 13.520931860908853, 13.514844603216863, 12.633421910853258, 11.891421678223422, 10.973807015836465, 11.959128797528667, 12.84175271269521, 13.7498540029439, 14.664589114774929, 13.623022734715722, 14.52302690278613, 13.647778239779786, 12.659919756762578, 11.71477626103508, 10.739610859438075, 9.94226315265038, 10.875634997075094, 11.820550175239346, 12.709323438469701, 13.582426820171687, 13.491381573345274, 12.526033790484576, 11.635714778970813, 10.919534196560743, 9.977908695626557, 10.965409450558658, 11.847882911782163, 12.741245970069286, 13.59023709117805, 12.66370951266668, 15.517183130251409, 14.573938436537924, 13.643894954756318, 12.696018710659304, 11.732755642805095, 10.949311672534844, 11.87549683988702, 12.835045434407759, 13.766490298932514, 13.477971110240603, 12.525425023237208, 11.589954893381597, 10.645687755967488, 9.984403451359071, 9.05117087364594, 9.897769974973839, 10.81257549545272, 11.75463199761017, 12.693993863734217, 11.776613459556472, 16.56938512528177, 15.542636273312477, 14.596465683696618, 13.671445228142142, 12.755860171260442, 11.887748350667897, 12.813647734783261, 13.824971737789095, 13.4896841952181, 12.51857413146393, 11.58872311824683, 10.64780402806823, 9.654659229224995, 8.95529536810297, 7.985093272785049, 8.894039204516446, 9.859701756715332, 10.83948577184571, 11.733274204085019, 10.728779422388737, 17.523211012499374, 16.5975282744115, 15.608566976029595, 14.631235874227933, 13.757640977245893, 12.903456381631297, 13.783038315751208, 13.585452188393809, 12.552302717688736, 11.709659189203958, 10.645478104094757, 9.609416842873141, 8.613994238826594, 8.031221180332428, 6.973777260067018, 7.93028280033898, 8.85138063549228, 9.815642685109491, 10.79768592984407, 9.79267571345012, 17.64834681450012, 17.561950304105274, 16.55288375522586, 15.558770063437766, 14.797286652354172, 13.956722999482794, 13.547425575864013, 12.60160248153819, 11.608743744712557, 10.663694452939612, 9.65689741048052, 8.617211861647295, 7.672043147067327, 6.991127433747645, 6.032030282160469, 6.963551106537062, 7.836809002556199, 8.853097831532448, 9.879966210673375, 8.847462184212604, 16.704440151846345, 17.461840774018082, 16.510873447458007, 15.564919474944835, 14.55260572589862, 13.567928882048768, 12.598609865826567, 11.639425634609351, 10.667031743229263, 9.686614307185815, 8.689603359469514, 7.710446871226544, 6.74068910107528, 6.006827750176722, 5.058239424783342, 5.923159476750814, 6.868369710664274, 7.925053047307484, 8.902363919118976, 7.871012597401966, 15.936342982273974, 16.46196054718314, 15.5226753529703, 14.595070530951544, 13.612374868447228, 12.628559280383232, 11.67350406050615, 10.704362197153342, 9.688578831185469, 8.66462690534821, 7.732905956814417, 6.753914995885308, 5.805640789097846, 4.941280705381411, 3.9902001770919124, 4.932151433478608, 5.919732281390299, 6.922340578607974, 7.893095473150977, 6.941958018805755, 15.05383193914894, 15.56071641033578, 14.59917912904238, 13.648569993354183, 12.703762183615222, 11.630077883912247, 10.694746744752285, 9.749732857869994, 8.772439075118529, 7.738022552502657, 6.7590233013771055, 5.832991574476777, 4.813208901320834, 3.8693931966528083, 2.929608068791371, 3.929193534721672, 4.93888800529797, 5.918632704333492, 6.937899875688736, 5.9967294644955, 15.588960143724425, 14.63559184689174, 13.625496089544267, 12.643378482572926, 11.706772050081064, 10.680933305589576, 9.73707420406311, 8.784472761445416, 7.806870299273847, 6.853562410976995, 5.847297746704227, 4.842966559526564, 3.912045300398804, 2.9091845657369584, 1.9573859137287355, 2.9609353218264327, 3.9745521852889616, 4.973056382310634, 5.92424871746184, 6.949504974359521], [6.986563530260987, 6.007807636517158, 5.046087759119849, 4.091091209603549, 3.0457568163929345, 1.986262579811839, 1.042466018526681, 2.0595345676019132, 2.9082623070874614, 3.8606713891099673, 4.903734336881898, 5.843453341975312, 6.773433027196359, 7.783894586838358, 8.727250807488591, 9.736573802521953, 10.788360135852315, 11.717564308723686, 12.736032680512094, 13.6939726259702, 6.022231137208862, 5.064937302838849, 4.1086019917029875, 3.1186100204612655, 2.0852716760706835, 1.0124334362417902, 0.0, 1.0345076457654754, 1.9798088681097012, 2.940374195888825, 3.872803776929952, 4.805621910743213, 5.858360589581218, 6.905135396314205, 7.951664302777405, 8.964262578193607, 10.028655080814875, 10.994733921285563, 12.018468381339456, 13.085197374702782, 7.0157390481534385, 6.070011042326487, 5.077534381428881, 4.0470433238391, 2.992108372300617, 2.010451246220825, 0.9951385594381645, 1.9705670506645179, 2.9547941337322112, 3.952719624508738, 4.887087933959619, 5.771029525386312, 6.808152829833233, 7.857737390823322, 8.850854744092391, 9.865133486621275, 10.912547843448612, 11.900148532510315, 12.899991723710203, 13.897140066089111, 7.983758355748523, 7.101669404589887, 6.05736396778498, 4.9977647014045345, 3.9443963871489007, 2.951223254934163, 1.9943321419944868, 3.0189517456987978, 4.006319661917889, 4.930631287348769, 5.912556943117875, 6.733176062261606, 7.781992214540712, 8.828660174309272, 9.902847154251132, 10.828890150218477, 11.759575529765081, 12.751063594409693, 13.67843575230028, 14.65709653412247, 8.87985943541689, 7.909606413267101, 6.973911148993369, 5.945300130244764, 4.9052519169005, 3.991198239317825, 2.9612692503746407, 3.890837509158756, 4.901503986499614, 5.9451258973832575, 6.842122772194685, 7.685979176546958, 8.713376806792411, 9.744045718697334, 10.710109261648274, 11.69183528208246, 12.697071253520585, 13.64393729377603, 14.679985492970284, 15.610729812424148, 9.818104009784781, 8.804263679420899, 7.822239377068332, 6.866345736756243, 5.844658107967553, 4.961715394306696, 3.9141826594676523, 4.890054792220185, 5.856642614988629, 6.799369563891052, 7.761776478515624, 8.696674512160271, 9.662376624590593, 10.674956228417724, 11.624048867365982, 12.587318942438406, 13.591203450692515, 14.579775953794217, 15.523214662613958, 16.59003788819833, 10.773276290726592, 9.753285700594452, 8.753520709817336, 7.778794959218217, 6.789397638544631, 5.7955390719086886, 4.87045112040399, 5.837309721269773, 6.801193731575587, 7.725752568325495, 8.75798698085874, 9.691153743975365, 10.60898316863169, 11.55406459923322, 12.514299494117111, 13.47951403721916, 14.509154672869276, 15.504794758673901, 16.457140209303674, 17.411133537305247, 11.68830071982659, 10.654097976968192, 9.67123117492118, 8.708795878891651, 7.740169630744885, 6.809068114167113, 5.872977510231121, 6.849061499418231, 7.806700335335868, 8.710719936505212, 9.717606434702285, 10.630487959165544, 11.589187002111881, 12.549042732356584, 13.44038890428925, 14.447341773284657, 15.472068723962627, 16.447812289516097, 17.391919983596026, 17.419634684391784, 12.652012703348475, 11.579299278487568, 10.601275353070694, 9.693687578414856, 8.753998006559224, 7.741666978914782, 6.88411560891351, 7.854360729969138, 8.841351670107407, 9.650742582682728, 10.605871148550332, 11.541362000588839, 12.475381622986262, 13.367991303768061, 14.002283850015445, 14.905254791004541, 15.858705673343444, 16.723145370042996, 17.463658627015487, 16.429840163271955, 13.577668025101715, 12.628484781051169, 11.614237635471385, 10.64876939416862, 9.770898166439167, 8.789075701053315, 7.856222644351456, 8.858837821911717, 9.824648524491952, 10.678948370876652, 11.53907276471498, 12.565561444583617, 12.883304637519052, 12.296446810596748, 13.008062606578855, 13.9483105596372, 14.80333131205615, 15.756265133288036, 16.490292821225015, 15.505111063299081, 14.521805023461765, 13.64105565071005, 12.68703214346135, 11.621442300381913, 10.706188712324147, 9.790320264742332, 8.920656529075883, 9.888522282149843, 10.785503417894954, 11.667015497938763, 12.561978524885765, 12.748963827782822, 11.867541135419216, 11.310348499871234, 11.986240452078256, 12.971562233770456, 13.854186148936998, 14.76228743918569, 15.619418004631191, 14.577851624571984, 15.477855792642393, 14.602607129636048, 13.61474864661884, 12.669605150891343, 11.673936477536387, 10.717818717147571, 9.916681661052007, 10.861596839216258, 11.750370102446611, 12.6234734841486, 12.725500797911232, 11.760153015050534, 10.869834003536772, 10.338461018208555, 10.990342131868347, 11.977842886800447, 12.860316348023952, 13.753679406311075, 14.545065981034313, 13.618538402522942, 16.472012020107673, 15.528767326394187, 14.59872384461258, 13.650847600515567, 12.667081260903407, 11.724867237032033, 10.916543503863933, 11.876092098384671, 12.807536962909424, 12.70845730665607, 11.759544247803166, 10.824074117947555, 9.879806980533447, 9.373868607967049, 10.063604309887731, 10.910203411215628, 11.825008931694509, 12.76706543385196, 13.683849382990346, 12.762220210489062, 17.524214015138032, 16.49746516316874, 15.55129457355288, 14.626274117998404, 13.658524794313974, 12.663303915165086, 11.854694398760174, 12.866018401766008, 12.550436565243409, 11.732992557321875, 10.803141544104776, 9.881923252634188, 8.888778453790954, 8.344760524710948, 8.99752670902684, 9.906472640758235, 10.87213519295712, 11.8519192080875, 12.723129723341147, 11.718634941644865, 17.617097741940846, 17.552357164267764, 16.56339586588586, 15.586064764084195, 14.644867070286267, 13.679011946128487, 12.82408497972812, 12.64620455841912, 11.613055087714047, 10.795351141299388, 9.859896529952701, 8.8435360674391, 7.8481134633925524, 7.344710658491032, 7.986210696308808, 8.94271623658077, 9.863814071734069, 10.82807612135128, 11.810119366085859, 10.782531232706248, 16.63591337825833, 17.39883297547523, 16.46776624947565, 15.477111308141556, 14.516871701595559, 13.487097301397457, 12.570207116813798, 11.662354851563501, 10.669496114737868, 9.724446822964923, 8.81220420828022, 7.8513310862132535, 6.906162371633285, 6.29555706516809, 7.044463718402259, 7.975984542778852, 8.84924243879799, 9.865531267774239, 10.892399646915164, 9.859895620454393, 15.692006715604558, 16.449407337776293, 15.49844001121622, 14.552486038703046, 13.54017228965683, 12.55549544580698, 11.621391406776352, 10.700178004634662, 9.727784113254573, 8.747366677211126, 7.772968535949287, 6.93160655648506, 5.974808325641239, 5.2409469747426805, 6.070672861025132, 6.935592912992604, 7.880803146906064, 8.937486483549275, 9.914797355360765, 8.883446033643756, 14.923909546032185, 15.449527110941352, 14.51024191672851, 13.582637094709755, 12.599941432205439, 11.616125844141443, 10.68338356616989, 9.765114567178653, 8.74933120121078, 7.7253792753735215, 6.81627113329419, 5.912393630947642, 5.0397600136638045, 4.175399929947369, 5.002633613333702, 5.944584869720398, 6.932165717632089, 7.934774014849764, 8.905528909392766, 7.954391455047545, 14.04139850290715, 14.548282974093992, 13.58674569280059, 12.636136557112394, 11.691328747373433, 10.617644447670457, 9.682313308510496, 8.737299421628204, 7.807692153802197, 6.798774922527967, 5.819775671402415, 4.893743944502087, 4.047328125886793, 3.103512421218767, 3.9420415050331608, 4.941626970963462, 5.9513214415397595, 6.931066140575282, 7.9503333119305255, 7.00916290073729, 14.576526707482635, 13.623158410649951, 12.613062653302478, 11.630945046331137, 10.694338613839275, 9.668499869347787, 8.72464076782132, 7.772039325203626, 6.7944368630320575, 5.879340212263106, 4.873075547990338, 3.8910565666379426, 3.0263992887475046, 2.096539682384923, 2.9698193499705257, 3.973368758068223, 4.986985621530752, 5.9854898185524235, 6.936682153703629, 7.961938410601312], [8.021071176026464, 7.042315282282634, 6.080595404885325, 5.1255988553690255, 4.059971016651099, 3.000476780070004, 2.046193893462072, 1.0291253443868398, 1.873754661321986, 2.826163743344492, 3.8692266911164226, 4.808945696209837, 5.738925381430883, 6.749386941072883, 7.692743161723117, 8.702066156756478, 9.75385249008684, 10.683056662958212, 11.70152503474662, 12.659464980204726, 7.056738782974338, 6.099444948604325, 5.143109637468464, 4.153117666226741, 3.119779321836159, 2.0469410820072653, 1.0345076457654754, 0.0, 0.9453012223442259, 1.9058665501233496, 2.8382961311644768, 3.771114264977738, 4.8238529438157425, 5.87062775054873, 6.91715665701193, 7.929754932428132, 8.9941474350494, 9.960226275520089, 10.983960735573982, 12.050689728937307, 8.030155138380225, 7.084427132553275, 6.080780955677206, 5.050289898087424, 3.9953549465489413, 3.013697820469149, 1.9902461618716818, 1.0148176706453285, 1.9272098450527793, 2.923672775068192, 3.858041084519073, 4.736521879620837, 5.7736451840677585, 6.823229745057848, 7.816347098326916, 8.830625840855799, 9.878040197683136, 10.865640886744838, 11.865484077944727, 12.862632420323635, 8.99817444597531, 8.096777007023405, 7.052471570218497, 5.992872303838052, 4.939503989582418, 3.94633085736768, 2.989439744428004, 2.0632023656796084, 2.9787353732384574, 3.9015844379082223, 4.883510093677328, 5.698668416496131, 6.747484568775238, 7.794152528543798, 8.868339508485658, 9.794382504453, 10.725067883999605, 11.716555948644217, 12.643928106534803, 13.622588888356994, 9.874967037850407, 8.904714015700618, 7.969018751426886, 6.940407732678281, 5.9003595193340175, 4.986305841751342, 3.941954703913343, 3.012386445129228, 3.9880980687807677, 4.916079047942711, 5.813075922754138, 6.651471530781484, 7.678869161026937, 8.70953807293186, 9.6756016158828, 10.657327636316985, 11.662563607755109, 12.609429648010554, 13.645477847204807, 14.576222166658672, 10.813211612218298, 9.799371281854416, 8.817346979501849, 7.86145333918976, 6.83976571040107, 5.9424008478453985, 4.894868113006355, 4.043409729475791, 5.0099975522442355, 5.853858266575176, 6.8120234790351315, 7.683435971936633, 8.627868978825118, 9.64044858265225, 10.589541221600507, 11.552811296672932, 12.556695804927042, 13.54526830802874, 14.488707016848482, 15.555530242432855, 11.76838389316011, 10.745330404895826, 9.74556541411871, 8.770839663519592, 7.781442342846004, 6.776224525447391, 5.851136573942693, 5.041974481663717, 5.954548668831194, 6.780241271009619, 7.812475683542864, 8.742011375694446, 9.574475522866216, 10.519556953467745, 11.479791848351637, 12.445006391453685, 13.474647027103801, 14.470287112908425, 15.4226325635382, 16.37662589153977, 12.680345424127964, 11.646142681269566, 10.663275879222555, 9.700840583193026, 8.732214335046258, 7.789753567705816, 6.853662963769824, 6.075928343381889, 6.960055272591474, 7.7652086391893365, 8.77209513738641, 9.681345590884625, 10.554679356346407, 11.51453508659111, 12.405881258523776, 13.412834127519183, 14.437561078197152, 15.413304643750623, 16.35741233783055, 17.366164445958518, 13.64405740764985, 12.571343982788942, 11.593320057372068, 10.68573228271623, 9.734683460097928, 8.722352432453485, 7.864801062452213, 7.126568903601635, 8.022491655889425, 8.705231285366853, 9.660359851234457, 10.595850703272964, 11.516244650434551, 12.471471981603445, 13.43175552151515, 14.390967348742018, 15.34441823108092, 16.313713884292074, 17.270377683991192, 17.421884867573333, 14.56971272940309, 13.620529485352543, 12.60628233977276, 11.640814098469994, 10.751583619977872, 9.769761154592018, 8.836908097890158, 8.131045995544214, 9.00578851027397, 9.733437073560777, 10.593561467399105, 11.620050147267742, 11.879368861251008, 12.723114752284099, 13.698210961250709, 14.64745271788317, 15.58305691165822, 16.535990732890106, 17.482337525526393, 16.497155767600457, 15.513849727763139, 14.633100355011425, 13.679076847762724, 12.613487004683288, 11.686874165862852, 10.771005718281035, 9.901341982614584, 9.17516067494337, 9.966643403676972, 10.721504200622888, 11.61646722756989, 11.745028051514778, 10.863605359151173, 11.737016441558584, 12.67638880675011, 13.670704392016425, 14.633911748539068, 15.54201303878776, 16.531907008578905, 15.569896328873359, 16.46990049694377, 15.594651833937423, 14.606793350920215, 13.659628490813107, 12.654621931075091, 11.698504170686274, 10.897367114590708, 10.148235232009785, 10.93151008822863, 11.677962186832724, 11.721565021643189, 10.75621723878249, 9.865898227268728, 10.765128959895906, 11.706754460830092, 12.750402623881508, 13.640041947626022, 14.533405005913146, 15.537110685335687, 14.610583106824317, 17.464056724409048, 16.52081203069556, 15.588747184534345, 14.640870940437331, 13.647766714442112, 12.705552690570737, 11.897228957402634, 11.217222013925394, 11.988676948691442, 11.673949660890596, 10.755608471535123, 9.820138341679511, 8.875871204265403, 9.8005365496544, 10.80770816257711, 11.689929010817698, 12.604734531296579, 13.54679103345403, 14.546348424213694, 13.754264914790436, 17.39869029743387, 17.487488503090507, 16.541317913474646, 15.616297457920169, 14.639210247852679, 13.64398936870379, 12.835379852298875, 12.260106438889839, 11.515928919477936, 10.6984849115564, 9.768633898339301, 8.877987476366142, 7.884842677522911, 8.771428466398298, 9.741630561716219, 10.686198240360305, 11.65186079255919, 12.66711315168185, 13.671462399483078, 12.713742544078382, 16.58259009617537, 17.41895462632773, 16.37757538290644, 15.370137851585913, 14.471711397641258, 13.505856273483477, 12.562180801904525, 11.611696912653645, 10.578547441948572, 9.760843495533912, 8.825388884187227, 7.839600291171055, 6.844177687124509, 7.771378600178383, 8.790607496091692, 9.747113036363654, 10.755471699306321, 11.719733748923533, 12.701776993658111, 11.777638835139765, 15.601405732492854, 16.364325329709754, 15.433258603710172, 14.44260366237608, 13.482364055830082, 12.45258965563198, 11.535699471048323, 10.627847205798027, 9.634988468972393, 8.689939177199449, 7.777696562514745, 6.84739530994521, 5.902226595365241, 6.933937043635463, 7.848860518185143, 8.888583076948724, 9.834194115913041, 10.85048294488929, 11.906815737141951, 10.87431171068118, 14.657499069839082, 15.414899692010817, 14.463932365450743, 13.51797839293757, 12.505664643891354, 11.520987800041503, 10.586883761010878, 9.665670358869185, 8.693276467489097, 7.71285903144565, 6.738460890183813, 5.897098910719585, 4.970872549373195, 5.902466657630084, 6.875069660808016, 7.920544590107656, 8.865754824021115, 9.922438160664326, 10.915347897877556, 9.897862123870542, 13.889401900266709, 14.415019465175876, 13.475734270963034, 12.548129448944279, 11.565433786439963, 10.581618198375967, 9.648875920404416, 8.730606921413177, 7.714823555445304, 6.690871629608046, 5.781763487528716, 4.877885985182167, 4.035824237395761, 5.021461512073624, 5.987585290448754, 6.9295365468354495, 7.917117394747141, 8.919725691964816, 9.906079451909555, 8.96880754527433, 13.006890857141675, 13.513775328328515, 12.552238047035114, 11.601628911346918, 10.656821101607957, 9.583136801904981, 8.647805662745021, 7.702791775862729, 6.773184508036723, 5.764267276762491, 4.78526802563694, 3.8592362987366116, 3.043392349618749, 3.987208054286775, 4.9269931821482125, 5.926578648078514, 6.936273118654811, 7.916017817690333, 8.950883854447314, 8.043670546502767, 13.542019061717161, 12.588650764884477, 11.578555007537004, 10.596437400565662, 9.6598309680738, 8.633992223582311, 7.690133122055846, 6.737531679438151, 5.759929217266582, 4.84483256649763, 3.838567902224862, 2.8565489208724673, 1.995990065532431, 3.0222562291183257, 3.974054881126549, 4.977604289224246, 5.991221152686775, 7.008166301874181, 7.959358637025385, 8.99644605636679], [8.96637239837069, 7.9876165046268595, 6.992911694527568, 6.037915145011269, 4.96833433974275, 3.908840103161655, 2.954557216553723, 1.937488667478491, 0.9284534389777601, 1.8808625210002663, 2.9239254687721967, 3.8636444738656106, 4.793624159086657, 5.804085718728657, 6.7474419393788905, 7.756764934412251, 8.808551267742613, 9.737755440613984, 10.756223812402393, 11.714163757860499, 8.002040005318563, 7.04474617094855, 6.088410859812689, 5.098418888570967, 4.065080544180385, 2.9922423043514916, 1.9798088681097012, 0.9453012223442259, 0.0, 0.9605653277791236, 1.8929949088202507, 2.8258130426335115, 3.878551721471516, 4.925326528204503, 5.971855434667703, 6.984453710083906, 8.048846212705175, 9.014925053175864, 10.038659513229756, 11.105388506593082, 8.97545636072445, 8.0297283548975, 7.026082178021431, 5.99559112043165, 4.940656168893167, 3.9589990428133746, 2.9355473842159077, 1.9601188929895543, 0.9819086227085535, 1.9783715527239663, 2.9127398621748473, 3.791220657276611, 4.828343961723532, 5.8779285227136215, 6.87104587598269, 7.885324618511572, 8.932738975338909, 9.920339664400611, 10.9201828556005, 11.917331197979408, 9.943475668319536, 9.04207822936763, 7.997772792562722, 6.938173526182277, 5.884805211926643, 4.891632079711906, 3.93474096677223, 3.008503588023834, 2.0334341508942315, 2.9562832155639964, 3.938208871333103, 4.753367194151904, 5.80218334643101, 6.84885130619957, 7.923038286141431, 8.849081282108774, 9.779766661655378, 10.77125472629999, 11.698626884190576, 12.677287666012766, 10.820268260194633, 9.850015238044843, 8.914319973771113, 7.885708955022507, 6.845660741678243, 5.9316070640955685, 4.887255926257569, 3.957687667473454, 3.0427968464365414, 3.970777825598485, 4.867774700409913, 5.706170308437256, 6.73356793868271, 7.764236850587633, 8.730300393538572, 9.712026413972758, 10.717262385410882, 11.664128425666327, 12.70017662486058, 13.630920944314445, 11.758512834562525, 10.744672504198643, 9.762648201846075, 8.806754561533985, 7.785066932745296, 6.887702070189624, 5.840169335350581, 4.988710951820018, 4.083959723440275, 4.90855704423095, 5.866722256690906, 6.7381347495924055, 7.682567756480892, 8.695147360308024, 9.644239999256282, 10.607510074328706, 11.611394582582815, 12.599967085684513, 13.543405794504254, 14.610229020088628, 12.713685115504337, 11.690631627240052, 10.690866636462935, 9.716140885863817, 8.72674356519023, 7.721525747791617, 6.796437796286918, 5.987275704007944, 5.028510840027233, 5.834940048665393, 6.867174461198638, 7.796710153350219, 8.62917430052199, 9.57425573112352, 10.534490626007411, 11.49970516910946, 12.529345804759576, 13.524985890564198, 14.477331341193972, 15.431324669195543, 13.625646646472187, 12.591443903613792, 11.60857710156678, 10.646141805537251, 9.677515557390484, 8.735054790050041, 7.798964186114049, 7.021229565726117, 6.034017443787514, 6.81990741684511, 7.826793915042183, 8.736044368540398, 9.609378134002181, 10.569233864246884, 11.46058003617955, 12.467532905174957, 13.492259855852927, 14.468003421406396, 15.412111115486322, 16.42086322361429, 14.589358629994075, 13.516645205133168, 12.538621279716294, 11.631033505060456, 10.679984682442154, 9.66765365479771, 8.81010228479644, 8.071870125945862, 7.096453827085465, 7.759930063022626, 8.71505862889023, 9.650549480928737, 10.570943428090327, 11.52617075925922, 12.486454299170925, 13.445666126397793, 14.399117008736695, 15.36841266194785, 16.32507646164697, 17.3588949253905, 15.515013951747315, 14.565830707696769, 13.551583562116985, 12.58611532081422, 11.696884842322097, 10.715062376936244, 9.782209320234385, 9.076347217888442, 8.07975068147001, 8.78813585121655, 9.648260245054878, 10.674748924923515, 11.573909307742053, 12.550031784171738, 13.480675542607514, 14.402610357765134, 15.45286360352731, 16.33529289870281, 17.344201416414133, 17.44245698994468, 16.459150950107365, 15.57840157735565, 14.62437807010695, 13.558788227027513, 12.632175388207077, 11.71630694062526, 10.846643204958811, 10.037114350245751, 9.040605574873013, 9.776202978278661, 10.671166005225663, 10.958023499328284, 11.708640091380815, 12.582051173788226, 13.521423538979752, 14.515739124246068, 15.47894648076871, 16.387047771017404, 17.37694174080855, 16.515197551217582, 17.415201719287992, 16.53995305628165, 15.55209457326444, 14.604929713157333, 13.599923153419317, 12.6438053930305, 11.842668336934935, 10.971281731721726, 10.00547225942467, 10.732660964488497, 10.82658163340786, 9.969212686595997, 10.71093295949837, 11.610163692125548, 12.551789193059735, 13.59543735611115, 14.485076679855664, 15.378439738142788, 16.439676665751016, 15.555884329168542, 17.3684858878984, 17.466113253039786, 16.534048406878572, 15.586172162781557, 14.593067936786337, 13.650853912914961, 12.842530179746861, 12.01903064587144, 11.062639119887482, 10.728648438546367, 9.836023279816047, 9.033133789493018, 9.720905936495045, 10.645571281884042, 11.652742894806753, 12.53496374304734, 13.449769263526221, 14.391825765683672, 15.391383156443336, 14.69956613713466, 16.453389075089643, 17.328360689605518, 16.382190099989657, 15.38462727532748, 14.528190981282485, 13.564168344878158, 12.574345347908315, 11.56302134490248, 10.570627697133709, 9.753183689212172, 8.823332675995072, 8.071840845407724, 8.729877409752552, 9.61646319862794, 10.586665293945861, 11.531232972589947, 12.496895524788833, 13.512147883911492, 14.51649713171272, 13.65904376642261, 15.637288873831142, 16.4736534039835, 15.432274160562212, 14.424836629241689, 13.526410175297034, 12.560555051139252, 11.616879579560297, 10.666395690309418, 9.633246219604345, 8.815542273189687, 7.880087661842999, 7.033453660212636, 7.689212419354151, 8.616413332408026, 9.635642228321334, 10.592147768593296, 11.600506431535964, 12.564768481153175, 13.546811725887753, 12.722940057483992, 14.656104510148626, 15.419024107365527, 14.487957381365947, 13.497302440031856, 12.537062833485859, 11.507288433287755, 10.590398248704098, 9.6825459834538, 8.689687246628166, 7.744637954855222, 6.8323953401705175, 6.006043926747859, 6.747261327594884, 7.778971775865105, 8.693895250414785, 9.733617809178366, 10.680373008036613, 11.696661837012861, 12.759071956537626, 11.819612933025406, 13.712197847494854, 14.469598469666591, 13.518631143106518, 12.572677170593344, 11.560363421547128, 10.575686577697278, 9.641582538666652, 8.72036913652496, 7.747975245144872, 6.767557809101424, 5.793159667839586, 4.9517976883753585, 5.815907281602837, 6.7475013898597265, 7.7201043930376585, 8.766723482231226, 9.711933716144687, 10.768617052787897, 11.761526790001128, 10.843163346214768, 12.944100677922481, 13.46971824283165, 12.530433048618809, 11.602828226600053, 10.620132564095737, 9.636316976031742, 8.70357469806019, 7.785305699068951, 6.769522333101078, 5.74557040726382, 4.836462265184489, 3.9325847628379407, 4.880858969625403, 5.866496244303266, 6.833764182572325, 7.77571543895902, 8.763296286870712, 9.765904584088387, 10.752258344033127, 9.914108767618556, 12.06158963479745, 12.568474105984288, 11.606936824690887, 10.65632768900269, 9.71151987926373, 8.637835579560756, 7.702504440400795, 6.757490553518503, 5.827883285692495, 4.818966054418265, 3.8399668032927137, 2.9139350763923857, 3.8895712417423196, 4.833386946410346, 5.773172074271783, 6.772757540202084, 7.782452010778382, 8.762196709813905, 9.797062746570885, 8.98897176884699, 12.596717839372934, 11.64334954254025, 10.633253785192776, 9.651136178221435, 8.714529745729573, 7.688691001238086, 6.7448318997116194, 5.7922304570939245, 4.814627994922356, 3.899531344153405, 2.893266679880637, 1.9112476985282414, 2.842168957656002, 3.8684351212418973, 4.82023377325012, 5.823783181347817, 6.837400044810346, 7.854345193997752, 8.805537529148957, 9.873308196913843], [9.926937726149811, 8.948181832405982, 7.953477022306692, 6.998480472790392, 5.928899667521874, 4.869405430940779, 3.915122544332847, 2.898053995257615, 1.8890187667568838, 1.0390508520987778, 2.001788510393905, 2.903079146086487, 3.833058831307533, 4.843520390949532, 5.786876611599766, 6.7961996066331265, 7.84798593996349, 8.77719011283486, 9.795658484623269, 10.753598430081375, 8.962605333097686, 8.005311498727673, 7.048976187591813, 6.05898421635009, 5.025645871959509, 3.9528076321306154, 2.940374195888825, 1.9058665501233496, 0.9605653277791236, 0.0, 0.932429581041127, 1.865247714854388, 2.917986393692393, 3.9647612004253805, 5.0112901068885805, 6.023888382304783, 7.088280884926052, 8.05435972539674, 9.078094185450633, 10.144823178813958, 9.936021688503574, 8.990293682676624, 7.986647505800555, 6.956156448210773, 5.9012214966722905, 4.919564370592498, 3.8961127119950314, 2.920684220768678, 1.9424739504876771, 1.0178062249448425, 1.9521745343957235, 2.830655329497487, 3.8677786339444085, 4.917363194934498, 5.910480548203566, 6.924759290732449, 7.972173647559785, 8.959774336621486, 9.959617527821374, 10.956765870200282, 10.90404099609866, 10.002643557146754, 8.958338120341846, 7.898738853961401, 6.845370539705767, 5.85219740749103, 4.895306294551354, 3.969068915802958, 2.953898947915825, 1.9957178877848727, 2.977643543553979, 3.792801866372781, 4.841618018651887, 5.888285978420447, 6.962472958362307, 7.888515954329651, 8.819201333876256, 9.810689398520868, 10.738061556411454, 11.716722338233645, 11.780833587973758, 10.810580565823969, 9.874885301550236, 8.84627428280163, 7.806226069457367, 6.892172391874692, 5.847821254036693, 4.918252995252577, 3.963261643458135, 3.0102124978193614, 3.9072093726307897, 4.745604980658133, 5.773002610903586, 6.803671522808509, 7.769735065759448, 8.751461086193634, 9.75669705763176, 10.703563097887205, 11.739611297081458, 12.670355616535323, 12.719078162341651, 11.705237831977769, 10.7232135296252, 9.76731988931311, 8.74563226052442, 7.848267397968748, 6.800734663129704, 5.857306488122694, 4.89071866535425, 3.9479917164518263, 4.906156928911782, 5.777569421813282, 6.722002428701768, 7.7345820325289, 8.683674671477158, 9.646944746549583, 10.650829254803693, 11.639401757905391, 12.582840466725132, 13.649663692309506, 13.674250443283462, 12.651196955019175, 11.65143196424206, 10.676706213642941, 9.687308892969353, 8.68209107557074, 7.757003124066042, 6.830308032021671, 5.835269781941208, 4.874374720886269, 5.906609133419514, 6.836144825571095, 7.668608972742866, 8.613690403344396, 9.573925298228287, 10.539139841330336, 11.568780476980452, 12.564420562785076, 13.51676601341485, 14.470759341416422, 14.586211974251313, 13.552009231392915, 12.569142429345904, 11.606707133316375, 10.638080885169607, 9.695620117829163, 8.759529513893172, 7.8142494193653835, 6.800487048505808, 5.859342089065986, 6.866228587263059, 7.775479040761274, 8.648812806223056, 9.608668536467759, 10.500014708400426, 11.506967577395834, 12.531694528073803, 13.507438093627274, 14.4515457877072, 15.46029789583517, 15.5499239577732, 14.477210532912292, 13.499186607495417, 12.59159883283958, 11.640550010221276, 10.628218982576833, 9.749652615500468, 8.77940749444484, 7.792416554306569, 6.799364735243502, 7.754493301111105, 8.689984153149613, 9.610378100311202, 10.565605431480094, 11.525888971391801, 12.485100798618669, 13.438551680957572, 14.407847334168725, 15.364511133867843, 16.398329597611376, 16.47557927952644, 15.526396035475893, 14.512148889896109, 13.546680648593343, 12.65745017010122, 11.675627704715366, 10.721759650938413, 9.783884586387419, 8.769636226977479, 7.827570523437427, 8.687694917275754, 9.714183597144391, 10.613343979962927, 11.589466456392612, 12.52011021482839, 13.442045029986012, 14.492298275748189, 15.374727570923687, 16.38363608863501, 17.368817846560948, 17.419716277886486, 16.538966905134775, 15.584943397886073, 14.519353554806637, 13.5927407159862, 12.66574969015551, 11.69486564882718, 10.72699989575322, 9.730491120380481, 8.81563765049954, 9.71060067744654, 10.659076729195087, 11.629107482062762, 12.575564767118127, 13.514937132309653, 14.418793355852756, 15.44144343886734, 16.38565436208342, 17.37554833187457, 17.475762878996704, 17.35031396824094, 17.500518384060776, 16.512659901043566, 15.565495040936455, 14.560488481198439, 13.593248142560748, 12.67550989420473, 11.661167277229195, 10.695357804932138, 9.772095636709375, 10.085794953527714, 10.929778014375119, 11.671498287277494, 12.570729019904672, 13.512354520838858, 14.556002683890274, 15.445642007634786, 16.33900506592191, 17.400241993530138, 16.516449656947664, 16.40792056011928, 17.374361317151997, 16.347364709128207, 15.399488465031192, 14.482246926659561, 13.538050040611791, 12.563855727645363, 11.724656401978512, 10.768264875994554, 9.98786175866622, 9.0952365999359, 9.99369911727214, 10.681471264274169, 11.606136609663166, 12.613308222585877, 13.495529070826462, 14.410334591305343, 15.352391093462794, 16.351948484222458, 15.660131464913785, 15.49282374731052, 16.367795361826392, 15.421624772210532, 14.424061947548354, 13.56762565350336, 12.615527829718966, 11.625704832749122, 10.803545334586921, 9.81115168681815, 9.012397009332025, 8.082545996114925, 9.032406173186846, 9.690442737531676, 10.577028526407064, 11.547230621724985, 12.49179830036907, 13.457460852567955, 14.472713211690614, 15.477062459491844, 14.619609094201735, 14.67672354605202, 15.513088076204378, 14.471708832783088, 13.464271301462563, 12.565844847517909, 11.599989723360128, 10.656314251781176, 9.892323429461634, 8.873770209288786, 8.07475559330954, 7.139300981962852, 7.99401898799176, 8.649777747133275, 9.57697866018715, 10.596207556100458, 11.55271309637242, 12.561071759315087, 13.525333808932299, 14.507377053666877, 13.683505385263118, 13.695539182369505, 14.458458779586403, 13.527392053586823, 12.53673711225273, 11.576497505706733, 10.546723105508631, 9.629832920924974, 8.908473722606015, 7.930211236312606, 7.003851274975076, 6.091608660290371, 6.966609254526983, 7.707826655374007, 8.73953710364423, 9.654460578193909, 10.69418313695749, 11.640938335815736, 12.657227164791985, 13.719637284316748, 12.78017826080453, 12.751632519715733, 13.509033141887468, 12.558065815327394, 11.61211184281422, 10.599798093768005, 9.615121249918154, 8.681017210887529, 7.849892029103567, 6.898417408402942, 6.026771129221277, 5.052372987959439, 5.912363016154482, 6.776472609381961, 7.70806671763885, 8.680669720816782, 9.72728881001035, 10.67249904392381, 11.729182380567021, 12.72209211778025, 11.803728673993891, 11.983535350143356, 12.509152915052526, 11.569867720839685, 10.64226289882093, 9.659567236316613, 8.675751648252618, 7.743009370281066, 6.866693144010977, 5.8651756012631155, 5.004783727383673, 4.095675585304342, 4.893150090617064, 5.841424297404527, 6.82706157208239, 7.7943295103514485, 8.736280766738144, 9.723861614649836, 10.726469911867511, 11.71282367181225, 10.87467409539768, 11.101024307018326, 11.607908778205164, 10.646371496911764, 9.695762361223567, 8.750954551484606, 7.677270251781631, 6.741939112621671, 5.796925225739379, 4.867317957913372, 4.078179374538118, 3.099180123412567, 3.8745004041715094, 4.850136569521443, 5.793952274189469, 6.733737402050907, 7.733322867981208, 8.743017338557506, 9.722762037593029, 10.75762807435001, 9.949537096626115, 11.636152511593808, 10.682784214761124, 9.672688457413651, 8.69057085044231, 7.753964417950448, 6.728125673458961, 5.784266571932495, 4.831665129314801, 3.854062667143232, 3.041048431297413, 2.051455010979148, 2.871813026307365, 3.802734285435126, 4.829000449021021, 5.780799101029244, 6.784348509126941, 7.79796537258947, 8.814910521776877, 9.766102856928082, 10.833873524692969], [10.859367307190938, 9.88061141344711, 8.88590660334782, 7.93091005383152, 6.861329248563002, 5.801835011981907, 4.847552125373975, 3.830483576298742, 2.821448347798011, 1.971480433139905, 1.0693589293527779, 1.9706495650453602, 2.900629250266406, 3.911090809908406, 4.85444703055864, 5.863770025592, 6.915556358922363, 7.844760531793734, 8.863228903582142, 9.821168849040248, 9.895034914138813, 8.9377410797688, 7.98140576863294, 6.991413797391218, 5.958075453000635, 4.885237213171742, 3.8728037769299517, 2.8382961311644763, 1.8929949088202507, 0.932429581041127, 0.0, 0.932818133813261, 1.9855568126512657, 3.0323316193842533, 4.078860525847453, 5.091458801263656, 6.1558513038849245, 7.121930144355614, 8.145664604409507, 9.212393597772833, 10.868451269544702, 9.922723263717751, 8.919077086841682, 7.8885860292519006, 6.833651077713418, 5.8519939516336255, 4.828542293036159, 3.853113801809805, 2.8749035315288043, 1.9502358059859697, 1.026633722807568, 1.89822574845636, 2.9353490529032813, 3.9849336138933706, 4.978050967162439, 5.9923297096913215, 7.039744066518658, 8.027344755580359, 9.027187946780247, 10.024336289159155, 11.836470577139787, 10.935073138187882, 9.890767701382973, 8.831168435002528, 7.777800120746894, 6.784626988532157, 5.827735875592481, 4.901498496844084, 3.8863285289569522, 2.928147468826, 2.0521027319658236, 2.8603722853316538, 3.9091884376107595, 4.9558563973793195, 6.03004337732118, 6.956086373288524, 7.886771752835129, 8.87825981747974, 9.805631975370327, 10.784292757192517, 12.713263169014885, 11.743010146865096, 10.807314882591363, 9.778703863842757, 8.738655650498494, 7.824601972915819, 6.780250835077819, 5.850682576293703, 4.895691224499262, 3.9426420788604886, 2.981668561042634, 3.813175399617006, 4.84057302986246, 5.871241941767383, 6.837305484718322, 7.819031505152507, 8.824267476590633, 9.771133516846078, 10.807181716040331, 11.737926035494196, 13.651507743382778, 12.637667413018896, 11.655643110666327, 10.699749470354238, 9.678061841565547, 8.780696979009875, 7.733164244170831, 6.78973606916382, 5.823148246395376, 4.880421297492953, 3.9806161173236267, 4.845139840772155, 5.789572847660642, 6.802152451487773, 7.751245090436031, 8.714515165508455, 9.718399673762566, 10.706972176864264, 11.650410885684005, 12.717234111268379, 14.60668002432459, 13.583626536060303, 12.583861545283186, 11.609135794684068, 10.61973847401048, 9.614520656611868, 8.68943270510717, 7.762737613062797, 6.767699362982334, 5.8068043019273965, 5.042969984702342, 5.903715244529968, 6.736179391701739, 7.681260822303269, 8.64149571718716, 9.606710260289208, 10.636350895939325, 11.631990981743948, 12.584336432373723, 13.538329760375294, 15.51864155529244, 14.484438812434043, 13.501572010387031, 12.539136714357502, 11.570510466210735, 10.62804969887029, 9.6919590949343, 8.74667900040651, 7.732916629546935, 6.791771670107114, 6.110440728906754, 6.843049459720147, 7.7163832251819295, 8.676238955426633, 9.5675851273593, 10.574537996354707, 11.599264947032676, 12.575008512586146, 13.519116206666073, 14.527868314794043, 16.482353538814326, 15.409640113953419, 14.431616188536545, 13.524028413880707, 12.572979591262403, 11.56064856361796, 10.682082196541595, 9.711837075485967, 8.724846135347697, 7.731794316284629, 7.089542420089002, 7.855934559865566, 8.677948519270075, 9.633175850438969, 10.593459390350674, 11.552671217577542, 12.506122099916444, 13.475417753127598, 14.432081552826716, 15.46590001657025, 17.408008860567566, 16.458825616517018, 15.444578470937236, 14.47911022963447, 13.589879751142346, 12.608057285756493, 11.65418923197954, 10.716314167428546, 9.702065808018604, 8.760000104478554, 8.02274403625365, 8.880134003860345, 9.6809143989218, 10.657036875351485, 11.587680633787263, 12.509615448944885, 13.559868694707061, 14.44229798988256, 15.451206507593882, 16.436388265519817, 17.37393515638044, 17.4713964861759, 16.517372978927202, 15.451783135847764, 14.525170297027326, 13.598179271196635, 12.627295229868306, 11.659429476794346, 10.662920701421607, 9.748067231540665, 9.045649796424435, 9.887605655910544, 10.696677901021635, 11.643135186077, 12.582507551268526, 13.486363774811629, 14.509013857826213, 15.453224781042296, 16.44311875083344, 17.363647704246915, 16.417884387199813, 17.368091932869007, 16.40236269994873, 15.448301333614292, 14.542962128985454, 13.612668979455126, 12.631287989416162, 11.858811627713296, 10.893002155416239, 10.261725339412171, 9.991599868878296, 10.876416468642832, 11.69438503290408, 12.615022667739678, 13.556648168673865, 14.480083121781638, 15.411997640037946, 16.384902841785877, 17.456528745007873, 17.44887923798879, 15.475490979078154, 16.44193173611087, 15.414935128087082, 14.467058883990068, 13.549817345618434, 12.605620459570664, 11.631426146604236, 10.792226820937385, 9.835835294953426, 9.227106562675568, 10.027666180977029, 10.92612869831327, 11.613900845315296, 12.538566190704293, 13.545737803627004, 14.42795865186759, 15.34276417234647, 16.28482067450392, 17.28437806526358, 16.592561045954913, 14.560394166269393, 15.435365780785267, 14.489195191169408, 13.49163236650723, 12.635196072462236, 11.683098248677839, 10.693275251707995, 9.871115753545794, 8.878722105777022, 8.251641813341372, 9.014975577156054, 9.964835754227977, 10.622872318572803, 11.509458107448191, 12.479660202766112, 13.424227881410197, 14.389890433609082, 15.405142792731741, 16.40949204053297, 15.552038675242862, 13.744293965010893, 14.580658495163252, 13.539279251741963, 12.53184172042144, 11.633415266476785, 10.667560142319003, 9.723884670740048, 8.959893848420506, 7.941340628247659, 7.176892349408311, 8.07173056300398, 8.926448569032889, 9.582207328174402, 10.509408241228277, 11.528637137141585, 12.485142677413547, 13.493501340356215, 14.457763389973426, 15.439806634708004, 14.615934966304245, 12.763109601328377, 13.526029198545277, 12.594962472545697, 11.604307531211607, 10.64406792466561, 9.614293524467506, 8.697403339883847, 7.976044141564887, 6.9977816552714796, 6.105988031073847, 7.024038241331498, 7.899038835568111, 8.640256236415135, 9.671966684685357, 10.586890159235036, 11.626612717998617, 12.573367916856864, 13.589656745833112, 14.652066865357876, 13.712607841845657, 11.819202938674605, 12.576603560846342, 11.625636234286269, 10.679682261773095, 9.66736851272688, 8.682691668877029, 7.748587629846401, 6.91746244806244, 5.965987827361816, 5.128907885320048, 5.984802569000566, 6.84479259719561, 7.708902190423089, 8.640496298679977, 9.61309930185791, 10.659718391051477, 11.604928624964938, 12.661611961608148, 13.654521698821377, 12.736158255035019, 11.051105769102229, 11.576723334011401, 10.63743813979856, 9.709833317779804, 8.727137655275488, 7.7433220672114915, 6.81057978923994, 5.93426356296985, 4.932746020221989, 4.106920483482444, 5.028105166345469, 5.8255796716581925, 6.773853878445655, 7.759491153123518, 8.726759091392577, 9.668710347779271, 10.656291195690963, 11.658899492908638, 12.645253252853378, 11.807103676438807, 10.1685947259772, 10.675479197164037, 9.713941915870636, 8.76333278018244, 7.818524970443479, 6.744840670740505, 5.809509531580544, 4.864495644698252, 3.9348883768722454, 3.1803161306368892, 4.031609704453694, 4.806929985212637, 5.7825661505625705, 6.7263818552305965, 7.666166983092034, 8.665752449022335, 9.675446919598633, 10.655191618634156, 11.690057655391136, 10.881966677667242, 10.703722930552683, 9.750354633719999, 8.740258876372526, 7.758141269401184, 6.821534836909322, 5.795696092417835, 4.8518369908913686, 3.8992355482736736, 2.9216330861021054, 2.108618850256286, 2.9838845920202752, 3.8042426073484923, 4.7351638664762525, 5.761430030062147, 6.713228682070371, 7.716778090168068, 8.730394953630597, 9.747340102818004, 10.69853243796921, 11.766303105734096], [11.792185441004198, 10.81342954726037, 9.81872473716108, 8.86372818764478, 7.794147382376262, 6.734653145795167, 5.780370259187235, 4.763301710112002, 3.7542664816112716, 2.904298566953166, 2.0021770631660387, 1.037831431232099, 1.967811116453145, 2.978272676095145, 3.9216288967453785, 4.930951891778739, 5.982738225109102, 6.911942397980473, 7.930410769768882, 8.888350715226988, 10.827853047952074, 9.87055921358206, 8.9142239024462, 7.924231931204478, 6.890893586813896, 5.818055346985003, 4.805621910743213, 3.7711142649777374, 2.8258130426335115, 1.865247714854388, 0.932818133813261, 0.0, 1.0527386788380049, 2.0995134855709923, 3.1460423920341922, 4.158640667450395, 5.2230331700716635, 6.1891120105423525, 7.212846470596246, 8.279575463959572, 11.801269403357962, 10.855541397531011, 9.851895220654942, 8.82140416306516, 7.766469211526679, 6.7848120854468865, 5.76136042684942, 4.785931935623066, 3.807721665342065, 2.8830539397992307, 1.959451856620829, 0.9654076146430992, 2.0025309190900207, 3.05211548008011, 4.0452328333491785, 5.059511575878061, 6.106925932705398, 7.094526621767099, 8.094369812966987, 9.091518155345895, 12.769288710953047, 11.867891272001144, 10.823585835196235, 9.76398656881579, 8.710618254560156, 7.717445122345418, 6.760554009405742, 5.834316630657346, 4.819146662770213, 3.860965602639261, 2.9767124737947155, 1.927554151518393, 2.976370303797499, 4.023038263566058, 5.097225243507918, 6.023268239475262, 6.953953619021867, 7.94544168366648, 8.872813841557065, 9.851474623379255, 13.646081302828145, 12.675828280678356, 11.740133016404625, 10.71152199765602, 9.671473784311756, 8.75742010672908, 7.713068968891081, 6.783500710106965, 5.828509358312523, 4.875460212673749, 3.906278302871526, 2.8803572658037453, 3.907754896049199, 4.938423807954122, 5.904487350905061, 6.886213371339246, 7.89144934277737, 8.838315383032814, 9.874363582227067, 10.805107901680932, 14.584325877196038, 13.570485546832156, 12.58846124447959, 11.6325676041675, 10.61087997537881, 9.713515112823137, 8.665982377984093, 7.71894142689898, 6.752353604130536, 5.809626655228113, 4.847219740603541, 3.9123217069588945, 4.856754713847381, 5.869334317674513, 6.818426956622771, 7.781697031695195, 8.785581539949305, 9.774154043051, 10.717592751870741, 11.784415977455115, 15.53949815813785, 14.516444669873565, 13.516679679096448, 12.54195392849733, 11.552556607823742, 10.54733879042513, 9.622250838920431, 8.691942970797957, 7.6969047207174945, 6.736009659662557, 5.904063873833332, 4.970897110716708, 5.803361257888478, 6.748442688490008, 7.708677583373899, 8.673892126475947, 9.703532762126063, 10.699172847930685, 11.65151829856046, 12.60551162656203, 16.4514596891057, 15.417256946247305, 14.434390144200293, 13.471954848170764, 12.503328600023996, 11.560867832683552, 10.624777228747561, 9.675884358141671, 8.662121987282095, 7.720977027842274, 6.887005004237871, 5.910231325906887, 6.7835650913686685, 7.743420821613372, 8.63476699354604, 9.641719862541445, 10.666446813219414, 11.642190378772883, 12.58629807285281, 13.59505018098078, 17.41517167262759, 16.342458247766682, 15.364434322349807, 14.456846547693969, 13.505797725075665, 12.493466697431222, 11.611287554276755, 10.641042433221127, 9.654051493082857, 8.66099967401979, 7.858607278090814, 6.923116426052306, 7.745130385456814, 8.700357716625708, 9.660641256537414, 10.619853083764282, 11.573303966103184, 12.542599619314338, 13.499263419013456, 14.53308188275699, 17.385254020927228, 17.39164375033028, 16.377396604750498, 15.411928363447732, 14.522697884955608, 13.540875419569755, 12.5833945897147, 11.645519525163706, 10.631271165753764, 9.689205462213714, 8.791808894255462, 7.947315870047085, 8.74809626510854, 9.724218741538225, 10.654862499974003, 11.576797315131625, 12.627050560893801, 13.5094798560693, 14.518388373780622, 15.503570131706558, 16.44111702256718, 17.429899572943743, 16.39726106929296, 15.563646050310457, 14.541485247225037, 13.607349298047101, 12.694494987579022, 11.899068050966449, 10.925050706154634, 10.677272589275825, 9.814714654426247, 8.954787522097284, 9.763859767208375, 10.71031705226374, 11.649689417455265, 12.553545640998369, 13.576195724012953, 14.520406647229036, 15.510300617020183, 16.430829570433655, 15.485066253386552, 16.435273799055743, 15.469544566135466, 14.515483199801029, 13.61014399517219, 12.679850845641862, 11.698469855602898, 10.925993493900034, 9.960184021602977, 10.898545219322944, 10.760664726880108, 9.943598334829572, 10.76156689909082, 11.682204533926418, 12.623830034860605, 13.547264987968378, 14.479179506224686, 15.452084707972618, 16.523710611194613, 17.390142792482695, 14.54267284526489, 15.509113602297607, 14.482116994273818, 13.534240750176805, 12.61699921180517, 11.6728023257574, 10.698608012790972, 9.859408687124123, 8.903017161140165, 9.86392644258634, 10.816472529589735, 10.87967723193255, 11.751593922094145, 12.646796944167924, 13.550567856841221, 14.499603581948426, 15.457622455187156, 16.399678957344605, 17.399236348104267, 17.525379179768173, 13.62757603245613, 14.502547646972003, 13.556377057356144, 12.558814232693967, 11.702377938648972, 10.750280114864575, 9.760457117894731, 8.938297619732534, 7.945903971963761, 8.979438828263087, 9.892732297398787, 10.897653888041237, 11.555690452386063, 12.442276241261451, 13.412478336579372, 14.357046015223457, 15.322708567422342, 16.337960926545, 17.34231017434623, 16.484856809056122, 12.81147583119763, 13.64784036134999, 12.606461117928701, 11.599023586608176, 10.700597132663521, 9.73474200850574, 8.791066536926785, 8.027075714607244, 7.0085224944343985, 8.033062984446277, 8.949487283246713, 9.85926670284615, 10.515025461987662, 11.442226375041537, 12.461455270954845, 13.417960811226807, 14.426319474169475, 15.390581523786686, 16.372624768521266, 15.548753100117505, 11.830291467515114, 12.593211064732015, 11.662144338732436, 10.671489397398343, 9.711249790852346, 8.681475390654244, 7.764585206070585, 7.043226007751626, 6.0649635214582185, 6.962158666111812, 7.901794961574231, 8.831856969381372, 9.573074370228396, 10.604784818498617, 11.519708293048296, 12.559430851811877, 13.506186050670124, 14.522474879646373, 15.584884999171136, 14.645425975658917, 10.886384804861343, 11.64378542703308, 10.692818100473007, 9.746864127959833, 8.734550378913617, 7.749873535063767, 6.815769496033139, 5.984644314249179, 5.033169693548555, 5.985078520358014, 6.862559289243299, 7.7776107310088705, 8.64172032423635, 9.573314432493238, 10.54591743567117, 11.592536524864737, 12.537746758778198, 13.594430095421409, 14.587339832634637, 13.668976388848279, 10.118287635288969, 10.64390520019814, 9.704620005985298, 8.777015183966542, 7.794319521462226, 6.8105039333982305, 5.877761655426678, 5.001445429156589, 3.999927886408728, 4.96309111852041, 5.905861886588202, 6.758397805471453, 7.706672012258915, 8.692309286936778, 9.659577225205837, 10.601528481592531, 11.589109329504224, 12.591717626721898, 13.578071386666638, 12.739921810252067, 9.23577659216394, 9.742661063350777, 8.781123782057376, 7.8305146463691795, 6.885706836630218, 5.812022536927244, 4.876691397767282, 3.931677510884991, 3.0020702430589843, 4.036486765674855, 4.964427838266955, 5.739748119025897, 6.715384284375832, 7.659199989043858, 8.598985116905295, 9.598570582835595, 10.608265053411893, 11.588009752447416, 12.622875789204397, 11.814784811480502, 9.770904796739421, 8.817536499906737, 7.8074407425592645, 6.825323135587923, 5.888716703096061, 4.862877958604574, 3.919018857078107, 2.9664174144604125, 1.9888149522888443, 3.0184610386310284, 3.9167027258335363, 4.737060741161753, 5.667982000289514, 6.694248163875408, 7.646046815883631, 8.649596223981328, 9.663213087443857, 10.680158236631264, 11.63135057178247, 12.699121239547356], [12.844924119842204, 11.866168226098376, 10.871463415999088, 9.916466866482788, 8.846886061214269, 7.787391824633173, 6.833108938025241, 5.816040388950008, 4.807005160449277, 3.9570372457911707, 2.967937414993643, 1.924336750822667, 0.9943570656016207, 2.00481862524362, 2.948174845893854, 3.957497840927215, 5.009284174257578, 5.938488347128949, 6.956956718917358, 7.914896664375464, 11.88059172679008, 10.923297892420067, 9.966962581284205, 8.976970610042484, 7.943632265651901, 6.870794025823008, 5.858360589581218, 4.8238529438157425, 3.8785517214715166, 2.917986393692393, 1.9855568126512657, 1.0527386788380049, 0.0, 1.0467748067329874, 2.093303713196187, 3.1059019886123895, 4.170294491233658, 5.136373331704347, 6.160107791758241, 7.2268367851215665, 12.854008082195968, 11.908280076369017, 10.904633899492948, 9.874142841903167, 8.819207890364684, 7.837550764284892, 6.814099105687425, 5.838670614461071, 4.86046034418007, 3.9357926186372354, 3.0121905354588336, 2.018146293481104, 1.0292606448930217, 2.0317362777934163, 3.0248536310624843, 4.039132373591367, 5.0865467304187035, 6.074147419480405, 7.073990610680293, 8.071138953059203, 13.822027389791053, 12.920629950839148, 11.87632451403424, 10.816725247653794, 9.76335693339816, 8.770183801183423, 7.813292688243747, 6.88705530949535, 5.871885341608218, 4.913704281477266, 4.029451152632721, 2.980292830356398, 2.0085249036318475, 3.0134919561338727, 4.087678936075733, 5.013721932043077, 5.944407311589682, 6.935895376234295, 7.86326753412488, 8.84192831594707, 14.69881998166615, 13.72856695951636, 12.79287169524263, 11.764260676494024, 10.72421246314976, 9.810158785567085, 8.765807647729085, 7.8362393889449695, 6.881248037150528, 5.928198891511754, 4.959016981709531, 3.93309594464175, 3.081145023240718, 3.9686492364376864, 4.934712779388626, 5.916438799822811, 6.881903035345185, 7.82876907560063, 8.864817274794882, 9.795561594248747, 15.637064556034042, 14.62322422567016, 13.641199923317593, 12.685306283005504, 11.663618654216814, 10.766253791661141, 9.718721056822098, 8.771680105736984, 7.80509228296854, 6.8623653340661175, 5.899958419441545, 4.965060385796899, 4.0301448410389, 4.928876486514146, 5.86214964735628, 6.8254197224287045, 7.829304230682814, 8.764607735618815, 9.708046444438557, 10.77486967002293, 16.592236836975854, 15.569183348711569, 14.569418357934453, 13.594692607335334, 12.605295286661747, 11.600077469263134, 10.674989517758435, 9.744681649635961, 8.749643399555499, 7.788748338500561, 6.956802552671336, 6.023635789554712, 4.976751385079997, 5.921832815681527, 6.85601896060713, 7.7797456789926835, 8.8093863146428, 9.6896265404985, 10.641971991128274, 11.595965319129846, 17.504198367943708, 16.46999562508531, 15.487128823038297, 14.524693527008768, 13.556067278862, 12.613606511521557, 11.677515907585565, 10.728623036979675, 9.7148606661201, 8.773715706680278, 7.904336549124496, 6.927562870793512, 5.9569552185601875, 6.9168109488048914, 7.782108370779269, 8.747573415058183, 9.772300365736152, 10.632644071340698, 11.576751765420624, 12.585503873548594, 17.413944471340827, 17.395196926604683, 16.41717300118781, 15.509585226531973, 14.558536403913669, 13.546205376269226, 12.66402623311476, 11.693781112059131, 10.706790171920861, 9.713738352857794, 8.788030987084264, 7.852540135045756, 6.918520512648333, 7.8737478438172275, 8.807982633770644, 9.767194460997512, 10.720645343336415, 11.599875598998004, 12.535443132917068, 13.569261596660603, 16.421433734830842, 17.37061697888139, 16.4966015264314, 15.552004839212024, 14.503321742258494, 13.635139810884596, 12.785474821451926, 12.121780942970524, 11.645920756584768, 10.703855053044718, 9.721232603248913, 8.876739579040535, 7.921486392300059, 8.897608868729744, 9.802203877207234, 10.724138692364853, 11.77439193812703, 12.566755835752966, 13.575664353464289, 14.560846111390225, 15.477296736470793, 16.456445522092217, 15.423807018441435, 14.590191999458934, 13.568031196373514, 12.633895247195579, 11.7210409367275, 11.077666263571368, 11.811556025745201, 11.691922180106829, 10.744138363419697, 9.884211231090735, 8.937249894399894, 9.883707179455259, 10.823079544646784, 11.700887018231597, 12.723537101246182, 13.577682626912702, 14.56757659670385, 15.488105550117321, 14.521245967290165, 15.429601600954502, 14.496090515283944, 13.542029148949506, 12.636689944320668, 11.70639679479034, 10.725015804751376, 10.104591706504953, 10.846689341193544, 11.785050538913511, 11.690088435873559, 10.873022043823022, 9.934957026282339, 10.855594661117937, 11.797220162052124, 12.694606365201606, 13.626520883457914, 14.586290659787316, 15.641928620300728, 16.447418772166362, 13.533126537832706, 14.503441404196364, 13.508662943422296, 12.560786699325282, 11.643545160953648, 10.699348274905878, 9.72515396193945, 9.035604924589345, 9.789522480730732, 10.750431762176907, 11.702977849180302, 11.809100940926001, 10.924984049285664, 11.820187071359443, 12.72395798403274, 13.672993709139945, 14.631012582378675, 15.572904632246432, 16.572462023006096, 17.4745723642545, 12.618029725023945, 13.52909359612048, 12.582923006504622, 11.585360181842445, 10.72892388779745, 9.776826064013052, 8.787003067043209, 7.992720499624901, 8.832409291554328, 9.865944147853654, 10.779237616989356, 11.806200331928096, 11.916012576028157, 12.849295154615545, 13.790035584893632, 14.676724479597338, 15.583886321116061, 16.55812530464843, 17.533181682655293, 17.537595487894126, 11.801929523765445, 12.674386310498464, 11.633007067077175, 10.625569535756654, 9.727143081811999, 8.761287957654217, 7.817612486075261, 7.053621663755721, 7.8950278140249655, 8.919568304036845, 9.835992602837281, 10.855395563462801, 11.527985823624089, 12.455186736677964, 13.474415632591272, 14.430921172863235, 15.439279835805902, 16.403541885423113, 17.385585130157693, 16.60149177895551, 10.820745160082929, 11.61975701388049, 10.68869028788091, 9.69803534654682, 8.737795740000823, 7.70802133980272, 6.791131155219061, 6.069771956900102, 6.951468841048786, 7.848663985702381, 8.7883002811648, 9.827985829998024, 10.586034731864823, 11.617745180135044, 12.532668654684723, 13.572391213448304, 14.537924839742812, 15.554213668719061, 16.621736998015738, 15.698164654496923, 9.876838497429159, 10.670331376181554, 9.71936404962148, 8.773410077108307, 7.7610963280620915, 6.776419484212242, 5.842315445181615, 5.011190263397655, 5.9196750131391225, 6.871583839948583, 7.7490646088338675, 8.790571092645298, 9.654680685872776, 10.586274794129665, 11.558877797307597, 12.624275313937426, 13.569485547850887, 14.626168884494097, 15.62735636903547, 14.721715067686285, 9.097908433002276, 9.670451149346613, 8.731165955133772, 7.803561133115016, 6.820865470610701, 5.837049882546705, 4.904307604575154, 4.027991378305065, 4.886433205999296, 5.849596438110979, 6.7923672061787705, 7.771358167107879, 8.719632373895342, 9.705269648573205, 10.712315904043841, 11.654267160430535, 12.641848008342228, 13.644456305559903, 14.630810065504642, 13.792660489090073, 8.183037913325935, 8.769207012499251, 7.80766973120585, 6.8570605955176545, 5.912252785778693, 4.838568486075719, 3.903237346915758, 2.9582234600334667, 3.888575562649552, 4.922992085265424, 5.901991336390975, 6.792486797863902, 7.768122963213837, 8.711938667881862, 9.6517237957433, 10.6513092616736, 11.661003732249897, 12.64074843128542, 13.6756144680424, 12.867523490318508, 8.797450745887897, 7.844082449055213, 6.83398669170774, 5.851869084736399, 4.915262652244537, 3.889423907753049, 2.9455648062265825, 1.9929633636088884, 2.875320271879412, 3.9049663582215963, 4.9112310224943645, 5.789799419999758, 6.720720679127519, 7.746986842713413, 8.698785494721637, 9.702334902819334, 10.715951766281863, 11.732896915469269, 12.684089250620474, 13.75185991838536], [13.891698926575192, 12.912943032831363, 11.918238222732073, 10.963241673215773, 9.893660867947254, 8.834166631366159, 7.879883744758228, 6.8628151956829955, 5.853779967182264, 5.003812052524158, 3.9812332150317946, 2.9376325508608185, 2.0076528656397725, 0.9971913059977732, 1.940547526648007, 2.949870521681368, 4.001656855011731, 4.930861027883102, 5.949329399671511, 6.907269345129617, 12.927366533523067, 11.970072699153054, 11.013737388017192, 10.023745416775471, 8.990407072384889, 7.917568832555995, 6.905135396314205, 5.87062775054873, 4.925326528204504, 3.9647612004253805, 3.0323316193842533, 2.0995134855709923, 1.0467748067329874, 0.0, 1.0465289064632, 2.0591271818794024, 3.123519684500671, 4.08959852497136, 5.113332985025254, 6.180061978388579, 13.900782888928955, 12.955054883102004, 11.951408706225935, 10.920917648636154, 9.865982697097671, 8.884325571017879, 7.860873912420412, 6.885445421194058, 5.907235150913058, 4.982567425370223, 4.058965342191821, 3.0649211002140913, 2.0345460320505184, 0.984961471060429, 1.978078824329497, 2.99235756685838, 4.039771923685716, 5.027372612747418, 6.027215803947306, 7.024364146326215, 14.86880219652404, 13.967404757572135, 12.923099320767227, 11.863500054386781, 10.810131740131148, 9.81695860791641, 8.860067494976734, 7.933830116228338, 6.918660148341205, 5.960479088210253, 5.076225959365708, 4.0270676370893845, 3.0133851091694455, 1.9667171494008855, 3.0409041293427452, 3.966947125310089, 4.897632504856694, 5.889120569501307, 6.816492727391892, 7.795153509214082, 15.745594788399137, 14.775341766249348, 13.839646501975617, 12.81103548322701, 11.770987269882747, 10.856933592300072, 9.812582454462072, 8.883014195677957, 7.928022843883515, 6.9749736982447414, 6.005791788442518, 4.979870751374737, 3.952543341609622, 2.9218744297046992, 3.8879379726556387, 4.869663993089824, 5.835128228612197, 6.781994268867642, 7.818042468061895, 8.74878678751576, 16.683839362767028, 15.669999032403148, 14.68797473005058, 13.732081089738491, 12.7103934609498, 11.793286430939867, 10.745753696100824, 9.769881563348292, 8.803293740579848, 7.8605667916774244, 6.898159877052852, 5.963261843408206, 4.894681283608291, 3.882101679781159, 4.815374840623293, 5.778644915695717, 6.782529423949827, 7.717832928885827, 8.661271637705568, 9.728094863289941, 17.63585019590808, 16.596215987990295, 15.596450997213179, 14.62172524661406, 13.632327925940473, 12.62711010854186, 11.702022157037161, 10.74288310724727, 9.747844857166807, 8.786949796111868, 7.82154603795198, 6.888379274835356, 5.822465204431059, 4.877383773829529, 5.809244153874142, 6.732970872259696, 7.762611507909813, 8.64285173376551, 9.595197184395285, 10.549190512396857, 17.345820398509524, 17.497028264364033, 16.514161462317023, 15.551726166287494, 14.583099918140727, 13.624018790095128, 12.687928186159137, 11.711844196972027, 10.698081826112452, 9.75693686667263, 8.750050368475558, 7.773276690144574, 6.802669037911249, 5.907053413394964, 6.7353335640462815, 7.700798608325195, 8.725525559003163, 9.585869264607709, 10.529976958687636, 11.538729066815606, 16.36716966460784, 17.38688647774416, 16.47010973851467, 15.499459335719942, 14.512594582892593, 13.674921213777283, 12.749954537644024, 12.568916131504263, 11.581925191365993, 10.588873372302928, 9.633744806435324, 8.698253954396817, 7.764234331999394, 6.8639903084073, 7.761207827037657, 8.720419654264525, 9.673870536603427, 10.553100792265015, 11.48866832618408, 12.522486789927614, 15.374658928097853, 16.3238421721484, 15.488974207185551, 14.54437751996618, 13.49569442301265, 12.62751249163875, 11.777847502206079, 12.725394049954769, 12.491634575935828, 11.549568872395778, 10.566946422599973, 9.722453398391595, 8.76720021165112, 7.935534801578612, 8.755429070474246, 9.677363885631866, 10.727617131394043, 11.519981029019977, 12.5288895467313, 13.514071304657236, 14.430521929737804, 15.448818202846368, 14.416179699195586, 13.582564680213085, 12.56040387712767, 11.626267927949733, 10.713413617481653, 11.681279370555613, 12.655500308212769, 12.537635999457889, 11.589852182770757, 10.729925050441794, 9.782963713750956, 8.921633112304127, 9.777251224974846, 10.65411221149861, 11.676762294513194, 12.530907820179713, 13.52080178997086, 14.441330743384333, 13.474471160557176, 14.382826794221513, 13.488463196038095, 12.534401829703658, 11.629062625074821, 10.698769475544495, 9.717388485505529, 10.731731102481064, 11.690633623661112, 12.62899482138108, 12.535802255224619, 11.718735863174082, 10.7806708456334, 9.893520593966805, 10.773149545184754, 11.647831558468619, 12.579746076724927, 13.539515853054327, 14.59515381356774, 15.400643965433375, 12.486351731099717, 13.456666597463375, 12.501035624176447, 11.553159380079434, 10.635917841707801, 9.691720955660031, 8.717526642693603, 9.677075237214341, 10.6334667631983, 11.594376044644475, 12.54692213164787, 12.65481476027706, 11.770697868636725, 10.858113004208311, 11.69988736716537, 12.648923092272575, 13.606941965511306, 14.526129825513443, 15.525687216273107, 16.42779755752151, 11.571254918290956, 12.521466276874632, 11.575295687258773, 10.577732862596596, 9.721296568551601, 8.769198744767206, 7.779375747797362, 8.722441844862075, 9.679000526948279, 10.712535383247605, 11.642386396464705, 12.669349111403445, 12.761726395379219, 11.887221087464413, 12.765964968026262, 13.652653862729968, 14.559815704248692, 15.51135049791544, 16.486406875922306, 17.475631594689247, 10.755154717032456, 11.666758991252618, 10.625379747831328, 9.617942216510805, 8.71951576256615, 7.75366063840837, 6.8099851668294145, 7.783343008992896, 8.741619049418917, 9.768979811827524, 10.810343373333415, 11.829746333958935, 12.502336594120223, 12.887270953684327, 13.777280980744294, 14.616410266907433, 15.62361561666116, 16.53519358465166, 17.45609228174727, 17.648266585688496, 9.773970353349942, 10.612129694634643, 9.681062968635063, 8.690408027300972, 7.730168420754976, 6.700394020556873, 5.783503835973214, 6.830282872831009, 7.798060076442737, 8.723763830330318, 9.762651051660933, 10.802336600494158, 11.560385502360957, 12.592095950631178, 13.507019425180857, 14.546741983944438, 15.512275610238946, 16.528564439215195, 17.59608776851187, 16.74493946122991, 8.83006369069617, 9.662704056935707, 8.711736730375634, 7.7657827578624605, 6.753469008816245, 5.768792164966395, 4.834688125935768, 5.793872357152984, 6.766266248533073, 7.746683684576521, 8.723415379330001, 9.764921863141431, 10.62903145636891, 11.560625564625798, 12.53322856780373, 13.59862608443356, 14.54383631834702, 15.600519654990231, 16.601707139531605, 15.768489874419272, 8.051133626269289, 8.662823830100766, 7.723538635887925, 6.795933813869169, 5.813238151364854, 4.8294225633008585, 3.8966802853293068, 4.865822148682116, 5.86078397649543, 6.8239472086071125, 7.766717976674904, 8.745708937604013, 9.693983144391476, 10.67962041906934, 11.734475884406747, 12.701041967163523, 13.688622815075215, 14.69123111229289, 15.67758487223763, 14.83943529582306, 7.136263106592947, 7.761579693253405, 6.800042411960005, 5.849433276271808, 4.904625466532847, 3.8309411668298723, 2.8956100276699113, 3.8651012775978026, 4.862926333145686, 5.897342855761558, 6.876342106887109, 7.8023738337874375, 8.814897769946823, 9.758713474614849, 10.698498602476286, 11.698084068406587, 12.707778538982884, 13.687523238018407, 14.722389274775388, 13.914298297051495, 7.789823426642049, 6.836455129809366, 5.826359372461893, 4.844241765490552, 3.90763533299869, 2.881796588507202, 1.9379374869807355, 2.9642979418836823, 3.8886160719175638, 4.918262158259748, 5.924526822532516, 6.836574226732745, 7.767495485860506, 8.7937616494464, 9.745560301454624, 10.749109709552322, 11.76272657301485, 12.779671722202256, 13.730864057353461, 14.798634725118347], [14.938227833038392, 13.959471939294563, 12.964767129195273, 12.009770579678973, 10.940189774410454, 9.880695537829359, 8.926412651221428, 7.909344102146195, 6.900308873645464, 6.018116618397627, 4.975053670625696, 3.93145300645472, 3.001473321233674, 1.991011761591675, 1.0476555409414412, 2.0187016480889284, 3.0704879814192916, 3.9996921542906625, 5.01816052607907, 5.976100471537176, 13.973895439986267, 13.016601605616254, 12.060266294480392, 11.070274323238671, 10.036935978848089, 8.964097739019195, 7.951664302777405, 6.91715665701193, 5.971855434667704, 5.0112901068885805, 4.078860525847453, 3.1460423920341922, 2.093303713196187, 1.0465289064632, 0.0, 1.0125982754162022, 2.0769907780374712, 3.0430696185081603, 4.066804078562054, 5.133533071925379, 14.947311795392155, 14.001583789565204, 12.997937612689135, 11.967446555099354, 10.912511603560871, 9.930854477481079, 8.907402818883611, 7.931974327657258, 6.953764057376258, 6.029096331833423, 5.105494248655021, 4.104908497622205, 3.067785193175283, 2.0182006321851937, 1.0250832789161257, 1.9519968638513814, 2.9994112206787182, 3.9870119097404197, 4.986855100940308, 5.984003443319217, 15.91533110298724, 15.013933664035333, 13.969628227230425, 12.91002896084998, 11.856660646594346, 10.863487514379608, 9.906596401439932, 8.980359022691538, 7.965189054804405, 7.007007994673453, 6.116213356773821, 5.067055034497498, 4.04662427029421, 2.99995631052565, 2.0888974688358335, 3.0070205569141923, 3.936682315555089, 4.928170380199702, 5.855542538090287, 6.8342033199124765, 16.792123694862337, 15.821870672712546, 14.886175408438815, 13.857564389690209, 12.817516176345945, 11.90346249876327, 10.859111360925272, 9.929543102141157, 8.974551750346714, 8.02150260470794, 7.045779185850631, 6.013180132979841, 4.985782502734387, 3.955113590829464, 3.1399253381467487, 3.9636542570007656, 4.874178039310592, 5.821044079566037, 6.857092278760289, 7.787836598214154, 17.730368269230226, 16.716527938866346, 15.734503636513779, 14.77860999620169, 13.756922367412999, 12.826525592064632, 11.778992857225589, 10.803120724473057, 9.836532901704613, 8.89380595280219, 7.931399038177617, 6.996501004532971, 5.927920444733056, 4.915340840905924, 4.067362206114403, 5.030632281186827, 5.906930107452245, 6.756882739584222, 7.7003214484039635, 8.767144673988337, 17.369424423226622, 17.62945514911506, 16.629690158337944, 15.654964407738825, 14.665567087065238, 13.660349269666625, 12.735261318161927, 11.776122268372035, 10.781084018291573, 9.820188957236633, 8.854785199076744, 7.921618435960121, 6.855704365555824, 5.9106229349542945, 5.061231519365252, 5.984958237750806, 6.890806785009633, 7.681901544463907, 8.634246995093681, 9.588240323095253, 16.38487020920792, 17.396615558433584, 16.518121997417815, 15.602319115996782, 14.670118636603112, 13.73071248466318, 13.721167347283902, 12.745083358096792, 11.731320987237217, 10.790176027797395, 9.783289529600323, 8.806515851269339, 7.835908199036014, 6.940292574519729, 5.9873209295373915, 6.9527859738163045, 7.853720836102983, 8.624919075306105, 9.569026769386031, 10.577778877514001, 15.406219475306237, 16.425936288442557, 15.588077819268303, 14.617427416473577, 13.63578698903082, 12.79811361991551, 13.743774993237926, 13.602155292629028, 12.615164352490758, 11.622112533427693, 10.666983967560089, 9.731493115521582, 8.797473493124158, 7.897229469532065, 7.013195192528766, 7.972407019755634, 8.830812941113166, 9.592150602963411, 10.527718136882475, 11.56153660062601, 14.413708738796249, 15.362891982846795, 14.596082221478985, 13.662345600719814, 12.618886829150876, 11.750704897776977, 12.77166795779998, 13.71921450554867, 13.524873737060593, 12.582808033520543, 11.600185583724738, 10.75569255951636, 9.800439372775884, 8.968773962703377, 8.007416435965355, 8.929351251122977, 9.890559028245002, 10.559030839718373, 11.567939357429696, 12.553121115355632, 13.4695717404362, 14.495741794830737, 13.52328771348902, 12.68967269450652, 11.683596283265896, 10.74946033408796, 11.707234073075554, 12.675099826149514, 13.64932076380667, 13.570875160582654, 12.623091343895522, 11.76316421156656, 10.816202874875719, 9.954872273428892, 9.029238590465955, 9.906099576989721, 10.839704191364154, 11.56995763087811, 12.559851600669257, 13.480380554082728, 12.513520971255572, 13.421876604919909, 12.59557121033153, 11.641509843997092, 10.752255031213048, 9.821961881682721, 10.71120894109943, 11.725551558074965, 12.684454079255014, 13.62281527697498, 13.569041416349384, 12.751975024298847, 11.813910006758164, 10.92675975509157, 10.025136910675863, 10.89981892395973, 11.831733442216038, 12.578565663752723, 13.634203624266135, 14.43969377613177, 11.525401541798113, 12.49571640816177, 11.608143638469882, 10.660267394372868, 9.759110247846028, 8.814913361798258, 9.711347098287504, 10.670895692808243, 11.627287218792201, 12.588196500238377, 13.540742587241771, 13.688053921401826, 12.803937029761489, 11.891352165333076, 10.95187473265648, 11.900910457763684, 12.858929331002415, 13.56517963621184, 14.564737026971503, 15.466847368219907, 10.610304728989352, 11.628574291168066, 10.682403701552207, 9.68484087689003, 8.828404582845035, 7.876476683665205, 8.773196203391263, 9.716262300455977, 10.67282098254218, 11.706355838841507, 12.636206852058606, 13.663169566997347, 13.794965556503982, 12.920460248589178, 12.017952333517371, 12.904641228221077, 13.811803069739803, 14.550400308613836, 15.5254566866207, 16.514681405387645, 9.794204527730852, 10.773867005546052, 9.732487762124762, 8.72505023080424, 7.826623776859585, 6.860768652701804, 7.803805622423316, 8.777163464586797, 9.735439505012817, 10.762800267421426, 11.804163828927317, 12.823566789552837, 13.496157049714125, 13.920510114809092, 13.029268346235401, 13.868397632398542, 14.875602982152271, 15.574243395350056, 16.495142092445665, 17.450785114326262, 8.813020164048336, 9.719237708928077, 8.788170982928497, 7.797516041594407, 6.83727643504841, 5.807502034850307, 6.7773242915671155, 7.82410332842491, 8.791880532036638, 9.71758428592422, 10.756471507254835, 11.79615705608806, 12.554205957954858, 13.58591640622508, 13.97101532414195, 14.905364068722424, 15.890174615088352, 16.644650258037995, 17.466485148906695, 17.79146836769311, 7.869113501394565, 8.769812071229142, 7.818844744669068, 6.872890772155895, 5.860577023109679, 4.875900179259829, 5.82850858152967, 6.787692812746886, 7.760086704126975, 8.740504140170422, 9.717235834923903, 10.758742318735333, 11.622851911962812, 12.5544460202197, 13.527049023397632, 14.592446540027462, 15.537656773940922, 16.59434011058413, 17.595527595125503, 16.815018780882472, 7.010772923262291, 7.7699318443942, 6.830646650181359, 5.903041828162603, 4.920346165658288, 3.9365305775942927, 4.890500740923208, 5.859642604276018, 6.854604432089332, 7.817767664201014, 8.760538432268806, 9.739529393197914, 10.687803599985378, 11.67344087466324, 12.728296340000648, 13.70212115975398, 14.689702007665673, 15.692310304883348, 16.678664064828087, 15.88596420228626, 6.089734200129747, 6.844332706775879, 5.882795425482479, 4.9321862897942825, 4.0117334808262815, 2.9380491811233065, 3.889430483263813, 4.858921733191704, 5.856746788739588, 6.891163311355459, 7.870162562481011, 8.796194289381338, 9.815976962537281, 10.759792667205307, 11.699577795066745, 12.699163260997045, 13.708857731573342, 14.688602430608865, 15.723468467365846, 14.960827203514695, 6.858654553049609, 5.905286256216926, 4.895190498869454, 3.9130728918981124, 2.97646645940625, 1.9889046028006363, 2.931757942574637, 3.958118397477584, 4.882436527511465, 5.912082613853649, 6.918347278126417, 7.883103133195945, 8.814024392323706, 9.8402905559096, 10.792089207917824, 11.795638616015522, 12.80925547947805, 13.826200628665458, 14.777392963816663, 15.84516363158155], [15.950826108454596, 14.972070214710767, 13.977365404611474, 13.022368855095174, 11.952788049826655, 10.89329381324556, 9.939010926637629, 8.921942377562397, 7.912907149061667, 6.985887445162273, 5.942824497390343, 4.8992238332193665, 3.96924414799832, 2.958782588356321, 2.015426367706087, 1.0061033726727262, 2.057889706003089, 2.98709387887446, 4.005562250662868, 4.963502196120974, 14.98649371540247, 14.029199881032458, 13.072864569896597, 12.082872598654875, 11.049534254264293, 9.976696014435399, 8.964262578193608, 7.929754932428132, 6.984453710083907, 6.023888382304783, 5.091458801263656, 4.158640667450395, 3.1059019886123895, 2.0591271818794024, 1.0125982754162022, 0.0, 1.064392502621269, 2.030471343091958, 3.0542058031458517, 4.120934796509177, 15.959910070808357, 15.014182064981407, 14.010535888105338, 12.980044830515556, 11.925109878977073, 10.943452752897281, 9.920001094299813, 8.94457260307346, 7.96636233279246, 7.0277373399025125, 6.0933690304516315, 5.033502549670141, 3.9963792452232196, 2.9467946842331303, 1.953677330964062, 0.9393985884351792, 1.986812945262516, 2.9744136343242173, 3.9742568255241055, 4.971405167903015, 16.92792937840344, 16.026531939451534, 14.982226502646627, 13.922627236266182, 12.869258922010548, 11.87608578979581, 10.919194676856135, 9.99295729810774, 8.963830062873495, 8.005649002742542, 7.044807408821757, 5.995649086545434, 4.975218322342147, 3.9285503625735867, 2.9204652774653344, 1.9944222814979902, 2.9240840401388866, 3.9155721047834993, 4.842944262674084, 5.821605044496274, 17.80472197027854, 16.834468948128748, 15.898773683855017, 14.870162665106411, 13.830114451762148, 12.916060774179472, 11.871709636341475, 10.942141377557359, 9.973192758415804, 9.00695132198651, 7.9743732378985674, 6.941774185027777, 5.914376554782323, 4.8837076428774004, 3.932782002018749, 2.9510559815845636, 3.86157976389439, 4.808445804149835, 5.844494003344087, 6.775238322797952, 17.311998428752233, 17.704988864646534, 16.722964562293967, 15.76707092198188, 14.74538329319319, 13.720496260093372, 12.672963525254328, 11.697091392501797, 10.730503569733353, 9.787776620830929, 8.825369706206356, 7.890471672561708, 6.821891112761794, 5.809311508934662, 4.8602188699864035, 4.0242259756776155, 4.894331832036043, 5.74428446416802, 6.687723172987761, 7.754546398572136, 16.35682614781042, 17.340655268784488, 16.67108527272142, 15.851545835654683, 15.124935882268, 14.554319937695364, 13.629231986190666, 12.670092936400774, 11.675054686320312, 10.714159625265372, 9.748755867105483, 8.81558910398886, 7.749675033584562, 6.804593602983032, 5.854088183237253, 4.9785519322415945, 5.87820850959343, 6.669303269047704, 7.621648719677478, 8.57564204767905, 15.372271933791719, 16.384017283017382, 15.720710729501372, 14.804907848080337, 14.174163890067746, 14.698483311427825, 14.586306432146904, 13.610222442959794, 12.596460072100218, 11.655315112660396, 10.648428614463324, 9.67165493613234, 8.701047283899015, 7.741191553654311, 6.780177593409392, 5.9463796683070935, 6.841122560686781, 7.612320799889902, 8.556428493969829, 9.565180602097799, 14.393621199890035, 15.413338013026355, 14.790666551351858, 13.820016148557132, 13.139832242495453, 13.765884446680156, 14.71154582000257, 14.467294377492031, 13.480303437353761, 12.487251618290696, 11.532123052423092, 10.596632200384585, 9.662612577987161, 8.698128448666647, 7.806051856400767, 6.966060584429482, 7.8182146656969636, 8.579552327547209, 9.515119861466273, 10.548938325209807, 13.401110463380046, 14.350293707430593, 13.798670953562539, 12.864934332803369, 12.12293208261551, 12.718475724541623, 13.739438784564625, 14.686985332313315, 14.390012821923596, 13.447947118383546, 12.46532466858774, 11.620831644379363, 10.665578457638887, 9.76967294183796, 8.800273099837357, 7.9230048157968245, 8.8779607528288, 9.54643256430217, 10.555341082013493, 11.54052283993943, 12.456973465019997, 13.483143519414535, 12.725876445572574, 11.892261426590075, 11.18764153673053, 11.717231160852606, 12.675004899840198, 13.642870652914159, 14.617091590571315, 14.436014245445657, 13.488230428758525, 12.628303296429563, 11.681341959738722, 10.755771252563475, 9.822095254337956, 8.899753141663567, 9.827105915947952, 10.557359355461907, 11.547253325253054, 12.467782278666526, 11.50092269583937, 12.409278329503707, 11.798159942415083, 10.844098576080645, 10.21989377151829, 10.789732708447367, 11.678979767864075, 12.69332238483961, 13.652224906019658, 14.590586103739625, 14.434180501212387, 13.61711410916185, 12.679049091621167, 11.727658734226154, 10.817993574547865, 9.893472488633575, 10.820975716860998, 11.56596738833652, 12.621605348849933, 13.427095500715568, 10.51280326638191, 11.483118132745568, 10.810732370553435, 9.862856126456421, 9.22674898815127, 9.782684188562904, 10.679117925052148, 11.638666519572887, 12.595058045556845, 13.555967327003021, 14.508513414006416, 14.553193006264829, 13.669076114624492, 12.69225114446766, 11.744731396528481, 10.961111964218395, 11.856283133190441, 12.552581360795637, 13.552138751555301, 14.454249092803705, 9.59770645357315, 10.658942301107219, 9.867242616843447, 8.887429608973584, 8.203644459695923, 8.84424751042985, 9.740967030155907, 10.684033127220621, 11.640591809306827, 12.674126665606153, 13.603977678823252, 14.630940393761993, 14.660104641366985, 13.721359227723761, 12.810808997389373, 11.964842734675788, 12.80915687192783, 13.537802033197634, 14.512858411204498, 15.50208312997144, 8.78160625231465, 9.83155770562695, 8.85514132451047, 7.927638962887793, 7.201863653710471, 7.82853947946645, 8.771576449187961, 9.744934291351441, 10.703210331777463, 11.730571094186072, 12.771934655691963, 13.791337616317483, 14.46392787647877, 14.721409093943675, 13.822125010107403, 12.928599138853253, 13.872956784340298, 14.561645119933853, 15.482543817029464, 16.438186838910056, 7.800421888632133, 8.776412135574535, 7.910824545314203, 7.00010477367796, 6.162217978602191, 6.775272861614953, 7.745095118331761, 8.791874155189557, 9.759651358801284, 10.685355112688866, 11.72424233401948, 12.763927882852705, 13.521976784719504, 14.553687232989725, 14.763871988013952, 13.965565575177134, 14.887528417276378, 15.632051982621794, 16.453886873490497, 17.38340036814757, 6.856515225978362, 7.836509375938652, 6.941498307054775, 5.997456207137632, 5.123682596301047, 5.843671006024475, 6.796279408294316, 7.7554636395115315, 8.72785753089162, 9.708274966935068, 10.685006661688549, 11.726513145499979, 12.590622738727458, 13.522216846984346, 14.494819850162278, 15.005957204963382, 15.855967709168304, 16.56009676684676, 17.451432040026994, 17.827617056298674, 5.9981746478460884, 6.809354129233722, 5.870068935020882, 4.942464113002126, 4.07258582394291, 4.904301404358939, 5.858271567687854, 6.827413431040664, 7.822375258853977, 8.78553849096566, 9.728309259033452, 10.70730021996256, 11.655574426750023, 12.641211701427887, 13.696067166765294, 14.669891986518628, 15.65747283443032, 16.660081131647996, 17.646434891592733, 16.898562477702463, 5.077135924713545, 5.831734431359677, 4.870197150066277, 3.91958801437808, 3.011967839696278, 3.9058200078879524, 4.857201310028459, 5.82669255995635, 6.8245176155042335, 7.858934138120105, 8.837933389245658, 9.763965116145986, 10.783747789301929, 11.727563493969955, 12.667348621831392, 13.666934087761692, 14.67662855833799, 15.656373257373513, 16.691239294130494, 15.9734254789309, 5.846056277633407, 4.892687980800724, 3.8825922234532513, 2.90047461648191, 1.9638681839900478, 2.956675429565282, 3.899528769339283, 4.92588922424223, 5.850207354276112, 6.879853440618295, 7.886118104891064, 8.890449292068727, 9.821370551196487, 10.847636714782382, 11.799435366790606, 12.802984774888303, 13.816601638350832, 14.83354678753824, 15.784739122689444, 16.85250979045433], [17.015218611075863, 16.036462717332032, 15.041757907232743, 14.086761357716442, 13.017180552447924, 11.957686315866829, 11.003403429258897, 9.986334880183666, 8.977299651682936, 8.050279947783544, 7.007217000011613, 5.963616335840636, 5.03363665061959, 4.02317509097759, 3.0798188703273564, 2.0704958752939953, 1.0366998108283523, 1.9659039836997234, 2.9843723554881314, 3.942312300946238, 16.050886218023738, 15.093592383653725, 14.137257072517864, 13.147265101276142, 12.11392675688556, 11.041088517056666, 10.028655080814875, 8.9941474350494, 8.048846212705175, 7.088280884926052, 6.1558513038849245, 5.2230331700716635, 4.170294491233658, 3.123519684500671, 2.0769907780374712, 1.064392502621269, 0.0, 0.9660788404706888, 1.9898133005245824, 3.056542293887908, 17.024302573429626, 16.078574567602676, 15.074928390726607, 14.044437333136825, 12.989502381598342, 12.00784525551855, 10.984393596921082, 10.00896510569473, 9.03075483541373, 8.092129842523782, 7.1577615330729, 6.09789505229141, 5.0607717478444885, 4.011187186854399, 3.018069833585331, 2.0037910910564483, 0.9712736246426826, 1.958874313704384, 2.958717504904272, 3.9558658472831816, 17.99232188102471, 17.090924442072804, 16.046619005267896, 14.98701973888745, 13.933651424631817, 12.94047829241708, 11.983587179477404, 11.024333834486907, 9.986041147891518, 9.027860087760565, 7.984102509298852, 6.934944187022529, 5.886128034743423, 4.839460074974863, 3.7652730950330024, 2.8392300990656585, 1.9085447195190532, 2.900032784163666, 3.827404942054251, 4.806065723876441, 17.280807862003776, 17.89886145075002, 16.963166186476286, 15.93455516772768, 14.894506954383417, 13.955567368353927, 12.884639654759662, 11.955071395975546, 10.944404918634687, 9.891455533081546, 8.858877448993605, 7.801719904687733, 6.774322274442279, 5.743653362537357, 4.777589819586417, 3.7958637991522317, 2.8460404432745565, 3.7929064835300013, 4.8289546827242535, 5.7596990021781185, 16.2964591081324, 17.31029943849628, 16.79782257437396, 15.972088544253314, 15.590191110760856, 14.565304077661038, 13.517771342821995, 12.541899210069463, 11.575311387301019, 10.632584438398595, 9.670177523774022, 8.735279490129376, 7.666698930329462, 6.65411932650233, 5.705026687554072, 4.869033793245284, 3.8787925114162096, 4.728745143548187, 5.672183852367928, 6.739007077952302, 15.341286827190586, 16.325115948164655, 15.802622828003729, 14.98308339093699, 15.855843643709665, 15.39912775526303, 14.474039803758332, 13.51490075396844, 12.519862503887978, 11.558967442833039, 10.59356368467315, 9.660396921556526, 8.594482851152229, 7.6494014205507, 6.698896000804921, 5.823359749809263, 4.862669188973597, 5.653763948427871, 6.606109399057645, 7.560102727059217, 14.356732613171886, 15.368477962397547, 14.852248284783679, 13.936445403362644, 14.905071651509411, 15.762875814049092, 15.43111424971457, 14.45503026052746, 13.441267889667884, 12.500122930228063, 11.49323643203099, 10.516462753700006, 9.545855101466682, 8.585999371221979, 7.62498541097706, 6.791187485874762, 5.825583240066948, 6.596781479270069, 7.540889173349996, 8.549641281477966, 13.378081879270201, 14.397798692406521, 13.922204106634165, 12.951553703839439, 13.900581162078131, 14.830276949301423, 15.77593832262384, 15.312102195059698, 14.325111254921428, 13.332059435858362, 12.376930869990758, 11.441440017952251, 10.507420395554828, 9.542936266234314, 8.650859673968435, 7.756126227416033, 6.80267534507713, 7.564013006927375, 8.49958054084644, 9.533399004589974, 12.385571142760213, 13.33475438681076, 12.930208508844846, 11.996471888085676, 12.883681002198188, 13.78286822716289, 14.803831287185895, 15.751377834934585, 15.234820639491263, 14.292754935951212, 13.310132486155407, 12.46563946194703, 11.510386275206553, 10.614480759405627, 9.645080917405025, 8.713070458783374, 7.862421432208966, 8.530893243682337, 9.53980176139366, 10.524983519319596, 11.441434144400164, 12.467604198794701, 11.857414000854881, 11.023798981872382, 11.948390456313208, 12.781623663473873, 13.739397402461469, 14.70726315553543, 15.681484093192585, 15.280822063013323, 14.333038246326192, 13.473111113997229, 12.526149777306388, 11.600579070131142, 10.666903071905624, 9.689818784650118, 8.811566595328117, 9.541820034842074, 10.531714004633221, 11.452242958046693, 10.485383375219536, 11.393739008883873, 10.92969749769739, 9.975636131362952, 10.980642691100968, 11.854125211068634, 12.743372270485345, 13.75771488746088, 14.716617408640928, 15.654978606360896, 15.278988318780053, 14.461921926729516, 13.523856909188833, 12.57246655179382, 11.662801392115533, 10.683538131620127, 9.805436396241163, 10.550428067716688, 11.6060660282301, 12.411556180095735, 9.497263945762077, 10.467578812125735, 9.942269925835742, 8.994393681738728, 10.036894434094247, 10.847076691184173, 11.743510427673419, 12.703059022194157, 13.659450548178116, 14.620359829624292, 15.572905916627686, 15.398000823832495, 14.513883932192158, 13.537058962035326, 12.589539214096149, 11.751177607204946, 10.840743812570606, 11.537042040175804, 12.536599430935468, 13.438709772183872, 8.582167132953316, 9.643402980487386, 8.998780172125754, 8.01896716425589, 9.0137899056389, 9.90864001305112, 10.805359532777178, 11.748425629841892, 12.704984311928094, 13.73851916822742, 14.66837018144452, 15.69533289638326, 15.504912458934651, 14.566167045291428, 13.65561681495704, 12.754908377662339, 11.793617551307992, 12.5222627125778, 13.497319090584664, 14.486543809351607, 7.766066931694817, 8.816018385007117, 7.986678879792777, 7.0591765181701, 8.055539137403082, 8.892931982087719, 9.835968951809232, 10.809326793972712, 11.767602834398732, 12.794963596807339, 13.836327158313232, 14.855730118938752, 15.52832037910004, 15.566216911511342, 14.666932827675073, 13.718664781839804, 12.857417463720461, 13.54610579931402, 14.467004496409631, 15.422647518290225, 6.7848825680123, 7.760872814954702, 7.0423621005965105, 6.131642328960267, 7.091881935506264, 7.839665364236222, 8.809487620953032, 9.856266657810828, 10.824043861422552, 11.749747615310135, 12.78863483664075, 13.828320385473974, 14.586369287340773, 15.618079735610994, 15.608679805581621, 14.755631218163686, 13.871989096656542, 14.616512662001961, 15.438347552870662, 16.36786104752774, 5.840975905358529, 6.855114328479463, 6.073035862337082, 5.128993762419939, 6.1076481360041175, 6.9080635086457445, 7.860671910915586, 8.819856142132801, 9.79225003351289, 10.772667469556337, 11.749399164309818, 12.790905648121248, 13.655015241348726, 14.586609349605615, 15.559212352783547, 15.785638622461928, 14.840428388548467, 15.544557446226925, 16.43589271940716, 17.344310634338377, 4.982635327226255, 5.940891684516029, 5.001606490303189, 4.074001668284433, 5.05655136364598, 5.968693906980208, 6.922664070309124, 7.891805933661933, 8.886767761475248, 9.849930993586929, 10.79270176165472, 11.771692722583829, 12.719966929371292, 13.705604204049155, 14.760459669386563, 15.734284489139897, 15.798844431698935, 16.607018269084215, 17.44516116537516, 17.962954980323733, 4.012743422092276, 4.963271986641984, 4.001734705348584, 3.051125569660387, 3.995933379399348, 4.970212510509222, 5.9215938126497285, 6.89108506257762, 7.888910118125503, 8.923326640741374, 9.902325891866926, 10.828357618767255, 11.848140291923198, 12.791955996591224, 13.731741124452661, 14.731326590382961, 15.741021060959259, 16.72076575999478, 17.75563179675176, 17.037817981552166, 4.926584526452769, 4.011162880273345, 3.0090002558525515, 2.032012171764217, 2.968618604256079, 4.0210679321865515, 4.963921271960553, 5.9902817268635, 6.914599856897381, 7.944245943239565, 8.950510607512333, 9.954841794689996, 10.885763053817756, 11.912029217403651, 12.863827869411875, 13.867377277509572, 14.880994140972101, 15.897939290159506, 16.84913162531071, 17.916902293075598], [17.981297451546553, 17.002541557802722, 16.00783674770343, 15.05284019818713, 13.983259392918612, 12.923765156337517, 11.969482269729586, 10.952413720654354, 9.943378492153624, 9.016358788254232, 7.973295840482301, 6.929695176311324, 5.999715491090278, 4.989253931448278, 4.0458977107980445, 3.036574715764684, 1.9868621549717815, 1.0576579821004106, 2.0732353249381887, 3.031175270396295, 17.016965058494428, 16.059671224124415, 15.103335912988554, 14.113343941746832, 13.08000559735625, 12.007167357527356, 10.994733921285565, 9.960226275520089, 9.014925053175864, 8.05435972539674, 7.121930144355614, 6.1891120105423525, 5.136373331704347, 4.08959852497136, 3.0430696185081603, 2.030471343091958, 0.9660788404706888, 0.0, 1.0237344600538936, 2.090463453417219, 17.990381413900316, 17.044653408073366, 16.041007231197295, 15.010516173607513, 13.95558122206903, 12.973924095989238, 11.95047243739177, 10.975043946165417, 9.996833675884417, 9.058208682994469, 8.123840373543588, 7.063973892762099, 6.0268505883151775, 4.977266027325088, 3.98414867405602, 2.9698699315271373, 1.9373524651133716, 1.0675178281678293, 2.0624024680014528, 3.0386998677341452, 17.598872447053196, 18.057003282543494, 17.012697845738586, 15.953098579358139, 14.899730265102505, 13.906557132887768, 12.949666019948092, 11.990412674957597, 10.952119988362208, 9.993938928231255, 8.95018134976954, 7.901023027493217, 6.852206875214111, 5.805538915445551, 4.7313519355036915, 3.8053089395363475, 2.8746235599897423, 2.10537236064149, 3.0278946492238363, 4.006555431046026, 16.66743676512909, 17.63768978727888, 16.97390429709569, 16.900634008198367, 15.860585794854105, 14.921646208824617, 13.850718495230351, 12.921150236446236, 11.910483759105377, 10.857534373552236, 9.824956289464295, 8.767798745158423, 7.740401114912968, 6.709732203008046, 5.743668660057106, 4.761942639622921, 3.8121192837452456, 3.179535386655317, 4.041037426177283, 4.971781745631148, 15.683088011257713, 16.696928341621593, 16.0341560053156, 16.922250888396743, 16.556269951231545, 15.531382918131726, 14.483850183292683, 13.507978050540151, 12.541390227771707, 11.598663278869283, 10.63625636424471, 9.701358330600064, 8.63277777080015, 7.620198166973019, 6.671105528024761, 5.8351126337159736, 4.844871351886899, 4.1153740466735025, 5.003872464673706, 5.969224303308548, 14.727915730315901, 15.711744851289968, 15.038956258945372, 15.933245735080419, 16.806005987853094, 16.36520659573372, 15.44011864422902, 14.48097959443913, 13.485941344358666, 12.525046283303727, 11.55964252514384, 10.626475762027216, 9.560561691622919, 8.61548026102139, 7.66497484127561, 6.789438590279953, 5.828748029444286, 5.040392851553186, 5.99273830218296, 6.946731630184532, 13.7433615162972, 14.75510686552286, 14.088581715725322, 14.886607747506073, 15.85523399565284, 16.728954654519782, 16.39719309018526, 15.42110910099815, 14.407346730138574, 13.466201770698753, 12.45931527250168, 11.482541594170696, 10.511933941937372, 9.552078211692669, 8.591064251447749, 7.7572663263454515, 6.791662080537637, 5.983410382395384, 6.927518076475311, 7.93627018460328, 12.764710782395516, 13.784427595531834, 13.158537537575809, 13.901716047982868, 14.85074350622156, 15.796355789772113, 16.74201716309453, 16.278181035530388, 15.291190095392118, 14.298138276329052, 13.343009710461448, 12.407518858422941, 11.473499236025518, 10.509015106705004, 9.616938514439124, 8.722205067886721, 7.768754185547819, 6.95064191005269, 7.886209443971754, 8.920027907715287, 11.772200045885526, 12.721383289936073, 12.145575255175117, 12.946634232229105, 13.833843346341617, 14.74894706763358, 15.769910127656585, 16.717456675405277, 16.200899479961954, 15.258833776421902, 14.276211326626097, 13.43171830241772, 12.476465115677243, 11.580559599876317, 10.611159757875713, 9.679149299254064, 8.828500272679655, 7.917522146807651, 8.926430664518975, 9.911612422444911, 10.828063047525477, 11.854233101920016, 11.072780747185153, 11.97396132601581, 12.898552800456637, 13.747702503944563, 14.705476242932159, 15.673341996006119, 16.647562933663274, 16.246900903484015, 15.299117086796882, 14.439189954467919, 13.492228617777078, 12.566657910601831, 11.632981912376312, 10.655897625120808, 9.777645435798807, 8.928448937967387, 9.918342907758534, 10.838871861172008, 9.87201227834485, 10.780367912009188, 10.145064244027662, 10.925798475506381, 11.930805035244397, 12.820204051539324, 13.709451110956035, 14.72379372793157, 15.682696249111618, 16.621057446831585, 16.245067159250745, 15.428000767200206, 14.489935749659523, 13.53854539226451, 12.628880232586221, 11.649616972090817, 10.771515236711853, 9.937056970842, 10.992694931355413, 11.79818508322105, 8.883892848887392, 9.85420771525105, 9.157636672166014, 9.944556025882157, 10.987056778237676, 11.81315553165486, 12.709589268144109, 13.669137862664847, 14.625529388648806, 15.586438670094982, 16.538984757098376, 16.364079664303187, 15.479962772662848, 14.503137802506016, 13.555618054566837, 12.717256447675636, 11.806822653041296, 10.923670943301117, 11.92322833406078, 12.825338675309187, 7.9501100442686665, 9.011345891802737, 8.205065943225714, 8.96912950839932, 9.963952249782329, 10.874718853521808, 11.771438373247868, 12.714504470312582, 13.671063152398784, 14.70459800869811, 15.63444902191521, 16.66141173685395, 16.47099129940534, 15.532245885762118, 14.621695655427729, 13.720987218133029, 12.759696391778682, 11.908891615703114, 12.883947993709977, 13.873172712476922, 6.996284157051062, 7.98695982220478, 7.192964650892737, 8.009338862313529, 9.005701481546511, 9.859010822558407, 10.802047792279922, 11.775405634443402, 12.733681674869421, 13.761042437278029, 14.80240599878392, 15.82180895940944, 16.494399219570727, 16.532295751982033, 15.633011668145759, 14.684743622310494, 13.823496304191151, 12.932734702439333, 13.853633399534944, 14.80927642141554, 5.996965311465329, 6.931814252152365, 6.248647871696471, 7.081804673103696, 8.042044279649692, 8.80574420470691, 9.77556646142372, 10.822345498281514, 11.790122701893242, 12.715826455780824, 13.754713677111438, 14.794399225944662, 15.552448127811461, 16.584158576081684, 16.574758646052306, 15.721710058634375, 14.838067937127231, 14.003141565127274, 14.824976455995975, 15.754489950653053, 4.968250191332495, 5.982388614453429, 5.279321633437042, 6.079156106563368, 7.0578104801475465, 7.874142349116433, 8.826750751386275, 9.785934982603491, 10.75832887398358, 11.738746310027027, 12.715478004780506, 13.756984488591936, 14.621094081819415, 15.552688190076303, 16.525291193254237, 16.751717462932618, 15.806507229019157, 14.931186349352238, 15.822521622532474, 16.73093953746369, 4.016616420162976, 4.990203320761584, 4.207892261403149, 5.024164012427862, 6.006713707789409, 6.9347727474508964, 7.888742910779812, 8.857884774132621, 9.852846601945936, 10.816009834057617, 11.758780602125409, 12.737771563054517, 13.68604576984198, 14.671683044519844, 15.726538509857251, 16.700363329610585, 16.764923272169625, 15.99364717220953, 16.831790068500474, 17.659994116059902, 3.046664581621587, 4.069747116963898, 3.1616263380543126, 4.001287913803816, 4.946095723542777, 5.93629135097991, 6.887672653120417, 7.857163903048308, 8.854988958596191, 9.889405481212062, 10.868404732337615, 11.794436459237943, 12.814219132393886, 13.758034837061912, 14.69781996492335, 15.69740543085365, 16.70709990142995, 16.997355046484014, 17.786985665962714, 18.003896822022856, 3.974350215255763, 3.100025849723403, 2.1007542542532387, 2.982174515907646, 3.918780948399508, 4.98714677265724, 5.930000112431241, 6.956360567334188, 7.88067869736807, 8.910324783710253, 9.916589447983021, 10.920920635160684, 11.851841894288444, 12.87810805787434, 13.829906709882563, 14.83345611798026, 15.847072981442789, 16.864018130630196, 17.8152104657814, 18.882981133546288], [19.005031911600447, 18.026276017856617, 17.031571207757324, 16.076574658241025, 15.006993852972506, 13.947499616391411, 12.99321672978348, 11.976148180708249, 10.967112952207518, 10.028743815363985, 8.985680867592054, 7.942080203421078, 7.0121005182000316, 6.001638958558032, 5.058282737907798, 4.0489597428744375, 2.9971734095440743, 2.0679692366727034, 1.0495008648842952, 2.0074408103424015, 18.040699518548323, 17.08340568417831, 16.12707037304245, 15.137078401800727, 14.103740057410144, 13.03090181758125, 12.01846838133946, 10.983960735573984, 10.038659513229758, 9.078094185450635, 8.145664604409507, 7.212846470596246, 6.160107791758241, 5.113332985025254, 4.066804078562054, 3.0542058031458517, 1.9898133005245824, 1.0237344600538936, 0.0, 1.0667289933633257, 17.60042985473118, 18.06838786812726, 17.06474169125119, 16.034250633661408, 14.979315682122925, 13.997658556043133, 12.974206897445665, 11.998778406219312, 11.020568135938312, 10.081943143048363, 9.147574833597483, 8.087708352815993, 7.050585048369071, 6.001000487378982, 5.007883134109914, 3.993604391581031, 2.961086925167265, 2.038511199147447, 1.0386680079475592, 2.014965407680252, 16.632410547136093, 17.601493882287205, 18.03643230579248, 16.976833039412035, 15.9234647251564, 14.930291592941662, 13.973400480001986, 13.014147135011488, 11.975854448416099, 11.017673388285147, 9.973915809823433, 8.92475748754711, 7.875941335268004, 6.829273375499444, 5.755086395557584, 4.82904339959024, 3.8983580200436356, 2.9315323470605286, 2.004160189169943, 2.982820970992133, 15.700974865211984, 16.671227887361773, 17.574918734947065, 17.924368468252265, 16.884320254908, 15.945380668878508, 14.874452955284243, 13.944884696500127, 12.934218219159268, 11.881268833606127, 10.848690749518186, 9.791533205212314, 8.764135574966861, 7.733466663061939, 6.767403120110999, 5.785677099676814, 4.835853743799139, 4.005695373074356, 3.017302966123389, 3.9480472855772546, 14.716626111340608, 15.73046644170449, 16.635170443166977, 17.59106408347907, 17.58000441128544, 16.55511737818562, 15.507584643346576, 14.531712510594044, 13.5651246878256, 12.622397738923176, 11.659990824298603, 10.725092790653957, 9.656512230854043, 8.643932627026912, 7.6948399880786535, 6.8588470937698665, 5.8686058119407924, 4.923576713439553, 3.9801380046198127, 4.945489843254655, 13.761453830398796, 14.722704108800599, 15.639970696796745, 16.61469644739586, 17.571429689953245, 17.388941055787612, 16.46385310428291, 15.504714054493022, 14.50967580441256, 13.54878074335762, 12.583376985197733, 11.650210222081109, 10.584296151676812, 9.639214721075282, 8.688709301329503, 7.8131730503338455, 6.85248248949818, 5.848595518319238, 4.969129431415916, 5.923122759417488, 12.776899616380096, 13.766066123033491, 14.689596153576694, 15.652031449606223, 16.62065769775299, 17.572092745523086, 17.420927550239153, 16.444843561052043, 15.431081190192467, 14.489936230752646, 13.483049732555573, 12.506276054224589, 11.535668401991265, 10.575812671746561, 9.614798711501642, 8.781000786399344, 7.793949752969791, 6.791613049161436, 5.976669971457214, 6.941192644106092, 11.798248882478411, 12.795386853042466, 13.759551975427181, 14.678135394892282, 15.627162853130976, 16.63949388077542, 17.616001087754086, 17.30191549558428, 16.31492455544601, 15.321872736382943, 14.36674417051534, 13.431253318476832, 12.497233696079409, 11.532749566758897, 10.640672974493016, 9.6815911123688, 8.728140230029897, 7.758844576818742, 6.935361338953657, 7.952504878741243, 10.78315930339616, 11.732342547446706, 12.74658969302649, 13.723053579138519, 14.610262693251032, 15.595677125767418, 16.643894052316142, 17.591440600064832, 17.224633940015845, 16.282568236475793, 15.299945786679988, 14.45545276247161, 13.500199575731134, 12.60429405993021, 11.626715440631076, 10.638535343736141, 9.67865863480559, 8.725724813573704, 7.997876755159791, 8.945150522527806, 9.83902230503611, 10.859155561422828, 11.700865357686698, 12.750380672925225, 13.674972147366052, 14.608576126263387, 15.579460167591716, 16.547325920665674, 17.524456593911452, 17.270635363537906, 16.322851546850774, 15.46292441452181, 14.514735913044714, 13.548971620060726, 12.6095992548692, 11.615283669602885, 10.627803797924742, 9.73665160473344, 8.994705454301826, 9.872409961254903, 8.882971535855482, 9.785290371512, 10.773148854529207, 11.702217822415797, 12.707224382153813, 13.681077673858148, 14.586344771204214, 15.600687388179749, 16.559589909359797, 17.497951107079764, 17.268801619304636, 16.451735227254098, 15.512443044927158, 14.520859101723405, 13.597236280145511, 12.553588117094096, 11.621673598837788, 10.745259637608054, 10.069057477898705, 10.831723183303945, 7.888815308390203, 8.859130174753862, 9.787936519688582, 10.720975372791573, 11.763476125147092, 12.674029153973686, 13.586482928392288, 14.546031522913026, 15.502423048896985, 16.46333233034316, 17.415878417346555, 17.387814124357078, 16.502470067930485, 15.48545151196491, 14.523974102126127, 13.614999888405961, 12.656981015167231, 11.73187361006717, 11.117350987206382, 11.858876775392082, 6.926375584214774, 7.987611431748844, 8.835365790748282, 9.745548855308735, 10.740371596691745, 11.735592475840633, 12.648332033496047, 13.59139813056076, 14.549019055710495, 15.582553912009821, 16.51240492522692, 17.53936764016566, 17.493498594672978, 16.490287080065507, 15.520084984747587, 14.575517306103503, 13.609854753904617, 12.717094282469168, 12.07807064685558, 12.906710812559817, 5.972549696997169, 6.9632253621508875, 7.8232644984153055, 8.785758209222944, 9.782120828455927, 10.724108202615108, 11.6789414525281, 12.65229929469158, 13.611637578181133, 14.63899834058974, 15.689113920293215, 16.708516880918737, 17.453965354762577, 17.49033694628542, 16.495779250552932, 15.539273710280968, 14.673654666317086, 13.740937369205387, 13.047756052680546, 13.842814521498434, 4.9732308514114365, 5.908079792098472, 6.878947719219039, 7.858224020013112, 8.818463626559108, 9.670841584763611, 10.653522364735432, 11.700301401593226, 12.668078605204954, 13.593782359092536, 14.641421598620733, 15.681107147453957, 16.51201426300331, 17.54372471127353, 17.43752622845948, 16.57624014660485, 15.688226299253166, 14.811344231893328, 14.019099109141576, 14.78802805073595, 3.944515731278602, 4.958654154399536, 5.90962148095961, 6.855575453472784, 7.867151311801739, 8.739239729173134, 9.704706654697986, 10.663890885915203, 11.636284777295291, 12.616702213338739, 13.675044139972353, 14.716550623783784, 15.580660217011262, 16.512254325268152, 17.484857328446086, 17.601875825058553, 16.656665591145092, 15.739389016118292, 15.016644275678075, 15.764477637546587, 2.992881960109083, 3.96646886070769, 4.90575405492053, 5.833358876939286, 6.816054539443601, 7.799870127507597, 8.766698814091525, 9.735840677444333, 10.751624043412207, 11.775575969249465, 12.718346737317257, 13.697337698246365, 14.645611905033828, 15.631249179711691, 16.6861046450491, 17.71274835672034, 17.61508163429556, 16.80184983897558, 16.025912721646076, 16.6935322161428, 2.022930121567694, 3.046012656910005, 4.007549938203405, 4.958159073891601, 5.902966883630562, 6.948676378089663, 7.90005768023017, 8.86954893015806, 9.867373985705944, 10.901790508321815, 11.880789759447367, 12.806821486347696, 13.826604159503638, 14.770419864171664, 15.710204992033102, 16.709790457963404, 17.719484928539703, 17.805557713250064, 16.981108319108316, 17.758065353440703, 2.95061575520187, 2.0762913896695094, 3.086387147016982, 3.992485770479939, 4.929092202971801, 5.999531799766993, 6.942385139540995, 7.968745594443941, 8.893063724477823, 9.922709810820008, 10.928974475092776, 11.933305662270438, 12.864226921398199, 13.890493084984094, 14.842291736992317, 15.845841145090015, 16.859458008552544, 17.87640315773995, 17.99885841484659, 18.819712216662392], [18.712785786466394, 19.051359152760675, 18.01329210980989, 17.05829556029359, 15.988714755025073, 14.929220518443978, 13.974937631836047, 12.957869082760816, 11.948833854260085, 10.99642477223758, 9.953361824465649, 8.909761160294673, 7.979781475073628, 6.969319915431628, 6.025963694781394, 5.0166406997480335, 3.9648543664176708, 3.0356501935463, 2.017181821757892, 1.0592418762997855, 17.64110002911337, 18.15013467754163, 17.19379936640577, 16.20380739516405, 15.170469050773468, 14.097630810944574, 13.085197374702783, 12.050689728937307, 11.105388506593082, 10.144823178813958, 9.21239359777283, 8.27957546395957, 7.2268367851215665, 6.180061978388579, 5.133533071925379, 4.120934796509177, 3.056542293887908, 2.090463453417219, 1.0667289933633257, 0.0, 16.635318241896726, 17.581046247723677, 18.116697604128195, 17.086206546538413, 16.031271594999932, 15.049614468920138, 14.02616281032267, 13.050734319096318, 12.066507236028624, 11.068581745252096, 10.134213435801215, 9.074346955019724, 8.037223650572802, 6.9876390895827125, 5.9945217363136445, 4.980242993784762, 3.9328286369574244, 2.945227947895723, 1.945384756695835, 0.9482364143169261, 15.667298934301643, 16.636382269452753, 17.569164462383863, 17.97799321047009, 16.924624896214453, 15.931451763999716, 14.97456065106004, 13.945526275421269, 12.90723358882588, 11.949052528694928, 10.905294950233213, 9.85613662795689, 8.807320475677784, 7.760652515909225, 6.686465535967366, 5.760422540000022, 4.8297371604534165, 3.838249095808804, 2.9108769379182187, 1.9888371870380417, 14.735863252377536, 15.706116274527325, 16.53747515125493, 17.554880438397262, 17.885480425966055, 16.87675980928829, 15.805832095694027, 14.876263836909912, 13.865597359569053, 12.812647974015912, 11.78006988992797, 10.722912345622099, 9.695514715376644, 8.66484580347172, 7.6987822605207805, 6.717056240086595, 5.767232884208919, 4.912412121822631, 3.9028742901383198, 2.9721299706844544, 13.75151449850616, 14.765354828870041, 15.597726859474845, 16.553620499786934, 17.460435871976262, 17.486496518595402, 16.438963783756357, 15.463091651003825, 14.496503828235381, 13.553776879332958, 12.591369964708385, 11.656471931063738, 10.587891371263824, 9.575311767436693, 8.626219128488435, 7.790226234179648, 6.799984952350573, 5.809148037454484, 4.865709328634743, 3.969572528361854, 12.796342217564348, 13.75759249596615, 14.602527113104614, 15.577252863703732, 16.515696341399185, 17.520914158797797, 17.395232244692693, 16.436093194902803, 15.44105494482234, 14.480159883767401, 13.514756125607514, 12.58158936249089, 11.515675292086593, 10.570593861485063, 9.620088441739284, 8.744552190743626, 7.777741765075769, 6.734166842334169, 5.854700755430846, 4.95801114658304, 11.811788003545647, 12.800954510199043, 13.652152569884564, 14.596298101052163, 15.56492434919893, 16.505363752159763, 17.441454356095754, 17.376222701461824, 16.36246033060225, 15.421315371162427, 14.414428872965354, 13.43765519463437, 12.467047542401046, 11.507191812156343, 10.546177851911423, 9.712379926809124, 8.679521076984722, 7.677184373176367, 6.862241295472144, 5.976081031271644, 10.833137269643963, 11.830275240208017, 12.72210839173505, 13.611406401528958, 14.56043385976765, 15.572764887412093, 16.549272094390762, 17.519517215446392, 17.24630369585579, 16.253251876792724, 15.29812331092512, 14.362632458886614, 13.42861283648919, 12.464128707168678, 11.526374263610597, 10.567162436383729, 9.613711554044826, 8.644415900833673, 7.820932662968587, 6.987393265906794, 9.818047690561711, 10.767230934612257, 11.709146109334359, 12.656324585775195, 13.543533699887707, 14.528948132404093, 15.577165058952819, 16.52471160670151, 17.41858249395113, 17.213947376885574, 16.23132492708977, 15.386831902881392, 14.431578716140915, 13.505722624732371, 12.512286764646005, 11.52410666775107, 10.56422995882052, 9.611296137588635, 8.883448079174721, 7.9800389096933575, 8.873910692201662, 9.894043948588378, 10.636351601344394, 11.683651679561901, 12.608243154002727, 13.541847132900063, 14.512731174228392, 15.480596927302352, 16.45772760054813, 17.38768009992628, 17.254230687260556, 16.385499398735394, 15.400307237059643, 14.434542944075655, 13.49517057888413, 12.500854993617814, 11.513375121939672, 10.622222928748371, 9.880276778316757, 8.907298348420454, 7.917859923021034, 8.82017875867755, 9.708635098186903, 10.635488829052472, 11.640495388790487, 12.614348680494825, 13.519615777840889, 14.533958394816423, 15.492860915996472, 16.43122211371644, 17.339707777575043, 17.37314933622367, 16.39801436894209, 15.406430425738334, 14.482807604160442, 13.439159441109027, 12.507244922852719, 11.630830961622985, 10.793139148980867, 9.866611570469496, 6.923703695555755, 7.894018561919412, 8.721207526325255, 9.654246379428248, 10.696747131783766, 11.607300160610361, 12.519753935028962, 13.4793025295497, 14.43569405553366, 15.396603336979835, 16.349149423983228, 17.284619553838837, 17.388041391945414, 16.37102283597984, 15.409545426141058, 14.500571212420892, 13.542552339182162, 12.617444934082101, 11.825962837149294, 10.893765162557633, 5.921586994449859, 6.951388369886583, 7.768636797384955, 8.67881986194541, 9.67364260332842, 10.668863482477308, 11.581603040132721, 12.524669137197435, 13.482290062347172, 14.515824918646498, 15.445675931863597, 16.472638646802338, 17.427901351797654, 17.37585840408044, 16.40565630876252, 15.461088630118436, 14.49542607791955, 13.602665606484099, 12.786682496798491, 11.941599199725369, 4.9677611072322545, 5.896496368787561, 6.756535505051978, 7.719029215859618, 8.715391835092602, 9.657379209251783, 10.612212459164775, 11.585570301328255, 12.54490858481781, 13.572269347226417, 14.622384926929891, 15.641787887555411, 16.387236361399253, 17.314437274453127, 17.381350574567865, 16.424845034295902, 15.559225990332019, 14.626508693220318, 13.756367902623458, 12.877702908663986, 3.9215979778399164, 4.841350798735146, 5.812218725855713, 6.791495026649786, 7.751734633195783, 8.604112591400286, 9.586793371372108, 10.633572408229902, 11.60134961184163, 12.527053365729213, 13.57469260525741, 14.614378154090634, 15.445285269639985, 16.476995717910206, 17.391919192459888, 17.461811470619786, 16.5737976232681, 15.696915555908259, 14.727710959084488, 13.822916437901501, 2.877786737915276, 3.89192516103621, 4.842892487596284, 5.788846460109458, 6.800422318438414, 7.672510735809808, 8.637977661334663, 9.59716189255188, 10.569555783931968, 11.549973219975415, 12.60831514660903, 13.64982163042046, 14.513931223647939, 15.445525331904827, 16.41812833508276, 17.48352585171259, 17.542236915160025, 16.624960340133224, 15.725256125620987, 14.799366024712139, 1.9261529667457573, 2.899739867344364, 3.839025061557205, 4.766629883575961, 5.749325546080276, 6.7331411341442715, 7.6999698207282, 8.66911168408101, 9.684895050048883, 10.708846975886141, 11.651617743953933, 12.630608704883041, 13.578882911670505, 14.564520186348368, 15.619375651685775, 16.653426478355794, 17.69352934857502, 17.687421162990514, 16.714975592404556, 15.72842060330835, 0.9562011282043682, 2.013468448794994, 2.9750057300883945, 3.925614865776591, 4.8704226755155515, 5.944106975218526, 6.909949548764825, 7.879440798692716, 8.8772658542406, 9.91168237685647, 10.890681627982023, 11.816713354882351, 12.836496028038294, 13.78031173270632, 14.720096860567757, 15.719682326498058, 16.729376797074355, 17.709121496109876, 17.670171189866796, 16.792953740606254, 1.8838867618385442, 2.8372550586712277, 3.8473508160187, 4.8294684229900415, 5.766074855481904, 6.840369255087224, 7.810014777296765, 8.836375232199712, 9.83134565758802, 10.860991743930205, 11.867256408202973, 12.819400732746494, 13.750321991874255, 14.77658815546015, 15.692319015630392, 16.69586842372809, 17.709485287190617, 18.726430436378024, 18.68792128560507, 17.854600603827944], [2.077467544569669, 2.893672078992898, 3.931739121943684, 4.869610216834456, 5.939191022102975, 6.977134755481696, 7.931417642089628, 8.94848619116486, 9.903909799702213, 10.856318881724718, 11.89938182949665, 12.839100834590063, 13.769080519811109, 14.779542079453108, 15.722898300103342, 16.732221295136704, 17.784007628467066, 18.71321180133844, 18.64993071961547, 17.694560118196513, 1.005781787216646, 1.9508017453145894, 2.90713705645045, 3.897129027692172, 4.930467372082754, 6.003305611911648, 7.015739048153438, 8.030155138380227, 8.975456360724452, 9.936021688503576, 10.868451269544703, 11.801269403357963, 12.854008082195968, 13.900782888928955, 14.947311795392155, 15.959910070808357, 17.024302573429626, 17.990381413900316, 17.600429854731175, 16.635318241896726, 0.0, 0.9457280058269512, 1.9493741827030209, 2.979865240292802, 4.034800191831285, 5.016457317911077, 6.039908976508544, 7.015337467734898, 7.9995645508025905, 8.997490041579118, 9.931858351029998, 10.991724831811489, 12.02884813625841, 13.0784326972485, 14.071550050517569, 15.085828793046453, 16.13324314987379, 17.12084383893549, 16.561761846783615, 15.687081827579801, 0.9680193075950846, 1.937102642746196, 2.9592995705702205, 3.9944840634997565, 5.04785237775539, 6.014833873009941, 6.971724985949617, 8.000759361588388, 9.039052048183777, 9.975401704419149, 10.957327360188254, 11.953871368686782, 13.002687520965887, 14.049355480734446, 15.123542460676306, 16.04958545664365, 16.980270836190257, 16.461519394006793, 15.596269665561232, 14.646481054858686, 1.8994549895191917, 2.869708011668981, 3.8054032759427128, 4.834014294691318, 5.893167808145453, 6.94938194502887, 7.938662094329771, 8.868230353113887, 9.878896830454746, 10.931846216007887, 11.886893189265065, 12.906674482972134, 13.934072113217589, 14.964741025122512, 15.930804568073452, 16.912530588507636, 16.33422240824841, 15.387356367992966, 14.583126888607786, 13.663188271212274, 2.883803743390568, 3.8731555737714567, 4.7451515677228, 5.7010452080348895, 6.722732836823579, 7.747619869923398, 8.79515260476244, 9.771024737514972, 10.737612560283416, 11.68033950918584, 12.642746423810413, 13.57764445745506, 14.646225017254974, 15.658804621082105, 16.607897260030363, 16.450925848001546, 15.4519424765065, 14.45151770797478, 13.620291850111363, 12.665745713534873, 3.83897602433238, 4.878610232250166, 5.740351314093031, 6.690050361351214, 7.667472367400657, 8.67269018479927, 9.597778136303969, 10.564636737169751, 11.559674987250215, 12.606722513620284, 13.63895692615353, 14.572123689270153, 15.592831561296071, 16.5379129918976, 16.420266739640063, 15.496599891437567, 14.525551653910279, 13.526498903095096, 12.63130042331526, 11.677307095313688, 4.823530238351081, 5.835248218017273, 6.6907258573130814, 7.653161153342611, 8.618244359600912, 9.601543589622532, 10.537634193558523, 11.513718182745633, 12.527480553605209, 13.46862551304503, 14.475512011242103, 15.452285689573086, 16.42289334180641, 16.394187246572262, 15.494177329467924, 14.528772155372069, 13.562637602816928, 12.583481372252898, 11.640434807229912, 10.659237210625085, 5.802180972252765, 6.805927488008298, 7.620770035462595, 8.591420438257323, 9.629204626179382, 10.534142454370201, 11.548772292240912, 12.51901741329654, 13.50600835343481, 14.408648159222546, 15.36377672509015, 16.299267577128656, 16.344794214470024, 15.437250351559925, 14.46830306647655, 13.509091239249681, 12.585545497806745, 11.616249844595592, 10.681743439733468, 9.647924975989934, 6.871145669772956, 7.820328913823502, 8.633732317863286, 9.546502254011086, 10.595185350964616, 11.580599783481002, 12.520879327678857, 13.52349450523912, 14.489305207819354, 15.431370911359405, 16.2969783412548, 16.338035654373037, 15.341828334818297, 14.365705858388612, 13.48381503977674, 12.55214700788234, 11.583982639874444, 10.64936960784063, 9.640461090129307, 8.65527933220337, 7.815282668133005, 8.832899783482384, 9.70652682585325, 10.51917516022438, 11.530475896849596, 12.464611846027532, 13.435495887355861, 14.403361640429821, 15.39987041580256, 16.419438038421518, 16.279040054071384, 15.330564002322836, 14.345371840647084, 13.379607547663097, 12.46199288527614, 11.575398682015596, 10.634837476755292, 9.68546764791596, 8.76958627353548, 7.728019893476273, 8.771333437313633, 9.736978414531814, 10.634243329010742, 11.56733801073381, 12.498223662061836, 13.39211029843277, 14.431521019331985, 15.376436197496236, 16.342245669793293, 16.456119302430633, 15.421179533500563, 14.455831750639865, 13.480696783358283, 12.407720066000419, 11.466094565066232, 10.581679335045587, 9.649764816789279, 8.676859615041346, 7.695234249938602, 6.768706671427232, 9.765489664778912, 10.663138611289952, 11.62167090087239, 12.548580460358034, 13.491368445428856, 14.399158818317233, 15.373353131283661, 16.3329017258044, 16.382409807140206, 15.421500525694029, 14.468954438690634, 13.533484308835023, 12.589217171420914, 11.565096747689365, 10.539356743085616, 9.590321017978411, 8.63230214473968, 7.69024564258223, 6.690688251822567, 5.773307847644824, 10.817691659809272, 11.719797968633312, 12.57424162981269, 13.524006977840871, 14.514472973884203, 15.337595496450286, 16.3115040261799, 16.650506009751243, 15.658112361982472, 14.646160101159195, 13.716309087942095, 12.769461543319595, 11.717669694076534, 10.649327695624956, 9.679125600307035, 8.73455792166295, 7.768895369464064, 6.7536430103414045, 5.729968592173369, 4.725473810477087, 11.771517547026876, 12.774689969732334, 13.586342922145667, 14.483797623926662, 15.480160243159645, 16.353303527413686, 16.72723819732166, 15.75388035515818, 14.720730884453108, 13.837245158899222, 12.773064073790021, 11.737002812568406, 10.74158020852186, 9.816617073054589, 8.759173152789177, 7.802667612517214, 6.794308949574548, 5.8300468999573365, 4.848003655222758, 3.7893701015384695, 12.817680676419215, 13.793670923361617, 14.530659701341932, 15.411331813136496, 16.371571419682493, 16.82641383732873, 15.816809685160358, 14.770030648302562, 13.777171911476929, 12.832122619703984, 11.784483380175788, 10.744797831342563, 9.799629116762594, 8.896965968300028, 7.937868816712854, 6.921957334109123, 5.887670461693634, 4.860377734356457, 3.8766605987617266, 2.8441565723009554, 13.861491916343855, 14.743096561060552, 15.49998593960136, 16.413980379676822, 16.8794888255881, 15.894811981738252, 14.868034115371929, 13.908849884154712, 12.936455992774624, 11.956038556731176, 10.881965803745686, 9.838032840921812, 8.868275070770547, 7.936680962513659, 6.964077959335727, 5.898680442705897, 4.953470208792438, 3.9323329501314923, 2.93114546559012, 1.867706985490317, 14.813125687513374, 15.770251807765481, 16.571415311635253, 16.921953630641028, 15.939257968136712, 14.955442380072716, 13.988613693488787, 13.019471830135979, 12.003688464168105, 10.979736538330847, 10.036965770263055, 9.057974809333947, 8.109700602546484, 7.124063327868621, 6.069207862531213, 5.035157035861195, 3.9950541656419696, 2.986166124075355, 1.9252073959903113, 0.938652406894106, 15.783077526054763, 16.818879718611793, 17.61768123498409, 17.69877566054282, 16.75396785080386, 15.680283551100885, 14.714440977554586, 13.744949727626695, 12.747124672078812, 11.71270814946294, 10.733708898337389, 9.80767717143706, 8.787894498281117, 7.844078793613091, 6.904293665751654, 5.904708199821353, 4.895013729245055, 3.915269030209533, 2.8804029934525524, 1.9927135507450744, 16.710763159688938, 17.66413145652162, 18.67422721386909, 18.626592538945886, 17.689986106454025, 16.629428129423555, 15.672113518243762, 14.710209824051272, 13.760379962848951, 12.776813892945626, 11.770549228672857, 10.766218041495195, 9.835296782367434, 8.826607828312103, 7.874809176303879, 6.871259768206182, 5.857642904743653, 4.849345424342031, 3.898153089190827, 3.0528424249099935], [2.9266999669097764, 1.9479440731659472, 2.9860111161167326, 3.9238822110075056, 4.993463016276024, 6.031406749654746, 6.985689636262678, 8.00275818533791, 8.95818179387526, 9.910590875897766, 10.953653823669697, 11.89337282876311, 12.823352513984156, 13.833814073626156, 14.77717029427639, 15.786493289309751, 16.838279622640115, 17.767483795511488, 18.327806304028957, 18.640288124023467, 1.9515097930435972, 1.0050737394876383, 1.9614090506234994, 2.9514010218652214, 3.9847393662558033, 5.057577606084697, 6.070011042326487, 7.084427132553275, 8.0297283548975, 8.990293682676624, 9.922723263717751, 10.855541397531011, 11.908280076369016, 12.955054883102003, 14.001583789565203, 15.014182064981405, 16.078574567602676, 17.044653408073366, 18.06838786812726, 17.58104624772368, 0.9457280058269512, 0.0, 1.0036461768760696, 2.0341372344658506, 3.0890721860043335, 4.070729312084126, 5.094180970681593, 6.069609461907946, 7.05383654497564, 8.051762035752168, 8.986130345203048, 10.045996825984538, 11.08312013043146, 12.13270469142155, 13.125822044690619, 14.140100787219502, 15.18751514404684, 16.175115833108542, 17.17495902430843, 16.632809833406753, 1.9137473134220357, 1.0628013448330031, 2.0135715647432693, 3.048756057672805, 4.102124371928439, 5.06910586718299, 6.025996980122666, 7.055031355761436, 8.093324042356825, 9.029673698592198, 10.011599354361303, 11.008143362859832, 12.056959515138937, 13.103627474907496, 14.177814454849356, 15.103857450816701, 16.034542830363307, 17.02603089500792, 16.541997671388184, 15.592209060685637, 2.8451829953461427, 2.073792669669671, 3.0094879339434026, 3.9962914865130346, 5.055444999967169, 6.109080851566652, 6.99293408850282, 7.922502347286936, 8.933168824627794, 9.986118210180935, 10.941165183438114, 11.960946477145184, 12.988344107390638, 14.019013019295562, 14.985076562246501, 15.966802582680687, 16.97203855411881, 16.333084373819915, 15.528854894434737, 14.608916277039224, 3.8295317492175194, 3.0772402317721466, 3.9492362257234896, 4.905129866035579, 5.9268174948242685, 6.951704527924086, 7.945847497595832, 8.921719630348363, 9.888307453116807, 10.831034402019231, 11.793441316643804, 12.72833935028845, 13.796919910088365, 14.809499513915496, 15.758592152863754, 16.721862227936178, 16.39767048233345, 15.39724571380173, 14.566019855938313, 13.611473719361824, 4.784704030159331, 4.136430970576534, 4.9444359720937205, 5.8941350193519035, 6.871557025401346, 7.876774842799959, 8.801862794304657, 9.76872139517044, 10.763759645250904, 11.757417406453675, 12.78965181898692, 13.722818582103544, 14.743526454129462, 15.688607884730992, 16.64884277961488, 16.44232789726452, 15.47127965973723, 14.472226908922046, 13.57702842914221, 12.623035101140639, 5.769258244178031, 5.09306895634364, 5.894810515313771, 6.857245811343301, 7.8223290176016, 8.80562824762322, 9.741718851559211, 10.717802840746321, 11.731565211605897, 12.672710171045718, 13.679596669242791, 14.656370347573775, 15.6269779998071, 16.586833730051804, 16.439905335294874, 15.47450016119902, 14.508365608643878, 13.529209378079848, 12.586162813056863, 11.604965216452035, 6.747908978079716, 6.063748226334666, 6.824854693463284, 7.795505096258012, 8.83328928418007, 9.73822711237089, 10.7528569502416, 11.723102071297228, 12.710093011435498, 13.612732817223234, 14.567861383090838, 15.503352235129345, 16.437371857526767, 16.382978357386875, 15.4140310723035, 14.454819245076632, 13.531273503633695, 12.561977850422542, 11.627471445560419, 10.593652981816884, 7.816873675599906, 7.126792531930427, 7.837816975863976, 8.750586912011775, 9.799270008965305, 10.78468444148169, 11.724963985679546, 12.727579163239808, 13.693389865820043, 14.635455569360094, 15.501062999255486, 16.527551679124123, 16.28755634064525, 15.311433864215562, 14.42954304560369, 13.49787501370929, 12.529710645701394, 11.59509761366758, 10.586189095956257, 9.601007338030321, 8.761010673959955, 8.139363401589309, 8.910611483853941, 9.723259818225069, 10.734560554850285, 11.66869650402822, 12.63958054535655, 13.60744629843051, 14.603955073803249, 15.623522696422205, 16.52396875942627, 16.276292008149785, 15.291099846474035, 14.325335553490048, 13.407720891103091, 12.521126687842546, 11.580565482582243, 10.63119565374291, 9.715314279362431, 8.673747899303224, 9.717061443140583, 9.213228591500137, 9.838327987011432, 10.771422668734498, 11.702308320062524, 12.59619495643346, 13.635605677332673, 14.580520855496925, 15.546330327793981, 16.56756260254196, 16.366907539327514, 15.401559756466815, 14.426424789185234, 13.35344807182737, 12.411822570893182, 11.527407340872537, 10.59549282261623, 9.622587620868297, 8.640962255765553, 7.714434677254182, 10.711217670605862, 10.139388788258275, 10.82575555887308, 11.752665118358722, 12.695453103429545, 13.603243476317921, 14.57743778928435, 15.536986383805088, 16.493377909789046, 16.36722853152098, 15.414682444517585, 14.479212314661973, 13.534945177247865, 12.510824753516316, 11.485084748912566, 10.536049023805361, 9.578030150566631, 8.63597364840918, 7.636416257649517, 6.719035853471774, 11.763419665636222, 11.196048145601635, 11.77832628781338, 12.72809163584156, 13.718557631884892, 14.541680154450974, 15.51558868418059, 16.526912687186424, 16.603840367809422, 15.591888106986149, 14.66203709376905, 13.715189549146546, 12.663397699903484, 11.595055701451907, 10.624853606133986, 9.6802859274899, 8.714623375291014, 7.699371016168355, 6.67569659800032, 5.671201816304038, 12.717245552853827, 12.250940146700657, 12.790427580146357, 13.687882281927351, 14.684244901160334, 15.557388185414375, 16.48497926514854, 16.69960836098513, 15.666458890280058, 14.782973164726176, 13.718792079616975, 12.68273081839536, 11.687308214348812, 10.762345078881541, 9.70490115861613, 8.748395618344167, 7.7400369554015, 6.775774905784289, 5.793731661049709, 4.73509810736542, 13.763408682246165, 13.306085716753072, 13.734744359342622, 14.615416471137184, 15.575656077683181, 16.605430477881285, 16.76253769098731, 15.715758654129512, 14.722899917303879, 13.777850625530935, 12.730211386002738, 11.690525837169513, 10.745357122589546, 9.84269397412698, 8.883596822539806, 7.8676853399360756, 6.8333984675205865, 5.806105740183408, 4.822388604588678, 3.7898845781279067, 14.807219922170805, 14.255511354452008, 14.704070597602051, 15.618065037677512, 16.614191459984326, 16.840539987565204, 15.813762121198879, 14.854577889981663, 13.882183998601574, 12.901766562558127, 11.827693809572636, 10.783760846748764, 9.8140030765975, 8.882408968340611, 7.909805965162679, 6.84440844853285, 5.899198214619389, 4.878060955958444, 3.8768734714170714, 2.8134349913172683, 15.758853693340324, 15.282666601156937, 15.775499969635943, 16.673057131813017, 16.884985973963662, 15.901170385899666, 14.934341699315738, 13.96519983596293, 12.949416469995056, 11.925464544157798, 10.982693776090006, 10.003702815160898, 9.055428608373434, 8.069791333695571, 7.0149358683581635, 5.980885041688145, 4.94078217146892, 3.931894129902306, 2.8709354018172624, 1.884380412721057, 16.72880553188171, 16.33129451200325, 16.82176589298478, 17.695933230437063, 17.69969585663081, 16.626011556927835, 15.660168983381537, 14.690677733453645, 13.692852677905762, 12.658436155289891, 11.679436904164339, 10.75340517726401, 9.733622504108068, 8.789806799440042, 7.850021671578604, 6.850436205648303, 5.8407417350720054, 4.860997036036483, 3.826130999279503, 2.938441556572026, 17.656491165515888, 17.301015779243745, 17.88263797678585, 17.680864533118932, 16.74425810062707, 15.718419356135584, 14.774560254609119, 13.821958811991424, 12.844356349819856, 11.848663096649238, 10.84239843237647, 9.838067245198808, 8.907145986071047, 7.880879822485152, 6.929081170476929, 5.925531762379231, 4.911914898916702, 3.91188932744606, 2.960696992294855, 3.902074847250101], [3.930346143785846, 2.951590250042017, 2.1064815774494288, 3.0287890851526593, 4.07833956374925, 5.038930088757139, 5.993212975365071, 7.010281524440304, 7.954535616999191, 8.906944699021697, 9.950007646793628, 10.889726651887042, 11.819706337108087, 12.830167896750087, 13.77352411740032, 14.782847112433682, 15.834633445764045, 16.763837618635417, 17.782305990423826, 18.740245935881934, 2.955155969919667, 2.0087199163637077, 1.0663159247686531, 2.056307896010375, 3.0552142643485545, 4.0651009451870905, 5.0775343814288805, 6.080780955677205, 7.026082178021431, 7.986647505800555, 8.919077086841682, 9.851895220654942, 10.904633899492946, 11.951408706225934, 12.997937612689134, 14.010535888105336, 15.074928390726605, 16.041007231197295, 17.06474169125119, 18.116697604128195, 1.9493741827030209, 1.0036461768760696, 0.0, 1.030491057589781, 2.0854260091282635, 3.0670831352080556, 4.0905347938055225, 5.065963285031876, 6.050190368099569, 7.048115858876097, 7.982484168326978, 9.042350649108467, 10.07947395355539, 11.129058514545479, 12.122175867814548, 13.136454610343431, 14.183868967170769, 15.171469656232471, 16.171312847432358, 17.168461189811268, 2.9173934902981054, 2.054230824672107, 1.0099253878671997, 2.0451098807967356, 3.0984781950523694, 4.06545969030692, 5.022350803246596, 6.051385178885366, 7.089677865480755, 8.026027521716127, 9.007953177485234, 10.00449718598376, 11.053313338262866, 12.099981298031425, 13.174168277973285, 14.10021127394063, 15.030896653487234, 16.022384718131846, 16.94975687602243, 16.595855237561707, 3.8488291722222123, 2.9773099632698647, 2.041614698996133, 2.9926453096369645, 4.051798823091099, 5.105434674690582, 5.98928791162675, 6.918856170410866, 7.929522647751724, 8.982472033304866, 9.937519006562045, 10.957300300269113, 11.984697930514567, 13.01536684241949, 13.98143038537043, 14.963156405804616, 15.968392377242738, 16.915258417498183, 16.532501071310804, 15.612562453915293, 4.8331779260935885, 3.963387293128788, 2.98136299077622, 3.9372566310883093, 4.958944259876999, 5.9838312929768165, 6.942201320719762, 7.918073453472294, 8.884661276240738, 9.827388225143162, 10.789795139767735, 11.724693173412382, 12.793273733212295, 13.805853337039427, 14.754945975987685, 15.718216051060109, 16.722100559314217, 16.400891890677798, 15.569666032814382, 14.615119896237893, 5.7883502070354, 4.976327727923566, 3.976562737146451, 4.926261784404634, 5.903683790454076, 6.908901607852689, 7.833989559357388, 8.80084816022317, 9.795886410303634, 10.753771229577605, 11.786005642110851, 12.719172405227475, 13.739880277253393, 14.684961707854923, 15.645196602738814, 16.61041114584086, 16.4749258366133, 15.475873085798115, 14.58067460601828, 13.626681278016708, 6.7729044210541005, 5.909804082413513, 4.926937280366501, 5.889372576396031, 6.85445578265433, 7.837755012675951, 8.773845616611943, 9.749929605799053, 10.76369197665863, 11.70483693609845, 12.711723434295523, 13.658506620417654, 14.629114272650979, 15.588970002895682, 16.5499839631406, 16.478146338075092, 15.512011785519949, 14.532855554955917, 13.589808989932932, 12.608611393328104, 7.751555154955785, 6.835005383932889, 5.856981458516015, 6.827631861310742, 7.8654160492328, 8.77035387742362, 9.784983715294333, 10.75522883634996, 11.74221977648823, 12.644859582275966, 13.59998814814357, 14.535479000182077, 15.4694986225795, 16.446729483638816, 16.41767724917957, 15.458465421952702, 14.534919680509766, 13.565624027298611, 12.631117622436488, 11.597299158692953, 8.820519852475975, 7.884190886496491, 6.869943740916707, 7.782713677064505, 8.831396774018035, 9.816811206534421, 10.757090750732278, 11.75970592829254, 12.725516630872775, 13.667582334412826, 14.533189764308219, 15.559678444176855, 16.472464502231226, 16.315080041091633, 15.433189222479761, 14.501521190585361, 13.533356822577465, 12.598743790543649, 11.589835272832326, 10.60465351490639, 9.764656850836024, 8.896761756155373, 7.942738248906672, 8.755386583277799, 9.766687319903015, 10.700823269080951, 11.67170731040928, 12.63957306348324, 13.63608183885598, 14.655649461474937, 15.556095524479003, 16.50457157622755, 16.294746023350108, 15.328981730366118, 14.411367067979162, 13.524772864718617, 12.584211659458314, 11.634841830618981, 10.7189604562385, 9.677394076179294, 10.720707620016652, 9.85831323508137, 8.870454752064163, 9.803549433787229, 10.734435085115255, 11.62832172148619, 12.667732442385404, 13.612647620549655, 14.578457092846712, 15.59968936759469, 16.502045596932867, 16.405205933342884, 15.430070966061304, 14.35709424870344, 13.415468747769253, 12.531053517748608, 11.5991389994923, 10.626233797744367, 9.644608432641622, 8.718080854130251, 11.714863847481931, 10.784473431839508, 9.85788232392581, 10.784791883411453, 11.727579868482275, 12.635370241370651, 13.60956455433708, 14.569113148857818, 15.525504674841777, 16.486413956287954, 16.418328621393655, 15.482858491538044, 14.538591354123936, 13.514470930392386, 12.488730925788637, 11.539695200681432, 10.581676327442702, 9.639619825285251, 8.640062434525587, 7.722682030347844, 12.767065842512292, 11.75662364248197, 10.81045305286611, 11.76021840089429, 12.750684396937622, 13.573806919503705, 14.547715449233321, 15.559039452239155, 16.48261786401818, 16.58367507665102, 15.653824063433918, 14.712904973255316, 13.667043876779552, 12.598701878327974, 11.628499783010053, 10.683932104365969, 9.718269552167083, 8.703017193044424, 7.67934277487639, 6.674847993180108, 13.720891729729896, 12.811515643580991, 11.822554345199087, 12.720009046980081, 13.716371666213064, 14.589514950467105, 15.517106030201267, 16.49046387236475, 16.617403662875827, 15.774760134391045, 14.710579049281844, 13.674517788060228, 12.679095184013683, 11.76599125575761, 10.708547335492199, 9.752041795220237, 8.74368313227757, 7.779421082660358, 6.7973778379257785, 5.73874428424149, 14.751927920217167, 13.775937673274765, 12.766871124395353, 13.647543236189914, 14.607782842735912, 15.637557242934015, 16.54358736105747, 16.66670342672528, 15.673844689899648, 14.728795398126703, 13.72199835566761, 12.682312806834386, 11.737144092254416, 10.84634015100305, 9.887242999415875, 8.871331516812145, 7.837044644396656, 6.8097519170594785, 5.826034781464747, 4.793530755003976, 15.70130311233579, 14.687164689214855, 13.736197362654782, 14.650191802730243, 15.646318225037055, 16.569159098524494, 16.663710811013658, 15.704526579796442, 14.732132688416353, 13.751715252372906, 12.754704304656604, 11.775547816413635, 10.80579004626237, 9.88605514521668, 8.913452142038748, 7.848054625408919, 6.902844391495459, 5.881707132834514, 4.880519648293141, 3.817081168193338, 16.65293688350531, 15.714319935919784, 14.807626734688673, 15.70518389686575, 16.687879559370064, 16.662399154053173, 15.72965687608162, 14.769463142340433, 13.75367977637256, 12.729727850535301, 11.798006902001507, 10.819015941072399, 9.870741734284936, 9.0063816505685, 8.018582045234233, 6.984531218564215, 5.9444283483449905, 4.935540306778376, 3.874581578693332, 2.8880265895971267, 17.622888722046696, 16.762947846766096, 15.85389265803751, 16.728059995489794, 16.737602057285162, 15.663917757582187, 14.728586618422225, 13.783572731539932, 12.837540020305617, 11.803123497689747, 10.824124246564194, 9.898092519663866, 8.878309846507923, 7.934494141839898, 6.9947090139784605, 6.026994073484042, 5.037792531096601, 4.097089686910655, 4.829777176155573, 3.942087733448095, 18.550574355680872, 17.73266911400659, 16.914764741838585, 16.677218356242864, 15.740611923751004, 14.714773179259517, 13.77091407773305, 12.818312635115355, 11.840710172943787, 10.918663356164087, 9.912398691891319, 8.908067504713657, 7.977146245585895, 6.974285510924048, 6.022486858915825, 5.030438636524385, 4.0168217730618565, 3.045883636882003, 3.9643431691709248, 4.905721024126171], [4.895775166482013, 3.917019272738183, 2.955299395340875, 2.000302845824575, 3.047848506159469, 4.008439031167359, 4.962721917775291, 5.979790466850522, 6.92404455940941, 7.876453641431916, 8.919516589203846, 9.85923559429726, 10.789215279518306, 11.799676839160306, 12.74303305981054, 13.7523560548439, 14.804142388174263, 15.733346561045634, 16.75181493283404, 17.70975487829215, 3.931442773429887, 2.974148939059874, 2.0178136279240126, 1.0278216566822906, 2.0247232067587735, 3.03460988759731, 4.0470433238391, 5.050289898087424, 5.99559112043165, 6.956156448210773, 7.8885860292519006, 8.82140416306516, 9.874142841903165, 10.920917648636152, 11.967446555099352, 12.980044830515554, 14.044437333136823, 15.010516173607511, 16.034250633661404, 17.086206546538413, 2.979865240292802, 2.0341372344658506, 1.030491057589781, 0.0, 1.0549349515384827, 2.036592077618275, 3.060043736215742, 4.035472227442096, 5.01969931050979, 6.017624801286317, 6.951993110737198, 8.011859591518688, 9.04898289596561, 10.0985674569557, 11.091684810224768, 12.10596355275365, 13.153377909580987, 14.14097859864269, 15.140821789842578, 16.137970132221486, 3.9478845478878863, 3.0847218822618885, 2.0404164454569806, 1.0146188232069546, 2.0679871374625884, 3.0349686327171392, 3.9918597456568152, 5.020894121295585, 6.059186807890974, 6.9955364641263476, 7.977462119895454, 8.974006128393981, 10.022822280673086, 11.069490240441645, 12.143677220383505, 13.069720216350849, 14.000405595897453, 14.991893660542065, 15.91926581843265, 16.89792660025484, 4.879320229811993, 3.9264605350695208, 2.990765270795789, 1.9621542520471837, 3.0213077655013185, 4.074943617100802, 4.95879685403697, 5.888365112821085, 6.899031590161943, 7.9519809757150846, 8.907027948972264, 9.926809242679333, 10.954206872924786, 11.98487578482971, 12.950939327780649, 13.932665348214835, 14.937901319652957, 15.884767359908402, 16.920815559102653, 16.617236690617673, 5.86366898368337, 4.901332133322171, 3.919307830969603, 2.9634141906575135, 3.9607139565683718, 4.98560098966819, 5.911710263129981, 6.8875823958825135, 7.854170218650958, 8.79689716755338, 9.759304082177954, 10.6942021158226, 11.762782675622514, 12.775362279449645, 13.724454918397903, 14.687724993470328, 15.691609501724436, 16.692034270256155, 16.574340269516764, 15.619794132940275, 6.818841264625181, 5.914272568116949, 4.914507577339833, 3.9524193439738378, 4.905453487145449, 5.910671304544062, 6.83575925604876, 7.8026178569145435, 8.797656106995007, 9.723280171987824, 10.75551458452107, 11.688681347637694, 12.709389219663612, 13.654470650265141, 14.614705545149032, 15.57992008825108, 15.926325810586187, 16.50312616507276, 15.585348842720661, 14.63135551471909, 7.803395478643882, 6.847748922606895, 5.864882120559884, 4.999057331548185, 5.856225479345703, 6.839524709367324, 7.775615313303316, 8.751699302490426, 9.765461673350002, 10.706606632789823, 11.713493130986896, 12.628015562827873, 13.598623215061197, 14.5584789453059, 15.51949290555082, 15.862565941901407, 14.963411759492836, 15.560108634230563, 14.616000940150636, 13.613285630030486, 8.782046212545566, 7.772950224126271, 6.794926298709397, 5.983949031071391, 6.890557126917995, 7.7721235741149926, 8.786753411985705, 9.756998533041333, 10.743989473179603, 11.646629278967339, 12.601757844834943, 13.53724869687345, 14.471268319270873, 15.44849918033019, 15.793985325462824, 14.842885025779019, 13.986319654482653, 14.596115084888392, 13.657309572654192, 12.623491108910658, 9.771318970740419, 8.822135726689872, 7.807888581110088, 6.939030846825155, 7.907457286797938, 8.819532296253525, 9.75886044742365, 10.761475624983913, 11.727286327564148, 12.669352031104198, 13.534959460999591, 14.561448140868228, 15.474234198922598, 15.681654900638106, 14.799764082026234, 13.885940794411678, 12.926573567350816, 13.62923484813343, 12.620326330422108, 11.635144572496172, 10.715455969100468, 9.834706596348754, 8.880683089100053, 7.911703753038449, 8.84274783268292, 9.776883781860855, 10.747767823189184, 11.715633576263144, 12.68814122096715, 13.65741915816631, 14.557865221170376, 15.506341272918924, 15.661320882896579, 14.695556589912592, 13.777941927525635, 12.909192468544935, 11.977428404231665, 12.665332888208761, 11.749451513828282, 10.707885133769075, 11.671506738281096, 10.796258075274752, 9.808399592257544, 8.959866603547876, 9.810495597895159, 10.704382234266093, 11.743792955165308, 12.688708133329559, 13.653007905518807, 14.613877144376145, 15.503815293624237, 15.560643678081885, 14.670324666568122, 13.723669108249913, 12.782043607315726, 11.915473121574927, 10.983558603318619, 11.656724855334147, 10.675099490231403, 9.748571911720033, 12.665662965746375, 11.72241827203289, 10.795827164119192, 9.9411090531721, 10.803640381262179, 11.711430754150555, 12.685625067116984, 13.645173661637722, 14.60156518762168, 15.562474469067856, 15.560034910834517, 14.624564780978906, 13.680297643564797, 12.84757046017756, 11.85530578533511, 10.906270060227905, 9.948251186989175, 10.670110882875031, 9.670553492115367, 8.753173087937625, 13.717864960776735, 12.69456848267535, 11.748397893059492, 10.916535570654938, 11.826744909717526, 12.649867432283608, 13.623775962013225, 14.635099965019059, 15.558678376798085, 15.55318401906124, 14.62333300584414, 13.682413915665538, 12.689269116822304, 11.818462376921458, 10.848260281603537, 9.903692602959453, 8.995377448251789, 9.733508250634205, 8.70983383246617, 7.705339050769889, 14.67169084799434, 13.749460483774373, 12.760499185392469, 11.876326216740729, 12.828525715702977, 13.66557546324701, 14.593166542981171, 15.566524385144652, 15.586912605286047, 14.744269076801267, 13.680087991692066, 12.64402673047045, 11.648604126423903, 10.932156117103691, 9.87471219683828, 8.939936198781988, 7.93157753583932, 8.80991214025014, 7.82786889551556, 6.769235341831272, 15.689872760410548, 14.713882513468146, 13.704815964588734, 12.803860405950562, 13.76410001249656, 14.718842081098506, 15.619647873837373, 15.636212369135501, 14.643353632309868, 13.698304340536923, 12.691507298077829, 11.651821749244604, 10.706653034664637, 9.892062370518905, 8.93296521893173, 7.934168474711022, 6.917005902903241, 7.840242974649259, 6.8565258390545285, 5.824021812593758, 16.63924795252917, 15.625109529408236, 14.674142202848163, 13.80650897249089, 14.802635394797703, 15.650443936688983, 15.633219753423878, 14.674035522206662, 13.701641630826574, 12.721224194783126, 11.724213247066825, 10.745056758823855, 9.77529898867259, 8.931777364732536, 7.959174361554604, 6.8937768449247745, 5.948566611011315, 6.912198190424294, 5.911010705882922, 4.847572225783119, 17.16473961216456, 16.652264776113167, 15.745571574882055, 14.861501066626397, 15.844196729130713, 15.631908096463391, 14.699165818491839, 13.738972084750653, 12.72318871878278, 11.699236792945522, 10.767515844411728, 9.78852488348262, 8.840250676695156, 7.97589059297872, 7.0248100646892215, 5.999608171571236, 4.990150567860846, 5.949615379076583, 4.905072636283114, 3.918517647186908, 18.042407674742783, 17.70089268695948, 16.79183749823089, 15.884377165250443, 15.70711099969538, 14.633426699992405, 13.698095560832444, 12.75308167395015, 11.807048962715838, 10.772632440099967, 9.793633188974415, 8.867601462074086, 7.847818788918143, 6.904003084250117, 5.96421795638868, 4.9966502728143, 4.0093062917685165, 4.945907504802101, 5.859544948151551, 4.918374536958315, 18.59230895980458, 17.638940662971898, 16.628844905624426, 15.646727298653085, 14.710120866161223, 13.684282121669735, 12.740423020143268, 11.787821577525573, 10.810219115354005, 9.888172298574306, 8.881907634301538, 7.877576447123874, 6.946655187996114, 5.943794453334268, 4.991995801326045, 4.000094835854643, 2.988335533733772, 3.8947014547734495, 4.845893789924654, 5.871150046822337], [5.8710801094105936, 4.892324215666765, 3.9306043382694567, 2.975607788753157, 1.9929135546209862, 2.953504079628876, 3.9077869662368077, 4.924855515312039, 5.869109607870927, 6.821518689893433, 7.8645816376653634, 8.804300642758777, 9.734280327979823, 10.744741887621823, 11.688098108272056, 12.697421103305418, 13.74920743663578, 14.678411609507151, 15.69687998129556, 16.654819926753667, 4.906747716358469, 3.9494538819884557, 2.993118570852595, 2.003126599610873, 0.9697882552202909, 1.979674936058827, 2.992108372300617, 3.9953549465489413, 4.940656168893167, 5.9012214966722905, 6.833651077713418, 7.766469211526679, 8.819207890364684, 9.865982697097671, 10.912511603560871, 11.925109878977073, 12.989502381598342, 13.95558122206903, 14.979315682122923, 16.03127159499993, 4.034800191831284, 3.089072186004333, 2.0854260091282635, 1.0549349515384827, 0.0, 0.9816571260797923, 2.0051087846772595, 2.980537275903613, 3.964764358971306, 4.962689849747833, 5.897058159198714, 6.956924639980205, 7.994047944427126, 9.043632505417214, 10.036749858686283, 11.051028601215165, 12.098442958042503, 13.086043647104205, 14.085886838304093, 15.083035180683002, 5.002819499426368, 4.1396568338003705, 3.095351396995463, 2.0695537747454376, 1.0615731542830105, 1.9800336811786565, 2.9369247941183327, 3.9659591697571033, 5.004251856352492, 5.940601512587863, 6.92252716835697, 7.919071176855498, 8.967887329134603, 10.014555288903162, 11.088742268845023, 12.014785264812367, 12.945470644358972, 13.936958709003584, 14.86433086689417, 15.84299164871636, 5.934255181350475, 4.981395486608004, 4.045700222334272, 3.017089203585667, 2.02242868403461, 3.020008665562319, 3.9038619024984866, 4.833430161282602, 5.84409663862346, 6.897046024176602, 7.85209299743378, 8.87187429114085, 9.899271921386305, 10.929940833291228, 11.896004376242168, 12.877730396676354, 13.882966368114475, 14.82983240836992, 15.865880607564174, 16.79662492701804, 6.918603935221852, 5.92144044655501, 4.9394161442024425, 3.9835225038903532, 2.961834875101663, 3.9867219082014813, 4.856775311591498, 5.832647444344031, 6.799235267112475, 7.7419622160148975, 8.70436913063947, 9.639267164284117, 10.707847724084031, 11.720427327911162, 12.66951996685942, 13.632790041931845, 14.636674550185955, 15.637099318717675, 16.580538027537415, 16.543319954435685, 7.873776216163664, 6.87046246772856, 5.870697476951444, 4.895971726352327, 3.9065744056787404, 4.911792223077353, 5.813043772527836, 6.779902373393619, 7.743786383699433, 8.668345220449341, 9.700579632982587, 10.63374639609921, 11.654454268125129, 12.599535698726658, 13.55977059361055, 14.524985136712598, 15.554625772362714, 16.562118123597358, 16.50887466421607, 15.554881336214498, 8.8054774869607, 7.771274744102303, 6.788407942055292, 5.825972646025762, 4.857346397878994, 5.840645627900615, 6.776736231836607, 7.752820221023717, 8.749292987459713, 9.653312588629058, 10.66019908682613, 11.57308061128939, 12.543688263522714, 13.503543993767417, 14.464557954012337, 14.995258799961247, 15.895736645699941, 16.48363445572597, 15.539526761646044, 14.536811451525894, 9.769189470482587, 8.69647604562168, 7.718452120204805, 6.810864345548968, 5.891678045451286, 6.773244492648284, 7.787874330518997, 8.758119451574625, 9.745110391712895, 10.593335234806574, 11.548463800674178, 12.483954652712685, 13.417974275110108, 14.395205136169425, 14.868241769284866, 13.97557788383886, 14.918644540689758, 15.537499193848719, 14.5808353941496, 13.547016930406066, 10.694844792235827, 9.74566154818528, 8.731414402605497, 7.765946161302731, 6.90857820533123, 7.820653214786818, 8.759981365956941, 9.762596543517205, 10.72840724609744, 11.621541023000498, 12.481665416838826, 13.508154096707463, 14.420940154761833, 14.755911344460149, 13.874020525848277, 13.018633652471518, 13.858898453557922, 14.616378106070451, 13.607469588359129, 12.622287830433192, 11.638981790595876, 10.758232417844162, 9.804208910595461, 8.738619067516025, 7.84386875121621, 8.778004700394145, 9.748888741722475, 10.716754494796435, 11.689262139500443, 12.60960815006261, 13.50457117700961, 14.453047228758159, 14.613096846912084, 13.769813033734634, 12.852198371347678, 12.041885326604776, 12.90975329043877, 13.720267839747246, 12.736594771765303, 11.695028391706096, 12.595032559776504, 11.71978389677016, 10.731925413752952, 9.786781918025454, 8.81161651642845, 9.705503152799384, 10.744913873698598, 11.68982905186285, 12.6541288240521, 13.566066136272445, 14.450521249463472, 14.505708726543402, 13.61538971502964, 12.797925552071955, 11.856300051137769, 11.048165979634767, 11.915883489525724, 12.711659806872632, 11.662242748168424, 10.735715169657054, 13.589188787241783, 12.645944093528298, 11.715900611746692, 10.768024367649678, 9.80476129979547, 10.712551672683848, 11.686745985650276, 12.646294580171014, 13.602686106154973, 14.563595387601149, 14.505099959296034, 13.569629829440423, 12.625362692026314, 11.920673590810663, 10.929562229157153, 9.980526504049948, 10.88057607319628, 11.725045834413516, 10.725488443653852, 9.808108039476107, 14.641390782272143, 13.61464193030285, 12.668471340686992, 11.743450885132516, 10.827865828250816, 11.6509883508169, 12.624896880546517, 13.636220883552351, 14.559799295331377, 14.498249067522755, 13.568398054305655, 12.627478964127054, 11.634334165283821, 10.891565507554562, 9.92136341223664, 8.976795733592555, 9.927702334458894, 10.788443202172688, 9.764768784004653, 8.760274002308371, 15.595216669489748, 14.669533931401872, 13.680572633019969, 12.703241531218307, 11.829646634236267, 12.666696381780302, 13.594287461514464, 14.567645303677944, 14.531977653747564, 13.689334125262782, 12.625153040153581, 11.589091778931966, 10.59366917488542, 9.974060535483876, 8.916616615218464, 8.01303932941509, 8.863902422046426, 9.828164471663637, 8.882803847054042, 7.824170293369754, 16.60994620803805, 15.633955961095646, 14.624889412216234, 13.63077572042814, 12.869292309344546, 13.719962999631798, 14.620768792370665, 14.581277417597018, 13.588418680771385, 12.64336938899844, 11.636572346539348, 10.596886797706123, 9.651718083126154, 8.93396678889909, 7.974869637311915, 6.976072893091207, 7.849330789110345, 8.865619618086594, 7.9114607905930106, 6.87895676413224, 16.87790183019845, 16.530345586041715, 15.579378259481642, 14.633424286968468, 13.90782769164569, 14.651564855222276, 14.578284801885395, 13.619100570668179, 12.64670667928809, 11.666289243244643, 10.669278295528342, 9.690121807285372, 8.720364037134107, 7.9736817831127205, 7.001078779934788, 5.935681263304959, 6.880891497218419, 7.93757483386163, 6.965945657421404, 5.902507177321601, 16.109804660626075, 17.083391561224683, 16.61602120312273, 15.688416381103975, 14.958924464003827, 14.576973144924906, 13.644230866953356, 12.68403713321217, 11.668253767244297, 10.644301841407039, 9.712580892873245, 8.733589931944136, 7.785315725156673, 6.920955641440238, 5.9698751131507395, 4.944673220032753, 5.932254067944444, 6.924920322005166, 5.960007587821595, 4.97345259872539, 16.9874727232043, 17.509130274877453, 16.547592993584054, 15.596983857895857, 14.652176048156896, 13.57849174845392, 12.643160609293961, 11.698146722411668, 10.752114011177355, 9.717697488561484, 8.738698237435932, 7.812666510535604, 6.792883837379661, 5.849068132711635, 4.909283004850198, 3.941715321275817, 4.9514097918521145, 5.921212447730683, 6.8348498910801325, 5.893679479886897, 17.5373740082661, 16.584005711433417, 15.573909954085943, 14.591792347114602, 13.65518591462274, 12.62934717013125, 11.685488068604785, 10.73288662598709, 9.755284163815523, 8.833237347035823, 7.826972682763055, 6.822641495585391, 5.891720236457631, 4.888859501795785, 3.9370608497875628, 2.94515988431616, 3.958776747778689, 4.870006397702031, 5.821198732853237, 6.846454989750918], [6.852737235490386, 5.873981341746557, 4.912261464349249, 3.9572649148329493, 2.9745706807007783, 1.9718469535490837, 2.9261298401570155, 3.9431983892322475, 4.887452481791135, 5.839861563813641, 6.882924511585571, 7.822643516678985, 8.75262320190003, 9.76308476154203, 10.706440982192264, 11.715763977225626, 12.767550310555988, 13.696754483427359, 14.715222855215767, 15.673162800673873, 5.888404842438261, 4.931111008068248, 3.974775696932387, 2.984783725690665, 1.9514453813000832, 0.9980178099790348, 2.010451246220825, 3.013697820469149, 3.958999042813375, 4.919564370592498, 5.8519939516336255, 6.7848120854468865, 7.837550764284892, 8.884325571017879, 9.930854477481079, 10.943452752897281, 12.00784525551855, 12.973924095989238, 13.997658556043131, 15.049614468920135, 5.016457317911077, 4.070729312084126, 3.067083135208056, 2.036592077618275, 0.9816571260797923, 0.0, 1.0234516585974671, 1.9988801498238207, 2.983107232891514, 3.981032723668041, 4.915401033118922, 5.9752675139004126, 7.012390818347334, 8.061975379337422, 9.055092732606491, 10.069371475135373, 11.11678583196271, 12.104386521024413, 13.104229712224301, 14.10137805460321, 5.984476625506161, 5.121313959880163, 4.077008523075255, 3.044918001569236, 1.991549687313602, 0.9983765550988642, 1.9552676680385404, 2.9843020436773107, 4.022594730272699, 4.958944386508071, 5.940870042277178, 6.937414050775706, 7.986230203054812, 9.032898162823372, 10.107085142765232, 11.033128138732575, 11.96381351827918, 12.955301582923791, 13.882673740814377, 14.861334522636568, 6.915912307430268, 5.9567597134318016, 5.02106444915807, 3.9924534304094648, 2.952405217065202, 2.0383515394825267, 2.9222047764186945, 3.8517730352028097, 4.862439512543668, 5.9153888980968095, 6.870435871353988, 7.890217165061058, 8.917614795306513, 9.948283707211436, 10.914347250162376, 11.896073270596561, 12.901309242034683, 13.848175282290129, 14.884223481484382, 15.814967800938247, 7.865257309949484, 6.851416979585602, 5.8693926772330345, 4.913499036920945, 3.8918114081322552, 3.02742851587074, 3.875118185511706, 4.850990318264238, 5.817578141032683, 6.760305089935105, 7.7227120045596775, 8.657610038204325, 9.726190598004239, 10.73877020183137, 11.687862840779628, 12.651132915852052, 13.655017424106163, 14.655442192637883, 15.598880901457624, 16.665704127041998, 8.820429590891296, 7.800439000759152, 6.800674009982036, 5.825948259382919, 4.836550938709332, 3.9722576795895757, 4.831386646448044, 5.798245247313827, 6.762129257619641, 7.686688094369549, 8.718922506902794, 9.652089270019419, 10.672797142045336, 11.617878572646866, 12.578113467530757, 13.543328010632806, 14.572968646282922, 15.580460997517568, 16.53280644814734, 16.48485786924509, 9.735454019991291, 8.701251277132895, 7.718384475085884, 6.755949179056354, 5.787322930909586, 5.035494739690888, 5.833913036275175, 6.809997025462285, 7.7676358613799215, 8.671655462549266, 9.678541960746339, 10.591423485209598, 11.562031137442922, 12.521886867687625, 13.482900827932545, 14.511155746698304, 15.535882697376273, 16.523478528359764, 16.469503294676635, 15.466787984556486, 10.699166003513179, 9.626452578652271, 8.648428653235397, 7.74084087857956, 6.821654578481878, 5.968093604438557, 6.845051134957564, 7.815296256013192, 8.802287196151461, 9.611678108726782, 10.566806674594385, 11.502297526632892, 12.436317149030316, 13.413548010089633, 13.987868223752688, 14.890839164741784, 15.844290047080687, 16.46747572687931, 15.510811927180193, 14.476993463436658, 11.624821325266419, 10.675638081215872, 9.661390935636089, 8.695922694333323, 7.838554738361822, 7.01550232657709, 7.817158170395509, 8.81977334795577, 9.785584050536006, 10.639883896920706, 11.500008290759034, 12.52649697062767, 13.439283028682041, 13.87553779892797, 12.993646980316099, 13.933894933374443, 14.788915685793393, 15.546354639101043, 14.53744612138972, 13.552264363463784, 12.568958323626468, 11.688208950874754, 10.734185443626053, 9.668595600546617, 8.773845284246802, 8.016746890266107, 8.881592055119937, 9.849457808193897, 10.746438943939008, 11.627951023982817, 12.522914050929819, 13.471390102678367, 13.631439720832292, 12.889439488202456, 11.9718248258155, 12.9571466075077, 13.839770522674241, 14.656465274587042, 13.666571304795895, 12.625004924736688, 13.525009092807096, 12.649760429800752, 11.661901946783544, 10.716758451056045, 9.741593049459041, 8.944245342671346, 9.87761718709606, 10.822532365260312, 11.711305628490665, 12.584409010192653, 13.46886412338368, 13.52405160046361, 12.633732588949847, 11.917552006539777, 10.97592650560559, 11.963427260537692, 12.845900721761195, 13.66384518442101, 12.592219281199016, 11.665691702687646, 14.519165320272375, 13.57592062655889, 12.645877144777282, 11.698000900680269, 10.734737832826061, 9.951293862555808, 10.877479029907986, 11.837027624428725, 12.768472488953478, 13.619027786929257, 13.523442833216242, 12.58797270336063, 11.643705565946522, 10.982421261338105, 10.049188683624974, 10.895787784952873, 11.810593305431752, 12.706702960493308, 11.707145569733644, 10.789765165555899, 15.571367315302735, 14.54461846333344, 13.598447873717582, 12.673427418163106, 11.757842361281408, 10.889730540688861, 11.815629924804227, 12.826953927810061, 13.725585678129882, 13.516591941442963, 12.586740928225863, 11.645821838047262, 10.652677039204029, 9.953313178082004, 8.983111082764083, 9.89205701449548, 10.857719566694366, 11.77010032825248, 10.746425910084445, 9.741931128388163, 16.52519320252034, 15.599510464432463, 14.610549166050559, 13.633218064248897, 12.75962316726686, 11.905438571652262, 12.785020505772174, 13.758378347935654, 13.550320527667772, 12.70767699918299, 11.643495914073789, 10.607434652852174, 9.612012048805628, 9.029238990311464, 7.971795070046053, 8.928300610318015, 9.845559548126218, 10.80982159774343, 9.864460973133834, 8.805827419449546, 16.840151366772428, 16.563932494126238, 15.554865945246824, 14.56075225345873, 13.799268842375138, 12.958705189503759, 13.811501836628373, 13.599620291517226, 12.606761554691593, 11.661712262918648, 10.654915220459555, 9.61522967162633, 8.670060957046362, 7.9891452437266794, 7.030048092139504, 7.957730019170999, 8.830987915190137, 9.847276744166386, 8.893117916672804, 7.860613890212033, 15.896244704118656, 16.91038312723959, 16.50935479251223, 15.563400819999059, 14.837804224676281, 13.890307045094236, 13.596627675805603, 12.637443444588387, 11.665049553208299, 10.68463211716485, 9.68762116944855, 8.70846468120558, 7.738706911054315, 7.004845560155757, 6.056257234762377, 6.917338389384751, 7.862548623298212, 8.919231959941422, 7.947602783501197, 6.884164303401394, 15.128147534546283, 16.10173443514489, 16.48943209143218, 15.561827269413426, 14.57913160690911, 13.595316018845114, 12.662573740873563, 11.702380007132378, 10.686596641164504, 9.662644715327247, 8.730923766793453, 7.751932805864343, 6.803658599076881, 5.939298515360446, 4.988217987070947, 5.926330346112545, 6.913911194024236, 7.906577448084958, 6.941664713901389, 5.955109724805183, 16.005815597124503, 16.52747314879766, 15.565935867504262, 14.615326731816065, 13.670518922077104, 12.596834622374129, 11.661503483214169, 10.716489596331876, 9.770456885097563, 8.736040362481692, 7.75704111135614, 6.831009384455812, 5.811226711299869, 4.867411006631843, 3.9276258787704057, 4.923372447355609, 5.933066917931907, 6.9028695738104755, 7.816507017159925, 6.875336605966689, 16.555716882186307, 15.602348585353624, 14.592252828006151, 13.61013522103481, 12.673528788542948, 11.647690044051458, 10.703830942524993, 9.751229499907298, 8.77362703773573, 7.851580220956031, 6.845315556683262, 5.840984369505599, 4.9100631103778385, 3.9072023757159933, 2.95540372370777, 3.9268170103959523, 4.940433873858481, 5.8516635237818235, 6.802855858933029, 7.82811211583071], [7.876188894087855, 6.897433000344026, 5.935713122946717, 4.980716573430417, 3.998022339298246, 2.981401139250004, 2.0376045779648457, 3.019371506258522, 3.8640008231936678, 4.816409905216174, 5.859472852988105, 6.799191858081519, 7.729171543302566, 8.739633102944564, 9.682989323594798, 10.69231231862816, 11.744098651958522, 12.673302824829893, 13.691771196618301, 14.649711142076407, 6.91185650103573, 5.9545626666657165, 4.998227355529855, 4.008235384288133, 2.9748970398975505, 2.007571995679955, 0.9951385594381645, 1.9902461618716818, 2.9355473842159077, 3.8961127119950314, 4.828542293036159, 5.76136042684942, 6.814099105687425, 7.860873912420412, 8.907402818883611, 9.920001094299813, 10.984393596921082, 11.95047243739177, 12.974206897445663, 14.026162810322669, 6.039908976508543, 5.094180970681592, 4.0905347938055225, 3.060043736215742, 2.0051087846772595, 1.0234516585974671, 0.0, 0.9754284912263534, 1.9596555742940467, 2.957581065070574, 3.891949374521455, 4.951815855302946, 5.988939159749867, 7.038523720739956, 8.031641074009025, 9.045919816537907, 10.093334173365244, 11.080934862426947, 12.080778053626835, 13.077926396005743, 7.0079282841036274, 6.106530845151723, 5.062225408346816, 4.00262614196637, 2.9492578277107357, 1.9560846954959983, 0.9991935825563222, 2.0238131862606332, 3.011181102479725, 3.9354927279106042, 4.917418383679711, 5.91396239217824, 6.962778544457346, 8.009446504225906, 9.083633484167766, 10.00967648013511, 10.940361859681714, 11.931849924326325, 12.859222082216911, 13.837882864039102, 7.884720875978725, 6.914467853828936, 5.978772589555204, 4.950161570806599, 3.9101133574623352, 2.996059679879661, 1.9661306909364762, 2.8956989497205914, 3.9063654270614494, 4.9499873379450925, 5.846984212756521, 6.866765506463592, 7.894163136709046, 8.924832048613968, 9.890895591564908, 10.872621611999094, 11.877857583437217, 12.824723623692662, 13.860771822886916, 14.79151614234078, 8.822965450346617, 7.809125119982735, 6.827100817630167, 5.871207177318078, 4.849519548529388, 3.9665768348685315, 2.9190441000294878, 3.89491623278202, 4.861504055550464, 5.804231004452887, 6.766637919077459, 7.7015359527221054, 8.77011651252202, 9.78269611634915, 10.731788755297408, 11.695058830369833, 12.698943338623941, 13.699368107155662, 14.642806815975403, 15.709630041559777, 9.778137731288428, 8.758147141156286, 7.75838215037917, 6.783656399780052, 5.794259079106466, 4.8004005124705245, 3.8753125609658254, 4.842171161831608, 5.806055172137422, 6.73061400888733, 7.762848421420575, 8.696015184537199, 9.716723056563117, 10.661804487164646, 11.622039382048538, 12.587253925150586, 13.616894560800702, 14.624386912035346, 15.57673236266512, 16.530725690666692, 10.693162160388425, 9.658959417530028, 8.676092615483016, 7.713657319453487, 6.74503107130672, 5.813929554728948, 4.877838950792956, 5.853922939980066, 6.811561775897703, 7.715581377067047, 8.72246787526412, 9.635349399727378, 10.605957051960702, 11.565812782205406, 12.526826742450325, 13.555081661216084, 14.579808611894054, 15.567404442877544, 16.51151213695747, 16.42449612495362, 11.656874143910311, 10.584160719049404, 9.60613679363253, 8.698549018976692, 7.7588594471210595, 6.746528419476617, 5.888977049475345, 6.859222170530973, 7.846213110669243, 8.655604023244564, 9.610732589112168, 10.546223441150675, 11.480243063548098, 12.457473924607415, 13.485671522702612, 14.44488334992948, 15.398334232268382, 16.367629885479538, 16.468520067577323, 15.43470160383379, 12.582529465663551, 11.633346221613005, 10.619099076033221, 9.653630834730455, 8.775759607001003, 7.7939371416151495, 6.861084084913291, 7.863699262473552, 8.829509965053788, 9.683809811438488, 10.543934205276816, 11.570422885145453, 12.483208943199823, 13.29158537003491, 14.00320116601702, 14.943449119075364, 15.798469871494314, 16.504062779498177, 15.495154261786853, 14.509972503860917, 13.5266664640236, 12.645917091271887, 11.691893584023186, 10.626303740943749, 9.711050152885983, 8.795181705304167, 7.925517969637717, 8.893383722711677, 9.79036485845679, 10.6718769385006, 11.5668399654476, 12.515316017196149, 12.853851521022854, 12.305487059309396, 12.98137901151642, 13.966700793208622, 14.849324708375162, 15.614173414984174, 14.624279445193027, 13.58271306513382, 14.482717233204228, 13.607468570197884, 12.619610087180677, 11.674466591453179, 10.678797918098223, 9.722680157709405, 8.92154310161384, 9.866458279778092, 10.755231543008447, 11.628334924710435, 12.512790037901462, 12.746463400654171, 11.85614438914041, 11.333599577646718, 11.985480691306512, 12.972981446238613, 13.855454907462116, 14.621553324818143, 13.549927421596148, 12.623399843084778, 15.476873460669507, 14.533628766956022, 13.603585285174416, 12.655709041077403, 11.671942701465243, 10.729728677593869, 9.921404944425767, 10.880953538946505, 11.81239840347126, 12.662953701447039, 12.745854633406804, 11.810384503551193, 10.866117366137084, 10.369007167405211, 11.058742869325895, 11.905341970653794, 12.820147491132673, 13.688268214311845, 12.688710823552181, 11.767081651050898, 16.529075455699868, 15.502326603730575, 14.556156014114716, 13.63113555856024, 12.66338623487581, 11.668165355726922, 10.859555839322008, 11.870879842327842, 12.769511592647664, 12.688731073428082, 11.758880060210982, 10.868233638237825, 9.875088839394591, 9.33989908414911, 9.992665268465004, 10.9016112001964, 11.867273752395286, 12.751665582071018, 11.727991163902983, 10.7234963822067, 16.73668989530229, 16.557218604829597, 15.568257306447693, 14.590926204646031, 13.649728510848103, 12.683873386690323, 11.828946420289954, 12.802304262453434, 12.568793603820252, 11.751089657405593, 10.815635046058908, 9.829846453042737, 8.83442384899619, 8.339849217929196, 8.981349255746974, 9.937854796018936, 10.858952631172233, 11.823214680789444, 10.84610421327743, 9.787392673268084, 15.816699708174962, 16.792689955117364, 16.51257408564396, 15.518460393855865, 14.689374185956382, 13.73714000454182, 12.855427751146156, 12.618093367669706, 11.625234630844073, 10.680185339071128, 9.767942724386426, 8.837641471816891, 7.8924727572369235, 7.290695624606254, 8.039602277840425, 8.971123102217017, 9.844380998236154, 10.860669827212403, 9.91656957527027, 8.884065548809499, 14.87279304552119, 15.886931468642125, 16.454178527322423, 15.508224554809251, 14.495910805763035, 13.511233961913184, 12.577129922882559, 11.655916520740867, 10.683522629360779, 9.703105193317331, 8.728707052055494, 7.887345072591266, 6.961118711244877, 6.2360855341808445, 7.065811420463297, 7.930731472430769, 8.875941706344229, 9.93262504298744, 8.971054442098664, 7.90761596199886, 14.104695875948817, 15.078282776547423, 15.465980432834716, 14.53837561081596, 13.555679948311644, 12.571864360247648, 11.639122082276097, 10.720853083284858, 9.705069717316984, 8.681117791479727, 7.772009649400397, 6.868132147053848, 6.026070399267443, 5.1705384893855335, 5.997772172771867, 6.939723429158563, 7.927304277070254, 8.929912574287929, 7.965116372498855, 6.978561383402649, 14.982363938527037, 15.504021490200197, 14.542484208906796, 13.5918750732186, 12.647067263479638, 11.573382963776663, 10.638051824616703, 9.693037937734411, 8.763430669908404, 7.754513438634173, 6.775514187508621, 5.849482460608293, 5.033638511490431, 4.098650980656931, 4.937180064471326, 5.936765530401627, 6.9464600009779245, 7.926204700013447, 8.839958675757392, 7.898788264564158, 15.532265223588842, 14.578896926756158, 13.568801169408685, 12.586683562437344, 11.650077129945482, 10.624238385453992, 9.680379283927527, 8.727777841309834, 7.750175379138264, 6.835078728369313, 5.8288140640965445, 4.846795082744149, 3.986236227404113, 3.0916782418230877, 3.9649579094086906, 4.95026866899342, 5.963885532455949, 6.875115182379291, 7.826307517530497, 8.85156377442818], [8.851617385314208, 7.8728614915703785, 6.9111416141730695, 5.95614506465677, 4.973450830524599, 3.956829630476357, 3.0130330691911986, 2.043943015032168, 2.8885723319673144, 3.8409814139898204, 4.884044361761751, 5.8237633668551645, 6.753743052076211, 7.764204611718211, 8.707560832368443, 9.716883827401805, 10.768670160732167, 11.697874333603538, 12.716342705391947, 13.674282650850053, 7.8872849922620825, 6.929991157892069, 5.973655846756208, 4.983663875514486, 3.950325531123904, 2.983000486906308, 1.9705670506645179, 1.0148176706453285, 1.9601188929895543, 2.920684220768678, 3.8531138018098052, 4.785931935623066, 5.838670614461071, 6.885445421194058, 7.931974327657258, 8.94457260307346, 10.00896510569473, 10.975043946165417, 11.99877840621931, 13.050734319096316, 7.015337467734898, 6.069609461907946, 5.065963285031877, 4.035472227442096, 2.980537275903613, 1.9988801498238207, 0.9754284912263534, 0.0, 0.9842270830676934, 1.9821525738442205, 2.9165208832951013, 3.976387364076592, 5.013510668523513, 6.0630952295136025, 7.0562125827826705, 8.070491325311554, 9.117905682138892, 10.105506371200594, 11.105349562400482, 12.10249790477939, 7.983356775329982, 7.081959336378076, 6.037653899573169, 4.978054633192723, 3.9246863189370895, 2.9315131867223516, 1.9746220737826756, 1.04838469503428, 2.035752611253371, 2.960064236684251, 3.941989892453357, 4.938533900951885, 5.987350053230991, 7.034018012999551, 8.108204992941412, 9.034247988908756, 9.96493336845536, 10.956421433099973, 11.883793590990559, 12.86245437281275, 8.860149367205079, 7.8898963450552895, 6.954201080781558, 5.925590062032953, 4.885541848688689, 3.9714881711060137, 2.9271370332680147, 1.9975687744838995, 3.0082352518247575, 3.9745588467187396, 4.871555721530167, 5.891337015237237, 6.918734645482691, 7.949403557387614, 8.915467100338553, 9.897193120772739, 10.902429092210864, 11.84929513246631, 12.885343331660563, 13.816087651114428, 9.79839394157297, 8.784553611209088, 7.802529308856521, 6.846635668544431, 5.824948039755742, 4.92758317720007, 3.8800504423610263, 3.028592058830463, 3.995179881598907, 4.9123380653512045, 5.87050327781116, 6.805401311455807, 7.867734463280873, 8.880314067108005, 9.829406706056263, 10.792676781128687, 11.796561289382797, 12.785133792484496, 13.728572501304237, 14.79539572688861, 10.753566222514781, 9.730512734250496, 8.73074774347338, 7.756021992874262, 6.766624672200676, 5.761406854802063, 4.836318903297364, 4.027156811018388, 4.9397309981858655, 5.838721069785648, 6.870955482318893, 7.804122245435517, 8.814341007321971, 9.7594224379235, 10.719657332807392, 11.68487187590944, 12.714512511559557, 13.71015259736418, 14.662498047993955, 15.616491375995526, 11.665527753482635, 10.631325010624238, 9.648458208577226, 8.686022912547697, 7.71739666440093, 6.774935897060487, 5.838845293124495, 5.061110672736561, 5.945237601946146, 6.823688437965365, 7.830574936162439, 8.743456460625696, 9.71406411285902, 10.673919843103723, 11.634933803348643, 12.652699611974938, 13.677426562652908, 14.653170128206378, 15.597277822286305, 16.606029930414273, 12.629239737004522, 11.556526312143614, 10.57850238672674, 9.670914612070902, 8.719865789452598, 7.707534761808156, 6.849983391806885, 6.111751232956307, 7.0076739852440975, 7.763711084142881, 8.718839650010484, 9.65433050204899, 10.588350124446414, 11.565580985505731, 12.593778583600928, 13.552990410827796, 14.506441293166699, 15.475736946377854, 16.432400746076972, 16.407067196928, 13.554895058757761, 12.605711814707215, 11.591464669127431, 10.625996427824665, 9.736765949332542, 8.75494348394669, 7.82209042724483, 7.116228324898885, 7.990970839628642, 8.791916872336806, 9.652041266175132, 10.678529946043769, 11.59131600409814, 12.567438480527825, 13.560874340614191, 14.509934642195137, 15.560187887957314, 16.442617183132814, 16.46751985488106, 15.482338096955127, 14.49903205711781, 13.618282684366097, 12.664259177117396, 11.59866933403796, 10.672056495217522, 9.756188047635707, 8.886524311969257, 8.160343004298042, 8.951825733031644, 9.779983999398917, 10.674947026345917, 11.623423078094465, 11.878423029796501, 12.751834112203912, 13.691206477395438, 14.685522062661754, 15.648729419184397, 16.55683070943309, 15.596645038287237, 14.55507865822803, 15.455082826298439, 14.579834163292094, 13.591975680274887, 12.644810820167777, 11.639804260429761, 10.683686500040945, 9.882549443945381, 9.133417561364457, 9.9166924175833, 10.736441985608753, 11.620897098799778, 11.771034909427819, 10.880715897914056, 11.779946630541234, 12.72157213147542, 13.765220294526836, 14.65485961827135, 15.548222676558474, 14.522293014690359, 13.595765436178988, 16.44923905376372, 15.505994360050233, 14.573929513889015, 13.626053269792001, 12.632949043796781, 11.690735019925409, 10.882411286757307, 10.202404343280065, 10.973859278046113, 11.771060762345357, 11.770426142180451, 10.83495601232484, 9.890688874910731, 10.815354220299728, 11.82252583322244, 12.704746681463027, 13.619552201941907, 14.561608704099358, 13.664139314778534, 12.739447244145108, 16.638555781889625, 16.472670832445175, 15.526500242829314, 14.601479787274839, 13.62439257720735, 12.629171698058462, 11.820562181653548, 11.24528876824451, 11.930972467222517, 11.71330258220173, 10.78345156898463, 9.892805147011472, 8.899660348168238, 9.786246137043626, 10.756448232361548, 11.701015911005634, 12.66667846320452, 13.681930822327178, 12.703419655129336, 11.698924873433054, 15.822455580631125, 16.872407033943425, 16.538601535162293, 15.56127043336063, 14.610734853179643, 13.644879729021863, 12.789952762621494, 12.18438760411369, 11.593365112593899, 10.77566116617924, 9.840206554832555, 8.854417961816385, 7.858995357769837, 8.786196270823712, 9.80542516673702, 10.761930707008982, 11.77028936995165, 12.734551419568861, 11.821532704503783, 10.762821164494436, 14.84127121694861, 15.817261463891011, 16.4480762743555, 15.457421333021408, 14.49718172647541, 13.467407326277309, 12.55051714169365, 11.642664876443353, 10.64980613961772, 9.704756847844775, 8.792514233160073, 7.862212980590538, 6.91704426601057, 7.948754714280791, 8.863678188830471, 9.903400747594052, 10.819809489462509, 11.836098318438758, 10.891998066496624, 9.859494040035854, 13.897364554294837, 14.911502977415772, 15.478750036096072, 14.532796063582898, 13.520482314536682, 12.535805470686832, 11.601701431656204, 10.680488029514514, 9.708094138134426, 8.727676702090978, 7.753278560829141, 6.911916581364913, 5.985690220018523, 6.917284328275413, 7.889887331453345, 8.906159963657123, 9.851370197570583, 10.908053534213794, 9.946482933325019, 8.883044453225216, 13.129267384722464, 14.10285428532107, 14.490551941608363, 13.562947119589607, 12.580251457085291, 11.596435869021295, 10.663693591049743, 9.745424592058505, 8.729641226090632, 7.705689300253375, 6.796581158174044, 5.8927036558274954, 5.050641908041089, 6.036279182718952, 6.97320066399822, 7.915151920384916, 8.902732768296607, 9.905341065514282, 8.94054486372521, 7.953989874629004, 14.006935447300684, 14.528592998973844, 13.567055717680443, 12.616446581992246, 11.671638772253285, 10.59795447255031, 9.662623333390348, 8.717609446508057, 7.788002178682049, 6.77908494740782, 5.800085696282268, 4.87405396938194, 4.058210020264077, 5.002025724932103, 5.912608555697679, 6.91219402162798, 7.921888492204277, 8.9016331912398, 9.815387166983747, 8.874216755790512, 14.556836732362488, 13.603468435529804, 12.59337267818233, 11.611255071210989, 10.674648638719127, 9.64880989422764, 8.704950792701172, 7.752349350083478, 6.77474688791191, 5.859650237142959, 4.853385572870191, 3.8713665915177957, 3.0108077361777594, 4.037073899763654, 4.9403864006350435, 5.925697160219773, 6.939314023682302, 7.850543673605644, 8.80173600875685, 9.826992265654534], [9.835844468381898, 8.85708857463807, 7.8953686972407615, 6.940372147724462, 5.950242962451303, 4.890748725870208, 3.9364658392622762, 2.919397290187044, 1.9103620616863135, 2.8627711437088195, 3.90583409148075, 4.845553096574164, 5.775532781795211, 6.785994341437211, 7.729350562087444, 8.738673557120805, 9.790459890451167, 10.719664063322538, 11.738132435110947, 12.696072380569053, 8.871512075329774, 7.9142182409597615, 6.9578829298239, 5.967890958582178, 4.934552614191596, 3.9672275699740016, 2.9547941337322112, 1.9272098450527793, 0.9819086227085535, 1.9424739504876771, 2.8749035315288043, 3.8077216653420654, 4.86046034418007, 5.907235150913057, 6.953764057376257, 7.9663623327924595, 9.03075483541373, 9.996833675884417, 11.02056813593831, 12.066507236028622, 7.99956455080259, 7.053836544975638, 6.050190368099569, 5.019699310509789, 3.9647643589713057, 2.9831072328915136, 1.9596555742940467, 0.9842270830676934, 0.0, 0.9979254907765271, 1.9322938002274082, 2.9921602810088985, 4.02928358545582, 5.07886814644591, 6.071985499714978, 7.08626424224386, 8.133678599071198, 9.1212792881329, 10.121122479332788, 11.118270821711697, 8.967583858397674, 8.06618641944577, 7.021880982640862, 5.962281716260416, 4.908913402004782, 3.915740269790045, 2.958849156850369, 2.0326117781019732, 1.051525528185678, 1.9758371536165573, 2.957762809385664, 3.9543068178841922, 5.003122970163298, 6.049790929931858, 7.123977909873718, 8.050020905841063, 8.980706285387667, 9.972194350032279, 10.899566507922865, 11.878227289745055, 9.84437645027277, 8.874123428122981, 7.938428163849251, 6.909817145100646, 5.869768931756382, 4.9557152541737075, 3.911364116335708, 2.981795857551593, 2.060888223727988, 2.990331763651046, 3.8873286384624746, 4.907109932169544, 5.934507562414998, 6.965176474319921, 7.93124001727086, 8.912966037705045, 9.91820200914317, 10.865068049398616, 11.901116248592869, 12.831860568046734, 10.782621024640664, 9.768780694276781, 8.786756391924214, 7.830862751612124, 6.809175122823435, 5.911810260267764, 4.86427752542872, 4.012819141898157, 3.1020511007317215, 3.9281109822835107, 4.886276194743467, 5.821174228388114, 6.88350738021318, 7.896086984040311, 8.845179622988569, 9.808449698060993, 10.812334206315104, 11.800906709416802, 12.744345418236543, 13.811168643820917, 11.737793305582475, 10.71473981731819, 9.714974826541074, 8.740249075941955, 7.750851755268369, 6.745633937869756, 5.820545986365057, 5.011383894086082, 4.04660221731868, 4.854493986717954, 5.886728399251199, 6.819895162367823, 7.830113924254277, 8.775195354855807, 9.735430249739698, 10.700644792841747, 11.730285428491863, 12.725925514296486, 13.678270964926261, 14.632264292927832, 12.64975483655033, 11.615552093691932, 10.63268529164492, 9.670249995615391, 8.701623747468624, 7.75916298012818, 6.823072376192188, 6.045337755804255, 5.052108821078961, 5.839461354897671, 6.846347853094745, 7.759229377558002, 8.729837029791327, 9.68969276003603, 10.65070672028095, 11.668472528907245, 12.693199479585214, 13.668943045138684, 14.613050739218611, 15.621802847346581, 13.613466820072215, 12.540753395211308, 11.562729469794434, 10.655141695138596, 9.704092872520292, 8.691761844875849, 7.834210474874578, 7.095978316024, 6.114545204376912, 6.779484001075187, 7.73461256694279, 8.670103418981297, 9.60412304137872, 10.581353902438037, 11.609551500533234, 12.568763327760102, 13.522214210099005, 14.49150986331016, 15.448173663009278, 16.48199212675281, 14.539122141825455, 13.589938897774909, 12.575691752195125, 11.610223510892359, 10.720993032400235, 9.739170567014382, 8.806317510312523, 8.10045540796658, 7.097842058761457, 7.807689789269112, 8.667814183107438, 9.694302862976075, 10.607088921030446, 11.583211397460131, 12.576647257546497, 13.525707559127444, 14.57596080488962, 15.458390100065122, 16.467298617776446, 16.466565180022823, 15.483259140185504, 14.60250976743379, 13.64848626018509, 12.582896417105653, 11.656283578285215, 10.740415130703399, 9.87075139503695, 9.055205727537198, 8.058696952164459, 8.795756916331223, 9.690719943278223, 10.639195995026771, 11.622852423130281, 12.569309708185646, 13.508682073377171, 14.502455884994188, 15.525105968008772, 16.469316891224857, 16.580872121354933, 15.539305741295724, 16.439309909366134, 15.564061246359788, 14.57620276334258, 13.62903790323547, 12.624031343497455, 11.667913583108637, 10.866776527013073, 9.989373109013172, 9.023563636716116, 9.75221490254106, 10.636670015732085, 10.951121309304549, 11.692841582206924, 12.592072314834102, 13.533697815768289, 14.577345978819704, 15.466985302564217, 16.36034836085134, 15.506520097758052, 14.579992519246682, 16.56942551163069, 16.490221443117925, 15.558156596956708, 14.610280352859695, 13.617176126864475, 12.6749621029931, 11.866638369824999, 11.037122023162887, 10.080730497178928, 10.786833679277663, 10.817931902524602, 10.01504241220157, 10.702814559203599, 11.627479904592596, 12.634651517515307, 13.516872365755892, 14.431677886234773, 15.373734388392224, 14.648366397846228, 13.723674327212802, 15.654328698821931, 16.715564546356003, 16.510727325897008, 15.585706870342532, 14.60861966027504, 13.613398781126152, 12.80478926472124, 12.030237334124104, 11.037843686355332, 10.735092311920727, 9.805241298703628, 9.053749468116276, 9.711786032461106, 10.598371821336494, 11.568573916654415, 12.5131415952985, 13.478804147497385, 14.494056506620044, 13.68764673819703, 12.683151956500748, 14.838228497563431, 15.888179950875733, 16.414182783270768, 15.406745251950241, 14.508318798005586, 13.542463673847806, 12.59878820226885, 11.648304313017972, 10.615154842312899, 9.79745089589824, 8.861996284551553, 8.01536228292119, 8.671121042062705, 9.59832195511658, 10.617550851029888, 11.57405639130185, 12.582415054244517, 13.546677103861729, 12.805759787571477, 11.74704824756213, 13.857044133880915, 14.833034380823317, 15.4698660040745, 14.479211062740408, 13.51897145619441, 12.489197055996309, 11.57230687141265, 10.664454606162353, 9.67159586933672, 8.726546577563775, 7.814303962879071, 6.987952549456413, 7.7291699503034375, 8.76088039857366, 9.67580387312334, 10.71552643188692, 11.662281630745166, 12.678570459721415, 11.876225149564316, 10.843721123103546, 12.913137471227143, 13.927275894348078, 14.500539765815072, 13.554585793301898, 12.542272044255682, 11.557595200405832, 10.623491161375204, 9.702277759233514, 8.729883867853426, 7.749466431809978, 6.775068290548139, 5.933706311083912, 6.797815904311391, 7.72941001256828, 8.702013015746212, 9.74863210493978, 10.69384233885324, 11.750525675496451, 10.93071001639271, 9.867271536292908, 12.14504030165477, 13.118627202253377, 13.512341671327363, 12.584736849308607, 11.602041186804291, 10.618225598740295, 9.685483320768743, 8.767214321777505, 7.7514309558096315, 6.727479029972374, 5.8183708878930425, 4.9144933855464945, 5.862767592333957, 6.84840486701182, 7.815672805280879, 8.757624061667574, 9.745204909579266, 10.747813206796941, 9.924771946792902, 8.938216957696696, 13.02270836423299, 13.550382728692844, 12.588845447399443, 11.638236311711246, 10.693428501972285, 9.61974420226931, 8.684413063109348, 7.739399176227057, 6.809791908401049, 5.800874677126819, 4.8218754260012675, 3.895843699100939, 4.871479864450873, 5.815295569118899, 6.755080696980337, 7.754666162910638, 8.764360633486936, 9.744105332522459, 10.77897136927944, 9.858443838858202, 13.578626462081488, 12.625258165248804, 11.61516240790133, 10.633044800929989, 9.696438368438127, 8.67059962394664, 7.726740522420173, 6.774139079802478, 5.79653661763091, 4.881439966861958, 3.8751753025891897, 2.893156321236795, 3.8240775803645555, 4.85034374395045, 5.802142395958674, 6.805691804056371, 7.8193086675189, 8.834770756673336, 9.785963091824541, 10.811219348722224], [10.833769959158426, 9.855014065414597, 8.89329418801729, 7.938297638500989, 6.946705892466716, 5.887211655885621, 4.932928769277689, 3.9158602202024575, 2.9068249917017264, 2.0568570770436203, 3.019594735338748, 3.92088537103133, 4.850865056252376, 5.8613266158943755, 6.804682836544609, 7.81400583157797, 8.865792164908333, 9.794996337779704, 10.813464709568112, 11.771404655026219, 9.869437566106301, 8.912143731736288, 7.955808420600428, 6.965816449358705, 5.932478104968124, 4.965153060750529, 3.9527196245087386, 2.923672775068192, 1.9783715527239663, 1.0178062249448425, 1.9502358059859697, 2.8830539397992307, 3.935792618637236, 4.982567425370223, 6.029096331833423, 7.0277373399025125, 8.092129842523782, 9.05820868299447, 10.081943143048363, 11.068581745252095, 8.997490041579116, 8.051762035752166, 7.048115858876097, 6.017624801286316, 4.962689849747833, 3.981032723668041, 2.957581065070574, 1.9821525738442205, 0.9979254907765271, 0.0, 0.934368309450881, 1.9942347902323714, 3.031358094679293, 4.080942655669382, 5.07406000893845, 6.088338751467333, 7.13575310829467, 8.123353797356373, 9.123196988556261, 10.12034533093517, 9.965509349174202, 9.064111910222298, 8.01980647341739, 6.960207207036944, 5.90683889278131, 4.913665760566572, 3.9567746476268963, 2.974385409566371, 1.9360927229709826, 0.9779116628400302, 1.9598373186091367, 2.956381327107665, 4.005197479386771, 5.051865439155331, 6.12605241909719, 7.052095415064534, 7.9827807946111395, 8.974268859255751, 9.901641017146337, 10.880301798968528, 10.842301941049298, 9.872048918899509, 8.936353654625778, 7.907742635877173, 6.867694422532909, 5.92406546139437, 4.853137747800106, 3.9235694890159905, 2.9454554185132924, 1.9924062728745189, 2.889403147685947, 3.909184441393017, 4.936582071638471, 5.967250983543393, 6.933314526494333, 7.915040546928518, 8.920276518366643, 9.867142558622088, 10.903190757816342, 11.833935077270207, 11.780546515417191, 10.766706185053309, 9.784681882700742, 8.828788242388653, 7.807100613599962, 6.8535838917321605, 5.806051156893117, 4.839500263177851, 3.872912440409407, 2.930185491506984, 3.88835070396694, 4.8232487376115865, 5.8855818894366525, 6.898161493263784, 7.847254132212042, 8.810524207284466, 9.814408715538576, 10.802981218640275, 11.746419927460016, 12.81324315304439, 12.696147656700374, 11.656513448782588, 10.656748458005472, 9.682022707406354, 8.692625386732766, 7.6874075693341535, 6.762319617829455, 5.812501807076829, 4.8174635569963655, 3.856568495941427, 4.888802908474672, 5.821969671591296, 6.83218843347775, 7.77726986407928, 8.737504758963171, 9.70271930206522, 10.732359937715335, 11.728000023519959, 12.680345474149734, 13.634338802151305, 13.591528468014726, 12.557325725156328, 11.574458923109317, 10.612023627079788, 9.64339737893302, 8.700936611592578, 7.764846007656586, 6.796443194420542, 5.782680823560966, 4.841535864121144, 5.848422362318217, 6.761303886781475, 7.731911539014799, 8.691767269259502, 9.652781229504422, 10.670547038130717, 11.695273988808687, 12.671017554362157, 13.615125248442084, 14.623877356570054, 14.555240451536612, 13.482527026675704, 12.50450310125883, 11.596915326602993, 10.64586650398469, 9.633535476340247, 8.731846390555624, 7.761601269499996, 6.774610329361726, 5.78155851029866, 6.7366870761662625, 7.67217792820477, 8.606197550602193, 9.58342841166151, 10.611626009756707, 11.570837836983575, 12.524288719322477, 13.493584372533633, 14.450248172232751, 15.484066635976285, 15.480895773289852, 14.531712529239305, 13.517465383659522, 12.551997142356756, 11.662766663864634, 10.68094419847878, 9.70395342599357, 8.766078361442576, 7.751830002032635, 6.809764298492585, 7.669888692330912, 8.69637737219955, 9.609163430253918, 10.585285906683604, 11.57872176676997, 12.527782068350916, 13.578035314113093, 14.460464609288595, 15.469373126999917, 16.45455488492585, 16.4250327716499, 15.544283398898187, 14.590259891649486, 13.52467004857005, 12.582079414388602, 11.647943465210666, 10.677059423882337, 9.709193670808377, 8.712684895435638, 7.797831425554697, 8.692794452501698, 9.641270504250246, 10.624926932353754, 11.571384217409118, 12.510756582600644, 13.50453039421766, 14.527180477232244, 15.471391400448331, 16.461285370239477, 16.48107937276012, 16.436051006605847, 16.505834877824185, 15.517976394806977, 14.554833739338857, 13.549827179600841, 12.575441917615905, 11.657703669259886, 10.643361052284352, 9.677551579987295, 8.754289411764534, 9.638744524955559, 10.604092307816257, 11.579227275097839, 12.543271699071797, 13.484897200005983, 14.498249741187669, 15.430164259443977, 16.403069461191908, 16.44829372922245, 15.521766150711079, 15.571500020854165, 16.54181488721782, 16.483952433060097, 15.536076188963081, 14.526687323548138, 13.582490437500368, 12.650658560954804, 11.691109966434066, 10.734718440450107, 9.788908188501138, 10.113042824880745, 11.011505342216985, 11.69927748921901, 12.623942834608007, 13.631114447530718, 14.513335295771304, 15.428140816250185, 16.370197318407634, 15.59764563326886, 14.665447958677198, 14.656403208045404, 15.717639055579474, 16.439430997155373, 15.441868172493196, 14.585431878448201, 13.633334054663807, 12.643511057693964, 11.821351559531763, 10.828957911762991, 10.03020323427687, 9.10035222105977, 10.050212398131691, 10.708248962476517, 11.594834751351906, 12.565036846669827, 13.509604525313911, 14.475267077512797, 15.490519436635456, 14.685572228973557, 13.681077447277275, 13.840303006786904, 14.890254460099206, 15.48951505772793, 14.482077526407405, 13.58365107246275, 12.61779594830497, 11.674120476726017, 10.910129654406475, 9.891576434233627, 9.092561818254381, 8.157107206907696, 9.011825212936603, 9.667583972078116, 10.594784885131991, 11.6140137810453, 12.570519321317262, 13.578877984259929, 14.54314003387714, 13.803685278348004, 12.744973738338658, 12.859118643104388, 13.83510889004679, 14.545198278531664, 13.554543337197572, 12.594303730651575, 11.564529330453473, 10.647639145869816, 9.926279947550857, 8.948017461257448, 8.021657499919918, 7.109414885235214, 7.984415479471825, 8.72563288031885, 9.757343328589071, 10.67226680313875, 11.711989361902331, 12.65874456076058, 13.675033389736829, 12.874150640340842, 11.841646613880071, 11.915211980450616, 12.92935040357155, 13.575872040272236, 12.629918067759062, 11.617604318712846, 10.632927474862996, 9.69882343583237, 8.86769825404841, 7.916223633347785, 7.04457735416612, 6.070179212904282, 6.930169241099325, 7.7942788343268035, 8.725872942583692, 9.698475945761624, 10.745095034955193, 11.690305268868654, 12.746988605511865, 11.928635507169236, 10.865197027069433, 11.147114810878243, 12.12070171147685, 12.587673945784527, 11.660069123765771, 10.677373461261455, 9.69355787319746, 8.760815595225909, 7.88449936895582, 6.882981826207959, 6.022589952328516, 5.113481810249185, 5.910956315561907, 6.859230522349369, 7.8448677970272325, 8.812135735296291, 9.754086991682987, 10.74166783959468, 11.744276136812354, 10.922697437569427, 9.936142448473221, 12.024782873456463, 12.625715003150008, 11.664177721856607, 10.71356858616841, 9.768760776429449, 8.695076476726474, 7.759745337566514, 6.814731450684222, 5.885124182858215, 5.095985599482961, 4.116986348357409, 4.8923066291163515, 5.867942794466287, 6.811758499134313, 7.75154362699575, 8.751129092926051, 9.760823563502349, 10.740568262537872, 11.775434299294853, 10.85636932963473, 12.653958736538652, 11.700590439705968, 10.690494682358494, 9.708377075387153, 8.77177064289529, 7.745931898403804, 6.802072796877338, 5.849471354259643, 4.871868892088075, 4.058854656242256, 3.0692612359239906, 3.8896192512522076, 4.820540510379969, 5.8468066739658635, 6.798605325974087, 7.8021547340717845, 8.815771597534313, 9.832696247449864, 10.783888582601069, 11.809144839498751], [11.768138268609308, 10.789382374865479, 9.827662497468172, 8.872665947951871, 7.881074201917598, 6.821579965336503, 5.867297078728571, 4.8502285296533385, 3.8411933011526074, 2.9912253864945013, 2.095992652160346, 2.997283287852928, 3.927262973073974, 4.937724532715974, 5.8810807533662075, 6.890403748399568, 7.942190081729931, 8.871394254601302, 9.88986262638971, 10.847802571847817, 10.803805875557183, 9.84651204118717, 8.890176730051309, 7.900184758809587, 6.866846414419005, 5.899521370201409, 4.887087933959619, 3.858041084519073, 2.9127398621748473, 1.9521745343957235, 1.026633722807568, 1.959451856620829, 3.012190535458834, 4.058965342191821, 5.105494248655021, 6.0933690304516315, 7.1577615330729, 8.123840373543588, 9.147574833597481, 10.134213435801211, 9.931858351029998, 8.986130345203048, 7.9824841683269785, 6.951993110737197, 5.897058159198714, 4.915401033118922, 3.8919493745214546, 2.9165208832951013, 1.9322938002274082, 0.934368309450881, 0.0, 1.0598664807814904, 2.096989785228412, 3.146574346218501, 4.139691699487569, 5.153970442016452, 6.2013847988437885, 7.18898548790549, 8.188828679105377, 9.185977021484286, 10.899877658625083, 9.998480219673178, 8.95417478286827, 7.894575516487824, 6.84120720223219, 5.8480340700174525, 4.8911429570777765, 3.908753719017252, 2.8704610324218636, 1.9122799722909112, 1.0254690091582557, 2.022013017656784, 3.07082916993589, 4.11749712970445, 5.19168410964631, 6.117727105613654, 7.048412485160259, 8.039900549804871, 8.967272707695457, 9.945933489517648, 11.77667025050018, 10.80641722835039, 9.870721964076658, 8.842110945328052, 7.802062731983789, 6.858433770845251, 5.787506057250987, 4.857937798466871, 3.8798237279641734, 2.9267745823254, 1.9550348382350662, 2.974816131942136, 4.00221376218759, 5.032882674092512, 5.998946217043452, 6.980672237477637, 7.985908208915762, 8.932774249171207, 9.96882244836546, 10.899566767819325, 12.714914824868073, 11.70107449450419, 10.719050192151622, 9.763156551839533, 8.741468923050842, 7.787952201183042, 6.740419466343998, 5.773868572628732, 4.807280749860288, 3.864553800957865, 2.953982394516059, 3.8888804281607054, 4.9512135799857715, 5.9637931838129035, 6.912885822761162, 7.876155897833586, 8.880040406087694, 9.868612909189393, 10.812051618009134, 11.878874843593508, 13.630515966151256, 12.59088175823347, 11.591116767456354, 10.616391016857236, 9.626993696183648, 8.621775878785035, 7.696687927280336, 6.74687011652771, 5.7518318664472465, 4.790936805392308, 4.016336261894774, 4.947455831918519, 5.897820124026869, 6.842901554628399, 7.80313644951229, 8.768350992614337, 9.797991628264453, 10.793631714069077, 11.745977164698852, 12.699970492700423, 14.525896777465608, 13.49169403460721, 12.508827232560199, 11.54639193653067, 10.577765688383902, 9.635304921043458, 8.699214317107467, 7.730811503871422, 6.717049133011846, 5.775904173572025, 5.083807006099186, 5.886790047108697, 6.857397699342021, 7.817253429586725, 8.72922585968443, 9.736178728679835, 10.760905679357805, 11.736649244911275, 12.680756938991202, 13.689509047119172, 15.489608760987494, 14.416895336126586, 13.438871410709712, 12.531283636053875, 11.58023481343557, 10.567903785791128, 9.666214700006504, 8.695969578950876, 7.708978638812607, 6.715926819749541, 6.062908697281433, 6.899675147254116, 7.8189629934301665, 8.774190324599061, 9.755100122675804, 10.714311949902672, 11.667762832241575, 12.63705848545273, 13.593722285151848, 14.627540748895383, 16.415264082740734, 15.466080838690187, 14.451833693110403, 13.486365451807638, 12.597134973315514, 11.61531250792966, 10.63832173544445, 9.700446670893456, 8.686198311483517, 7.744132607943466, 6.996110313446082, 7.923874591248895, 8.821928873081893, 9.798051349511578, 10.749321366112394, 11.671256181270014, 12.72150942703219, 13.603938722207692, 14.612847239919015, 15.598028997844951, 16.535575888705573, 16.47865170834907, 15.524628201100368, 14.459038358020932, 13.516447723839484, 12.582311774661548, 11.611427733333219, 10.643561980259259, 9.64705320488652, 8.732199735005578, 8.019016073616868, 8.931346243299094, 9.837692375181728, 10.784149660237093, 11.723522025428618, 12.648004507136758, 13.670654590151342, 14.614865513367429, 15.604759483158576, 16.525288436572048, 15.579525119524945, 16.53360677452508, 16.45234470425786, 15.489202048789739, 14.484195489051723, 13.509810227066787, 12.592071978710768, 11.577729361735233, 10.611919889438177, 9.688657721215414, 8.96496614607073, 9.920157056031382, 10.835399507064173, 11.756037141899771, 12.697662642833958, 13.641723854106766, 14.573638372363074, 15.546543574111007, 16.618169477333, 16.45613446016196, 14.637131711403283, 15.607446577766941, 16.44156885089465, 15.493692606797635, 14.576451068426001, 13.632254182378231, 12.658059869411803, 11.818860543744952, 10.862469017760993, 10.253740285483136, 9.955524499662543, 10.85623595313436, 11.80050309054847, 12.720629552141277, 13.624400464814574, 14.573436189921779, 15.531455063160509, 16.47351156531796, 16.53201394271974, 15.59981626812808, 13.722034898594522, 14.783270746128592, 15.515828913976975, 14.518266089314798, 13.661829795269803, 12.709731971485406, 11.719908974515562, 10.897749476353361, 9.90535582858459, 9.278275536148941, 10.03472053051065, 10.98458070758257, 11.6426172719274, 12.529203060802788, 13.499405156120709, 14.443972834764793, 15.409635386963679, 16.424887746086338, 15.619940538424439, 14.615445756728157, 12.905934697336022, 13.955886150648324, 14.56591297454953, 13.558475443229007, 12.660048989284352, 11.69419386512657, 10.750518393547615, 9.986527571228073, 8.967974351055226, 8.20352607221588, 9.091475516358576, 9.946193522387484, 10.601952281528998, 11.529153194582873, 12.548382090496181, 13.504887630768144, 14.51324629371081, 15.477508343328022, 14.738053587798886, 13.67934204778954, 11.924750333653506, 12.900740580595908, 13.621596195353264, 12.630941254019174, 11.670701647473177, 10.640927247275073, 9.724037062691416, 9.002677864372455, 8.024415378079047, 7.1326217538814145, 8.043783194686094, 8.918783788922706, 9.660001189769732, 10.691711638039953, 11.606635112589633, 12.646357671353213, 13.59311287021146, 14.609401699187709, 13.808518949791724, 12.776014923330953, 10.980843670999736, 11.99498209412067, 12.652269957093836, 11.706315984580662, 10.694002235534446, 9.709325391684596, 8.77522135265397, 7.944096170870008, 6.992621550169384, 6.155541608127616, 7.004547522355162, 7.864537550550206, 8.728647143777685, 9.660241252034574, 10.632844255212506, 11.679463344406074, 12.624673578319534, 13.681356914962745, 12.863003816620118, 11.799565336520315, 10.21274650142736, 11.186333402025966, 11.664071862606127, 10.736467040587371, 9.753771378083055, 8.76995579001906, 7.837213512047508, 6.960897285777418, 5.959379743029557, 5.133554206290012, 6.047850119700065, 6.845324625012788, 7.79359883180025, 8.779236106478113, 9.746504044747173, 10.688455301133867, 11.67603614904556, 12.678644446263235, 11.85706574702031, 10.870510757924103, 11.09041456400558, 11.702112919971606, 10.740575638678205, 9.789966502990008, 8.845158693251047, 7.771474393548073, 6.836143254388112, 5.89112936750582, 4.961522099679813, 4.206949853444457, 5.05135465780829, 5.8266749385672325, 6.802311103917167, 7.746126808585193, 8.685911936446631, 9.685497402376932, 10.69519187295323, 11.674936571988752, 12.709802608745733, 11.790737639085611, 11.73035665336025, 10.776988356527566, 9.766892599180093, 8.784774992208751, 7.84816855971689, 6.822329815225403, 5.8784707136989365, 4.9258692710812415, 3.9482668089096733, 3.1352525730638545, 4.003629545374872, 4.823987560703088, 5.754908819830849, 6.781174983416744, 7.732973635424967, 8.736523043522665, 9.750139906985194, 10.767064556900745, 11.71825689205195, 12.743513148949633], [12.757593055647298, 11.77883716190347, 10.784132351804182, 9.829135802287881, 8.759554997019363, 7.700060760438267, 6.745777873830335, 5.728709324755102, 4.719674096254371, 3.869706181596265, 2.967584677809138, 2.0032390458751985, 2.9332187310962445, 3.9436802907382438, 4.8870365113884775, 5.896359506421838, 6.948145839752201, 7.877350012623572, 8.89581838441198, 9.853758329870086, 11.793260662595173, 10.83596682822516, 9.8796315170893, 8.889639545847578, 7.856301201456995, 6.783462961628102, 5.771029525386312, 4.736521879620836, 3.791220657276611, 2.830655329497487, 1.89822574845636, 0.9654076146430992, 2.018146293481104, 3.0649211002140913, 4.104908497622205, 5.033502549670141, 6.09789505229141, 7.063973892762099, 8.087708352815993, 9.074346955019722, 10.991724831811489, 10.045996825984538, 9.042350649108469, 8.011859591518688, 6.956924639980205, 5.9752675139004126, 4.951815855302946, 3.976387364076592, 2.9921602810088985, 1.9942347902323714, 1.0598664807814904, 0.0, 1.0371233044469215, 2.0867078654370106, 3.0798252187060786, 4.0941039612349615, 5.141518318062298, 6.129119007123999, 7.1289621983238876, 8.126110540702797, 11.959744139406574, 11.058346700454669, 10.01404126364976, 8.954441997269315, 7.901073683013681, 6.907900550798944, 5.951009437859268, 4.9686201997987425, 3.9303275132033537, 2.9721464530724013, 2.0113048591516165, 0.9621465368752937, 2.0109626891543995, 3.0576306489229594, 4.13181762886482, 5.057860624832164, 5.988546004378769, 6.9800340690233815, 7.907406226913967, 8.886067008736157, 12.83653673128167, 11.866283709131881, 10.93058844485815, 9.901977426109545, 8.861929212765281, 7.918300251626742, 6.847372538032477, 5.917804279248362, 4.939690208745664, 3.9734487723163685, 2.940870688228427, 1.9149496511606459, 2.9423472814060996, 3.9730161933110226, 4.939079736261962, 5.920805756696147, 6.926041728134272, 7.872907768389717, 8.90895596758397, 9.839700287037834, 13.774781305649563, 12.760940975285681, 11.778916672933114, 10.823023032621025, 9.801335403832335, 8.776938679847456, 7.729405945008413, 6.75353381225588, 5.786945989487436, 4.844219040585013, 3.8818121259604412, 2.9469140923157946, 3.8913470992042813, 4.903926703031413, 5.853019341979671, 6.816289417052095, 7.820173925306205, 8.808746428407902, 9.752185137227643, 10.819008362812017, 14.61950244481567, 13.579868236897884, 12.580103246120768, 11.60537749552165, 10.615980174848062, 9.610762357449449, 8.68567440594475, 7.726535356154858, 6.731497106074395, 5.770602045019457, 4.938656259190232, 4.005489496073608, 4.837953643245379, 5.783035073846909, 6.7432699687308, 7.7084845118328476, 8.738125147482965, 9.733765233287587, 10.686110683917361, 11.640104011918933, 15.51488325613002, 14.480680513271624, 13.497813711224612, 12.535378415195083, 11.566752167048316, 10.622651336621672, 9.686560732685681, 8.710476743498571, 7.696714372638995, 6.755569413199174, 5.921597389594771, 4.944823711263787, 5.8181574767255695, 6.778013206970273, 7.669359378902939, 8.676312247898347, 9.701039198576316, 10.676782764129785, 11.620890458209711, 12.629642566337681, 16.478595239651906, 15.405881814791, 14.427857889374126, 13.520270114718288, 12.567581229013784, 11.555250201369342, 10.645879939633653, 9.675634818578025, 8.688643878439755, 7.69559205937669, 6.893199663447714, 5.957708811409206, 6.779722770813715, 7.7349501019826095, 8.695233641894314, 9.654445469121182, 10.607896351460084, 11.57719200467124, 12.533855804370358, 13.567674268113892, 16.41984640628413, 16.4550673173546, 15.440820171774817, 14.475351930472051, 13.584481388893728, 12.602658923507875, 11.617986975071599, 10.680111910520605, 9.665863551110665, 8.723797847570614, 7.826401279612363, 6.981908255403985, 7.78268865046544, 8.758811126895125, 9.689454885330903, 10.611389700488523, 11.6616429462507, 12.544072241426202, 13.552980759137524, 14.53816251706346, 15.475709407924082, 16.51221972736171, 16.513614679764782, 15.448024836685345, 14.496112963466631, 13.561977014288695, 12.591092972960366, 11.623227219886406, 10.626718444513667, 9.711864974632725, 8.849307039783149, 7.989379907454184, 8.798452152565275, 9.74490943762064, 10.684281802812166, 11.588138026355267, 12.610788109369851, 13.554999032585938, 14.544893002377085, 15.465421955790557, 14.519658638743454, 15.473740293743589, 16.434952180778566, 15.48089081444413, 14.575551609815292, 13.645258460284964, 12.663877470246, 11.891401108543134, 10.925591636246077, 10.668322960842561, 9.79525711223701, 8.978190720186472, 9.79615928444772, 10.716796919283318, 11.658422420217505, 12.581857373325276, 13.513771891581584, 14.486677093329517, 15.558302996551511, 16.424735177839597, 13.577265230621792, 14.54758009698545, 15.44752460891692, 14.499648364819906, 13.582406826448272, 12.638209940400502, 11.664015627434074, 10.824816301767223, 9.868424775783264, 10.82933405722944, 10.785815465828824, 9.91426961728945, 10.786186307451045, 11.681389329524825, 12.585160242198121, 13.534195967305326, 14.492214840544056, 15.434271342701507, 16.43382873346117, 16.588802746792492, 12.662168417813032, 13.723404265347101, 14.521784671999246, 13.524221847337069, 12.667785553292074, 11.715687729507676, 10.725864732537833, 9.903705234375632, 8.91131158660686, 9.944846442906186, 10.858139912041887, 10.875562561374744, 11.777214834193538, 12.710497412780926, 13.651237843059013, 14.537926737762719, 15.445088579281443, 16.419492015103504, 16.67980701920593, 15.675312237509647, 11.846068216554531, 12.896019669866833, 13.5718687325718, 12.564431201251278, 11.666004747306623, 10.70014962314884, 9.756474151569886, 8.992483329250344, 7.973930109077498, 8.998470599089377, 9.914894897889813, 10.824674317489249, 11.480433076630762, 12.407633989684637, 13.426862885597945, 14.383368425869907, 15.391727088812575, 16.355989138429784, 15.797920068580376, 14.73920852857103, 10.864883852872016, 11.840874099814418, 12.627551953375535, 11.636897012041445, 10.676657405495448, 9.646883005297344, 8.729992820713685, 8.008633622394726, 7.030371136101318, 7.927566280754912, 8.86720257621733, 9.797264584024472, 10.538481984871495, 11.570192433141717, 12.485115907691396, 13.524838466454977, 14.471593665313222, 15.48788249428947, 14.868385430573214, 13.835881404112444, 9.920977190218245, 10.93511561333918, 11.658225715116107, 10.712271742602933, 9.699957993556717, 8.715281149706867, 7.781177110676239, 6.950051928892279, 5.9985773081916545, 6.950486135001114, 7.827966903886399, 8.74301834565197, 9.607127938879449, 10.538722047136337, 11.51132505031427, 12.557944139507836, 13.503154373421296, 14.559837710064507, 13.922870297401609, 12.859431817301806, 9.15288002064587, 10.126466921244477, 10.670027620628398, 9.742422798609642, 8.759727136105326, 7.7759115480413294, 6.843169270069778, 5.966853043799689, 4.965335501051828, 5.92849873316351, 6.871269501231302, 7.723805420114552, 8.672079626902015, 9.657716901579878, 10.624984839848935, 11.56693609623563, 12.554516944147322, 13.557125241364997, 12.9169322278018, 11.930377238705594, 10.03054808322409, 10.708068677993875, 9.746531396700474, 8.795922261012278, 7.851114451273317, 6.777430151570343, 5.842099012410382, 4.897085125528091, 3.9674778577020837, 5.001894380317955, 5.929835452910054, 6.705155733668996, 7.680791899018931, 8.624607603686956, 9.564392731548393, 10.563978197478693, 11.573672668054991, 12.553417367090514, 13.588283403847495, 12.780192426123602, 10.73631241138252, 9.782944114549837, 8.772848357202363, 7.790730750231022, 6.85412431773916, 5.828285573247673, 4.8844264717212065, 3.9318250291035124, 2.9542225669319437, 3.9838686532741274, 4.882110340476635, 5.702468355804852, 6.633389614932613, 7.659655778518507, 8.61145443052673, 9.615003838624428, 10.628620702086957, 11.645565851274363, 12.596758186425568, 13.664528854190454], [13.79471636009422, 12.815960466350392, 11.8212556562511, 10.8662591067348, 9.796678301466281, 8.737184064885186, 7.782901178277255, 6.765832629202023, 5.756797400701292, 4.906829486043186, 3.9971980598866645, 2.9535973957156885, 2.0236177104946425, 3.0317373380482917, 3.9750935586985254, 4.9844165537318865, 6.03620288706225, 6.965407059933621, 7.983875431722028, 8.941815377180134, 12.830383967042096, 11.873090132672083, 10.916754821536221, 9.9267628502945, 8.893424505903917, 7.820586266075024, 6.808152829833234, 5.7736451840677585, 4.828343961723532, 3.867778633944409, 2.9353490529032817, 2.0025309190900207, 1.0292606448930217, 2.0345460320505184, 3.067785193175283, 3.9963792452232196, 5.0607717478444885, 6.0268505883151775, 7.050585048369071, 8.037223650572802, 12.02884813625841, 11.08312013043146, 10.079473953555391, 9.04898289596561, 7.994047944427127, 7.012390818347335, 5.988939159749868, 5.013510668523514, 4.02928358545582, 3.031358094679293, 2.096989785228412, 1.0371233044469215, 0.0, 1.0495845609900893, 2.0427019142591574, 3.05698065678804, 4.1043950136153775, 5.091995702677079, 6.091838893876967, 7.088987236255877, 12.996867443853496, 12.09547000490159, 11.051164568096683, 9.991565301716237, 8.938196987460604, 7.945023855245866, 6.98813274230619, 6.005743504245665, 4.967450817650276, 4.0092697575193235, 3.0484281635985377, 1.9992698413222152, 0.9792642587388258, 2.0259322185073856, 3.1001191984492453, 4.026162194416589, 4.956847573963194, 5.948335638607807, 6.875707796498392, 7.854368578320582, 13.873660035728593, 12.903407013578803, 11.967711749305073, 10.939100730556467, 9.899052517212203, 8.955423556073665, 7.884495842479399, 6.954927583695284, 5.976813513192586, 5.01057207676329, 3.9779939926753483, 2.9520729556075676, 2.051884378347696, 2.9810894988111993, 3.9471530417621388, 4.928879062196324, 5.894343297718697, 6.841209337974142, 7.877257537168395, 8.80800185662226, 14.811904610096486, 13.798064279732603, 12.816039977380036, 11.860146337067947, 10.838458708279257, 9.814061984294378, 8.766529249455335, 7.7906571167028025, 6.824069293934358, 5.8813423450319355, 4.918935430407363, 3.9840373967627167, 3.000884196145878, 3.941316748887659, 4.874589909729793, 5.8378599848022175, 6.841744493056327, 7.7770479979923275, 8.720486706812068, 9.787309932396441, 15.656625749262592, 14.616991541344806, 13.61722655056769, 12.642500799968571, 11.653103479294984, 10.647885661896371, 9.722797710391673, 8.76365866060178, 7.768620410521317, 6.807725349466379, 5.946571573707897, 5.013404810591273, 3.947490740186976, 4.8925721707885055, 5.852807065672397, 6.7921859413661965, 7.821826577016313, 8.702066802872011, 9.654412253501786, 10.608405581503357, 16.55200656057694, 15.517803817718546, 14.534937015671535, 13.572501719642005, 12.603875471495238, 11.659774641068594, 10.723684037132603, 9.747600047945493, 8.733837677085917, 7.792692717646096, 6.875075904231474, 5.8983022259004905, 4.927694573667166, 5.88755030391187, 6.778896475844536, 7.7600136774316955, 8.784740628109663, 9.645084333714209, 10.589192027794136, 11.597944135922106, 16.42638473371434, 16.443005119237924, 15.464981193821048, 14.55739341916521, 13.604704533460707, 12.592373505816264, 11.664186788315812, 10.693941667260184, 9.706950727121914, 8.713898908058846, 7.758770342191243, 6.823279490152735, 5.889259867755311, 6.844487198924206, 7.804770738835911, 8.76398256606278, 9.717433448401682, 10.612315861371515, 11.54788339529058, 12.581701859034114, 15.433873997204353, 16.3830572412549, 16.47794347622174, 15.512475234918973, 14.62160469334065, 13.639782227954797, 12.636293823753757, 11.680730742462806, 10.616660111691747, 9.674594408151696, 8.691971958355891, 7.847478934147514, 6.892225747407037, 7.8683482238367235, 8.7989919822725, 9.72092679743012, 10.771180043192297, 11.579196098126477, 12.5881046158378, 13.573286373763736, 14.489736998844304, 15.515907053238841, 16.357616849502712, 15.617110712263607, 14.594949909178187, 13.660813960000251, 12.74795964953217, 12.10692690846439, 11.57751500509475, 10.662661535213807, 9.714877718526676, 8.854950586197713, 7.907989249506873, 8.854446534562237, 9.793818899753763, 10.697675123296865, 11.720325206311449, 12.590122889286214, 13.580016859077361, 14.500545812490833, 13.533686229663676, 14.442041863328013, 15.429900346345221, 14.568947861754179, 13.663608657125339, 12.733315507595012, 11.751934517556046, 11.133852351397975, 11.875949986086566, 11.619119521423643, 10.660827790980537, 9.84376139893, 8.905696381389317, 9.826334016224916, 10.767959517159102, 11.691394470266873, 12.623308988523181, 13.596214190271114, 14.65436888267424, 15.459859034539875, 12.545566800206217, 13.515881666569875, 14.535581656226968, 13.587705412129955, 12.670463873758319, 11.726266987710549, 10.75207267474412, 10.064865569482366, 10.818783125623753, 11.779692407069929, 11.651386144572351, 10.77984029603298, 9.895723404392642, 10.790926426466422, 11.694697339139719, 12.643733064246923, 13.601751937485654, 14.543808439643104, 15.543365830402768, 16.47556350499443, 11.630469987397456, 12.691705834931525, 13.609841719309294, 12.612278894647117, 11.755842600602122, 10.803744776817723, 9.81392177984788, 9.021981144517921, 9.861669936447349, 10.895204792746675, 11.808498261882377, 11.741133240118273, 10.886751931135136, 11.820034509722523, 12.76077494000061, 13.647463834704316, 14.55462567622304, 15.529029112045102, 16.504085490051967, 16.71243554195657, 10.814369786138956, 11.86432123945126, 12.659925779881847, 11.652488248561326, 10.754061794616671, 9.788206670458889, 8.844531198879933, 8.082882308648742, 8.924288458917987, 9.948828948929865, 10.865253247730303, 11.86179762193617, 11.927416921533537, 12.820084375942438, 13.772090952718642, 14.611220238881781, 15.618425588635509, 16.55287219878132, 16.835043373027297, 15.776331833017952, 9.833185422456442, 10.809175669398844, 11.715609000685582, 10.724954059351493, 9.764714452805496, 8.734940052607392, 7.818049868023732, 7.099032601793123, 7.980729485941808, 8.877924630595402, 9.817560926057821, 10.834387888471392, 11.575605289318416, 12.607315737588637, 13.522239212138317, 14.561961770901897, 15.508716969760144, 16.525005798736395, 15.905508735020137, 14.873004708559366, 8.88927875980267, 9.903417182923604, 10.746282762426153, 9.80032878991298, 8.788015040866764, 7.803338197016914, 6.869234157986287, 6.040450908290676, 6.948935658032144, 7.900844484841604, 8.778325253726889, 9.78014165009889, 10.64425124332637, 11.575845351583258, 12.54844835476119, 13.595067443954758, 14.540277677868218, 15.596961014511429, 14.95999360184853, 13.896555121748728, 8.11575671619895, 9.089343616797557, 9.758084667938444, 8.830479845919688, 7.847784183415373, 6.863968595351378, 5.931226317379825, 5.057252023198086, 5.915693850892318, 6.878857083004, 7.821627851071792, 8.760928724561472, 9.709202931348935, 10.694840206026798, 11.662108144295857, 12.604059400682551, 13.591640248594244, 14.594248545811919, 13.954055532248722, 12.967500543152516, 8.99342477877717, 9.796125725303924, 8.834588444010523, 7.883979308322327, 6.939171498583366, 5.865487198880391, 4.93015605972043, 3.987484104926488, 4.917836207542574, 5.952252730158445, 6.931251981283997, 7.7422790381159174, 8.717915203465852, 9.661730908133878, 10.601516035995315, 11.601101501925616, 12.610795972501913, 13.590540671537436, 14.625406708294417, 13.817315730570524, 9.82436945869257, 8.871001161859885, 7.860905404512412, 6.8787877975410705, 5.942181365049208, 4.916342620557721, 3.972483519031254, 3.02222400850191, 3.9045809167724337, 4.934227003114618, 5.9192336449235565, 6.739591660251773, 7.670512919379534, 8.69677908296543, 9.648577734973653, 10.65212714307135, 11.66574400653388, 12.682689155721285, 13.63388149087249, 14.701652158637376], [14.84430092108431, 13.865545027340481, 12.87084021724119, 11.91584366772489, 10.84626286245637, 9.786768625875276, 8.832485739267344, 7.815417190192113, 6.806381961691382, 5.956414047033276, 4.966194686092224, 3.9225940219212476, 2.9926143367002016, 1.9821527770582021, 2.9255089977084356, 3.9348319927417963, 4.9866183260721595, 5.91582249894353, 6.934290870731939, 7.892230816190045, 13.879968528032185, 12.922674693662172, 11.96633938252631, 10.97634741128459, 9.943009066894007, 8.870170827065113, 7.857737390823323, 6.823229745057848, 5.8779285227136215, 4.917363194934498, 3.9849336138933706, 3.0521154800801096, 2.0317362777934163, 0.984961471060429, 2.0182006321851937, 2.9467946842331303, 4.011187186854399, 4.977266027325088, 6.001000487378982, 6.9876390895827125, 13.0784326972485, 12.13270469142155, 11.12905851454548, 10.0985674569557, 9.043632505417216, 8.061975379337424, 7.038523720739957, 6.063095229513603, 5.07886814644591, 4.080942655669382, 3.146574346218501, 2.0867078654370106, 1.0495845609900893, 0.0, 0.9931173532690681, 2.007396095797951, 3.0548104526252877, 4.042411141686989, 5.042254332886877, 6.039402675265786, 14.046452004843585, 13.14505456589168, 12.100749129086772, 11.041149862706327, 9.987781548450693, 8.994608416235955, 8.03771730329628, 7.055328065235754, 6.017035378640365, 5.058854318509413, 4.098012724588627, 3.0488544023123043, 2.0284236381090164, 0.9817556783404564, 2.055942658282316, 2.98198565424966, 3.912671033796265, 4.904159098440878, 5.831531256331463, 6.8101920381536525, 14.923244596718684, 13.952991574568895, 13.017296310295162, 11.988685291546556, 10.948637078202292, 10.005008117063754, 8.934080403469489, 8.004512144685373, 7.0263980741826755, 6.060156637753379, 5.027578553665437, 3.9949795007946465, 2.9675818705491928, 1.9369129586442702, 2.9029765015952096, 3.8847025220293947, 4.850166757551768, 5.797032797807213, 6.833080997001465, 7.76382531645533, 15.806657894796485, 14.792817564432603, 13.810793262080034, 12.854899621767945, 11.833211992979255, 10.808324959879437, 9.760792225040394, 8.784920092287862, 7.818332269519417, 6.8756053206169945, 5.913198405992422, 4.978300372347776, 3.9097198125478614, 2.89714020872073, 3.830413369562864, 4.793683444635288, 5.7975679528893975, 6.732871457825398, 7.676310166645139, 8.743133392229513, 16.65088872484765, 15.611254516929865, 14.611489526152749, 13.63676377555363, 12.647366454880043, 11.64214863748143, 10.717060685976731, 9.75792163618684, 8.762883386106376, 7.801988325051438, 6.836584566891551, 5.903417803774927, 4.83750373337063, 3.8924223027691003, 4.824282682813713, 5.748009401199267, 6.7776500368493835, 7.657890262705083, 8.610235713334857, 9.564229041336429, 16.360858927449097, 16.512066793303603, 15.529199991256593, 14.566764695227064, 13.598138447080297, 12.6390573190347, 11.70296671509871, 10.726882725911599, 9.713120355052023, 8.771975395612202, 7.765088897415128, 6.7883152190841445, 5.81770756685082, 4.922091942334534, 5.750372092985852, 6.715837137264765, 7.740564087942734, 8.60090779354728, 9.545015487627207, 10.553767595755177, 15.382208193547413, 16.401925006683733, 16.459244169406105, 15.55165639475027, 14.583987211426813, 13.57165618378237, 12.554199781499465, 11.583954660443837, 10.596963720305567, 9.6039119012425, 8.648783335374896, 7.713292483336389, 6.779272860938965, 5.87902883734687, 6.776246355977227, 7.735458183204095, 8.688909065542997, 9.568139321204587, 10.503706855123651, 11.537525318867186, 14.389697457037425, 15.338880701087971, 16.353127846667753, 15.529338991026606, 14.480655894073076, 13.612473962699177, 12.762808973266507, 12.57074373564646, 11.5066731048754, 10.56460740133535, 9.581984951539544, 8.737491927331167, 7.7822387405906905, 6.950573330518182, 7.770467599413816, 8.692402414571436, 9.742655660333613, 10.535019557959549, 11.543928075670872, 12.529109833596808, 13.445560458677376, 14.471730513071913, 15.313440309335784, 14.567526151273515, 13.545365348188096, 12.61122939901016, 11.69837508854208, 12.666240841616041, 12.467527998278403, 11.55267452839746, 10.604890711710329, 9.744963579381366, 8.798002242690526, 7.936671641243697, 8.792289753914416, 9.66915074043818, 10.691800823452764, 11.545946349119285, 12.535840318910433, 13.456369272323904, 12.489509689496748, 13.397865323161085, 14.385723806178293, 13.519363300764088, 12.61402409613525, 11.683730946604921, 10.702349956565957, 11.716692573541492, 12.67559509472154, 12.509132514607296, 11.55084078416419, 10.733774392113654, 9.79570937457297, 8.908559122906375, 9.788188074124324, 10.662870087408189, 11.594784605664497, 12.5545543819939, 13.610192342507311, 14.415682494372946, 11.501390260039289, 12.471705126402947, 13.485997095236877, 12.538120851139864, 11.62087931276823, 10.67668242672046, 9.70248811375403, 10.66203670827477, 11.618428234258728, 12.579337515704903, 12.541399137756004, 11.669853289216633, 10.785736397576295, 9.873151533147881, 10.71492589610494, 11.663961621212145, 12.621980494450876, 13.541168354453015, 14.54072574521268, 15.442836086461083, 10.586293447230528, 11.647529294764597, 12.560257158319203, 11.562694333657026, 10.706258039612031, 9.754160215827634, 8.76433721885779, 9.707403315922503, 10.663961998008709, 11.697496854308035, 12.627347867525135, 12.631146233301926, 11.776764924318789, 10.902259616403983, 11.781003496965832, 12.667692391669538, 13.574854233188262, 14.526389026855012, 15.501445404861876, 16.49067012362882, 9.770193245972028, 10.820144699284329, 11.610341218891758, 10.602903687571235, 9.70447723362658, 8.738622109468798, 7.7949466378898435, 8.768304480053324, 9.726580520479345, 10.753941282887954, 11.795304844393844, 12.814707805019363, 12.81742991471719, 11.902309482623897, 12.792319509683864, 13.631448795847003, 14.63865414560073, 15.550232113591232, 16.47113081068684, 16.771085117717952, 8.789008882289512, 9.764999129231914, 10.666024439695493, 9.675369498361402, 8.715129891815405, 7.685355491617301, 6.768465307033643, 7.815244343891438, 8.783021547503166, 9.708725301390746, 10.747612522721361, 11.787298071554586, 12.545346973421385, 12.951463075946839, 13.734066487590413, 14.668415232170886, 15.653225778536811, 16.62063897627917, 16.955093296010226, 15.922589269549455, 7.8451022196357405, 8.859240642756674, 9.696698201436064, 8.75074422892289, 7.7384304798766745, 6.753753636026824, 5.819649596996197, 6.778833828213413, 7.751227719593502, 8.731645155636949, 9.70837685039043, 10.74988333420186, 11.613992927429338, 12.545587035686227, 13.518190038864159, 14.583587555493988, 15.528797789407449, 16.58548112605066, 16.009578162838622, 14.946139682738817, 7.06617215520886, 8.039759055807467, 8.708500106948355, 7.780895284929598, 6.798199622425283, 5.814384034361288, 4.881641756389736, 5.850783619742545, 6.845745447555859, 7.808908679667541, 8.751679447735333, 9.73067040866444, 10.678944615451904, 11.664581890129767, 12.711692705285946, 13.65364396167264, 14.641224809584333, 15.643833106802008, 15.003640093238811, 14.017085104142605, 7.943840217787081, 8.746541164313834, 7.785003883020433, 6.834394747332237, 5.8895869375932755, 4.815902637890301, 3.8805714987303404, 4.850062748658232, 5.847887804206115, 6.882304326821986, 7.861303577947537, 8.787335304847865, 9.767499764455941, 10.711315469123967, 11.651100596985405, 12.650686062915705, 13.660380533492003, 14.640125232527526, 15.674991269284506, 14.866900291560613, 8.774784897702478, 7.821416600869794, 6.811320843522322, 5.82920323655098, 4.892596804059118, 3.8667580595676307, 2.9228989580411646, 3.9492594129441114, 4.873577542977992, 5.903223629320176, 6.909488293592944, 7.7891762212418625, 8.720097480369624, 9.746363643955519, 10.698162295963742, 11.70171170406144, 12.715328567523969, 13.732273716711376, 14.683466051862581, 15.751236719627467], [15.837418274353379, 14.85866238060955, 13.863957570510257, 12.908961020993956, 11.839380215725438, 10.779885979144343, 9.825603092536412, 8.80853454346118, 7.79949931496045, 6.949531400302344, 5.959312039361293, 4.915711375190316, 3.9857316899692696, 2.9752701303272704, 2.072738819857567, 2.9597807036367882, 4.0115670369671514, 4.940771209838522, 5.95923958162693, 6.917179527085036, 14.873085881301254, 13.91579204693124, 12.95945673579538, 11.969464764553658, 10.936126420163076, 9.863288180334182, 8.850854744092391, 7.816347098326915, 6.87104587598269, 5.910480548203566, 4.978050967162439, 4.045232833349178, 3.0248536310624843, 1.978078824329497, 1.0250832789161257, 1.953677330964062, 3.018069833585331, 3.98414867405602, 5.007883134109914, 5.9945217363136445, 14.071550050517567, 13.125822044690617, 12.122175867814548, 11.091684810224766, 10.036749858686283, 9.055092732606491, 8.031641074009023, 7.0562125827826705, 6.071985499714978, 5.07406000893845, 4.139691699487569, 3.0798252187060786, 2.0427019142591574, 0.9931173532690681, 0.0, 1.0142787425288828, 2.0616930993562197, 3.049293788417921, 4.049136979617809, 5.046285321996718, 15.039569358112653, 14.138171919160746, 13.093866482355837, 12.034267215975392, 10.980898901719758, 9.98772576950502, 9.030834656565345, 8.048445418504821, 7.010152731909432, 6.05197167177848, 5.091130077857695, 4.041971755581372, 3.0215409913780844, 1.9748730316095244, 1.0638141899197076, 1.9898571858870515, 2.9205425654336565, 3.9120306300782692, 4.839402787968854, 5.818063569791044, 15.916361949987747, 14.946108927837958, 14.010413663564227, 12.981802644815621, 11.941754431471358, 10.998125470332822, 9.927197756738556, 8.99762949795444, 8.019515427451742, 7.053273991022447, 6.020695906934505, 4.9880968540637145, 3.960699223818261, 2.930030311913338, 2.1148420592306225, 2.946490885973625, 3.85803828918916, 4.8049043294446045, 5.840952528638857, 6.771696848092722, 16.79977524806555, 15.78593491770167, 14.803910615349103, 13.848016975037014, 12.826329346248324, 11.801442313148506, 10.753909578309463, 9.778037445556931, 8.811449622788487, 7.868722673886063, 6.906315759261491, 5.971417725616845, 4.90283716581693, 3.890257561989798, 3.042278927198277, 4.005549002270701, 4.890790357330813, 5.74074298946279, 6.684181698282531, 7.751004923866906, 16.35328467310519, 16.604371870198932, 15.604606879421818, 14.6298811288227, 13.640483808149112, 12.635265990750499, 11.7101780392458, 10.75103898945591, 9.756000739375446, 8.795105678320507, 7.829701920160619, 6.896535157043995, 5.830621086639698, 4.885539656038168, 4.036148240449126, 4.95987495883468, 5.8746670348882, 6.665761794342474, 7.618107244972248, 8.57210057297382, 15.368730459086489, 16.380475808312152, 16.522317344525664, 15.559882048496133, 14.591255800349366, 13.632174672303767, 12.696084068367776, 11.720000079180666, 10.70623770832109, 9.765092748881269, 8.758206250684196, 7.7814325723532125, 6.810824920119888, 5.915209295603603, 4.962237650621265, 5.927702694900178, 6.837581085981551, 7.608779325184672, 8.552887019264599, 9.561639127392569, 14.390079725184805, 15.409796538321125, 16.373961660705838, 15.642510695389705, 14.660870267946944, 13.823196898831634, 13.547317134768532, 12.577072013712904, 11.590081073574634, 10.597029254511567, 9.641900688643963, 8.706409836605456, 7.772390214208033, 6.872146190615939, 5.98811191361264, 6.947323740839508, 7.8146731909917335, 8.576010852841979, 9.511578386761043, 10.545396850504577, 13.397568988674816, 14.346752232725363, 15.360999378305147, 14.687428879635942, 13.643970108067, 12.775788176693101, 13.755926326535574, 13.563861088915527, 12.499790458144467, 11.557724754604417, 10.575102304808611, 9.730609280600234, 8.77535609385976, 7.943690683787251, 6.982333157049229, 7.90426797220685, 8.87441927812357, 9.54289108959694, 10.551799607308263, 11.5369813652342, 12.453431990314767, 13.479602044709305, 14.321311840973175, 13.714755973422648, 12.70867956218202, 11.774543613004084, 12.691492441811148, 13.659358194885108, 13.46064535154747, 12.545791881666528, 11.598008064979396, 10.738080932650433, 9.791119595959595, 8.929788994512766, 8.004155311549829, 8.881016298073593, 9.823564441242722, 10.553817880756677, 11.543711850547824, 12.464240803961296, 11.49738122113414, 12.405736854798477, 13.393595337815684, 12.666593122913218, 11.777338310129174, 10.847045160598846, 11.695467309835024, 12.709809926810559, 13.668712447990607, 13.502249867876364, 12.543958137433258, 11.726891745382721, 10.78882672784204, 9.901676476175444, 9.000053631759737, 9.874735645043602, 10.80665016329991, 11.56242591363129, 12.618063874144703, 13.423554026010338, 10.50926179167668, 11.479576658040338, 12.506573266064127, 11.685350673288994, 10.784193526762154, 9.839996640714384, 10.695605467023098, 11.655154061543836, 12.611545587527795, 13.57245486897397, 13.534516491025071, 12.6629706424857, 11.778853750845364, 10.86626888641695, 9.926791453740353, 10.875827178847558, 11.833846052086288, 12.549039886090407, 13.54859727685007, 14.450707618098475, 9.59416497886792, 10.655400826401989, 11.601571416017848, 10.709924155806156, 9.853487861761163, 8.90155996258133, 9.757454572126857, 10.70052066919157, 11.657079351277776, 12.690614207577102, 13.620465220794202, 13.624263586570994, 12.769882277587858, 11.895376969673052, 10.992869054601245, 11.879557949304951, 12.786719790823675, 13.534260558492404, 14.509316936499268, 15.49854165526621, 8.77806477760942, 9.82801623092172, 10.726253988944983, 9.750133509720365, 8.851707055775712, 7.88585193161793, 8.78806399115891, 9.761421833322391, 10.719697873748412, 11.747058636157021, 12.788422197662912, 13.807825158288432, 13.810547267986259, 12.895426835892966, 12.004185067319277, 12.843314353482416, 13.850519703236143, 14.558103645228623, 15.479002342324234, 16.434645364204826, 7.796880413926903, 8.772870660869305, 9.781937209748717, 8.822599320510532, 7.862359713964536, 6.832585313766433, 7.761582660302711, 8.808361697160507, 9.776138900772233, 10.701842654659815, 11.74072987599043, 12.780415424823655, 13.538464326690454, 13.905029196813, 12.945932045225826, 13.8802807898063, 14.865091336172224, 15.628510507916564, 16.450345398785267, 16.915706622818522, 6.852973751273132, 7.867112174394066, 8.81807950095414, 7.897974051072021, 6.885660302025805, 5.900983458175955, 6.8127669502652655, 7.771951181482481, 8.74434507286257, 9.724762508906018, 10.701494203659498, 11.743000687470929, 12.607110280698407, 13.538704388955296, 13.919722902602953, 14.920672419592547, 15.83353062806415, 16.556555292141528, 17.00269551610769, 15.939257036007884, 6.073054801939792, 7.046641702538398, 7.823746265984944, 6.896141443966188, 5.9454294445744145, 4.961613856510419, 5.874759109658804, 6.843900973011613, 7.838862800824927, 8.80202603293661, 9.744796801004401, 10.72378776193351, 11.672061968720973, 12.657699243398836, 13.704810058555013, 14.646761314941708, 15.6343421628534, 16.636950460071077, 15.996757446507878, 15.010202457411673, 6.950722864518013, 7.785411762323739, 6.823874481030339, 5.873265345342142, 4.96564517066034, 3.963132460039432, 4.873688851999408, 5.8431801019273, 6.841005157475183, 7.875421680091055, 8.854420931216607, 9.780452658116936, 10.760617117725008, 11.704432822393034, 12.644217950254472, 13.643803416184772, 14.65349788676107, 15.633242585796593, 16.668108622553575, 15.860017644829682, 7.799733608597469, 6.846365311764786, 5.8362695544173135, 4.854151947445972, 3.91754551495411, 3.013987881716762, 3.9160163113102326, 4.9423767662131795, 5.866694896247061, 6.896340982589245, 7.902605646862013, 8.78229357451093, 9.713214833638691, 10.739480997224586, 11.69127964923281, 12.694829057330507, 13.708445920793036, 14.725391069980443, 15.676583405131648, 16.744354072896535], [16.851697016882262, 15.872941123138434, 14.87823631303914, 13.92323976352284, 12.853658958254321, 11.794164721673226, 10.839881835065295, 9.822813285990064, 8.813778057489333, 7.9252860335974535, 6.8822230858255224, 5.838622421654546, 4.9086427364334995, 3.8981811767915, 2.954824956141266, 1.9455019611079054, 2.9972882944382686, 3.9264924673096395, 4.944960839098048, 5.902900784556154, 15.887364623830138, 14.930070789460125, 13.973735478324263, 12.983743507082542, 11.95040516269196, 10.877566922863066, 9.865133486621275, 8.830625840855799, 7.885324618511572, 6.924759290732449, 5.9923297096913215, 5.05951157587806, 4.039132373591367, 2.99235756685838, 1.9519968638513814, 0.9393985884351792, 2.0037910910564483, 2.9698699315271373, 3.993604391581031, 4.980242993784762, 15.085828793046451, 14.1401007872195, 13.136454610343431, 12.10596355275365, 11.051028601215167, 10.069371475135375, 9.045919816537907, 8.070491325311554, 7.08626424224386, 6.088338751467333, 5.153970442016452, 4.0941039612349615, 3.05698065678804, 2.007396095797951, 1.0142787425288828, 0.0, 1.0474143568273369, 2.0350150458890384, 3.034858237088926, 4.0320065794678355, 16.053848100641535, 15.15245066168963, 14.108145224884721, 13.048545958504276, 11.995177644248642, 11.002004512033905, 10.045113399094229, 9.062724161033705, 8.024431474438316, 7.066250414307364, 6.105408820386579, 5.056250498110256, 4.035819733906967, 2.9891517741384073, 1.981066689030155, 1.055023693062811, 1.9846854517037076, 2.97617351634832, 3.903545674238905, 4.882206456061095, 16.930640692516633, 15.960387670366842, 15.024692406093111, 13.996081387344505, 12.956033174000241, 12.012404212861705, 10.94147649926744, 10.011908240483324, 9.033794169980625, 8.06755273355133, 7.034974649463389, 6.002375596592597, 4.974977966347144, 3.944309054442221, 2.9933834135835697, 2.011657393149384, 2.922181175459211, 3.869047215714656, 4.905095414908908, 5.835839734362773, 16.372599840317054, 16.765590276211356, 15.783565973858787, 14.827672333546698, 13.805984704758007, 12.78109767165819, 11.733564936819146, 10.757692804066615, 9.79110498129817, 8.848378032395747, 7.885971117771175, 6.951073084126528, 5.882492524326613, 4.869912920499482, 3.920820281551224, 3.084827387242436, 3.9549332436008644, 4.804885875732841, 5.7483245845525826, 6.815147810136957, 15.417427559375241, 16.40125668034931, 16.5842622379315, 15.609536487332383, 14.620139166658795, 13.614921349260182, 12.689833397755484, 11.730694347965592, 10.73565609788513, 9.77476103683019, 8.809357278670303, 7.876190515553679, 6.810276445149382, 5.865195014547853, 4.9146895948020735, 4.039153343806415, 4.938809921158252, 5.729904680612526, 6.6822501312422995, 7.636243459243872, 14.43287334535654, 15.444618694582202, 16.3681487251254, 15.744306436515515, 15.113562478502924, 14.582998447647716, 13.646907843711725, 12.670823854524615, 11.65706148366504, 10.715916524225218, 9.709030026028145, 8.732256347697161, 7.761648695463836, 6.801792965219132, 5.8407790049742125, 5.006981079871913, 5.901723972251602, 6.672922211454724, 7.61702990553465, 8.62578201366262, 13.454222611454856, 14.473939424591176, 15.43810454697589, 14.75941473699231, 14.079230830930632, 14.705283035115334, 14.49814091011248, 13.527895789056853, 12.540904848918583, 11.547853029855515, 10.592724463987912, 9.657233611949405, 8.723213989551981, 7.758729860231468, 6.866653267965587, 6.026661995994302, 6.878816077261785, 7.64015373911203, 8.575721273031094, 9.609539736774629, 12.461711874944868, 13.410895118995414, 14.425142264575198, 13.804332921238547, 13.062330671050688, 13.657874312976801, 14.678837372999803, 14.514684864259475, 13.450614233488416, 12.508548529948365, 11.52592608015256, 10.681433055944183, 9.726179869203706, 8.83027435340278, 7.8608745114021765, 6.983606227361644, 7.938562164393621, 8.607033975866992, 9.615942493578315, 10.60112425150425, 11.517574876584819, 12.543744930979356, 13.385454727243227, 12.831660015025253, 12.127040125165708, 12.656629749287784, 13.614403488275377, 14.582269241349337, 14.411469126891419, 13.496615657010476, 12.548831840323345, 11.688904707994382, 10.741943371303542, 9.816372664128295, 8.882696665902776, 7.960354553228387, 8.887707327512771, 9.617960767026728, 10.607854736817876, 11.528383690231347, 10.56152410740419, 11.469879741068528, 12.457738224085736, 11.783497164515826, 11.159292359953469, 11.729131296882546, 12.618378356299253, 13.632720973274788, 14.591623494454836, 14.453073643220312, 13.494781912777206, 12.67771552072667, 11.739650503185986, 10.788260145790973, 9.878594986112684, 8.954073900198397, 9.881577128425818, 10.626568799901342, 11.682206760414754, 12.48769691228039, 9.573404677946732, 10.54371954431039, 11.570716152334178, 10.802254714891601, 10.166147576586448, 10.722082776998082, 11.618516513487327, 12.578065108008065, 13.534456633992024, 14.4953659154382, 14.48534026636902, 13.613794417829649, 12.729677526189311, 11.75285255603248, 10.8053328080933, 10.021713375783216, 10.916884544755261, 11.613182772360458, 12.612740163120122, 13.514850504368527, 8.65830786513797, 9.71954371267204, 10.665714302287899, 9.826828197408764, 9.143043048131101, 9.78364609886503, 10.680365618591086, 11.6234317156558, 12.579990397742005, 13.613525254041331, 14.54337626725843, 14.575087361914942, 13.720706052931805, 12.781960639288581, 11.871410408954192, 11.02544414624061, 11.869758283492647, 12.598403444762456, 13.573459822769319, 14.562684541536262, 7.8422076638794715, 8.892159117191772, 9.790396875215034, 8.867037551322973, 8.14126224214565, 8.767938067901628, 9.71097503762314, 10.68433287978662, 11.642608920212641, 12.66996968262125, 13.711333244127141, 14.730736204752661, 14.70921141856237, 13.782010505508495, 12.882726421672224, 11.989200550418074, 12.933558195905116, 13.622246531498675, 14.543145228594286, 15.49878825047488, 6.861023300196955, 7.837013547139357, 8.846080096018769, 7.93950336211314, 7.101616567037371, 7.714671450050131, 8.68449370676694, 9.731272743624736, 10.699049947236462, 11.624753701124044, 12.66364092245466, 13.703326471287884, 14.461375373154683, 14.783570551165948, 13.824473399578773, 13.026166986741956, 13.948129828841196, 14.692653394186616, 15.514488285055316, 16.444001779712394, 5.917116637543183, 6.931255060664117, 7.880896895489954, 6.9368547955728115, 6.063081184736227, 6.783069594459654, 7.735677996729495, 8.694862227946711, 9.6672561193268, 10.647673555370247, 11.624405250123727, 12.665911733935157, 13.530021327162636, 14.461615435419525, 14.7982642569559, 14.066558616528203, 14.916569120733122, 15.62069817841158, 16.512033451591815, 16.953535778536768, 5.058776059410909, 6.032362960009516, 6.809467523456061, 5.8818627014373055, 5.011984412378089, 5.843699992794118, 6.797670156123034, 7.766812019475843, 8.761773847289158, 9.724937079400839, 10.66770784746863, 11.646698808397739, 12.594973015185202, 13.580610289863065, 14.635465755200473, 15.05756665980041, 15.87498516388359, 16.68315900126887, 17.011036189036762, 16.024481199940556, 5.93644412198913, 6.771133019794855, 5.809595738501455, 4.85898660281326, 3.9513664281314576, 4.845218596323131, 5.796599898463638, 6.76609114839153, 7.763916203939413, 8.798332726555284, 9.777331977680836, 10.703363704581164, 11.723146377737107, 12.666962082405133, 13.60674721026657, 14.606332676196871, 15.616027146773169, 16.59577184580869, 17.630637882565672, 16.874296387358566, 6.785454866068586, 5.832086569235903, 4.821990811888431, 3.8398732049170894, 2.9032667724252272, 3.896074018000461, 4.8389273577744625, 5.865287812677409, 6.789605942711291, 7.819252029053475, 8.825516693326243, 9.796572317039814, 10.727493576167575, 11.75375973975347, 12.705558391761693, 13.70910779985939, 14.72272466332192, 15.739669812509327, 16.690862147660532, 17.75863281542542], [17.899111373709598, 16.920355479965767, 15.925650669866476, 14.970654120350176, 13.901073315081657, 12.841579078500562, 11.88729619189263, 10.8702276428174, 9.861192414316669, 8.97270039042479, 7.92963744265286, 6.886036778481883, 5.956057093260837, 4.945595533618837, 4.002239312968603, 2.9929163179352423, 2.007973435471035, 2.937177608342406, 3.955645980130814, 4.9135859255889205, 16.934778980657473, 15.97748514628746, 15.021149835151599, 14.031157863909877, 12.997819519519295, 11.924981279690401, 10.91254784344861, 9.878040197683134, 8.932738975338909, 7.972173647559786, 7.039744066518659, 6.106925932705398, 5.0865467304187035, 4.039771923685716, 2.9994112206787182, 1.986812945262516, 0.9712736246426826, 1.9373524651133716, 2.9610869251672653, 3.932828636957425, 16.13324314987379, 15.187515144046838, 14.183868967170769, 13.153377909580987, 12.098442958042504, 11.116785831962712, 10.093334173365244, 9.117905682138892, 8.133678599071198, 7.13575310829467, 6.201384798843789, 5.141518318062299, 4.1043950136153775, 3.0548104526252877, 2.0616930993562197, 1.0474143568273369, 0.0, 0.9876006890617015, 1.9874438802615895, 2.9845922226404986, 17.101262457468874, 16.189431848078392, 15.145126411273486, 14.08552714489304, 13.032158830637407, 12.03898569842267, 11.082094585482993, 10.053060209844222, 9.014767523248834, 8.056586463117881, 7.012828884656168, 5.963670562379845, 4.914854410100739, 3.8681864503321792, 2.7939994703903195, 1.8679564744229755, 0.9372710948763706, 1.928759159520983, 2.8561313174115686, 3.8347920992337583, 16.309534237361092, 16.997368856755607, 16.061673592481874, 15.03306257373327, 13.993014360389006, 12.984293743711245, 11.913366030116979, 10.983797771332863, 9.973131293992004, 8.920181908438863, 7.887603824350921, 6.83044628004505, 5.803048649799596, 4.772379737894673, 3.806316194943734, 2.8245901745095487, 1.8747668186318738, 2.8216328588873187, 3.8576810580815715, 4.788425377535437, 15.325185483489715, 16.339025813853596, 16.596498755218953, 15.640605114906862, 14.618917486118171, 13.594030453018354, 12.54649771817931, 11.570625585426779, 10.604037762658335, 9.661310813755911, 8.698903899131338, 7.764005865486692, 6.695425305686777, 5.682845701859646, 4.733753062911388, 3.897760168602601, 2.907518886773527, 3.757471518905504, 4.700910227725245, 5.76773345330962, 14.370013202547904, 15.35384232352197, 16.271108911518112, 15.95435701557967, 15.43307194801896, 14.427854130620346, 13.502766179115648, 12.543627129325756, 11.548588879245294, 10.587693818190354, 9.622290060030467, 8.689123296913843, 7.623209226509546, 6.678127795908017, 5.727622376162238, 4.85208612516658, 3.8913955643309146, 4.6824903237851885, 5.634835774414962, 6.588829102416534, 13.385458988529203, 14.397204337754863, 15.320734368298064, 14.907719028005324, 15.876345276152092, 15.395931229007878, 14.459840625071887, 13.483756635884777, 12.469994265025202, 11.52884930558538, 10.521962807388308, 9.545189129057324, 8.574581476824, 7.614725746579296, 6.653711786334377, 5.819913861232079, 4.854309615424265, 5.6255078546273865, 6.569615548707313, 7.578367656835282, 12.406808254627519, 13.426525067763837, 14.39069019014855, 13.92282732848212, 14.871854786720814, 15.75269739194267, 15.311073691472641, 14.340828570417013, 13.353837630278743, 12.360785811215678, 11.405657245348074, 10.470166393309567, 9.536146770912143, 8.571662641591631, 7.679586049325751, 6.78485260277335, 5.831401720434448, 6.592739382284693, 7.528306916203756, 8.56212537994729, 11.414297518117529, 12.363480762168075, 13.37772790774786, 12.967745512728357, 13.85495462684087, 14.705288669804137, 15.726251729827142, 15.327617645619638, 14.263547014848578, 13.321481311308528, 12.338858861512723, 11.494365837304345, 10.539112650563869, 9.643207134762944, 8.67380729276234, 7.741796834140692, 6.891147807566283, 7.559619619039654, 8.568528136750977, 9.553709894676913, 10.47016051975748, 11.496330574152019, 12.33804037041589, 11.995072606515063, 12.91966408095589, 13.70404410611512, 14.661817845102716, 15.629683598176676, 15.224401908251581, 14.309548438370639, 13.361764621683507, 12.501837489354545, 11.554876152663704, 10.629305445488459, 9.69562944726294, 8.718545160007436, 7.840292970685434, 8.57054641019939, 9.560440379990537, 10.48096933340401, 9.514109750576852, 10.42246538424119, 11.410323867258398, 10.946909756005635, 11.95191631574365, 12.776545653709881, 13.665792713126592, 14.680135330102127, 15.639037851282175, 15.266006424580475, 14.307714694137369, 13.490648302086832, 12.552583284546149, 11.601192927151137, 10.691527767472849, 9.712264506977444, 8.83416277159848, 9.579154443074003, 10.634792403587415, 11.440282555453052, 8.525990321119394, 9.496305187483053, 10.52330179550684, 9.96566730638141, 11.00816805873693, 11.76949713382542, 12.665930870314666, 13.625479464835404, 14.581870990819363, 15.542780272265539, 15.298273047729182, 14.426727199189811, 13.542610307549474, 12.565785337392644, 11.618265589453465, 10.779903982562264, 9.869470187927924, 10.56576841553312, 11.565325806292783, 12.46743614754119, 7.6108935083106335, 8.672129355844703, 9.618299945460562, 8.990240788898573, 9.985063530281582, 10.831060455692366, 11.727779975418425, 12.670846072483139, 13.627404754569344, 14.66093961086867, 15.59079062408577, 15.388020143275105, 14.533638834291967, 13.594893420648745, 12.684343190314356, 11.783634753019657, 10.822343926665312, 11.550989087935116, 12.52604546594198, 13.515270184708925, 6.794793307052134, 7.844744760364437, 8.742982518387699, 8.030450142812782, 9.026812762045765, 9.815352424728966, 10.758389394450479, 11.731747236613959, 12.69002327703998, 13.71738403944859, 14.758747600954479, 15.778150561579999, 15.522144199922534, 14.59494328686866, 13.695659203032388, 12.747391157197121, 11.88614383907778, 12.574832174671336, 13.495730871766947, 14.451373893647542, 5.813608943369618, 6.789599190312021, 7.798665739191433, 7.10291595360295, 8.063155560148946, 8.762085806877469, 9.731908063594279, 10.778687100452075, 11.746464304063801, 12.672168057951383, 13.711055279281997, 14.750740828115221, 15.50878972998202, 15.596503332526112, 14.637406180938937, 13.784357593521005, 12.90071547201386, 13.645239037359277, 14.467073928227977, 15.396587422885055, 4.869702280715846, 5.88384070383678, 6.834808030396855, 6.100267387062622, 7.0789217606468, 7.8304839512869915, 8.783092353556833, 9.74227658477405, 10.714670476154138, 11.695087912197586, 12.671819606951065, 13.713326090762495, 14.577435683989973, 15.509029792246862, 15.611197038316064, 14.814364997819247, 13.869154763905787, 14.57328382158424, 15.464619094764476, 16.373037009695693, 4.011361702583573, 4.984948603182179, 5.924233797395019, 5.045275292927116, 6.027824988288662, 6.891114349621455, 7.845084512950371, 8.81422637630318, 9.809188204116495, 10.772351436228176, 11.715122204295968, 12.694113165225076, 13.64238737201254, 14.628024646690402, 15.68288011202781, 15.805373041091453, 14.827570807056254, 15.635744644441532, 16.473887540732477, 17.071895556767895, 4.889029765161793, 5.934545611284666, 4.973008329991266, 4.02239919430307, 4.967207004042031, 5.892632953150469, 6.8440142552909755, 7.813505505218867, 8.81133056076675, 9.845747083382621, 10.824746334508173, 11.750778061408502, 12.770560734564445, 13.71437643923247, 14.654161567093908, 15.653747033024208, 15.808415083148585, 16.639452518716016, 17.429083138194716, 17.9217107441859, 5.816715398795969, 4.982436504916028, 3.980273880495234, 3.0032857964068995, 3.9398922288987617, 4.9434883748277985, 5.8863417146018, 6.912702169504747, 7.837020299538628, 8.866666385880812, 9.87293105015358, 10.84398667386715, 11.77490793299491, 12.801174096580805, 13.752972748589029, 14.756522156686726, 15.770139020149255, 16.787084169336662, 17.738276504487867, 18.806047172252754], [18.8867120627713, 17.907956169027468, 16.91325135892818, 15.958254809411878, 14.88867400414336, 13.829179767562264, 12.874896880954333, 11.857828331879102, 10.848793103378371, 9.960301079486491, 8.91723813171456, 7.873637467543584, 6.943657782322537, 5.933196222680538, 4.989840002030304, 3.9805170069969433, 2.9955741245327365, 2.1251758102682397, 3.0880120640317426, 4.004469824195509, 17.922379669719174, 16.96508583534916, 16.0087505242133, 15.018758552971578, 13.985420208580996, 12.912581968752102, 11.900148532510311, 10.865640886744837, 9.920339664400611, 8.959774336621487, 8.02734475558036, 7.094526621767099, 6.074147419480406, 5.027372612747419, 3.9870119097404197, 2.9744136343242173, 1.958874313704384, 1.0675178281678293, 2.038511199147447, 2.9452279478957233, 17.120843838935492, 16.175115833108542, 15.171469656232471, 14.14097859864269, 13.086043647104207, 12.104386521024415, 11.080934862426947, 10.105506371200594, 9.1212792881329, 8.123353797356373, 7.188985487905491, 6.129119007124, 5.091995702677079, 4.04241114168699, 3.049293788417921, 2.0350150458890384, 0.9876006890617015, 0.0, 0.999843191199888, 1.996991533578797, 16.531354618885366, 17.1770325371401, 16.13272710033519, 15.073127833954745, 14.019759519699111, 13.026586387484373, 12.069695274544697, 11.040660898905927, 10.002368212310538, 9.044187152179585, 8.00042957371787, 6.951271251441547, 5.902455099162441, 4.855787139393881, 3.7816001594520214, 2.8555571634846775, 1.9248717839380722, 1.037854532473661, 1.9652266903642464, 2.9438874721864363, 15.59991893696126, 16.57017195911105, 17.04927428154358, 16.020663262794972, 14.98061504945071, 13.971894432772945, 12.90096671917868, 11.971398460394564, 10.960731983053705, 9.907782597500564, 8.875204513412623, 7.818046969106752, 6.790649338861298, 5.759980426956376, 4.793916884005436, 3.8121908635712507, 2.8623675076935755, 2.112017558487488, 2.978369467317693, 3.909113786771558, 14.615570183089883, 15.629410513453765, 16.556693357488513, 16.628205803968562, 15.606518175179874, 14.581631142080056, 13.534098407241013, 12.558226274488481, 11.591638451720037, 10.648911502817613, 9.68650458819304, 8.751606554548394, 7.68302599474848, 6.670446390921349, 5.721353751973091, 4.885360857664303, 3.8951195758352286, 3.0478562185056735, 3.9412045058141163, 4.906556344448958, 13.660397902148071, 14.644227023122138, 15.561493611118284, 16.5362193617174, 16.420672637080663, 15.415454819682049, 14.49036686817735, 13.53122781838746, 12.536189568306996, 11.575294507252057, 10.60989074909217, 9.676723985975546, 8.610809915571249, 7.665728484969719, 6.71522306522394, 5.839686814228282, 4.878996253392616, 3.9728750233853574, 4.9252204740151315, 5.879213802016704, 12.67584368812937, 13.68758903735503, 14.611119067898233, 15.573554363927762, 16.542180612074528, 16.383531918069583, 15.44744131413359, 14.47135732494648, 13.457594954086904, 12.516449994647083, 11.50956349645001, 10.532789818119026, 9.562182165885702, 8.602326435640999, 7.641312475396079, 6.80751455029378, 5.841910304485967, 4.915892554227555, 5.860000248307482, 6.868752356435451, 11.697192954227686, 12.716909767364005, 13.68107488974872, 14.604347505659874, 15.642131693581932, 16.654462721226373, 16.298674380534344, 15.328429259478717, 14.341438319340448, 13.348386500277382, 12.393257934409778, 11.457767082371271, 10.523747459973848, 9.559263330653334, 8.667186738387453, 7.772453291835052, 6.819002409496149, 5.883124081884862, 6.818691615803925, 7.852510079547458, 10.704682217717698, 11.653865461768245, 12.668112607348029, 13.64926568990611, 14.64114174666382, 15.626556179180206, 16.67477310572893, 16.315218334681344, 15.251147703910283, 14.309082000370232, 13.326459550574427, 12.48196652636605, 11.526713339625573, 10.630807823824647, 9.661407981824043, 8.729397523202394, 7.802938139871709, 6.850004318639823, 7.858912836351146, 8.844094594277081, 9.760545219357649, 10.786715273752186, 11.628425070016057, 12.698979384221861, 13.70585120077884, 14.639455179676176, 15.610339221004505, 16.578204974078464, 16.212002597313283, 15.297149127432343, 14.349365310745211, 13.489438178416249, 12.542476841725408, 11.616906134550161, 10.683230136324642, 9.706145849069138, 8.75208330299086, 7.860931109799559, 8.850825079590706, 9.771354033004178, 8.804494450177021, 9.712850083841358, 10.700708566858566, 11.733096875828585, 12.7381034355666, 13.711956727270938, 14.617223824617001, 15.631566441592536, 16.590468962772587, 16.25360711364218, 15.295315383199073, 14.478248991148536, 13.540183973607853, 12.58879361621284, 11.679128456534551, 10.677867622160214, 9.745953103903906, 8.869539142674173, 9.925177103187584, 10.73066725505322, 7.816375020719562, 8.78668988708322, 9.813686495107008, 10.75185442620436, 11.79435517855988, 12.704908207386474, 13.617361981805075, 14.576910576325814, 15.533302102309772, 16.49421138375595, 16.285873736790887, 15.414327888251515, 14.530210996611178, 13.553386026454346, 12.605866278515167, 11.73927939347208, 10.78126052023335, 9.856153115133289, 10.855710505892953, 11.757820847141357, 6.887442085409077, 7.948677932943148, 8.86624484416107, 9.776427908721523, 10.771250650104532, 11.76647152925342, 12.679211086908834, 13.622277183973548, 14.579898109123285, 15.61343296542261, 16.54328397863971, 16.37562083233681, 15.521239523353671, 14.582494109710447, 13.644364489813707, 12.699796811169623, 11.734134258970737, 10.841373787535286, 11.816430165542151, 12.805654884309092, 5.933616198191473, 6.9654331696005585, 7.854143551828093, 8.816637262635732, 9.812999881868715, 10.754987256027896, 11.709820505940888, 12.683178348104368, 13.64251663159392, 14.66987739400253, 15.719992973706002, 16.739395934331522, 16.509744888984237, 15.582543975930362, 14.62005875561905, 13.663553215347088, 12.797934171383206, 11.865216874271505, 12.786115571367118, 13.74175859324771, 4.93429735260574, 5.910287599548143, 6.909826772631827, 7.8891030734259, 8.849342679971896, 9.701720638176399, 10.68440141814822, 11.731180455006015, 12.698957658617742, 13.624661412505324, 14.67230065203352, 15.711986200866745, 16.49639041904372, 16.520902885112775, 15.561805733525599, 14.70051965167097, 13.812505804319287, 12.935623736959446, 13.757458627828148, 14.686972122485223, 3.9753947846913897, 4.989533207812324, 5.940500534372398, 6.886454506885571, 7.8980303652145265, 8.770118782585921, 9.735585708110774, 10.69476993932799, 11.667163830708079, 12.647581266751526, 13.659420296012765, 14.700926779824195, 15.565036373051674, 16.496630481308564, 16.535596590902728, 15.726155330124673, 14.780945096211212, 13.86366852118441, 14.755003794364647, 15.66342170929586, 3.0237610135218707, 3.9973479141204775, 4.936633108333318, 5.864237930352074, 6.846933592856389, 7.830749180920384, 8.797577867504312, 9.766719730857123, 10.782503096824996, 11.759952125289876, 12.702722893357668, 13.681713854286777, 14.62998806107424, 15.615625335752103, 16.67048080108951, 16.71716337339688, 15.73936113936168, 14.926129344041701, 15.764272240332648, 16.592476287892072, 3.9014290761000914, 4.958696396690717, 4.229144166222142, 5.009999883364771, 5.954807693103732, 6.880233642212169, 7.831614944352676, 8.801106194280568, 9.79893124982845, 10.833347772444322, 11.812347023569874, 12.738378750470202, 13.758161423626145, 14.701977128294171, 15.641762256155609, 16.64134772208591, 16.72020541545401, 15.929837218316184, 16.719467837794888, 17.657009425189976, 4.8291147097342675, 4.114802588816957, 3.1682720824210677, 3.990886485468601, 4.927492917960463, 5.931089063889499, 6.8739424036635, 7.900302858566447, 8.824620988600328, 9.854267074942513, 10.860531739215281, 11.831587362928852, 12.762508622056613, 13.788774785642508, 14.740573437650731, 15.744122845748429, 16.75773970921096, 16.981043268344834, 17.737217933533163, 18.718656288411665], [18.639229391353282, 17.97294332602794, 17.91309455012806, 16.958098000611763, 15.888517195343246, 14.82902295876215, 13.87474007215422, 12.857671523078988, 11.848636294578258, 10.960144270686378, 9.917081322914447, 8.873480658743471, 7.943500973522426, 6.933039413880426, 5.989683193230192, 4.9803601981968315, 3.9954173157326247, 3.1066372446202624, 2.0881688728318544, 3.0046266329956204, 17.56754363400026, 17.964929026549044, 17.008593715413184, 16.018601744171463, 14.985263399780882, 13.912425159951988, 12.899991723710198, 11.865484077944723, 10.920182855600498, 9.959617527821374, 9.027187946780247, 8.094369812966987, 7.073990610680293, 6.027215803947306, 4.986855100940308, 3.9742568255241055, 2.958717504904272, 2.0624024680014528, 1.0386680079475592, 1.945384756695835, 16.561761846783615, 17.17495902430843, 16.171312847432358, 15.140821789842576, 14.085886838304093, 13.104229712224301, 12.080778053626833, 11.10534956240048, 10.121122479332787, 9.12319698855626, 8.188828679105377, 7.1289621983238876, 6.091838893876966, 5.042254332886877, 4.049136979617809, 3.034858237088926, 1.9874438802615895, 0.999843191199888, 0.0, 0.9971483423789091, 15.593742539188531, 16.56282587433964, 17.092207720154697, 16.03260845377425, 14.97924013951862, 13.986067007303882, 13.029175894364206, 12.000141518725435, 10.961848832130046, 10.003667771999094, 8.95991019353738, 7.910751871261057, 6.861935718981951, 5.815267759213391, 4.741080779271531, 3.815037783304187, 2.884352403757582, 1.8928643391129691, 0.9654921812223838, 1.9441529630445737, 14.662306857264424, 15.632559879414213, 16.5362507269995, 16.98014388261448, 15.94009566927022, 14.931375052592456, 13.86044733899819, 12.930879080214075, 11.920212602873216, 10.867263217320074, 9.834685133232133, 8.777527588926262, 7.750129958680808, 6.719461046775885, 5.753397503824946, 4.771671483390761, 3.821848127513085, 2.967027365126796, 1.97863495817583, 2.9093792776296956, 13.677958103393047, 14.69179843375693, 15.596502435219415, 16.552396075531504, 16.565998794999384, 15.541111761899566, 14.493579027060523, 13.517706894307992, 12.551119071539548, 11.608392122637124, 10.64598520801255, 9.711087174367904, 8.64250661456799, 7.629927010740858, 6.6808343717926, 5.844841477483813, 4.854600195654738, 3.8849087054919944, 2.9414699966722533, 3.9068218353070954, 12.722785822451236, 13.684036100853039, 14.601302688849184, 15.576028439448303, 16.532761682005685, 16.37493543950156, 15.44984748799686, 14.490708438206969, 13.495670188126507, 12.534775127071567, 11.569371368911678, 10.636204605795054, 9.570290535390757, 8.625209104789228, 7.67470368504345, 6.799167434047792, 5.838476873212126, 4.809927510371678, 3.9304614234683566, 4.884454751469929, 11.738231608432535, 12.727398115085931, 13.650928145629134, 14.613363441658663, 15.58198968980543, 16.56528891982705, 16.4069219339531, 15.43083794476599, 14.417075573906414, 13.475930614466593, 12.46904411626952, 11.492270437938537, 10.521662785705212, 9.561807055460509, 8.60079309521559, 7.76699517011329, 6.755281745022231, 5.752945041213875, 4.938001963509654, 5.902524636158532, 10.759580874530851, 11.756718845094905, 12.72088396747962, 13.644156583390775, 14.658198715343875, 15.670529742988318, 16.647036949966985, 16.287909879298226, 15.300918939159956, 14.30786712009689, 13.352738554229287, 12.41724770219078, 11.483228079793356, 10.518743950472844, 9.602134931648106, 8.642923104421238, 7.689472222082336, 6.720176568871182, 5.896693331006097, 6.913836870793682, 9.744491295448599, 10.693674539499145, 11.70792168507893, 12.689074767637011, 13.641298555463932, 14.626712987980317, 15.674929914529041, 16.62247646227773, 16.210628323729793, 15.26856262018974, 14.285940170393935, 13.441447146185558, 12.486193959445082, 11.581483292769882, 10.588047432683515, 9.59986733578858, 8.63999062685803, 7.687056805626143, 6.959208747212232, 7.9064825145802455, 8.80035429708855, 9.820487553475266, 10.662197349739136, 11.73275166394494, 12.706008009578952, 13.639611988476286, 14.610496029804615, 15.578361782878575, 16.55549245612435, 16.256629747251854, 15.30884593056472, 14.448918798235757, 13.476067905097153, 12.510303612113166, 11.57093124692164, 10.576615661655325, 9.589135789977181, 8.697983596785878, 7.956037446354268, 8.833741953307342, 7.844303527907922, 8.746622363564438, 9.734480846581645, 10.733253684628696, 11.738260244366712, 12.712113536071048, 13.617380633417113, 14.631723250392648, 15.590625771572697, 16.528986969292664, 16.254796003018583, 15.437729610968045, 14.473775036979598, 13.482191093775844, 12.55856827219795, 11.514920109146535, 10.583005590890227, 9.706591629660492, 9.030389469951146, 9.793055175356384, 6.850147300442643, 7.8204621668063, 8.818972381901482, 9.752011235004472, 10.794511987359991, 11.705065016186586, 12.617518790605187, 13.577067385125925, 14.533458911109884, 15.49436819255606, 16.446914279559454, 16.373808508071026, 15.463802059982923, 14.44678350401735, 13.485306094178567, 12.576331880458401, 11.61831300721967, 10.693205602119608, 10.078682979258824, 10.820208767444521, 5.887707576267214, 6.948943423801285, 7.866401652961182, 8.776584717521635, 9.771407458904644, 10.766628338053533, 11.679367895708946, 12.62243399277366, 13.580054917923398, 14.613589774222724, 15.543440787439824, 16.570403502378564, 16.454830586725414, 15.451619072117948, 14.481416976800027, 13.536849298155943, 12.571186745957057, 11.678426274521605, 11.039402638908022, 11.868042804612257, 4.93388168904961, 5.9656986604586955, 6.854300360628205, 7.816794071435844, 8.813156690668826, 9.755144064828007, 10.709977314741, 11.68333515690448, 12.642673440394034, 13.670034202802643, 14.720149782506116, 15.739552743131636, 16.48500121697548, 16.451668938337864, 15.45711124260537, 14.500605702333408, 13.634986658369526, 12.702269361257825, 12.009088044732989, 12.804146513550874, 3.934562843463877, 4.91055309040628, 5.909983581431939, 6.889259882226011, 7.849499488772008, 8.70187744697651, 9.684558226948333, 10.731337263806129, 11.699114467417855, 12.624818221305437, 13.672457460833634, 14.712143009666859, 15.543050125216212, 16.574760573486433, 16.39885822051192, 15.53757213865729, 14.649558291305606, 13.772676223945766, 12.98043110119402, 13.749360042788389, 2.9755515934915016, 3.9896900166124354, 4.94065734317251, 5.886611315685683, 6.898187174014639, 7.770275591386033, 8.735742516910888, 9.694926748128104, 10.667320639508192, 11.64773807555164, 12.706080002185256, 13.747586485996687, 14.611696079224165, 15.543290187481054, 16.515893190658986, 16.563207817110992, 15.617997583197532, 14.70072100817073, 13.977976267730519, 14.725809629599027, 2.023917822321983, 2.99750472292059, 3.9367899171334306, 4.8643947391521865, 5.8470904016565015, 6.830905989720497, 7.797734676304426, 8.766876539657236, 9.78265990562511, 10.806611831462368, 11.74938259953016, 12.728373560459268, 13.676647767246731, 14.662285041924594, 15.717140507262002, 16.75119133393202, 16.576413626348, 15.763181831028021, 14.98724471369852, 15.654864208195239, 2.901585884900203, 3.958853205490829, 4.920390486784229, 5.870999622472425, 6.815807432211386, 7.829387386191484, 8.795229959737782, 9.764721209665673, 10.762546265213556, 11.733216184307922, 12.712215435433475, 13.638247162333803, 14.658029835489746, 15.601845540157772, 16.54163066801921, 17.54121613394951, 17.55725790244033, 16.766889705302503, 15.94244031116076, 16.719397345493142, 3.8292715185343793, 3.1149593976170684, 4.125055154964541, 4.990729676668489, 5.927336109160351, 6.930932255089387, 7.873785594863389, 8.900146049766334, 9.824464179800216, 10.854110266142401, 11.860374930415169, 12.831430554128739, 13.7623518132565, 14.788617976842394, 15.740416628850618, 16.743966036948315, 17.757582900410846, 17.818095755331154, 16.960190406899034, 17.78104420871483], [17.76454937214947, 18.5807539065727, 18.910242892506975, 17.955246342990677, 16.885665537722158, 15.826171301141061, 14.87188841453313, 13.854819865457898, 12.845784636957168, 11.944661186554507, 10.901598238782576, 9.8579975746116, 8.928017889390555, 7.917556329748555, 6.974200109098321, 5.964877114064961, 4.913090780734597, 3.983886607863226, 2.965418236074818, 2.0074782906167115, 16.692863614796448, 17.637883572894392, 18.005742057792094, 17.015750086550373, 15.982411742159792, 14.909573502330899, 13.897140066089108, 12.862632420323633, 11.917331197979408, 10.956765870200284, 10.024336289159157, 9.091518155345897, 8.071138953059203, 7.024364146326215, 5.984003443319217, 4.971405167903015, 3.955865847283181, 3.0386998677341452, 2.014965407680252, 0.9482364143169261, 15.687081827579801, 16.632809833406753, 17.168461189811268, 16.137970132221486, 15.083035180683003, 14.101378054603211, 13.077926396005743, 12.10249790477939, 11.118270821711697, 10.12034533093517, 9.185977021484288, 8.126110540702797, 7.088987236255876, 6.039402675265786, 5.046285321996718, 4.0320065794678355, 2.9845922226404986, 1.996991533578797, 0.9971483423789091, 0.0, 14.719062519984716, 15.688145855135827, 16.669780975581183, 17.029756796153166, 15.97638848189753, 14.983215349682792, 14.026324236743116, 12.997289861104345, 11.958997174508957, 11.000816114378004, 9.957058535916289, 8.907900213639966, 7.85908406136086, 6.8124161015923, 5.73822912165044, 4.8121861256830964, 3.881500746136491, 2.8900126814918785, 1.962640523601293, 1.0406007727211155, 13.787626838060609, 14.757879860210398, 15.638091664452249, 16.65549695159458, 16.93724401164913, 15.928523394971366, 14.8575956813771, 13.928027422592985, 12.917360945252126, 11.864411559698985, 10.831833475611043, 9.774675931305172, 8.747278301059717, 7.716609389154795, 6.750545846203855, 5.76881982576967, 4.818996469891994, 3.9641757075057056, 2.9546378758213936, 2.023893556367528, 12.803278084189232, 13.817118414553114, 14.698343372672161, 15.65423701298425, 16.56105238517358, 16.538260104278475, 15.490727369439432, 14.5148552366869, 13.548267413918456, 12.605540465016032, 11.64313355039146, 10.708235516746813, 9.639654956946899, 8.627075353119768, 7.67798271417151, 6.8419898198627225, 5.851748538033648, 4.860911623137558, 3.917472914317817, 3.021336114044928, 11.848105803247421, 12.809356081649224, 13.70314362630193, 14.677869376901048, 15.6163128545965, 16.621530671995114, 16.44699583037577, 15.48785678058588, 14.492818530505415, 13.531923469450476, 12.566519711290589, 11.633352948173965, 10.567438877769668, 9.622357447168138, 8.671852027422359, 7.7963157764267015, 6.829505350758842, 5.785930428017242, 4.906464341113921, 4.009774732266114, 10.86355158922872, 11.852718095882116, 12.75276908308188, 13.69691461424948, 14.665540862396247, 15.60598026535708, 16.54207086929307, 16.427986287144897, 15.414223916285323, 14.473078956845502, 13.466192458648429, 12.489418780317445, 11.51881112808412, 10.558955397839418, 9.597941437594498, 8.7641435124922, 7.731284662667795, 6.72894795885944, 5.914004881155218, 5.027844616954717, 9.884900855327036, 10.88203882589109, 11.822724904932366, 12.712022914726274, 13.661050372964967, 14.67338140060941, 15.64988860758808, 16.620133728643708, 16.298067281538867, 15.3050154624758, 14.349886896608197, 13.41439604456969, 12.480376422172267, 11.515892292851753, 10.57813784929367, 9.618926022066802, 8.6654751397279, 7.696179486516746, 6.872696248651661, 6.039156851589867, 8.869811276244784, 9.81899452029533, 10.809762622531675, 11.756941098972511, 12.644150213085023, 13.629564645601409, 14.677781572150135, 15.625328119898825, 16.519199007148448, 16.26571096256865, 15.283088512772846, 14.438595488564468, 13.483342301823992, 12.557486210415444, 11.564050350329078, 10.575870253434143, 9.615993544503594, 8.663059723271708, 7.935211664857796, 7.03180249537643, 7.925674277884735, 8.94580753427145, 9.73696811454171, 10.784268192759217, 11.708859667200043, 12.64246364609738, 13.613347687425708, 14.581213440499669, 15.558344113745445, 16.48829661312359, 16.305994272943632, 15.437262984418467, 14.452070822742716, 13.486306529758728, 12.546934164567203, 11.552618579300887, 10.565138707622745, 9.673986514431444, 8.932040363999832, 7.959061934103527, 6.969623508704107, 7.8719423443606225, 8.80925161138422, 9.736105342249788, 10.741111901987804, 11.71496519369214, 12.620232291038205, 13.63457490801374, 14.593477429193788, 15.531838626913755, 16.44032429077236, 16.424912921906742, 15.44977795462516, 14.458194011421407, 13.534571189843515, 12.4909230267921, 11.559008508535792, 10.682594547306058, 9.84490273466394, 8.91837515615257, 5.975467281238828, 6.945782147602485, 7.821824039522571, 8.754862892625564, 9.797363644981083, 10.707916673807677, 11.620370448226279, 12.579919042747017, 13.536310568730975, 14.497219850177151, 15.449765937180546, 16.385236067036157, 16.439804977628487, 15.422786421662913, 14.461309011824131, 13.552334798103965, 12.594315924865235, 11.669208519765174, 10.877726422832367, 9.945528748240706, 5.002221855005047, 6.0520048830838995, 6.8692533105822715, 7.779436375142726, 8.774259116525736, 9.769479995674624, 10.682219553330038, 11.625285650394751, 12.582906575544488, 13.616441431843814, 14.546292445060914, 15.573255159999654, 16.52851786499497, 16.427621989763512, 15.457419894445593, 14.512852215801509, 13.547189663602623, 12.654429192167171, 11.838446082481564, 10.993362785408442, 4.048395967787442, 4.997112881984878, 5.857152018249295, 6.819645729056934, 7.816008348289918, 8.757995722449099, 9.712828972362091, 10.686186814525572, 11.645525098015126, 12.672885860423733, 13.723001440127208, 14.742404400752728, 15.487852874596568, 16.415053787650443, 16.433114160250938, 15.476608619978974, 14.610989576015092, 13.67827227890339, 12.80813148830653, 11.929466494347059, 3.022214491037233, 3.941967311932462, 4.912835239053029, 5.892111539847102, 6.852351146393099, 7.704729104597602, 8.687409884569425, 9.734188921427219, 10.701966125038947, 11.627669878926529, 12.675309118454726, 13.71499466728795, 14.545901782837301, 15.577612231107523, 16.492535705657204, 16.513575056302855, 15.625561208951172, 14.748679141591332, 13.779474544767561, 12.874680023584574, 1.9784032511125924, 2.9925416742335265, 3.9435090007936004, 4.889462973306774, 5.901038831635731, 6.773127249007125, 7.738594174531979, 8.697778405749196, 9.670172297129284, 10.650589733172731, 11.708931659806346, 12.750438143617776, 13.614547736845255, 14.546141845102143, 15.518744848280075, 16.584142364909905, 16.594000500843098, 15.676723925816296, 14.77701971130406, 13.851129610395212, 1.0267694799430735, 2.0003563805416804, 2.9396415747545213, 3.8672463967732775, 4.849942059277593, 5.833757647341589, 6.8005863339255175, 7.769728197278327, 8.7855115632462, 9.809463489083457, 10.75223425715125, 11.731225218080358, 12.67949942486782, 13.665136699545684, 14.719992164883092, 15.75404299155311, 16.794145861772336, 16.739184748673587, 15.76673917808763, 14.780184188991424, 1.9044375425212943, 2.9617048631119203, 3.9232421444053207, 4.8738512800935165, 5.818659089832478, 6.832239043812575, 7.798081617358873, 8.767572867286765, 9.765397922834648, 10.736067841929012, 11.715067093054564, 12.641098819954893, 13.660881493110836, 14.604697197778862, 15.544482325640299, 16.5440677915706, 17.5537622621469, 17.74289262294807, 16.72193477554987, 15.844717326289327, 2.83212317615547, 3.785491472988153, 4.7955872303356255, 5.777704837306967, 6.714311269798829, 7.7813836221352455, 8.751029144344788, 9.732832963711342, 10.72780338909965, 11.757449475441835, 12.762792205487983, 13.643786197819036, 14.574707456946797, 15.600973620532692, 16.516704480702934, 17.52025388880063, 18.533870752263162, 18.69087720643935, 17.739684871288144, 16.906364189511017], [3.0454868521647533, 3.8616913865879834, 4.899758429538769, 5.837629524429542, 6.90721032969806, 7.945154063076782, 8.899436949684713, 9.916505498759944, 10.871929107297296, 11.824338189319802, 12.867401137091733, 13.807120142185147, 14.737099827406192, 15.747561387048192, 16.690917607698424, 17.700240602731785, 18.752026936062148, 18.656530429153612, 17.681911412020384, 16.726540810601428, 1.9738010948117304, 2.9188210529096743, 3.8751563640455355, 4.865148335287258, 5.8984866796778395, 6.971324919506733, 7.983758355748523, 8.99817444597531, 9.943475668319536, 10.90404099609866, 11.836470577139787, 12.769288710953047, 13.822027389791051, 14.868802196524038, 15.915331102987238, 16.92792937840344, 17.99232188102471, 17.5988724470532, 16.63241054713609, 15.667298934301641, 0.9680193075950846, 1.9137473134220357, 2.9173934902981054, 3.9478845478878863, 5.002819499426369, 5.984476625506161, 7.007928284103628, 7.983356775329982, 8.967583858397676, 9.965509349174203, 10.899877658625083, 11.959744139406574, 12.996867443853496, 14.046452004843585, 15.039569358112654, 16.053848100641538, 17.101262457468874, 16.53135461888537, 15.593742539188531, 14.719062519984716, 0.0, 0.9690833351511113, 2.013388771956019, 3.0729880383364647, 4.126356352592099, 5.1195294848068365, 6.076420597746512, 7.1054549733852825, 8.14374765998067, 9.101928720111623, 10.145686298573338, 11.194844620849661, 12.243660773128767, 13.290328732897326, 14.364515712839186, 15.290558708806529, 16.221244088353135, 15.493500086411709, 14.628250357966147, 13.6784617472636, 0.9314356819241071, 1.9016887040738966, 2.8373839683476283, 3.865994987096234, 4.925148500550368, 5.981362637433786, 7.043357706126667, 7.972925964910782, 8.983592442251641, 10.036541827804783, 11.069119911892724, 12.126277456198595, 13.15367508644405, 14.184343998348973, 15.150407541299913, 16.132133561734097, 15.366203100653326, 14.419337060397881, 13.615107581012701, 12.695168963617188, 1.9157844357954836, 2.905136266176372, 3.7771322601277157, 4.733025900439805, 5.7547135292284946, 6.779600562328312, 7.8271332971673555, 8.803005429919887, 9.769593252688331, 10.712320201590755, 11.674727116215328, 12.609625149859975, 13.678205709659888, 14.69078531348702, 15.639877952435278, 15.487807677165524, 14.483923168911415, 13.483498400379695, 12.652272542516277, 11.697726405939788, 2.8709567167372954, 3.9105909246550814, 4.772332006497947, 5.72203105375613, 6.699453059805572, 7.704670877204185, 8.629758828708884, 9.596617429574666, 10.59165567965513, 11.638703206025198, 12.670937618558444, 13.604104381675068, 14.624812253700986, 15.569893684302516, 15.482152572940944, 14.558485724738448, 13.557532346315194, 12.55847959550001, 11.663281115720174, 10.709287787718603, 3.8555109307559965, 4.867228910422188, 5.722706549717997, 6.685141845747527, 7.650225052005826, 8.633524282027446, 9.569614885963437, 10.545698875150547, 11.559461246010123, 12.500606205449944, 13.507492703647017, 14.484266381978001, 15.454874034211326, 15.467269822358338, 14.556063162768805, 13.59065798867295, 12.594618295221842, 11.615462064657812, 10.672415499634827, 9.69121790303, 4.834161664657681, 5.837908180413214, 6.65275072786751, 7.623401130662238, 8.661185318584296, 9.566123146775116, 10.580752984645827, 11.550998105701455, 12.537989045839725, 13.44062885162746, 14.395757417495064, 15.331248269533571, 15.4178767902561, 14.510332927346003, 13.53018889977743, 12.570977072550562, 11.61752619021166, 10.648230537000506, 9.713724132138383, 8.679905668394849, 5.90312636217787, 6.852309606228417, 7.6657130102682025, 8.578482946416, 9.627166043369531, 10.612580475885917, 11.552860020083772, 12.555475197644034, 13.52128590022427, 14.46335160376432, 15.328959033659713, 15.411118230159113, 14.414910910604375, 13.43878843417469, 12.556897615562818, 11.625229583668418, 10.63428412147743, 9.681350300245544, 8.672441782534221, 7.687260024608285, 6.847263360537919, 7.8648804758873, 8.738507518258167, 9.551155852629295, 10.562456589254511, 11.496592538432447, 12.467476579760776, 13.435342332834736, 14.431851108207475, 15.45141873082643, 15.352122629857462, 14.403646578108914, 13.418454416433162, 12.452690123449175, 11.535075461062219, 10.648481257801674, 9.70792005254137, 8.758550223702038, 7.801566965940397, 6.760000585881189, 7.803314129718547, 8.768959106936729, 9.666224021415658, 10.599318703138724, 11.53020435446675, 12.424090990837685, 13.4635017117369, 14.40841688990115, 15.374226362198208, 15.52920187821671, 14.494262109286641, 13.528914326425943, 12.553779359144361, 11.480802641786497, 10.53917714085231, 9.654761910831665, 8.722847392575357, 7.749942190827424, 6.727214942343518, 5.8006873638321474, 8.797470357183826, 9.695119303694867, 10.653651593277306, 11.580561152762948, 12.52334913783377, 13.431139510722147, 14.405333823688576, 15.364882418209314, 15.455492382926282, 14.494583101480107, 13.542037014476712, 12.6065668846211, 11.662299747206992, 10.638179323475443, 9.612439318871694, 8.663403593764489, 7.705384720525759, 6.763328218368308, 5.763770827608645, 4.8463904234309005, 9.849672352214187, 10.751778661038227, 11.606222322217606, 12.555987670245786, 13.546453666289118, 14.3695761888552, 15.343484718584817, 15.747408958599973, 14.755015310831201, 13.721480454531877, 12.791629441314777, 11.842544119105673, 10.790752269862612, 9.722410271411034, 8.752208176093113, 7.807640497449028, 6.841977945250142, 5.826725586127482, 4.803051167959447, 3.7985563862631646, 10.803498239431791, 11.806670662137249, 12.618323614550583, 13.515778316331577, 14.51214093556456, 15.385284219818601, 15.835866851090007, 14.862509008926526, 13.829359538221453, 12.912565512271904, 11.848384427162703, 10.812323165941088, 9.81690056189454, 8.889699648840665, 7.832255728575254, 6.875750188303292, 5.867391525360626, 4.903129475743414, 3.921086231008836, 2.8624526773245473, 11.84966136882413, 12.825651615766532, 13.562640393746848, 14.44331250554141, 15.403552112087407, 15.952590306167105, 14.925438338928704, 13.878659302070908, 12.885800565245274, 11.94075127347233, 10.893112033944133, 9.853426485110909, 8.90825777053094, 7.993859620245957, 7.034762468658782, 5.995039909895201, 4.960753037479712, 3.933460310142535, 2.9497431745478044, 1.9172391480870332, 12.89347260874877, 13.775077253465467, 14.531966632006277, 15.445961072081738, 16.00566529442648, 15.020988450576628, 13.97666276914027, 13.017478537923054, 12.045084646542966, 11.064667210499518, 9.990594457514028, 8.946661494690156, 7.976903724538892, 7.045309616282003, 6.072706613104071, 5.007309096474241, 4.062098862560781, 3.00541552591757, 2.004228041376198, 0.9407895612763947, 13.845106379918288, 14.802232500170396, 15.60339600404017, 16.500953166217244, 16.741509402106555, 15.75769381404256, 14.79086512745863, 13.821723264105822, 12.805939898137948, 11.78198797230069, 10.839217204232899, 9.86022624330379, 8.911952036516327, 8.05525506084712, 7.0003995955097125, 5.966348768839694, 4.926245898620469, 3.917357857053855, 2.8563991289688113, 1.8698441398726058, 14.815058218459678, 15.85086041101671, 16.649661927389005, 17.52382926484129, 17.685159583782358, 16.611475284079383, 15.645632710533086, 14.676141460605194, 13.678316405057311, 12.64389988244144, 11.664900631315888, 10.73886890441556, 9.719086231259617, 8.77527052659159, 7.835485398730153, 6.835899932799852, 5.826205462223554, 4.846460763188032, 3.811594726431052, 2.9343772771705092, 15.742743852093854, 16.696112148926538, 17.70620790627401, 18.54294266273746, 18.634914262007374, 17.560619862402053, 16.60330525122226, 15.641401557029772, 14.69157169582745, 13.708005625924125, 12.701740961651357, 11.697409774473694, 10.766488515345934, 9.759506205801012, 8.807707553792788, 7.811099169970466, 6.797482306507937, 5.780537157320531, 4.829344822169326, 3.9960241403921968], [3.9895013117427793, 3.01074541799895, 4.048812460949736, 4.986683555840509, 6.056264361109028, 7.093160913429246, 8.047443800037177, 9.064512349112409, 9.97053166834539, 10.922940750367896, 11.966003698139827, 12.905722703233241, 13.835702388454287, 14.846163948096287, 15.78952016874652, 16.798843163779882, 17.850629497110244, 17.862932904105676, 17.265004959195956, 17.69562414575254, 2.9428844299628416, 2.0678750843206415, 3.0242103954565023, 4.014202366698225, 5.047540711088807, 6.119331769859198, 7.101669404589888, 8.096777007023405, 9.04207822936763, 10.002643557146754, 10.935073138187882, 11.867891272001142, 12.920629950839146, 13.967404757572133, 15.013933664035333, 16.026531939451534, 17.090924442072804, 18.057003282543494, 17.6014938822872, 16.636382269452753, 1.937102642746196, 1.0628013448330031, 2.054230824672107, 3.084721882261888, 4.1396568338003705, 5.121313959880163, 6.106530845151723, 7.081959336378077, 8.06618641944577, 9.064111910222298, 9.99848021967318, 11.05834670045467, 12.095470004901593, 13.145054565891682, 14.138171919160751, 15.152450661689635, 16.189431848078392, 17.177032537140093, 16.56282587433964, 15.688145855135827, 0.9690833351511113, 0.0, 1.0443054368049076, 2.1039047031853535, 3.1572730174409873, 4.150446149655725, 5.107337262595401, 6.136371638234171, 7.17466432482956, 8.132845384960511, 9.176602963422226, 10.22576128569855, 11.274577437977655, 12.321245397746214, 13.395432377688074, 14.321475373655417, 15.252160753202022, 16.243648817846633, 15.597333693117259, 14.647545082414712, 1.9005190170752184, 1.0109913248366678, 1.9466865891103995, 2.9752976078590048, 4.03445112131314, 5.090665258196557, 6.074274370975555, 7.003842629759671, 8.01450910710053, 9.067458492653671, 10.100036576741612, 11.157194121047484, 12.184591751292938, 13.215260663197862, 14.181324206148801, 15.163050226582987, 16.189656476957524, 15.388420395548993, 14.584190916163813, 13.6642522987683, 2.8848677709465953, 2.0144388869391436, 2.8864348808904867, 3.842328521202576, 4.864016149991266, 5.8889031830910845, 6.936435917930128, 7.91230805068266, 8.878895873451103, 9.821622822353527, 10.7840297369781, 11.718927770622747, 12.78750833042266, 13.800087934249792, 14.74918057319805, 15.712450648270474, 15.453006504062527, 14.452581735530806, 13.621355877667389, 12.6668097410909, 3.840040051888407, 3.073629625743531, 3.8816346272607176, 4.8313336745189, 5.808755680568344, 6.813973497966956, 7.739061449471655, 8.705920050337438, 9.700958300417902, 10.74800582678797, 11.780240239321216, 12.71340700243784, 13.734114874463758, 14.679196305065288, 15.639431199949179, 15.52756905988956, 14.526615681466305, 13.527562930651122, 12.632364450871286, 11.678371122869715, 4.824594265907108, 4.030267611510638, 4.8320091704807675, 5.794444466510297, 6.759527672768598, 7.742826902790219, 8.67891750672621, 9.65500149591332, 10.668763866772895, 11.609908826212717, 12.61679532440979, 13.593569002740773, 14.564176654974098, 15.524032385218801, 15.525146497919916, 14.559741323824062, 13.563701630372954, 12.584545399808924, 11.641498834785938, 10.66030123818111, 5.8032449998087925, 5.0009468815016636, 5.762053348630281, 6.732703751425008, 7.770487939347066, 8.675425767537888, 9.690055605408599, 10.660300726464227, 11.647291666602497, 12.549931472390233, 13.505060038257836, 14.440550890296343, 15.374570512693767, 15.479416262497113, 14.499272234928542, 13.540060407701674, 12.586609525362771, 11.617313872151618, 10.682807467289495, 9.64898900354596, 6.872209697328982, 6.063991187097424, 6.775015631030973, 7.687785567178771, 8.736468664132301, 9.721883096648687, 10.662162640846544, 11.664777818406806, 12.630588520987041, 13.572654224527092, 14.438261654422485, 15.464750334291121, 15.383994245755485, 14.4078717693258, 13.525980950713928, 12.59431291881953, 11.603367456628542, 10.650433635396656, 9.641525117685333, 8.656343359759397, 7.816346695689031, 7.076562056756307, 7.847810139020938, 8.660458473392065, 9.671759210017282, 10.605895159195217, 11.576779200523546, 12.544644953597507, 13.541153728970245, 14.560721351589203, 15.46116741459327, 15.372729913260024, 14.387537751584272, 13.421773458600285, 12.504158796213328, 11.617564592952785, 10.677003387692482, 9.72763355885315, 8.770650301091509, 7.7290839210323, 8.772397464869659, 8.150427246667135, 8.775526642178429, 9.708621323901493, 10.639506975229521, 11.533393611600456, 12.57280433249967, 13.517719510663921, 14.483528982960978, 15.504761257708957, 15.46334544443775, 14.49799766157705, 13.522862694295469, 12.449885976937606, 11.50826047600342, 10.623845245982777, 9.691930727726469, 8.719025525978536, 7.69629827749463, 6.769770698983259, 9.766553692334938, 9.076587443425273, 9.762954214040077, 10.689863773525717, 11.632651758596541, 12.54044213148492, 13.514636444451348, 14.474185038972086, 15.430576564956045, 15.463666436631216, 14.511120349627822, 13.57565021977221, 12.631383082358102, 11.607262658626553, 10.581522654022804, 9.632486928915599, 8.674468055676869, 7.732411553519419, 6.732854162759756, 5.815473758582012, 10.818755687365298, 10.133246800768633, 10.715524942980377, 11.665290291008555, 12.655756287051888, 13.478878809617973, 14.452787339347589, 15.464111342353423, 15.724098645982313, 14.690563789682988, 13.760712776465889, 12.811627454256785, 11.759835605013723, 10.691493606562146, 9.721291511244225, 8.776723832600139, 7.811061280401253, 6.795808921278593, 5.772134503110558, 4.767639721414276, 11.772581574582903, 11.188138801867655, 11.727626235313354, 12.625080937094346, 13.621443556327328, 14.494586840581373, 15.422177920315535, 15.831592344077634, 14.798442873372561, 13.881648847423016, 12.817467762313814, 11.7814065010922, 10.785983897045654, 9.858782983991778, 8.801339063726367, 7.844833523454404, 6.836474860511737, 5.872212810894526, 4.890169566159947, 3.8315360124756586, 12.818744703975241, 12.24328437192007, 12.671943014509619, 13.552615126304179, 14.512854732850176, 15.54262913304828, 15.894521674079812, 14.847742637222016, 13.854883900396382, 12.909834608623438, 11.862195369095241, 10.822509820262017, 9.87734110568205, 8.962942955397068, 8.003845803809893, 6.964123245046313, 5.929836372630824, 4.902543645293647, 3.918826509698915, 2.8863224832381444, 13.862555943899881, 13.192710009619006, 13.641269252769048, 14.555263692844507, 15.55139011515132, 15.99007178572774, 14.945746104291382, 13.986561873074166, 13.014167981694078, 12.03375054565063, 10.95967779266514, 9.915744829841268, 8.945987059690003, 8.014392951433114, 7.0417899482551825, 5.976392431625353, 5.0311821977118925, 3.9744988610686818, 2.9733113765273096, 1.909872896427506, 14.8141897150694, 14.219865256323935, 14.71269862480294, 15.610255786980014, 16.592951449484328, 16.72677714919367, 15.759948462609742, 14.790806599256932, 13.775023233289058, 12.7510713074518, 11.808300539384009, 10.8293095784549, 9.881035371667437, 9.02433839599823, 7.969482930660822, 6.935432103990805, 5.89532923377158, 4.886441192204966, 3.8254824641199225, 2.8389274750237172, 15.78414155361079, 15.268493167170249, 15.758964548151777, 16.633131885604058, 17.57793969534302, 17.580558619230494, 16.614716045684197, 15.645224795756306, 14.647399740208423, 13.612983217592552, 12.633983966467, 11.707952239566671, 10.688169566410728, 9.744353861742702, 8.804568733881265, 7.804983267950964, 6.795288797374666, 5.815544098339144, 4.780678061582163, 3.9034606123216204, 16.711827187244964, 16.238214434410743, 16.81983663195285, 17.65224528350023, 17.756607975097204, 16.730769230605716, 15.78691012907925, 14.834308686461554, 13.856706224289987, 12.911464441482241, 11.905199777209473, 10.900868590031811, 9.96994733090405, 8.943681167318156, 7.991882515309932, 6.9883331072122346, 5.974716243749706, 4.974690672279063, 4.023498337127858, 4.964876192083104], [4.940271531653046, 3.9615156379092165, 3.1164069653166284, 4.0387144730198585, 5.088264951616449, 6.048855476624339, 7.003138363232271, 8.020206912307502, 8.926226231540484, 9.87863531356299, 10.921698261334921, 11.861417266428335, 12.79139695164938, 13.80185851129138, 14.745214731941614, 15.754537726974975, 16.80632406030534, 16.947935626124213, 17.749534250924604, 18.524921193320203, 3.9650813577868664, 3.0186453042309074, 2.0762413126358528, 3.0662332838775748, 4.065139652215754, 5.07502633305429, 6.05736396778498, 7.052471570218498, 7.997772792562724, 8.958338120341848, 9.890767701382975, 10.823585835196235, 11.87632451403424, 12.923099320767227, 13.969628227230427, 14.982226502646629, 16.0466190052679, 17.01269784573859, 18.036432305792484, 17.569164462383867, 2.9592995705702205, 2.0135715647432693, 1.0099253878671997, 2.0404164454569806, 3.095351396995463, 4.077008523075255, 5.062225408346816, 6.0376538995731694, 7.021880982640862, 8.01980647341739, 8.954174782868272, 10.014041263649762, 11.051164568096684, 12.100749129086774, 13.093866482355843, 14.108145224884726, 15.145126411273484, 16.132727100335185, 17.092207720154693, 16.669780975581183, 2.013388771956019, 1.0443054368049076, 0.0, 1.0595992663804457, 2.1129675806360795, 3.1061407128508174, 4.063031825790493, 5.0920662014292635, 6.130358888024652, 7.088539948155605, 8.132297526617318, 9.181455848893641, 10.230272001172747, 11.276939960941306, 12.351126940883166, 13.277169936850509, 14.207855316397113, 15.199343381041725, 16.12671553893231, 15.652659246203505, 2.9376375975524547, 1.9673845754026653, 1.0316893111289336, 2.0071346952206746, 3.066288208674809, 4.122502345558226, 5.029968934170648, 5.959537192954763, 6.970203670295621, 8.023153055848763, 9.055731139936704, 10.112888684242575, 11.14028631448803, 12.170955226392953, 13.137018769343893, 14.118744789778079, 15.145351040152617, 16.092217080408062, 15.589305079952606, 14.669366462557093, 3.9219863514238313, 2.9534619052615887, 1.9714376029090208, 2.92733124322111, 3.9490188720098, 4.973905905109618, 5.982882343263659, 6.958754476016192, 7.925342298784636, 8.868069247687059, 9.830476162311632, 10.765374195956278, 11.833954755756192, 12.846534359583323, 13.795626998531581, 14.758897073604006, 15.762781581858114, 15.480274741891863, 14.626470041456182, 13.671923904879693, 4.877158632365643, 3.9664023400563675, 2.9666373492792517, 3.9163363965374343, 4.893758402586878, 5.8989762199854905, 6.824064171490189, 7.790922772355972, 8.785961022436435, 9.794452252121502, 10.826686664654748, 11.759853427771372, 12.78056129979729, 13.72564273039882, 14.68587762528271, 15.651092168384759, 15.563734261943543, 14.555255937012179, 13.637478614660079, 12.683485286658508, 5.861712846384344, 4.899878694546313, 3.9170118924993016, 4.8794471885288315, 5.844530394787132, 6.827829624808753, 7.763920228744745, 8.740004217931855, 9.75376658879143, 10.694911548231252, 11.701798046428324, 12.678571724759308, 13.649179376992633, 14.609035107237336, 15.570049067482255, 15.596859904301299, 14.600820210850191, 13.61223840616998, 12.668130712090054, 11.665415401969904, 6.840363580286028, 5.825079996065689, 4.847056070648815, 5.817706473443542, 6.8554906613656, 7.760428489556421, 8.775058327427134, 9.745303448482762, 10.732294388621032, 11.634934194408768, 12.590062760276371, 13.525553612314878, 14.459573234712302, 15.436804095771619, 15.53639081540578, 14.577178988178911, 13.623728105840009, 12.654432452628853, 11.70943934459361, 10.675620880850076, 7.823448742679837, 6.87426549862929, 5.860018353049506, 6.772788289197306, 7.8214713861508365, 8.806885818667222, 9.74716536286508, 10.749780540425341, 11.715591243005576, 12.657656946545627, 13.52326437644102, 14.549753056309656, 15.462539114364027, 15.452177206130708, 14.570286387518836, 13.638618355624434, 12.640486037105777, 11.687552215873891, 10.678643698162569, 9.693461940236633, 8.767585741039886, 7.886836368288173, 6.932812861039471, 7.7454611954106, 8.756761932035817, 9.690897881213752, 10.661781922542081, 11.629647675616042, 12.62615645098878, 13.645724073607738, 14.546170136611805, 15.494646188360353, 15.43184318838918, 14.466078895405193, 13.548464233018237, 12.661870029757692, 11.721308824497388, 10.771938995658056, 9.807768881568743, 8.766202501509536, 9.723636510220514, 8.848387847214171, 7.860529364196963, 8.79362404592003, 9.724509697248056, 10.61839633361899, 11.657807054518205, 12.602722232682456, 13.568531704979513, 14.589763979727492, 15.492120209065666, 15.542303098381959, 14.567168131100377, 13.494191413742515, 12.552565912808328, 11.668150682787683, 10.736236164531375, 9.763330962783442, 8.733416857971864, 7.806889279460495, 10.717792737685793, 9.77454804397231, 8.84795693605861, 9.774866495544254, 10.717654480615076, 11.625444853503453, 12.599639166469881, 13.55918776099062, 14.515579286974578, 15.476488568420754, 15.55542578643273, 14.619955656577119, 13.67568851916301, 12.651568095431461, 11.625828090827712, 10.676792365720507, 9.718773492481777, 8.776716990324326, 7.777159599564663, 6.85977919538692, 11.769994732716153, 10.746698254614769, 9.80052766499891, 10.750293013027092, 11.740759009070423, 12.563881531636506, 13.537790061366122, 14.549114064371956, 15.472692476150982, 15.734869226487897, 14.805018213270797, 13.85593289106169, 12.804141041818628, 11.73579904336705, 10.76559694804913, 9.821029269405045, 8.85536671720616, 7.8401143580835, 6.816439939915465, 5.811945158219183, 12.723820619933758, 11.80159025571379, 10.812628957331887, 11.710083659112883, 12.706446278345865, 13.579589562599907, 14.507180642334069, 15.480538484497549, 15.84274831017747, 14.925954284227924, 13.861773199118723, 12.825711937897108, 11.830289333850562, 10.903088420796687, 9.845644500531275, 8.889138960259313, 7.880780297316646, 6.916518247699434, 5.934475002964855, 4.875841449280566, 13.742002532349966, 12.766012285407564, 11.756945736528152, 12.637617848322716, 13.597857454868713, 14.627631855066817, 15.53366197319027, 15.892048074026924, 14.89918933720129, 13.954140045428346, 12.90650080590015, 11.866815257066925, 10.921646542486956, 10.007248392201976, 9.048151240614802, 8.008428681851221, 6.974141809435732, 5.946849082098554, 4.9631319465038235, 3.9306279200430523, 14.69137772446859, 13.677239301347655, 12.726271974787581, 13.640266414863044, 14.636392837169856, 15.559233710657294, 15.99005154109629, 15.030867309879074, 14.058473418498986, 13.078055982455538, 12.003983229470048, 10.960050266646174, 9.99029249649491, 9.058698388238021, 8.086095385060089, 7.0206978684302594, 6.0754876345168, 5.018804297873589, 4.017616813332217, 2.954178333232414, 15.643011495638108, 14.704394548052584, 13.797701346821473, 14.69525850899855, 15.677954171502867, 16.49860331232283, 16.701347490622915, 15.779388530207633, 14.76360516423976, 13.739653238402502, 12.807932289868708, 11.8289413289396, 10.880667122152136, 10.0163070384357, 9.01378836746573, 7.979737540795713, 6.939634670576488, 5.9307466290098745, 4.86978790092483, 3.883232911828625, 16.612963334179497, 15.753022458898897, 14.84396727017031, 15.718134607622597, 16.662942417361556, 16.635608372123478, 15.700277232963519, 14.755263346081225, 13.82565607825522, 12.813048885556947, 11.834049634431395, 10.908017907531066, 9.888235234375124, 8.944419529707098, 8.00463440184566, 7.036919461351241, 6.0477179189638, 5.107015074777854, 5.824983498387072, 4.947766049126528, 17.540648967813674, 16.72274372613939, 15.904839353971385, 16.737248005518765, 16.712302538292295, 15.686463793800808, 14.742604692274343, 13.790003249656648, 12.81240078748508, 11.897304136716128, 10.89103947244336, 9.909020491090965, 8.987071633453093, 7.984210898791249, 7.032412246783025, 6.040364024391584, 5.026747160929055, 4.055809024749203, 4.974268557038124, 5.915646411993371], [5.910393989688966, 4.931638095945138, 3.9699182185478294, 3.0149216690315295, 4.062467329366424, 5.016764955118319, 5.971047841726251, 6.988116390801483, 7.866626965160037, 8.819036047182543, 9.862098994954474, 10.801818000047888, 11.731797685268933, 12.742259244910933, 13.685615465561167, 14.694938460594528, 15.74672479392489, 16.675928966796263, 17.694397338584672, 18.65233728404278, 4.9460615966368415, 3.9887677622668285, 3.0324324511309673, 2.0424404798892453, 3.0393420299657286, 4.04293581154827, 4.9977647014045345, 5.992872303838052, 6.938173526182277, 7.898738853961401, 8.831168435002528, 9.763986568815788, 10.816725247653793, 11.86350005438678, 12.91002896084998, 13.922627236266182, 14.98701973888745, 15.953098579358139, 16.976833039412032, 17.977993210470085, 3.9944840634997565, 3.048756057672805, 2.0451098807967356, 1.0146188232069546, 2.0695537747454376, 3.0449180015692354, 4.00262614196637, 4.978054633192723, 5.962281716260417, 6.9602072070369445, 7.8945755164878255, 8.954441997269315, 9.991565301716237, 11.041149862706327, 12.034267215975396, 13.048545958504278, 14.085527144893039, 15.07312783395474, 16.032608453774248, 17.02975679615316, 3.0729880383364647, 2.1039047031853535, 1.0595992663804457, 0.0, 1.0533683142556338, 2.0465414464703713, 3.0034325594100473, 4.032466935048817, 5.070759621644206, 6.0289406817751585, 7.072698260236873, 8.121856582513196, 9.170672734792301, 10.21734069456086, 11.29152767450272, 12.217570670470064, 13.148256050016668, 14.13974411466128, 15.067116272551866, 16.045777054374057, 3.8820947340123553, 2.911841711862566, 1.9761464475888344, 0.9475354288402291, 2.006688942294364, 3.062903079177781, 3.9703696677902016, 4.899937926574317, 5.910604403915175, 6.963553789468317, 7.9961318735562585, 9.05328941786213, 10.080687048107585, 11.111355960012508, 12.077419502963448, 13.059145523397634, 14.085751773772172, 15.032617814027617, 16.06866601322187, 15.602617867410721, 4.866443487883732, 3.886713310115216, 2.904689007762648, 1.948795367450559, 2.946095133361417, 3.9709821664612353, 4.923283076883213, 5.899155209635746, 6.86574303240419, 7.8084699813066125, 8.770876895931185, 9.705774929575831, 10.774355489375745, 11.786935093202876, 12.736027732151134, 13.699297807223559, 14.703182315477669, 15.70360708400939, 15.55972144630981, 14.60517530973332, 5.821615768825543, 4.899653744909995, 3.899888754132879, 2.937800520766883, 3.8908346639384943, 4.896052481337107, 5.821140432841806, 6.787999033707589, 7.783037283788052, 8.734852985741055, 9.7670873982743, 10.700254161390925, 11.720962033416843, 12.666043464018372, 13.626278358902264, 14.591492902004312, 15.621133537654428, 15.488507341865807, 14.570730019513707, 13.616736691512136, 6.806169982844244, 5.83313009939994, 4.850263297352929, 3.9844385083412304, 4.841606656138748, 5.824905886160369, 6.760996490096361, 7.737080479283471, 8.750842850143046, 9.691987809582868, 10.69887430777994, 11.639588376581104, 12.610196028814428, 13.570051759059131, 14.53106571930405, 15.55932063806981, 15.54527734731009, 14.545489811023609, 13.601382116943682, 12.598666806823532, 7.784820716745928, 6.7583314009193165, 5.780307475502442, 4.969330207864436, 5.87593830371104, 6.757504750908038, 7.7721345887787505, 8.742379709834378, 9.729370649972648, 10.632010455760383, 11.587139021627987, 12.522629873666494, 13.456649496063918, 14.433880357123234, 15.462077955218431, 15.52163612463881, 14.568185242299908, 13.598889589088754, 12.642690749447238, 11.608872285703704, 8.756700147533465, 7.807516903482918, 6.7932697579031345, 5.924412023618199, 6.892838463590984, 7.804913473046572, 8.744241624216695, 9.746856801776957, 10.712667504357192, 11.654733207897243, 12.520340637792636, 13.546829317661272, 14.459615375715643, 15.435737852145328, 15.525121448286852, 14.59345341639245, 13.584943173565678, 12.632009352333792, 11.62310083462247, 10.637919076696534, 9.700837145893514, 8.8200877731418, 7.866064265893099, 6.897084929831493, 7.828129009475964, 8.7622649586539, 9.733148999982228, 10.701014753056189, 11.673522397760195, 12.642800334959354, 13.54324639796342, 14.491722449711968, 15.475378877815478, 15.420913956173209, 14.503299293786252, 13.616705090525707, 12.676143885265404, 11.726774056426072, 10.752226018028644, 9.710659637969437, 10.656887915074142, 9.781639252067798, 8.79378076905059, 7.945247780340922, 8.795876774688203, 9.689763411059138, 10.729174131958352, 11.674089310122604, 12.638389082311852, 13.59925832116919, 14.489196470417282, 15.45454425327798, 15.522003191868393, 14.44902647451053, 13.507400973576344, 12.622985743555699, 11.69107122529939, 10.718166023551458, 9.677873994431765, 8.751346415920395, 11.651044142539421, 10.707799448825936, 9.781208340912238, 8.926490229965145, 9.789021558055223, 10.6968119309436, 11.671006243910028, 12.630554838430767, 13.586946364414725, 14.547855645860901, 15.479754824009095, 15.574790717345135, 14.630523579931026, 13.606403156199477, 12.580663151595727, 11.631627426488523, 10.673608553249792, 9.731552051092342, 8.731994660332678, 7.814614256154935, 12.703246137569781, 11.679949659468397, 10.733779069852538, 9.901916747447983, 10.81212608651057, 11.635248609076653, 12.60915713880627, 13.620481141812103, 14.54405955359113, 15.523320395195096, 15.6316589297951, 14.690739839616498, 13.697595040773264, 12.690634104135066, 11.720432008817145, 10.77586433017306, 9.810201777974175, 8.794949418851516, 7.771275000683481, 6.766780218987199, 13.657072024787386, 12.734841660567419, 11.745880362185515, 10.861707393533774, 11.813906892496021, 12.650956640040054, 13.578547719774216, 14.551905561937696, 15.481441031120493, 15.752595000752226, 14.688413915643025, 13.65235265442141, 12.656930050374863, 11.8579234815647, 10.800479561299289, 9.843974021027327, 8.83561535808466, 7.871353308467448, 6.88931006373287, 5.830676510048582, 14.675253937203594, 13.699263690261192, 12.69019714138178, 11.789241582743607, 12.749481189289604, 13.70422325789155, 14.605029050630417, 15.535755268793315, 15.627860772810445, 14.6828114810375, 13.699833222028788, 12.660147673195564, 11.714978958615596, 10.906681193725861, 9.947584042138686, 8.948787297917978, 7.931624726110195, 6.985490336568514, 5.917967007271838, 4.8854629808110674, 15.624629129322217, 14.610490706201283, 13.65952337964121, 12.791890149283935, 13.788016571590747, 14.635825113482028, 15.553844760667863, 15.658542662707239, 14.68614877132715, 13.705731335283703, 12.731333194021865, 11.753382682774815, 10.78362491262355, 9.946396187939492, 8.97379318476156, 7.90839566813173, 6.9631854342182695, 6.078403564254034, 5.077216079712662, 4.013777599612859, 16.576262900491738, 15.637645952906212, 14.730952751675101, 13.846882243419442, 14.829577905923758, 15.575194715147564, 15.641748224242466, 14.72347922525123, 13.707695859283357, 12.683743933446099, 11.774635791366768, 10.796850807433579, 9.848576600646116, 8.98421651692968, 8.033135988640183, 7.01422699477819, 6.004769391067801, 6.964234202283539, 5.919691459490068, 4.933136470393863, 17.546214739033125, 16.686273863752525, 15.777218675023938, 14.869758342043488, 15.814566151782449, 15.576009105743033, 14.640677966583072, 13.695664079700778, 12.766056811874773, 11.757139580600544, 10.778140329474992, 9.852108602574663, 8.856144712869103, 7.912329008201078, 6.97254388033964, 6.0112690960212545, 5.023925114975471, 5.960526328009056, 6.874163771358505, 5.93299336016527, 18.473900372667302, 17.65599513099302, 16.83809075882501, 15.888871739939658, 15.65270327191185, 14.626864527420363, 13.683005425893896, 12.7304039832762, 11.752801521104633, 10.837704870335681, 9.831440206062913, 8.849421224710518, 7.954981111947075, 6.952120377285228, 6.000321725277005, 5.014713659061598, 4.002954356940727, 4.909320277980404, 5.860512613131609, 6.885768870029291], [6.932653263693606, 5.953897369949776, 4.992177492552467, 4.037180943036168, 3.0544867089039967, 3.963396640862686, 4.917679527470618, 5.93474807654585, 6.8132586509044035, 7.76566773292691, 8.80873068069884, 9.748449685792254, 10.6784293710133, 11.6888909306553, 12.632247151305533, 13.641570146338895, 14.693356479669257, 15.622560652540628, 16.641029024329036, 17.598968969787144, 5.96832087064148, 5.011027036271467, 4.054691725135606, 3.0646997538938834, 2.0313614095033015, 2.989567497292637, 3.9443963871489007, 4.939503989582418, 5.884805211926643, 6.845370539705767, 7.777800120746894, 8.710618254560154, 9.763356933398159, 10.810131740131146, 11.856660646594346, 12.869258922010548, 13.933651424631817, 14.899730265102505, 15.923464725156398, 16.924624896214453, 5.04785237775539, 4.102124371928439, 3.0984781950523694, 2.0679871374625884, 1.0615731542830105, 1.991549687313602, 2.949257827710736, 3.9246863189370895, 4.908913402004783, 5.906838892781311, 6.841207202232192, 7.901073683013682, 8.938196987460604, 9.987781548450693, 10.980898901719762, 11.995177644248646, 13.032158830637407, 14.019759519699107, 14.979240139518618, 15.976388481897526, 4.126356352592099, 3.1572730174409873, 2.1129675806360795, 1.0533683142556338, 0.0, 0.9931731322147377, 1.950064245154414, 2.9790986207931844, 4.017391307388573, 4.975572367519526, 6.01932994598124, 7.068488268257562, 8.117304420536668, 9.163972380305227, 10.238159360247087, 11.164202356214432, 12.094887735761036, 13.086375800405648, 14.013747958296234, 14.992408740118425, 4.935463048267989, 3.9652100261182, 3.029514761844468, 2.000903743095863, 0.9608555297515997, 2.017069666635017, 2.917001353534568, 3.846569612318683, 4.8572360896595415, 5.910185475212683, 6.942763559300625, 7.999921103606496, 9.02731873385195, 10.057987645756873, 11.024051188707812, 12.005777209141998, 13.03238345951654, 13.979249499771985, 15.015297698966238, 15.946042018420103, 5.873707622635881, 4.859867292272, 3.877842989919432, 2.9219493496073428, 1.9002617208186527, 2.925148753918471, 3.8699147626275794, 4.845786895380112, 5.812374718148556, 6.755101667050979, 7.717508581675551, 8.652406615320198, 9.720987175120111, 10.733566778947242, 11.6826594178955, 12.645929492967925, 13.649814001222033, 14.650238769753754, 15.593677478573495, 15.481746800152672, 6.828879903577693, 5.808889313445549, 4.809124322668434, 3.8343985720693166, 2.84500125139573, 3.8502190687943427, 4.775307020299041, 5.742165621164824, 6.7372038712452875, 7.681484671485422, 8.713719084018667, 9.646885847135291, 10.667593719161209, 11.612675149762739, 12.57291004464663, 13.538124587748678, 14.567765223398794, 15.575257574633438, 15.447301509933059, 14.493308181931488, 7.7439043326776895, 6.709701589819293, 5.726834787772281, 4.7643994917427515, 3.795773243595984, 4.779072473617605, 5.715163077553597, 6.691247066740707, 7.705009437600283, 8.646154397040105, 9.653040895237178, 10.58622006232547, 11.556827714558795, 12.516683444803498, 13.477697405048417, 14.505952323814176, 15.530679274492146, 15.42206130144296, 14.477953607363034, 13.475238297242884, 8.707616316199577, 7.634902891338669, 6.656878965921795, 5.749291191265957, 4.830104891168276, 5.7116713383652735, 6.726301176235986, 7.696546297291614, 8.683537237429885, 9.58617704321762, 10.541305609085224, 11.476796461123731, 12.410816083521155, 13.388046944580472, 14.416244542675669, 15.03715103812187, 15.445221692776862, 14.475926039565708, 13.51926223986659, 12.485443776123056, 9.633271637952816, 8.68408839390227, 7.669841248322486, 6.70437300701972, 5.847005051048219, 6.759080060503807, 7.698408211673931, 8.701023389234193, 9.66683409181443, 10.60889979535448, 11.474507225249873, 12.50099590511851, 13.41378196317288, 14.389904439602565, 14.935593680131287, 14.080206806754529, 14.507738773019327, 13.55480495178744, 12.545896434076118, 11.560714676150182, 10.577408636312866, 9.696659263561152, 8.74263575631245, 7.677045913233014, 6.782295596933199, 7.716431546111135, 8.687315587439464, 9.655181340513424, 10.627688985217432, 11.596966922416591, 12.497412985420658, 13.445889037169206, 14.429545465272716, 14.831386188017644, 13.913771525630688, 13.103458480887786, 13.614285416112772, 12.66491558727344, 11.675021617482292, 10.633455237423085, 11.533459405493494, 10.65821074248715, 9.670352259469942, 8.725208763742444, 7.750043362145439, 8.643929998516374, 9.683340719415588, 10.62825589757984, 11.592555669769089, 12.553424908626427, 13.44336305787452, 14.408710840735218, 14.62528227626345, 13.859498706354966, 12.91787320542078, 12.109739133917778, 12.64520069885534, 11.672295497107408, 10.600669593885414, 9.674142015374043, 12.527615632958772, 11.584370939245288, 10.654327457463681, 9.706451213366668, 8.743188145512459, 9.650978518400837, 10.625172831367266, 11.584721425888004, 12.541112951871963, 13.502022233318138, 14.433921411466333, 14.579522390674233, 13.635255253260125, 12.973970948651706, 11.991135383440163, 11.042099658332958, 11.681066888758561, 10.73901038660111, 9.739452995841447, 8.817823823340161, 13.579817627989133, 12.55306877601984, 11.606898186403981, 10.681877730849505, 9.766292673967806, 10.58941519653389, 11.563323726263507, 12.57464772926934, 13.498226141048367, 14.477486982652334, 14.578290615539467, 13.637371525360866, 12.644226726517632, 11.944862865395605, 10.974660770077683, 10.038368887875565, 10.817660113482942, 9.802407754360283, 8.778733336192248, 7.774238554495966, 14.533643515206737, 13.607960777118862, 12.618999478736958, 11.641668376935296, 10.768073479953257, 11.605123227497291, 12.532714307231453, 13.506072149394933, 14.43560761857773, 14.699226686496594, 13.635045601387393, 12.598984340165778, 11.60356173611923, 11.020788677625065, 9.963344757359653, 9.0746124836981, 9.843151679918485, 8.878889630301273, 7.896846385566695, 6.838134845557349, 15.548373053755038, 14.572382806812636, 13.563316257933224, 12.56920256614513, 11.807719155061536, 12.658389845348788, 13.559195638087655, 14.489921856250552, 14.57449245855481, 13.629443166781865, 12.646464907773156, 11.606779358939932, 10.661610644359964, 9.98069493104028, 9.021597779453105, 8.037646047374217, 8.910903943393356, 8.038858650824148, 6.971335321527472, 5.938831295066701, 16.027318921600514, 15.468772431758705, 14.517805105198631, 13.571851132685458, 12.846254537362679, 13.589991700939265, 14.5080113481251, 14.605174348451603, 13.632780457071515, 12.652363021028068, 11.677964879766229, 10.700014368519183, 9.730256598367918, 8.996395247469358, 8.047806922075978, 6.997254417587969, 7.94246465150143, 7.131771878509669, 6.130584393968297, 5.067145913868494, 16.978952692770033, 16.49373324305256, 15.55444804883972, 14.626843226820965, 13.897351309720817, 14.529361302604801, 14.588379909986832, 13.670110910995595, 12.654327545027721, 11.630375619190463, 10.721267477111132, 9.743482493177947, 8.795208286390483, 7.930848202674047, 6.979767674384549, 6.006246374315763, 6.993827222227455, 7.986493476288176, 6.973059773745701, 5.9865047846494965, 17.880826024418823, 17.542361153898874, 16.600328461133206, 15.64971932544501, 14.957969293967448, 14.522640791487397, 13.587309652327438, 12.642295765445144, 11.712688497619139, 10.703771266344908, 9.724772015219356, 8.798740288319028, 7.802776398613471, 6.858960693945445, 5.919175566084007, 5.003288475558827, 6.012982946135125, 6.982785602013694, 7.896423045363144, 6.955252634169908, 18.481523051299572, 17.52815475446689, 16.518058997119418, 15.535941390148079, 14.599334957656216, 13.573496213164727, 12.629637111638262, 11.677035669020567, 10.699433206849, 9.784336556080047, 8.77807189180728, 7.796052910454884, 6.901612797691441, 5.898752063029596, 4.946953411021372, 4.006733038599171, 5.0203499020616995, 5.931579551985042, 6.882771887136247, 7.90802814403393], [7.851113790589251, 6.872357896845422, 5.910638019448113, 4.955641469931813, 3.9729472357996425, 2.970223508647948, 3.9245063952558796, 4.941574944331112, 5.820085518689666, 6.7724946007121725, 7.815557548484103, 8.755276553577517, 9.685256238798562, 10.695717798440562, 11.639074019090796, 12.648397014124157, 13.70018334745452, 14.62938752032589, 15.647855892114299, 16.605795837572405, 6.886781397537126, 5.929487563167113, 4.973152252031252, 3.983160280789529, 2.9498219363989473, 1.996394365077899, 2.951223254934163, 3.94633085736768, 4.891632079711906, 5.85219740749103, 6.784626988532157, 7.717445122345418, 8.770183801183423, 9.81695860791641, 10.86348751437961, 11.876085789795813, 12.940478292417081, 13.90655713288777, 14.930291592941662, 15.931451763999716, 6.01483387300994, 5.069105867182989, 4.06545969030692, 3.0349686327171392, 1.9800336811786565, 0.9983765550988642, 1.9560846954959983, 2.9315131867223516, 3.915740269790045, 4.913665760566572, 5.848034070017453, 6.907900550798944, 7.945023855245865, 8.994608416235955, 9.987725769505024, 11.002004512033906, 12.038985698422671, 13.026586387484372, 13.986067007303882, 14.98321534968279, 5.1195294848068365, 4.150446149655725, 3.106140712850817, 2.0465414464703713, 0.9931731322147377, 0.0, 0.9568911129396761, 1.9859254885784465, 3.024218175173835, 3.9823992353047872, 5.026156813766502, 6.075315136042825, 7.124131288321931, 8.170799248090491, 9.244986228032351, 10.171029223999696, 11.1017146035463, 12.093202668190912, 13.020574826081498, 13.999235607903689, 5.928636180482727, 4.958383158332937, 4.022687894059206, 2.9940768753106006, 1.9540286619663374, 1.0399749843836623, 1.9238282213198303, 2.8533964801039455, 3.864062957444804, 4.917012342997945, 5.949590427085887, 7.006747971391759, 8.034145601637213, 9.064814513542137, 10.030878056493076, 11.012604076927262, 12.039210327301804, 12.98607636755725, 14.022124566751502, 14.952868886205367, 6.8668807548506186, 5.853040424486737, 4.8710161221341695, 3.9151224818220802, 2.8934348530333907, 2.0290519607718758, 2.876741630412842, 3.8526137631653743, 4.819201585933818, 5.761928534836241, 6.724335449460813, 7.65923348310546, 8.727814042905374, 9.740393646732505, 10.689486285680763, 11.652756360753187, 12.656640869007298, 13.657065637539018, 14.60050434635876, 15.667327571943133, 7.822053035792431, 6.802062445660288, 5.802297454883172, 4.827571704284055, 3.8381743836104683, 2.9738811244907115, 3.8330100913491796, 4.799868692214963, 5.763752702520777, 6.688311539270685, 7.720545951803929, 8.653712714920553, 9.674420586946471, 10.619502017548001, 11.579736912431892, 12.54495145553394, 13.574592091184057, 14.582084442418703, 15.534429893048477, 15.486481314146227, 8.737077464892428, 7.702874722034031, 6.72000791998702, 5.75757262395749, 4.788946375810722, 4.037118184592024, 4.835536481176311, 5.811620470363421, 6.769259306281057, 7.673278907450402, 8.680165405647475, 9.593046930110733, 10.563654582344057, 11.52351031258876, 12.48452427283368, 13.512779191599439, 14.537506142277408, 15.5251019732609, 15.471126739577773, 14.468411429457623, 9.700789448414316, 8.628076023553408, 7.650052098136533, 6.742464323480696, 5.823278023383014, 4.9697170493396925, 5.8466745798587, 6.816919700914328, 7.803910641052598, 8.613301553627918, 9.568430119495522, 10.50392097153403, 11.437940593931453, 12.41517145499077, 13.443369053085966, 14.402580880312835, 15.356031762651737, 15.469099171780448, 14.51243537208133, 13.478616908337795, 10.626444770167556, 9.67726152611701, 8.663014380537225, 7.6975461392344595, 6.840178183262958, 6.017125771478225, 6.818781615296645, 7.821396792856906, 8.787207495437142, 9.641507341821843, 10.50163173566017, 11.528120415528807, 12.440906473583178, 13.417028950012863, 13.992023535414964, 14.932271488473308, 15.500911905234066, 14.54797808400218, 13.539069566290857, 12.553887808364921, 11.570581768527605, 10.689832395775891, 9.73580888852719, 8.670219045447753, 7.775468729147938, 7.018370335167242, 7.8832155000210715, 8.851081253095032, 9.748062388840145, 10.629574468883954, 11.524537495830955, 12.473013547579503, 13.456669975683013, 13.88781604330132, 12.970201380914364, 13.955523162606566, 14.60745854832751, 13.658088719488179, 12.668194749697031, 11.626628369637825, 12.526632537708233, 11.651383874701889, 10.663525391684681, 9.718381895957183, 8.743216494360178, 7.945868787572481, 8.879240631997195, 9.824155810161447, 10.712929073391802, 11.58603245509379, 12.470487568284817, 13.435835351145515, 13.632109144048712, 12.915928561638642, 11.974303060704456, 12.961803815636557, 13.63837383107008, 12.665468629322147, 11.593842726100153, 10.667315147588782, 13.520788765173512, 12.577544071460027, 11.64750058967842, 10.699624345581407, 9.736361277727198, 8.952917307456943, 9.879102474809121, 10.83865106932986, 11.770095933854615, 12.620651231830394, 13.46104592187663, 13.586349258459496, 12.642082121045387, 11.98079781643697, 11.04756523872384, 11.894164340051738, 12.674240020973297, 11.732183518815846, 10.732626128056182, 9.8109969555549, 14.572990760203872, 13.54624190823458, 12.60007131861872, 11.675050863064245, 10.759465806182545, 9.891353985589996, 10.817253369705362, 11.828577372711196, 12.727209123031018, 13.596115981164589, 13.585117483324728, 12.644198393146127, 11.651053594302894, 10.951689733180869, 9.981487637862948, 10.890433569594345, 11.81083324569768, 10.79558088657502, 9.771906468406986, 8.767411686710703, 15.526816647421477, 14.601133909333601, 13.612172610951697, 12.634841509150036, 11.761246612167996, 10.907062016553397, 11.786643950673309, 12.760001792836789, 13.66459060056038, 13.706053554281855, 12.641872469172654, 11.605811207951039, 10.610388603904493, 10.02761554541033, 8.970171625144918, 9.92667716541688, 10.836324812133222, 9.872062762516011, 8.890019517781433, 7.831307977772086, 15.978052452039549, 15.565555939027375, 14.556489390147963, 13.562375698359869, 12.800892287276275, 11.960328634404894, 12.813125281529508, 13.743851499692408, 13.581319326340072, 12.636270034567127, 11.65329177555842, 10.613606226725196, 9.668437512145227, 8.987521798825544, 8.028424647238369, 8.956106574269864, 9.829364470289, 9.032031783038885, 7.9645084537422095, 6.932004427281439, 15.034145789385777, 16.04828421250671, 15.51097823741337, 14.565024264900197, 13.839427669577418, 12.89193048999537, 13.761940991566954, 13.612001216236866, 12.639607324856778, 11.65918988881333, 10.684791747551492, 9.706841236304445, 8.73708346615318, 8.003222115254621, 7.054633789861241, 7.915714944483615, 8.860925178397075, 8.124945010724407, 7.123757526183034, 6.060319046083231, 15.985779560555295, 16.959366461153902, 16.54762118105446, 15.620016359035704, 14.815115679724903, 13.831300091660907, 13.595206777772095, 12.676937778780857, 11.661154412812984, 10.637202486975726, 9.728094344896395, 8.750309360963207, 7.802035154175745, 6.93767507045931, 5.9865945421698115, 6.924706901211409, 7.9122877491231005, 8.904954003183821, 7.940041269000252, 6.953486279904046, 16.887652892204084, 17.460106185696194, 16.498568904402795, 15.547959768714598, 14.603151958975637, 13.529467659272662, 12.5941365201127, 11.649122633230407, 10.719515365404401, 9.710598134130171, 8.731598883004619, 7.805567156104291, 6.809603266398733, 5.865787561730707, 4.92600243386927, 5.921749002454473, 6.931443473030771, 7.901246128909339, 8.81488357225879, 7.873713161065554, 17.488349919084836, 16.534981622252154, 15.524885864904682, 14.542768257933341, 13.606161825441479, 12.580323080949992, 11.636463979423525, 10.68386253680583, 9.706260074634262, 8.791163423865312, 7.784898759592543, 6.802879778240147, 5.9084396654767035, 4.905578930814858, 3.9537802788066347, 4.9251935654948165, 5.938810428957345, 6.850040078880688, 7.801232414031892, 8.826488670929576], [8.808004903528929, 7.829249009785099, 6.86752913238779, 5.91253258287149, 4.929838348739319, 3.927114621587624, 3.036798160521168, 4.018565088814844, 4.86319440574999, 5.8156034877724965, 6.858666435544427, 7.798385440637841, 8.728365125858886, 9.738826685500886, 10.68218290615112, 11.691505901184481, 12.743292234514843, 13.672496407386214, 14.690964779174623, 15.648904724632729, 7.843672510476803, 6.88637867610679, 5.9300433649709285, 4.940051393729206, 3.9067130493386237, 2.953285478017575, 1.9943321419944868, 2.989439744428004, 3.93474096677223, 4.895306294551354, 5.827735875592481, 6.760554009405742, 7.813292688243747, 8.860067494976734, 9.906596401439934, 10.919194676856137, 11.983587179477405, 12.949666019948094, 13.973400480001986, 14.97456065106004, 6.971724985949616, 6.025996980122665, 5.022350803246596, 3.9918597456568152, 2.9369247941183327, 1.9552676680385404, 0.9991935825563222, 1.9746220737826756, 2.958849156850369, 3.9567746476268963, 4.891142957077777, 5.951009437859268, 6.988132742306189, 8.03771730329628, 9.030834656565348, 10.04511339909423, 11.082094585482995, 12.069695274544696, 13.029175894364206, 14.026324236743115, 6.076420597746512, 5.107337262595401, 4.063031825790493, 3.0034325594100477, 1.950064245154414, 0.9568911129396761, 0.0, 1.0290343756387703, 2.067327062234159, 3.0255081223651112, 4.069265700826826, 5.118424023103149, 6.167240175382255, 7.213908135150815, 8.288095115092675, 9.21413811106002, 10.144823490606624, 11.136311555251236, 12.063683713141822, 13.042344494964013, 6.8855272934224026, 5.915274271272613, 4.979579006998882, 3.9509679882502766, 2.910919774906014, 1.9968660973233385, 0.9669371083801541, 1.8965053671642695, 2.907171844505128, 3.9601212300582693, 4.992699314146211, 6.049856858452083, 7.077254488697537, 8.10792340060246, 9.073986943553399, 10.055712963987585, 11.082319214362128, 12.029185254617573, 13.065233453811826, 13.995977773265691, 7.823771867790295, 6.809931537426414, 5.827907235073846, 4.872013594761757, 3.850325965973067, 2.9673832523122097, 1.919850517473166, 2.8957226502256983, 3.8623104729941424, 4.805037421896565, 5.767444336521137, 6.702342370165784, 7.770922929965699, 8.78350253379283, 9.732595172741089, 10.695865247813513, 11.699749756067622, 12.700174524599342, 13.643613233419083, 14.710436459003457, 8.778944148732107, 7.758953558599964, 6.759188567822848, 5.784462817223731, 4.795065496550144, 3.8012069299142026, 2.8761189784095036, 3.8429775792752863, 4.806861589581101, 5.731420426331009, 6.7636548388642534, 7.6968216019808775, 8.717529474006797, 9.662610904608327, 10.622845799492218, 11.588060342594266, 12.617700978244383, 13.625193329479027, 14.577538780108801, 15.531532108110373, 9.693968577832106, 8.659765834973708, 7.676899032926696, 6.714463736897166, 5.745837488750398, 4.814735972172627, 3.8786453682366346, 4.854729357423745, 5.812368193341381, 6.716387794510726, 7.723274292707799, 8.636155817171057, 9.606763469404381, 10.566619199649084, 11.527633159894004, 12.555888078659764, 13.580615029337734, 14.568210860321225, 15.512318554401151, 15.425302542397297, 10.65768056135399, 9.584967136493082, 8.606943211076208, 7.699355436420372, 6.759665864564738, 5.747334836920295, 4.889783466919024, 5.860028587974652, 6.847019528112922, 7.656410440688242, 8.611539006555844, 9.547029858594351, 10.481049480991775, 11.458280342051092, 12.486477940146289, 13.445689767373157, 14.39914064971206, 15.368436302923214, 15.469326485021003, 14.43550802127747, 11.58333588310723, 10.634152639056683, 9.6199054934769, 8.654437252174136, 7.776566024444682, 6.794743559058828, 5.861890502356969, 6.86450567991723, 7.830316382497466, 8.684616228882167, 9.544740622720493, 10.57122930258913, 11.4840153606435, 12.460137837073185, 13.453573697159552, 14.402633998740498, 15.452887244502675, 15.504869196941854, 14.495960679230532, 13.510778921304595, 12.527472881467279, 11.646723508715565, 10.692700001466864, 9.62711015838743, 8.711856570329662, 7.795988122747845, 6.9263243870813955, 7.894190140155355, 8.791171275900469, 9.672683355944278, 10.567646382891278, 11.516122434639826, 12.499778862743335, 13.304680641865719, 13.92709249385404, 14.91241427554624, 15.564349661267185, 14.614979832427853, 13.625085862636706, 12.583519482577499, 13.483523650647907, 12.608274987641563, 11.620416504624355, 10.675273008896859, 9.679604335541901, 8.723486575153084, 7.922349519057518, 8.86726469722177, 9.756037960452126, 10.629141342154114, 11.513596455345139, 12.478944238205838, 12.855337971696732, 12.33279316020304, 12.931194173644132, 13.918694928576231, 14.595264944009754, 13.622359742261821, 12.550733839039827, 11.624206260528457, 14.477679878113186, 13.534435184399701, 12.604391702618097, 11.656515458521083, 10.672749118908921, 9.730535095037546, 8.922211361869444, 9.881759956390182, 10.813204820914939, 11.663760118890718, 12.504154808936953, 12.809578086107516, 11.865310948693407, 11.368200749961535, 12.004456351663515, 12.851055452991412, 13.631131133912973, 12.689074631755522, 11.689517240995858, 10.767888068494578, 15.529881873143546, 14.503133021174255, 13.556962431558397, 12.63194197600392, 11.664192652319487, 10.668971773170599, 9.860362256765685, 10.871686259771518, 11.770318010091342, 12.639224868224913, 12.758073642767304, 11.867427220794148, 10.874282421950914, 10.339092666705433, 10.938378750802624, 11.847324682534019, 12.767724358637356, 11.752471999514697, 10.728797581346662, 9.72430279965038, 15.737496312745971, 15.558025022273277, 14.569063723891373, 13.591732622089712, 12.65053492829178, 11.684679804134, 10.829752837733631, 11.803110679897111, 12.707699487620705, 12.750283239961917, 11.81482862861523, 10.82904003559906, 9.833617431552513, 9.339042800485519, 9.927062738084592, 10.883568278356554, 11.793215925072898, 10.828953875455687, 9.846910630721109, 8.788199090711762, 15.021161339099873, 15.997151586042275, 15.513380503087639, 14.519266811299545, 13.690180603400059, 12.737946421985496, 11.856234168589832, 12.78696038675273, 12.624428213400396, 11.679378921627452, 10.767136306942747, 9.836835054373214, 8.891666339793247, 8.289889207162577, 8.985315760178043, 9.91299768720954, 10.786255583228678, 9.988922895978561, 8.921399566681886, 7.888895540221115, 14.0772546764461, 15.091393099567036, 16.04236042612711, 15.521915377839873, 14.654225121425824, 13.669548277575974, 12.805049878627278, 12.65511010329719, 11.682716211917102, 10.702298775873654, 9.727900634611816, 8.88653865514759, 7.960312293801199, 7.235279116737168, 8.011524902800916, 8.872606057423292, 9.817816291336753, 9.081836123664083, 8.08064863912271, 7.017210159022907, 15.02888844761562, 16.002475348214226, 16.46517401539104, 15.537569193372283, 14.554873530867967, 13.571057942803971, 12.638315664832419, 11.720046665841181, 10.704263299873308, 9.68031137403605, 8.771203231956719, 7.867325729610171, 7.025263981823765, 6.169732071941857, 6.9434856551094875, 7.881598014151086, 8.869178862062778, 9.861845116123499, 8.896932381939928, 7.910377392843722, 15.930761779264408, 16.503215072756518, 15.541677791463119, 14.591068655774922, 13.646260846035961, 12.572576546332986, 11.637245407173024, 10.692231520290731, 9.762624252464725, 8.753707021190495, 7.774707770064944, 6.848676043164615, 6.0328320940467535, 5.097844563213254, 5.882893546808946, 6.87864011539415, 7.888334585970448, 8.858137241849017, 9.771774685198467, 8.830604274005232, 16.531458806145164, 15.57809050931248, 14.567994751965006, 13.585877144993665, 12.649270712501803, 11.623431968010316, 10.679572866483849, 9.726971423866154, 8.749368961694586, 7.834272310925635, 6.828007646652867, 5.845988665300471, 4.9854298099604355, 4.09087182437941, 4.910671391746311, 5.882084678434493, 6.895701541897022, 7.8069311918203645, 8.75812352697157, 9.783379783869254], [9.837039279167696, 8.858283385423867, 7.896563508026559, 6.9415669585102595, 5.9588727243780895, 4.956148997226395, 4.061417764225479, 3.0923277100664484, 3.9369570270015943, 4.889366109024101, 5.932429056796032, 6.872148061889446, 7.802127747110492, 8.812589306752491, 9.755945527402725, 10.765268522436086, 11.817054855766449, 12.74625902863782, 13.764727400426228, 14.722667345884334, 8.872706886115571, 7.915413051745559, 6.959077740609698, 5.969085769367975, 4.935747424977394, 3.9823198536563456, 3.0189517456987978, 2.0632023656796084, 3.008503588023834, 3.969068915802958, 4.901498496844085, 5.834316630657346, 6.887055309495351, 7.9338301162283384, 8.980359022691538, 9.99295729810774, 11.024333834486905, 11.990412674957593, 13.014147135011486, 13.945526275421267, 8.000759361588386, 7.055031355761436, 6.051385178885367, 5.020894121295585, 3.965959169757103, 2.9843020436773107, 2.0238131862606332, 1.04838469503428, 2.0326117781019732, 2.974385409566371, 3.908753719017252, 4.9686201997987425, 6.005743504245664, 7.055328065235753, 8.048445418504821, 9.062724161033703, 10.053060209844222, 11.040660898905923, 12.000141518725433, 12.997289861104342, 7.1054549733852825, 6.136371638234171, 5.0920662014292635, 4.032466935048818, 2.9790986207931844, 1.9859254885784465, 1.0290343756387703, 0.0, 1.0382926865953885, 1.9964737467263407, 3.040231325188055, 4.089389647464378, 5.138205799743484, 6.184873759512044, 7.259060739453904, 8.185103735421247, 9.115789114967852, 10.107277179612463, 11.03464933750305, 12.01331011932524, 7.9145616690611735, 6.944308646911384, 6.008613382637653, 4.980002363889048, 3.939954150544784, 2.9496800518279995, 1.8787523382337348, 0.9491840794496195, 1.9598505567904776, 3.0109683567608294, 3.9697971542648656, 5.026954698570737, 6.054352328816191, 7.0850212407211135, 8.051084783672053, 9.032810804106239, 10.053284838723355, 11.0001508789788, 12.036199078173054, 12.966943397626919, 8.852806243429065, 7.838965913065183, 6.8569416107126155, 5.901047970400526, 4.879360341611837, 3.87919848216579, 2.8316657473267464, 1.980207363796183, 2.946795186564627, 3.8895221354670504, 4.851929050091623, 5.786827083736269, 6.855407643536184, 7.867987247363315, 8.817079886311573, 9.780349961383997, 10.784234469638108, 11.784659238169828, 12.72809794698957, 13.794921172573943, 9.721762247134, 8.682128039216215, 7.6823630484390995, 6.707637297839982, 5.718239977166395, 4.713022159767783, 3.787934208263084, 2.9787721159841087, 3.8913463031515856, 4.815905139901494, 5.848139552434739, 6.781306315551363, 7.8020141875772815, 8.747095618178811, 9.707330513062702, 10.67254505616475, 11.702185691814867, 12.709678043049513, 13.662023493679287, 14.616016821680859, 10.617143058448356, 9.582940315589958, 8.600073513542947, 7.637638217513417, 6.669011969366649, 5.726551202026207, 4.790460598090215, 4.0127259777022815, 4.896852906911866, 5.800872508081211, 6.807759006278284, 7.720640530741541, 8.691248182974865, 9.651103913219568, 10.612117873464488, 11.640372792230249, 12.665099742908218, 13.65269557389171, 14.596803267971637, 15.605555376099607, 11.580855041970242, 10.508141617109334, 9.53011769169246, 8.622529917036623, 7.6714810944183185, 6.659150066773876, 5.801598696772604, 5.063366537922027, 5.959289290209817, 6.740895154258727, 7.6960237201263295, 8.631514572164837, 9.565534194562261, 10.542765055621578, 11.570962653716775, 12.530174480943643, 13.483625363282545, 14.4529210164937, 15.409584816192819, 15.358682501893721, 12.506510363723482, 11.557327119672935, 10.543079974093152, 9.577611732790386, 8.688381254298262, 7.7065587889124085, 6.77370573221055, 6.067843629864606, 6.942586144594362, 7.769100942452652, 8.629225336290979, 9.655714016159616, 10.568500074213986, 11.544622550643671, 12.538058410730038, 13.487118712310984, 14.53737195807316, 15.419801253248663, 15.419135159846784, 14.433953401920848, 13.450647362083531, 12.569897989331817, 11.615874482083116, 10.55028463900368, 9.623671800183242, 8.707803352601426, 7.838139616934976, 7.111958309263763, 7.903441037997364, 8.757168069514764, 9.652131096461764, 10.600607148210312, 11.584263576313822, 12.530720861369186, 13.470093226560712, 14.463867038177728, 15.486517121192312, 15.538154313044105, 14.548260343252958, 13.50669396319375, 14.406698131264159, 13.531449468257815, 12.543590985240607, 11.596426125133497, 10.591419565395482, 9.635301805006664, 8.8341647489111, 8.085032866330177, 8.868307722549021, 9.7136260557246, 10.598081168915625, 11.563428951776324, 11.929100592948336, 12.828331325575514, 13.7699568265097, 14.813604989561115, 15.518439424626006, 14.545534222878073, 13.47390831965608, 12.547380741144709, 15.400854358729438, 14.457609665015953, 13.525544818854735, 12.577668574757721, 11.584564348762502, 10.642350324891126, 9.834026591723026, 9.154019648245786, 9.925474583011834, 10.748244832461204, 11.588639522507439, 11.88334070735912, 10.93907356994501, 11.863738915334007, 12.870910528256719, 13.753131376497306, 14.564874116619604, 13.622817614462154, 12.62326022370249, 11.691062549110828, 15.638081227574958, 15.424286137410894, 14.478115547795035, 13.553095092240559, 12.576007882173068, 11.580787003024179, 10.772177486619267, 10.19690407321023, 10.882587772188238, 11.723709581795399, 11.831836264018909, 10.941189842045752, 9.948045043202518, 10.834630832077906, 11.804832927395827, 12.749400606039913, 13.715063158238799, 12.781506375153466, 11.75783195698543, 10.753337175289149, 14.821981026316458, 15.882864437995126, 15.490216840128012, 14.51288573832635, 13.56235015814536, 12.59649503398758, 11.741568067587213, 11.13600290907941, 11.819969249717602, 11.82404586121352, 10.888591249866835, 9.902802656850664, 8.907380052804116, 9.834580965857992, 10.853809861771301, 11.810315402043264, 12.818674064985931, 11.857988251094456, 10.875945006359878, 9.817233466350531, 13.9921269634611, 14.968117210403502, 15.977183759282914, 15.440419927536183, 14.601995833253639, 13.649761651839077, 12.768049398443413, 12.119852615935029, 11.698190834652, 10.753141542879055, 9.840898928194353, 8.910597675624818, 7.96542896104485, 8.997139409315071, 9.912062883864753, 10.94203206284831, 11.81528995886745, 11.017957271617332, 9.950433942320657, 8.917929915859887, 13.048220300807328, 14.062358723928263, 15.013326050488336, 15.581180758617178, 14.568867009570962, 13.584190165721111, 12.650086126690486, 11.728872724548793, 10.756478833168705, 9.776061397125257, 8.80166325586342, 7.960301276399193, 7.034074915052804, 7.965669023309693, 8.938272026487626, 9.901640433062063, 10.846850666975524, 10.110870499302852, 9.10968301476148, 8.046244534661676, 13.999854071976847, 14.973440972575453, 15.538936636642642, 14.611331814623886, 13.62863615211957, 12.644820564055575, 11.712078286084024, 10.793809287092785, 9.778025921124911, 8.754073995287653, 7.844965853208324, 6.941088350861775, 6.0990266030753695, 7.084663877753233, 7.9725200307482575, 8.910632389789857, 9.89821323770155, 10.890879491762268, 9.925966757578697, 8.939411768482492, 14.901727403625635, 15.576977694008123, 14.615440412714722, 13.664831277026526, 12.720023467287565, 11.646339167584589, 10.71100802842463, 9.765994141542338, 8.83638687371633, 7.827469642442099, 6.848470391316548, 5.9224386644162195, 5.106594715298358, 6.050410419966384, 6.911927922447716, 7.90767449103292, 8.917368961609219, 9.887171617487786, 10.800809060837235, 9.859638649644, 15.605221427396769, 14.651853130564085, 13.641757373216612, 12.65963976624527, 11.723033333753408, 10.697194589261919, 9.753335487735454, 8.80073404511776, 7.823131582946191, 6.908034932177239, 5.901770267904471, 4.919751286552075, 4.05919243121204, 5.0854585947979345, 5.939705767385081, 6.911119054073263, 7.924735917535792, 8.835965567459134, 9.787157902610339, 10.812414159508021], [10.875331965763085, 9.896576072019256, 8.934856194621949, 7.979859645105648, 6.997165410973477, 5.942274254055886, 4.987991367447954, 3.9709228183727223, 2.9618875898719916, 3.9142966718944976, 4.95568745830973, 5.8569780940023115, 6.786957779223358, 7.797419338865358, 8.74077555951559, 9.750098554548952, 10.801884887879314, 11.731089060750685, 12.749557432539094, 13.7074973779972, 9.91099957271096, 8.953705738340947, 7.9973704272050865, 7.007378455963364, 5.974040111572782, 5.018753098159679, 4.006319661917889, 2.9787353732384574, 2.0334341508942315, 2.953898947915825, 3.8863285289569522, 4.819146662770213, 5.871885341608218, 6.918660148341205, 7.965189054804405, 8.963830062873495, 9.986041147891518, 10.952119988362206, 11.975854448416099, 12.90723358882588, 9.039052048183775, 8.093324042356825, 7.0896778654807555, 6.059186807890974, 5.004251856352491, 4.022594730272699, 3.0111811024797244, 2.035752611253371, 1.051525528185678, 1.9360927229709826, 2.8704610324218636, 3.9303275132033537, 4.967450817650275, 6.017035378640364, 7.010152731909432, 8.024431474438316, 9.014767523248835, 10.002368212310536, 10.961848832130046, 11.958997174508955, 8.14374765998067, 7.17466432482956, 6.130358888024652, 5.070759621644206, 4.017391307388572, 3.024218175173835, 2.067327062234159, 1.0382926865953885, 0.0, 0.9581810601309523, 2.0019386385926667, 3.0510969608689895, 4.099913113148095, 5.146581072916655, 6.220768052858515, 7.146811048825859, 8.077496428372465, 9.068984493017076, 9.996356650907662, 10.975017432729853, 8.952854355656562, 7.982601333506772, 7.0469060692330405, 6.0182950504844355, 4.978246837140172, 3.9879727384233883, 2.917045024829123, 1.987476766045008, 1.00936269554231, 1.972675670165441, 2.9315044676694773, 3.988662011975349, 5.016059642220803, 6.046728554125726, 7.012792097076665, 7.99451811751085, 9.014992152127968, 9.961858192383414, 10.997906391577667, 11.928650711031532, 9.891098930024453, 8.877258599660571, 7.895234297308003, 6.939340656995914, 5.917653028207225, 4.917491168761178, 3.8699584339221347, 3.017113395314488, 2.050525572546044, 2.910454888797906, 3.872861803422478, 4.807759837067125, 5.87634039686704, 6.888920000694171, 7.838012639642429, 8.801282714714853, 9.805167222968961, 10.805591991500682, 11.749030700320423, 12.815853925904797, 10.76005493372939, 9.720420725811604, 8.720655735034487, 7.74592998443537, 6.756532663761783, 5.7513148463631705, 4.826226894858472, 3.9901149392134654, 2.9950766891330023, 3.836837893232349, 4.869072305765594, 5.802239068882218, 6.822946940908137, 7.768028371509667, 8.728263266393558, 9.693477809495606, 10.723118445145722, 11.730610796380367, 12.682956247010141, 13.636949575011712, 11.655435745043743, 10.621233002185345, 9.638366200138334, 8.675930904108805, 7.707304655962037, 6.764843888621595, 5.828753284685603, 5.0143456637528585, 4.000583292893283, 4.821805261412067, 5.828691759609139, 6.7415732840723965, 7.712180936305721, 8.672036666550424, 9.633050626795344, 10.661305545561104, 11.686032496239074, 12.673628327222564, 13.617736021302491, 14.626488129430461, 12.619147728565629, 11.546434303704721, 10.568410378287847, 9.66082260363201, 8.709773781013705, 7.6974427533692635, 6.839891383367992, 6.050010616329504, 5.063019676191234, 5.761827907589582, 6.716956473457185, 7.652447325495693, 8.586466947893117, 9.563697808952433, 10.59189540704763, 11.551107234274498, 12.504558116613401, 13.473853769824554, 14.430517569523673, 15.464336033267207, 13.544803050318869, 12.595619806268322, 11.581372660688539, 10.615904419385773, 9.72667394089365, 8.744851475507797, 7.8119984188059375, 7.054487708272083, 6.046316530575779, 6.7900336957835075, 7.650158089621835, 8.676646769490471, 9.589432827544842, 10.565555303974527, 11.558991164060894, 12.508051465641842, 13.558304711404018, 14.440734006579516, 15.449642524290839, 15.472246088516235, 14.488940048678918, 13.608190675927204, 12.654167168678503, 11.588577325599067, 10.66196448677863, 9.746096039196814, 8.876432303530365, 8.00368019935152, 7.0071714239787815, 7.778100822845619, 8.67306384979262, 9.621539901541167, 10.605196329644677, 11.551653614700042, 12.491025979891567, 13.484799791508586, 14.50744987452317, 15.451660797739253, 15.586553029848345, 14.544986649789138, 15.444990817859546, 14.569742154853202, 13.581883671835994, 12.634718811728884, 11.629712251990869, 10.673594491602053, 9.872457435506488, 8.937847580827494, 7.9720381085304375, 8.734558809055455, 9.61901392224648, 10.58436170510718, 11.55949667238876, 12.52354109636272, 13.465166597296907, 14.478519138478594, 15.410433656734902, 15.58382690947346, 14.512201006251466, 13.585673427740096, 15.574110793714572, 15.49590235161134, 14.563837505450122, 13.615961261353108, 12.622857035357889, 11.680643011486517, 10.872319278318415, 9.985596494977209, 9.02920496899325, 9.76917758579206, 10.609572275838294, 11.066567940387248, 11.754340087389277, 12.679005432778274, 13.686177045700985, 14.56839789394157, 15.483203414420451, 14.66111030105754, 13.661552910297877, 12.729355235706215, 14.659013980905812, 15.720249828439881, 15.516408234390422, 14.591387778835946, 13.614300568768458, 12.61907968961957, 11.810470173214656, 10.978711805938426, 9.986318158169654, 10.744642335126255, 10.856766826889306, 10.105274996301954, 10.763311560646784, 11.649897349522172, 12.620099444840093, 13.564667123484178, 14.530329675683063, 13.819799061748855, 12.79612464358082, 11.791629861884537, 13.842913779647311, 14.90379719132598, 15.883207851883792, 15.551178424921737, 14.60064284474075, 13.63478772058297, 12.779860754182602, 11.917810641807606, 10.923699635699016, 10.848976424083919, 9.913521812737232, 9.066887811106868, 9.722646570248383, 10.649847483302258, 11.669076379215566, 12.625581919487528, 13.633940582430196, 12.896280937689845, 11.914237692955266, 10.85552615294592, 12.953834276865713, 13.929824523808115, 14.938891072687527, 15.490636060168555, 14.530396453622558, 13.500622053424456, 12.583731868840797, 11.715980134348031, 10.723121397522398, 9.778072105749454, 8.86582949106475, 8.03947807764209, 8.780695478489116, 9.812405926759338, 10.727329401309017, 11.767051960072598, 12.713807158930845, 12.05624995821272, 10.988726628916044, 9.956222602455274, 12.009927614211941, 13.024066037332876, 13.97503336389295, 14.566010790730045, 13.55369704168383, 12.569020197833979, 11.634916158803351, 10.753803287419192, 9.781409396039104, 8.800991959995656, 7.8265938187338175, 6.9852318392695905, 7.849341432497069, 8.780935540753958, 9.75353854393189, 10.800157633125458, 11.745367867038919, 11.14916318589824, 10.147975701356868, 9.084537221257065, 12.96156138538146, 13.935148285980066, 14.52376666875551, 13.596161846736754, 12.613466184232438, 11.629650596168442, 10.69690831819689, 9.818739849963183, 8.80295648399531, 7.779004558158052, 6.869896416078721, 5.966018913732173, 6.914293120519635, 7.899930395197498, 8.867198333466558, 9.809149589853252, 10.796730437764944, 11.79933873498262, 10.964259444174086, 9.97770445507788, 13.863434717030248, 14.56180772612099, 13.60027044482759, 12.649661309139393, 11.704853499400432, 10.631169199697457, 9.695838060537495, 8.750824173655204, 7.821216905829196, 6.852400205312497, 5.873400954186946, 4.947369227286617, 5.923005392636552, 6.866821097304578, 7.806606225166015, 8.806191691096316, 9.815886161672614, 10.795630860708137, 11.830496897465117, 10.897931336239388, 14.590051459509635, 13.63668316267695, 12.626587405329477, 11.644469798358136, 10.707863365866274, 9.682024621374786, 8.73816551984832, 7.785564077230625, 6.807961615059057, 5.932965495047636, 4.926700830774868, 3.944681849422473, 4.875603108550234, 5.901869272136128, 6.853667924144352, 7.857217332242049, 8.870834195704578, 9.874258254054523, 10.825450589205728, 11.85070684610341], [11.811681621998456, 10.832925728254628, 9.87120585085732, 8.91620930134102, 7.924617555306747, 6.865123318725652, 5.91084043211772, 4.893771883042487, 3.8847366545417565, 3.0347687398836505, 3.9975063981787775, 4.89879703387136, 5.8287767190924065, 6.839238278734406, 7.78259449938464, 8.791917494418001, 9.843703827748364, 10.772908000619735, 11.791376372408143, 12.74931631786625, 10.847349228946332, 9.890055394576319, 8.933720083440457, 7.943728112198736, 6.910389767808154, 5.943064723590559, 4.930631287348769, 3.9015844379082223, 2.9562832155639964, 1.9957178877848727, 2.928147468826, 3.860965602639261, 4.913704281477266, 5.960479088210253, 7.007007994673453, 8.005649002742542, 9.027860087760565, 9.993938928231254, 11.017673388285147, 11.949052528694928, 9.975401704419147, 9.029673698592196, 8.026027521716127, 6.995536464126347, 5.940601512587864, 4.958944386508072, 3.9354927279106042, 2.960064236684251, 1.9758371536165573, 0.9779116628400302, 1.9122799722909112, 2.9721464530724013, 4.009269757519323, 5.058854318509412, 6.05197167177848, 7.066250414307363, 8.056586463117883, 9.044187152179585, 10.003667771999094, 11.000816114378003, 9.101928720111625, 8.132845384960513, 7.088539948155605, 6.0289406817751585, 4.975572367519525, 3.9823992353047872, 3.0255081223651112, 1.9964737467263407, 0.9581810601309523, 0.0, 1.0437575784617144, 2.092915900738037, 3.141732053017143, 4.188400012785703, 5.262586992727563, 6.188629988694907, 7.119315368241512, 8.110803432886124, 9.03817559077671, 10.0168363725989, 9.911035415787515, 8.940782393637726, 8.005087129363993, 6.976476110615388, 5.936427897271124, 4.946153798554341, 3.8752260849600755, 2.9456578261759603, 1.9675437556732622, 1.0144946100344887, 1.9733234075385249, 3.0304809518443965, 4.057878582089851, 5.088547493994773, 6.054611036945713, 7.036337057379898, 8.056811091997016, 9.003677132252461, 10.039725331446714, 10.97046965090058, 10.849279990155404, 9.835439659791522, 8.853415357438955, 7.897521717126867, 6.875834088338177, 5.875672228892132, 4.8281394940530875, 3.861588600337821, 2.895000777569377, 1.9522738286669536, 2.914680743291526, 3.8495787769361725, 4.918159336736087, 5.930738940563218, 6.879831579511476, 7.843101654583901, 8.84698616283801, 9.847410931369732, 10.790849640189473, 11.857672865773846, 11.718235993860343, 10.678601785942558, 9.678836795165441, 8.704111044566323, 7.714713723892737, 6.709495906494124, 5.784407954989425, 4.834590144236799, 3.8395518941563354, 2.8786568331013966, 3.910891245634642, 4.844058008751266, 5.864765880777185, 6.809847311378714, 7.770082206262606, 8.735296749364654, 9.76493738501477, 10.772429736249416, 11.72477518687919, 12.678768514880762, 12.613616805174697, 11.5794140623163, 10.596547260269288, 9.634111964239759, 8.665485716092991, 7.723024948752548, 6.786934344816556, 5.818531531580511, 4.8047691607209355, 3.863624201281114, 4.870510699478187, 5.783392223941444, 6.753999876174769, 7.7138556064194725, 8.674869566664391, 9.703124485430152, 10.727851436108121, 11.715447267091614, 12.65955496117154, 13.66830706929951, 13.577328788696583, 12.504615363835676, 11.526591438418802, 10.619003663762964, 9.66795484114466, 8.655623813500217, 7.7539347277155946, 6.783689606659967, 5.796698666521697, 4.80364684745863, 5.758775413326233, 6.694266265364741, 7.628285887762164, 8.605516748821481, 9.633714346916678, 10.592926174143546, 11.546377056482449, 12.515672709693604, 13.472336509392722, 14.506154973136256, 14.502984110449823, 13.553800866399277, 12.539553720819493, 11.574085479516727, 10.684855001024603, 9.70303253563875, 8.726041763153539, 7.788166698602545, 6.773918339192606, 5.831852635652555, 6.691977029490882, 7.71846570935952, 8.63125176741389, 9.607374243843575, 10.600810103929941, 11.549870405510887, 12.600123651273064, 13.482552946448566, 14.491461464159888, 15.476643222085825, 15.447121108809872, 14.566371736058159, 13.612348228809457, 12.546758385730021, 11.604167751548571, 10.670031802370636, 9.699147761042306, 8.731282007968346, 7.734773232595608, 6.819919762714667, 7.714882789661667, 8.663358841410215, 9.647015269513725, 10.59347255456909, 11.532844919760615, 12.526618731377631, 13.549268814392216, 14.493479737608302, 15.48337370739945, 15.503167709920092, 15.458139343765819, 15.527923214984156, 14.540064731966948, 13.576922076498827, 12.57191551676081, 11.597530254775874, 10.679792006419856, 9.665449389444321, 8.699639917147264, 7.776377748924504, 8.660832862115528, 9.626180644976227, 10.601315612257808, 11.565360036231768, 12.506985537165955, 13.52033807834764, 14.452252596603948, 15.425157798351881, 15.47038206638242, 14.54385448787105, 14.615929733583622, 15.58624459994728, 15.506040770220064, 14.55816452612305, 13.548775660708106, 12.604578774660336, 11.672746898114774, 10.713198303594035, 9.756806777610077, 8.810996525661109, 9.651391215707342, 10.562259542079206, 11.506526679493314, 12.529952446473274, 13.43372335914657, 14.382759084253776, 15.340777957492506, 15.619291361188495, 14.61973397042883, 13.68753629583717, 13.700832920774861, 14.76206876830893, 15.70823935792479, 15.533059073325287, 14.538236331942278, 13.543015452793389, 12.610897793011015, 11.706313614555253, 10.71391996678648, 9.786461274995304, 10.078263883899801, 11.02812406097172, 11.686160625316548, 12.572746414191936, 13.542948509509857, 14.487516188153943, 15.45317874035283, 14.777980121879805, 13.75430570371177, 12.749810922015488, 12.88473271951636, 13.94561613119503, 14.92502679175284, 15.459989189247437, 14.561562735302783, 13.595707611145002, 12.652032139566046, 11.888041317246508, 10.869488097073658, 10.070473481094414, 9.135018869747727, 9.989736875776634, 10.645495634918147, 11.572696547972022, 12.59192544388533, 13.548430984157292, 14.55678964709996, 13.854461997820795, 12.872418753086217, 11.81370721307687, 11.99565321673476, 12.971643463677163, 13.980710012556575, 14.532455000037604, 13.572215393491607, 12.542440993293505, 11.625550808709846, 10.904191610390889, 9.925929124097479, 8.999569162759949, 8.087326548075245, 8.962327142311857, 9.70354454315888, 10.735254991429102, 11.650178465978781, 12.689901024742362, 13.636656223600609, 13.014431018343673, 11.946907689046999, 10.914403662586228, 11.051746554080989, 12.065884977201923, 13.016852303761997, 13.607829730599095, 12.595515981552879, 11.610839137703028, 10.6767350986724, 9.845609916888442, 8.894135296187816, 8.022489017006151, 7.048090875744313, 7.908080903939355, 8.772190497166834, 9.703784605423722, 10.676387608601654, 11.723006697795222, 12.668216931708683, 12.107344246029195, 11.106156761487822, 10.04271828138802, 12.003380325250507, 12.976967225849114, 13.56558560862456, 12.637980786605803, 11.655285124101487, 10.671469536037492, 9.73872725806594, 8.862411031795851, 7.86089348904799, 7.000501615168546, 6.091393473089216, 6.8888679784019375, 7.8371421851894, 8.822779459867263, 9.790047398136322, 10.731998654523016, 11.719579502434708, 12.722187799652383, 11.900609100409458, 10.914054111313252, 12.905253656899296, 13.60362666599004, 12.64208938469664, 11.691480249008443, 10.746672439269481, 9.672988139566506, 8.737657000406545, 7.792643113524252, 6.863035845698246, 6.073897262322991, 5.09489801119744, 5.870218291956382, 6.8458544573063165, 7.7896701619743425, 8.72945528983578, 9.72904075576608, 10.738735226342378, 11.7184799253779, 12.753345962134881, 11.83428099247476, 13.631870399378684, 12.678502102546, 11.668406345198527, 10.686288738227185, 9.749682305735323, 8.723843561243836, 7.779984459717369, 6.827383017099674, 5.849780554928105, 5.036766319082286, 4.047172898764021, 4.867530914092238, 5.7984521732199985, 6.824718336805893, 7.776516988814116, 8.780066396911813, 9.793683260374342, 10.810607910289894, 11.7618002454411, 12.787056502338782], [12.793607277767563, 11.814851384023735, 10.853131506626427, 9.898134957110127, 8.906543211075855, 7.847048974494759, 6.892766087886827, 5.875697538811594, 4.866662310310863, 4.016694395652757, 3.1214616613186017, 4.014543905026814, 4.944523590247861, 5.95498514988986, 6.898341370540094, 7.907664365573455, 8.959450698903817, 9.888654871775188, 10.907123243563596, 11.865063189021702, 11.829274884715439, 10.871981050345426, 9.915645739209564, 8.925653767967843, 7.89231542357726, 6.924990379359666, 5.912556943117876, 4.883510093677328, 3.938208871333103, 2.977643543553979, 2.0521027319658236, 2.9767124737947155, 4.029451152632721, 5.076225959365708, 6.116213356773821, 7.044807408821757, 7.98410250929885, 8.950181349769538, 9.973915809823431, 10.905294950233213, 10.957327360188254, 10.011599354361303, 9.007953177485234, 7.977462119895453, 6.92252716835697, 5.940870042277178, 4.917418383679711, 3.9419898924533574, 2.957762809385664, 1.9598373186091367, 1.0254690091582557, 2.0113048591516165, 3.0484281635985377, 4.098012724588627, 5.091130077857695, 6.105408820386578, 7.012828884656168, 8.00042957371787, 8.959910193537379, 9.957058535916287, 10.145686298573338, 9.176602963422226, 8.132297526617318, 7.072698260236873, 6.019329945981239, 5.026156813766502, 4.069265700826826, 3.0402313251880555, 2.0019386385926667, 1.0437575784617144, 0.0, 1.0491583222763228, 2.0979744745554285, 3.1446424343239885, 4.218829414265848, 5.144872410233192, 6.075557789779797, 7.06704585442441, 7.994418012314995, 8.973078794137185, 10.95479299424923, 9.98453997209944, 9.048844707825708, 8.020233689077102, 6.9801854757328385, 5.989911377016055, 4.91898366342179, 3.989415404637675, 3.011301334134977, 1.962143913164752, 0.9295658290768104, 1.9867233733826821, 3.014121003628136, 4.044789915533059, 5.010853458483998, 5.992579478918183, 7.0130535135353, 7.959919553790745, 8.995967752984997, 9.926712072438862, 11.821972874161867, 10.808132543797985, 9.826108241445416, 8.870214601133327, 7.8485269723446365, 6.823639939244819, 5.776107204405775, 4.800235071653242, 3.8336472488847986, 2.8909202999823753, 1.9285133853578031, 2.8634114190024498, 3.9319919788023645, 4.9445715826294965, 5.893664221577755, 6.856934296650179, 7.860818804904288, 8.861243573436008, 9.80468228225575, 10.871505507840123, 12.666203704213032, 11.626569496295247, 10.62680450551813, 9.652078754919012, 8.662681434245425, 7.657463616846811, 6.732375665342112, 5.773236615552221, 4.7781983654717575, 3.8173033044168183, 2.9908672527365185, 3.921986822760263, 4.878598522843462, 5.823679953444992, 6.783914848328883, 7.74912939143093, 8.778770027081046, 9.786262378315692, 10.738607828945467, 11.692601156947038, 13.561584515527382, 12.527381772668987, 11.544514970621975, 10.582079674592446, 9.613453426445679, 8.669352596019035, 7.733261992083044, 6.757178002895934, 5.743415632036358, 4.802270672596536, 4.058337996940931, 4.861321037950441, 5.831928690183766, 6.79178442042847, 7.710004258501022, 8.716957127496428, 9.741684078174398, 10.72927990915789, 11.673387603237817, 12.682139711365787, 14.52529649904927, 13.452583074188363, 12.474559148771489, 11.566971374115651, 10.614282488411147, 9.601951460766704, 8.692581199031016, 7.722336077975388, 6.735345137837118, 5.742293318774052, 5.037439688123177, 5.87420613809586, 6.793493984271911, 7.748721315440806, 8.735878521492397, 9.695090348719265, 10.648541231058168, 11.617836884269323, 12.574500683968441, 13.608319147711976, 15.45095182080251, 14.501768576751964, 13.48752143117218, 12.522053189869414, 11.631182648291091, 10.649360182905237, 9.664688234468962, 8.726813169917968, 7.712564810508027, 6.770499106967977, 5.970641304287827, 6.898405582090639, 7.796459863923637, 8.772582340353322, 9.730099764928987, 10.652034580086607, 11.702287825848783, 12.584717121024285, 13.593625638735608, 14.578807396661544, 15.516354287522166, 15.514339446410846, 14.560315939162145, 13.494726096082708, 12.542814222863994, 11.608678273686058, 10.637794232357729, 9.669928479283769, 8.67341970391103, 7.758566234030089, 6.993547064458612, 7.9058772341408385, 8.812223366023472, 9.758680651078837, 10.698053016270363, 11.62878290595335, 12.651432988967935, 13.595643912184022, 14.585537881975169, 15.50606683538864, 14.560303518341538, 15.52594849555972, 15.488032442319636, 14.515568547814249, 13.510561988076233, 12.536176726091297, 11.618438477735278, 10.604095860759744, 9.638286388462687, 8.715024220239926, 7.9394971369124745, 8.894688046873126, 9.809930497905917, 10.730568132741515, 11.672193633675702, 12.62250225292336, 13.554416771179667, 14.5273219729276, 15.598947876149595, 15.491822198223737, 13.629762375649898, 14.600077242013556, 15.627073850037345, 15.496810997438473, 14.487422132023529, 13.543225245975758, 12.611393369430196, 11.651844774909458, 10.6954532489255, 9.74964299697653, 8.930055490504287, 9.830766943976105, 10.775034081390213, 11.695160542983022, 12.598931455656318, 13.547967180763523, 14.505986054002253, 15.448042556159704, 15.567701680781516, 14.635504006189855, 12.714665562841137, 13.775901410375207, 14.722071999991066, 15.535526706488684, 14.679090412443689, 13.726992588659291, 12.737169591689447, 11.915010093527247, 10.922616445758475, 10.303744545307195, 9.942746094325262, 10.792059888061399, 11.766062608132707, 12.724268626239123, 13.66500905651721, 14.551697951220916, 15.458859792739641, 15.750673005886268, 14.726998587718233, 13.722503806021951, 11.898565361582637, 12.959448773261306, 13.881269213291123, 14.575736060402892, 13.677309606458238, 12.711454482300455, 11.767779010721501, 11.00378818840196, 9.985234968229111, 9.228995081374133, 10.116944525516832, 10.971662531545741, 11.627421290687254, 12.554622203741129, 13.573851099654437, 14.5303566399264, 15.538715302869067, 14.827154881827258, 13.84511163709268, 12.786400097083334, 10.951895638273044, 11.927885885215446, 12.936952434094858, 13.64820187119306, 12.687962264647062, 11.658187864448958, 10.741297679865301, 10.019938481546342, 9.041675995252932, 8.15809076303967, 9.06925220384435, 9.944252798080964, 10.685470198927987, 11.717180647198209, 12.632104121747888, 13.671826680511469, 14.618581879369714, 14.058188596805389, 12.990665267508714, 11.958161241047943, 10.007988975619273, 11.022127398740208, 11.973094725300282, 12.723576601754548, 11.711262852708332, 10.726586008858481, 9.792481969827856, 8.961356788043895, 8.00988216734327, 7.181010617285872, 8.030016531513418, 8.890006559708462, 9.754116152935941, 10.68571026119283, 11.658313264370761, 12.704932353564327, 13.650142587477788, 13.151101824490908, 12.149914339949536, 11.086475859849733, 10.959622746788792, 11.933209647387399, 12.681332479780012, 11.753727657761257, 10.77103199525694, 9.787216407192945, 8.854474129221394, 7.978157902951304, 6.976640360203443, 6.159023215448268, 7.073319128858321, 7.870793634171044, 8.819067840958507, 9.80470511563637, 10.771973053905427, 11.713924310292121, 12.701505158203814, 13.704113455421489, 12.882534756178565, 11.895979767082359, 11.86149607843758, 12.719373537145492, 11.75783625585209, 10.807227120163894, 9.862419310424933, 8.78873501072196, 7.853403871561999, 6.908389984679706, 5.978782716853699, 5.232418862602713, 6.076823666966546, 6.852143947725488, 7.8277801130754225, 8.771595817743448, 9.711380945604885, 10.710966411535185, 11.720660882111483, 12.700405581147006, 13.735271617903987, 12.816206648243867, 12.747617270534137, 11.794248973701453, 10.78415321635398, 9.802035609382639, 8.865429176890776, 7.839590432399289, 6.895731330872823, 5.943129888255128, 4.965527426083559, 4.16072158222211, 5.029098554533127, 5.849456569861344, 6.780377828989105, 7.806643992574999, 8.758442644583223, 9.76199205268092, 10.77560891614345, 11.792533566059001, 12.743725901210206, 13.768982158107889], [13.719739592522592, 12.740983698778763, 11.746278888679473, 10.791282339163173, 9.721701533894654, 8.662207297313559, 7.707924410705628, 6.6908558616303955, 5.681820633129664, 4.831852718471559, 3.9297312146844314, 2.965385582750492, 3.895365267971538, 4.905826827613537, 5.849183048263771, 6.858506043297131, 7.910292376627495, 8.839496549498866, 9.857964921287275, 10.815904866745381, 12.755407199470467, 11.798113365100454, 10.841778053964592, 9.851786082722871, 8.818447738332289, 7.745609498503395, 6.733176062261605, 5.69866841649613, 4.753367194151904, 3.792801866372781, 2.8603722853316538, 1.927554151518393, 2.980292830356398, 4.027067637089385, 5.067055034497498, 5.995649086545435, 6.934944187022528, 7.901023027493217, 8.92475748754711, 9.856136627956891, 11.953871368686782, 11.008143362859832, 10.004497185983762, 8.974006128393981, 7.919071176855498, 6.937414050775706, 5.913962392178239, 4.938533900951885, 3.9543068178841922, 2.956381327107665, 2.022013017656784, 0.9621465368752937, 1.9992698413222152, 3.0488544023123048, 4.041971755581373, 5.056250498110256, 5.963670562379845, 6.951271251441547, 7.9107518712610565, 8.907900213639966, 11.194844620849661, 10.22576128569855, 9.181455848893641, 8.121856582513196, 7.068488268257561, 6.075315136042824, 5.118424023103148, 4.089389647464378, 3.0510969608689895, 2.092915900738037, 1.0491583222763228, 0.0, 1.048816152279106, 2.0954841120476657, 3.1696710919895255, 4.095714087956869, 5.026399467503475, 6.017887532148087, 6.9452596900386725, 7.923920471860862, 12.003951316525553, 11.033698294375764, 10.098003030102031, 9.069392011353425, 8.029343798009162, 7.039069699292377, 5.968141985698113, 5.038573726913997, 4.060459656411299, 3.0113022354410752, 1.9787241513531333, 0.9528031142853521, 1.9802007445308059, 3.0108696564357285, 3.976933199386668, 4.958659219820853, 5.9638951912589775, 6.910761231514423, 7.946809430708676, 8.87755375016254, 12.81312507788921, 11.799284747525327, 10.81726044517276, 9.86136680486067, 8.83967917607198, 7.814792142972163, 6.767259408133119, 5.791387275380587, 4.824799452612143, 3.88207250370972, 2.919665589085148, 1.984767555440501, 2.9292005623289876, 3.941780166156119, 4.890872805104377, 5.854142880176801, 6.85802738843091, 7.846599891532608, 8.790038600352348, 9.856861825936722, 13.657355907940376, 12.61772170002259, 11.617956709245474, 10.643230958646356, 9.653833637972768, 8.648615820574156, 7.723527869069457, 6.7643888192795645, 5.769350569199101, 4.808455508144164, 3.9765097223149386, 3.0433429591983145, 3.875807106370085, 4.820888536971615, 5.781123431855506, 6.746337974957553, 7.77597861060767, 8.771618696412292, 9.723964147042066, 10.677957475043637, 14.552736719254728, 13.51853397639633, 12.535667174349319, 11.57323187831979, 10.604605630173022, 9.660504799746379, 8.724414195810388, 7.748330206623278, 6.734567835763702, 5.793422876323881, 4.959450852719478, 3.9826771743884932, 4.856010939850275, 5.815866670094979, 6.707212842027645, 7.7141657110230515, 8.738892661701021, 9.71463622725449, 10.658743921334416, 11.667496029462386, 15.516448702776614, 14.443735277915707, 13.465711352498833, 12.558123577842995, 11.605434692138491, 10.593103664494048, 9.683733402758362, 8.713488281702734, 7.726497341564463, 6.7334455225013965, 5.93105312657242, 4.995562274533912, 5.8175762339384205, 6.772803565107315, 7.73308710501902, 8.692298932245889, 9.645749814584791, 10.615045467795944, 11.571709267495063, 12.605527731238597, 15.457699869408836, 15.492920780479308, 14.478673634899524, 13.513205393596758, 12.622334852018435, 11.640512386632581, 10.655840438196307, 9.717965373645313, 8.703717014235373, 7.7616513106953215, 6.864254742737069, 6.019761718528691, 6.820542113590147, 7.796664590019833, 8.72730834845561, 9.649243163613232, 10.699496409375408, 11.581925704550907, 12.59083422226223, 13.576015980188165, 14.513562871048787, 15.550073190486415, 15.551468142889489, 14.485878299810052, 13.53396642659134, 12.599830477413404, 11.628946436085075, 10.661080683011114, 9.664571907638376, 8.749718437757434, 7.887160502907854, 7.02723337057889, 7.836305615689982, 8.782762900745347, 9.722135265936872, 10.625991489479976, 11.64864157249456, 12.592852495710643, 13.58274646550179, 14.503275418915262, 13.55751210186816, 14.511593756868294, 15.499452239885501, 15.506720751541595, 14.501714191803579, 13.527328929818642, 12.609590681462624, 11.59524806448709, 10.629438592190033, 9.70617642396727, 8.833110575361715, 8.016044183311177, 8.834012747572427, 9.754650382408025, 10.696275883342212, 11.619710836449984, 12.551625354706292, 13.524530556454225, 14.59615645967622, 15.462588640964304, 12.615118693746497, 13.585433560110156, 14.612430168133944, 15.461794901695198, 14.544553363323564, 13.600356477275794, 12.626162164309365, 11.786962838642518, 10.83057131265856, 10.740795200703873, 9.823668928953529, 8.952123080414156, 9.824039770575752, 10.719242792649531, 11.623013705322828, 12.572049430430033, 13.530068303668763, 14.472124805826214, 15.471682196585878, 15.6266562099172, 11.700021880937737, 12.761257728471806, 13.707428318087665, 14.48636838421236, 13.629932090167365, 12.677834266382968, 11.688011269413124, 10.865851771250927, 9.873458123482155, 10.906992979781482, 10.836359532774503, 9.91341602449945, 10.815068297318245, 11.748350875905633, 12.68909130618372, 13.575780200887426, 14.482942042406151, 15.457345478228211, 15.718150791445575, 14.713656009749293, 10.883921679679236, 11.93387313299154, 12.832110891014802, 13.52657773812657, 12.628151284181914, 11.662296160024132, 10.718620688445178, 9.954629866125638, 8.936076645952792, 9.960617135964668, 10.877041434765106, 10.951803209694535, 11.855733287716646, 12.748400742125547, 13.70040731890175, 14.53953660506489, 15.54674195481862, 15.8183070855546, 14.836263840820022, 13.777552300810676, 9.902737315996722, 10.878727562939124, 11.887794111818536, 12.599043548916736, 11.638803942370739, 10.609029542172635, 9.692139357588978, 8.970780159270019, 7.992517672976612, 8.889712817630205, 9.829349113092624, 10.759411120899765, 11.500628521746789, 12.53233897001701, 13.44726244456669, 14.48698500333027, 15.433740202188515, 15.107346919081712, 14.039823589785037, 13.007319563324266, 8.95883065334295, 9.972969076463885, 10.923936403023959, 11.674418279478225, 10.662104530432009, 9.677427686582158, 8.743323647551533, 7.912198465767572, 6.960723845066948, 7.912632671876407, 8.790113440761692, 9.705164882527264, 10.569274475754742, 11.50086858401163, 12.473471587189563, 13.520090676383129, 14.46530091029659, 14.200260146767231, 13.19907266222586, 12.135634182126056, 9.910464424512469, 10.884051325111075, 11.63217415750369, 10.704569335484933, 9.721873672980617, 8.738058084916622, 7.805315806945071, 6.928999580674982, 5.927482037927121, 6.890645270038803, 7.833416038106595, 8.685951956989845, 9.634226163777308, 10.619863438455171, 11.587131376724228, 12.529082633110923, 13.516663481022615, 14.51927177824029, 13.879078764677093, 12.892523775580887, 10.81233775616126, 11.670215214869168, 10.708677933575768, 9.75806879788757, 8.81326098814861, 7.739576688445636, 6.8042455492856755, 5.859231662403384, 4.9296243945773774, 5.964040917193248, 6.891981989785348, 7.6673022705442895, 8.642938435894223, 9.586754140562249, 10.526539268423686, 11.526124734353987, 12.535819204930284, 13.515563903965807, 14.550429940722788, 13.742338962998895, 11.698458948257814, 10.74509065142513, 9.734994894077657, 8.752877287106315, 7.816270854614453, 6.790432110122966, 5.8465730085965, 4.893971565978806, 3.916369103807237, 4.946015190149421, 5.8442568773519294, 6.664614892680145, 7.595536151807906, 8.6218023153938, 9.573600967402024, 10.577150375499722, 11.59076723896225, 12.607712388149658, 13.558904723300863, 14.62667539106575], [14.768555744801699, 13.78979985105787, 12.795095040958579, 11.840098491442278, 10.77051768617376, 9.711023449592664, 8.756740562984733, 7.739672013909502, 6.7306367854087705, 5.8806688707506645, 4.97646231862549, 3.932861654454514, 3.002881969233468, 4.010576415167218, 4.953932635817452, 5.963255630850813, 6.922827845571774, 7.852032018443145, 8.870500390231554, 9.82844033568966, 13.804223351749574, 12.84692951737956, 11.8905942062437, 10.900602235001978, 9.867263890611396, 8.794425650782502, 7.781992214540712, 6.747484568775237, 5.80218334643101, 4.841618018651887, 3.9091884376107595, 2.9763703037974985, 2.0085249036318475, 3.0133851091694455, 4.04662427029421, 4.975218322342147, 5.886128034743422, 6.852206875214111, 7.8759413352680046, 8.807320475677786, 13.002687520965889, 12.056959515138939, 11.05331333826287, 10.022822280673088, 8.967887329134605, 7.986230203054813, 6.962778544457346, 5.987350053230992, 5.003122970163298, 4.005197479386771, 3.07082916993589, 2.0109626891543995, 0.9792642587388258, 2.0284236381090164, 3.0215409913780844, 4.035819733906967, 4.914854410100739, 5.902455099162441, 6.86193571898195, 7.85908406136086, 12.243660773128767, 11.274577437977655, 10.230272001172747, 9.170672734792301, 8.117304420536668, 7.12413128832193, 6.167240175382254, 5.138205799743484, 4.099913113148095, 3.141732053017143, 2.0979744745554285, 1.048816152279106, 0.0, 1.0466679597685598, 2.1208549397104193, 3.0468979356777632, 3.9775833152243685, 4.969071379868981, 5.896443537759566, 6.875104319581756, 13.052767468804658, 12.08251444665487, 11.146819182381137, 10.11820816363253, 9.078159950288267, 8.087885851571484, 7.016958137977219, 6.087389879193103, 5.1092758086904055, 4.0601183877201805, 3.027540303632239, 2.0016192665644583, 1.0726201196088703, 2.0018252400723737, 2.967888783023313, 3.9496148034574983, 4.915079038979871, 5.8619450792353165, 6.897993278429569, 7.828737597883434, 13.861941230168318, 12.848100899804436, 11.866076597451867, 10.910182957139778, 9.888495328351087, 8.86360829525127, 7.816075560412226, 6.840203427659693, 5.873615604891249, 4.930888655988826, 3.968481741364254, 3.0335837077196075, 2.021619937407052, 2.9620524901488334, 3.8953256509909675, 4.858595726063392, 5.862480234317501, 6.797783739253502, 7.741222448073243, 8.808045673657617, 14.706172060219481, 13.666537852301696, 12.66677286152458, 11.692047110925461, 10.702649790251874, 9.697431972853261, 8.772344021348562, 7.813204971558671, 6.818166721478208, 5.85727166042327, 4.96730731496907, 4.034140551852446, 2.9682264814481494, 3.913307912049679, 4.87354280693357, 5.812921682627371, 6.842562318277487, 7.722802544133186, 8.67514799476296, 9.629141322764532, 15.601552871533833, 14.567350128675436, 13.584483326628424, 12.622048030598895, 11.653421782452128, 10.709320952025486, 9.773230348089495, 8.797146358902385, 7.783383988042809, 6.842239028602987, 5.895811645492648, 4.919037967161664, 3.9484303149283395, 4.9082860451730435, 5.799632217105709, 6.780749418692869, 7.8054763693708376, 8.665820074975384, 9.60992776905531, 10.61867987718328, 15.447120474975517, 15.492551430194812, 14.514527504777938, 13.6069397301221, 12.654250844417598, 11.641919816773155, 10.684922529576983, 9.714677408521355, 8.727686468383085, 7.734634649320019, 6.779506083452416, 5.844015231413908, 4.909995609016485, 5.8652229401853795, 6.825506480097085, 7.784718307323953, 8.738169189662855, 9.63305160263269, 10.568619136551755, 11.60243760029529, 14.454609738465528, 15.403792982516075, 15.527489787178629, 14.562021545875863, 13.671151004297542, 12.689328538911688, 11.657029565014929, 10.701466483723982, 9.637395852952922, 8.695330149412872, 7.712707699617066, 6.868214675408687, 5.912961488668211, 6.889083965097897, 7.819727723533674, 8.741662538691294, 9.79191578445347, 10.599931839387652, 11.608840357098975, 12.594022115024911, 13.51047274010548, 14.536642794500017, 15.378352590763887, 15.496757581542287, 14.467645265308889, 13.533509316130953, 12.562625274802624, 11.594759521728664, 10.598250746355925, 9.683397276474983, 8.735613459787851, 7.875686327458887, 6.928724990768046, 7.875182275823411, 8.814554641014936, 9.718410864558038, 10.741060947572622, 11.610858630547389, 12.600752600338536, 13.521281553752008, 12.554421970924851, 13.462777604589188, 14.450636087606396, 15.492732709576076, 14.642447734244264, 13.712154584713936, 12.730773594674972, 12.113116610136801, 11.563117430907582, 10.639855262684819, 9.681563532241713, 8.864497140191174, 7.926432122650491, 8.84706975748609, 9.788695258420276, 10.712130211528047, 11.644044729784355, 12.616949931532288, 13.675104623935415, 14.48059477580105, 11.566302541467392, 12.53661740783105, 13.563614015854839, 14.511490259951852, 13.649302950877244, 12.705106064829474, 11.730911751863045, 11.044129828221193, 11.79804738436258, 11.62466797283692, 10.672121885833526, 9.800576037294153, 8.916459145653816, 9.811662167727595, 10.715433080400892, 11.664468805508097, 12.622487678746827, 13.564544180904278, 14.564101571663942, 15.496299246255603, 10.651205728658631, 11.7124415761927, 12.65861216580856, 13.59111797176604, 12.734681677721046, 11.782583853936648, 10.792760856966805, 10.001245403256748, 10.840934195186176, 11.874469051485502, 11.684812489654501, 10.761868981379447, 9.907487672396309, 10.840770250983697, 11.781510681261784, 12.66819957596549, 13.575361417484213, 14.549764853306275, 15.52482123131314, 15.762472162028402, 9.835105527400131, 10.885056980712433, 11.783294738735695, 12.63132732568025, 11.732900871735595, 10.767045747577814, 9.823370275998858, 9.062146567387568, 9.903552717656812, 10.928093207668692, 11.844517506469128, 11.800256166574535, 10.94815266279471, 11.840820117203611, 12.792826693979816, 13.631955980142955, 14.639161329896682, 15.573607940042494, 15.885079993099131, 14.826368453089785, 8.853921163717615, 9.829911410660017, 10.838977959539429, 11.703793136470416, 10.74355352992442, 9.713779129726317, 8.796888945142658, 8.07829686053195, 8.959993744680633, 9.857188889334227, 10.796825184796646, 11.80822727317887, 11.890103754553977, 12.889973710526553, 13.734573671886364, 14.668922416466838, 15.653732962832763, 16.15616307136082, 15.088639742064142, 14.056135715603371, 7.910014501063844, 8.924152924184778, 9.875120250744851, 10.779167867031907, 9.766854117985691, 8.78217727413584, 7.848073235105214, 7.019715167029502, 7.92819991677097, 8.88010874358043, 9.757589512465714, 10.753981034806369, 11.618090628033848, 12.549684736290736, 13.522287739468668, 14.568906828662234, 15.514117062575695, 15.249076299046337, 14.247888814504964, 13.184450334405161, 8.861648272233364, 9.83523517283197, 10.736923745057371, 9.809318923038616, 8.8266232605343, 7.842807672470304, 6.910065394498752, 6.036516281936912, 6.894958109631143, 7.858121341742825, 8.800892109810617, 9.73476810926895, 10.683042316056413, 11.668679590734277, 12.635947529003333, 13.577898785390028, 14.56547963330172, 15.568087930519395, 14.9278949169562, 13.941339927859994, 9.763521603882154, 10.77496480242285, 9.81342752112945, 8.862818385441253, 7.918010575702292, 6.844326275999317, 5.908995136839357, 4.966748363665314, 5.897100466281399, 6.93151698889727, 7.9105162400228215, 8.716118422823396, 9.691754588173328, 10.635570292841354, 11.575355420702792, 12.574940886633092, 13.58463535720939, 14.564380056244913, 15.599246093001893, 14.791155115278002, 10.69120723751633, 9.849840238978812, 8.839744481631339, 7.857626874659997, 6.9210204421681345, 5.895181697676647, 4.951322596150181, 4.0014882672407355, 4.883845175511259, 5.9134912618534425, 6.893073029631035, 7.713431044959251, 8.644352304087011, 9.670618467672906, 10.62241711968113, 11.625966527778827, 12.639583391241356, 13.656528540428763, 14.607720875579968, 15.675491543344855], [15.815223704570258, 14.836467810826429, 13.841763000727138, 12.886766451210837, 11.817185645942319, 10.757691409361223, 9.803408522753292, 8.78633997367806, 7.7773047451773305, 6.927336830519224, 5.947950364432681, 4.9043497002617045, 3.974370015040658, 2.9639084553986588, 3.9072646760488925, 4.916587671082254, 5.876159885803214, 6.805364058674585, 7.823832430462993, 8.781772375921099, 14.850891311518133, 13.89359747714812, 12.937262166012259, 11.947270194770537, 10.913931850379955, 9.841093610551061, 8.82866017430927, 7.794152528543796, 6.84885130619957, 5.888285978420447, 4.9558563973793195, 4.023038263566058, 3.0134919561338727, 1.9667171494008855, 2.99995631052565, 3.9285503625735867, 4.839460074974862, 5.805538915445551, 6.829273375499445, 7.760652515909226, 14.049355480734448, 13.103627474907498, 12.099981298031429, 11.069490240441647, 10.014555288903164, 9.032898162823372, 8.009446504225904, 7.034018012999551, 6.049790929931858, 5.051865439155331, 4.11749712970445, 3.0576306489229594, 2.0259322185073856, 0.9817556783404564, 1.9748730316095244, 2.9891517741384073, 3.8681864503321792, 4.855787139393881, 5.81526775921339, 6.8124161015923, 13.290328732897327, 12.321245397746216, 11.276939960941307, 10.217340694560862, 9.163972380305228, 8.170799248090491, 7.213908135150814, 6.184873759512044, 5.146581072916655, 4.188400012785703, 3.1446424343239885, 2.0954841120476657, 1.0466679597685598, 0.0, 1.0741869799418597, 2.0002299759092037, 2.9309153554558085, 3.922403420100421, 4.849775577991006, 5.828436359813196, 14.099435428573218, 13.129182406423428, 12.193487142149698, 11.164876123401092, 10.124827910056828, 9.134553811340044, 8.063626097745779, 7.134057838961663, 6.155908836401145, 5.102959450848004, 4.070381366760062, 3.0132238224541905, 1.9858261922087368, 0.9551572803038139, 1.9212208232547532, 2.9029468436889383, 3.8684110792113118, 4.8152771194667565, 5.85132531866101, 6.782069638114875, 14.82490221645603, 13.811061886092148, 12.829037583739579, 11.87314394342749, 10.8514563146388, 9.826569281538982, 8.779036546699938, 7.803164413947406, 6.836576591178962, 5.893849642276539, 4.931442727651967, 3.99654469400732, 2.9279641342074054, 1.915384530380274, 2.8486576912224075, 3.8119277662948314, 4.815812274548941, 5.751115779484942, 6.694554488304683, 7.761377713889058, 15.669133046507195, 14.62949883858941, 13.629733847812293, 12.655008097213175, 11.665610776539587, 10.660392959140975, 9.735305007636276, 8.776165957846384, 7.78112770776592, 6.820232646710982, 5.854828888551094, 4.92166212543447, 3.8557480550301735, 2.910666624428644, 3.842527004473257, 4.76625372285881, 5.795894358508926, 6.676134584364625, 7.628480034994399, 8.582473362995971, 15.37910324910864, 15.53031111496315, 14.547444312916138, 13.585009016886609, 12.616382768739841, 11.657301640694243, 10.721211036758252, 9.745127047571142, 8.731364676711566, 7.790219717271745, 6.783333219074672, 5.806559540743688, 4.835951888510364, 3.940336263994078, 4.768616414645396, 5.734081458924308, 6.758808409602277, 7.619152115206823, 8.56325980928675, 9.57201191741472, 14.400452515206956, 15.420169328343274, 15.477488491065651, 14.569900716409814, 13.602231533086355, 12.589900505441912, 11.57244410315901, 10.602198982103381, 9.615208041965111, 8.622156222902044, 7.66702765703444, 6.731536804995932, 5.797517182598509, 4.897273159006414, 5.794490677636771, 6.753702504863639, 7.707153387202542, 8.58638364286413, 9.521951176783194, 10.555769640526728, 13.407941778696967, 14.357125022747514, 15.371372168327298, 15.524982532163577, 14.57952771977666, 13.594113287260274, 12.544551138596955, 11.588988057306004, 10.524917426534945, 9.582851722994894, 8.600229273199089, 7.755736248990711, 6.800483062250235, 5.9688176521777265, 6.788711921073361, 7.710646736230982, 8.760899981993159, 9.553263879619092, 10.562172397330414, 11.54735415525635, 12.463804780336918, 13.489974834731456, 14.331684630995326, 15.40223894520113, 14.527121026528551, 13.592985077350615, 12.680130766882536, 12.482281095310686, 11.485772319937947, 10.570918850057005, 9.623135033369874, 8.76320790104091, 7.81624656435007, 6.954915962903241, 7.81053407557396, 8.687395062097725, 9.71004514511231, 10.564190670778828, 11.554084640569975, 12.474613593983447, 11.50775401115629, 12.416109644820628, 13.403968127837835, 14.446064749807515, 13.595779774475705, 12.665486624945377, 11.684105634906413, 12.698448251881947, 12.450639004489604, 11.527376836266841, 10.569085105823735, 9.752018713773198, 8.813953696232515, 7.92680344456592, 8.806432395783869, 9.681114409067733, 10.613028927324041, 11.572798703653442, 12.628436664166854, 13.43392681603249, 10.519634581698831, 11.48994944806249, 12.516946056086278, 13.464822300183291, 12.602634991108685, 11.658438105060915, 10.684243792094486, 11.643792386615225, 12.600183912599183, 12.512189546418943, 11.559643459415549, 10.688097610876177, 9.80398071923584, 8.891395854807426, 9.733170217764485, 10.68220594287169, 11.64022481611042, 12.559412676112558, 13.558970066872222, 14.461080408120626, 9.60453776889007, 10.66577361642414, 11.611944206039999, 12.544450011997482, 11.688013717952487, 10.73591589416809, 9.746092897198245, 10.689158994262959, 11.645717676349165, 12.67925253264849, 12.572334063236523, 11.649390554961471, 10.795009245978333, 9.920503938063527, 10.799247818625377, 11.685936713329083, 12.593098554847806, 13.544633348514555, 14.51968972652142, 15.508914445288362, 8.788437567631572, 9.838389020943874, 10.736626778967135, 11.58465936591169, 10.686232911967036, 9.720377787809255, 8.776702316230299, 9.75006015839378, 10.7083361988198, 11.73569696122841, 12.7770605227343, 12.687777740156559, 11.835674236376734, 10.920553804283442, 11.810563831343408, 12.649693117506548, 13.656898467260275, 14.568476435250775, 15.489375132346387, 15.789329439377497, 7.807253203949056, 8.783243450891458, 9.79230999977087, 10.657125176701857, 9.69688557015586, 8.667111169957758, 7.750220985374099, 8.797000022231895, 9.764777225843622, 10.690480979731204, 11.729368201061819, 12.769053749895043, 12.777625328136, 11.969707397606383, 12.752310809249957, 13.686659553830431, 14.671470100196355, 15.638883297938715, 16.1353077018327, 15.10280367537193, 6.863346541295284, 7.877484964416218, 8.828452290976292, 9.732499907263346, 8.72018615821713, 7.73550931436728, 6.801405275336654, 7.7605895065538695, 8.732983397933959, 9.713400833977406, 10.690132528730887, 11.731639012542317, 12.595748605769796, 13.024317488031793, 13.726101666627084, 14.727051183616679, 15.639909392088281, 16.2957442588149, 15.294556774273525, 14.231118294173722, 7.814980312464803, 8.78856721306341, 9.69025578528881, 8.762650963270055, 7.77995530076574, 6.796139712701744, 5.863397434730192, 6.8325392980830015, 7.827501125896315, 8.790664358007998, 9.73343512607579, 10.712426087004898, 11.660700293792361, 12.646337568470225, 13.682615488771894, 14.624566745158589, 15.612147593070281, 16.614755890287956, 15.97456287672476, 14.988007887628553, 8.716853644113595, 9.72829684265429, 8.766759561360889, 7.816150425672693, 6.871342615933732, 5.797658316230757, 4.862327177070797, 5.831818426998688, 6.8296434825465715, 7.864060005162443, 8.843059256287995, 9.762786382591955, 10.738422547941889, 11.682238252609915, 12.622023380471353, 13.621608846401653, 14.63130331697795, 15.611048016013473, 16.645914052770454, 15.837823075046561, 9.644539277747771, 8.803172279210251, 7.793076521862779, 6.810958914891438, 5.874352482399575, 4.848513737908087, 3.904654636381621, 4.931015091284568, 5.85533322131845, 6.884979307660633, 7.8912439719334015, 8.760099004727811, 9.691020263855572, 10.717286427441467, 11.66908507944969, 12.672634487547388, 13.686251351009917, 14.703196500197322, 15.654388835348527, 16.722159503113414], [16.889410684512118, 15.91065479076829, 14.915949980668998, 13.960953431152697, 12.891372625884179, 11.831878389303084, 10.877595502695153, 9.860526953619921, 8.85149172511919, 8.001523810461084, 7.022137344374541, 5.978536680203565, 5.048556994982518, 4.0380954353405185, 3.1365530097772747, 3.9265686501380603, 4.801972905861354, 5.731177078732725, 6.7496454505211325, 7.707585395979239, 15.925078291459993, 14.96778445708998, 14.011449145954119, 13.021457174712397, 11.988118830321815, 10.915280590492921, 9.90284715425113, 8.868339508485656, 7.923038286141431, 6.962472958362307, 6.03004337732118, 5.097225243507919, 4.087678936075733, 3.0409041293427452, 2.0888974688358335, 2.9204652774653344, 3.765273095033002, 4.731351935503691, 5.755086395557584, 6.686465535967367, 15.123542460676308, 14.177814454849358, 13.174168277973289, 12.143677220383507, 11.088742268845024, 10.107085142765232, 9.083633484167764, 8.108204992941412, 7.123977909873719, 6.126052419097191, 5.19168410964631, 4.13181762886482, 3.100119198449245, 2.055942658282316, 1.0638141899197076, 1.981066689030155, 2.7939994703903195, 3.781600159452021, 4.741080779271531, 5.73822912165044, 14.364515712839186, 13.395432377688074, 12.351126940883166, 11.29152767450272, 10.238159360247087, 9.24498622803235, 8.288095115092673, 7.259060739453903, 6.2207680528585145, 5.262586992727562, 4.218829414265848, 3.1696710919895255, 2.1208549397104193, 1.0741869799418597, 0.0, 0.926042995967344, 1.856728375513949, 2.8482164401585615, 3.775588598049147, 4.754249379871337, 15.173622408515078, 14.203369386365289, 13.267674122091556, 12.23906310334295, 11.199014889998686, 10.208740791281905, 9.137813077687639, 8.208244818903523, 7.217842968359186, 6.1648935828060445, 5.1323154987181026, 4.075157954412231, 3.0477603241667772, 2.0170914122618546, 1.051027869310915, 1.8826766960539172, 2.794224099269452, 3.741090139524897, 4.7771383387191495, 5.707882658173014, 15.837075062302583, 14.823234731938701, 13.841210429586132, 12.885316789274043, 11.863629160485353, 10.838742127385535, 9.791209392546492, 8.81533725979396, 7.848749437025515, 6.906022488123092, 5.94361557349852, 5.0087175398538735, 3.9401369800539587, 2.927557376226827, 1.9784647372785693, 2.9417348123509934, 3.8269761674111056, 4.676928799543083, 5.620367508362824, 6.687190733947198, 15.289470483185482, 15.641671684435963, 14.641906693658846, 13.667180943059728, 12.67778362238614, 11.672565804987528, 10.74747785348283, 9.788338803692938, 8.793300553612474, 7.832405492557536, 6.867001734397648, 5.933834971281024, 4.867920900876727, 3.922839470275197, 2.9723340505294185, 3.8960607689149724, 4.810852844968493, 5.601947604422767, 6.554293055052541, 7.508286383054113, 14.304916269166782, 15.316661618392443, 15.555003677572978, 14.59256838154345, 13.623942133396682, 12.640642903375062, 11.70455229943907, 10.72846831025196, 9.714705939392385, 8.773560979952563, 7.76667448175549, 6.789900803424506, 5.819293151191181, 4.8594374209464775, 3.898423460701558, 4.863888504980471, 5.773766896061844, 6.544965135264965, 7.489072829344892, 8.497824937472862, 13.326265535265097, 14.345982348401417, 15.31014747078613, 15.577460081066654, 14.585572795767174, 13.573241768122731, 12.555785365839826, 11.585540244784198, 10.598549304645928, 9.60549748558286, 8.650368919715257, 7.71487806767675, 6.780858445279327, 5.8163743159588135, 4.924297723692932, 5.8835095509198005, 6.750859001072026, 7.512196662922271, 8.447764196841336, 9.48158266058487, 12.333754798755109, 13.282938042805656, 14.29718518838544, 15.278338270943522, 14.707784297986708, 13.839602366612809, 13.527892401277771, 12.572329319986821, 11.508258689215761, 10.56619298567571, 9.583570535879906, 8.739077511671528, 7.783824324931052, 6.8879188091301256, 5.918518967129522, 6.840453782287143, 7.810605088203862, 8.479076899677233, 9.487985417388556, 10.473167175314492, 11.38961780039506, 12.415787854789597, 13.257497651053468, 14.328051965259272, 13.772493752101727, 12.838357802923792, 13.754317746824396, 13.465622357991503, 12.469113582618764, 11.554260112737822, 10.60647629605069, 9.746549163721728, 8.799587827030887, 7.87401711985564, 6.940341121630121, 7.817202108153886, 8.759750251323013, 9.49000369083697, 10.479897660628117, 11.400426614041589, 10.433567031214432, 11.34192266487877, 12.329781147895977, 13.371877769865657, 12.841152500048882, 11.910859350518553, 12.758292614848273, 13.772635231823807, 13.433980267170421, 12.510718098947658, 11.552426368504552, 10.735359976454015, 9.797294958913332, 8.845904601518319, 7.93623944184003, 8.810921455123895, 9.742835973380203, 10.498611723711583, 11.554249684224995, 12.35973983609063, 9.445447601756973, 10.415762468120631, 11.44275907614442, 12.390635320241433, 11.848007716681861, 10.903810830634091, 11.758430772036347, 12.717979366557085, 13.674370892541043, 13.49553080909976, 12.542984722096366, 11.671438873556994, 10.787321981916657, 9.810497011759825, 8.862977263820646, 9.812012988927851, 10.770031862166581, 11.4852256961707, 12.484783086930364, 13.386893428178768, 8.530350788948212, 9.591586636482281, 10.53775722609814, 11.535320050760317, 10.91730205168087, 9.965374152501038, 10.820279877140106, 11.76334597420482, 12.719904656291025, 13.75343951259035, 13.55567532591734, 12.632731817642288, 11.77835050865915, 10.839605095015926, 9.929054864681538, 10.815743759385244, 11.722905600903967, 12.470446368572697, 13.44550274657956, 14.434727465346503, 7.714250587689713, 8.764202041002013, 9.662439799025275, 10.630402039297767, 9.91552124569542, 8.949666121537637, 9.85088929617216, 10.82424713833564, 11.78252317876166, 12.80988394117027, 13.851247502676161, 13.671119002837376, 12.766855874289716, 11.83965496123584, 10.94037087739957, 11.779500163562709, 12.786705513316436, 13.494289455308916, 14.415188152404527, 15.37083117428512, 6.733066224007196, 7.709056470949598, 8.71812301982901, 9.702867850087934, 8.926173903884244, 7.8963995036861405, 8.82440796531596, 9.871187002173755, 10.838964205785482, 11.764667959673064, 12.803555181003679, 13.843240729836904, 13.708806966048982, 12.841215006893293, 11.882117855306118, 12.816466599886592, 13.801277146252517, 14.564696317996857, 15.386531208865557, 16.17699065531379, 5.789159561353425, 6.803297984474359, 7.754265311034433, 8.700219283547606, 7.949474491945512, 6.964797648095662, 7.875592255278514, 8.83477648649573, 9.807170377875819, 10.787587813919266, 11.764319508672747, 12.805825992484177, 13.669935585711656, 13.828511715861177, 12.855908712683245, 13.85685822967284, 14.769716438144442, 15.49274110222182, 16.368743754215384, 15.30530527411558, 6.740793332522943, 7.714380233121551, 8.653665427334392, 7.839274763317435, 6.993051101408244, 6.025428046430126, 6.9375844146720524, 7.906726278024862, 8.901688105838176, 9.864851337949858, 10.80762210601765, 11.786613066946758, 12.734887273734222, 13.720524548412085, 13.923947960374674, 14.847866272945046, 15.72813248129491, 16.55520192507911, 17.04874985666662, 16.062194867570415, 7.642666664171735, 8.69993398476236, 7.767007800381585, 6.816398664693389, 5.9324331171616125, 5.0269466499591395, 5.936514157012657, 6.906005406940548, 7.903830462488432, 8.938246985104303, 9.917246236229856, 10.836973362533815, 11.81260952788375, 12.756425232551775, 13.696210360413213, 14.695795826343513, 15.70549029691981, 16.685234995955334, 17.720101032712314, 16.91201005498842, 8.570352297805911, 7.776435975306347, 6.774273350885553, 5.797285266797219, 4.884333461455382, 4.077802071636469, 4.978841616323481, 6.005202071226428, 6.92952020126031, 7.959166287602494, 8.965430951875263, 9.834285984669672, 10.765207243797432, 11.791473407383327, 12.74327205939155, 13.746821467489248, 14.760438330951777, 15.777383480139182, 16.728575815290387, 17.796346483055274], [17.81545368047946, 16.83669778673563, 15.841992976636341, 14.88699642712004, 13.817415621851522, 12.757921385270427, 11.803638498662496, 10.786569949587264, 9.777534721086534, 8.927566806428427, 7.937246778888333, 6.893646114717357, 5.96366642949631, 4.953204869854311, 4.009848649204077, 3.0005256541707164, 3.87592990989401, 4.805134082765381, 5.823602454553789, 6.781542400011896, 16.851121287427336, 15.893827453057323, 14.937492141921462, 13.94750017067974, 12.914161826289158, 11.841323586460264, 10.828890150218474, 9.794382504452999, 8.849081282108774, 7.88851595432965, 6.956086373288523, 6.023268239475262, 5.013721932043077, 3.966947125310089, 3.0070205569141923, 1.9944222814979902, 2.839230099065658, 3.8053089395363466, 4.82904339959024, 5.760422540000023, 16.04958545664365, 15.103857450816701, 14.100211273940632, 13.06972021635085, 12.014785264812367, 11.033128138732575, 10.009676480135107, 9.034247988908755, 8.05002090584106, 7.052095415064534, 6.117727105613653, 5.057860624832163, 4.026162194416589, 2.98198565424966, 1.9898571858870515, 1.055023693062811, 1.8679564744229755, 2.855557163484677, 3.815037783304187, 4.8121861256830964, 15.29055870880653, 14.321475373655419, 13.27716993685051, 12.217570670470066, 11.164202356214432, 10.171029223999694, 9.214138111060018, 8.185103735421247, 7.146811048825859, 6.188629988694907, 5.144872410233193, 4.095714087956869, 3.0468979356777632, 2.0002299759092037, 0.926042995967344, 0.0, 0.930685379546605, 1.9221734441912175, 2.849545602081803, 3.828206383903993, 16.099665404482423, 15.129412382332632, 14.1937171180589, 13.165106099310295, 12.125057885966031, 11.11633726928827, 10.045409555694004, 9.115841296909888, 8.10517481956903, 7.052225434015888, 6.019647349927946, 4.9624898056220745, 3.935092175376621, 2.904423263471698, 1.9383597205207588, 0.9566337000865733, 1.868181103302108, 2.8150471435575533, 3.851095342751806, 4.781839662205671, 15.318599768159949, 15.710566583148545, 14.728542280795976, 13.772648640483887, 12.750961011695196, 11.726073978595378, 10.678541243756335, 9.702669111003804, 8.73608128823536, 7.793354339332936, 6.830947424708364, 5.896049391063717, 4.827468831263802, 3.814889227436671, 2.865796588488413, 2.0298036941796256, 2.9009331714437616, 3.7508858035757386, 4.69432451239548, 5.761147737979854, 14.363427487218138, 15.347256608192204, 15.52923854486869, 14.554512794269572, 13.565115473595984, 12.559897656197371, 11.634809704692673, 10.675670654902781, 9.680632404822319, 8.71973734376738, 7.754333585607491, 6.821166822490867, 5.75525275208657, 4.810171321485041, 3.8596659017392625, 2.9841296507436046, 3.884809849001149, 4.675904608455422, 5.628250059085196, 6.582243387086768, 13.378873273199437, 14.390618622425096, 15.314148652968298, 15.479900232753293, 14.511273984606525, 13.527974754584905, 12.591884150648914, 11.615800161461804, 10.602037790602228, 9.660892831162407, 8.654006332965334, 7.6772326546343495, 6.706625002401025, 5.746769272156321, 4.785755311911402, 3.951957386809103, 4.8477239000945, 5.61892213929762, 6.563029833377547, 7.571781941505516, 12.400222539297753, 13.41993935243407, 14.384104474818784, 15.307377090729938, 15.134254523993441, 14.460573619332575, 13.44311721704967, 12.472872095994042, 11.485881155855772, 10.492829336792704, 9.5377007709251, 8.602209918886594, 7.66819029648917, 6.703706167168657, 5.811629574902776, 4.971638302931492, 5.824816005104682, 6.586153666954926, 7.52172120087399, 8.555539664617523, 11.407711802787762, 12.356895046838309, 13.371142192418093, 14.352295274976175, 14.117354364113497, 14.712898006039612, 14.415224252487615, 13.459661171196664, 12.395590540425605, 11.453524836885554, 10.47090238708975, 9.626409362881372, 8.671156176140896, 7.775250660339969, 6.805850818339366, 5.928582534298834, 6.884562092236518, 7.5530339037098875, 8.561942421421211, 9.547124179347147, 10.463574804427713, 11.489744858822252, 12.331454655086123, 13.402008969291927, 13.182063818228517, 13.711653442350595, 14.669427181338191, 14.352954209201346, 13.356445433828608, 12.441591963947666, 11.493808147260534, 10.633881014931571, 9.68691967824073, 8.761348971065484, 7.827672972839965, 6.905330860165577, 7.8337072553556695, 8.563960694869623, 9.55385466466077, 10.474383618074244, 9.507524035247085, 10.415879668911424, 11.403738151928632, 12.445834773898312, 12.214316053016278, 12.784154989945357, 13.673402049362068, 14.687744666337602, 14.321312118380265, 13.398049950157501, 12.439758219714395, 11.622691827663859, 10.684626810123175, 9.733236452728162, 8.823571293049874, 7.899050207135586, 8.827577056268716, 9.572568727744237, 10.628206688257649, 11.433696840123286, 8.519404605789628, 9.489719472153286, 10.516716080177074, 11.464592324274088, 11.221171269649258, 11.777106470060893, 12.673540206550141, 13.63308880107088, 14.589480327054838, 14.382862660309604, 13.430316573306209, 12.558770724766838, 11.6746538331265, 10.697828862969669, 9.75030911503049, 8.966689682720405, 9.862884472598159, 10.559182700203353, 11.558740090963017, 12.460850432211423, 7.604307792980867, 8.665543640514937, 9.611714230130795, 10.609277054792972, 10.19806674119391, 10.83866979192784, 11.7353893116539, 12.678455408718614, 13.635014090804816, 14.668548947104142, 14.443007177127184, 13.520063668852131, 12.665682359868994, 11.72693694622577, 10.816386715891381, 9.970420453177798, 10.815758211335545, 11.54440337260535, 12.519459750612214, 13.508684469379158, 6.788207591722369, 7.83815904503467, 8.736396803057932, 9.704359043330424, 9.19628593520846, 9.82296176096444, 10.765998730685954, 11.739356572849434, 12.697632613275454, 13.724993375684061, 14.766356937189952, 14.55845085404722, 13.65418772549956, 12.726986812445684, 11.827702728609413, 10.934176857355263, 11.879558123748014, 12.56824645934157, 13.48914515643718, 14.444788178317776, 5.807023228039853, 6.783013474982255, 7.792080023861667, 8.77682485412059, 8.15664026010018, 8.769695143112942, 9.739517399829753, 10.786296436687547, 11.754073640299275, 12.679777394186857, 13.71866461551747, 14.758350164350695, 14.596138817258826, 13.728546858103137, 12.769449706515962, 11.971143293679145, 12.894129756684094, 13.63865332202951, 14.46048821289821, 15.390001707555289, 4.863116565386081, 5.877254988507015, 6.828222315067089, 7.7741762875802625, 7.118104877799038, 7.838093287522465, 8.790701689792307, 9.749885921009524, 10.722279812389612, 11.70269724843306, 12.679428943186538, 13.720935426997968, 14.585045020225447, 14.71584356707102, 13.743240563893089, 13.011534923465392, 13.86256904857602, 14.566698106254474, 15.45803337943471, 16.231348270082925, 5.8147503365555995, 6.788337237154206, 7.727622431367046, 6.913231767350091, 6.0670081054409, 6.898723685856929, 7.852693849185845, 8.821835712538654, 9.816797540351969, 10.77996077246365, 11.722731540531441, 12.70172250146055, 13.649996708248013, 14.635633982925876, 14.811279811584518, 14.002542966737598, 14.820985091726488, 15.629158929111766, 16.46730182540271, 16.98823786353776, 6.716623668204391, 7.773890988795017, 6.8409648044142415, 5.890355668726045, 5.0063901211942685, 5.900242289385942, 6.851623591526449, 7.8211148414543405, 8.818939897002224, 9.853356419618095, 10.832355670743647, 11.758387397643975, 12.738652523851092, 13.682468228519118, 14.622253356380556, 15.005500865494534, 15.801829367818819, 16.63286680338625, 17.42249742286495, 17.838053050955764, 7.644309301838566, 6.850392979339004, 5.8482303549182095, 4.871242270829875, 3.958290465488038, 4.951097711063272, 5.893951050837273, 6.92031150574022, 7.844629635774102, 8.874275722116286, 9.880540386389054, 10.760328980637015, 11.691250239764775, 12.71751640335067, 13.669315055358894, 14.672864463456591, 15.68648132691912, 16.703426476106525, 17.65461881125773, 18.722389479022617], [18.746139060026067, 17.767383166282237, 16.772678356182947, 15.817681806666647, 14.748101001398128, 13.688606764817033, 12.734323878209102, 11.71725532913387, 10.70822010063314, 9.858252185975033, 8.866908537529229, 7.823307873358253, 6.893328188137207, 5.882866628495207, 4.939510407844973, 3.9301874128116125, 2.9452445303474057, 3.8744487032187767, 4.892917075007185, 5.850857020465291, 17.781806666973942, 16.82451283260393, 15.868177521468068, 14.878185550226346, 13.844847205835764, 12.77200896600687, 11.75957552976508, 10.725067883999605, 9.77976666165538, 8.819201333876256, 7.886771752835129, 6.953953619021868, 5.944407311589681, 4.897632504856694, 3.936682315555089, 2.9240840401388866, 1.9085447195190532, 2.8746235599897423, 3.898358020043636, 4.829737160453417, 16.980270836190257, 16.034542830363307, 15.030896653487238, 14.000405595897456, 12.945470644358974, 11.963813518279181, 10.940361859681714, 9.96493336845536, 8.980706285387667, 7.98278079461114, 7.048412485160259, 5.988546004378769, 4.956847573963194, 3.912671033796265, 2.9205425654336565, 1.9846854517037076, 0.9372710948763706, 1.9248717839380722, 2.884352403757582, 3.881500746136491, 16.221244088353135, 15.252160753202023, 14.207855316397115, 13.14825605001667, 12.094887735761036, 11.101714603546299, 10.144823490606623, 9.115789114967852, 8.077496428372463, 7.119315368241511, 6.075557789779797, 5.026399467503475, 3.9775833152243685, 2.9309153554558085, 1.856728375513949, 0.930685379546605, 0.0, 0.9914880646446125, 1.9188602225351978, 2.8975210043573876, 15.37226314248472, 16.060097761879238, 15.124402497605505, 14.0957914788569, 13.055743265512636, 12.047022648834876, 10.97609493524061, 10.046526676456494, 9.035860199115636, 7.982910813562493, 6.950332729474551, 5.89317518516868, 4.865777554923226, 3.8351086430183035, 2.869045100067364, 1.8873190796331785, 0.9374957237555032, 1.884361764010948, 2.9204099632052007, 3.851154282659066, 14.387914388613343, 15.401754718977225, 15.659227660342582, 14.703334020030493, 13.681646391241802, 12.656759358141985, 11.609226623302941, 10.63335449055041, 9.666766667781966, 8.724039718879542, 7.76163280425497, 6.826734770610323, 5.7581542108104085, 4.7455746069832765, 3.7964819680350184, 2.9604890737262304, 1.9702477918971564, 2.8202004240291334, 3.7636391328488745, 4.830462358433249, 13.432742107671531, 14.416571228645598, 15.333837816641744, 15.485198173816178, 14.49580085314259, 13.490583035743978, 12.565495084239279, 11.606356034449387, 10.611317784368925, 9.650422723313985, 8.685018965154097, 7.751852202037473, 6.6859381316331765, 5.740856701031647, 4.790351281285868, 3.9148150302902094, 2.954124469454544, 3.7452192289088173, 4.6975646795385915, 5.651558007540164, 12.44818789365283, 13.45993324287849, 14.383463273421693, 15.345898569451222, 15.44195936415313, 14.45866013413151, 13.522569530195518, 12.546485541008408, 11.532723170148833, 10.591578210709011, 9.584691712511939, 8.607918034180955, 7.63731038194763, 6.677454651702926, 5.716440691458007, 4.882642766355708, 3.9170385205478944, 4.688236759751015, 5.6323444538309415, 6.641096561958911, 11.469537159751146, 12.489253972887465, 13.45341909527218, 14.376691711183334, 15.414475899105392, 15.391258998879179, 14.373802596596272, 13.403557475540644, 12.416566535402374, 11.423514716339309, 10.468386150471705, 9.532895298433198, 8.598875676035775, 7.634391546715262, 6.742314954449382, 5.8475815078969795, 4.894130625558077, 5.655468287408322, 6.5910358213273845, 7.624854285070918, 10.477026423241158, 11.426209667291705, 12.440456812871489, 13.42160989542957, 14.423194265186941, 15.408608697703327, 15.345909632034218, 14.390346550743269, 13.32627591997221, 12.384210216432159, 11.401587766636354, 10.557094742427976, 9.6018415556875, 8.705936039886575, 7.736536197885972, 6.804525739264322, 5.953876712689913, 6.622348524163283, 7.631257041874606, 8.616438799800541, 9.532889424881109, 10.559059479275646, 11.400769275539517, 12.471323589745321, 13.487903719301961, 14.422039668479897, 15.392923709808226, 15.28363958874795, 14.287130813375212, 13.37227734349427, 12.424493526807138, 11.564566394478176, 10.617605057787335, 9.69203435061209, 8.758358352386571, 7.781274065131065, 6.903021875809063, 7.633275315323019, 8.623169285114166, 9.543698238527638, 8.576838655700481, 9.485194289364818, 10.473052772382026, 11.515149394351706, 12.520155954089722, 13.497796594783962, 14.503827201219172, 15.518169818194707, 15.251997497926869, 14.328735329704106, 13.370443599261, 12.553377207210463, 11.61531218966978, 10.663921832274768, 9.75425667259648, 8.774993412101074, 7.896891676722109, 8.641883348197632, 9.697521308711044, 10.50301146057668, 7.588719226243022, 8.55903409260668, 9.586030700630468, 10.533906944727482, 11.585574159393047, 12.529771045440818, 13.503965358407246, 14.463513952927984, 15.419905478911943, 15.313548039856208, 14.361001952852813, 13.489456104313442, 12.605339212673105, 11.628514242516275, 10.680994494577096, 9.842632887685893, 8.932199093051553, 9.628497320656749, 10.628054711416413, 11.530165052664817, 6.673622413434263, 7.734858260968333, 8.681028850584193, 9.67859167524637, 10.67341441662938, 11.668635295778268, 12.658458292748112, 13.603181335120233, 14.564675849445713, 15.59821070574504, 15.373692556673788, 14.450749048398736, 13.596367739415598, 12.657622325772376, 11.747072095437987, 10.846363658143286, 9.88507283178894, 10.613717993058746, 11.588774371065611, 12.577999089832552, 5.8575222121757635, 6.907473665488066, 7.805711423511328, 8.773673663783818, 9.7700362830168, 10.73589140717458, 11.690724657087573, 12.664082499251053, 13.62729437191635, 14.654655134324958, 15.696018695830848, 15.489136233593822, 14.584873105046166, 13.65767219199229, 12.75838810815602, 11.81012006232075, 10.948872744201408, 11.637561079794965, 12.558459776890578, 13.51410279877117, 4.876337848493248, 5.8523280954356505, 6.861394644315062, 7.846139474573985, 8.806379081119982, 9.69935690175384, 10.669179158470648, 11.715958195328444, 12.68373539894017, 13.609439152827752, 14.648326374158366, 15.68801192299159, 15.526824196805432, 14.659232237649743, 13.700135086062568, 12.847086498644632, 11.963444377137488, 12.707967942482906, 13.529802833351608, 14.459316328008683, 3.9324311858394756, 4.946569608960409, 5.897536935520484, 6.843490908033657, 7.855804657079873, 8.767755046163362, 9.720363448433202, 10.679547679650419, 11.651941571030507, 12.632359007073955, 13.609090701827434, 14.650597185638864, 15.514706778866342, 15.646528946617627, 14.673925943439695, 13.877093902942875, 12.931883669029414, 13.63601272670787, 14.527347999888107, 15.43576591481932, 4.884064957008994, 5.8576518576076015, 6.796937051820442, 5.982546387803486, 6.965096083165033, 7.828385444497825, 8.78235560782674, 9.751497471179551, 10.746459298992864, 11.709622531104545, 12.652393299172337, 13.631384260101445, 14.579658466888908, 15.565295741566771, 15.741965191131124, 14.86810194621508, 13.890299712179882, 14.698473549565161, 15.536616445856108, 16.364820493415532, 5.7859382886577855, 6.843205609248411, 5.910279424867637, 4.95967028917944, 5.904478098918402, 6.8299040480268385, 7.781285350167345, 8.750776600095236, 9.74860165564312, 10.78301817825899, 11.762017429384542, 12.68804915628487, 13.669337903397698, 14.613153608065724, 15.552938735927162, 15.871059844972017, 14.871143988272213, 15.702181423839644, 16.491812043318347, 17.429353630713436, 6.713623922291961, 5.9197075997924, 4.917544975371605, 3.9405568912832702, 4.877163323775132, 5.880759469704168, 6.82361280947817, 7.849973264381116, 8.774291394414998, 9.803937480757183, 10.810202145029951, 11.69101436018362, 12.621935619311381, 13.648201782897276, 14.6000004349055, 15.603549843003197, 15.892114746306957, 16.753387473868294, 17.509562139056623, 18.491000493935125], [18.53898693857646, 17.71211632018841, 16.882590795303752, 16.80916987131126, 15.73958906604274, 14.680094829461645, 13.725811942853714, 12.708743393778482, 11.699708165277752, 10.849740250619647, 9.85839660217384, 8.814795938002865, 7.884816252781819, 6.87435469313982, 5.930998472489586, 4.921675477456225, 3.9367325949920176, 3.1630303427419006, 3.9810332119448235, 4.89749097210859, 17.467301181223437, 17.816000897248543, 16.859665586112683, 15.86967361487096, 14.836335270480378, 13.763497030651484, 12.751063594409693, 11.716555948644217, 10.771254726299992, 9.810689398520868, 8.87825981747974, 7.94544168366648, 6.935895376234294, 5.889120569501307, 4.928170380199702, 3.9155721047834993, 2.9000327841636655, 2.10537236064149, 2.9315323470605286, 3.8382490958088047, 16.461519394006793, 17.02603089500792, 16.02238471813185, 14.991893660542068, 13.936958709003585, 12.955301582923793, 11.931849924326325, 10.956421433099973, 9.972194350032279, 8.974268859255751, 8.039900549804871, 6.980034069023381, 5.948335638607807, 4.904159098440878, 3.9120306300782692, 2.97617351634832, 1.928759159520983, 1.037854532473661, 1.8928643391129691, 2.8900126814918785, 15.493500086411707, 16.243648817846637, 15.19934338104173, 14.139744114661285, 13.086375800405651, 12.093202668190914, 11.136311555251238, 10.107277179612467, 9.068984493017078, 8.110803432886126, 7.067045854424411, 6.017887532148087, 4.969071379868981, 3.922403420100421, 2.8482164401585615, 1.9221734441912175, 0.9914880646446125, 0.0, 0.9273721578905854, 1.9060329397127753, 14.5620644044876, 15.53231742663739, 16.11589056225012, 15.087279543501515, 14.047231330157251, 13.038510713479486, 11.96758299988522, 11.038014741101104, 10.027348263760246, 8.974398878207104, 7.941820794119163, 6.884663249813292, 5.857265619567838, 4.826596707662915, 3.860533164711976, 2.8788071442777907, 1.9289837884001155, 1.0741630260138273, 1.9405149348440316, 2.8712592542978967, 13.577715650616224, 14.591555980980106, 15.518838825014853, 15.694822084675106, 14.673134455886416, 13.648247422786598, 12.600714687947555, 11.624842555195023, 10.65825473242658, 9.715527783524156, 8.753120868899583, 7.818222835254935, 6.74964227545502, 5.737062671627888, 4.78797003267963, 3.951977138370843, 2.961735856541769, 2.010001686032013, 2.903349973340455, 3.8687018119752965, 12.622543369674412, 13.606372490648479, 14.523639078644623, 15.49836482924374, 15.487288917787204, 14.482071100388591, 13.556983148883893, 12.597844099094, 11.602805849013539, 10.641910787958599, 9.67650702979871, 8.743340266682086, 7.677426196277788, 6.732344765676259, 5.7818393459304795, 4.906303094934822, 3.9456125340991566, 2.935020490911697, 3.8873659415414705, 4.841359269543043, 11.637989155655712, 12.649734504881371, 13.573264535424572, 14.535699831454101, 15.504326079600869, 15.450148198776121, 14.51405759484013, 13.53797360565302, 12.524211234793444, 11.583066275353623, 10.57617977715655, 9.599406098825567, 8.628798446592242, 7.668942716347538, 6.707928756102619, 5.87413083100032, 4.880374725562249, 3.8780380217538943, 4.8221457158338215, 5.830897823961791, 10.659338421754027, 11.679055234890345, 12.643220357275059, 13.566492973186213, 14.604277161108271, 15.616608188752714, 15.365290661240886, 14.395045540185258, 13.408054600046988, 12.415002780983922, 11.459874215116319, 10.524383363077812, 9.590363740680388, 8.625879611359874, 7.727227912188126, 6.768016084961258, 5.814565202622355, 4.845269549411201, 5.7808370833302645, 6.814655547073798, 9.666827685244037, 10.616010929294584, 11.630258074874368, 12.61141115743245, 13.606690083167294, 14.59210451568368, 15.640321442232406, 15.381834615387882, 14.317763984616823, 13.375698281076772, 12.393075831280967, 11.54858280707259, 10.593329620332113, 9.697424104531187, 8.713140413223535, 7.7249603163286, 6.765083607398048, 5.812149786166162, 6.821058303877485, 7.806240061803421, 8.722690686883988, 9.748860741278525, 10.590570537542396, 11.6611248517482, 12.671399537282314, 13.60500351617965, 14.57588755750798, 15.54375331058194, 15.278618878019826, 14.363765408138883, 13.415981591451752, 12.55605445912279, 11.60116088563717, 10.635396592653183, 9.696024227461658, 8.701708642195342, 7.714228770517199, 6.823076577325898, 7.812970547117044, 8.733499500530518, 7.76663991770336, 8.674995551367697, 9.662854034384905, 10.698645212332059, 11.703651772070074, 12.677505063774412, 13.606639911119077, 14.620982528094611, 15.57988504927466, 15.32022339434872, 14.361931663905613, 13.544865271855077, 12.598868017519615, 11.607284074315862, 10.683661252737968, 9.640013089686553, 8.708098571430245, 7.831684610200512, 8.887322570713923, 9.69281272257956, 6.778520488245902, 7.748835354609559, 8.775831962633347, 9.717402762707835, 10.759903515063353, 11.670456543889948, 12.60677806830715, 13.566326662827889, 14.522718188811847, 15.483627470258023, 15.352490017497427, 14.480944168958056, 13.58889504052294, 12.571876484557368, 11.610399074718584, 10.701424860998419, 9.743405987759688, 8.81829858265963, 9.817855973419293, 10.719966314667698, 5.849587552935415, 6.910823400469486, 7.831793180664544, 8.741976245224997, 9.736798986608006, 10.732019865756895, 11.66862717341091, 12.611693270475623, 13.604086918244395, 14.637621774543721, 15.56747278776082, 15.44223711304335, 14.579923567265434, 13.576712052657966, 12.606509957340045, 11.66194227869596, 10.696279726497075, 9.803519255061627, 10.778575633068492, 11.767800351835433, 4.895761665717811, 5.927578637126896, 6.819691888331567, 7.782185599139206, 8.778548218372189, 9.74440334252997, 10.699236592442963, 11.672594434606443, 12.71214381318762, 13.739504575596229, 14.80368566070543, 15.839746921927045, 15.503962831931755, 14.57676191887788, 13.582204223145387, 12.625698682873425, 11.760079638909543, 10.827362341797846, 11.748261038893459, 12.70390406077405, 3.896442820132078, 4.87243306707448, 5.875375109135301, 6.854651409929374, 7.814891016475371, 8.780595291875589, 9.83355999087405, 10.880339027731846, 11.856691068228436, 12.782394822116018, 13.830034061644215, 14.86971961047744, 15.814888325057407, 15.483048352639111, 14.523951201051936, 13.662665119197307, 12.774651271845624, 11.897769204485787, 12.719604095354489, 13.649117590011564, 2.940943121194864, 3.9550815443157976, 4.906048870875872, 5.852002843389045, 6.864316592435261, 7.848993436285111, 8.893319117721468, 9.852503348938685, 10.824897240318773, 11.80531467636222, 12.879387429347712, 13.923320392171586, 14.893078162322851, 15.82467227057974, 15.497742058429063, 14.68830079765101, 13.74309056373755, 12.82581398871075, 13.717149261890988, 14.625567176822202, 3.8925768923643824, 4.86616379296299, 5.80544898717583, 6.733053809194586, 7.715749471698901, 8.699565059762897, 9.666393746346825, 10.635535609699634, 11.651318975667508, 12.675270901504765, 13.618041669572557, 14.597032630501666, 15.545306837289129, 16.530944111966992, 16.565781306120492, 15.679308840923216, 14.701506606888017, 13.888274811568042, 14.726417707858989, 15.554621755418413, 4.794450224013173, 5.851717544603799, 5.266998698695803, 5.951158353824052, 6.895966163563013, 7.821392112671451, 8.772773414811958, 9.74226466473985, 10.740089720287733, 11.774506242903604, 12.753505494029156, 13.679537220929484, 14.66082596804231, 15.604641672710336, 16.544426800571774, 16.682266739680152, 15.682350882980348, 14.891982685842525, 15.68161330532123, 16.619154892716317, 5.7221358576473484, 5.007823736730037, 4.206126614894728, 4.932044955927882, 5.868651388419744, 6.872247534348781, 7.815100874122782, 8.84146132902573, 9.76577945905961, 10.795425545401795, 11.801690209674563, 12.682502424828233, 13.613423683955993, 14.639689847541888, 15.591488499550112, 16.595037907647807, 16.70332164101509, 15.943188735871177, 16.699363401059504, 17.680801755938006], [17.673737210130902, 17.007451144805557, 17.792005633541347, 17.736542029201846, 16.666961223933328, 15.60746698735223, 14.6531841007443, 13.636115551669068, 12.627080323168338, 11.77711240851023, 10.785768760064425, 9.74216809589345, 8.812188410672404, 7.801726851030405, 6.858370630380171, 5.84904763534681, 4.864104752882604, 4.072129425842647, 3.0536610540542384, 3.9701188142180044, 16.60205145277788, 17.547071410875823, 17.787037744003264, 16.797045772761543, 15.763707428370962, 14.690869188542068, 13.678435752300278, 12.643928106534803, 11.698626884190578, 10.738061556411454, 9.805631975370327, 8.872813841557067, 7.86326753412488, 6.816492727391893, 5.855542538090287, 4.842944262674084, 3.827404942054251, 3.0278946492238363, 2.004160189169943, 2.910876937918219, 15.596269665561234, 16.541997671388184, 16.949756876022438, 15.919265818432656, 14.864330866894173, 13.882673740814381, 12.859222082216913, 11.88379359099056, 10.899566507922867, 9.90164101714634, 8.967272707695457, 7.907406226913967, 6.875707796498393, 5.831531256331464, 4.839402787968854, 3.9035456742389054, 2.8561313174115686, 1.9652266903642464, 0.9654921812223838, 1.962640523601293, 14.628250357966149, 15.59733369311726, 16.126715538932316, 15.06711627255187, 14.013747958296236, 13.020574826081498, 12.063683713141822, 11.034649337503051, 9.996356650907662, 9.03817559077671, 7.994418012314997, 6.945259690038673, 5.896443537759567, 4.849775577991007, 3.775588598049147, 2.849545602081803, 1.9188602225351978, 0.9273721578905854, 0.0, 0.97866078182219, 13.696814676042042, 14.66706769819183, 15.570758545777121, 16.014651701392097, 14.974603488047835, 13.965882871370072, 12.894955157775806, 11.96538689899169, 10.954720421650832, 9.90177103609769, 8.86919295200975, 7.812035407703878, 6.784637777458424, 5.753968865553501, 4.787905322602562, 3.8061793021683763, 2.856355946290701, 2.0015351839044127, 1.0131427769534462, 1.9438870964073116, 12.712465922170665, 13.726306252534547, 14.631010253997033, 15.586903894309122, 15.600506613777, 14.575619580677182, 13.52808684583814, 12.552214713085608, 11.585626890317164, 10.64289994141474, 9.680493026790167, 8.74559499314552, 7.677014433345606, 6.664434829518474, 5.715342190570216, 4.879349296261428, 3.889108014432354, 2.919416524269611, 1.9759778154498697, 2.9413296540847114, 11.757293641228854, 12.718543919630658, 13.635810507626802, 14.61053625822592, 15.567269500783302, 15.409443258279175, 14.484355306774477, 13.525216256984585, 12.530178006904123, 11.569282945849183, 10.603879187689294, 9.67071242457267, 8.604798354168373, 7.659716923566845, 6.709211503821066, 5.833675252825407, 4.872984691989742, 3.8444353291492948, 2.964969242245973, 3.9189625702475452, 10.772739427210153, 11.76190593386355, 12.685435964406752, 13.64787126043628, 14.616497508583048, 15.599796738604669, 15.441429752730714, 14.465345763543604, 13.451583392684029, 12.510438433244207, 11.503551935047135, 10.52677825671615, 9.556170604482826, 8.596314874238123, 7.635300913993205, 6.801502988890906, 5.789789563799847, 4.787452859991492, 3.9725097822872706, 4.937032454936149, 9.794088693308469, 10.791226663872525, 11.755391786257238, 12.678664402168392, 13.696218085156653, 14.708549112801096, 15.685056319779767, 15.322417698075842, 14.335426757937572, 13.342374938874507, 12.387246373006903, 11.451755520968396, 10.517735898570972, 9.553251769250458, 8.636642750425725, 7.677430923198856, 6.723980040859954, 5.754684387648799, 4.931201149783714, 5.948344689571299, 8.778999114226217, 9.728182358276763, 10.742429503856547, 11.72358258641463, 12.67931792527671, 13.664732357793095, 14.712949284341821, 15.660495832090511, 15.245136142507407, 14.303070438967357, 13.320447989171551, 12.475954964963174, 11.520701778222698, 10.6159911115475, 9.622555251461133, 8.634375154566198, 7.674498445635646, 6.721564624403761, 5.993716565989849, 6.940990333357863, 7.8348621158661675, 8.854995372252883, 9.696705168516754, 10.767259482722558, 11.74402737939173, 12.677631358289066, 13.648515399617395, 14.616381152691355, 15.612889928064094, 15.291137566029468, 14.343353749342336, 13.483426617013373, 12.51057572387477, 11.544811430890782, 10.605439065699256, 9.61112348043294, 8.623643608754797, 7.732491415563496, 6.9905452651318845, 7.86824977208496, 6.878811346685539, 7.7811301823420544, 8.768988665359263, 9.771273054441474, 10.77627961417949, 11.750132905883827, 12.679267753228492, 13.693610370204027, 14.652512891384076, 15.590874089104043, 15.289303821796198, 14.472237429745661, 13.508282855757214, 12.51669891255346, 11.593076090975567, 10.549427927924151, 9.617513409667843, 8.74109944843811, 8.064897288728764, 8.827562994134002, 5.88465511922026, 6.854969985583917, 7.856991751714258, 8.79003060481725, 9.832531357172769, 10.743084385999364, 11.679405910416566, 12.638954504937304, 13.595346030921263, 14.556255312367439, 15.508801399370833, 15.40831632684864, 14.498309878760539, 13.481291322794966, 12.519813912956183, 11.610839699236017, 10.652820825997287, 9.727713420897226, 9.113190798036442, 9.854716586222139, 4.92221539504483, 5.983451242578901, 6.904421022773958, 7.814604087334413, 8.809426828717422, 9.80464770786631, 10.741255015520325, 11.684321112585039, 12.67671476035381, 13.710249616653137, 14.640100629870236, 15.667063344808977, 15.489338405503032, 14.486126890895564, 13.515924795577643, 12.571357116933559, 11.605694564734673, 10.712934093299223, 10.073910457685638, 10.902550623389875, 3.9683895078272258, 5.000206479236311, 5.892319730440981, 6.854813441248621, 7.851176060481604, 8.817031184639387, 9.771864434552379, 10.74522227671586, 11.784771655297035, 12.812132417705644, 13.876313502814845, 14.91237476403646, 15.829467258926089, 15.486176757115478, 14.491619061382986, 13.535113521111024, 12.669494477147142, 11.736777180035443, 11.043595863510605, 11.838654332328492, 2.969070662241493, 3.9450609091838955, 4.948002951244716, 5.9272792520387885, 6.8875188585847855, 7.853223133985004, 8.906187832983466, 9.952966869841262, 10.929318910337852, 11.855022664225434, 12.90266190375363, 13.942347452586855, 14.887516167166822, 15.919226615437044, 15.433366039289535, 14.572079957434905, 13.684066110083222, 12.807184042723383, 12.014938919971636, 12.783867861566005, 2.013570963304278, 3.0277093864252125, 3.978676712985287, 4.92463068549846, 5.936944434544676, 6.921621278394527, 7.965946959830884, 8.9251311910481, 9.897525082428189, 10.877942518471636, 11.952015271457128, 12.995948234281002, 13.965706004432267, 14.897300112689155, 15.869903115867087, 15.597715635888608, 14.652505401975148, 13.735228826948347, 13.012484086508135, 13.760317448376643, 2.9652047344737973, 3.938791635072404, 4.878076829285245, 5.805681651304001, 6.788377313808316, 7.7721929018723115, 8.73902158845624, 9.70816345180905, 10.723946817776923, 11.747898743614181, 12.690669511681973, 13.669660472611081, 14.617934679398545, 15.603571954076408, 16.658427419413815, 16.588723679160815, 15.610921445125616, 14.797689649805639, 14.021752532476135, 14.689372026972855, 3.867078066122587, 4.924345386713213, 5.885882668006613, 6.828557749928047, 7.773365559667008, 8.748764270562036, 9.700145572702542, 10.669636822630434, 11.667461878178317, 12.674503096459736, 13.653502347585288, 14.579534074485617, 15.588198125932896, 16.53201383060092, 17.471798958462358, 17.59168157791775, 16.591765721217946, 15.801397524080121, 14.976948129938377, 15.753905164270758, 4.794763699756763, 4.080451578839453, 5.090547336186925, 5.859417113818468, 6.79602354631033, 7.799619692239366, 8.742473032013367, 9.768833486916314, 10.693151616950194, 11.722797703292379, 12.729062367565147, 13.609874582718819, 14.54079584184658, 15.567062005432474, 16.518860657440698, 17.522410065538395, 17.61273647925269, 16.852603574108773, 15.99469822567665, 16.815552027492448], [16.723948599428354, 17.540153133851582, 18.57822017680237, 18.715202811024035, 17.645622005755516, 16.58612776917442, 15.631844882566488, 14.614776333491257, 13.605741104990527, 12.75577319033242, 11.764429541886615, 10.72082887771564, 9.790849192494594, 8.780387632852594, 7.837031412202361, 6.827708417169, 5.842765534704793, 5.0244873805843415, 4.006019008795933, 3.048079063337827, 15.652262842075332, 16.597282800173275, 17.553618111309135, 17.77570655458373, 16.74236821019315, 15.669529970364257, 14.657096534122466, 13.622588888356992, 12.677287666012766, 11.716722338233643, 10.784292757192516, 9.851474623379255, 8.841928315947069, 7.795153509214082, 6.8342033199124765, 5.821605044496274, 4.806065723876441, 4.006555431046027, 2.982820970992133, 1.9888371870380417, 14.646481054858686, 15.592209060685637, 16.595855237561707, 16.897926600254845, 15.842991648716362, 14.86133452263657, 13.837882864039102, 12.86245437281275, 11.878227289745055, 10.880301798968528, 9.945933489517646, 8.886067008736156, 7.854368578320582, 6.8101920381536525, 5.818063569791044, 4.882206456061095, 3.8347920992337583, 2.9438874721864363, 1.9441529630445737, 1.0406007727211155, 13.6784617472636, 14.647545082414712, 15.652659246203507, 16.045777054374057, 14.992408740118425, 13.999235607903687, 13.042344494964011, 12.01331011932524, 10.975017432729851, 10.016836372598899, 8.973078794137185, 7.923920471860862, 6.875104319581756, 5.828436359813196, 4.754249379871337, 3.828206383903993, 2.8975210043573876, 1.9060329397127753, 0.97866078182219, 0.0, 12.747026065339494, 13.717279087489283, 14.620969935074573, 15.638375222216904, 15.953264269870024, 14.94454365319226, 13.873615939597995, 12.94404768081388, 11.93338120347302, 10.88043181791988, 9.847853733831938, 8.790696189526066, 7.763298559280614, 6.732629647375691, 5.766566104424752, 4.7848400839905665, 3.835016728112891, 2.950085302294531, 1.914037103100278, 0.9832927836464128, 11.762677311468117, 12.776517641832, 13.681221643294485, 14.637115283606574, 15.562220420657832, 15.554280362499371, 14.506747627660328, 13.530875494907797, 12.564287672139352, 11.621560723236929, 10.659153808612356, 9.724255774967709, 8.655675215167795, 7.643095611340664, 6.694002972392406, 5.824620127202272, 4.820735618948163, 3.8203108504164427, 2.8768721415967016, 1.980735341323813, 10.807505030526306, 11.76875530892811, 12.686021896924254, 13.660747647523372, 14.617480890080754, 15.622698707479367, 15.463016088596666, 14.503877038806774, 13.508838788726312, 12.547943727671372, 11.582539969511485, 10.649373206394861, 9.583459135990564, 8.638377705389034, 7.687872285643255, 6.778946083766251, 5.788904578037727, 4.745329655296127, 3.865863568392805, 2.9691739595449986, 9.822950816507605, 10.812117323161003, 11.735647353704204, 12.698082649733733, 13.6667088978805, 14.65000812790212, 15.586098731838112, 15.444006545365795, 14.43024417450622, 13.489099215066398, 12.482212716869325, 11.505439038538341, 10.534831386305017, 9.574975656060314, 8.613961695815394, 7.723667828177915, 6.69068388994668, 5.688347186138325, 4.873404108434102, 3.987243844233602, 8.84430008260592, 9.841438053169977, 10.80560317555469, 11.728875791465844, 12.71755730333446, 13.729888330978904, 14.706395537957574, 15.676640659013202, 15.314087539759761, 14.321035720696695, 13.365907154829092, 12.430416302790585, 11.496396680393161, 10.531912551072649, 9.537537076572555, 8.578325249345687, 7.624874367006785, 6.655578713795631, 5.8320954759305454, 4.998556078868753, 7.829210503523669, 8.778393747574215, 9.792640893154, 10.773793975712081, 11.700657143454517, 12.686071575970903, 13.734288502519629, 14.681835050268319, 15.595084039644904, 15.281731220789545, 14.29910877099374, 13.454615746785363, 12.493007914124016, 11.51688543769433, 10.523449577607964, 9.53526948071303, 8.575392771782479, 7.622458950550592, 6.89461089213668, 5.991201722655317, 6.88507350516362, 7.905206761550335, 8.746916557814206, 9.81747087202001, 10.765366597569537, 11.698970576466873, 12.669854617795203, 13.637720370869163, 14.634229146241902, 15.568671293491686, 15.322014531164525, 14.396662211697354, 13.411470050021602, 12.445705757037615, 11.50633339184609, 10.512017806579774, 9.52453793490163, 8.633385741710327, 7.891439591278716, 6.918461161382414, 5.929022735982992, 6.831341571639507, 7.819200054656715, 8.792612272619282, 9.797618832357298, 10.771472124061635, 11.7006069714063, 12.714949588381835, 13.673852109561883, 14.61221330728185, 15.520698971140455, 15.384312149185629, 14.409177181904047, 13.417593238700293, 12.4939704171224, 11.450322254070985, 10.518407735814677, 9.641993774584941, 8.804301961942825, 7.877774383431455, 4.934866508517713, 5.90518137488137, 6.878330969892067, 7.811369822995059, 8.853870575350578, 9.764423604177171, 10.700745128594374, 11.660293723115112, 12.61668524909907, 13.577594530545246, 14.530140617548641, 15.465610747404252, 15.399204204907372, 14.3821856489418, 13.420708239103016, 12.51173402538285, 11.55371515214412, 10.628607747044057, 9.837125650111254, 8.904927975519593, 3.9616210822839317, 5.022856929818002, 5.925760240951767, 6.835943305512221, 7.8307660468952305, 8.825986926044118, 9.762594233698133, 10.705660330762846, 11.698053978531618, 12.731588834830944, 13.661439848048044, 14.688402562986784, 15.740194412229846, 15.387021217042397, 14.416819121724476, 13.472251443080392, 12.506588890881506, 11.613828419446055, 10.79784530976045, 9.952762012687328, 3.0077951950663273, 4.039612166475412, 4.9136589486187905, 5.876152659426429, 6.872515278659413, 7.838370402817194, 8.793203652730186, 9.766561494893667, 10.806110873474843, 11.833471635883452, 12.897652720992653, 13.933713982214268, 14.8508064771039, 15.778007390157775, 15.392513387529819, 14.436007847257857, 13.570388803293975, 12.637671506182274, 11.767530715585417, 10.888865721625946, 2.0084763494805946, 2.984466596422997, 3.969342169422525, 4.948618470216597, 5.908858076762594, 6.874562352162814, 7.927527051161276, 8.97430608801907, 9.950658128515661, 10.876361882403243, 11.92400112193144, 12.963686670764664, 13.908855385344634, 14.940565833614855, 15.865033191422022, 15.472974283581738, 14.584960436230055, 13.708078368870215, 12.738873772046448, 11.83407925086346, 1.0349101814820882, 2.0490486046030223, 3.0000159311630963, 3.945969903676269, 4.958283652722486, 5.942960496572336, 6.987286178008693, 7.946470409225909, 8.918864300605998, 9.899281736649446, 10.973354489634936, 12.01728745245881, 12.987045222610075, 13.918639330866963, 14.891242334044895, 15.956639850674724, 15.553399728121981, 14.636123153095179, 13.736418938582947, 12.810528837674099, 1.986543952651607, 2.960130853250214, 3.8994160474630544, 4.82702086948181, 5.809716531986125, 6.793532120050121, 7.76036080663405, 8.729502669986859, 9.745286035954733, 10.76923796179199, 11.712008729859782, 12.69099969078889, 13.639273897576354, 14.624911172254217, 15.679766637591625, 16.71381746426164, 16.51181577127245, 15.69858397595247, 14.726138405366516, 13.73958341627031, 2.9450383152424098, 4.002305635833036, 4.945681970811892, 5.849896968105856, 6.794704777844817, 7.7920135165211075, 8.757856090067406, 9.727347339995298, 10.725172395543181, 11.695842314637545, 12.674841565763098, 13.600873292663426, 14.620655965819369, 15.564471670487395, 16.504256798348834, 17.503842264279136, 17.49266004736478, 16.702291850226953, 15.681334002828757, 14.804116553568214, 3.872723948876586, 4.826092245709269, 5.8361880030567415, 6.818305610028083, 7.754912042519945, 8.741158094843778, 9.710803617053319, 10.692607436419875, 11.671812398772385, 12.70145848511457, 13.707723149387338, 14.588535364541007, 15.519456623668768, 16.545722787254665, 17.47647895341147, 18.480028361509167, 18.513630805399522, 17.650276433718236, 16.69908409856703, 15.865763416789902], [3.9769225340888603, 4.79312706851209, 5.831194111462876, 6.769065206353649, 7.838646011622167, 8.876589745000889, 9.83087263160882, 10.847941180684051, 11.748721699172393, 12.701130781194898, 13.74419372896683, 14.683912734060243, 15.613892419281289, 16.62435397892329, 17.567710199573522, 18.577033194606884, 18.31750767283213, 17.725094747229505, 16.750475730096277, 15.795105128677319, 2.905236776735838, 3.8502567348337813, 4.8065920459696425, 5.796584017211365, 6.829922361601946, 7.90276060143084, 8.87985943541689, 9.874967037850407, 10.820268260194633, 11.780833587973756, 12.713263169014883, 13.646081302828144, 14.698819981666148, 15.745594788399135, 16.792123694862333, 17.804721970278536, 17.280807862003776, 16.667436765129093, 15.700974865211982, 14.735863252377534, 1.8994549895191917, 2.8451829953461427, 3.8488291722222123, 4.879320229811993, 5.934255181350476, 6.915912307430268, 7.884720875978725, 8.860149367205079, 9.844376450272772, 10.8423019410493, 11.776670250500182, 12.836536731281672, 13.873660035728594, 14.923244596718684, 15.916361949987753, 16.930640692516636, 16.309534237361092, 15.599918936961263, 14.662306857264424, 13.787626838060609, 0.9314356819241071, 1.9005190170752184, 2.9376375975524547, 3.8820947340123553, 4.935463048267989, 5.928636180482727, 6.8855272934224026, 7.914561669061173, 8.95285435565656, 9.911035415787513, 10.954792994249228, 12.003951316525551, 13.052767468804657, 14.099435428573216, 15.173622408515076, 16.09966540448242, 15.372263142484723, 14.562064404487602, 13.69681467604204, 12.747026065339494, 0.0, 0.9702530221497894, 1.905948286423521, 2.9345593051721264, 3.993712818626261, 5.049926955509679, 6.120854669103943, 7.050422927888059, 8.061089405228918, 9.11403879078206, 10.14661687487, 11.203774419175872, 12.231172049421325, 13.261840961326248, 14.227904504277188, 15.209630524711374, 14.43476741872922, 13.487901378473774, 12.683671899088594, 11.763733281693082, 0.9843487538713767, 1.973700584252265, 2.8456965782036083, 3.8015902185156976, 4.823277847304388, 5.848164880404205, 6.8956976152432485, 7.871569747995781, 8.838157570764224, 9.780884519666648, 10.743291434291221, 11.678189467935868, 12.746770027735781, 13.759349631562912, 14.70844227051117, 14.556371995241417, 13.552487486987308, 12.552062718455588, 11.72083686059217, 10.76629072401568, 1.9395210348131884, 2.9791552427309744, 3.8408963245738392, 4.790595371832022, 5.768017377881465, 6.773235195280078, 7.698323146784777, 8.665181747650559, 9.660219997731023, 10.707267524101091, 11.739501936634337, 12.672668699750961, 13.693376571776879, 14.638458002378409, 14.550716891016837, 13.627050042814341, 12.626096664391087, 11.627043913575903, 10.731845433796067, 9.777852105794496, 2.9240752488318895, 3.935793228498081, 4.791270867793889, 5.753706163823419, 6.718789370081719, 7.70208860010334, 8.638179204039332, 9.614263193226442, 10.628025564086018, 11.56917052352584, 12.576057021722912, 13.552830700053896, 14.52343835228722, 14.553398921070016, 13.624627480844698, 12.659222306748843, 11.663182613297735, 10.684026382733705, 9.74097981771072, 8.759782221105892, 3.902725982733574, 4.906472498489107, 5.721315045943403, 6.69196544873813, 7.729749636660188, 8.634687464851009, 9.649317302721721, 10.61956242377735, 11.60655336391562, 12.509193169703355, 13.464321735570959, 14.399812587609466, 14.504005888967779, 13.596462026057681, 12.598753217853323, 11.639541390626455, 10.686090508287553, 9.7167948550764, 8.782288450214276, 7.748469986470742, 4.971690680253763, 5.92087392430431, 6.734277328344094, 7.647047264491894, 8.695730361445424, 9.68114479396181, 10.621424338159667, 11.624039515719929, 12.589850218300164, 13.531915921840215, 14.397523351735607, 14.497247328870792, 13.501040009316053, 12.524917532886368, 11.643026714274496, 10.711358682380094, 9.702848439553323, 8.749914618321437, 7.7410061006101145, 6.755824342684178, 5.915827678613812, 6.933444793963193, 7.8070718363340585, 8.619720170705188, 9.631020907330404, 10.56515685650834, 11.536040897836669, 12.50390665091063, 13.500415426283368, 14.519983048902326, 14.43825172856914, 13.489775676820592, 12.50458351514484, 11.538819222160853, 10.621204559773897, 9.734610356513352, 8.794049151253049, 7.844679322413717, 6.87013128401629, 5.828564903957082, 6.87187844779444, 7.837523425012621, 8.73478833949155, 9.667883021214617, 10.598768672542644, 11.492655308913578, 12.532066029812793, 13.476981207977044, 14.4427906802741, 14.615330976928389, 13.580391207998318, 12.61504342513762, 11.639908457856038, 10.566931740498175, 9.625306239563988, 8.740891009543343, 7.808976491287035, 6.8360712895391025, 5.795779260419411, 4.8692516819080405, 7.866034675259719, 8.763683621770758, 9.722215911353198, 10.649125470838841, 11.591913455909664, 12.49970382879804, 13.473898141764469, 14.433446736285207, 14.54162148163796, 13.580712200191785, 12.62816611318839, 11.69269598333278, 10.74842884591867, 9.724308422187121, 8.698568417583372, 7.749532692476168, 6.791513819237437, 5.849457317079986, 4.849899926320323, 3.93251952214258, 8.91823667029008, 9.820342979114118, 10.674786640293497, 11.624551988321679, 12.61501798436501, 13.438140506931093, 14.41204903666071, 14.83353805731165, 13.841144409542878, 12.807609553243553, 11.877758540026454, 10.928673217817353, 9.876881368574292, 8.808539370122713, 7.8383372748047915, 6.893769596160706, 5.928107043961821, 4.912854684839161, 3.8891802666711257, 2.8846854849748436, 9.872062557507684, 10.87523498021314, 11.686887932626474, 12.58434263440747, 13.580705253640453, 14.453848537894494, 15.038962594136846, 14.065604751973366, 13.02605537339219, 11.99869461098358, 10.93451352587438, 9.898452264652764, 8.903029660606219, 7.975828747552344, 6.918384827286933, 5.961879287014971, 4.953520624072304, 3.9892585744550932, 3.0072153297205144, 1.9485817760362263, 10.918225686900023, 11.894215933842425, 12.63120471182274, 13.511876823617303, 14.4721164301633, 15.265650628326028, 14.212685929327566, 13.16590689246977, 12.173048155644137, 11.227998863871193, 10.180359624342996, 9.140674075509772, 8.195505360929804, 7.163794912659582, 6.204697761072406, 5.164975202308826, 4.130688329893337, 3.1033956025561587, 2.035872273259483, 1.0033682467987122, 11.962036926824663, 12.84364157154136, 13.600530950082169, 14.514525390157631, 15.510651812464443, 15.952424132500735, 14.908098451064378, 13.948914219847161, 12.976520328467073, 11.996102892423625, 10.922030139438135, 9.878097176614263, 8.908339406462998, 7.97674529820611, 7.004142295028178, 5.938744778398348, 4.993534544484888, 3.936851207841677, 2.935663723300305, 1.8722252432005018, 12.913670697994181, 13.870796818246289, 14.67196032211606, 15.569517484293138, 16.552213146797452, 16.689129495966665, 15.722300809382737, 14.753158946029927, 13.737375580062054, 12.713423654224796, 11.770652886157004, 10.791661925227896, 9.843387718440432, 8.986690742771225, 7.931835277433818, 6.8977844507638, 5.857681580544575, 4.8487935389779615, 3.7878348108929183, 2.801279821796713, 13.88362253653557, 14.919424729092603, 15.718226245464898, 16.592393582917182, 17.537201392656144, 17.54291096600349, 16.577068392457193, 15.607577142529301, 14.609752086981418, 13.575335564365547, 12.596336313239995, 11.670304586339666, 10.650521913183724, 9.706706208515698, 8.76692108065426, 7.76733561472396, 6.757641144147662, 5.77789644511214, 4.7430304083551595, 3.865812959094616, 14.811308170169747, 15.764676467002431, 16.774772224349903, 17.611506980813353, 18.548113413305213, 18.49205554432616, 17.534740933146367, 16.57283723895388, 15.623007377751557, 14.639441307848232, 13.633176643575464, 12.628845456397801, 11.69792419727004, 10.690941887725119, 9.739143235716895, 8.742534851894575, 7.728917988432046, 6.711972839244639, 5.760780504093434, 4.927459822316304], [4.9471755562386495, 4.0217367428356185, 5.059803785786404, 5.926763380894096, 6.97430904122899, 7.928606666980885, 8.882889553588816, 9.899958102664048, 10.778468677022603, 11.730877759045109, 12.77394070681704, 13.713659711910454, 14.6436393971315, 15.6541009567735, 16.597457177423735, 17.606780172457096, 17.636566319599428, 16.85194157926901, 16.25401363435929, 16.765358150827108, 3.875489798885627, 3.0788664091573095, 4.035201720293171, 4.954282191751812, 5.951183741828294, 6.954777523410836, 7.909606413267101, 8.904714015700618, 9.850015238044843, 10.810580565823967, 11.743010146865094, 12.675828280678354, 13.728566959516359, 14.775341766249346, 15.821870672712546, 16.834468948128748, 17.89886145075002, 17.63768978727888, 16.671227887361773, 15.706116274527323, 2.869708011668981, 2.073792669669671, 2.9773099632698647, 3.9264605350695208, 4.981395486608004, 5.9567597134318016, 6.914467853828936, 7.8898963450552895, 8.874123428122983, 9.87204891889951, 10.80641722835039, 11.866283709131881, 12.903407013578803, 13.952991574568893, 14.946108927837962, 15.960387670366845, 16.997368856755603, 16.57017195911105, 15.632559879414213, 14.757879860210398, 1.9016887040738966, 1.0109913248366678, 1.9673845754026653, 2.911841711862566, 3.9652100261182, 4.958383158332937, 5.915274271272613, 6.9443086469113835, 7.982601333506772, 8.940782393637724, 9.984539972099437, 11.03369829437576, 12.082514446654866, 13.129182406423425, 14.203369386365285, 15.129412382332628, 16.060097761879234, 15.532317426637391, 14.667067698191829, 13.717279087489283, 0.9702530221497894, 0.0, 0.9356952642737317, 1.964306283022337, 3.0234597964764713, 4.079673933359889, 5.150601646954153, 6.080169905738269, 7.090836383079127, 8.143785768632268, 9.17636385272021, 10.233521397026081, 11.260919027271534, 12.291587939176457, 13.257651482127397, 14.239377502561583, 15.292928731410248, 14.458154400623563, 13.653924921238383, 12.73398630384287, 1.954601776021166, 1.0034475621024757, 1.875443556053819, 2.831337196365908, 3.8530248251545975, 4.877911858254416, 5.925444593093459, 6.901316725845992, 7.867904548614436, 8.810631497516859, 9.773038412141432, 10.707936445786078, 11.776517005585992, 12.789096609413123, 13.738189248361381, 14.701459323433806, 14.522740509137098, 13.522315740605377, 12.69108988274196, 11.73654374616547, 2.909774056962978, 2.0626383009068627, 2.8706433024240496, 3.820342349682232, 4.797764355731675, 5.802982173130288, 6.7280701246349865, 7.69492872550077, 8.689966975581232, 9.737014501951302, 10.769248914484548, 11.702415677601172, 12.72312354962709, 13.66820498022862, 14.62843987511251, 14.597303064964132, 13.596349686540877, 12.597296935725693, 11.702098455945857, 10.748105127944285, 3.8943282709816787, 3.0192762866739695, 3.8210178456441, 4.78345314167363, 5.748536347931929, 6.73183557795355, 7.667926181889542, 8.644010171076651, 9.657772541936227, 10.598917501376048, 11.605803999573121, 12.582577677904105, 13.55318533013743, 14.513041060382132, 14.594880502994489, 13.629475328898634, 12.633435635447526, 11.654279404883495, 10.711232839860509, 9.730035243255681, 4.872979004883363, 3.989955556664995, 4.751062023793613, 5.721712426588341, 6.7594966145103985, 7.664434442701219, 8.679064280571932, 9.64930940162756, 10.63630034176583, 11.538940147553564, 12.494068713421168, 13.429559565459675, 14.363579187857098, 14.56671504820747, 13.569006240003114, 12.609794412776246, 11.656343530437344, 10.687047877226188, 9.752541472364065, 8.71872300862053, 5.941943702403552, 5.052999862260756, 5.764024306194305, 6.676794242342105, 7.725477339295635, 8.71089177181202, 9.651171316009878, 10.65378649357014, 11.619597196150375, 12.561662899690425, 13.427270329585816, 14.453759009454453, 14.471293031465843, 13.495170555036157, 12.613279736424285, 11.681611704529885, 10.673101461703112, 9.720167640471226, 8.711259122759904, 7.726077364833968, 6.886080700763602, 6.065570731919639, 6.836818814184269, 7.649467148555399, 8.660767885180615, 9.59490383435855, 10.56578787568688, 11.53365362876084, 12.530162404133579, 13.549730026752536, 14.450176089756601, 14.460028698970381, 13.47483653729463, 12.509072244310643, 11.591457581923686, 10.704863378663141, 9.764302173402838, 8.814932344563505, 7.840384306166079, 6.798817926106871, 7.8421314699442295, 7.139435921830467, 7.764535317341761, 8.697629999064826, 9.628515650392854, 10.52240228676379, 11.561813007663003, 12.506728185827255, 13.472537658124311, 14.49376993287229, 14.550644230148109, 13.58529644728741, 12.610161480005829, 11.537184762647964, 10.595559261713777, 9.711144031693133, 8.779229513436825, 7.806324311688892, 6.7660322825692, 5.83950470405783, 8.836287697409508, 8.065596118588605, 8.751962889203408, 9.67887244868905, 10.621660433759875, 11.529450806648253, 12.503645119614681, 13.46319371413542, 14.419585240119378, 14.550965222341574, 13.59841913533818, 12.662949005482568, 11.71868186806846, 10.69456144433691, 9.668821439733161, 8.719785714625957, 7.761766841387226, 6.8197103392297755, 5.820152948470112, 4.902772544292369, 9.888489692439869, 9.122255475931965, 9.704533618143708, 10.654298966171888, 11.644764962215222, 12.467887484781306, 13.441796014510922, 14.453120017516756, 14.811397431692669, 13.777862575393344, 12.848011562176245, 11.89892623996714, 10.84713439072408, 9.778792392272502, 8.80859029695458, 7.8640226183104955, 6.89836006611161, 5.88310770698895, 4.859433288820915, 3.8549385071246327, 10.842315579657473, 10.177147477030987, 10.716634910476685, 11.614089612257679, 12.610452231490662, 13.483595515744707, 14.411186595478869, 15.035857774123157, 13.99630839554198, 12.968947633133372, 11.90476654802417, 10.868705286802555, 9.873282682756008, 8.946081769702133, 7.888637849436722, 6.93213230916476, 5.923773646222093, 4.959511596604882, 3.9774683518703036, 2.9188347981860154, 11.888478709049812, 11.232293047083402, 11.66095168967295, 12.541623801467512, 13.50186340801351, 14.531637808211613, 15.182938951477354, 14.136159914619558, 13.143301177793925, 12.19825188602098, 11.150612646492783, 10.110927097659559, 9.165758383079591, 8.13404793480937, 7.1749507832221955, 6.135228224458615, 5.100941352043126, 4.073648624705948, 3.0061252954092725, 1.9736212689485015, 12.932289948974452, 12.181718684782338, 12.63027792793238, 13.54427236800784, 14.540398790314653, 15.46323966380209, 15.878351473214169, 14.919167241996952, 13.946773350616864, 12.966355914573416, 11.892283161587926, 10.848350198764052, 9.878592428612787, 8.946998320355899, 7.974395317177967, 6.908997800548137, 5.963787566634678, 4.907104229991467, 3.905916745450095, 2.8424782653502914, 13.88392372014397, 13.208873931487267, 13.701707299966271, 14.599264462143347, 15.581960124647663, 16.40260926546763, 16.692553831532525, 15.723411968179716, 14.707628602211843, 13.683676676374585, 12.740905908306793, 11.761914947377685, 10.813640740590222, 9.956943764921016, 8.902088299583609, 7.868037472913591, 6.827934602694366, 5.819046561127752, 4.758087833042708, 3.7715328439465026, 14.85387555868536, 14.25750184233358, 14.747973223315109, 15.622140560767393, 16.566948370506353, 17.401090661938614, 17.547321414606984, 16.577830164679092, 15.580005109131209, 14.545588586515338, 13.566589335389786, 12.640557608489457, 11.620774935333515, 10.676959230665489, 9.737174102804051, 8.73758863687375, 7.727894166297452, 6.74814946726193, 5.71328343050495, 4.836065981244406, 15.781561192319536, 15.227223109574075, 15.808845307116183, 16.64125395866356, 17.577860391155422, 17.53870623928293, 16.59484713775646, 15.642245695138767, 14.6646432329672, 13.749546582198247, 12.74328191792548, 11.761262936573084, 10.866822823809638, 9.863962089147796, 8.912163437139572, 7.926555370924164, 6.914796068803293, 5.985681997115732, 5.0344896619645265, 5.897712844466094], [5.882870820512381, 4.95743200710935, 4.148096276445562, 4.991068116620363, 6.038613776955258, 6.992911402707153, 7.947194289315085, 8.964262838390317, 9.842773412748873, 10.795182494771378, 11.83824544254331, 12.777964447636723, 13.707944132857769, 14.718405692499768, 15.661761913150002, 16.671084908183364, 16.700871055325695, 15.91624631499528, 16.717844939795672, 17.49323188219127, 4.811185063159359, 4.014561673431041, 3.107930623764786, 4.018586927478079, 5.0154884775545625, 6.019082259137105, 6.973911148993368, 7.969018751426886, 8.914319973771113, 9.874885301550236, 10.807314882591363, 11.740133016404624, 12.792871695242628, 13.839646501975615, 14.886175408438815, 15.898773683855017, 16.963166186476286, 16.973904297095693, 17.57491873494706, 16.537475151254935, 3.8054032759427128, 3.0094879339434026, 2.041614698996133, 2.990765270795789, 4.045700222334272, 5.02106444915807, 5.978772589555204, 6.954201080781558, 7.938428163849251, 8.936353654625778, 9.870721964076658, 10.930588444858149, 11.96771174930507, 13.01729631029516, 14.01041366356423, 15.024692406093113, 16.061673592481874, 17.049274281543575, 16.5362507269995, 15.638091664452249, 2.8373839683476283, 1.9466865891103995, 1.0316893111289336, 1.9761464475888344, 3.029514761844468, 4.022687894059206, 4.979579006998882, 6.008613382637652, 7.0469060692330405, 8.005087129363993, 9.048844707825708, 10.098003030102031, 11.146819182381137, 12.193487142149696, 13.267674122091556, 14.193717118058899, 15.124402497605503, 16.115890562250115, 15.57075854577712, 14.620969935074573, 1.905948286423521, 0.9356952642737317, 0.0, 1.0286110187486053, 2.0877645322027396, 3.143978669086157, 4.214906382680422, 5.144474641464537, 6.155141118805395, 7.208090504358537, 8.240668588446479, 9.29782613275235, 10.325223762997805, 11.355892674902728, 12.321956217853668, 13.303682238287854, 14.357233467136519, 15.304099507391964, 14.557615768823673, 13.63767715142816, 2.8902970402948975, 1.921772594132655, 0.9397482917800872, 1.8956419320921765, 2.9173295608808663, 3.9422165939806844, 4.9897493288197285, 5.965621461572261, 6.932209284340705, 7.874936233243128, 8.837343147867701, 9.772241181512348, 10.840821741312261, 11.853401345139392, 12.80249398408765, 13.765764059160075, 14.769648567414183, 14.44858543076293, 13.59478073032725, 12.64023459375076, 3.8454693212367093, 2.9347130289274337, 1.9349480381503181, 2.884647085408501, 3.8620690914579434, 4.867286908856556, 5.792374860361255, 6.759233461227038, 7.754271711307501, 8.801319237677571, 9.833553650210817, 10.766720413327441, 11.787428285353359, 12.732509715954889, 13.69274461083878, 14.657959153940828, 14.53204495081461, 13.523566625883246, 12.605789303531147, 11.651795975529575, 4.83002353525541, 3.8681893834173797, 2.8853225813703682, 3.847757877399898, 4.812841083658197, 5.796140313679818, 6.73223091761581, 7.70831490680292, 8.722077277662496, 9.663222237102318, 10.67010873529939, 11.646882413630374, 12.617490065863699, 13.577345796108402, 14.538359756353321, 14.565170593172367, 13.569130899721259, 12.580549095041048, 11.636441400961122, 10.633726090840971, 5.808674269157095, 4.793390684936756, 3.8153667595198817, 4.786017162314609, 5.823801350236667, 6.728739178427487, 7.7433690162982, 8.713614137353828, 9.700605077492098, 10.603244883279833, 11.558373449147437, 12.493864301185944, 13.427883923583368, 14.405114784642684, 14.504701504276847, 13.545489677049979, 12.592038794711076, 11.622743141499921, 10.677750033464678, 9.643931569721143, 6.791759431550904, 5.842576187500358, 4.828329041920574, 5.741098978068372, 6.789782075021902, 7.775196507538287, 8.715476051736145, 9.718091229296407, 10.683901931876642, 11.625967635416693, 12.491575065312086, 13.518063745180722, 14.430849803235093, 14.430865819309888, 13.548975000698016, 12.617306968803618, 11.608796725976845, 10.655862904744959, 9.646954387033636, 8.6617726291077, 7.735896429910953, 6.8551470571592406, 5.901123549910539, 6.713771884281666, 7.725072620906882, 8.659208570084818, 9.630092611413147, 10.597958364487107, 11.594467139859846, 12.614034762478804, 13.51448082548287, 14.462956877231418, 14.41053180156836, 13.444767508584373, 12.527152846197417, 11.640558642936874, 10.69999743767657, 9.750627608837238, 8.77607957043981, 7.734513190380603, 8.691947199091581, 7.816698536085238, 6.82884005306803, 7.761934734791095, 8.692820386119122, 9.586707022490057, 10.62611774338927, 11.571032921553522, 12.536842393850579, 13.558074668598557, 14.460430897936732, 14.52099171156114, 13.545856744279558, 12.472880026921695, 11.531254525987508, 10.646839295966865, 9.714924777710557, 8.742019575962624, 7.701727546842932, 6.775199968331561, 9.68610342655686, 8.742858732843375, 7.816267624929678, 8.743177184415318, 9.685965169486142, 10.59375554237452, 11.567949855340949, 12.527498449861687, 13.483889975845646, 14.444799257291821, 14.53411439961191, 13.5986442697563, 12.65437713234219, 11.630256708610641, 10.604516704006892, 9.655480978899687, 8.697462105660957, 7.755405603503507, 6.755848212743844, 5.838467808566101, 10.73830542158722, 9.715008943485836, 8.768838353869977, 9.718603701898155, 10.709069697941489, 11.532192220507573, 12.50610075023719, 13.517424753243024, 14.44100316502205, 14.713557839667077, 13.783706826449977, 12.834621504240873, 11.782829654997812, 10.714487656546234, 9.744285561228313, 8.799717882584227, 7.8340553303853415, 6.818802971262682, 5.795128553094647, 4.790633771398364, 11.692131308804825, 10.769900944584858, 9.780939646202954, 10.678394347983946, 11.67475696721693, 12.547900251470974, 13.475491331205136, 14.448849173368616, 14.932003659815713, 13.904642897407104, 12.840461812297903, 11.804400551076288, 10.808977947029742, 9.881777033975867, 8.824333113710455, 7.867827573438492, 6.859468910495826, 5.895206860878615, 4.913163616144035, 3.854530062459747, 12.710313221221034, 11.734322974278632, 10.72525642539922, 11.60592853719378, 12.566168143739777, 13.59594254393788, 14.501972662061338, 15.07185517889329, 14.078996442067657, 13.133947150294713, 12.086307910766516, 11.046622361933292, 10.101453647353322, 9.069743199083101, 8.110646047495926, 7.070923488732346, 6.036636616316857, 5.0093438889796795, 3.941820559683004, 2.909316533222233, 13.659688413339657, 12.645549990218722, 11.694582663658649, 12.608577103734108, 13.60470352604092, 14.527544399528358, 15.450788372098783, 15.854862506270685, 14.882468614890596, 13.902051178847149, 12.827978425861659, 11.784045463037785, 10.81428769288652, 9.882693584629632, 8.9100905814517, 7.84469306482187, 6.8994828309084095, 5.842799494265199, 4.841612009723827, 3.778173529624023, 14.611322184509175, 13.672705236923651, 12.76601203569254, 13.663569197869615, 14.64626486037393, 15.466914001193894, 16.388796212705245, 16.659107232453447, 15.643323866485575, 14.619371940648318, 13.676601172580526, 12.697610211651417, 11.749336004863954, 10.892639029194747, 9.83778356385734, 8.803732737187321, 7.763629866968097, 6.754741825401483, 5.693783097316439, 4.707228108220234, 15.581274023050565, 14.721333147769965, 13.812277959041378, 14.68644529649366, 15.631253106232622, 16.46539539766488, 16.616824414171905, 15.671810527289614, 14.742203259463608, 13.73328602818938, 12.754286777063827, 11.828255050163499, 10.832291160457938, 9.888475455789912, 8.948690327928475, 7.987415543610089, 7.000071562564305, 6.138704385906788, 6.64897869477868, 5.771761245518137, 16.50895965668474, 15.69105441501046, 14.873150042842452, 15.70555869438983, 16.642165126881693, 16.603010975009198, 15.659151873482731, 14.706550430865036, 13.728947968693468, 12.813851317924517, 11.807586653651748, 10.825567672299353, 9.931127559535907, 8.928266824874063, 7.9764681728658395, 6.990860106650432, 5.97910080452956, 5.087498335878137, 5.970184926238258, 6.833408108739825], [6.857929418529196, 5.879173524785366, 4.917453647388058, 3.9624570978717584, 5.010002758206653, 5.964300383958548, 6.91858327056648, 7.935651819641713, 8.814162394000267, 9.766571476022772, 10.809634423794703, 11.749353428888117, 12.679333114109163, 13.689794673751162, 14.633150894401396, 15.642473889434758, 15.936648672035293, 16.865852844906666, 17.735250226938003, 18.510637169333602, 5.839796081907965, 4.936303191107057, 3.979967879971196, 2.989975908729474, 3.9868774588059575, 4.9904712403885, 5.945300130244764, 6.940407732678281, 7.885708955022507, 8.84627428280163, 9.778703863842757, 10.711521997656018, 11.764260676494022, 12.811035483227009, 13.857564389690209, 14.870162665106411, 15.93455516772768, 16.90063400819837, 17.924368468252265, 17.554880438397266, 4.834014294691318, 3.996291486513034, 2.9926453096369645, 1.9621542520471837, 3.0170892035856665, 3.9924534304094648, 4.950161570806599, 5.925590062032953, 6.9098171451006465, 7.907742635877174, 8.842110945328056, 9.901977426109546, 10.939100730556468, 11.988685291546558, 12.981802644815627, 13.99608138734451, 15.033062573733268, 16.02066326279497, 16.980143882614477, 16.65549695159458, 3.8659949870962333, 2.9752976078590048, 2.0071346952206746, 0.9475354288402291, 2.000903743095863, 2.9940768753106006, 3.9509679882502766, 4.980002363889047, 6.0182950504844355, 6.976476110615388, 8.020233689077102, 9.069392011353425, 10.11820816363253, 11.16487612340109, 12.23906310334295, 13.165106099310293, 14.095791478856897, 15.08727954350151, 16.014651701392093, 15.638375222216904, 2.9345593051721264, 1.964306283022337, 1.0286110187486053, 0.0, 1.0591535134541346, 2.115367650337552, 3.1862953639318166, 4.115863622715932, 5.12653010005679, 6.1794794856099315, 7.2120575696978735, 8.269215114003746, 9.296612744249199, 10.327281656154122, 11.293345199105062, 12.275071219539248, 13.328622448387913, 14.275488488643358, 15.311536687837611, 14.655082438570492, 3.918908059043503, 2.939177881274987, 1.957153578922419, 1.0012599386103298, 1.9985597045211878, 3.023446737621006, 4.070979472460049, 5.046851605212582, 6.013439427981026, 6.9561663768834485, 7.918573291508021, 8.853471325152668, 9.922051884952582, 10.934631488779713, 11.883724127727971, 12.846994202800396, 13.850878711054506, 14.851303479586226, 14.61218601746958, 13.657639880893091, 4.874080339985315, 3.952118316069766, 2.95235332529265, 1.9902650919266542, 2.943299235098265, 3.948517052496878, 4.873605004001576, 5.8404636048673595, 6.835501854947823, 7.882549381317892, 8.914783793851138, 9.847950556967762, 10.86865842899368, 11.81373985959521, 12.7739747544791, 13.739189297581149, 14.768829933231265, 14.540971913025578, 13.623194590673478, 12.669201262671907, 5.8586345540040154, 4.885594670559712, 3.9027278685127005, 3.036903079501001, 3.894071227298519, 4.87737045732014, 5.813461061256132, 6.789545050443242, 7.803307421302818, 8.74445238074264, 9.751338878939713, 10.728112557270697, 11.698720209504021, 12.658575939748724, 13.619589899993644, 14.670706153887604, 14.597741918469861, 13.59795438218338, 12.653846688103453, 11.651131377983303, 6.8372852879057, 5.810795972079088, 4.832772046662214, 4.021794779024207, 4.928402874870811, 5.809969322067809, 6.824599159938521, 7.794844280994149, 8.781835221132418, 9.684475026920156, 10.63960359278776, 11.575094444826266, 12.50911406722369, 13.486344928283007, 14.514542526378204, 14.574100695798581, 13.620649813459679, 12.651354160248525, 11.69515532060701, 10.661336856863475, 7.809164718693236, 6.859981474642689, 5.845734329062905, 4.97687659477797, 5.945303034750754, 6.857378044206342, 7.7967061953764665, 8.799321372936728, 9.765132075516963, 10.707197779057013, 11.572805208952408, 12.599293888821045, 13.512079946875415, 14.4882024233051, 14.577586019446622, 13.64591798755222, 12.637407744725449, 11.684473923493563, 10.67556540578224, 9.690383647856304, 8.753301717053285, 7.872552344301572, 6.91852883705287, 5.949549500991264, 6.880593580635734, 7.81472952981367, 8.785613571142, 9.75347932421596, 10.725986968919965, 11.695264906119125, 12.595710969123193, 13.54418702087174, 14.52784344897525, 14.47337852733298, 13.555763864946023, 12.669169661685478, 11.728608456425174, 10.779238627585842, 9.804690589188414, 8.763124209129208, 9.709352486233913, 8.83410382322757, 7.846245340210362, 6.9977123515006925, 7.848341345847974, 8.742227982218909, 9.781638703118123, 10.726553881282374, 11.690853653471622, 12.65172289232896, 13.541661041577054, 14.507008824437753, 14.574467763028164, 13.501491045670301, 12.559865544736114, 11.67545031471547, 10.743535796459161, 9.770630594711228, 8.730338565591536, 7.803810987080166, 10.703508713699192, 9.760264019985708, 8.833672912072009, 7.978954801124916, 8.841486129214994, 9.74927650210337, 10.723470815069799, 11.683019409590537, 12.639410935574496, 13.600320217020672, 14.532219395168868, 14.627255288504905, 13.682988151090797, 12.658867727359247, 11.633127722755498, 10.684091997648293, 9.726073124409563, 8.784016622252112, 7.784459231492449, 6.867078827314706, 11.755710708729552, 10.732414230628168, 9.786243641012309, 8.954381318607753, 9.864590657670341, 10.687713180236424, 11.66162170996604, 12.672945712971874, 13.5965241247509, 14.575784966354867, 14.812317845198583, 13.863232522989476, 12.811440673746414, 11.743098675294837, 10.772896579976916, 9.828328901332831, 8.862666349133946, 7.847413990011287, 6.823739571843252, 5.8192447901469695, 12.709536595947156, 11.78730623172719, 10.798344933345286, 9.914171964693544, 10.866371463655792, 11.703421211199824, 12.631012290933986, 13.604370133097467, 14.533905602280264, 14.93325391615571, 13.869072831046509, 12.833011569824894, 11.837588965778348, 10.910388052724473, 9.852944132459061, 8.8964385921871, 7.888079929244432, 6.9238178796272205, 5.941774634892641, 4.883141081208352, 13.727718508363365, 12.751728261420963, 11.742661712541551, 10.841706153903377, 11.801945760449374, 12.756687829051321, 13.657493621790188, 14.588219839953085, 15.107607460816263, 14.162558169043319, 13.114918929515122, 12.075233380681897, 11.130064666101928, 10.098354217831707, 9.139257066244532, 8.099534507480952, 7.065247635065463, 6.0379549077282855, 4.97043157843161, 3.9379275519708385, 14.677093700481988, 13.662955277361053, 12.71198795080098, 11.844354720443706, 12.840481142750518, 13.688289684641799, 14.606309331827633, 15.56549356304485, 15.63368420016738, 14.653266764123932, 13.678868622862094, 12.700918111615046, 11.73116034146378, 10.893931616779719, 9.921328613601787, 8.855931096971958, 7.910720863058498, 6.871410513013803, 5.870223028472431, 4.806784548372628, 15.628727471651507, 14.690110524065982, 13.783417322834872, 12.899346814579213, 13.882042477083528, 14.627659286307335, 15.544317172434095, 15.67101465409146, 14.655231288123586, 13.631279362286328, 12.722171220206997, 11.74438623627381, 10.796112029486347, 9.93175194576991, 8.980671417480412, 7.96176242361842, 6.952304819908029, 7.783352844150087, 6.722394116065043, 5.7358391269688385, 16.598679310192896, 15.738738434912296, 14.82968324618371, 13.922222913203258, 14.86703072294222, 15.62614068277832, 15.5882133954233, 14.643199508541008, 13.713592240715002, 12.704675009440773, 11.725675758315221, 10.799644031414893, 9.803680141709334, 8.859864437041308, 7.92007930917987, 6.958804524861484, 5.9714605438157, 6.908061756849284, 7.677589713527285, 6.800372264266741, 17.526364943827073, 16.70845970215279, 15.890555329984783, 14.941336311099429, 15.87794274359129, 15.574399956260592, 14.630540854734125, 13.67793941211643, 12.700336949944862, 11.78524029917591, 10.778975634903142, 9.796956653550748, 8.902516540787303, 7.899655806125457, 6.9478571541172345, 5.962249087901827, 4.950489785780955, 5.856855706820633, 6.808048041971837, 7.83330429886952], [7.893508793445205, 6.914752899701376, 5.953033022304067, 4.998036472787767, 4.015342238655596, 4.924252170614285, 5.8785350572222175, 6.895603606297449, 7.774114180656003, 8.726523262678509, 9.76958621045044, 10.709305215543854, 11.639284900764899, 12.649746460406899, 13.593102681057132, 14.602425676090494, 15.654212009420856, 16.58341618229223, 17.601884554080637, 18.559824499538745, 6.898949595362097, 5.9718825660230666, 5.015547254887205, 4.025555283645483, 2.992216939254901, 3.9504230270442364, 4.9052519169005, 5.9003595193340175, 6.845660741678243, 7.806226069457367, 8.738655650498494, 9.671473784311754, 10.724212463149758, 11.770987269882745, 12.817516176345945, 13.830114451762148, 14.894506954383417, 15.860585794854105, 16.884320254907998, 17.88548042596605, 5.893167808145452, 5.055444999967168, 4.051798823091099, 3.0213077655013185, 2.02242868403461, 2.9524052170652015, 3.9101133574623357, 4.885541848688689, 5.869768931756383, 6.86769442253291, 7.802062731983791, 8.861929212765281, 9.899052517212203, 10.948637078202292, 11.941754431471361, 12.956033174000243, 13.993014360389004, 14.980615049450705, 15.940095669270216, 16.937244011649124, 4.9251485005503675, 4.034451121313139, 3.0662882086748096, 2.006688942294364, 0.9608555297515997, 1.9540286619663374, 2.9109197749060134, 3.939954150544784, 4.978246837140173, 5.936427897271125, 6.980185475732839, 8.029343798009162, 9.078159950288267, 10.124827910056826, 11.199014889998686, 12.12505788596603, 13.055743265512634, 14.047231330157246, 14.974603488047832, 15.953264269870022, 3.9937128186262605, 3.0234597964764713, 2.0877645322027396, 1.0591535134541346, 0.0, 1.0562141368834175, 2.1271418504776824, 3.0567101092617976, 4.067376586602656, 5.120325972155797, 6.152904056243739, 7.2100616005496105, 8.237459230795064, 9.268128142699988, 10.234191685650927, 11.215917706085113, 12.269468934933778, 13.216334975189223, 14.252383174383477, 15.183127493837342, 4.912852092884282, 3.8990117625204, 2.916987460167832, 1.9610938198557428, 0.9394061910670531, 1.9642932241668714, 3.011825959005915, 3.9876980917584475, 4.954285914526892, 5.897012863429315, 6.859419778053887, 7.794317811698534, 8.862898371498448, 9.875477975325579, 10.824570614273837, 11.787840689346261, 12.791725197600371, 13.792149966132092, 14.735588674951833, 14.520891270401073, 5.868024373826094, 4.848033783693951, 3.848268792916835, 2.873543042317717, 1.8841457216441304, 2.8893635390427432, 3.8144514905474423, 4.781310091413225, 5.776348341493688, 6.823395867863758, 7.855630280397003, 8.788797043513627, 9.809504915539545, 10.754586346141075, 11.714821241024966, 12.680035784127014, 13.70967641977713, 14.717168771011776, 14.48644598018146, 13.532452652179888, 6.78304880292609, 5.748846060067693, 4.765979258020682, 3.803543961991152, 2.8349177138443844, 3.8182169438660054, 4.754307547801997, 5.730391536989107, 6.744153907848683, 7.685298867288505, 8.692185365485578, 9.668959043816562, 10.639566696049886, 11.59942242629459, 12.560436386539509, 13.61155264043347, 14.644536578664706, 14.461205771691361, 13.517098077611434, 12.514382767491284, 7.746760786447977, 6.6740473615870695, 5.696023436170195, 4.788435661514358, 3.869249361416676, 4.750815808613674, 5.765445646484387, 6.735690767540015, 7.7226817076782845, 8.625321513466021, 9.580450079333625, 10.515940931372132, 11.449960553769555, 12.427191414828872, 13.45538901292407, 14.414600840150937, 14.484366163025264, 13.515070509814109, 12.55840671011499, 11.524588246371456, 8.672416108201217, 7.7232328641506705, 6.7089857185708865, 5.743517477268121, 4.88614952129662, 5.798224530752208, 6.737552681922332, 7.740167859482593, 8.70597856206283, 9.64804426560288, 10.513651695498273, 11.54014037536691, 12.45292643342128, 13.429048909850966, 14.422484769937332, 14.5867273601968, 13.546883243267727, 12.593949422035841, 11.585040904324519, 10.599859146398583, 9.616553106561266, 8.735803733809552, 7.781780226560851, 6.716190383481415, 5.8214400671816, 6.7555760163595355, 7.726460057687864, 8.694325810761823, 9.666833455465833, 10.636111392664992, 11.536557455669058, 12.485033507417606, 13.468689935521116, 14.41514722057648, 14.54990209954342, 13.609979034330058, 12.653429886361172, 11.70406005752184, 10.714166087730693, 9.672599707671486, 10.572603875741894, 9.69735521273555, 8.709496729718342, 7.764353233990843, 6.789187832393839, 7.683074468764774, 8.722485189663987, 9.667400367828238, 10.63170014001749, 11.592569378874828, 12.48250752812292, 13.447855310983618, 14.4229902782652, 14.495629280267698, 13.554003779333511, 12.61625968736005, 11.684345169103741, 10.711439967355808, 9.639814064133814, 8.713286485622444, 11.566760103207173, 10.623515409493688, 9.69347192771208, 8.745595683615067, 7.782332615760859, 8.690122988649236, 9.664317301615664, 10.623865896136403, 11.580257422120361, 12.541166703566537, 13.473065881714733, 14.383934208086597, 14.596110783011724, 13.653005961956644, 12.627265957352895, 11.67823023224569, 10.72021135900696, 9.77815485684951, 8.778597466089845, 7.856968293588562, 12.618962098237533, 11.592213246268239, 10.64604265665238, 9.721022201097904, 8.805437144216206, 9.628559666782289, 10.602468196511905, 11.61379219951774, 12.537370611296765, 13.516631452900732, 14.446482466117832, 14.598227055112464, 13.605082256269231, 12.737236909892234, 11.767034814574313, 10.822467135930228, 9.856804583731343, 8.841552224608684, 7.817877806440649, 6.8133830247443665, 13.572787985455138, 12.64710524736726, 11.658143948985357, 10.680812847183695, 9.807217950201657, 10.64426769774569, 11.571858777479852, 12.545216619643332, 13.47475208882613, 14.502112851234738, 14.59590113113899, 13.559839869917376, 12.56441726587083, 11.904604273646926, 10.847160353381515, 9.890654813109553, 8.882296150166885, 7.918034100549674, 6.935990855815096, 5.877279315805749, 14.587517524003436, 13.611527277061034, 12.602460728181622, 11.608347036393528, 10.846863625309936, 11.697534315597187, 12.598340108336053, 13.52906632649895, 14.418311061802308, 14.590298696533466, 13.607320437524757, 12.567634888691533, 11.622466174111564, 10.941550460791879, 9.982453309204704, 8.998501577125817, 8.124401148519597, 7.097108421182419, 6.029585091885743, 4.997081065424973, 15.522055325128038, 14.507916902007103, 13.55694957544703, 12.610995602933857, 11.88539900761108, 12.629136171187664, 13.547155818373499, 14.506340049590715, 14.593635986823116, 13.613218550779669, 12.63882040951783, 11.660869898270782, 10.691112128119517, 9.957250777220958, 9.008662451827577, 7.958109947339569, 8.90332018125303, 7.930564026467938, 6.929376541926565, 5.865938061826762, 16.47368909629756, 15.53287771330096, 14.59359251908812, 13.665987697069363, 12.936495779969217, 13.5685057728532, 14.48516365897996, 14.630966440747196, 13.615183074779322, 12.591231148942065, 11.682123006862733, 10.704338022929546, 9.756063816142083, 8.891703732425647, 7.940623204136148, 6.967101904067363, 7.954682751979054, 8.842506357604222, 7.781547629519178, 6.794992640422973, 17.443640934838946, 16.581505624147272, 15.639472931381606, 14.68886379569341, 13.997113764215849, 14.566987169324186, 14.548165182079037, 13.603151295196744, 12.673544027370738, 11.66462679609651, 10.685627544970957, 9.759595818070629, 8.76363192836507, 7.819816223697044, 6.880031095835607, 5.964144005310427, 6.9738384758867245, 7.943641131765293, 8.73674322698142, 7.859525777720876, 18.371326568473123, 17.551226891387767, 16.69009480056092, 15.70797719358958, 15.045213419922078, 14.534351742916328, 13.590492641389861, 12.637891198772166, 11.660288736600599, 10.745192085831647, 9.738927421558879, 8.756908440206484, 7.8624683274430405, 6.859607592781195, 5.907808940772972, 4.96758856835077, 5.981205431813299, 6.892435081736641, 7.843627416887847, 8.86888367378553], [8.891088774972914, 7.9123328812290845, 6.9506130038317755, 5.995616454315476, 5.012922220183305, 4.01019849303161, 4.964481379639542, 5.981549928714774, 6.860060503073328, 7.812469585095834, 8.855532532867764, 9.795251537961178, 10.725231223182224, 11.735692782824223, 12.679049003474457, 13.688371998507819, 14.740158331838181, 15.669362504709552, 16.68783087649796, 17.645770821956066, 7.9267563819207885, 6.969462547550775, 6.013127236414914, 5.023135265173192, 3.98979692078261, 3.0363693494615616, 3.9911982393178254, 4.986305841751342, 5.931607064095568, 6.892172391874691, 7.8246019729158185, 8.757420106729079, 9.810158785567083, 10.85693359230007, 11.90346249876327, 12.916060774179472, 13.955567368353927, 14.921646208824615, 15.945380668878508, 16.87675980928829, 6.949381945028869, 6.109080851566652, 5.105434674690583, 4.074943617100802, 3.020008665562319, 2.0383515394825267, 2.996059679879661, 3.971488171106014, 4.9557152541737075, 5.92406546139437, 6.858433770845251, 7.918300251626742, 8.955423556073663, 10.005008117063753, 10.998125470332822, 12.012404212861703, 12.984293743711245, 13.971894432772945, 14.931375052592456, 15.928523394971364, 5.981362637433785, 5.090665258196556, 4.122502345558226, 3.062903079177781, 2.017069666635017, 1.0399749843836623, 1.9968660973233385, 2.949680051828, 3.9879727384233883, 4.946153798554341, 5.989911377016055, 7.039069699292378, 8.087885851571484, 9.134553811340043, 10.208740791281903, 11.11633726928827, 12.047022648834874, 13.038510713479486, 13.965882871370072, 14.944543653192262, 5.049926955509678, 4.079673933359889, 3.143978669086157, 2.115367650337552, 1.0562141368834175, 0.0, 1.070927713594265, 2.0004959723783804, 3.0111624497192384, 4.06411183527238, 5.096689919360322, 6.153847463666193, 7.181245093911647, 8.21191400581657, 9.17797754876751, 10.159703569201696, 11.213254798050361, 12.160120838305806, 13.19616903750006, 14.126913356953924, 5.969066229767699, 4.955225899403818, 3.9732015970512498, 3.0173079567391605, 1.9956203279504705, 0.9890769763882133, 2.023841122687277, 2.999713255439809, 3.9663010782082533, 4.9090280271106765, 5.871434941735249, 6.806332975379895, 7.87491353517981, 8.887493139006942, 9.8365857779552, 10.799855853027625, 11.803740361281733, 12.804165129813454, 13.747603838633195, 14.814427064217568, 6.924238510709511, 5.903012019555481, 4.903247028778366, 3.9285212781792485, 2.939123957505662, 1.933906140107049, 2.858994091611748, 3.8258526924775307, 4.820890942557994, 5.83541103154512, 6.867645444078365, 7.800812207194989, 8.821520079220909, 9.766601509822438, 10.72683640470633, 11.692050947808378, 12.721691583458494, 13.729183934693138, 14.681529385322913, 14.58743088804142, 7.838027038787621, 6.803824295929225, 5.820957493882213, 4.858522197852683, 3.889895949705916, 2.9971432002083613, 3.8615204814388786, 4.837604470625989, 5.826397546318274, 6.767542505758096, 7.774429003955168, 8.740146422385168, 9.710754074618492, 10.670609804863195, 11.631623765108115, 12.659878683873876, 13.684605634551845, 14.672201465535336, 14.572076313472966, 13.569361003352816, 8.801739022309508, 7.729025597448601, 6.751001672031727, 5.843413897375889, 4.9242275972782075, 3.92974206495603, 4.872658580121268, 5.842903701176896, 6.829894641315166, 7.707565151935611, 8.662693717803215, 9.598184569841722, 10.532204192239146, 11.509435053298462, 12.53763265139366, 13.496844478620527, 14.45029536095943, 14.57004874567564, 13.613384945976522, 12.579566482232988, 9.727394344062748, 8.778211100012202, 7.763963954432418, 6.798495713129652, 5.941127757158151, 4.977150787094564, 5.844765615559213, 6.847380793119474, 7.81319149569971, 8.735770940129536, 9.595895333967864, 10.6223840138365, 11.535170071890871, 12.511292548320556, 13.504728408406923, 14.453788709987869, 14.601861479129258, 13.648927657897373, 12.64001914018605, 11.654837382260114, 10.671531342422798, 9.790781969671084, 8.836758462422383, 7.771168619342946, 6.876418303043131, 5.978395350783581, 6.9091995002836395, 7.877065253357599, 8.774046389102713, 9.723838067191647, 10.618801094138648, 11.567277145887196, 12.550933573990706, 13.497390859046071, 14.010176365298026, 14.66495727019159, 13.708408122222703, 12.759038293383371, 11.769144323592224, 10.727577943533017, 11.627582111603425, 10.752333448597081, 9.764474965579874, 8.819331469852376, 7.844166068255371, 6.905893803188819, 7.905224632259762, 8.850139810424015, 9.73891307365437, 10.680296053401483, 11.56475116659251, 12.530098949453208, 13.50523391673479, 13.955903546022304, 13.014278045088117, 13.67123792322158, 12.739323404965273, 11.76641820321734, 10.694792299995346, 9.768264721483975, 12.621738339068704, 11.67849364535522, 10.748450163573613, 9.8005739194766, 8.83731085162239, 7.912942323073282, 8.887136636039711, 9.84668523056045, 10.796079934117182, 11.714914830138087, 12.555309520184323, 13.466177846556187, 13.682057105429049, 13.020772800820632, 12.087540223107501, 12.73444436912911, 11.77642549589038, 10.834368993732928, 9.834811602973264, 8.911946529450093, 13.673940334099065, 12.647191482129772, 11.701020892513913, 10.776000436959437, 9.846599880355223, 8.851379001206334, 9.825287530935952, 10.836611533941786, 11.753193123293586, 12.690379579472282, 13.568000124005298, 13.684173377529788, 12.691028578686556, 11.99166471756453, 11.02146262224661, 11.878681272813646, 10.91301872061476, 9.897766361492101, 8.874091943324066, 7.869597161627784, 14.62776622131667, 13.702083483228794, 12.71312218484689, 11.735791083045228, 10.832942156327515, 9.867087032169735, 10.794678111903899, 11.76803595406738, 12.690574600822949, 13.717935363231557, 13.681847453556315, 12.6457861923347, 11.650363588288155, 11.06759052979399, 10.010146609528578, 10.94686894999297, 9.938510287050303, 8.974248237433091, 7.992204992698513, 6.9334934526891665, 15.152096922788106, 14.666505512922567, 13.657438964043155, 12.663325272255062, 11.872587831435794, 10.920353650021232, 11.821159442760099, 12.751885660922998, 13.634133573799128, 13.676245018950791, 12.693266759942082, 11.653581211108857, 10.708412496528888, 10.027496783209203, 9.068399631622029, 9.996081558653525, 9.180615285403015, 8.153322558065836, 7.085799228769161, 6.05329520230839, 15.97945383467435, 15.562895137868637, 14.611927811308563, 13.66597383879539, 12.83663234946156, 11.85195550561171, 12.769975152797544, 13.72915938401476, 13.679582309240441, 12.699164873196993, 11.724766731935155, 10.746816220688107, 9.777058450536842, 9.043197099638283, 8.094608774244902, 8.955689928867278, 9.900900162780738, 8.986778163351355, 7.985590678809983, 6.9221521987101795, 16.93108760584387, 16.587855949162492, 15.648570754949652, 14.720965932930897, 13.775140695341241, 12.791325107277245, 13.707982993404006, 13.71691276316452, 12.701129397196647, 11.67717747135939, 10.768069329280058, 9.79028434534687, 8.842010138559408, 7.977650054842972, 7.026569526553473, 7.964681885595072, 8.952262733506764, 9.89872049448764, 8.837761766402595, 7.85120677730639, 17.83296093749266, 17.636483860008806, 16.694451167243137, 15.743842031554943, 14.835758679587872, 13.789806503748231, 13.634111504496362, 12.689097617614069, 11.759490349788063, 10.750573118513834, 9.771573867388282, 8.845542140487954, 7.849578250782395, 6.905762546114369, 5.9659774182529315, 6.961723986838136, 7.971418457414433, 8.941221113293002, 9.792957363864836, 8.913688145449218, 18.528324903468498, 17.574956606635816, 16.564860849288344, 15.582743242317003, 14.64613680982514, 13.620298065333653, 12.676438963807186, 11.723837521189491, 10.746235059017923, 9.831138408248973, 8.824873743976205, 7.8428547626238085, 6.948414649860365, 5.94555391519852, 4.993755263190296, 5.965168549878479, 6.978785413341008, 7.89001506326435, 8.841207398415555, 9.86646365531324], [9.77494201190908, 8.79618611816525, 7.834466240767942, 6.879469691251643, 5.896775457119473, 4.894051729967778, 4.0037352689013215, 4.971080048300183, 5.815709365235329, 6.7681184472578355, 7.811181395029767, 8.75090040012318, 9.680880085344226, 10.691341644986226, 11.63469786563646, 12.644020860669821, 13.695807194000183, 14.625011366871554, 15.643479738659963, 16.60141968411807, 8.810609618856954, 7.853315784486942, 6.896980473351081, 5.906988502109359, 4.873650157718777, 3.9202225863977294, 2.9612692503746407, 3.941954703913343, 4.887255926257569, 5.847821254036693, 6.78025083507782, 7.713068968891081, 8.765807647729085, 9.812582454462072, 10.859111360925272, 11.871709636341475, 12.884639654759662, 13.85071849523035, 14.874452955284243, 15.805832095694024, 7.9386620943297705, 6.992934088502819, 5.98928791162675, 4.95879685403697, 3.9038619024984866, 2.9222047764186945, 1.9661306909364762, 2.9271370332680147, 3.911364116335708, 4.8531377478001065, 5.7875060572509875, 6.847372538032478, 7.884495842479399, 8.934080403469489, 9.927197756738558, 10.941476499267441, 11.913366030116979, 12.90096671917868, 13.86044733899819, 14.857595681377099, 7.043357706126666, 6.074274370975554, 5.029968934170647, 3.9703696677902016, 2.917001353534568, 1.9238282213198303, 0.9669371083801541, 1.8787523382337348, 2.9170450248291235, 3.875226084960076, 4.91898366342179, 5.968141985698113, 7.016958137977219, 8.063626097745779, 9.137813077687639, 10.045409555694004, 10.976094935240608, 11.96758299988522, 12.894955157775806, 13.873615939597997, 6.120854669103943, 5.150601646954154, 4.2149063826804225, 3.186295363931817, 2.1271418504776824, 1.070927713594265, 0.0, 0.9295682587841153, 1.9402347361249737, 2.993184121678115, 4.025762205766057, 5.0829197500719285, 6.110317380317382, 7.140986292222305, 8.107049835173244, 9.08877585560743, 10.142327084456095, 11.08919312471154, 12.125241323905794, 13.055985643359659, 6.998779078849101, 5.98493874848522, 5.002914446132652, 4.047020805820563, 3.0253331770318734, 2.0004461439320553, 0.9529134090930117, 1.928785541845544, 2.895373364613988, 3.8381003135164113, 4.800507228140984, 5.735405261785631, 6.803985821585545, 7.816565425412676, 8.765658064360935, 9.728928139433359, 10.732812647687467, 11.733237416219188, 12.676676125038929, 13.743499350623303, 7.843009908900267, 6.803375700982481, 5.803610710205366, 4.828884959606248, 3.8394876389326615, 2.8342698215340483, 1.9091818700293492, 2.876040470895132, 3.8399244812009465, 4.764483317950854, 5.796717730484099, 6.729884493600723, 7.750592365626643, 8.695673796228172, 9.655908691112064, 10.621123234214112, 11.650763869864228, 12.658256221098872, 13.610601671728647, 14.564594999730218, 8.738390720214621, 7.7041879773562245, 6.721321175309213, 5.758885879279683, 4.7902596311329155, 3.8477988637924723, 2.9117082598564803, 3.8877922490435903, 4.845431084961227, 5.749450686130571, 6.756337184327645, 7.669218708790902, 8.639826361024227, 9.59968209126893, 10.56069605151385, 11.58895097027961, 12.61367792095758, 13.60127375194107, 14.545381446020997, 14.469724684779816, 9.702102703736509, 8.629389278875601, 7.6513653534587265, 6.743777578802889, 5.792728756184584, 4.780397728540141, 3.9228463585388695, 4.8930914795944975, 5.8800824197327675, 6.689473332308087, 7.64460189817569, 8.580092750214197, 9.51411237261162, 10.491343233670937, 11.519540831766134, 12.478752658993002, 13.432203541331905, 14.40149919454306, 14.513748627403523, 13.479930163659988, 10.627758025489749, 9.678574781439202, 8.664327635859419, 7.698859394556653, 6.809628916064527, 5.827806450678674, 4.894953393976815, 5.897568571537076, 6.863379274117312, 7.717679120502012, 8.577803514340339, 9.604292194208975, 10.517078252263346, 11.493200728693031, 12.486636588779398, 13.435696890360344, 14.48595013612252, 14.549291339324373, 13.54038282161305, 12.555201063687115, 11.571895023849798, 10.691145651098084, 9.737122143849383, 8.671532300769947, 7.744919461949507, 6.829051014367691, 5.959387278701241, 6.927253031775201, 7.824234167520315, 8.705746247564123, 9.600709274511123, 10.549185326259671, 11.532841754363181, 12.479299039418546, 13.418671404610071, 14.412445216227088, 14.608771803649704, 13.659401974810372, 12.669508005019225, 11.627941624960018, 12.527945793030426, 11.652697130024082, 10.664838647006874, 9.717673786899763, 8.712667227161747, 7.756549466772929, 6.955412410677364, 7.900327588841616, 8.789100852071972, 9.66220423377396, 10.546659346964985, 11.512007129825683, 12.487142097107265, 13.299730268583193, 13.898131282024286, 14.571601604648581, 13.639687086392273, 12.66678188464434, 11.595155981422346, 10.668628402910976, 13.522102020495705, 12.57885732678222, 11.646792480621, 10.698916236523987, 9.705812010528767, 8.763597986657391, 7.95527425348929, 8.91482284801003, 9.846267712534784, 10.696823010510563, 11.537217700556798, 12.448086026928662, 12.817825908178746, 12.335137858341687, 12.97139346004367, 13.6441406516246, 12.68612177838587, 11.744065276228419, 10.744507885468755, 9.812310210877094, 14.574304015526065, 13.545533799177159, 12.5993632095613, 11.674342754006824, 10.697255543939333, 9.702034664790444, 8.89342514838553, 9.904749151391364, 10.803380901711188, 11.672287759844759, 12.549908304377773, 12.819942180279487, 11.826797381436252, 11.306029775085586, 11.905315859182778, 12.814261790914173, 11.942731569696162, 10.927479210573503, 9.903804792405468, 8.899310010709186, 14.770559204365817, 14.60042580027618, 13.611464501894277, 12.634133400092615, 11.683597819911625, 10.717742695753845, 9.862815729353477, 10.836173571516957, 11.74076237924055, 12.74703722377782, 12.76734358810057, 11.781554995084399, 10.786132391037851, 10.305979908865671, 10.893999846464746, 11.850505386736709, 10.968223136131705, 10.003961086514494, 9.021917841779915, 7.963206301770569, 14.08116920919384, 15.057159456136242, 14.555781281090542, 13.561667589302449, 12.723243495019904, 11.771009313605342, 10.889297060209678, 11.820023278372576, 12.68432135221673, 12.631893881112791, 11.719651266428087, 10.789350013858552, 9.844181299278585, 9.25682631554273, 9.952252868558197, 10.879934795589694, 10.25154299899728, 9.224250271660102, 8.156726942363427, 7.1242229159026556, 14.908526121080085, 15.92266454420102, 15.51027012835595, 14.564316155842777, 13.68728801304567, 12.70261116919582, 11.838112770247124, 12.79729700146434, 12.635231171402442, 11.654813735358994, 10.680415594097155, 9.839053614632927, 8.912827253286538, 8.20221622511732, 8.97846201118107, 9.839543165803446, 10.784753399716907, 10.048773232044237, 9.047585747502865, 7.984147267403061, 15.860159892249603, 16.83374679284821, 16.536096843448423, 15.608492021429667, 14.625796358925351, 13.641980770861355, 12.776120610853585, 12.672561625326521, 11.656778259358648, 10.63282633352139, 9.723718191442059, 8.819840689095509, 7.977778941309104, 7.136669180322009, 7.910422763489641, 8.84853512253124, 9.836115970442933, 10.828782224503652, 9.863869490320083, 8.877314501223877, 16.762033223898392, 17.455730032241856, 16.494192750948457, 15.54358361526026, 14.5987758055213, 13.525091505818324, 12.589760366658364, 11.644746479776071, 10.715139211950065, 9.706221980675835, 8.727222729550283, 7.801191002649954, 6.9853470535320925, 6.064781671593407, 6.849830655189099, 7.8455772237743036, 8.855271694350602, 9.825074350229169, 10.738711793578618, 9.797541382385383, 17.483973765630502, 16.53060546879782, 15.520509711450346, 14.538392104479005, 13.601785671987143, 12.575946927495654, 11.632087825969188, 10.679486383351493, 9.701883921179926, 8.786787270410974, 7.780522606138206, 6.79850362478581, 5.9379447694457745, 5.0578089327595634, 5.877608500126464, 6.849021786814647, 7.862638650277176, 8.773868300200517, 9.725060635351722, 10.750316892249405], [10.704510270693195, 9.725754376949366, 8.764034499552059, 7.8090379500357585, 6.8263437159035885, 5.823619988751893, 4.933303527685437, 4.0415117895160675, 4.886141106451214, 5.838550188473721, 6.881613136245651, 7.821332141339065, 8.75131182656011, 9.76177338620211, 10.705129606852344, 11.714452601885705, 12.766238935216068, 13.695443108087439, 14.713911479875847, 15.671851425333953, 9.74017787764107, 8.782884043271057, 7.826548732135197, 6.836556760893474, 5.803218416502893, 4.849790845181844, 3.8908375091587564, 3.012386445129228, 3.957687667473454, 4.918252995252577, 5.850682576293704, 6.783500710106965, 7.83623938894497, 8.883014195677958, 9.929543102141158, 10.94214137755736, 11.955071395975546, 12.921150236446234, 13.944884696500127, 14.876263836909908, 8.868230353113885, 7.922502347286935, 6.918856170410866, 5.888365112821085, 4.833430161282602, 3.8517730352028097, 2.895698949720592, 1.9975687744838995, 2.981795857551593, 3.9235694890159905, 4.857937798466871, 5.917804279248362, 6.954927583695283, 8.004512144685371, 8.99762949795444, 10.011908240483322, 10.983797771332863, 11.971398460394564, 12.930879080214075, 13.928027422592983, 7.9729259649107815, 7.00384262975967, 5.9595371929547625, 4.899937926574317, 3.8465696123186834, 2.8533964801039455, 1.8965053671642695, 0.9491840794496195, 1.987476766045008, 2.9456578261759603, 3.9894154046376746, 5.038573726913997, 6.087389879193103, 7.134057838961663, 8.208244818903523, 9.115841296909888, 10.046526676456493, 11.038014741101104, 11.96538689899169, 12.944047680813881, 7.050422927888058, 6.080169905738269, 5.144474641464537, 4.115863622715932, 3.0567101092617976, 2.0004959723783804, 0.9295682587841153, 0.0, 1.0106664773408582, 2.063615862894, 3.0961939469819413, 4.153351491287813, 5.180749121533267, 6.211418033438189, 7.177481576389129, 8.159207596823315, 9.21275882567198, 10.159624865927425, 11.195673065121678, 12.126417384575543, 7.928347337633217, 6.914507007269336, 5.932482704916768, 4.976589064604679, 3.9549014358159886, 2.9300144027161705, 1.882481667877127, 1.0310232843465637, 1.9976111071150078, 2.940338056017431, 3.902744970642003, 4.837643004286649, 5.906223564086564, 6.918803167913696, 7.867895806861954, 8.831165881934378, 9.835050390188488, 10.83547515872021, 11.77891386753995, 12.845737093124324, 8.772578167684383, 7.7329439597665965, 6.733178968989481, 5.758453218390364, 4.769055897716777, 3.763838080318164, 2.838750128813465, 2.0295880365344896, 2.9421622237019665, 3.866721060451874, 4.898955472985119, 5.832122236101743, 6.8528301081276615, 7.797911538729191, 8.758146433613081, 9.72336097671513, 10.753001612365246, 11.760493963599894, 12.712839414229668, 13.66683274223124, 9.667958978998737, 8.63375623614034, 7.650889434093329, 6.688454138063799, 5.719827889917031, 4.777367122576588, 3.841276518640596, 3.0635418982526628, 3.9476688274622465, 4.851688428631591, 5.858574926828664, 6.771456451291922, 7.742064103525246, 8.70191983376995, 9.662933794014869, 10.691188712780628, 11.715915663458597, 12.703511494442091, 13.647619188522018, 14.656371296649988, 10.631670962520623, 9.558957537659715, 8.580933612242841, 7.6733458375870045, 6.722297014968699, 5.7099659873242565, 4.852414617322985, 4.114182458472408, 5.010105210760198, 5.791711074809107, 6.7468396406767095, 7.682330492715217, 8.61635011511264, 9.593580976171957, 10.621778574267154, 11.580990401494022, 12.534441283832924, 13.503736937044078, 14.460400736743196, 14.409498422444102, 11.557326284273863, 10.608143040223316, 9.593895894643532, 8.628427653340768, 7.739197174848643, 6.757374709462789, 5.8245216527609305, 5.1186595504149865, 5.993402065144743, 6.819916863003032, 7.680041256841359, 8.706529936709996, 9.619315994764365, 10.59543847119405, 11.588874331280417, 12.537934632861365, 13.588187878623541, 14.47061717379904, 14.469951080397164, 13.484769322471228, 12.501463282633912, 11.620713909882198, 10.666690402633497, 9.601100559554062, 8.674487720733623, 7.758619273151806, 6.888955537485357, 6.1627742298141435, 6.954256958547745, 7.807983990065144, 8.702947017012145, 9.651423068760693, 10.6350794968642, 11.581536781919565, 12.520909147111091, 13.514682958728109, 14.537333041742693, 14.588970233594486, 13.599076263803338, 12.557509883744132, 13.45751405181454, 12.582265388808196, 11.594406905790988, 10.647242045683878, 9.642235485945863, 8.686117725557045, 7.88498066946148, 7.135848786880558, 7.919123643099401, 8.76444197627498, 9.648897089466006, 10.614244872326704, 11.589379839608286, 12.553424263582244, 13.49504976451643, 14.508402305698118, 14.569255345176387, 13.596350143428454, 12.52472424020646, 11.59819666169509, 14.451670279279819, 13.508425585566334, 12.576360739405116, 11.628484495308102, 10.635380269312883, 9.693166245441507, 8.884842512273405, 8.204835568796167, 8.976290503562215, 9.799060753011585, 10.63945544305782, 11.550323769429683, 11.88825764939463, 12.812922994783627, 13.820094607706338, 14.573708910408715, 13.615690037169985, 12.673633535012534, 11.67407614425287, 10.74187846966121, 14.688897148125339, 14.475102057961275, 13.528931468345416, 12.60391101279094, 11.626823802723449, 10.63160292357456, 9.822993407169646, 9.247719993760612, 9.933403692738619, 10.77452550234578, 11.652146046878794, 11.890373921495371, 10.897229122652137, 11.783814911527525, 12.754017006845446, 13.698584685489532, 12.872299828480278, 11.857047469357619, 10.833373051189584, 9.828878269493302, 13.872796946866838, 14.933680358545507, 14.541032760678393, 13.563701658876731, 12.613166078695741, 11.64731095453796, 10.792383988137592, 10.186818829629791, 10.870785170267983, 11.849274966278841, 11.837775329316454, 10.851986736300283, 9.856564132253736, 10.78376504530761, 11.802993941220919, 12.759499481492881, 11.89779139491582, 10.93352934529861, 9.951486100564031, 8.892774560554685, 13.151600950409724, 14.127591197352126, 15.136657746231538, 14.491235848086564, 13.65281175380402, 12.700577572389458, 11.818865318993794, 11.17066853648541, 11.814344143244162, 11.702325622328676, 10.790083007643972, 9.859781755074437, 8.91461304049447, 9.94632348876469, 10.86124696331437, 11.809503054373808, 11.181111257781394, 10.153818530444216, 9.086295201147541, 8.05379117468677, 13.97895786229597, 14.993096285416904, 15.944063611976977, 15.493884414626892, 14.616856271829786, 13.632179427979935, 12.76768102903124, 12.229250229987857, 11.705662912618326, 10.725245476574878, 9.75084733531304, 8.909485355848814, 7.983258994502423, 8.914853102759311, 9.887456105937243, 10.76911142458756, 11.71432165850102, 10.97834149082835, 9.977154006286979, 8.913715526187175, 14.930591633465488, 15.904178534064094, 16.48812071609226, 15.560515894073506, 14.57782023156919, 13.594004643505194, 12.661262365533643, 11.742993366542406, 10.727210000574532, 9.703258074737274, 8.794149932657943, 7.890272430311395, 7.048210682524989, 8.033847957202852, 8.839991022273756, 9.778103381315354, 10.765684229227046, 11.758350483287767, 10.793437749104196, 9.80688276000799, 15.832464965114276, 16.52616177345774, 15.564624492164342, 14.614015356476145, 13.669207546737184, 12.595523247034208, 11.660192107874249, 10.715178220991955, 9.78557095316595, 8.77665372189172, 7.797654470766168, 6.8716227438658395, 6.055778794747977, 6.994349930377522, 7.779398913973214, 8.775145482558418, 9.784839953134716, 10.754642609013285, 11.668280052362734, 10.727109641169498, 16.554405506846386, 15.601037210013704, 14.59094145266623, 13.60882384569489, 12.672217413203027, 11.646378668711538, 10.702519567185073, 9.749918124567378, 8.77231566239581, 7.857219011626859, 6.850954347354091, 5.868935366001695, 5.008376510661659, 5.987377191543679, 6.807176758910579, 7.778590045598762, 8.792206909061292, 9.703436558984633, 10.654628894135838, 11.67988515103352], [11.715176748034054, 10.736420854290225, 9.774700976892918, 8.819704427376617, 7.8370101932444465, 6.834286466092752, 5.943970005026295, 4.980285513915033, 3.9712502854143015, 4.923659367436808, 5.96505015385204, 6.866340789544623, 7.796320474765669, 8.806782034407668, 9.750138255057902, 10.759461250091263, 11.811247583421626, 12.740451756292996, 13.758920128081405, 14.716860073539511, 10.750844354981929, 9.793550520611916, 8.837215209476055, 7.847223238234333, 6.813884893843751, 5.860457322522703, 4.901503986499614, 3.9880980687807672, 3.0427968464365414, 3.963261643458135, 4.895691224499262, 5.828509358312523, 6.881248037150528, 7.928022843883515, 8.974551750346716, 9.973192758415806, 10.944404918634687, 11.910483759105375, 12.934218219159268, 13.86559735956905, 9.878896830454744, 8.933168824627794, 7.929522647751725, 6.899031590161943, 5.84409663862346, 4.862439512543668, 3.9063654270614503, 3.0082352518247575, 2.060888223727988, 2.9454554185132924, 3.8798237279641734, 4.939690208745664, 5.976813513192585, 7.026398074182675, 8.019515427451744, 9.033794169980627, 9.973131293992004, 10.960731983053705, 11.920212602873216, 12.917360945252124, 8.983592442251641, 8.01450910710053, 6.970203670295621, 5.910604403915175, 4.8572360896595415, 3.864062957444804, 2.907171844505128, 1.9598505567904776, 1.00936269554231, 1.9675437556732622, 3.0113013341349766, 4.060459656411299, 5.1092758086904055, 6.155908836401145, 7.217842968359186, 8.10517481956903, 9.035860199115634, 10.027348263760246, 10.954720421650832, 11.933381203473022, 8.061089405228916, 7.090836383079127, 6.155141118805395, 5.12653010005679, 4.067376586602656, 3.0111624497192384, 1.9402347361249737, 1.0106664773408582, 0.0, 1.0529493855531415, 2.0855274696410833, 3.142685013946955, 4.170082644192409, 5.200751556097331, 6.166815099048271, 7.148541119482456, 8.20209234833112, 9.148958388586566, 10.18500658778082, 11.115750907234684, 8.939013814974075, 7.925173484610194, 6.943149182257626, 5.987255541945537, 4.965567913156847, 3.940680880057029, 2.8931481452179852, 2.0077506997721777, 1.0411628770037336, 1.9838898259061568, 2.946296740530729, 3.8811947741753756, 4.94977533397529, 5.962354937802422, 6.91144757675068, 7.874717651823104, 8.878602160077214, 9.879026928608935, 10.822465637428676, 11.88928886301305, 9.78324464502524, 8.743610437107455, 7.743845446330338, 6.769119695731221, 5.779722375057634, 4.7745045576590215, 3.849416606154323, 2.980752243671155, 1.985713993590692, 2.9102728303406, 3.9425072428738446, 4.875674005990469, 5.8963818780163875, 6.841463308617917, 7.801698203501808, 8.766912746603856, 9.796553382253972, 10.80404573348862, 11.756391184118394, 12.710384512119965, 10.678625456339592, 9.644422713481196, 8.661555911434185, 7.699120615404656, 6.730494367257888, 5.788033599917446, 4.851942995981454, 4.004982968210548, 2.9912205973509725, 3.895240198520317, 4.90212669671739, 5.815008221180648, 6.785615873413972, 7.745471603658676, 8.706485563903595, 9.734740482669354, 10.759467433347323, 11.747063264330817, 12.691170958410744, 13.699923066538714, 11.64233743986148, 10.569624015000572, 9.591600089583698, 8.68401231492786, 7.7329634923095565, 6.7206324646651145, 5.863081094663843, 5.040647920787194, 4.053656980648924, 4.835262844697833, 5.7903914105654355, 6.725882262603943, 7.659901885001367, 8.637132746060683, 9.66533034415588, 10.624542171382748, 11.57799305372165, 12.547288706932804, 13.503952506631922, 14.537770970375457, 12.56799276161472, 11.618809517564173, 10.60456237198439, 9.639094130681624, 8.7498636521895, 7.768041186803648, 6.8351881301017885, 6.045125012729772, 5.036953835033469, 5.863468632891758, 6.723593026730085, 7.750081706598722, 8.662867764653093, 9.638990241082778, 10.632426101169145, 11.581486402750091, 12.631739648512267, 13.514168943687766, 14.523077461399089, 14.495435799812086, 13.51212975997477, 12.631380387223055, 11.677356879974354, 10.611767036894918, 9.68515419807448, 8.769285750492665, 7.899622014826216, 6.994317503809209, 5.997808728436471, 6.85153575995387, 7.746498786900871, 8.694974838649419, 9.678631266752928, 10.625088551808293, 11.564460916999819, 12.558234728616835, 13.58088481163142, 14.525095734847502, 14.609742741144196, 13.568176361084989, 14.468180529155397, 13.592931866149053, 12.605073383131845, 11.657908523024735, 10.65290196328672, 9.696784202897904, 8.89564714680234, 7.928484885285185, 6.962675412988127, 7.807993746163707, 8.692448859354732, 9.65779664221543, 10.632931609497012, 11.596976033470972, 12.538601534405158, 13.551954075586844, 14.483868593843152, 14.607016620769311, 13.535390717547317, 12.608863139035947, 14.647545730822825, 14.519092062907191, 13.587027216745973, 12.63915097264896, 11.64604674665374, 10.703832722782366, 9.895508989614266, 8.9762337994349, 8.01984227345094, 8.84261252290031, 9.683007212946546, 10.59387553931841, 11.538142676732518, 12.561568443712478, 13.465339356385774, 14.41437508149298, 14.62635651451084, 13.68430001235339, 12.684742621593726, 11.752544947002065, 13.732448918014065, 14.793684765548134, 14.539597945686273, 13.614577490131797, 12.637490280064307, 11.642269400915419, 10.833659884510507, 9.969349110396116, 8.976955462627345, 9.818077272234506, 10.69569781676752, 11.114637691844266, 11.772674256189093, 12.659260045064482, 13.629462140382403, 14.574029819026489, 13.882966305821135, 12.867713946698476, 11.844039528530441, 10.839544746834159, 12.916348716755564, 13.977232128434233, 15.018611371855522, 14.574368136217588, 13.6238325560366, 12.65797743187882, 11.803050465478453, 10.908447946265296, 9.914336940156709, 10.892826736167567, 10.922884508279541, 10.076250506649178, 10.732009265790692, 11.659210178844567, 12.678439074757875, 13.634944615029838, 12.908457872256678, 11.944195822639466, 10.962152577904888, 9.903441037895542, 12.140934473068866, 13.116924720011268, 14.12599126889068, 15.177830171818744, 14.663478231144879, 13.711244049730317, 12.829531796334653, 11.850754649958521, 10.857895913132888, 10.787434801291763, 9.875192186607059, 9.0488407731844, 9.790058174031426, 10.821768622301647, 11.736692096851327, 12.776414655614907, 12.191777735122251, 11.164485007785073, 10.096961678488398, 9.064457652027627, 12.96829138495511, 13.982429808076045, 14.933397134636119, 15.575373486272357, 14.56305973722614, 13.57838289337629, 12.644278854345663, 11.763165982961501, 10.790772091581413, 9.810354655537965, 8.835956514276127, 7.9945945348119, 8.85870412803938, 9.790298236296268, 10.7629012394742, 11.77977790192842, 12.72498813584188, 11.989007968169211, 10.98782048362784, 9.924382003528036, 13.919925156124629, 14.893512056723235, 15.533129364297821, 14.605524542279065, 13.62282887977475, 12.639013291710754, 11.706271013739201, 10.828102545505493, 9.812319179537619, 8.788367253700361, 7.87925911162103, 6.975381609274482, 7.923655816061944, 8.909293090739807, 9.850657499614615, 10.788769858656213, 11.776350706567905, 12.769016960628626, 11.804104226445055, 10.81754923734885, 14.821798487773417, 15.571170421663302, 14.609633140369901, 13.659024004681704, 12.714216194942743, 11.640531895239768, 10.705200756079806, 9.760186869197515, 8.830579601371507, 7.8617629008548064, 6.882763649729255, 5.956731922828927, 6.932368088178861, 7.876183792846887, 8.790065391314073, 9.785811959899277, 10.795506430475575, 11.765309086354144, 12.678946529703593, 11.737776118510357, 15.599414155051946, 14.646045858219262, 13.635950100871788, 12.653832493900447, 11.717226061408585, 10.691387316917098, 9.74752821539063, 8.794926772772937, 7.817324310601368, 6.942328190589946, 5.936063526317178, 4.954044544964782, 5.884965804092543, 6.911231967678438, 7.817843236251438, 8.78925652293962, 9.80287338640215, 10.714103036325492, 11.665295371476697, 12.69055162837438], [12.768126133587195, 11.789370239843366, 10.82765036244606, 9.872653812929759, 8.889959578797587, 7.879617928760141, 6.925335042152209, 5.908266493076977, 4.899231264576246, 4.049263349918139, 5.012001008213266, 5.913291643905849, 6.843271329126895, 7.853732888768895, 8.79708910941913, 9.806412104452491, 10.858198437782853, 11.787402610654224, 12.805870982442633, 13.763810927900739, 11.80379374053507, 10.846499906165057, 9.890164595029196, 8.900172623787475, 7.866834279396892, 6.913406708075844, 5.945125897383257, 4.916079047942711, 3.970777825598485, 3.0102124978193614, 3.9426420788604886, 4.875460212673749, 5.928198891511754, 6.9749736982447414, 8.02150260470794, 9.00695132198651, 9.891455533081546, 10.857534373552234, 11.881268833606127, 12.81264797401591, 10.931846216007886, 9.986118210180935, 8.982472033304866, 7.9519809757150846, 6.897046024176602, 5.9153888980968095, 4.9499873379450925, 3.974558846718739, 2.990331763651046, 1.9924062728745189, 2.9267745823254, 3.9734487723163685, 5.01057207676329, 6.060156637753379, 7.053273991022447, 8.06755273355133, 8.920181908438863, 9.907782597500564, 10.867263217320076, 11.864411559698985, 10.036541827804783, 9.067458492653671, 8.023153055848763, 6.963553789468317, 5.910185475212683, 4.917012342997945, 3.9601212300582693, 3.01096835676083, 1.972675670165441, 1.0144946100344887, 1.962143913164752, 3.011302235441075, 4.0601183877201805, 5.102959450848004, 6.1648935828060445, 7.052225434015888, 7.982910813562493, 8.974398878207106, 9.901771036097692, 10.880431817919883, 9.114038790782057, 8.143785768632268, 7.208090504358537, 6.1794794856099315, 5.120325972155797, 4.06411183527238, 2.993184121678115, 2.063615862894, 1.0529493855531415, 0.0, 1.0325780840879417, 2.0897356283938135, 3.1171332586392673, 4.14780217054419, 5.113865713495129, 6.095591733929314, 7.1491429627779794, 8.096009003033425, 9.132057202227678, 10.062801521681543, 9.868831792811955, 8.854991462448073, 7.872967160095505, 6.917073519783416, 5.895385890994726, 4.870498857894908, 3.8229661230558647, 2.8470939903033323, 1.8805061675348882, 0.9377792186324649, 1.9001861332570371, 2.8350841669016837, 3.9036647267015985, 4.91624433052873, 5.865336969476989, 6.828607044549413, 7.832491552803522, 8.832916321335242, 9.776355030154983, 10.843178255739357, 10.71306262286312, 9.673428414945334, 8.673663424168218, 7.698937673569101, 6.709540352895514, 5.704322535496901, 4.779234583992203, 3.8200955342023097, 2.8250572841218466, 1.864162223066908, 2.896396635600153, 3.829563398716777, 4.850271270742696, 5.795352701344226, 6.755587596228117, 7.720802139330164, 8.75044277498028, 9.757935126214926, 10.710280576844701, 11.664273904846272, 11.608443434177474, 10.574240691319076, 9.591373889272065, 8.628938593242536, 7.660312345095768, 6.716211514669125, 5.780120910733133, 4.804036921546023, 3.7902745506864473, 2.8491295912466255, 3.8560160894436986, 4.768897613906956, 5.739505266140281, 6.699360996384985, 7.660374956629904, 8.688629875395662, 9.713356826073632, 10.700952657057124, 11.645060351137051, 12.653812459265021, 12.57215541769936, 11.499441992838452, 10.521418067421578, 9.61383029276574, 8.661141407061235, 7.648810379416793, 6.739440117681106, 5.769194996625478, 4.782204056487208, 3.7891522374241413, 4.744280803291744, 5.679771655330252, 6.6137912777276755, 7.591022138786991, 8.619219736882188, 9.578431564109056, 10.531882446447959, 11.501178099659114, 12.457841899358232, 13.491660363101767, 13.4978107394526, 12.548627495402053, 11.53438034982227, 10.568912108519504, 9.678041566941179, 8.696219101555327, 7.711547153119051, 6.773672088568056, 5.759423729158117, 4.817358025618066, 5.6774824194563935, 6.703971099325031, 7.616757157379402, 8.592879633809087, 9.586315493895453, 10.535375795476398, 11.585629041238574, 12.468058336414076, 13.476966854125399, 14.462148612051335, 14.441947737812649, 13.561198365060935, 12.607174857812234, 11.541585014732798, 10.589673141514082, 9.655537192336146, 8.684653151007817, 7.7167873979338575, 6.7202786225611195, 5.805425152680178, 6.700388179627179, 7.648864231375727, 8.632520659479237, 9.578977944534602, 10.518350309726127, 11.512124121343142, 12.534774204357726, 13.478985127573813, 14.46887909736496, 14.497994338922869, 14.443644733731329, 14.522749843986933, 13.534891360969725, 12.562427466464337, 11.557420906726321, 10.583035644741384, 9.665297396385368, 8.650954779409833, 7.6851453071127755, 6.761883138890015, 7.6463382520810415, 8.61168603494174, 9.586821002223322, 10.55086542619728, 11.492490927131467, 12.50584346831315, 13.437757986569459, 14.410663188317391, 14.465208695385197, 13.538681116873827, 13.601435123549132, 14.57174998991279, 14.491546160185575, 13.543669916088561, 12.534281050673616, 11.590084164625846, 10.658252288080286, 9.698703693559548, 8.742312167575589, 7.796501915626619, 8.636896605672856, 9.54776493204472, 10.492032069458828, 11.515457836438786, 12.419228749112083, 13.368264474219288, 14.326283347458018, 14.614117990191271, 13.614560599431607, 12.682362924839946, 12.686338310740371, 13.74757415827444, 14.6937447478903, 14.518564463290797, 13.523741721907788, 12.5285208427589, 11.596403182976527, 10.691819004520765, 9.699425356751993, 8.771966664960814, 9.64958720949383, 10.509057876130013, 11.483060596201321, 12.544565919694888, 13.485306349972975, 14.37199524467668, 14.812784283659015, 13.797531924536356, 12.773857506368321, 11.769362724672039, 11.870238109481871, 12.93112152116054, 13.972500764581829, 14.991284666347426, 14.486482138015248, 13.520627013857466, 12.565793763944473, 11.630917840389944, 10.636806834281355, 9.846716128893876, 10.149513479782215, 11.004231485811124, 11.659990244952636, 12.587191158006512, 13.60642005391982, 14.562925594191782, 13.838275850094558, 12.874013800477346, 11.891970555742768, 10.833259015733422, 11.087985087515724, 12.063975334458126, 13.073041883337538, 14.124880786265603, 14.586710003526097, 13.556935603327995, 12.640045418744334, 11.918686220425377, 10.940423734131967, 10.014063772794435, 9.101821158109733, 9.976821752346346, 10.71803915319337, 11.749749601463591, 12.66467307601327, 13.704395634776851, 13.244727120675392, 12.217434393338214, 11.14991106404154, 10.117407037580769, 11.91534199940197, 12.929480422522905, 13.880447749082979, 14.622324340633584, 13.610010591587368, 12.625333747737518, 11.691229708706889, 10.86010452692293, 9.908629906222304, 9.036983627040637, 8.0625854857788, 8.922575513973845, 9.786685107201324, 10.718279215458212, 11.690882218636144, 12.73750130782971, 13.68271154174317, 13.041957353722353, 12.04076986918098, 10.977331389081177, 12.86697577057149, 13.840562671170096, 14.580080218659049, 13.652475396640293, 12.669779734135977, 11.685964146071981, 10.753221868100427, 9.876905641830339, 8.875388099082478, 8.014996225203033, 7.105888083123704, 7.903362588436426, 8.85163679522389, 9.837274069901753, 10.80454200817081, 11.746493264557504, 12.734074112469196, 13.736682409686871, 12.857053611998197, 11.87049862290199, 13.768849102220278, 14.61812127602453, 13.656583994731129, 12.705974859042932, 11.761167049303971, 10.687482749600996, 9.752151610441032, 8.807137723558741, 7.8775304557327335, 7.088391872357479, 6.109392621231928, 6.884712901990871, 7.860349067340805, 8.80416477200883, 9.743949899870268, 10.743535365800568, 11.753229836376866, 12.732974535412389, 13.731895915256734, 12.790725504063499, 14.646365009413174, 13.69299671258049, 12.682900955233016, 11.700783348261675, 10.764176915769813, 9.738338171278325, 8.794479069751857, 7.841877627134163, 6.864275164962594, 6.051260929116775, 5.061667508798509, 5.8820255241267265, 6.812946783254487, 7.839212946840382, 8.791011598848606, 9.794561006946303, 10.808177870408832, 11.767052421878633, 12.718244757029838, 13.74350101392752], [13.723173106844374, 12.744417213100546, 11.782697335703238, 10.827700786186938, 9.836109040152662, 8.776614803571567, 7.822331916963636, 6.805263367888404, 5.796228139387673, 4.946260224729567, 4.051027490395412, 4.944109734103625, 5.8740894193246715, 6.884550978966671, 7.827907199616905, 8.837230194650266, 9.889016527980628, 10.818220700851999, 11.836689072640407, 12.794629018098513, 12.75884071379225, 11.801546879422236, 10.845211568286375, 9.855219597044654, 8.821881252654071, 7.854556208436477, 6.842122772194687, 5.813075922754139, 4.867774700409913, 3.9072093726307897, 2.981668561042634, 3.9062783028715264, 4.9590169817095315, 6.005791788442519, 7.045779185850632, 7.974373237898568, 8.858877448993605, 9.824956289464293, 10.848690749518186, 11.780069889927967, 11.886893189265065, 10.941165183438114, 9.937519006562045, 8.907027948972264, 7.852092997433781, 6.870435871353989, 5.846984212756522, 4.871555721530168, 3.887328638462474, 2.889403147685947, 1.9550348382350662, 2.940870688228427, 3.9779939926753487, 5.027578553665438, 6.020695906934506, 7.034974649463389, 7.887603824350922, 8.875204513412623, 9.834685133232133, 10.831833475611042, 11.069119911892724, 10.100036576741612, 9.055731139936704, 7.9961318735562585, 6.942763559300625, 5.949590427085887, 4.992699314146211, 3.9697971542648656, 2.9315044676694773, 1.9733234075385249, 0.9295658290768104, 1.9787241513531333, 3.0275403036322395, 4.070381366760062, 5.1323154987181026, 6.019647349927946, 6.950332729474551, 7.941820794119164, 8.86919295200975, 9.84785373383194, 10.14661687487, 9.176363852720211, 8.240668588446479, 7.2120575696978735, 6.152904056243739, 5.096689919360322, 4.025762205766057, 3.0961939469819413, 2.0855274696410833, 1.0325780840879417, 0.0, 1.0571575443058716, 2.0845551745513253, 3.115224086456248, 4.081287629407187, 5.0630136498413725, 6.1165648786900375, 7.063430918945483, 8.099479118139735, 9.0302234375936, 10.892407045085053, 9.87856671472117, 8.896542412368603, 7.940648772056515, 6.9189611432678255, 5.894074110168008, 4.846541375328965, 3.8706692425764326, 2.9040814198079885, 1.9613544709055653, 0.9989475562809929, 1.9338455899256395, 3.002426149725554, 4.0150057535526855, 4.964098392500944, 5.927368467573368, 6.931252975827477, 7.931677744359198, 8.875116453178938, 9.941939678763312, 11.736637875136221, 10.697003667218436, 9.69723867644132, 8.722512925842201, 7.733115605168614, 6.727897787770001, 5.802809836265302, 4.8436707864754105, 3.848632536394947, 2.8877374753400082, 2.0613014236597085, 2.992420993683453, 3.949032693766652, 4.894114124368182, 5.854349019252073, 6.81956356235412, 7.849204198004236, 8.856696549238881, 9.809041999868656, 10.763035327870227, 12.632018686450571, 11.597815943592176, 10.614949141545164, 9.652513845515635, 8.683887597368868, 7.739786766942225, 6.803696163006233, 5.827612173819123, 4.813849802959547, 3.8727048435197258, 3.1287721678641205, 3.9317552088736316, 4.9023628611069565, 5.8622185913516605, 6.780438429424212, 7.787391298419619, 8.812118249097587, 9.79971408008108, 10.743821774161006, 11.752573882288976, 13.59573066997246, 12.523017245111552, 11.544993319694678, 10.63740554503884, 9.684716659334336, 8.672385631689894, 7.763015369954206, 6.792770248898578, 5.805779308760308, 4.812727489697242, 4.107873859046368, 4.94464030901905, 5.863928155195102, 6.8191554863639965, 7.806312692415586, 8.765524519642454, 9.718975401981357, 10.688271055192512, 11.64493485489163, 12.678753318635165, 14.5213859917257, 13.572202747675153, 12.557955602095369, 11.592487360792603, 10.70161681921428, 9.719794353828426, 8.73512240539215, 7.797247340841157, 6.782998981431217, 5.840933277891167, 5.041075475211017, 5.968839753013829, 6.866894034846828, 7.843016511276514, 8.800533935852176, 9.722468751009796, 10.772721996771972, 11.655151291947474, 12.664059809658797, 13.649241567584733, 14.586788458445355, 14.584773617334035, 13.630750110085334, 12.565160267005897, 11.613248393787183, 10.679112444609247, 9.708228403280918, 8.740362650206958, 7.74385387483422, 6.829000404953279, 6.063981235381803, 6.9763114050640285, 7.882657536946663, 8.829114822002028, 9.768487187193553, 10.69921707687654, 11.721867159891124, 12.66607808310721, 13.655972052898358, 14.57650100631183, 13.630737689264727, 14.596382666482908, 14.558466613242825, 13.586002718737438, 12.580996158999422, 11.606610897014486, 10.688872648658467, 9.674530031682933, 8.708720559385876, 7.785458391163115, 7.009931307835665, 7.965122217796315, 8.880364668829108, 9.801002303664706, 10.742627804598893, 11.692936423846549, 12.624850942102857, 13.59775614385079, 14.669382047072784, 14.562256369146926, 12.700196546573087, 13.670511412936746, 14.697508020960534, 14.567245168361662, 13.557856302946718, 12.613659416898948, 11.681827540353385, 10.722278945832647, 9.765887419848688, 8.82007716789972, 8.00048966142748, 8.901201114899294, 9.845468252313403, 10.765594713906212, 11.66936562657951, 12.618401351686714, 13.576420224925444, 14.518476727082895, 14.638135851704705, 13.705938177113044, 11.785099733764326, 12.846335581298396, 13.792506170914255, 14.790068995576432, 14.54731697418089, 13.552096095032, 12.619978435249626, 11.715394256793864, 10.723000609025092, 9.795541917233916, 9.013180265248455, 9.862494058984588, 10.836496779055896, 11.794702797162314, 12.7354432274404, 13.622132122144107, 14.52929396366283, 14.821107176809454, 13.797432758641419, 12.792937976945137, 10.968999532505826, 12.029882944184495, 12.98478057844586, 14.003564480211457, 14.606875435535049, 13.641020311377266, 12.697344839798312, 11.933354017478772, 10.914800797305922, 10.158560910450944, 9.956425279400529, 10.900881244179676, 11.877161769454297, 12.794752663382228, 13.746759240158433, 14.585888526321572, 14.861851102367655, 13.897589052750444, 12.915545808015866, 11.85683426800652, 10.055407003427781, 11.031397250370183, 12.040463799249595, 13.09230270217766, 13.617528093723873, 12.58775369352577, 11.67086350894211, 10.949504310623153, 9.971241824329743, 9.08765659211648, 9.998818032921161, 10.873818627157773, 11.615036028004797, 12.646746476275018, 13.561669950824697, 14.601392509588278, 14.277305204763337, 13.250012477426159, 12.182489148129484, 11.149985121668713, 10.882763915314028, 11.896902338434963, 12.847869664995036, 13.653142430831359, 12.640828681785143, 11.656151837935292, 10.722047798904665, 9.890922617120706, 8.93944799642008, 8.110576446362682, 8.959582360590229, 9.819572388785271, 10.68368198201275, 11.615276090269639, 12.58787909344757, 13.634498182641138, 14.579708416554599, 14.074535437810294, 13.073347953268922, 12.009909473169118, 11.834397686483547, 12.807984587082153, 13.610898308856823, 12.683293486838068, 11.700597824333752, 10.716782236269756, 9.784039958298203, 8.907723732028115, 7.906206189280254, 7.088589044525078, 8.002884957935132, 8.800359463247853, 9.748633670035316, 10.73427094471318, 11.701538882982238, 12.643490139368932, 13.631070987280625, 14.6336792844983, 13.812100585255376, 12.82554559615917, 12.736271018132335, 13.648939366222303, 12.687402084928902, 11.736792949240705, 10.791985139501744, 9.71830083979877, 8.782969700638809, 7.837955813756517, 6.90834854593051, 6.161984691679523, 7.006389496043356, 7.781709776802298, 8.757345942152233, 9.701161646820259, 10.640946774681696, 11.640532240611996, 12.650226711188294, 13.629971410223817, 14.664837446980798, 13.745772477320678, 13.663956651766512, 12.723814802778264, 11.713719045430791, 10.73160143845945, 9.794995005967587, 8.7691562614761, 7.825297159949634, 6.872695717331939, 5.89509325516037, 5.09028741129892, 5.958664383609937, 6.779022398938154, 7.709943658065915, 8.73620982165181, 9.688008473660034, 10.691557881757731, 11.70517474522026, 12.722099395135812, 13.673291730287017, 14.6985479871847], [14.672542706807945, 13.693786813064117, 12.699082002964825, 11.744085453448525, 10.674504648180006, 9.615010411598911, 8.66072752499098, 7.6436589759157485, 6.634623747415017, 5.784655832756911, 4.8825343289697845, 3.9181886970358444, 4.84816838225689, 5.85862994189889, 6.801986162549124, 7.8113091575824845, 8.838419715516086, 9.767623888387456, 10.786092260175865, 11.744032205633971, 13.70821031375582, 12.750916479385808, 11.794581168249946, 10.804589197008225, 9.771250852617642, 8.698412612788749, 7.685979176546959, 6.651471530781484, 5.706170308437257, 4.7456049806581335, 3.8131753996170064, 2.8803572658037453, 3.9330959446417504, 4.979870751374738, 6.013180132979841, 6.941774185027777, 7.801719904687733, 8.767798745158421, 9.791533205212314, 10.722912345622095, 12.906674482972134, 11.960946477145184, 10.957300300269115, 9.926809242679333, 8.87187429114085, 7.890217165061058, 6.866765506463591, 5.891337015237237, 4.907109932169544, 3.909184441393017, 2.974816131942136, 1.9149496511606459, 2.9520729556075676, 3.9949795007946465, 4.9880968540637145, 6.002375596592597, 6.8304462800450505, 7.818046969106752, 8.777527588926262, 9.77467593130517, 12.126277456198595, 11.157194121047484, 10.112888684242575, 9.05328941786213, 7.999921103606496, 7.006747971391759, 6.049856858452083, 5.026954698570737, 3.988662011975349, 3.0304809518443965, 1.9867233733826821, 0.9528031142853521, 2.0016192665644583, 3.01322382245419, 4.075157954412231, 4.9624898056220745, 5.89317518516868, 6.8846632498132925, 7.812035407703878, 8.790696189526068, 11.203774419175874, 10.233521397026085, 9.297826132752352, 8.269215114003746, 7.2100616005496105, 6.153847463666193, 5.0829197500719285, 4.153351491287813, 3.142685013946955, 2.0897356283938135, 1.0571575443058716, 0.0, 1.0273976302454537, 2.0580665421503763, 3.0241300851013158, 4.005856105535501, 5.059407334384166, 6.006273374639611, 7.042321573833863, 7.973065893287728, 11.86032196360386, 10.846481633239978, 9.86445733088741, 8.90856369057532, 7.88687606178663, 6.861989028686812, 5.814456293847768, 4.838584161095236, 3.8719963383267912, 2.929269389424368, 1.9668624747997956, 1.031964441155149, 1.9763974480436355, 2.988977051870767, 3.9380696908190247, 4.901339765891449, 5.905224274145558, 6.905649042677279, 7.84908775149702, 8.915910977081394, 12.704552793655026, 11.66491858573724, 10.665153594960124, 9.690427844361006, 8.701030523687418, 7.695812706288804, 6.770724754784106, 5.811585704994213, 4.81654745491375, 3.855652393858811, 3.0237066080295865, 2.0905398449129624, 2.923003992084733, 3.8680854226862627, 4.828320317570154, 5.793534860672201, 6.8231754963223175, 7.830667847556963, 8.783013298186738, 9.73700662618831, 13.599933604969376, 12.56573086211098, 11.582864060063969, 10.62042876403444, 9.651802515887672, 8.707701685461027, 7.771611081525036, 6.795527092337926, 5.78176472147835, 4.8406197620385285, 4.0066477384341255, 3.029874060103141, 3.903207825564923, 4.863063555809627, 5.754409727742293, 6.761362596737699, 7.786089547415668, 8.773685378399161, 9.717793072479088, 10.726545180607058, 14.563645588491264, 13.490932163630356, 12.512908238213482, 11.605320463557645, 10.652631577853139, 9.640300550208696, 8.730930288473008, 7.760685167417381, 6.773694227279111, 5.780642408216044, 4.978250012287067, 4.0427591602485595, 4.864773119653068, 5.820000450821963, 6.780283990733668, 7.739495817960536, 8.692946700299439, 9.662242353510592, 10.61890615320971, 11.652724616953245, 14.504896755123484, 14.540117666193957, 13.525870520614173, 12.560402279311408, 11.669531737733083, 10.68770927234723, 9.703037323910953, 8.76516225935996, 7.75091389995002, 6.808848196409969, 5.911451628451717, 5.0669586042433385, 5.867738999304795, 6.843861475734481, 7.774505234170258, 8.69644004932788, 9.746693295090056, 10.629122590265554, 11.638031107976877, 12.623212865902813, 13.560759756763435, 14.597270076201063, 14.598665028604138, 13.533075185524702, 12.581163312305986, 11.64702736312805, 10.67614332179972, 9.70827756872576, 8.711768793353022, 7.796915323472081, 6.934357388622502, 6.074430256293538, 6.88350250140463, 7.829959786459995, 8.76933215165152, 9.673188375194623, 10.695838458209208, 11.64004938142529, 12.629943351216438, 13.55047230462991, 12.604708987582807, 13.570353964800988, 14.558212447818196, 14.55391763725624, 13.548911077518225, 12.574525815533288, 11.65678756717727, 10.642444950201735, 9.676635477904679, 8.753373309681917, 7.880307461076364, 7.063241069025825, 7.8812096332870745, 8.801847268122673, 9.74347276905686, 10.666907722164632, 11.59882224042094, 12.571727442168873, 13.643353345390867, 14.509785526678952, 11.67416784489117, 12.644482711254827, 13.671479319278616, 14.61935556337563, 14.525771221465522, 13.581574335417752, 12.649742458872188, 11.69019386435145, 10.733802338367491, 9.787992086418521, 8.870865814668178, 7.9993199661288035, 8.8712366562904, 9.76643967836418, 10.670210591037476, 11.61924631614468, 12.57726518938341, 13.519321691540862, 14.518879082300526, 14.673853095631848, 10.759071032082408, 11.820306879616478, 12.766477469232337, 13.764040293894514, 14.582735204452717, 13.63063738066832, 12.640814383698476, 11.818654885536276, 10.826261237767504, 10.763456835752717, 9.883556418489153, 8.960612910214097, 9.862265183032893, 10.79554776162028, 11.736288191898367, 12.622977086602074, 13.530138928120799, 14.504542363942859, 14.765347677160227, 13.760852895463945, 9.942970830823908, 11.003854242502577, 11.92762303413999, 12.946406935905586, 13.580954398467266, 12.615099274309484, 11.67142380273053, 10.90743298041099, 9.888879760238142, 10.91342025025002, 10.826801432641227, 9.999000095409183, 10.902930173431294, 11.795597627840195, 12.747604204616398, 13.586733490779539, 14.593938840533268, 14.865503971269252, 13.883460726534674, 12.824749186525327, 8.99824945912191, 9.974239706064312, 10.983306254943724, 12.035145157871789, 12.591607056656091, 11.561832656457987, 10.64494247187433, 9.923583273555371, 8.945320787261963, 9.842515931915557, 10.782152227377976, 11.02640982887396, 11.84488126519056, 12.844751221163136, 13.689351182522946, 14.62369992710342, 15.33446274906921, 14.307170021732032, 13.239646692435358, 12.207142665974587, 9.825606371008156, 10.839744794129091, 11.790712120689165, 12.627221393763577, 11.614907644717361, 10.63023080086751, 9.696126761836885, 8.865001580052924, 7.9135269593523, 8.86543578616176, 9.742916555047044, 10.657967996812616, 11.522077590040094, 12.453671698296983, 13.426274701474915, 14.472893790668481, 15.418104024581941, 15.131692982116165, 14.130505497574793, 13.06706701747499, 10.777240142177675, 11.750827042776281, 12.584977271789041, 11.657372449770286, 10.67467678726597, 9.690861199201974, 8.758118921230423, 7.881802694960334, 6.8802851522124735, 7.843448384324155, 8.786219152391947, 9.638755071275197, 10.58702927806266, 11.572666552740523, 12.53993449100958, 13.481885747396275, 14.469466595307967, 15.472074892525642, 14.831881878962445, 13.84532688986624, 11.679113473826463, 12.62301832915452, 11.66148104786112, 10.710871912172923, 9.766064102433962, 8.692379802730988, 7.7570486635710285, 6.812034776688736, 5.88242750886273, 6.9168440314786, 7.8447851040707, 8.620105384829643, 9.595741550179575, 10.539557254847601, 11.479342382709039, 12.478927848639339, 13.488622319215636, 14.46836701825116, 15.50323305500814, 14.695142077284249, 12.60679910746064, 11.697893765710482, 10.687798008363009, 9.705680401391668, 8.769073968899805, 7.743235224408319, 6.799376122881853, 5.846774680264158, 4.869172218092589, 5.898818304434773, 6.797059991637282, 7.617418006965498, 8.548339266093258, 9.574605429679153, 10.526404081687376, 11.529953489785074, 12.543570353247603, 13.56051550243501, 14.511707837586215, 15.579478505351101], [15.699940337053398, 14.72118444330957, 13.726479633210278, 12.771483083693978, 11.70190227842546, 10.642408041844364, 9.688125155236433, 8.671056606161201, 7.662021377660471, 6.812053463002365, 5.909931959215238, 4.945586327281298, 4.075502088842339, 4.949734647607396, 5.893090868257629, 6.90241386329099, 7.811022085270632, 8.740226258142004, 9.758694629930412, 10.716634575388518, 14.735607944001273, 13.77831410963126, 12.8219787984954, 11.831986827253678, 10.798648482863095, 9.725810243034202, 8.713376806792411, 7.678869161026936, 6.733567938682711, 5.773002610903587, 4.84057302986246, 3.907754896049199, 3.081145023240718, 3.9525433416096223, 4.985782502734387, 5.914376554782323, 6.774322274442279, 7.740401114912968, 8.764135574966861, 9.695514715376643, 13.934072113217589, 12.988344107390638, 11.984697930514569, 10.954206872924788, 9.899271921386305, 8.917614795306513, 7.894163136709046, 6.918734645482692, 5.934507562414998, 4.936582071638471, 4.00221376218759, 2.9423472814060996, 2.051884378347696, 2.967581870549193, 3.9606992238182612, 4.974977966347144, 5.803048649799597, 6.790649338861298, 7.750129958680808, 8.747278301059717, 13.15367508644405, 12.184591751292938, 11.14028631448803, 10.080687048107585, 9.027318733851951, 8.034145601637213, 7.077254488697537, 6.054352328816192, 5.016059642220803, 4.057878582089851, 3.014121003628136, 1.9802007445308059, 1.0726201196088703, 1.9858261922087368, 3.0477603241667772, 3.935092175376621, 4.865777554923226, 5.857265619567839, 6.784637777458424, 7.763298559280614, 12.231172049421327, 11.260919027271537, 10.325223762997805, 9.296612744249199, 8.237459230795064, 7.181245093911647, 6.110317380317382, 5.180749121533267, 4.170082644192409, 3.1171332586392673, 2.0845551745513253, 1.0273976302454537, 0.0, 1.0306689119049228, 1.9967324548558623, 2.9784584752900476, 4.032009704138712, 4.978875744394157, 6.0149239435884105, 6.9456682630422755, 12.845937900046804, 11.832097569682922, 10.850073267330355, 9.894179627018266, 8.872491998229576, 7.847604965129758, 6.800072230290715, 5.824200097538182, 4.857612274769738, 3.914885325867315, 2.9524784112427427, 2.017580377598096, 0.9489998177981817, 1.9615794216253133, 2.910672060573571, 3.873942135645995, 4.877826643900104, 5.878251412431824, 6.8216901212515655, 7.88851334683594, 13.690168730097971, 12.650534522180186, 11.65076953140307, 10.676043780803951, 9.686646460130364, 8.68142864273175, 7.756340691227052, 6.79720164143716, 5.802163391356697, 4.841268330301758, 3.8946871953602002, 2.961520432243576, 1.8956063618392793, 2.840687792440809, 3.8009226873247, 4.7661372304267475, 5.795777866076864, 6.803270217311509, 7.755615667941282, 8.709608995942855, 14.585549541412323, 13.551346798553926, 12.568479996506914, 11.606044700477385, 10.637418452330618, 9.693317621903974, 8.757227017967983, 7.781143028780873, 6.767380657921297, 5.826235698481475, 4.823191525883779, 3.8464178475527944, 2.8758101953194695, 3.8356659255641734, 4.727012097496839, 5.7339649664922465, 6.758691917170214, 7.746287748153707, 8.690395442233633, 9.699147550361603, 14.448913595607966, 14.476548100073302, 13.498524174656428, 12.59093640000059, 11.638247514296086, 10.625916486651644, 9.612302409968114, 8.642057288912486, 7.655066348774215, 6.662014529711149, 5.706885963843546, 4.771395111805038, 3.8373754894076146, 4.792602820576509, 5.752886360488214, 6.712098187715082, 7.665549070053984, 8.63484472326514, 9.591508522964258, 10.625326986707792, 13.477499124878031, 14.426682368928578, 14.511486457057119, 13.546018215754353, 12.619386026585765, 11.63397159406938, 10.58440944540606, 9.62884636411511, 8.564775733344051, 7.622710029804001, 6.6400875800081955, 5.795594555799817, 4.84034136905934, 5.816463845489026, 6.747107603924803, 7.669042419082424, 8.719295664844601, 9.601724960020102, 10.610633477731424, 11.59581523565736, 12.533362126517982, 13.56987244595561, 14.458531320730234, 14.424137461933416, 13.395025145700018, 12.460889196522082, 11.490005155193753, 10.522139402119793, 9.525630626747054, 8.610777156866112, 7.66299334017898, 6.803066207850017, 5.856104871159175, 6.80256215621454, 7.7419345214060655, 8.645790744949167, 9.668440827963753, 10.612651751179838, 11.602545720970985, 12.523074674384457, 11.577311357337354, 12.542956334555535, 13.530814817572743, 14.573200382754399, 14.362772910912257, 13.38838764892732, 12.470649400571302, 11.456306783595767, 10.49049731129871, 9.567235143075948, 8.608943412632842, 7.791877020582303, 6.85381200304162, 7.774449637877218, 8.716075138811405, 9.639510091919176, 10.571424610175484, 11.544329811923417, 12.615955715145411, 13.482387896433499, 10.646770214645715, 11.617085081009373, 12.644081689033161, 13.591957933130175, 14.588461183317422, 13.644264297269652, 12.670069984303224, 12.116749947830064, 11.512957134674226, 10.55204785322805, 9.599501766224655, 8.727955917685282, 7.843839026044945, 8.739042048118725, 9.642812960792021, 10.591848685899226, 11.549867559137956, 12.491924061295407, 13.491481452055071, 14.423679126646732, 9.731673401836954, 10.792909249371023, 11.739079838986882, 12.736642663649059, 13.673839910161224, 12.721742086376826, 11.731919089406983, 11.073865522865619, 11.853658868012957, 11.527512602562245, 10.61219237004563, 9.689248861770576, 8.834867552787438, 9.768150131374826, 10.708890561652913, 11.595579456356619, 12.502741297875342, 13.477144733697404, 14.45220111170427, 14.746468831906888, 8.915573200578454, 9.976456612257122, 10.900225403894536, 11.919009305660133, 12.672059104175773, 11.70620398001799, 10.762528508439036, 10.13476668699644, 10.916277390483595, 11.940817880495473, 11.555437384197704, 10.727636046965664, 9.87553254318584, 10.76819999759474, 11.720206574370945, 12.559335860534084, 13.566541210287811, 14.500987820433624, 14.869076662977617, 13.810365122968271, 7.970851828876457, 8.946842075818859, 9.95590862469827, 11.007747527626336, 11.682711762364598, 10.652937362166494, 9.736047177582837, 9.15091698014082, 9.972718417507416, 10.86991356216101, 11.809549857623429, 11.755045780430441, 10.817483634945106, 11.817353590917682, 12.661953552277494, 13.596302296857967, 14.581112843223892, 15.334567651977485, 14.26704432268081, 13.23454029622004, 8.798208740762702, 9.812347163883636, 10.76331449044371, 11.709268462956883, 10.706012350425867, 9.721335506576017, 8.787231467545391, 8.092335286638374, 8.940924589597753, 9.892833416407212, 10.770314185292497, 11.685365627058069, 11.748837680937152, 12.68043178919404, 13.63574440965462, 14.636693926644215, 15.549552135115817, 16.15909061236162, 15.157903127820248, 14.094464647720445, 9.74984251193222, 10.723429412530827, 11.662714606743668, 10.748477155478792, 9.765781492974476, 8.78196590491048, 7.8492236269389295, 7.109136401545783, 7.907682782457926, 8.870846014569608, 9.8136167826374, 10.66615270152065, 11.614426908308113, 12.600064182985976, 13.567332121255035, 14.50928337764173, 15.496864225553422, 16.499472522771097, 15.8592795092079, 14.872724520111694, 10.65171584358101, 11.708983164171636, 10.752585753569626, 9.80197661788143, 8.857168808142468, 7.783484508439495, 6.848153369279534, 6.039368483274185, 6.909825139108182, 7.944241661724053, 8.872182734316153, 9.647503015075095, 10.62313918042503, 11.566954885093056, 12.506740012954493, 13.506325478884794, 14.516019949461091, 15.495764648496614, 16.530630685253595, 15.722539707529702, 11.579401477215187, 10.785485154715627, 9.778902714071515, 8.796785107100174, 7.860178674608312, 6.834339930116824, 5.890480828590358, 5.074108386849606, 5.896569848338043, 6.926215934680227, 7.824457621882735, 8.644815637210952, 9.575736896338713, 10.602003059924607, 11.553801711932831, 12.557351120030528, 13.570967983493057, 14.587913132680463, 15.539105467831668, 16.606876135596554], [16.730609248958324, 15.751853355214495, 14.757148545115202, 13.802151995598901, 12.732571190330383, 11.673076953749288, 10.718794067141356, 9.701725518066125, 8.692690289565395, 7.842722374907288, 6.903107644736495, 5.859506980565518, 4.929527295344472, 3.9190657357024725, 4.862421956352707, 5.871744951386067, 6.780353173365709, 7.70955734623708, 8.728025718025489, 9.685965663483595, 15.766276855906199, 14.808983021536186, 13.852647710400324, 12.862655739158603, 11.82931739476802, 10.756479154939127, 9.744045718697336, 8.70953807293186, 7.764236850587634, 6.80367152280851, 5.871241941767383, 4.938423807954122, 3.9686492364376864, 2.9218744297046992, 3.955113590829464, 4.8837076428774004, 5.743653362537357, 6.709732203008046, 7.7334666630619395, 8.66484580347172, 14.96474102512251, 14.01901301929556, 13.01536684241949, 11.98487578482971, 10.929940833291226, 9.948283707211434, 8.924832048613967, 7.949403557387614, 6.965176474319921, 5.967250983543393, 5.032882674092512, 3.973016193311022, 2.9810894988111993, 1.9369129586442702, 2.930030311913338, 3.944309054442221, 4.772379737894674, 5.759980426956376, 6.719461046775885, 7.716609389154795, 14.184343998348972, 13.21526066319786, 12.170955226392952, 11.111355960012506, 10.057987645756873, 9.064814513542135, 8.10792340060246, 7.0850212407211135, 6.046728554125725, 5.088547493994772, 4.044789915533058, 3.0108696564357285, 2.0018252400723737, 0.9551572803038139, 2.0170914122618546, 2.904423263471698, 3.8351086430183035, 4.826596707662916, 5.753968865553501, 6.732629647375691, 13.261840961326248, 12.291587939176459, 11.355892674902728, 10.327281656154122, 9.268128142699988, 8.21191400581657, 7.140986292222305, 6.211418033438189, 5.200751556097331, 4.14780217054419, 3.115224086456248, 2.0580665421503763, 1.0306689119049228, 0.0, 0.9660635429509394, 1.9477895633851248, 3.0013407922337896, 3.9482068324892348, 4.984255031683487, 5.914999351137352, 13.869744936152214, 12.855904605788332, 11.873880303435765, 10.917986663123676, 9.896299034334985, 8.871412001235168, 7.8238792663961245, 6.848007133643592, 5.881419310875148, 4.938692361972725, 3.9762854473481526, 3.041387413703506, 1.9728068539035915, 0.9602272500764599, 1.8935004109185938, 2.8567704859910177, 3.860654994245127, 4.861079762776847, 5.804518471596588, 6.871341697180963, 14.713975766203381, 13.674341558285596, 12.67457656750848, 11.699850816909361, 10.710453496235774, 9.70523567883716, 8.780147727332462, 7.82100867754257, 6.8259704274621065, 5.865075366407169, 4.899671608247281, 3.9665048451306566, 2.9005907747263597, 1.9555093441248301, 2.887369724169443, 3.8110964425549967, 4.8407370782051125, 5.786098567656531, 6.738444018286304, 7.692437346287877, 14.489067232400545, 14.575153834659336, 13.592287032612324, 12.629851736582795, 11.661225488436028, 10.70214436039043, 9.766053756454438, 8.789969767267328, 7.776207396407752, 6.835062436967931, 5.828175938770858, 4.851402260439874, 3.88079460820655, 2.9851789836902642, 3.8134591343415827, 4.778924178620495, 5.803651129298463, 6.729116098498729, 7.673223792578655, 8.681975900706625, 13.510416498498861, 14.53013331163518, 14.522331210761838, 13.614743436106, 12.647074252782541, 11.634743225138099, 10.617286822855194, 9.647041701799566, 8.660050761661296, 7.666998942598229, 6.7118703767306265, 5.776379524692119, 4.842359902294695, 3.9421158787026, 4.8393333973329575, 5.798545224559826, 6.751996106898728, 7.696347626156035, 8.6319151600751, 9.665733623818634, 12.517905761988873, 13.46708900603942, 14.481336151619203, 14.569825251859763, 13.624370439472845, 12.638956006956459, 11.589393858293139, 10.63383077700219, 9.56976014623113, 8.62769444269108, 7.645071992895276, 6.800578968686898, 5.845325781946421, 5.013660371873913, 5.833554640769547, 6.755489455927168, 7.805742701689345, 8.663227862910997, 9.67213638062232, 10.657318138548256, 11.573768763628824, 12.599938818023361, 13.441648614287232, 14.512202928493036, 14.400009558587097, 13.465873609409162, 12.494989568080832, 11.527123815006872, 10.530615039634133, 9.615761569753191, 8.667977753066062, 7.808050620737097, 6.8610892840462565, 5.999758682599428, 6.855376795270146, 7.732237781793911, 8.754887864808497, 9.674154654070733, 10.66404862386188, 11.584577577275352, 10.617717994448196, 11.526073628112533, 12.51393211112974, 13.55602873309942, 14.55093705477952, 13.620643905249192, 12.639262915210228, 12.461291196482847, 11.49548172418579, 10.572219555963027, 9.613927825519923, 8.796861433469385, 7.858796415928701, 6.971646164262106, 7.851275115480055, 8.72595712876392, 9.657871647020228, 10.63077684876816, 11.702402751990155, 12.543890799324394, 9.629598564990737, 10.599913431354395, 11.626910039378183, 12.574786283475197, 13.5577922714125, 12.61359538536473, 11.639401072398302, 12.59894966691904, 12.517941547561307, 11.557032266115131, 10.604486179111737, 9.732940330572363, 8.848823438932026, 7.936238574503613, 8.778012937460671, 9.727048662567876, 10.685067535806606, 11.617390821227277, 12.61694821198694, 13.549145886578602, 8.714501752181976, 9.775737599716045, 10.721908189331904, 11.719471013994081, 12.643170998256302, 11.691073174471905, 10.701250177502061, 11.644316274566775, 12.600874956652977, 12.532497015449326, 11.617176782932711, 10.694233274657657, 9.83985196567452, 8.965346657759715, 9.844090538321563, 10.730779433025269, 11.637941274543994, 12.602611493629274, 13.577667871636137, 14.58216265333242, 7.898401550923477, 8.959284962602146, 9.869556491989613, 10.88834039375521, 11.641390192270851, 10.675535068113069, 9.731859596534115, 10.705217438697595, 11.663493479123614, 12.690854241532222, 12.560421797084786, 11.732620459852743, 10.88051695607292, 9.96539652397963, 10.855406551039593, 11.694535837202734, 12.701741186956463, 13.626454580365493, 14.547353277461104, 14.834172159073681, 6.9401829169715334, 7.916173163913935, 8.925239712793347, 9.977078615721412, 10.652042850459676, 9.622268450261572, 8.705378265677913, 9.752157302535707, 10.719934506147435, 11.645638260035017, 12.684525481365633, 12.76003019331752, 11.822468047832187, 11.014550117302571, 11.797153528946142, 12.731502273526615, 13.716312819892543, 14.696861443053434, 15.297713234585732, 14.265209208124961, 7.767539828857779, 8.781678251978713, 9.732645578538786, 10.67859955105196, 9.675343438520946, 8.690666594671095, 7.756562555640468, 8.715746786857684, 9.688140678237772, 10.66855811428122, 11.6452898090347, 12.68679629284613, 12.753822093824233, 12.06916020772798, 12.770944386323269, 13.771893903312863, 14.68475211178447, 15.624906227278398, 16.18857203972517, 15.125133559625366, 8.719173600027299, 9.692760500625905, 10.632045694838746, 9.71780824357387, 8.735112581069554, 7.751296993005559, 6.818554715034006, 7.787696578386815, 8.78265840620013, 9.745821638311812, 10.688592406379604, 11.667583367308712, 12.615857574096175, 13.134707252523292, 13.838983634014697, 14.76290194658507, 15.643168154934937, 16.65205619650155, 16.88994842111282, 15.903393432016616, 9.621046931676089, 10.678314252266714, 9.721916841664704, 8.771307705976508, 7.8264998962375465, 6.752815596534572, 5.8174844573746105, 6.786975707302502, 7.784800762850385, 8.819217285466257, 9.79821653659181, 10.67817192698002, 11.653808092329953, 12.59762379699798, 13.537408924859417, 14.536994390789717, 15.546688861366015, 16.526433560401536, 17.561299597158516, 16.753208619434627, 10.548732565310265, 9.754816242810703, 8.748233802166592, 7.766116195195251, 6.829509762703389, 5.803671018211902, 4.859811916685435, 5.886172371588382, 6.810490501622263, 7.840136587964447, 8.846401252237216, 9.675484549115875, 10.606405808243636, 11.63267197182953, 12.584470623837754, 13.588020031935452, 14.60163689539798, 15.618582044585388, 16.569774379736593, 17.63754504750148], [17.69667279190926, 16.71791689816543, 15.72321208806614, 14.768215538549839, 13.69863473328132, 12.639140496700225, 11.684857610092294, 10.667789061017062, 9.658753832516332, 8.808785917858227, 7.869171187687434, 6.825570523516458, 5.895590838295411, 4.8851292786534115, 4.187580879088189, 4.938885374691475, 5.81428963041477, 6.743493803286141, 7.761962175074549, 8.719902120532655, 16.732340398857136, 15.775046564487123, 14.818711253351262, 13.82871928210954, 12.795380937718958, 11.722542697890065, 10.710109261648274, 9.675601615882798, 8.730300393538572, 7.769735065759448, 6.837305484718321, 5.90448735090506, 4.934712779388626, 3.8879379726556387, 3.1399253381467482, 3.932782002018749, 4.777589819586417, 5.743668660057106, 6.767403120111, 7.698782260520781, 15.93080456807345, 14.9850765622465, 13.98143038537043, 12.950939327780649, 11.896004376242166, 10.914347250162374, 9.890895591564906, 8.915467100338553, 7.93124001727086, 6.933314526494333, 5.998946217043452, 4.939079736261961, 3.9471530417621388, 2.9029765015952096, 2.1148420592306225, 2.9933834135835697, 3.8063161949437347, 4.793916884005436, 5.753397503824946, 6.750545846203855, 15.150407541299911, 14.1813242061488, 13.137018769343891, 12.077419502963446, 11.024051188707812, 10.030878056493075, 9.073986943553399, 8.051084783672053, 7.012792097076664, 6.054611036945712, 5.010853458483997, 3.976933199386668, 2.967888783023313, 1.9212208232547532, 1.051027869310915, 1.9383597205207588, 2.869045100067364, 3.8605331647119767, 4.787905322602562, 5.766566104424752, 14.22790450427719, 13.2576514821274, 12.321956217853668, 11.293345199105062, 10.234191685650927, 9.17797754876751, 8.107049835173244, 7.177481576389129, 6.166815099048271, 5.113865713495129, 4.081287629407187, 3.0241300851013158, 1.9967324548558623, 0.9660635429509394, 0.0, 0.9817260204341853, 2.03527724928285, 2.9821432895382953, 4.018191488732548, 4.9489358081864125, 14.786047192991665, 13.772206862627783, 12.790182560275216, 11.834288919963127, 10.812601291174436, 9.787714258074619, 8.740181523235576, 7.764309390483044, 6.7977215677146, 5.854994618812177, 4.892587704187605, 3.9576896705429583, 2.8891091107430436, 1.876529506915912, 0.9274368679676543, 1.8907069430400782, 2.8945914512941875, 3.8950162198259077, 4.838454928645649, 5.9052781542300234, 14.507557903468307, 14.590643815125047, 13.59087882434793, 12.616153073748812, 11.626755753075225, 10.621537935676612, 9.696449984171913, 8.737310934382021, 7.742272684301558, 6.7813776232466205, 5.8159738650867325, 4.8828071019701085, 3.8168930315658116, 2.871811600964282, 1.9213061812185037, 2.8450328996040573, 3.8746735352541735, 4.820035024705591, 5.772380475335365, 6.726373803336937, 13.523003689449606, 14.534749038675264, 14.503975808262062, 13.541540512232533, 12.572914264085766, 11.589615034064146, 10.653524430128154, 9.677440440941044, 8.663678070081469, 7.722533110641647, 6.715646612444575, 5.738872934113591, 4.768265281880266, 3.8084095516355623, 2.8473955913906432, 3.812860635669556, 4.837587586347524, 5.763052555547789, 6.707160249627716, 7.715912357755685, 12.544352955547922, 13.564069768684238, 14.528234891068953, 14.526432211755738, 13.534544926456258, 12.522213898811815, 11.504757496528912, 10.534512375473284, 9.547521435335014, 8.554469616271946, 7.599341050404343, 6.663850198365835, 5.729830575968411, 4.765346446647898, 3.873269854382018, 4.832481681608886, 5.785932563947789, 6.730284083205095, 7.665851617124159, 8.699670080867692, 11.551842219037932, 12.501025463088478, 13.515272608668262, 14.496425691226344, 14.511841113146563, 13.526426680630177, 12.476864531966857, 11.521301450675907, 10.457230819904847, 9.515165116364797, 8.532542666568991, 7.688049642360614, 6.732796455620138, 5.836890939819211, 4.867491097818608, 5.789425912976228, 6.839679158738406, 7.697164319960057, 8.70607283767138, 9.691254595597316, 10.607705220677882, 11.63387527507242, 12.47558507133629, 13.546139385542094, 14.562719515098735, 13.889385672234706, 13.382460241754549, 12.414594488680589, 11.41808571330785, 10.503232243426908, 9.555448426739776, 8.695521294410813, 7.748559957719973, 6.822989250544726, 5.889313252319207, 6.7661742388429715, 7.7888243218575575, 8.708091111119792, 9.69798508091094, 10.618514034324413, 9.651654451497254, 10.560010085161592, 11.5478685681788, 12.58996519014848, 13.594971749886495, 12.961887219829467, 13.605326458161166, 13.348761870156563, 12.382952397859507, 11.459690229636744, 10.501398499193638, 9.684332107143101, 8.746267089602417, 7.794876732207404, 6.885211572529116, 7.75989358581298, 8.691808104069288, 9.664713305817221, 10.736339209039215, 11.577827256373455, 8.663535022039795, 9.633849888403454, 10.660846496427242, 11.608722740524255, 12.660389955189821, 11.954838699945006, 12.60546461534924, 13.565013209869978, 13.405412221235022, 12.444502939788846, 11.491956852785451, 10.62041100424608, 9.736294112605743, 8.75946914244891, 7.811949394509732, 8.760985119616937, 9.719003992855667, 10.651327278276337, 11.650884669036001, 12.583082343627662, 7.748438209231036, 8.809674056765106, 9.755844646380964, 10.753407471043142, 11.74823021242615, 11.016402021811952, 11.667313720452999, 12.610379817517712, 13.566938499603918, 13.419967689123041, 12.504647456606426, 11.581703948331374, 10.727322639348236, 9.788577225705012, 8.878026995370623, 9.76471589007433, 10.671877731593053, 11.636547950678334, 12.6116043286852, 13.616099110381482, 6.932338007972538, 7.993221419651207, 8.903492949038673, 9.92227685080427, 10.918639470037252, 10.000693990848552, 10.697923139485052, 11.671280981648533, 12.629557022074554, 13.656917784483163, 13.4478924707585, 12.620091133526461, 11.715828004978802, 10.788627091924926, 9.889343008088655, 10.728472294251794, 11.735677644005522, 12.660391037414554, 13.581289734510166, 14.5522028193201, 5.974119374020594, 6.950109620962996, 7.959176169842408, 9.011015072770473, 9.97125467931647, 8.947427372997055, 9.671441808628852, 10.718220845486648, 11.685998049098375, 12.611701802985957, 13.650589024316572, 13.602947811318035, 12.657779096738068, 11.790187137582379, 10.831089985995204, 11.765438730575678, 12.750249276941602, 13.730797900102495, 14.552632790971197, 15.231272751075903, 6.80147628590684, 7.815614709027773, 8.766582035587847, 9.71253600810102, 9.000502361256428, 8.015825517406578, 8.722626098591407, 9.681810329808624, 10.654204221188712, 11.63462165723216, 12.61135335198564, 13.65285983579707, 13.589133142730114, 12.777483846550263, 11.804880843372331, 12.805830360361925, 13.718688568833528, 14.658842684327459, 15.550177957507696, 16.091197102576306, 7.753110057076358, 8.726696957674966, 9.665982151887807, 8.85159148787085, 8.00536782596166, 7.076455915741041, 7.7846182579849454, 8.753760121337756, 9.74872194915107, 10.711885181262751, 11.654655949330543, 12.633646910259651, 13.581921117047115, 13.843030891345574, 12.87292009106376, 13.796838403634132, 14.677104611983996, 15.68599265355061, 16.559446403475697, 16.869456974967555, 8.65498338872515, 9.712250709315775, 8.779324524935001, 7.828715389246804, 6.944749841715027, 6.077974519270055, 6.78354800032555, 7.753039250253441, 8.750864305801326, 9.785280828417196, 10.764280079542749, 11.644235469930958, 12.61987163528089, 13.563687339948917, 13.933512199364301, 14.799796302391067, 15.657948888076326, 16.637693587111848, 17.514642000937936, 17.719272162385565, 9.582669022359326, 8.788752699859764, 7.786590075438969, 6.809601991350634, 5.896650186008797, 5.1288299409473845, 5.825875459636374, 6.852235914539321, 7.776554044573203, 8.806200130915387, 9.812464795188156, 10.641548092066813, 11.572469351194574, 12.598735514780468, 13.550534166788692, 14.55408357488639, 15.567700438348918, 16.584645587536325, 17.53583792268753, 18.603608590452417], [18.678398812343445, 17.699642918599615, 16.704938108500325, 15.749941558984025, 14.680360753715506, 13.620866517134411, 12.66658363052648, 11.649515081451248, 10.640479852950518, 9.790511938292411, 8.85089720812162, 7.807296543950643, 6.877316858729596, 5.866855299087597, 4.96648234929065, 3.957159354257289, 4.832563609980584, 5.761767782851955, 6.780236154640363, 7.738176100098469, 17.71406641929132, 16.756772584921308, 15.800437273785446, 14.810445302543725, 13.777106958153142, 12.704268718324249, 11.691835282082458, 10.657327636316984, 9.712026413972758, 8.751461086193634, 7.819031505152507, 6.886213371339246, 5.916438799822811, 4.869663993089824, 3.9636542570007656, 2.951055981584563, 3.7958637991522317, 4.76194263962292, 5.785677099676814, 6.717056240086595, 16.912530588507636, 15.966802582680685, 14.963156405804616, 13.932665348214835, 12.877730396676352, 11.89607327059656, 10.872621611999092, 9.897193120772739, 8.912966037705045, 7.915040546928519, 6.980672237477638, 5.920805756696147, 4.928879062196324, 3.884702522029395, 2.946490885973625, 2.011657393149384, 2.824590174509549, 3.8121908635712507, 4.77167148339076, 5.768819825769669, 16.132133561734097, 15.163050226582985, 14.118744789778077, 13.059145523397632, 12.005777209141998, 11.01260407692726, 10.055712963987585, 9.032810804106239, 7.99451811751085, 7.036337057379898, 5.992579478918183, 4.958659219820854, 3.9496148034574983, 2.9029468436889387, 1.8826766960539172, 0.9566337000865733, 1.8873190796331785, 2.8788071442777907, 3.806179302168376, 4.784840083990566, 15.209630524711374, 14.239377502561585, 13.303682238287854, 12.275071219539248, 11.215917706085113, 10.159703569201696, 9.08877585560743, 8.159207596823315, 7.148541119482457, 6.095591733929315, 5.063013649841373, 4.005856105535502, 2.9784584752900476, 1.9477895633851248, 0.9817260204341853, 0.0, 1.0535512288486648, 2.0004172691041098, 3.0364654682983625, 3.967209787752228, 14.503969893706504, 14.753932883061971, 13.771908580709402, 12.816014940397313, 11.794327311608622, 10.769440278508805, 9.721907543669762, 8.74603541091723, 7.779447588148785, 6.836720639246362, 5.87431372462179, 4.939415690977143, 3.870835131177229, 2.8582555273500976, 1.9091628884018397, 1.0731699940930521, 2.0770545023471616, 2.9362559291222956, 3.8796946379420367, 4.946517863526411, 13.548797612764693, 14.53262673373876, 14.572604844782116, 13.597879094182998, 12.60848177350941, 11.603263956110798, 10.6781760046061, 9.719036954816207, 8.723998704735743, 7.763103643680806, 6.7976998855209185, 5.8645331224042945, 4.798619051999998, 3.853537621398468, 2.903032201652689, 2.027495950657031, 3.057136586307147, 3.8612747340019795, 4.813620184631754, 5.767613512633326, 12.564243398745992, 13.575988747971651, 14.499518778514854, 14.52326653266672, 13.554640284519952, 12.571341054498332, 11.63525045056234, 10.65916646137523, 9.645404090515655, 8.704259131075833, 7.69737263287876, 6.720598954547776, 5.749991302314451, 4.790135572069747, 3.8291216118248284, 2.9953236867225295, 4.020050637400498, 4.804292264844177, 5.748399958924104, 6.757152067052073, 11.585592664844308, 12.605309477980626, 13.569474600365341, 14.492747216276495, 14.516270946890444, 13.503939919246001, 12.486483516963096, 11.516238395907468, 10.529247455769198, 9.53619563670613, 8.581067070838527, 7.64557621880002, 6.7115565964025965, 5.747072467082083, 4.854995874816203, 4.015004602844918, 4.968455485183821, 5.771523792501483, 6.707091326420547, 7.74090979016408, 10.59308192833432, 11.542265172384866, 12.55651231796465, 13.537665400522732, 14.539249770280103, 14.508152701064361, 13.458590552401041, 12.50302747111009, 11.438956840339031, 10.49689113679898, 9.514268687003176, 8.669775662794798, 7.714522476054322, 6.8186169602533955, 5.849217118252794, 4.97194883421226, 6.022202079974438, 6.738404029256444, 7.747312546967767, 8.732494304893702, 9.64894492997427, 10.675114984368808, 11.516824780632678, 12.587379094838482, 13.603959224395123, 14.538095173573058, 14.364186262188733, 13.396320509114773, 12.399811733742034, 11.484958263861092, 10.53717444717396, 9.677247314844998, 8.730285978154157, 7.80471527097891, 6.871039272753393, 5.9486971600790035, 6.971347243093589, 7.74933082041618, 8.739224790207327, 9.659753743620799, 8.692894160793642, 9.60124979445798, 10.589108277475187, 11.631204899444867, 12.636211459182883, 13.613852099877123, 14.58705247859535, 14.330487890590748, 13.36467841829369, 12.441416250070928, 11.483124519627822, 10.666058127577285, 9.727993110036602, 8.776602752641589, 7.866937592963302, 6.942416507049012, 7.87433102530532, 8.757938853290794, 9.813576813804206, 10.619066965669841, 7.704774731336184, 8.675089597699841, 9.70208620572363, 10.649962449820643, 11.701629664486209, 12.645826550533979, 13.587190635783424, 14.546739230304162, 14.387138241669206, 13.42622896022303, 12.473682873219635, 11.602137024680264, 10.718020133039927, 9.741195162883095, 8.793675414943918, 8.010055982633832, 8.909638441634764, 9.74455282574991, 10.744110216509574, 11.646220557757978, 6.789677918527426, 7.850913766061496, 8.797084355677356, 9.794647180339533, 10.789469921722542, 11.78469080087143, 12.649039740887183, 13.592105837951896, 14.548664520038102, 14.401693709557225, 13.48637347704061, 12.563429968765558, 11.70904865978242, 10.770303246139196, 9.85975301580481, 9.013786753091225, 9.86251218037215, 10.729773498151907, 11.704829876158772, 12.694054594925714, 5.973577717268926, 7.023529170581227, 7.921766928604489, 8.940550830370086, 9.936913449603068, 10.779595461051013, 11.679649159919236, 12.653007002082717, 13.611283042508738, 14.638643804917347, 14.429618491192684, 13.601817153960646, 12.697554025412986, 11.77035311235911, 10.87106902852284, 9.97754315726869, 10.926312092784618, 11.753616584888126, 12.674515281983739, 13.63015830386433, 4.99239335358641, 5.968383600528812, 6.977450149408224, 8.029289052336289, 8.989528658882286, 9.726328843199516, 10.653167829063037, 11.699946865920833, 12.667724069532559, 13.593427823420141, 14.632315044750756, 14.58467383175222, 13.639505117172252, 12.771913158016563, 11.812816006429388, 11.014509593592571, 11.940883725720699, 12.824023447576067, 13.64585833844477, 14.575371833101844, 5.819750265472654, 6.8338886885935874, 7.784856015153662, 8.730809987666834, 8.074738577885611, 8.794726987609039, 9.704352119025591, 10.663536350242808, 11.635930241622896, 12.616347677666344, 13.593079372419824, 14.634585856231254, 14.570859163164299, 13.759209866984447, 12.786606863806515, 12.054901223378819, 12.909323017612625, 13.752068231801031, 14.643403504981269, 15.551821419912482, 6.771384036642172, 7.74497093724078, 8.68425613145362, 7.869865467436664, 7.023641805527473, 7.855357385943502, 8.76634427841913, 9.73548614177194, 10.730447969585255, 11.693611201696935, 12.636381969764727, 13.615372930693836, 14.563647137481299, 14.824756911779758, 13.854646111497944, 13.045909266651025, 13.867739060763093, 14.814529054658323, 15.65267195094927, 16.480875998508694, 7.6732573682909635, 8.730524688881589, 7.797598504500815, 6.846989368812618, 5.963023821280841, 6.856875989472515, 7.765274020759735, 8.734765270687626, 9.73259032623551, 10.76700684885138, 11.746006099976933, 12.625961490365142, 13.601597655715077, 14.545413360383103, 14.915238219798486, 14.04886716540796, 14.848583336855423, 15.818236928932805, 16.60786754841151, 17.545409135806597, 8.60094300192514, 7.807026679425578, 6.804864055004783, 5.827875970916448, 4.914924165574611, 5.907731411149845, 6.807601480070559, 7.833961934973506, 8.758280065007387, 9.787926151349572, 10.79419081562234, 11.623274112500999, 12.55419537162876, 13.580461535214654, 14.532260187222878, 15.045422602367617, 15.869554094890168, 16.869442978961455, 17.625617644149784, 18.607055999028287], [18.411689952818076, 17.584819334430026, 16.755293809545368, 15.942651710460654, 15.68559672515363, 14.626102488572535, 13.671819601964604, 12.654751052889372, 11.645715824388642, 10.795747909730537, 9.804404261284732, 8.760803597113757, 7.83082391189271, 6.820362352250711, 5.877006131600477, 4.867683136567116, 3.8827402541029086, 4.8119444269742795, 5.830412798762687, 6.788352744220793, 17.340004195465053, 17.762008556359433, 16.805673245223574, 15.81568127398185, 14.782342929591268, 13.709504689762374, 12.697071253520583, 11.662563607755107, 10.717262385410882, 9.756697057631758, 8.82426747659063, 7.89144934277737, 6.881903035345185, 5.835128228612198, 4.874178039310593, 3.8615797638943903, 2.8460404432745565, 3.812119283745245, 4.835853743799139, 5.76723288420892, 16.334222408248408, 16.97203855411881, 15.96839237724274, 14.937901319652958, 13.882966368114475, 12.901309242034683, 11.877857583437216, 10.902429092210863, 9.918202009143169, 8.920276518366641, 7.985908208915761, 6.926041728134271, 5.894343297718697, 4.850166757551769, 3.8580382891891594, 2.922181175459211, 1.8747668186318738, 2.862367507693575, 3.8218481275130847, 4.818996469891994, 15.366203100653324, 16.189656476957527, 15.14535104015262, 14.085751773772175, 13.032383459516542, 12.039210327301804, 11.082319214362128, 10.053284838723357, 9.014992152127968, 8.056811091997016, 7.013053513535301, 5.9638951912589775, 4.915079038979871, 3.8684110792113118, 2.794224099269452, 1.868181103302108, 0.9374957237555032, 1.9289837884001155, 2.8563559462907007, 3.8350167281128904, 14.434767418729217, 15.29292873141025, 14.357233467136519, 13.328622448387913, 12.269468934933778, 11.213254798050361, 10.142327084456095, 9.21275882567198, 8.20209234833112, 7.1491429627779794, 6.1165648786900375, 5.059407334384166, 4.032009704138712, 3.0013407922337896, 2.03527724928285, 1.0535512288486648, 0.0, 0.946866040255445, 1.9829142394496977, 2.9136585589035633, 13.45041866485784, 14.464258995221723, 14.825459809558067, 13.869566169245978, 12.847878540457287, 11.82299150735747, 10.775458772518427, 9.799586639765895, 8.832998816997451, 7.890271868095027, 6.927864953470455, 5.992966919825808, 4.924386360025894, 3.911806756198762, 2.9627141172505045, 2.036636576395763, 1.0327520681416533, 1.8827047002736306, 2.8261434090933717, 3.8929666346777463, 12.49524638391603, 13.479075504890094, 14.39634209288624, 14.651430323031663, 13.662033002358076, 12.656815184959463, 11.731727233454764, 10.772588183664872, 9.77754993358441, 8.81665487252947, 7.851251114369583, 6.918084351252959, 5.852170280848662, 4.907088850247132, 3.9561770760617896, 2.990962532959742, 2.016628745699041, 2.8077235051533145, 3.7600689557830886, 4.714062283784661, 11.510692169897329, 12.522437519122986, 13.44596754966619, 14.408402845695718, 14.607785158929051, 13.624485928907431, 12.68839532497144, 11.71231133578433, 10.698548964924754, 9.757404005484933, 8.75051750728786, 7.773743828956877, 6.8031361767235525, 5.843280446478849, 4.882266486233929, 3.9587902690252403, 2.9795427967923915, 3.750741035995512, 4.694848730075439, 5.703600838203408, 10.532041435995644, 11.55175824913196, 12.515923371516676, 13.43919598742783, 14.476980175349889, 14.5570847936551, 13.539628391372196, 12.569383270316568, 11.582392330178298, 10.589340511115232, 9.634211945247628, 8.698721093209121, 7.764701470811698, 6.800217341491185, 5.869297611368345, 4.910085784141477, 3.956634901802574, 4.717972563652818, 5.653540097571882, 6.687358561315415, 9.539530699485654, 10.488713943536201, 11.502961089115985, 12.484114171674067, 13.485698541431438, 14.471112973947823, 14.51173542681014, 13.556172345519192, 12.492101714748133, 11.550036011208082, 10.567413561412277, 9.7229205372039, 8.767667350463423, 7.848645972490121, 6.855210112403754, 5.867030015508819, 5.01638098893441, 5.684852800407779, 6.693761318119102, 7.678943076045038, 8.595393701125605, 9.621563755520143, 10.463273551784013, 11.533827865989817, 12.550407995546458, 13.484543944724393, 14.455427986052722, 14.449465383523874, 13.452956608151135, 12.538103138270193, 11.590319321583062, 10.728422746493143, 9.743230584817391, 8.777466291833404, 7.8380939266418785, 6.843778341375562, 5.965526152053561, 6.695779591567515, 7.685673561358661, 8.606202514772136, 7.639342931944977, 8.547698565609315, 9.535557048626522, 10.577653670596202, 11.582660230334218, 12.560300871028458, 13.566331477463669, 14.580674094439203, 14.417823292702792, 13.494561124480029, 12.536269394036923, 11.716072683981418, 10.740937716699836, 9.749353773496082, 8.833992246851787, 7.837497688345571, 6.959395952966607, 7.70438762444213, 8.76002558495554, 9.565515736821178, 6.651223502487519, 7.621538368851176, 8.648534976874965, 9.596411220971978, 10.648078435637544, 11.592275321685314, 12.566469634651742, 13.52601822917248, 14.48240975515644, 14.479373834632131, 13.526827747628737, 12.652151581084397, 11.730964739703161, 10.713946183737589, 9.760730068832403, 8.905137163930391, 7.994703369296051, 8.691001596901247, 9.69055898766091, 10.592669328909315, 5.736126689678761, 6.797362537212831, 7.74353312682869, 8.741095951490866, 9.735918692873875, 10.731139572022764, 11.720962568992608, 12.716507272857836, 13.708900920626608, 14.742435776925934, 14.539518351449711, 13.61344452516969, 12.721993266445654, 11.74305426699369, 10.826807669693295, 9.908867934387784, 8.947577108033439, 9.676222269303244, 10.651278647310107, 11.64050336607705, 4.920026488420261, 5.969977941732562, 6.868215699755824, 7.8869996015214205, 8.883362220754403, 9.849217344912184, 10.804050594825176, 11.777408436988656, 12.816957815569832, 13.844318577978441, 14.908499663087643, 14.651831710364778, 13.67030504626748, 12.743104133213604, 11.829129878837211, 10.872624338565249, 10.011377020445908, 10.700065356039463, 11.620964053135074, 12.576607075015668, 3.9388421247377448, 4.914832371680147, 5.923898920559559, 6.9757378234876235, 7.9359774300336205, 8.965751830231724, 10.018716529230186, 11.065495566087982, 12.058354302913616, 13.00340359468656, 14.051042834214757, 15.090728383047981, 14.612256138026746, 13.729974008330935, 12.77087685674376, 11.909590774889132, 11.025948653381988, 11.770472218727404, 12.592307109596105, 13.521820604253183, 4.869926909594978, 5.864258009379083, 6.815225335939157, 7.761179308452331, 8.773493057498547, 9.705250769918864, 10.657859172188704, 11.617043403405921, 12.58943729478601, 13.569854730829457, 14.546586425582937, 15.588092909394367, 15.543610184018792, 14.717270717298819, 13.744667714120887, 12.939598179187374, 11.994387945273914, 12.698517002952368, 13.589852276132603, 14.49827019106382, 5.821560680764497, 6.7951475813631035, 7.734432775575944, 6.920042111558989, 7.902591806920536, 8.765881168253328, 9.719851331582243, 10.688993194935051, 11.683955022748368, 12.647118254860048, 13.58988902292784, 14.568879983856949, 15.517154190644412, 15.78281776209413, 14.812706961812315, 13.93060622245958, 12.952803988424382, 13.76097782580966, 14.599120722100604, 15.427324769660032, 6.723434012413288, 7.780701333003915, 6.847775148623139, 5.897166012934943, 6.841973822673904, 7.767399771782342, 8.718781073922848, 9.68827232385074, 10.686097379398623, 11.720513902014494, 12.699513153140046, 13.625544880040374, 14.6068336271532, 15.550649331821226, 15.873299070112857, 14.933564121216516, 13.933648264516712, 14.764685700084142, 15.554316319562846, 16.491857906957936, 7.651119646047464, 6.8572033235479015, 5.855040699127107, 4.878052615038773, 5.814659047530635, 6.818255193459672, 7.761108533233673, 8.78746898813662, 9.711787118170502, 10.741433204512687, 11.747697868785455, 12.628510083939123, 13.559431343066883, 14.585697506652778, 15.537496158661002, 15.930119558176173, 14.954619022551457, 15.815891750112794, 16.57206641530112, 17.553504770179625], [17.464823912562633, 16.637953294174583, 15.808427769289922, 16.617191302910467, 16.632462765409077, 15.57296852882798, 14.618685642220049, 13.601617093144817, 12.592581864644087, 11.74261394998598, 10.751270301540176, 9.7076696373692, 8.777689952148155, 7.767228392506155, 6.823872171855921, 5.814549176822561, 4.829606294358354, 4.237193368755728, 5.055196237958651, 5.9716539981224175, 16.39313815520961, 17.338158113307554, 16.848593421970698, 16.762547314237292, 15.729208969846711, 14.656370730017818, 13.643937293776027, 12.609429648010552, 11.664128425666327, 10.703563097887203, 9.771133516846076, 8.838315383032816, 7.828769075600629, 6.781994268867642, 5.821044079566037, 4.808445804149835, 3.7929064835300013, 3.179535386655317, 4.005695373074356, 4.912412121822632, 15.387356367992965, 16.333084373819915, 16.915258417498187, 15.884767359908405, 14.829832408369922, 13.84817528229013, 12.824723623692662, 11.84929513246631, 10.865068049398616, 9.867142558622088, 8.932774249171207, 7.872907768389716, 6.841209337974142, 5.797032797807213, 4.8049043294446045, 3.8690472157146556, 2.8216328588873187, 2.112017558487488, 2.967027365126796, 3.9641757075057056, 14.41933706039788, 15.38842039554899, 16.092217080408066, 15.032617814027619, 13.979249499771985, 12.986076367557247, 12.029185254617571, 11.0001508789788, 9.961858192383412, 9.00367713225246, 7.959919553790746, 6.910761231514423, 5.8619450792353165, 4.8152771194667565, 3.741090139524897, 2.8150471435575533, 1.884361764010948, 1.0741630260138273, 2.0015351839044127, 2.950085302294531, 13.487901378473772, 14.458154400623561, 15.304099507391964, 14.275488488643358, 13.216334975189223, 12.160120838305806, 11.08919312471154, 10.159624865927425, 9.148958388586566, 8.096009003033425, 7.063430918945483, 6.006273374639611, 4.978875744394157, 3.9482068324892348, 2.9821432895382953, 2.0004172691041098, 0.946866040255445, 0.0, 1.0360481991942527, 1.966792518648118, 12.503552624602396, 13.517392954966278, 14.444675799001025, 14.810270063871913, 13.788582435083223, 12.763695401983405, 11.716162667144362, 10.74029053439183, 9.773702711623386, 8.830975762720962, 7.86856884809639, 6.933670814451744, 5.865090254651829, 4.852510650824697, 3.903418011876439, 2.9401479368040153, 1.936263428549906, 0.9358386600181856, 1.8792773688379265, 2.946100594422301, 11.548380343660584, 12.53220946463465, 13.449476052630795, 14.424201803229913, 14.60273689698401, 13.597519079585398, 12.6724311280807, 11.71329207829081, 10.718253828210345, 9.757358767155406, 8.764085595476383, 7.830918832359759, 6.7650047619554625, 5.819923331353933, 4.859688436470042, 3.8944738933679943, 2.9044323876394698, 1.8608574648978695, 2.8132029155276435, 3.7671962435292157, 10.563826129641884, 11.575571478867543, 12.499101509410744, 13.461536805440273, 14.43016305358704, 14.527997289315683, 13.591906685379692, 12.615822696192582, 11.602060325333007, 10.660915365893185, 9.654028867696113, 8.677255189365129, 7.706647537131804, 6.7467918068871, 5.785777846642181, 4.839195637779657, 3.8062116995484216, 2.803874995740067, 3.7479826898199935, 4.756734797947963, 9.5851753957402, 10.604892208876517, 11.56905733126123, 12.492329947172385, 13.530114135094443, 14.542445162738886, 14.433420265889312, 13.463175144833684, 12.476184204695414, 11.483132385632347, 10.528003819764743, 9.592512967726236, 8.658493345328813, 7.681262484269496, 6.653064886174299, 5.693853058947431, 4.740402176608528, 3.7711065233973735, 4.7066740573164365, 5.74049252105997, 8.59266465923021, 9.541847903280756, 10.55609504886054, 11.537248131418622, 12.538832501175992, 13.524246933692378, 14.572995830521704, 14.449964220036307, 13.385893589265248, 12.443827885725197, 11.461205435929392, 10.616712411721014, 9.60853572372576, 8.632413247296075, 7.638977387209708, 6.650797290314773, 5.690920581384221, 4.737986760152335, 5.746895277863658, 6.732077035789594, 7.64852766087016, 8.674697715264696, 9.516407511528568, 10.586961825734372, 11.603541955291012, 12.537677904468948, 13.508561945797277, 14.476427698871237, 14.34674848266825, 13.431895012787308, 12.460666073047644, 11.512190021299096, 10.526997859623345, 9.561233566639357, 8.621861201447832, 7.627545616181516, 6.640065744503373, 5.748913551312071, 6.738807521103217, 7.6593364745166905, 6.692476891689532, 7.600832525353868, 8.588691008371077, 9.630787630340757, 10.635794190078773, 11.613434830773013, 12.619465437208225, 13.63380805418376, 14.592710575363808, 14.388352998997144, 13.406616145501506, 12.499839958787371, 11.52470499150579, 10.533121048302036, 9.60949822672414, 8.565850063672725, 7.633935545416418, 6.757521584186685, 7.813159544700095, 8.618649696565733, 5.704357462232074, 6.674672328595731, 7.7016689366195195, 8.649545180716533, 9.7012123953821, 10.64540928142987, 11.619603594396299, 12.579152188917037, 13.535543714900996, 14.496452996347172, 14.371388985745961, 13.43591885589035, 12.514732014509114, 11.497713458543542, 10.536236048704756, 9.627261834984592, 8.669242961745862, 7.744135556645801, 8.743692947405465, 9.64580328865387, 4.789260649423316, 5.850496496957386, 6.796667086573245, 7.794229911235422, 8.789052652618432, 9.78427353176732, 10.774096528737164, 11.769641232602394, 12.762034880371166, 13.79556973667049, 14.72542074988759, 14.397211799975643, 13.505760541251608, 12.502549026644141, 11.53234693132622, 10.587779252682136, 9.62211670048325, 8.729356229047799, 9.704412607054664, 10.693637325821605, 3.9731604481648155, 5.023111901477117, 5.921349659500381, 6.940133561265977, 7.936496180498961, 8.902351304656742, 9.857184554569734, 10.830542396733215, 11.87009177531439, 12.897452537722998, 13.961633622832199, 14.997694884053814, 14.42979980591793, 13.502598892864055, 12.508041197131563, 11.5515356568596, 10.685916612895719, 9.753199315784018, 10.67409801287963, 11.629741034760222, 2.9919760844822996, 3.967966331424702, 4.977032880304114, 6.028871783232179, 6.989111389778176, 8.018885789976279, 9.071850488974741, 10.118629525832535, 11.111488262658169, 12.056537554431113, 13.10417679395931, 14.143862342792534, 15.089031057372502, 14.408885326625287, 13.449788175038112, 12.588502093183482, 11.7004882458318, 10.823606178471959, 11.645441069340661, 12.574954563997736, 3.9849954837766193, 4.917391969123638, 5.868359295683712, 6.814313268196885, 7.826627017243101, 8.811303861092952, 9.855629542529309, 10.814813773746526, 11.787207665126614, 12.767625101170061, 13.841697854155552, 14.885630816979425, 15.85538858713069, 15.39618203559317, 14.423579032415239, 13.614137771637186, 12.668927537723725, 11.751650962696923, 12.64298623587716, 13.551404150808374, 4.936629254946138, 5.910216155544745, 6.849501349757586, 7.7771061717763414, 8.759801834280657, 9.712747208508771, 10.666717371837688, 11.635859235190498, 12.630821063003813, 13.593984295115494, 14.536755063183286, 15.515746024112394, 16.464020230899855, 16.46172908038848, 15.491618280106668, 14.605145814909392, 13.627343580874193, 12.814111785554214, 13.652254681845161, 14.480458729404585, 5.868613250027, 6.925880570617625, 6.341161724709631, 6.844032053190388, 7.78883986292935, 8.714265812037786, 9.665647114178293, 10.635138364106185, 11.632963419654068, 12.667379942269939, 13.646379193395491, 14.57241092029582, 15.553699667408646, 16.49751537207667, 16.55221038840721, 15.608103713666328, 14.608187856966524, 13.817819659828697, 14.607450279307402, 15.544991866702489, 6.7962988836611755, 6.081986762743865, 5.280289640908556, 5.824918655294218, 6.76152508778608, 7.765121233715116, 8.707974573489118, 9.734335028392064, 10.658653158425945, 11.68829924476813, 12.694563909040898, 13.575376124194568, 14.506297383322329, 15.532563546908223, 16.484362198916447, 16.604659150625984, 15.629158615001268, 14.869025709857349, 15.625200375045676, 16.606638729924178], [16.660594433177454, 15.99430836785211, 16.778862856587903, 17.58762639020844, 17.66851096460333, 16.609016728022233, 15.654733841414302, 14.63766529233907, 13.62863006383834, 12.778662149180235, 11.787318500734429, 10.743717836563453, 9.813738151342408, 8.803276591700408, 7.859920371050174, 6.850597376016814, 5.865654493552607, 5.085272202796093, 4.066803831007684, 4.962116166438105, 15.588908675824433, 16.533928633922375, 17.490263945058235, 17.798595513431547, 16.765257169040964, 15.692418929212073, 14.679985492970282, 13.645477847204805, 12.70017662486058, 11.739611297081456, 10.80718171604033, 9.874363582227069, 8.864817274794882, 7.818042468061895, 6.85709227876029, 5.844494003344088, 4.828954682724254, 4.041037426177283, 3.017302966123389, 3.9028742901383198, 14.583126888607786, 15.528854894434737, 16.532501071310808, 16.920815559102657, 15.865880607564174, 14.884223481484382, 13.860771822886914, 12.885343331660561, 11.901116248592867, 10.90319075781634, 9.96882244836546, 8.90895596758397, 7.877257537168395, 6.833080997001466, 5.840952528638857, 4.905095414908908, 3.8576810580815715, 2.978369467317693, 1.97863495817583, 2.9546378758213936, 13.615107581012701, 14.584190916163813, 15.589305079952608, 16.068666013221872, 15.01529769896624, 14.022124566751502, 13.065233453811826, 12.036199078173055, 10.997906391577667, 10.039725331446714, 8.995967752984999, 7.946809430708676, 6.89799327842957, 5.85132531866101, 4.7771383387191495, 3.8510953427518055, 2.9204099632052007, 1.9405149348440316, 1.0131427769534462, 1.914037103100278, 12.683671899088594, 13.653924921238383, 14.557615768823673, 15.31153668783761, 14.252383174383475, 13.196169037500058, 12.125241323905792, 11.195673065121676, 10.185006587780817, 9.132057202227676, 8.099479118139735, 7.042321573833863, 6.01492394358841, 4.984255031683487, 4.018191488732548, 3.0364654682983625, 1.9829142394496977, 1.0360481991942527, 0.0, 0.9307443194538654, 11.699323145217218, 12.7131634755811, 13.617867477043585, 14.573761117355675, 14.759017522381203, 13.734130489281386, 12.686597754442342, 11.71072562168981, 10.744137798921367, 9.801410850018943, 8.83900393539437, 7.904105901749722, 6.835525341949808, 5.822945738122677, 4.8738530991744184, 3.910583024101994, 2.906698515847885, 1.9062737473161644, 0.9628350384964234, 1.9281868771312654, 10.744150864275406, 11.70540114267721, 12.622667730673355, 13.597393481272473, 14.554126723829855, 14.567954166883379, 13.64286621537868, 12.683727165588788, 11.688688915508326, 10.727793854453386, 9.734520682774363, 8.801353919657739, 7.735439849253441, 6.790358418651912, 5.8301235237680205, 4.864908980665973, 3.874867474937449, 2.8312925521958485, 1.9518264652925268, 2.905819793294099, 9.759596650256706, 10.748763156910103, 11.672293187453304, 12.634728483482833, 13.6033547316296, 14.586653961651221, 14.562341772677671, 13.586257783490561, 12.572495412630985, 11.631350453191164, 10.624463954994091, 9.647690276663107, 8.677082624429783, 7.717226894185079, 6.7562129339401595, 5.8096307250776364, 4.776646786846401, 3.774310083038046, 2.9593670053338244, 3.9238896779827024, 8.780945916355021, 9.778083886919077, 10.74224900930379, 11.665521625214945, 12.703305813137003, 13.715636840781446, 14.693407410919534, 14.433610232131663, 13.446619291993393, 12.453567472930326, 11.498438907062722, 10.562948055024215, 9.628928432626791, 8.651697571567475, 7.623499973472278, 6.6642881462454095, 5.710837263906507, 4.741541610695353, 3.918058372830268, 4.9352019126178535, 7.765856337272769, 8.715039581323316, 9.7292867269031, 10.710439809461182, 11.687137046135877, 12.672551478652263, 13.721300375481588, 14.668846923230278, 14.356328676563226, 13.414262973023176, 12.43164052322737, 11.587147499018993, 10.578970811023739, 9.602848334594054, 8.609412474507687, 7.621232377612752, 6.6613556686822, 5.708421847450314, 4.980573789036402, 5.9278475564044175, 6.82171933891272, 7.841852595299436, 8.683562391563306, 9.75411670576911, 10.751846500250897, 11.685982449428833, 12.656866490757162, 13.624732243831122, 14.621241019203861, 14.402330100085287, 13.431101160345623, 12.482625108597075, 11.497432946921323, 10.531668653937336, 9.59229628874581, 8.597980703479495, 7.610500831801351, 6.719348638610049, 5.977402488178438, 6.855106995131514, 5.865668569732092, 6.767987405388608, 7.7558458884058155, 8.779092175300642, 9.784098735038658, 10.761739375732898, 11.728539674051595, 12.74288229102713, 13.701784812207178, 14.640146009927145, 14.377051232799484, 13.47027504608535, 12.495140078803768, 11.503556135600014, 10.57993331402212, 9.536285150970706, 8.604370632714398, 7.727956671484664, 7.051754511775316, 7.8144202171805555, 4.871512342266813, 5.841827208630471, 6.849973481579404, 7.797849725676418, 8.849516940341985, 9.792356306822466, 10.728677831239668, 11.688226425760407, 12.644617951744365, 13.605527233190541, 14.558073320193936, 14.406353943188329, 13.485167101807093, 12.46814854584152, 11.506671136002737, 10.597696922282571, 9.639678049043841, 8.71457064394378, 8.100048021082994, 8.841573809268693, 3.9090726180913844, 4.970308465625455, 5.897402752639104, 6.863876008157516, 7.858698749540525, 8.853919628689413, 9.790526936343428, 10.733593033408141, 11.725986681176913, 12.759521537476239, 13.689372550693339, 14.716335265632079, 14.476195628549586, 13.47298411394212, 12.502782018624199, 11.558214339980115, 10.592551787781229, 9.699791316345777, 9.06076768073219, 9.889407846436429, 2.95524673087378, 3.9870637022828648, 4.8853014603061276, 5.904085362071724, 6.9004479813047075, 7.866303105462489, 8.821136355375481, 9.794494197538961, 10.834043576120138, 11.861404338528747, 12.925585423637948, 13.961646684859563, 14.957069288906109, 14.473033980162034, 13.478476284429542, 12.52197074415758, 11.656351700193698, 10.723634403081997, 10.030453086557158, 10.825511555375046, 1.955927885288047, 2.9319181322304493, 3.9409846811098617, 4.992823584037927, 5.953063190583924, 6.982837590782027, 8.03580228978049, 9.082581326638284, 10.075440063463917, 11.020489355236862, 12.068128594765058, 13.107814143598283, 14.05298285817825, 15.084693306448472, 14.42022326233609, 13.558937180481461, 12.670923333129778, 11.794041265769938, 11.001796143018188, 11.770725084612561, 2.948947284582366, 3.8813437699293853, 4.83231109648946, 5.778265069002633, 6.790578818048849, 7.775255661898699, 8.819581343335056, 9.778765574552272, 10.75115946593236, 11.731576901975808, 12.8056496549613, 13.849582617785174, 14.819340387936439, 15.750934496193327, 15.394014119713217, 14.584572858935164, 13.639362625021704, 12.722086049994902, 11.999341309554687, 12.747174671423199, 3.9005810557518847, 4.874167956350492, 5.8134531505633324, 6.741057972582088, 7.723753635086403, 8.707569223150399, 9.674397909734328, 10.643539773087138, 11.659323139055012, 12.68327506489227, 13.626045832960061, 14.60503679388917, 15.553311000676633, 16.538948275354496, 16.462053367404646, 15.57558090220737, 14.597778668172172, 13.784546872852193, 13.008609755522688, 13.67622925001941, 4.859075418342688, 5.916342738933315, 6.859719073912169, 7.763934071206134, 8.708741880945094, 9.706050619621385, 10.671893193167683, 11.641384443095575, 12.639209498643458, 13.609879417737824, 14.588878668863376, 15.514910395763705, 16.534693068919648, 17.478508773587674, 17.52264547570519, 16.578538800964306, 15.578622944264502, 14.788254747126675, 13.963805352984929, 14.740762387317314, 5.786761051976864, 5.093594355792899, 6.103690113140371, 6.860966854488471, 7.797573286980334, 8.801169432909369, 9.74402277268337, 10.770383227586318, 11.694701357620199, 12.724347443962383, 13.730612108235151, 14.611424323388821, 15.542345582516582, 16.568611746102476, 17.5204103981107, 17.575094237923963, 16.599593702299245, 15.839460797155327, 14.981555448723203, 15.802409250539002], [15.740655815781942, 16.55686035020517, 17.594927393155956, 18.518370709662307, 18.599255284057193, 17.539761047476098, 16.585478160868167, 15.568409611792935, 14.559374383292205, 13.7094064686341, 12.718062820188294, 11.674462156017318, 10.744482470796273, 9.734020911154273, 8.79066469050404, 7.781341695470679, 6.796398813006472, 6.007780164230754, 4.989311792442346, 4.03137184698424, 14.668970058428918, 15.613990016526861, 16.570325327662722, 17.560317298904444, 17.69600148849483, 16.623163248665936, 15.610729812424147, 14.57622216665867, 13.630920944314445, 12.670355616535321, 11.737926035494194, 10.805107901680934, 9.795561594248747, 8.74878678751576, 7.787836598214155, 6.775238322797953, 5.759699002178119, 4.971781745631149, 3.948047285577255, 2.9721299706844544, 13.663188271212272, 14.608916277039222, 15.612562453915292, 16.617236690617677, 16.79662492701804, 15.814967800938247, 14.791516142340779, 13.816087651114426, 12.831860568046732, 11.833935077270205, 10.899566767819325, 9.839700287037834, 8.80800185662226, 7.763825316455331, 6.771696848092723, 5.835839734362773, 4.788425377535437, 3.9091137867715577, 2.9093792776296956, 2.023893556367528, 12.695168963617187, 13.664252298768298, 14.669366462557095, 15.602617867410721, 15.946042018420105, 14.952868886205367, 13.995977773265691, 12.96694339762692, 11.928650711031532, 10.97046965090058, 9.926712072438864, 8.87755375016254, 7.828737597883435, 6.782069638114875, 5.707882658173015, 4.781839662205671, 3.8511542826590666, 2.8712592542978967, 1.9438870964073116, 0.9832927836464128, 11.76373328169308, 12.733986303842869, 13.63767715142816, 14.655082438570492, 15.183127493837342, 14.126913356953924, 13.055985643359659, 12.126417384575543, 11.115750907234684, 10.062801521681543, 9.030223437593602, 7.973065893287729, 6.9456682630422755, 5.914999351137353, 4.948935808186413, 3.9672097877522283, 2.9136585589035633, 1.966792518648118, 0.9307443194538654, 0.0, 10.779384527821703, 11.793224858185585, 12.697928859648073, 13.653822499960162, 14.57892763701142, 14.66487480873525, 13.617342073896207, 12.641469941143676, 11.674882118375232, 10.732155169472808, 9.769748254848235, 8.834850221203588, 7.766269661403674, 6.753690057576542, 5.804597418628284, 4.84132734355586, 3.8374428353017507, 2.83701806677003, 1.8935793579502889, 0.9974425576774, 9.824212246879892, 10.785462525281698, 11.702729113277842, 12.67745486387696, 13.634188106434342, 14.639405923832955, 14.573610534832545, 13.614471485042653, 12.619433234962191, 11.658538173907251, 10.665265002228228, 9.732098239111604, 8.666184168707307, 7.7211027381057775, 6.760867843221886, 5.795653300119839, 4.805611794391314, 3.762036871649714, 2.882570784746392, 1.9858811758985855, 8.839658032861191, 9.82882453951459, 10.752354570057792, 11.71478986608732, 12.683416114234088, 13.666715344255708, 14.6028059481917, 14.517002102944426, 13.50323973208485, 12.562094772645029, 11.555208274447956, 10.578434596116972, 9.607826943883648, 8.647971213638945, 7.686957253394025, 6.740375044531501, 5.707391106300266, 4.705054402491911, 3.8901113247876897, 3.003951060587189, 7.861007298959508, 8.858145269523565, 9.822310391908278, 10.745583007819432, 11.773292886561956, 12.785623914206399, 13.762663091465669, 14.732908212521297, 14.377363611447258, 13.38431179238419, 12.429183226516587, 11.49369237447808, 10.559672752080656, 9.58244189102134, 8.554244292926143, 7.595032465699275, 6.641581583360373, 5.672285930149219, 4.848802692284133, 4.01526329522234, 6.8459177198772565, 7.795100963927803, 8.809348109507587, 9.790501192065669, 10.756392726682012, 11.741807159198398, 12.790556056027723, 13.738102603776413, 14.651351593152999, 14.34500729247704, 13.362384842681235, 12.517891818472858, 11.509715130477604, 10.533592654047919, 9.540156793961552, 8.551976697066618, 7.592099988136066, 6.63916616690418, 5.911318108490268, 5.007908939008903, 5.901780721517207, 6.921913977903923, 7.763623774167795, 8.834178088373598, 9.821102180797032, 10.755238129974968, 11.726122171303297, 12.693987924377257, 13.690496699749996, 14.665859676683116, 14.36184547979949, 13.413369428050942, 12.42817726637519, 11.462412973391203, 10.523040608199677, 9.528725022933362, 8.541245151255216, 7.650092958063915, 6.908146807632304, 5.935168377736, 4.945729952336579, 5.848048787993095, 6.835907271010303, 7.848347855846777, 8.853354415584793, 9.830995056279033, 10.79779535459773, 11.812137971573264, 12.771040492753313, 13.70940169047328, 14.617887354331884, 14.401019365539216, 13.425884398257635, 12.434300455053881, 11.510677633475986, 10.46702947042457, 9.535114952168263, 8.658700990938529, 7.8210091782964115, 6.894481599785041, 3.9515737248713, 4.921888591234958, 5.919229162125539, 6.867105406222553, 7.918772620888119, 8.861611987368601, 9.797933511785804, 10.757482106306542, 11.7138736322905, 12.674782913736676, 13.62732900074007, 14.562799130595682, 14.41591142126096, 13.398892865295387, 12.437415455456602, 11.528441241736436, 10.570422368497706, 9.645314963397645, 8.85383286646484, 7.921635191873179, 2.9783282986375186, 4.039564146171589, 4.9666584331852395, 5.933131688703651, 6.92795443008666, 7.923175309235548, 8.859782616889563, 9.802848713954276, 10.795242361723048, 11.828777218022374, 12.758628231239474, 13.785590946178214, 14.837382795421275, 14.403728433395985, 13.433526338078064, 12.48895865943398, 11.523296107235094, 10.630535635799642, 9.814552526114038, 8.969469229040914, 2.024502411419914, 3.056319382829, 3.9545571408522626, 4.973341042617859, 5.969703661850843, 6.935558786008624, 7.890392035921615, 8.863749878085097, 9.903299256666273, 10.930660019074882, 11.994841104184083, 13.030902365405698, 14.026324969452244, 14.953525882506119, 14.409220603883407, 13.452715063611445, 12.587096019647563, 11.654378722535862, 10.784237931939005, 9.905572937979532, 1.0251835658341817, 2.0011738127765843, 3.0102403616559967, 4.062079264584062, 5.022318871130059, 6.052093271328162, 7.105057970326624, 8.151837007184419, 9.144695744010052, 10.089745035782997, 11.137384275311193, 12.177069824144418, 13.122238538724385, 14.153948986994607, 15.113046138581781, 14.489681499935326, 13.601667652583643, 12.724785585223803, 11.755580988400036, 10.850786467217045, 2.018202965128501, 2.9505994504755204, 3.901566777035595, 4.847520749548768, 5.859834498594984, 6.844511342444834, 7.888837023881191, 8.848021255098407, 9.820415146478496, 10.800832582521943, 11.874905335507435, 12.918838298331309, 13.888596068482574, 14.820190176739462, 15.792793179917394, 15.51531717838903, 14.570106944475569, 13.652830369448766, 12.753126154936535, 11.827236054027683, 2.96983673629802, 3.9434236368966267, 4.8827088311094675, 5.810313653128223, 6.793009315632538, 7.776824903696534, 8.743653590280463, 9.712795453633273, 10.728578819601147, 11.752530745438404, 12.695301513506196, 13.674292474435305, 14.622566681222768, 15.608203955900631, 16.66305942123804, 16.506325221661236, 15.528522987626037, 14.715291192306058, 13.7428456217201, 12.756290632623895, 3.9283310988888225, 4.985598419479448, 5.928974754458304, 6.833189751752269, 7.7779975614912304, 8.77530630016752, 9.741148873713819, 10.71064012364171, 11.708465179189593, 12.67913509828396, 13.658134349409512, 14.58416607630984, 15.603948749465783, 16.54776445413381, 17.487549581995246, 17.50928312041817, 16.509367263718367, 15.71899906658054, 14.698041219182342, 13.820823769921798, 4.856016732522998, 5.809385029355681, 6.819480786703154, 7.791711173942336, 8.728317606434198, 9.72445087849019, 10.674767092137236, 11.675900220066287, 12.625445677074064, 13.655091763416248, 14.661356427689016, 15.542168642842686, 16.473089901970447, 17.49935606555634, 18.451154717564563, 18.505838557377828, 17.53033802175311, 16.66698365007182, 15.715791314920615, 14.882470633143486], [4.961271287960237, 5.777475822383467, 6.815542865334253, 7.753413960225026, 8.822994765493544, 9.837104263498565, 10.791387150106496, 11.808455699181728, 12.686966273540282, 13.639375355562787, 14.682438303334719, 15.622157308428132, 16.552136993649178, 17.562598553291178, 18.50595477394141, 18.318101801424955, 17.333158918960752, 16.740745993358125, 15.766126976224902, 14.810756374805942, 3.889585530607214, 4.834605488705158, 5.790940799841019, 6.780932771082742, 7.814271115473323, 8.863275119928517, 9.81810400978478, 10.813211612218296, 11.758512834562522, 12.719078162341646, 13.651507743382773, 14.584325877196033, 15.637064556034037, 16.683839362767024, 17.730368269230226, 17.31199842875223, 16.2964591081324, 15.683088011257714, 14.716626111340606, 13.751514498506157, 2.883803743390568, 3.8295317492175194, 4.8331779260935885, 5.86366898368337, 6.918603935221853, 7.865257309949482, 8.822965450346615, 9.798393941572968, 10.782621024640662, 11.78054651541719, 12.714914824868071, 13.774781305649562, 14.811904610096484, 15.806657894796484, 16.79977524806555, 16.37259984031705, 15.325185483489715, 14.615570183089885, 13.677958103393047, 12.803278084189232, 1.9157844357954836, 2.884867770946595, 3.921986351423831, 4.866443487883732, 5.87370762263588, 6.866880754850618, 7.823771867790294, 8.852806243429065, 9.891098930024453, 10.849279990155406, 11.821972874161865, 12.81312507788921, 13.861941230168314, 14.824902216456028, 15.837075062302581, 15.318599768159949, 14.387914388613344, 13.577715650616224, 12.712465922170663, 11.762677311468117, 0.9843487538713767, 1.954601776021166, 2.8902970402948975, 3.9189080590435026, 4.912852092884281, 5.969066229767698, 6.998779078849101, 7.928347337633217, 8.939013814974075, 9.868831792811953, 10.892407045085054, 11.860321963603857, 12.845937900046804, 13.869744936152214, 14.786047192991667, 14.503969893706506, 13.45041866485784, 12.503552624602396, 11.699323145217218, 10.779384527821705, 0.0, 1.0138403303638814, 1.9958646327164493, 2.9517582730285383, 3.973445901817228, 4.998332934917046, 6.04586566975609, 7.021737802508622, 7.988325625277066, 8.931052574179489, 9.893459488804062, 10.828357522448709, 11.896938082248623, 12.909517686075754, 13.858610325024012, 13.57202324137004, 12.56813873311593, 11.56771396458421, 10.736488106720794, 9.781941970144304, 0.9551722809418117, 1.994806488859598, 2.99106437908668, 3.9407634263448625, 4.9181854323943055, 5.923403249792918, 6.848491201297617, 7.8153498021634, 8.810388052243862, 9.857435578613932, 10.889669991147178, 11.822836754263802, 12.84354462628972, 13.78862605689125, 13.56636813714546, 12.642701288942964, 11.64174791051971, 10.642695159704525, 9.74749667992469, 8.79350335192312, 1.9397264949605126, 2.951444474626705, 3.9343112766737165, 4.896746572703246, 5.8653728208500135, 6.8486720508716346, 7.7847626548076265, 8.760846643994736, 9.774609014854311, 10.715753974294133, 11.722640472491205, 12.69941415082219, 13.670021803055514, 13.569244367955259, 12.640278726973321, 11.674873552877466, 10.678833859426359, 9.699677628862327, 8.756631063839341, 7.775433467234516, 2.9183772288621967, 3.922123744617731, 4.8643554548232295, 5.835005857617957, 6.872790045540015, 7.781270915619303, 8.795900753490017, 9.766145874545645, 10.753136814683915, 11.655776620471649, 12.610905186339252, 13.54639603837776, 13.519851335853021, 12.612307472942923, 11.614404463981947, 10.655192636755078, 9.701741754416176, 8.73244610120502, 7.797939696342898, 6.764121232599365, 3.9873419263823866, 4.936525170432933, 5.877317737223921, 6.790087673371721, 7.838770770325251, 8.824185202841637, 9.768007788927962, 10.770622966488224, 11.73643366906846, 12.67849937260851, 13.5441068025039, 13.513092775756034, 12.516885456201296, 11.54076297977161, 10.658872161159739, 9.727204129265335, 8.718499685681946, 7.76556586445006, 6.756657346738737, 5.771475588812801, 4.931478924742436, 5.949096040091816, 6.9501122452138855, 7.762760579585015, 8.774061316210231, 9.708197265388167, 10.679081306716496, 11.646947059790456, 12.643455835163195, 13.66656649967062, 13.454097175454383, 12.505621123705835, 11.520428962030083, 10.554664669046096, 9.63705000665914, 8.750455803398593, 7.80989459813829, 6.860524769298959, 5.885782530144912, 4.844216150085704, 5.887529693923064, 6.853174671141244, 7.841033154158452, 8.810923430094444, 9.74180908142247, 10.635695717793405, 11.67510643869262, 12.62002161685687, 13.585831089153928, 13.631176423813631, 12.596236654883562, 11.630888872022863, 10.655753904741282, 9.582777187383417, 8.64115168644923, 7.756736456428584, 6.824821938172276, 5.851916736424344, 4.811430506548033, 3.884902928036663, 6.881685921388343, 7.779334867899381, 8.80633147592317, 9.754207720020183, 10.73495386478949, 11.642744237677867, 12.616938550644296, 13.576487145165034, 13.557466928523203, 12.596557647077027, 11.644011560073633, 10.708541430218022, 9.764274292803913, 8.740153869072364, 7.714413864468614, 6.76537813936141, 5.8073592661226785, 4.865302763965228, 3.8657453732055647, 2.9483649690278213, 7.933887916418702, 8.835994225242741, 9.75890220486347, 10.72963423750302, 11.72445697888603, 12.58118091581092, 13.555089445540537, 13.84946149052195, 12.857067842753178, 11.823532986453854, 10.893681973236754, 9.944518664702594, 8.892726815459532, 7.824384817007954, 6.854182721690033, 5.909615043045948, 4.943952490847062, 3.928700131724402, 2.905025713556367, 1.900530931860085, 8.887713803636307, 9.890886226341763, 10.771003497196446, 11.689424883588812, 12.685787502821794, 13.596888946774321, 14.054886027347147, 13.081528185183666, 12.04197880660249, 11.014618044193881, 9.95043695908468, 8.914375697863065, 7.918953093816518, 6.991752180762644, 5.934308260497232, 4.97780272022527, 3.9694440572826037, 3.0051820076653923, 2.0231387629308135, 0.9644272229214675, 9.933876933028646, 10.909867179971048, 11.715320276392712, 12.616959072798645, 13.577198679344642, 14.606973079542744, 14.87808475397355, 13.831305717115754, 12.83844698029012, 11.893397688517176, 10.84575844898898, 9.806072900155755, 8.860904185575786, 7.835152389990957, 6.876055238403781, 6.014769156549153, 4.984015690218683, 4.009668107916428, 2.9421447786197525, 1.9096407521589818, 10.977688172953286, 11.859292817669983, 12.68464651465214, 13.619607639338973, 14.615734061645785, 15.538574935133221, 15.753802251817108, 14.794618020599891, 13.822224129219803, 12.841806693176355, 11.767733940190865, 10.723800977366993, 9.754043207215728, 8.82244909895884, 7.849846095780908, 6.89766521602407, 5.952454982110609, 4.921199961713054, 3.9200124771716816, 2.8565739970718784, 11.929321944122805, 12.886448064374912, 13.756075886686032, 14.67459973347448, 15.657295395978796, 16.47794453679876, 16.568004610135468, 15.598862746782657, 14.583079380814784, 13.559127454977526, 12.616356686909734, 11.637365725980626, 10.689091519193163, 9.887996143754151, 8.916184031305194, 7.882133204635177, 6.842030334415952, 5.833142292849338, 4.772183564764295, 3.7856285756680896, 12.899273782664194, 13.935075975221226, 14.80234181003487, 15.697475832098526, 16.642283641837487, 17.476425933269745, 17.487464635914726, 16.517973385986835, 15.520148330438952, 14.48573180782308, 13.580685067111371, 12.654653340211043, 11.6348706670551, 10.691054962387074, 9.751269834525637, 8.751684368595336, 7.741989898019039, 6.762245198983517, 5.727379162226536, 4.850161712965993, 13.82695941629837, 14.780327713131054, 15.790423470478528, 16.716589229994696, 17.653195662486556, 18.425570511592415, 18.4451371766039, 17.483233482411414, 16.533403621209093, 15.557429088203683, 14.61752539744684, 13.613194210269178, 12.682272951141417, 11.675290641596495, 10.723491989588272, 9.72688360576595, 8.713266742303421, 7.696321593116016, 6.745129257964811, 5.91180857618768], [5.950623118341125, 5.025184304938095, 6.0632513478888805, 6.9016349791467455, 7.9143540011759965, 8.823263933134685, 9.777546819742616, 10.794615368817848, 11.673125943176403, 12.625535025198909, 13.66859797297084, 14.608316978064254, 15.5382966632853, 16.548758222927297, 17.49211444357753, 17.642205948771494, 16.743147065898178, 15.958522325567762, 15.250566072256813, 15.82262525963134, 4.878937360988102, 4.082313971259786, 5.029703217897442, 5.929153790004461, 6.891228701775301, 7.849434789564636, 8.8042636794209, 9.799371281854418, 10.744672504198643, 11.705237831977767, 12.637667413018894, 13.570485546832154, 14.623224225670159, 15.669999032403146, 16.716527938866346, 17.704988864646534, 17.310299438496283, 16.696928341621597, 15.730466441704488, 14.76535482887004, 3.8731555737714567, 3.077240231772147, 3.9633872931287883, 4.901332133322171, 5.92144044655501, 6.8514169795856015, 7.809125119982736, 8.78455361120909, 9.768780694276783, 10.76670618505331, 11.70107449450419, 12.760940975285681, 13.798064279732603, 14.792817564432603, 15.785934917701672, 16.765590276211356, 16.3390258138536, 15.629410513453768, 14.69179843375693, 13.817118414553114, 2.905136266176372, 2.0144388869391436, 2.9534619052615887, 3.8867133101152165, 4.859867292272, 5.853040424486737, 6.809931537426413, 7.838965913065183, 8.877258599660571, 9.835439659791524, 10.808132543797983, 11.799284747525327, 12.848100899804432, 13.811061886092146, 14.823234731938697, 15.710566583148543, 15.401754718977228, 14.591555980980107, 13.726306252534545, 12.776517641832, 1.973700584252265, 1.0034475621024757, 1.921772594132655, 2.939177881274987, 3.8990117625204, 4.955225899403818, 5.98493874848522, 6.914507007269336, 7.925173484610194, 8.854991462448073, 9.878566714721172, 10.846481633239975, 11.832097569682922, 12.855904605788332, 13.772206862627783, 14.75393288306197, 14.464258995221725, 13.51739295496628, 12.7131634755811, 11.793224858185587, 1.0138403303638814, 0.0, 0.9820243023525679, 1.9379179426646571, 2.9596055714533467, 3.984492604553165, 5.0320253393922085, 6.007897472144741, 6.974485294913185, 7.917212243815608, 8.87961915844018, 9.814517192084827, 10.88309775188474, 11.895677355711872, 12.84476999466013, 13.808040069732554, 13.581979063479814, 12.581554294948093, 11.750328437084676, 10.795782300508186, 1.9690126113056932, 1.0591907388043873, 1.9772240487227988, 2.9269230959809813, 3.9043451020304243, 4.909562919429037, 5.834650870933736, 6.801509471799519, 7.796547721879982, 8.84359524825005, 9.875829660783296, 10.80899642389992, 11.829704295925838, 12.774785726527368, 13.735020621411259, 13.656541619306848, 12.655588240883594, 11.656535490068409, 10.761337010288573, 9.807343682287001, 2.953566825324394, 2.0158287245714943, 2.927598591942849, 3.890033887972379, 4.855117094230678, 5.838416324252299, 6.774506928188291, 7.750590917375401, 8.764353288234977, 9.705498247674798, 10.712384745871871, 11.689158424202855, 12.65976607643618, 13.619621806680883, 13.654119057337205, 12.68871388324135, 11.692674189790242, 10.71351795922621, 9.770471394203225, 8.789273797598398, 3.9322175592260784, 2.98650799456252, 3.8576427700923626, 4.82829317288709, 5.866077360809148, 6.771015188999968, 7.7856450268706805, 8.755890147926308, 9.742881088064578, 10.645520893852314, 11.600649459719918, 12.536140311758425, 13.470159934155848, 13.626147803306804, 12.62824479434583, 11.669032967118962, 10.71558208478006, 9.746286431568905, 8.811780026706781, 7.777961562963247, 4.998735544208827, 4.049552300158281, 4.870605052493055, 5.783374988640853, 6.832058085594383, 7.817472518110768, 8.757752062308626, 9.760367239868888, 10.726177942449123, 11.668243645989174, 12.533851075884566, 13.560339755753203, 13.530725786565176, 12.55460331013549, 11.672712491523619, 10.741044459629219, 9.732340016045828, 8.779406194813943, 7.770497677102619, 6.785315919176683, 5.942872542568876, 5.062123169817164, 5.943399560483019, 6.756047894854147, 7.767348631479363, 8.701484580657299, 9.672368621985628, 10.640234375059588, 11.636743150432327, 12.656310773051285, 13.556756836055351, 13.519461454069715, 12.534269292393963, 11.568504999409976, 10.65089033702302, 9.764296133762475, 8.823734928502171, 7.87436509966284, 6.899622860508794, 5.858056480449586, 6.898923311749504, 6.135988359727992, 6.871116063640511, 7.804210745363576, 8.735096396691603, 9.628983033062537, 10.668393753961752, 11.613308932126003, 12.57911840442306, 13.600350679171038, 13.610076985247442, 12.644729202386744, 11.669594235105162, 10.596617517747298, 9.654992016813111, 8.770576786792466, 7.838662268536158, 6.865757066788225, 5.8252708369119155, 4.898743258400545, 7.893079539214783, 7.062148556486129, 7.8585436355021585, 8.785453194987799, 9.728241180058623, 10.636031552947, 11.610225865913428, 12.569774460434166, 13.526165986418125, 13.610397977440908, 12.657851890437513, 11.722381760581902, 10.778114623167793, 9.753994199436244, 8.728254194832495, 7.779218469725291, 6.82119959648656, 5.879143094329109, 4.879585703569446, 3.9622052993917025, 8.945281534245144, 8.118807913829489, 8.811114364442458, 9.760879712470636, 10.75134570851397, 11.574468231080052, 12.548376760809669, 13.559700763815503, 13.870908173117058, 12.837373316817734, 11.907522303600635, 10.958358995066474, 9.906567145823413, 8.838225147371835, 7.868023052053914, 6.923455373409829, 5.957792821210943, 4.942540462088283, 3.9188660439202483, 2.914371262223966, 9.899107421462748, 9.17369991492851, 9.823215656775435, 10.720670358556427, 11.71703297778941, 12.590176262043453, 13.517767341777615, 14.095368515547547, 13.05581913696637, 12.028458374557761, 10.96427728944856, 9.928216028226945, 8.9327934241804, 8.005592511126524, 6.948148590861114, 5.991643050589151, 4.983284387646485, 4.0190223380292736, 3.036979093294695, 1.9782675532853489, 10.945270550855087, 10.228845484980926, 10.7675324359717, 11.64820454776626, 12.608444154312258, 13.63821855451036, 14.544248672633817, 14.845146047479634, 13.852287310654, 12.907238018881056, 11.85959877935286, 10.819913230519635, 9.874744515939666, 8.848992720354838, 7.889895568767662, 7.028609486913034, 5.997856020582565, 5.0235084382803095, 3.9559851089836338, 2.923481082522863, 11.989081790779727, 11.178271122679861, 11.73685867423113, 12.650853114306589, 13.6469795366134, 14.569820410100837, 15.493064382671262, 15.808458350963775, 14.836064459583687, 13.85564702354024, 12.78157427055475, 11.737641307730875, 10.76788353757961, 9.836289429322722, 8.86368642614479, 7.91150554638795, 6.96629531247449, 5.910551792093942, 4.90936430755257, 3.845925827452767, 12.940715561949245, 12.20542636938479, 12.808288046265021, 13.705845208442096, 14.688540870946412, 15.509190011766373, 16.431072223277724, 16.612703077146538, 15.596919711178666, 14.572967785341408, 13.630197017273616, 12.651206056344508, 11.702931849557045, 10.901836474118033, 9.905535861686083, 8.871485035016065, 7.831382164796841, 6.822494123230227, 5.761535395145183, 4.774980406048978, 13.910667400490635, 13.254054280231104, 13.854553969613859, 14.728721307066142, 15.673529116805103, 16.50767140823736, 17.43214248093712, 17.502163057717148, 16.533988660802834, 15.499572138186963, 14.57003689749226, 13.644005170591932, 12.624222497435989, 11.680406792767963, 10.740621664906525, 9.741036198976225, 8.731341728399928, 7.7515970293644045, 6.716730992607424, 5.8395135433468806, 14.838353034124811, 14.223775547471599, 14.915426053414933, 15.747834704962312, 16.684441137454172, 17.45681598656003, 17.48950440391026, 16.53690296129257, 15.559300499120999, 14.644203848352047, 13.63793918407928, 12.655920202726884, 11.761480089963438, 10.758619355301596, 9.806820703293372, 8.86660033087117, 7.889667667055942, 6.989129559218208, 6.037937224067003, 6.901160406568568], [6.822619112292469, 5.897180298889437, 5.087844568225648, 5.919610676794178, 6.932329698823429, 7.841239630782117, 8.795522517390049, 9.81259106646528, 10.691101640823835, 11.64351072284634, 12.686573670618271, 13.626292675711685, 14.55627236093273, 15.56673392057473, 16.510090141224964, 16.660181646418927, 15.761122763545607, 14.976498023215193, 15.778096648015586, 16.553483590411183, 5.750933354939447, 4.954309965211128, 4.047678915544873, 4.947129487651893, 5.909204399422733, 6.8674104872120685, 7.822239377068332, 8.817346979501849, 9.762648201846075, 10.723213529625198, 11.655643110666325, 12.588461244479586, 13.64119992331759, 14.687974730050577, 15.734503636513777, 16.722964562293967, 16.79782257437396, 16.0341560053156, 16.635170443166974, 15.597726859474845, 4.7451515677228, 3.9492362257234896, 2.9813629907762205, 3.919307830969603, 4.9394161442024425, 5.869392677233034, 6.827100817630168, 7.8025293088565215, 8.786756391924214, 9.784681882700742, 10.719050192151624, 11.778916672933114, 12.816039977380036, 13.810793262080033, 14.803910615349102, 15.783565973858787, 16.59649875521895, 16.55669335748852, 15.596502435219415, 14.698343372672161, 3.7771322601277153, 2.8864348808904867, 1.9714376029090208, 2.904689007762648, 3.877842989919432, 4.8710161221341695, 5.8279072350738454, 6.8569416107126155, 7.895234297308004, 8.853415357438957, 9.826108241445416, 10.817260445172758, 11.866076597451864, 12.829037583739577, 13.84121042958613, 14.728542280795976, 15.65922766034258, 15.518838825014857, 14.631010253997031, 13.681221643294485, 2.8456965782036083, 1.875443556053819, 0.9397482917800872, 1.957153578922419, 2.916987460167832, 3.9732015970512498, 5.002914446132652, 5.932482704916768, 6.943149182257626, 7.872967160095505, 8.896542412368605, 9.864457330887406, 10.850073267330353, 11.873880303435763, 12.790182560275216, 13.771908580709402, 14.825459809558067, 14.444675799001029, 13.617867477043585, 12.697928859648073, 1.9958646327164493, 0.9820243023525679, 0.0, 0.9558936403120892, 1.977581269100779, 3.0024683022005973, 4.050001037039641, 5.025873169792173, 5.992460992560617, 6.93518794146304, 7.897594856087612, 8.832492889732258, 9.901073449532172, 10.913653053359303, 11.862745692307561, 12.826015767379985, 13.829900275634095, 13.508837138982843, 12.655032438547162, 11.700486301970672, 2.9510369136582613, 1.9949647371473467, 0.9951997463702309, 1.9448987936284134, 2.9223207996778564, 3.9275386170764692, 4.852626568581168, 5.819485169446951, 6.814523419527414, 7.861570945897483, 8.893805358430729, 9.826972121547353, 10.84767999357327, 11.792761424174799, 12.75299631905869, 13.718210862160738, 13.603967350698396, 12.583818334103158, 11.666041011751059, 10.712047683749487, 3.935591127676962, 2.9284410916372927, 1.945574289590281, 2.9080095856198107, 3.8730927918781104, 4.856392021899731, 5.792482625835723, 6.768566615022833, 7.782328985882409, 8.723473945322231, 9.730360443519304, 10.707134121850288, 11.677741774083612, 12.637597504328316, 13.598611464573235, 13.637092993056152, 12.641053299605044, 11.64080080326096, 10.696693109181034, 9.693977799060884, 4.914241861578646, 3.8536423931566683, 2.8756184677397942, 3.8462688705345216, 4.88405305845658, 5.7889908866474, 6.803620724518113, 7.773865845573741, 8.760856785712011, 9.663496591499747, 10.618625157367351, 11.554116009405858, 12.488135631803281, 13.465366492862598, 13.576623904160632, 12.617412076933764, 11.663961194594862, 10.694665541383708, 9.73800174168459, 8.704183277941056, 5.852011139770816, 4.90282789572027, 3.888580750140486, 4.801350686288285, 5.850033783241816, 6.835448215758201, 7.775727759956058, 8.778342937516319, 9.744153640096556, 10.686219343636607, 11.551826773532, 12.578315453400636, 13.491101511455007, 13.53662761248806, 12.654736793876188, 11.723068761981786, 10.714364318398395, 9.76143049716651, 8.752521979455187, 7.767340221529251, 6.7961481381308655, 5.915398765379153, 4.961375258130451, 5.774023592501578, 6.785324329126796, 7.719460278304732, 8.690344319633061, 9.658210072707021, 10.65471884807976, 11.674286470698718, 12.574732533702784, 13.523208585451332, 13.516293594746532, 12.550529301762545, 11.632914639375588, 10.746320436115042, 9.80575923085474, 8.856389402015408, 7.881647162861363, 6.840080782802154, 7.752198907311493, 6.87695024430515, 5.8890917612879425, 6.822186443011007, 7.753072094339036, 8.64695873070997, 9.686369451609185, 10.631284629773436, 11.597094102070493, 12.618326376818471, 13.520682606156646, 13.62675350473931, 12.651618537457729, 11.578641820099866, 10.63701631916568, 9.752601089145033, 8.820686570888725, 7.847781369140793, 6.807295139264483, 5.880767560753113, 8.746355134776772, 7.803110441063287, 6.87651933314959, 7.80342889263523, 8.746216877706056, 9.654007250594432, 10.62820156356086, 11.5877501580816, 12.544141684065558, 13.505050965511733, 13.639876192790082, 12.70440606293447, 11.760138925520362, 10.736018501788813, 9.710278497185064, 8.761242772077859, 7.803223898839128, 6.861167396681677, 5.861610005922014, 4.94422960174427, 9.798557129807133, 8.775260651705748, 7.82909006208989, 8.778855410118068, 9.769321406161403, 10.592443928727485, 11.566352458457102, 12.577676461462936, 13.501254873241962, 13.819397619170305, 12.889546605953205, 11.940383297419041, 10.88859144817598, 9.820249449724402, 8.850047354406481, 7.905479675762397, 6.939817123563511, 5.924564764440851, 4.900890346272816, 3.896395564576534, 10.752383017024737, 9.83015265280477, 8.841191354422866, 9.738646056203859, 10.735008675436841, 11.608151959690886, 12.535743039425048, 13.509100881588529, 14.03784343931894, 13.010482676910332, 11.94630159180113, 10.910240330579516, 9.914817726532968, 8.987616813479093, 7.930172893213682, 6.97366735294172, 5.965308689999054, 5.001046640381842, 4.019003395647263, 2.9602918556379167, 11.770564929440946, 10.794574682498544, 9.785508133619132, 10.666180245413692, 11.626419851959689, 12.656194252157793, 13.56222437028125, 14.492950588444147, 14.834311613006568, 13.889262321233623, 12.841623081705427, 11.801937532872202, 10.856768818292235, 9.831017022707405, 8.87191987112023, 8.010633789265603, 6.976384908096945, 5.949092180759767, 4.881568851463092, 3.8490648250023205, 12.719940121559569, 11.705801698438634, 10.75483437187856, 11.66882881195402, 12.664955234260832, 13.58779610774827, 14.511040080318695, 15.470224311535912, 15.818088761936254, 14.837671325892806, 13.763598572907316, 12.719665610083442, 11.749907839932177, 10.818313731675289, 9.845710728497357, 8.784441356601956, 7.839231122688496, 6.782547786045285, 5.781360301503913, 4.71792182140411, 13.671573892729088, 12.732956945143563, 11.826263743912452, 12.723820906089527, 13.706516568593843, 14.527165709413806, 15.449047920925157, 16.418189784277967, 16.532170534947156, 15.508218609109896, 14.599110467030565, 13.621325483097378, 12.673051276309915, 11.808691192593479, 10.777531855637427, 9.743481028967409, 8.703378158748183, 7.694490117181569, 6.633531389096525, 5.64697640000032, 14.641525731270477, 13.781584855989877, 12.87252966726129, 13.746697004713573, 14.691504814452534, 15.525647105884792, 16.450118178584553, 16.520138755364577, 15.59053148753857, 14.581614256264341, 13.602615005138789, 12.67658327823846, 11.680619388532902, 10.736803683864876, 9.797018556003438, 8.881131465478258, 7.928614122738119, 7.078452677686874, 7.5887269865587665, 6.711509537298223, 15.569211364904653, 14.751306123230371, 13.933401751062364, 14.765810402609743, 15.702416835101605, 16.47479168420746, 16.507480101557693, 15.554878658939998, 14.57727619676843, 13.662179545999479, 12.65591488172671, 11.673895900374315, 10.779455787610871, 9.776595052949027, 8.824796400940803, 7.884576028518603, 6.907643364703374, 6.027246627658223, 6.909933218018345, 7.773156400519911], [7.7785127526045565, 6.8530739392015265, 5.918713585998388, 4.963717036482088, 5.976436058511339, 6.885345990470028, 7.83962887707796, 8.856697426153191, 9.735208000511747, 10.687617082534253, 11.730680030306184, 12.670399035399598, 13.600378720620643, 14.610840280262643, 15.554196500912877, 15.834447616298283, 14.935388733424963, 15.864592906296334, 16.733990288327675, 17.50937723072327, 6.706826995251534, 5.910203605523217, 4.981227818581527, 3.991235847339804, 4.953310759110644, 5.911516846899979, 6.866345736756243, 7.861453339189761, 8.806754561533987, 9.76731988931311, 10.699749470354238, 11.632567604167498, 12.685306283005502, 13.73208108973849, 14.77860999620169, 15.767070921981878, 15.972088544253316, 16.922250888396746, 17.591064083479065, 16.553620499786934, 5.701045208034889, 4.905129866035579, 3.9372566310883097, 2.9634141906575135, 3.9835225038903532, 4.913499036920944, 5.8712071773180785, 6.846635668544432, 7.830862751612125, 8.828788242388653, 9.763156551839533, 10.823023032621023, 11.860146337067945, 12.854899621767945, 13.848016975037014, 14.8276723335467, 15.640605114906863, 16.628205803968566, 16.552396075531504, 15.65423701298425, 4.733025900439804, 3.8423285212025755, 2.92733124322111, 1.948795367450559, 2.9219493496073428, 3.9151224818220802, 4.872013594761756, 5.901047970400526, 6.939340656995915, 7.8975217171268675, 8.870214601133327, 9.86136680486067, 10.910182957139776, 11.87314394342749, 12.885316789274043, 13.772648640483888, 14.703334020030493, 15.694822084675105, 15.58690389430912, 14.637115283606574, 3.801590218515697, 2.831337196365908, 1.8956419320921765, 1.0012599386103298, 1.9610938198557428, 3.0173079567391605, 4.047020805820564, 4.9765890646046795, 5.9872555419455376, 6.917073519783416, 7.940648772056516, 8.908563690575319, 9.894179627018266, 10.917986663123676, 11.834288919963129, 12.816014940397315, 13.86956616924598, 14.810270063871915, 14.573761117355675, 13.653822499960162, 2.9517582730285383, 1.9379179426646571, 0.9558936403120892, 0.0, 1.0216876287886898, 2.046574661888508, 3.094107396727552, 4.069979529480084, 5.036567352248528, 5.979294301150951, 6.941701215775523, 7.8765992494201695, 8.945179809220084, 9.957759413047215, 10.906852051995473, 11.870122127067898, 12.874006635322008, 13.874431403853729, 13.61092607885925, 12.656379942282761, 3.90693055397035, 2.950858377459436, 1.9510933866823201, 0.9890051533163243, 1.9664271593657672, 2.97164497676438, 3.896732928269079, 4.863591529134862, 5.858629779215325, 6.905677305585394, 7.937911718118639, 8.871078481235262, 9.891786353261182, 10.836867783862711, 11.797102678746603, 12.762317221848651, 13.791957857498767, 13.539711974415248, 12.621934652063148, 11.667941324061577, 4.891484767989051, 3.884334731949382, 2.9014679299023705, 2.0356431408906714, 2.917199151566021, 3.900498381587642, 4.836588985523634, 5.812672974710744, 6.82643534557032, 7.767580305010142, 8.774466803207215, 9.751240481538199, 10.721848133771523, 11.681703864016226, 12.642717824261146, 13.693834078155106, 13.596946939917135, 12.59669444357305, 11.652586749493123, 10.649871439372973, 5.8701355018907355, 4.809536033468758, 3.831512108051884, 3.0205348404138768, 3.951530799138313, 4.833097246335311, 5.847727084206023, 6.817972205261651, 7.804963145399921, 8.707602951187658, 9.662731517055262, 10.598222369093769, 11.532241991491192, 12.509472852550509, 13.537670450645706, 13.573305717245855, 12.619854834906953, 11.650559181695797, 10.693895381996679, 9.660076918253145, 6.807904780082906, 5.858721536032359, 4.844474390452575, 3.9756166561676403, 4.9684309590182565, 5.8805059684738445, 6.819834119643969, 7.82244929720423, 8.788259999784467, 9.730325703324517, 10.59593313321991, 11.622421813088547, 12.535207871142918, 13.511330347572603, 13.610630434188275, 12.678962402293877, 11.670257958710485, 10.717324137478599, 9.708415619767276, 8.72323386184134, 7.752041778442955, 6.871292405691242, 5.91726889844254, 4.948289562380934, 5.9037215049032365, 6.837857454081172, 7.8087414954095005, 8.77660724848346, 9.74911489318747, 10.718392830386628, 11.618838893390695, 12.567314945139243, 13.550971373242753, 13.506422942074632, 12.588808279687676, 11.702214076427133, 10.76165287116683, 9.812283042327497, 8.837540803173452, 7.795974423114243, 8.708092547623583, 7.8328438846172395, 6.844985401600032, 5.9964524128903625, 6.871469270115476, 7.765355906486411, 8.804766627385623, 9.749681805549875, 10.713981577739126, 11.674850816596464, 12.564788965844556, 13.530136748705255, 13.607512177769816, 12.534535460411954, 11.592909959477767, 10.708494729457124, 9.776580211200816, 8.803675009452883, 7.763188779576573, 6.836661201065202, 9.702248775088862, 8.759004081375377, 7.832412973461679, 6.977694862514586, 7.864614053482496, 8.772404426370873, 9.746598739337301, 10.70614733385804, 11.662538859841998, 12.623448141288174, 13.55534731943637, 13.660299703246558, 12.71603256583245, 11.6919121421009, 10.666172137497151, 9.717136412389946, 8.759117539151216, 7.817061036993766, 6.817503646234103, 5.90012324205636, 10.754450770119222, 9.731154292017838, 8.784983702401979, 7.953121379997423, 8.887718581937843, 9.710841104503926, 10.684749634233542, 11.696073637239376, 12.619652049018402, 13.598912890622369, 13.845440246265296, 12.896276937731132, 11.84448508848807, 10.776143090036493, 9.805940994718572, 8.861373316074486, 7.8957107638756, 6.8804584047529405, 5.856783986584905, 4.852289204888623, 11.708276657336826, 10.78604629311686, 9.797084994734956, 8.912912026083214, 9.889499387923294, 10.726549135467327, 11.654140215201489, 12.627498057364969, 13.557033526547766, 13.966376317222423, 12.902195232113222, 11.866133970891607, 10.87071136684506, 9.943510453791184, 8.886066533525772, 7.929560993253809, 6.921202330311143, 5.9569402806939316, 4.974897035959352, 3.916185495950006, 12.726458569753035, 11.750468322810633, 10.741401773931221, 9.840446215293047, 10.800685821839044, 11.779815753318823, 12.68062154605769, 13.611347764220588, 14.500592499523945, 14.845155961545714, 13.797516722017518, 12.757831173184293, 11.812662458604326, 10.786910663019496, 9.827813511432321, 8.966527429577692, 7.932278548409034, 6.904985821071856, 5.83746249177518, 4.804958465314409, 13.675833761871658, 12.661695338750723, 11.71072801219065, 10.843094781833376, 11.839221204140188, 12.7114176089093, 13.629437256095136, 14.588621487312352, 15.532386327433608, 15.574312370635413, 14.599914229373574, 13.621963718126525, 12.65220594797526, 11.77420737198738, 10.801604368809448, 9.740334996914045, 8.795124763000585, 7.738441426357374, 6.737253941816002, 5.673815461716199, 14.627467533041177, 13.688850585455652, 12.782157384224542, 11.898086875968882, 12.880782538473198, 13.650787210574837, 14.567445096701597, 15.536586960054407, 15.576276894635066, 14.552324968797809, 13.643216826718477, 12.665431842785289, 11.717157635997825, 10.85279755228139, 9.90171702399189, 8.928195723923107, 7.953564758518359, 8.650383757493659, 7.5894250294086145, 6.60287004031241, 15.597419371582566, 14.737478496301966, 13.82842330757338, 12.920962974592928, 13.86577078433189, 14.649268607045823, 15.568515354360992, 15.564245115052488, 14.634637847226482, 13.625720615952254, 12.646721364826702, 11.720689637926373, 10.724725748220813, 9.780910043552787, 8.84112491569135, 7.92523782516617, 6.97272048242603, 7.909321695459614, 8.544620626870856, 7.667403177610312, 16.52510500521674, 15.70719976354246, 14.889295391374453, 13.940076372489099, 14.87668280498096, 15.598413185368493, 15.551586461245606, 14.59898501862791, 13.621382556456343, 12.706285905687391, 11.700021241414623, 10.718002260062228, 9.823562147298782, 8.820701412636938, 7.868902760628714, 6.928682388206513, 5.951749724391285, 6.858115645430963, 7.809307980582167, 8.729050040832], [8.800200381393248, 7.854159090768429, 6.89243921337112, 5.937442663854821, 4.95474842972265, 5.863658361681338, 6.81794124828927, 7.835009797364503, 8.713520371723057, 9.665929453745562, 10.708992401517493, 11.648711406610907, 12.578691091831953, 13.589152651473952, 14.532508872124186, 15.06357204017235, 15.763883363458392, 16.693087536329763, 17.63861122510593, 18.416192602912602, 7.7285146240402245, 6.91128875709012, 5.954953445954259, 4.964961474712537, 3.931623130321954, 4.88982921811129, 5.844658107967554, 6.839765710401071, 7.785066932745297, 8.74563226052442, 9.678061841565547, 10.610879975378808, 11.663618654216812, 12.710393460949799, 13.756922367412999, 14.745383293193187, 15.590191110760856, 16.556269951231545, 17.58000441128544, 17.460435871976266, 6.722732836823579, 5.926817494824269, 4.958944259877, 3.9607139565683713, 2.961834875101663, 3.891811408132255, 4.849519548529389, 5.824948039755743, 6.8091751228234365, 7.807100613599964, 8.741468923050846, 9.801335403832336, 10.838458708279259, 11.833211992979258, 12.826329346248327, 13.805984704758009, 14.618917486118173, 15.606518175179875, 16.565998794999384, 16.56105238517358, 5.7547135292284946, 4.864016149991266, 3.9490188720098, 2.9460951333614167, 1.9002617208186527, 2.8934348530333907, 3.8503259659730666, 4.879360341611837, 5.9176530282072255, 6.875834088338178, 7.8485269723446365, 8.839679176071982, 9.888495328351087, 10.851456314638801, 11.863629160485353, 12.750961011695198, 13.681646391241802, 14.673134455886414, 15.600506613777, 15.562220420657834, 4.823277847304388, 3.853024825154598, 2.9173295608808663, 1.9985597045211878, 0.9394061910670531, 1.9956203279504705, 3.0253331770318734, 3.9549014358159886, 4.965567913156847, 5.895385890994726, 6.918961143267826, 7.886876061786629, 8.872491998229576, 9.896299034334987, 10.812601291174438, 11.794327311608624, 12.84787854045729, 13.788582435083224, 14.759017522381203, 14.578927637011422, 3.973445901817228, 2.9596055714533467, 1.977581269100779, 1.0216876287886898, 0.0, 1.024887033099818, 2.072419767938862, 3.048291900691394, 4.014879723459838, 4.957606672362261, 5.920013586986833, 6.85491162063148, 7.923492180431395, 8.936071784258527, 9.885164423206785, 10.84843449827921, 11.852319006533317, 12.852743775065038, 13.79618248388478, 13.581485079334021, 4.92861818275904, 3.908627592626898, 2.908862601849782, 1.9341368512506643, 0.9447395305770774, 1.9499573479756904, 2.8750452994803894, 3.841903900346172, 4.836942150426635, 5.883989676796705, 6.916224089329949, 7.849390852446573, 8.870098724472493, 9.815180155074023, 10.775415049957914, 11.740629593059962, 12.770270228710078, 13.777762579944723, 13.547039789114407, 12.593046461112836, 5.843642611859037, 4.809439869000641, 3.826573066953629, 2.864137770924099, 1.8955115227773316, 2.8788107527989526, 3.8149013567349446, 4.790985345922055, 5.80474771678163, 6.745892676221452, 7.752779174418524, 8.729552852749508, 9.700160504982833, 10.660016235227536, 11.621030195472455, 12.672146449366416, 13.705130387597652, 13.52179958062431, 12.577691886544383, 11.574976576424232, 6.807354595380923, 5.734641170520017, 4.7566172451031425, 3.849029470447305, 2.9298431703496233, 3.811409617546621, 4.826039455417334, 5.796284576472962, 6.783275516611232, 7.685915322398968, 8.641043888266571, 9.576534740305078, 10.510554362702502, 11.487785223761819, 12.515982821857015, 13.475194649083884, 13.54495997195821, 12.575664318747057, 11.619000519047939, 10.585182055304404, 7.733009917134165, 6.7838266730836185, 5.769579527503835, 4.804111286201069, 3.946743330229567, 4.858818339685154, 5.798146490855279, 6.80076166841554, 7.766572370995776, 8.708638074535827, 9.57424550443122, 10.600734184299856, 11.513520242354227, 12.489642718783912, 13.483078578870279, 13.647321169129746, 12.607477052200673, 11.654543230968788, 10.645634713257465, 9.660452955331529, 8.677146915494214, 7.796397542742501, 6.842374035493799, 5.776784192414363, 4.882033876114547, 5.816169825292483, 6.787053866620811, 7.75491961969477, 8.727427264398779, 9.696705201597938, 10.597151264602005, 11.545627316350553, 12.529283744454062, 13.475741029509427, 13.610495908476366, 12.670572843263004, 11.714023695294118, 10.764653866454786, 9.774759896663639, 8.733193516604432, 9.633197684674842, 8.7579490216685, 7.770090538651291, 6.8249470429237915, 5.849781641326787, 6.743668277697721, 7.783078998596934, 8.727994176761186, 9.692293948950436, 10.653163187807774, 11.543101337055866, 12.508449119916564, 13.483584087198146, 13.556223089200644, 12.614597588266458, 11.676853496292996, 10.744938978036688, 9.772033776288755, 8.70040787306676, 7.77388029455539, 10.627353912140121, 9.684109218426638, 8.754065736645028, 7.806189492548015, 6.8429264246938075, 7.750716797582184, 8.724911110548613, 9.68445970506935, 10.64085123105331, 11.601760512499485, 12.53365969064768, 13.444528017019543, 13.73772019462114, 12.71359977088959, 11.687859766285841, 10.738824041178637, 9.780805167939906, 8.838748665782456, 7.839191275022793, 6.91756210252151, 11.679555907170482, 10.652807055201187, 9.706636465585328, 8.781616010030852, 7.866030953149155, 8.689153475715237, 9.663062005444853, 10.674386008450687, 11.597964420229713, 12.57722526183368, 13.50707627505078, 13.917964566519819, 12.866172717276758, 11.79783071882518, 10.827628623507259, 9.883060944863175, 8.917398392664289, 7.90214603354163, 6.878471615373595, 5.873976833677313, 12.633381794388086, 11.707699056300209, 10.718737757918305, 9.741406656116643, 8.867811759134606, 9.704861506678638, 10.6324525864128, 11.60581042857628, 12.535345897759075, 13.562706660167684, 13.923882860901909, 12.887821599680294, 11.892398995633748, 10.965198082579873, 9.907754162314461, 8.951248622042499, 7.942889959099832, 6.97862790948262, 5.996584664748042, 4.9378731247386956, 13.648111332936384, 12.672121085993982, 11.66305453711457, 10.668940845326476, 9.907457434242884, 10.758128124530135, 11.658933917269, 12.589660135431899, 13.478904870735255, 14.423954162508199, 14.546726628591811, 13.507041079758586, 12.561872365178617, 11.808598291808185, 10.84950114022101, 9.93790776819287, 8.953966177197724, 7.926673449860546, 6.8591501205638705, 5.8266460941031, 14.582649134060986, 13.568510710940052, 12.617543384379978, 11.671589411866805, 10.945992816544027, 11.689729980120612, 12.607749627306445, 13.566933858523662, 14.510698698644918, 14.552624741846723, 13.578226600584884, 12.600276089337836, 11.63051831918657, 10.896656968288012, 9.948068642894631, 8.897516138406623, 9.816812391789275, 8.760129055146065, 7.7589415706046925, 6.695503090504889, 15.534282905230505, 14.593471522233909, 13.654186328021067, 12.726581506002312, 11.997089588902165, 12.629099581786148, 13.545757467912907, 14.514899331265717, 14.554589265846376, 13.530637340009118, 12.621529197929787, 11.6437442139966, 10.695470007209137, 9.8311099234927, 8.880029395203202, 7.906508095134416, 8.894088943046109, 9.672071386282349, 8.611112658197305, 7.6245576691011, 16.504234743771896, 15.642099433080222, 14.700066740314554, 13.749457604626357, 13.057707573148797, 13.627580978257134, 14.546827725572301, 14.542557486263798, 13.612950218437792, 12.604032987163563, 11.625033736038011, 10.699002009137683, 9.703038119432124, 8.759222414764098, 7.81943728690266, 6.903550196377481, 7.913244666953778, 8.883047322832347, 9.566308255659546, 8.689090806399003, 17.431920377406072, 16.611820700320717, 15.750688609493869, 14.768571002522528, 14.105807228855028, 14.576725556579804, 14.529898832456915, 13.57729738983922, 12.599694927667652, 11.6845982768987, 10.678333612625933, 9.696314631273538, 8.801874518510093, 7.799013783848247, 6.8472151318400245, 5.906994759417824, 6.920611622880353, 7.831841272803695, 8.7830336079549, 9.75073766962069], [9.825087414493066, 8.879046123868246, 7.917326246470938, 6.962329696954638, 5.9796354628224675, 4.999275469419823, 5.953558356027755, 6.970626905102987, 7.816155509167384, 8.76856459118989, 9.81162753896182, 10.751346544055234, 11.68132622927628, 12.69178778891828, 13.635144009568513, 14.644467004601875, 15.602003888489392, 16.531208061360765, 17.549676433149173, 18.50761637860728, 8.753401657140042, 7.936175790189938, 6.979840479054077, 5.989848507812354, 4.956510163421772, 4.025446325849774, 4.961715394306696, 5.9424008478453985, 6.887702070189624, 7.848267397968748, 8.780696979009875, 9.713515112823135, 10.76625379166114, 11.793286430939867, 12.826525592064634, 13.720496260093372, 14.56530407766104, 15.531382918131728, 16.55511737818562, 17.486496518595406, 7.747619869923397, 6.951704527924087, 5.983831292976817, 4.98560098966819, 3.9867219082014813, 3.02742851587074, 3.9665768348685315, 4.92758317720007, 5.911810260267764, 6.8535838917321605, 7.7879522011830415, 8.776938679847458, 9.81406198429438, 10.808324959879439, 11.801442313148508, 12.781097671658193, 13.594030453018357, 14.58163114208006, 15.541111761899568, 16.53826010427848, 6.779600562328312, 5.888903183091084, 4.973905905109618, 3.9709821664612353, 2.925148753918471, 2.0290519607718758, 2.9673832523122092, 3.87919848216579, 4.917491168761178, 5.875672228892131, 6.823639939244819, 7.814792142972164, 8.86360829525127, 9.826569281538983, 10.838742127385537, 11.726073978595382, 12.656759358141986, 13.648247422786598, 14.575619580677184, 15.554280362499375, 5.848164880404205, 4.877911858254416, 3.9422165939806844, 3.023446737621006, 1.9642932241668714, 0.9890769763882133, 2.0004461439320553, 2.9300144027161705, 3.9406808800570285, 4.870498857894908, 5.894074110168009, 6.8619890286868115, 7.847604965129759, 8.87141200123517, 9.787714258074622, 10.769440278508808, 11.822991507357473, 12.763695401983409, 13.734130489281387, 14.664874808735252, 4.998332934917046, 3.9844926045531652, 3.0024683022005973, 2.046574661888508, 1.024887033099818, 0.0, 1.0475327348390437, 2.023404867591576, 2.9899926903600202, 3.9327196392624435, 4.895126553887016, 5.830024587531662, 6.898605147331577, 7.911184751158709, 8.860277390106967, 9.823547465179391, 10.827431973433502, 11.827856741965222, 12.771295450784963, 13.838118676369337, 5.953505215858858, 4.913935043167269, 3.9141700523901535, 2.9394443017910357, 1.9500469811174486, 0.9448291637188355, 1.8699171152235343, 2.836775716089317, 3.83181396616978, 4.859102643696887, 5.891337056230132, 6.824503819346756, 7.845211691372675, 8.790293121974205, 9.750528016858096, 10.715742559960145, 11.74538319561026, 12.752875546844907, 13.705220997474681, 13.598353911653206, 6.848950062399408, 5.814747319541011, 4.831880517494, 3.86944522146447, 2.9008189733177026, 2.0080662238201477, 2.872443505050665, 3.848527494237775, 4.8373205699300605, 5.778465529369882, 6.7853520275669545, 7.7621257058979385, 8.732733358131263, 9.692589088375966, 10.653603048620885, 11.683570296025643, 12.708297246703612, 13.695893077687105, 13.582999337084752, 12.580284026964602, 7.812662045921295, 6.739948621060387, 5.761924695643513, 4.854336920987675, 3.9351506208899947, 2.9406650885678163, 3.883581603733054, 4.853826724788682, 5.840817664926952, 6.718488175547398, 7.6736167414150005, 8.609107593453508, 9.543127215850932, 10.520358076910249, 11.548555675005446, 12.507767502232314, 13.461218384571216, 13.580971769287427, 12.624307969588308, 11.590489505844774, 8.738317367674535, 7.789134123623988, 6.774886978044204, 5.8094187367414385, 4.952050780769938, 3.9880738107063496, 4.8556886391709995, 5.858303816731261, 6.824114519311497, 7.746693963741323, 8.60681835757965, 9.633307037448287, 10.546093095502657, 11.522215571932342, 12.515651432018709, 13.464711733599657, 13.612784502741045, 12.659850681509159, 11.650942163797836, 10.6657604058719, 9.682454366034584, 8.80170499328287, 7.847681486034169, 6.782091642954732, 5.887341326654918, 4.989318374395367, 5.920122523895426, 6.887988276969385, 7.784969412714499, 8.734761090803435, 9.629724117750435, 10.578200169498983, 11.561856597602493, 12.508313882657857, 13.447686247849383, 13.675880293803376, 12.71933114583449, 11.769961316995158, 10.78006734720401, 9.738500967144804, 10.638505135215212, 9.763256472208868, 8.77539798919166, 7.830254493464161, 6.855089091867159, 5.916816826800606, 6.916147655871549, 7.861062834035801, 8.749836097266156, 9.69121907701327, 10.575674190204296, 11.541021973064995, 12.516156940346576, 13.480201364320536, 13.630473540897206, 12.682160946833367, 11.750246428577059, 10.777341226829126, 9.705715323607132, 8.779187745095761, 11.63266136268049, 10.689416668967006, 9.759373187185398, 8.811496943088384, 7.848233875234179, 6.923865346685068, 7.898059659651498, 8.857608254172236, 9.807002957728969, 10.725837853749875, 11.56623254379611, 12.477100870167973, 13.421368007582082, 13.72947572352034, 12.70373571891659, 11.754699993809385, 10.796681120570655, 9.854624618413204, 8.85506722765354, 7.922869553061879, 12.684863357710851, 11.658114505741556, 10.711943916125698, 9.786923460571222, 8.85752290396701, 7.862302024818121, 8.836210554547739, 9.847534557553573, 10.764116146905373, 11.70130260308407, 12.578923147617084, 13.438393814253267, 13.680105555074768, 12.822717751925, 11.852515656607078, 10.907947977962992, 9.942285425764107, 8.927033066641448, 7.9033586484734135, 6.898863866777131, 13.638689244928456, 12.713006506840578, 11.724045208458675, 10.746714106657013, 9.843865179939304, 8.878010055781521, 9.805601135515685, 10.778958977679165, 11.701497624434737, 12.728858386843346, 13.522168161769159, 13.634863168722912, 12.639440564676367, 11.990085115679692, 10.93264119541428, 9.976135655142318, 8.967776992199651, 8.00351494258244, 7.02147169784786, 5.962760157838514, 14.653418783476754, 13.677428536534352, 12.66836198765494, 11.674248295866846, 10.883510855047582, 9.931276673633018, 10.832082466371887, 11.762808684534784, 12.645056597410916, 13.59010588918386, 13.682343736330294, 12.64265818749707, 11.6974894729171, 11.016573759597415, 10.05747660801024, 10.962794801292688, 9.978853210297542, 8.951560482960364, 7.884037153663688, 6.851533127202917, 15.587956584601356, 14.573818161480421, 13.622850834920348, 12.676896862407174, 11.847555373073346, 10.862878529223496, 11.780898176409332, 12.740082407626549, 13.676850425320579, 13.65525987929105, 12.680861738029211, 11.735893197076319, 10.766135426925054, 10.032274076026495, 9.083685750633114, 9.92240317150644, 10.841699424889093, 9.785016088245882, 8.78382860370451, 7.720390123604707, 16.539590355770876, 15.598778972774278, 14.659493778561437, 13.731888956542681, 12.786063718953027, 11.802248130889032, 12.718906017015794, 13.688047880368604, 13.657224403290703, 12.633272477453446, 11.724164335374114, 10.779361321735083, 9.83108711494762, 8.966727031231184, 8.015646502941685, 8.931395128234234, 9.918975976145926, 10.696958419382169, 9.635999691297124, 8.649444702200919, 17.509542194312267, 16.64740688362059, 15.705374190854924, 14.754765055166727, 13.846681703199659, 12.800729527360017, 13.719976274675188, 13.645192623708125, 12.71558535588212, 11.70666812460789, 10.727668873482338, 9.80163714658201, 8.838655227170607, 7.894839522502582, 6.955054394641144, 7.928437229477298, 8.938131700053596, 9.907934355932165, 10.591195288759366, 9.713977839498822, 18.437227827946444, 17.617128150861085, 16.74289254475121, 15.76077493777987, 14.824168505288007, 13.749874105682688, 13.632533969901242, 12.679932527283547, 11.70233006511198, 10.787233414343028, 9.78096875007026, 8.798949768717865, 7.937491626248579, 6.934630891586732, 5.982832239578509, 6.9318817925176415, 7.94549865598017, 8.856728305903513, 9.807920641054718, 10.77562470272051], [10.727855421002092, 9.749099527258263, 8.787379649860956, 7.832383100344655, 6.849688866212484, 5.8469651390607895, 4.956648677994334, 5.923993457393195, 6.768622774328341, 7.721031856350847, 8.764094804122777, 9.703813809216191, 10.633793494437237, 11.644255054079236, 12.58761127472947, 13.596934269762832, 14.554471153650347, 15.483675326521718, 16.502143698310125, 17.460083643768233, 9.763523027949967, 8.806229193579954, 7.849893882444094, 6.859901911202371, 5.826563566811789, 4.873135995490741, 3.9141826594676528, 4.894868113006355, 5.840169335350581, 6.800734663129704, 7.7331642441708315, 8.665982377984092, 9.718721056822096, 10.745753696100826, 11.778992857225592, 12.672963525254326, 13.517771342821995, 14.483850183292683, 15.507584643346576, 16.438963783756357, 8.79515260476244, 7.945847497595832, 6.942201320719763, 5.911710263129981, 4.856775311591498, 3.875118185511706, 2.919044100029488, 3.8800504423610263, 4.86427752542872, 5.806051156893117, 6.740419466343998, 7.7294059450084145, 8.766529249455337, 9.760792225040397, 10.753909578309466, 11.733564936819148, 12.546497718179312, 13.534098407241014, 14.493579027060523, 15.490727369439432, 7.8271332971673555, 6.936435917930127, 5.982882343263659, 4.923283076883213, 3.8699147626275794, 2.876741630412842, 1.919850517473166, 2.8316657473267464, 3.869958433922135, 4.8281394940530875, 5.776107204405775, 6.76725940813312, 7.8160755604122265, 8.77903654669994, 9.791209392546492, 10.678541243756337, 11.609226623302941, 12.600714687947553, 13.52808684583814, 14.50674762766033, 6.8956976152432485, 5.925444593093459, 4.989749328819728, 4.070979472460049, 3.011825959005915, 2.023841122687277, 0.9529134090930117, 1.882481667877127, 2.8931481452179852, 3.8229661230558647, 4.846541375328965, 5.814456293847768, 6.8000722302907155, 7.823879266396125, 8.740181523235577, 9.721907543669763, 10.775458772518428, 11.716162667144363, 12.686597754442342, 13.617342073896207, 6.04586566975609, 5.0320253393922085, 4.050001037039641, 3.0941073967275514, 2.072419767938862, 1.0475327348390437, 0.0, 0.9758721327525323, 1.9424599555209765, 2.8851869044233998, 3.847593819047972, 4.782491852692619, 5.851072412492534, 6.863652016319666, 7.812744655267924, 8.776014730340348, 9.779899238594457, 10.780324007126177, 11.723762715945918, 12.790585941530292, 6.890096499807256, 5.850462291889469, 4.850697301112354, 3.8759715505132366, 2.88657422983965, 1.8813564124410367, 0.9562684609363377, 1.9231270618021203, 2.887011072107935, 3.8115699088578427, 4.8438043213910875, 5.776971084507712, 6.797678956533631, 7.742760387135161, 8.702995282019051, 9.6682098251211, 10.697850460771216, 11.705342812005862, 12.657688262635636, 13.611681590637208, 7.78547731112161, 6.751274568263213, 5.768407766216201, 4.8059724701866715, 3.837346222039904, 2.8948854546994602, 1.9587948507634685, 2.9348788399505787, 3.8925176758682154, 4.79653727703756, 5.8034237752346325, 6.71630529969789, 7.686912951931214, 8.646768682175917, 9.607782642420837, 10.636037561186598, 11.660764511864567, 12.64836034284806, 13.592468036927986, 13.516811275686804, 8.749189294643497, 7.676475869782589, 6.698451944365715, 5.790864169709877, 4.839815347091571, 3.8274843194471293, 2.969932949445858, 3.940178070501486, 4.927169010639756, 5.736559923215076, 6.691688489082678, 7.627179341121186, 8.56119896351861, 9.538429824577927, 10.566627422673124, 11.525839249899992, 12.479290132238894, 13.44858578545005, 13.56083521831051, 12.527016754566976, 9.674844616396737, 8.72566137234619, 7.711414226766406, 6.74594598546364, 5.856715506971515, 4.874893041585663, 3.9420399848838032, 4.9446551624440644, 5.9104658650243005, 6.764765711409001, 7.624890105247328, 8.651378785115964, 9.564164843170335, 10.54028731960002, 11.533723179686387, 12.482783481267333, 13.53303672702951, 13.59637793023136, 12.587469412520038, 11.602287654594102, 10.618981614756786, 9.738232242005072, 8.78420873475637, 7.718618891676934, 6.792006052856495, 5.87613760527468, 5.0064738696082305, 5.97433962268219, 6.871320758427303, 7.752832838471113, 8.647795865418113, 9.59627191716666, 10.57992834527017, 11.526385630325535, 12.46575799551706, 13.459531807134077, 13.655858394556692, 12.70648856571736, 11.716594595926212, 10.675028215867005, 11.575032383937414, 10.69978372093107, 9.711925237913862, 8.76476037780675, 7.759753818068734, 6.803636057679919, 6.002499001584353, 6.9474141797486055, 7.836187442978959, 8.709290824680949, 9.593745937871974, 10.559093720732672, 11.534228688014254, 12.498273111988214, 13.4398986129224, 13.618688195555569, 12.68677367729926, 11.713868475551328, 10.642242572329334, 9.715714993817963, 12.569188611402693, 11.625943917689208, 10.693879071527988, 9.746002827430974, 8.752898601435755, 7.810684577564381, 7.0023608443962795, 7.961909438917019, 8.893354303441772, 9.743909601417553, 10.584304291463788, 11.495172617835651, 12.43943975524976, 13.2880512674347, 13.640262967638792, 12.691227242531587, 11.733208369292857, 10.791151867135406, 9.791594476375742, 8.859396801784081, 13.621390606433053, 12.592620390084146, 11.646449800468288, 10.721429344913812, 9.744342134846322, 8.749121255697434, 7.9405117392925195, 8.951835742298353, 9.850467492618176, 10.719374350751748, 11.596994895284762, 12.456465561920945, 12.779710790529265, 12.258943184178598, 12.858229268275789, 11.955480712802036, 10.98981816060315, 9.974565801480491, 8.950891383312456, 7.946396601616175, 13.817645795272806, 13.647512391183168, 12.658551092801265, 11.681219990999603, 10.730684410818615, 9.764829286660834, 8.909902320260466, 9.883260162423946, 10.78784897014754, 11.79412381468481, 12.540239909436837, 12.73446840417741, 11.739045800130864, 11.258893317958684, 11.846913255557757, 11.02366838998136, 10.015309727038693, 9.051047677421481, 8.069004432686903, 7.010292892677557, 14.642525639730389, 14.611934420876942, 13.60286787199753, 12.608754180209436, 11.770330085926894, 10.818095904512331, 9.936383651116667, 10.867109869279565, 11.731407943123719, 12.676457234896663, 12.672564675521098, 11.742263422951567, 10.797094708371597, 10.209739724635742, 10.905166277651208, 11.832848204682705, 11.026385945136585, 9.999093217799407, 8.931569888502732, 7.899065862041961, 15.541657809142418, 15.508324045823011, 14.557356719262938, 13.611402746749764, 12.73437460395266, 11.749697760102809, 10.885199361154113, 11.84438359237133, 12.763201771033382, 12.607727144452005, 11.633329003190166, 10.791967023725938, 9.865740662379551, 9.155129634210333, 9.931375420274081, 10.792456574896457, 11.737666808809918, 10.832548823084926, 9.831361338543553, 8.76792285844375, 16.493291580311936, 16.52246862856825, 15.583183434355412, 14.655578612336656, 13.67288294983234, 12.689067361768345, 11.823207201760574, 12.792349065113385, 12.609691668451658, 11.5857397426144, 10.67663160053507, 9.77275409818852, 8.930692350402117, 8.089582589415022, 8.863336172582652, 9.801448531624251, 10.789029379535943, 11.744491154221212, 10.683532426136168, 9.696977437039962, 17.395164911960727, 17.571096539414565, 16.62891787950613, 15.678308743817933, 14.733500934078972, 13.68754875823933, 12.824277459419969, 12.597659888869082, 11.668052621043076, 10.659135389768846, 9.680136138643293, 8.754104411742965, 7.938260462625104, 7.017695080686419, 7.802744064282111, 8.798490632867315, 9.808185103443613, 10.777987759322182, 11.638728023598409, 10.750454791478395, 18.322850545594903, 17.48351887789083, 16.47342312054336, 15.491305513572016, 14.554699081080154, 13.528860336588664, 12.5850012350622, 11.632399792444504, 10.654797330272936, 9.739700679503985, 8.733436015231216, 7.7514170338788215, 6.890858178538786, 6.010722341852576, 6.830521909219476, 7.801935195907658, 8.815552059370187, 9.72678170929353, 10.677974044444735, 11.703230301342417], [11.703727553754623, 10.724971660010794, 9.763251782613487, 8.808255233097187, 7.825560998965017, 6.822837271813322, 5.932520810746866, 5.072535073862631, 5.917164390797778, 6.869573472820284, 7.859094998516599, 8.756772858131079, 9.686752543352124, 10.697214102994124, 11.640570323644358, 12.64989331867772, 13.578599020897814, 14.507803193769185, 15.526271565557593, 16.4842115110157, 10.739395160702498, 9.782101326332485, 8.825766015196624, 7.835774043954903, 6.802435699564321, 5.849008128243273, 4.890054792220186, 4.043409729475791, 4.988710951820018, 5.857306488122694, 6.789736069163821, 7.71894142689898, 8.771680105736985, 9.76988156334829, 10.803120724473057, 11.697091392501793, 12.541899210069461, 13.50797805054015, 14.531712510594042, 15.463091651003824, 9.771024737514974, 8.921719630348363, 7.918073453472294, 6.8875823958825135, 5.832647444344031, 4.850990318264238, 3.8949162327820206, 3.028592058830463, 4.012819141898156, 4.839500263177851, 5.773868572628732, 6.753533812255881, 7.7906571167028025, 8.784920092287862, 9.778037445556931, 10.757692804066615, 11.570625585426779, 12.55822627448848, 13.51770689430799, 14.514855236686898, 8.803005429919889, 7.912308050682659, 6.958754476016191, 5.899155209635746, 4.845786895380112, 3.8526137631653743, 2.8957226502256983, 1.980207363796183, 3.017113395314488, 3.861588600337821, 4.800235071653242, 5.791387275380587, 6.840203427659693, 7.803164413947406, 8.81533725979396, 9.702669111003804, 10.633354490550408, 11.62484255519502, 12.552214713085606, 13.530875494907797, 7.871569747995781, 6.901316725845992, 5.96562146157226, 5.0468516052125825, 3.9876980917584475, 2.9997132554398087, 1.928785541845544, 1.0310232843465637, 2.0077506997721777, 2.8470939903033323, 3.870669242576432, 4.838584161095235, 5.824200097538182, 6.848007133643592, 7.764309390483045, 8.74603541091723, 9.799586639765895, 10.740290534391832, 11.71072562168981, 12.641469941143676, 7.021737802508622, 6.007897472144741, 5.025873169792173, 4.069979529480084, 3.048291900691394, 2.023404867591576, 0.9758721327525323, 0.0, 0.9665878227684441, 1.9093147716708674, 2.8717216862954396, 3.806619719940086, 4.8752002797400005, 5.887779883567132, 6.836872522515391, 7.800142597587815, 8.804027105841925, 9.804451874373646, 10.747890583193387, 11.81471380877776, 7.865968632559788, 6.826334424642002, 5.826569433864886, 4.851843683265769, 3.8624463625921823, 2.857228545193569, 1.93214059368887, 0.9985647521879257, 1.9111389393554026, 2.8356977761053104, 3.867932188638555, 4.801098951755179, 5.821806823781098, 6.766888254382628, 7.727123149266519, 8.692337692368566, 9.721978328018682, 10.72947067925333, 11.681816129883105, 12.635809457884676, 8.761349443874142, 7.727146701015745, 6.744279898968734, 5.781844602939204, 4.813218354792436, 3.870757587451993, 2.934666983516001, 2.032518613906099, 2.916645543115683, 3.8206651442850275, 4.827551642482101, 5.740433166945358, 6.711040819178683, 7.670896549423387, 8.631910509668305, 9.660165428434064, 10.684892379112034, 11.672488210095528, 12.616595904175455, 13.625348012303425, 9.72506142739603, 8.652348002535122, 7.674324077118247, 6.76673630246241, 5.8156874798441045, 4.803356452199662, 3.9458050821983903, 3.0831591741258446, 3.9790819264136346, 4.760687790462543, 5.715816356330146, 6.651307208368654, 7.5853268307660775, 8.562557691825393, 9.59075528992059, 10.549967117147458, 11.503417999486361, 12.472713652697514, 13.429377452396633, 13.502888887319509, 10.65071674914927, 9.701533505098723, 8.68728635951894, 7.721818118216174, 6.832587639724048, 5.8507651743381945, 4.917912117636336, 4.087636266068423, 4.962378780798179, 5.788893578656468, 6.6490179724947955, 7.675506652363433, 8.588292710417804, 9.564415186847489, 10.557851046933855, 11.506911348514802, 12.557164594276978, 13.439593889452476, 13.563341545272571, 12.578159787346635, 11.594853747509319, 10.714104374757605, 9.760080867508904, 8.694491024429468, 7.767878185609028, 6.852009738027212, 5.982346002360762, 5.13175094546758, 5.923233674201182, 6.77696070571858, 7.671923732665581, 8.62039978441413, 9.604056212517639, 10.550513497573004, 11.48988586276453, 12.483659674381546, 13.50630975739613, 13.682360698469893, 12.692466728678745, 11.650900348619539, 12.550904516689947, 11.675655853683603, 10.687797370666395, 9.740632510559283, 8.735625950821268, 7.77950819043245, 6.978371134336885, 6.104825502533995, 6.888100358752838, 7.733418691928417, 8.617873805119443, 9.583221587980141, 10.558356555261723, 11.522400979235682, 12.464026480169869, 13.477379021351554, 13.662645810051794, 12.689740608303861, 11.618114705081867, 10.691587126570496, 13.545060744155226, 12.601816050441741, 11.669751204280521, 10.721874960183507, 9.728770734188288, 8.786556710316912, 7.978232977148811, 7.173812284449603, 7.945267219215651, 8.768037468665021, 9.608432158711256, 10.51930048508312, 11.463567622497228, 12.486993389477188, 13.390764302150485, 13.66709937528412, 12.70908050204539, 11.76702399988794, 10.767466609128276, 9.835268934536614, 13.657873863778775, 13.56849252283668, 12.622321933220821, 11.697301477666345, 10.720214267598854, 9.724993388449965, 8.916383872045051, 8.216696709414048, 8.902380408392055, 9.743502217999216, 10.62112276253223, 11.480593429168414, 11.9282524069987, 12.814838195874088, 13.78504029119201, 12.931352845554569, 11.965690293355683, 10.950437934233024, 9.92676351606499, 8.922268734368707, 12.841773662520275, 13.902657074198943, 13.634423225553798, 12.657092123752136, 11.706556543571146, 10.740701419413366, 9.885774453012997, 9.155795545283228, 9.839761885921419, 10.818251681932278, 11.564367776684305, 11.883010020646847, 10.887587416600299, 11.814788329654174, 12.82278538831029, 11.999540522733893, 10.991181859791226, 10.026919810174014, 9.044876565439436, 7.98616502543009, 13.666653506977857, 14.64264375392026, 14.578740004750063, 13.58462631296197, 12.746202218679425, 11.793968037264863, 10.912255783869199, 10.139645252138846, 10.783320858897598, 11.728370150670543, 11.821106291990535, 10.890805039421, 9.945636324841033, 10.977346773111254, 11.881038410403741, 12.808720337435238, 12.002258077889117, 10.974965350551939, 9.907442021255264, 8.874937994794493, 14.565785676389885, 15.57992409951082, 15.53322885201547, 14.587274879502298, 13.71024673670519, 12.72556989285534, 11.861071493906644, 11.198226945641293, 11.815114686807261, 11.756268760921442, 10.781870619659603, 9.940508640195377, 9.014282278848986, 9.945876387105875, 10.907247553026615, 11.76832870764899, 12.713538941562451, 11.808420955837459, 10.807233471296087, 9.743794991196284, 15.517419447559403, 16.49100634815801, 16.559055567107944, 15.631450745089188, 14.648755082584872, 13.664939494520876, 12.799079334513106, 12.181425830733884, 11.718869313307708, 10.734281359083838, 9.825173217004506, 8.921295714657958, 8.079233966871552, 9.064871241549415, 9.839208305335186, 10.777320664376784, 11.764901512288477, 12.720363286973745, 11.659404558888701, 10.672849569792495, 16.41929277920819, 17.461602490249756, 16.500065208956357, 15.54945607326816, 14.6046482635292, 13.530963963826224, 12.595632824666263, 11.65061893778397, 10.721011669957964, 9.807677006238283, 8.82867775511273, 7.902646028212403, 7.08680207909454, 7.993567213438952, 8.778616197034644, 9.774362765619848, 10.784057236196146, 11.753859892074713, 12.614600156350942, 11.726326924230927, 17.34697841284237, 16.536477926805716, 15.526382169458245, 14.544264562486903, 13.607658129995041, 12.581819385503554, 11.637960283977087, 10.685358841359392, 9.707756379187824, 8.888242295973424, 7.8819776317006545, 6.899958650348259, 6.039399795008222, 6.986594474605108, 7.806394041972008, 8.777807328660192, 9.79142419212272, 10.702653842046061, 11.653846177197266, 12.679102434094949], [12.670315376523067, 11.691559482779239, 10.729839605381931, 9.774843055865631, 8.792148821733461, 7.789425094581766, 6.8991086335153105, 6.021448390918767, 5.012413162418036, 5.929769517453027, 6.892507175748155, 7.790185035362635, 8.72016472058368, 9.73062628022568, 10.673982500875914, 11.683305495909275, 12.61201119812937, 13.54121537100074, 14.559683742789149, 15.517623688247255, 11.705982983470943, 10.74868914910093, 9.792353837965068, 8.802361866723347, 7.769023522332765, 6.8155959510117174, 5.85664261498863, 5.0099975522442355, 4.083959723440276, 4.89071866535425, 5.823148246395377, 6.752353604130536, 7.805092282968541, 8.803293740579846, 9.836532901704613, 10.730503569733349, 11.575311387301017, 12.541390227771705, 13.565124687825598, 14.49650382823538, 10.737612560283418, 9.888307453116807, 8.884661276240738, 7.854170218650958, 6.799235267112475, 5.817578141032683, 4.861504055550465, 3.995179881598907, 3.102051100731722, 3.872912440409407, 4.807280749860288, 5.786945989487437, 6.824069293934358, 7.818332269519418, 8.811449622788487, 9.79110498129817, 10.604037762658335, 11.591638451720037, 12.551119071539546, 13.548267413918454, 9.769593252688333, 8.878895873451103, 7.925342298784635, 6.86574303240419, 5.812374718148556, 4.819201585933818, 3.8623104729941424, 2.946795186564627, 2.050525572546044, 2.895000777569377, 3.8336472488847986, 4.824799452612143, 5.873615604891249, 6.836576591178962, 7.848749437025516, 8.73608128823536, 9.666766667781964, 10.658254732426576, 11.585626890317162, 12.564287672139352, 8.838157570764226, 7.867904548614436, 6.932209284340704, 6.013439427981026, 4.954285914526891, 3.966301078208253, 2.895373364613988, 1.9976111071150078, 1.0411628770037336, 1.8805061675348882, 2.904081419807988, 3.871996338326791, 4.857612274769738, 5.881419310875148, 6.797721567714601, 7.779447588148786, 8.832998816997451, 9.773702711623386, 10.744137798921365, 11.67488211837523, 7.988325625277066, 6.974485294913185, 5.992460992560617, 5.036567352248528, 4.014879723459838, 2.9899926903600202, 1.9424599555209765, 0.9665878227684441, 0.0, 0.9427269489024231, 1.9051338635269954, 2.840031897171642, 3.9086124569715563, 4.921192060798688, 5.870284699746946, 6.833554774819371, 7.83743928307348, 8.8378640516052, 9.781302760424941, 10.848125986009315, 8.832556455328232, 7.792922247410446, 6.7931572566333305, 5.818431506034213, 4.8290341853606265, 3.823816367962013, 2.898728416457314, 1.9395893666674215, 0.9445511165869586, 1.8691099533368662, 2.901344365870111, 3.834511128986735, 4.855219001012654, 5.8003004316141835, 6.760535326498075, 7.725749869600122, 8.755390505250238, 9.762882856484884, 10.715228307114659, 11.66922163511623, 9.727937266642588, 8.69373452378419, 7.710867721737178, 6.748432425707648, 5.77980617756088, 4.837345410220437, 3.901254806284445, 2.9638200912068147, 1.950057720347239, 2.8540773215165833, 3.8609638197136564, 4.773845344176914, 5.744452996410239, 6.704308726654943, 7.665322686899862, 8.69357760566562, 9.71830455634359, 10.705900387327082, 11.650008081407009, 12.658760189534979, 10.691649250164472, 9.618935825303565, 8.64091189988669, 7.733324125230854, 6.782275302612549, 5.769944274968106, 4.9123929049668345, 3.9994850437834604, 3.0124941036451904, 3.794099967694099, 4.749228533561702, 5.68471938560021, 6.618739007997633, 7.595969869056949, 8.624167467152146, 9.583379294379014, 10.536830176717917, 11.506125829929072, 12.46278962962819, 13.496608093371725, 11.617304571917712, 10.668121327867166, 9.653874182287382, 8.688405940984618, 7.799175462492492, 6.817352997106639, 5.88449994040478, 5.003962135726039, 3.995790958029735, 4.822305755888024, 5.682430149726351, 6.708918829594989, 7.62170488764936, 8.597827364079045, 9.591263224165411, 10.540323525746356, 11.590576771508532, 12.473006066684034, 13.481914584395357, 13.544747610115078, 12.561441570277761, 11.680692197526048, 10.726668690277346, 9.661078847197912, 8.734466008377472, 7.818597560795656, 6.921020379879435, 5.953154626805476, 4.956645851432738, 5.810372882950136, 6.705335909897137, 7.653811961645685, 8.637468389749195, 9.58392567480456, 10.523298039996085, 11.5170718516131, 12.539721934627684, 13.48393285784377, 13.659054551447188, 12.617488171387981, 13.51749233945839, 12.642243676452045, 11.654385193434837, 10.707220333327728, 9.702213773589712, 8.746096013200894, 7.901664625256985, 6.887322008281451, 5.921512535984394, 6.766830869159973, 7.651285982350999, 8.616633765211699, 9.59176873249328, 10.555813156467238, 11.497438657401425, 12.510791198583108, 13.442705716839416, 13.656328431072303, 12.58470252785031, 11.658174949338939, 13.60638285381909, 13.568403873210183, 12.636339027048965, 11.688462782951952, 10.695358556956732, 9.753144533085358, 8.894619516951904, 7.935070922431165, 6.978679396447207, 7.801449645896577, 8.641844335942814, 9.552712662314677, 10.496979799728786, 11.520405566708744, 12.42417647938204, 13.373212204489246, 13.675668324813836, 12.733611822656385, 11.734054431896721, 10.80185675730506, 12.69128604101033, 13.752521888544399, 13.588909755989265, 12.66388930043479, 11.6868020903673, 10.691581211218411, 9.832770411848145, 8.928186233392383, 7.935792585623611, 8.776914395230772, 9.654534939763789, 10.514005606399971, 11.48800832647128, 12.549513649964846, 13.490254080242932, 13.897940668323013, 12.932278116124127, 11.917025757001468, 10.893351338833433, 9.888856557137151, 11.875185839751829, 12.936069251430498, 13.977448494851787, 13.62367994652058, 12.673144366339592, 11.707289242181812, 10.802160992816091, 9.867285069261563, 8.873174063152973, 9.851663859163834, 10.597779953915863, 11.117413383652913, 11.773172142794426, 12.700373055848301, 13.719601951761609, 12.966128345502337, 11.95776968255967, 10.993507632942459, 10.01146438820788, 8.952752848198534, 12.700065684209411, 13.676055931151813, 14.685122480031225, 14.551214135730413, 13.712790041447871, 12.760555860033309, 11.828642323672291, 10.809591772954786, 9.816733036129152, 10.761782327902097, 10.916355063610794, 10.090003650188136, 10.83122105103516, 11.86293149930538, 12.77785497385506, 13.775308160203682, 12.968845900657563, 11.941553173320385, 10.87402984402371, 9.841525817562939, 13.59919785362144, 14.613336276742375, 15.564303603302449, 15.553862702270742, 14.676834559473637, 13.692157715623786, 12.777458033709737, 11.820920755418904, 10.848526864038815, 10.8515175325417, 9.877119391279862, 9.035757411815634, 9.899867005043113, 10.831461113300001, 11.804064116477933, 12.734916530417435, 13.680126764330895, 12.775008778605903, 11.77382129406453, 10.710382813964728, 14.550831624790959, 15.524418525389565, 16.45697361011583, 15.529368788097075, 14.54667312559276, 13.562857537528764, 12.630115259557213, 11.753799033287123, 10.752281490539264, 9.829530130704097, 8.920421988624765, 8.016544486278216, 8.964818693065679, 9.950455967743542, 10.80579612810363, 11.743908487145228, 12.73148933505692, 13.68695110974219, 12.625992381657145, 11.63943739256094, 15.452704956439748, 16.49501466748131, 15.533477386187911, 14.582868250499715, 13.638060440760754, 12.564376141057778, 11.629045001897818, 10.684031115015525, 9.75442384718952, 8.902925777858542, 7.9239265267329895, 6.997894799832661, 7.973530965182595, 8.917346669850621, 9.745204019803088, 10.740950588388293, 11.75064505896459, 12.720447714843157, 13.581187979119386, 12.69291474699937, 16.380390590073922, 15.569890104037274, 14.5597943466898, 13.57767673971846, 12.641070307226597, 11.615231562735108, 10.671372461208643, 9.718771018590948, 8.74116855641938, 7.931767096651663, 6.942173676333398, 5.995207421968517, 6.926128681096277, 7.952394844682172, 8.772981864740453, 9.744395151428636, 10.758012014891165, 11.669241664814505, 12.62043399996571, 13.645690256863393], [13.613042325425491, 12.634286431681662, 11.672566554284355, 10.717570004768055, 9.734875770635883, 8.73215204348419, 7.841835582417732, 6.846045711709441, 5.83701048320871, 4.987042568550605, 5.949780226845731, 6.847458086460211, 7.7774377716812575, 8.787899331323256, 9.73125555197349, 10.740578547006852, 11.669284249226946, 12.598488422098317, 13.616956793886725, 14.574896739344831, 12.648709932373366, 11.691416098003353, 10.735080786867492, 9.74508881562577, 8.711750471235188, 7.75832289991414, 6.799369563891052, 5.853858266575175, 4.90855704423095, 3.9479917164518263, 4.880421297492953, 5.809626655228112, 6.8623653340661175, 7.8605667916774244, 8.89380595280219, 9.787776620830925, 10.632584438398593, 11.598663278869282, 12.622397738923175, 13.553776879332956, 11.68033950918584, 10.831034402019231, 9.827388225143162, 8.79689716755338, 7.7419622160148975, 6.760305089935105, 5.8042310044528875, 4.912338065351204, 3.9281109822835107, 2.930185491506984, 3.864553800957865, 4.844219040585013, 5.881342345031935, 6.875605320616995, 7.868722673886063, 8.848378032395747, 9.661310813755911, 10.648911502817612, 11.608392122637122, 12.60554046501603, 10.712320201590755, 9.821622822353527, 8.868069247687059, 7.8084699813066125, 6.755101667050979, 5.761928534836241, 4.805037421896565, 3.889522135467051, 2.910454888797906, 1.9522738286669536, 2.8909202999823758, 3.88207250370972, 4.930888655988826, 5.893849642276539, 6.906022488123092, 7.793354339332936, 8.72403971887954, 9.715527783524152, 10.642899941414738, 11.621560723236929, 9.780884519666648, 8.810631497516859, 7.874936233243128, 6.956166376883449, 5.897012863429315, 4.9090280271106765, 3.8381003135164113, 2.9403380560174313, 1.9838898259061568, 0.9377792186324649, 1.9613544709055653, 2.929269389424368, 3.9148853258673153, 4.938692361972725, 5.854994618812177, 6.836720639246362, 7.890271868095027, 8.830975762720962, 9.801410850018941, 10.732155169472806, 8.93105257417949, 7.917212243815609, 6.935187941463041, 5.979294301150952, 4.957606672362262, 3.9327196392624435, 2.8851869044233998, 1.9093147716708674, 0.9427269489024231, 0.0, 0.9624069146245723, 1.8973049482692188, 2.9658855080691335, 3.978465111896265, 4.927557750844523, 5.890827825916947, 6.894712334171056, 7.895137102702777, 8.838575811522517, 9.905399037106891, 9.775283404230654, 8.735649196312869, 7.735884205535753, 6.761158454936636, 5.771761134263049, 4.766543316864436, 3.8414553653597374, 2.882316315569845, 1.8872780654893817, 0.9263830044344431, 1.9586174169676882, 2.8917841800843123, 3.912492052110231, 4.857573482711761, 5.817808377595652, 6.783022920697699, 7.8126635563478155, 8.82015590758246, 9.772501358212235, 10.726494686213806, 10.67066421554501, 9.636461472686612, 8.6535946706396, 7.691159374610071, 6.722533126463303, 5.77843229603666, 4.842341692100668, 3.8662577029135576, 2.8524953320539823, 1.9113503726141605, 2.9182368708112336, 3.831118395274491, 4.801726047507816, 5.76158177775252, 6.722595737997439, 7.750850656763198, 8.775577607441166, 9.763173438424658, 10.707281132504585, 11.716033240632555, 11.634376199066896, 10.561662774205988, 9.583638848789114, 8.676051074133277, 7.723362188428771, 6.711031160784328, 5.801660899048641, 4.831415777993013, 3.844424837854743, 2.8513730187916764, 3.806501584659279, 4.741992436697787, 5.676012059095211, 6.6532429201545265, 7.681440518249723, 8.640652345476592, 9.594103227815495, 10.56339888102665, 11.520062680725768, 12.553881144469303, 12.560031520820136, 11.61084827676959, 10.596601131189805, 9.63113288988704, 8.740262348308715, 7.758439882922861, 6.773767934486586, 5.835892869935591, 4.821644510525652, 3.8795788069856014, 4.739703200823929, 5.766191880692566, 6.678977938746936, 7.655100415176622, 8.648536275262988, 9.597596576843934, 10.64784982260611, 11.530279117781612, 12.539187635492935, 13.524369393418871, 13.504168519180185, 12.623419146428471, 11.66939563917977, 10.603805796100334, 9.651893922881616, 8.71775797370368, 7.746873932375352, 6.7790081793013925, 5.782499403928655, 4.867645934047713, 5.762608960994713, 6.711085012743261, 7.694741440846771, 8.641198725902136, 9.580571091093661, 10.574344902710678, 11.596994985725262, 12.541205908941349, 13.531099878732496, 13.560215120290405, 13.505865515098865, 13.584970625354469, 12.597112142337261, 11.624648247831871, 10.619641688093855, 9.645256426108919, 8.727518177752902, 7.713175560777367, 6.747366088480311, 5.82410392025755, 6.708559033448576, 7.673906816309275, 8.649041783590857, 9.613086207564814, 10.554711708499001, 11.568064249680686, 12.499978767936994, 13.472883969684927, 13.527429476752733, 12.600901898241363, 12.663655904916666, 13.633970771280325, 13.553766941553109, 12.605890697456095, 11.596501832041152, 10.652304945993382, 9.72047306944782, 8.760924474927082, 7.804532948943123, 6.858722696994155, 7.699117387040389, 8.609985713412254, 9.554252850826362, 10.57767861780632, 11.481449530479617, 12.430485255586822, 13.388504128825552, 13.676338771558807, 12.676781380799143, 11.744583706207482, 11.748559092107905, 12.809794939641975, 13.755965529257834, 13.580785244658333, 12.585962503275324, 11.590741624126435, 10.658623964344061, 9.754039785888299, 8.761646138119527, 7.83418744632835, 8.711807990861365, 9.571278657497547, 10.545281377568855, 11.606786701062422, 12.547527131340509, 13.434216026044215, 13.875005065026551, 12.859752705903892, 11.836078287735857, 10.831583506039575, 10.932458890849405, 11.993342302528074, 13.034721545949363, 14.05350544771496, 13.54870291938278, 12.582847795225, 11.628014545312007, 10.693138621757479, 9.699027615648891, 8.908936910261412, 9.655053005013439, 10.609665842692635, 11.585946367967257, 12.513147281021132, 13.558843144058539, 13.908855294404761, 12.900496631462094, 11.936234581844882, 10.954191337110304, 9.895479797100958, 11.757338735306988, 12.73332898224939, 13.742395531128802, 14.794234434056866, 14.588348594491059, 13.636114413076497, 12.654495876168209, 11.635445325450704, 10.64258658862507, 9.979841228595877, 10.039600376742198, 10.91460097097881, 11.655818371825834, 12.687528820096055, 13.602452294645735, 14.642174853409315, 13.911572849559985, 12.884280122222806, 11.816756792926132, 10.784252766465361, 12.656470904719017, 13.670609327839951, 14.621576654400025, 15.556490783187945, 14.544177034141729, 13.559500190291878, 12.625396151261251, 11.794270969477292, 10.842796348776666, 9.974762845673105, 9.000364704411266, 9.860354732606309, 10.724464325833788, 11.656058434090676, 12.628661437268608, 13.675280526462174, 14.620490760375635, 13.717735727508325, 12.716548242966953, 11.65310976286715, 13.608104675888535, 14.581691576487142, 15.51424666121341, 14.586641839194654, 13.603946176690338, 12.620130588626342, 11.68738831065479, 10.811072084384701, 9.80955454163684, 8.9527754438355, 8.04366730175617, 8.84114180706889, 9.789416013856354, 10.775053288534217, 11.742321226803274, 12.684272483189968, 13.67185333110166, 14.629678058644611, 13.568719330559567, 12.582164341463361, 14.509978007537324, 15.55228771857889, 14.59075043728549, 13.640141301597293, 12.695333491858332, 11.621649192155356, 10.686318052995395, 9.741304166113103, 8.811696898287096, 8.026171090989946, 7.047171839864394, 7.822492120623335, 8.798128285973268, 9.741943990641294, 10.681729118502732, 11.681314584433032, 12.69100905500933, 13.66317466374558, 14.523914928021808, 13.635641695901795, 15.4376636411715, 14.62716315513485, 13.617067397787377, 12.634949790816036, 11.698343358324173, 10.672504613832686, 9.728645512306219, 8.776044069688526, 7.798441607516956, 6.98904014774924, 5.999446727430975, 6.819804742759191, 7.750726001886951, 8.776992165472846, 9.715708813642877, 10.687122100331058, 11.700738963793587, 12.611968613716929, 13.563160948868134, 14.588417205765817], [14.575449240050064, 13.596693346306235, 12.634973468908928, 11.679976919392628, 10.697282685260456, 9.694558958108761, 8.804242497042306, 7.804210924169397, 6.795175695668666, 5.94520778101056, 5.049975046676405, 5.88505117183564, 6.815030857056686, 7.825492416698686, 8.76884863734892, 9.778171632382282, 10.706877334602375, 11.636081507473746, 12.654549879262154, 13.61248982472026, 13.61111684699794, 12.653823012627926, 11.697487701492065, 10.707495730250344, 9.674157385859761, 8.720729814538712, 7.761776478515625, 6.8120234790351315, 5.866722256690906, 4.906156928911782, 3.9806161173236267, 4.847219740603541, 5.899958419441546, 6.898159877052852, 7.9313990381776165, 8.825369706206354, 9.670177523774022, 10.63625636424471, 11.659990824298603, 12.591369964708385, 12.642746423810413, 11.793441316643804, 10.789795139767735, 9.759304082177954, 8.70436913063947, 7.722712004559678, 6.766637919077461, 5.87050327781116, 4.886276194743467, 3.88835070396694, 2.953982394516059, 3.8818121259604417, 4.918935430407363, 5.913198405992423, 6.906315759261491, 7.885971117771175, 8.69890389913134, 9.686504588193042, 10.64598520801255, 11.64313355039146, 11.674727116215328, 10.7840297369781, 9.83047616231163, 8.770876895931185, 7.717508581675552, 6.724335449460814, 5.767444336521138, 4.851929050091623, 3.872861803422478, 2.914680743291526, 1.9285133853578031, 2.919665589085148, 3.968481741364254, 4.931442727651967, 5.94361557349852, 6.830947424708364, 7.761632804254969, 8.75312086889958, 9.680493026790167, 10.659153808612357, 10.743291434291221, 9.773038412141432, 8.8373431478677, 7.918573291508021, 6.859419778053886, 5.871434941735249, 4.800507228140984, 3.9027449706420034, 2.946296740530729, 1.9001861332570371, 0.9989475562809929, 1.9668624747997956, 2.952478411242743, 3.976285447348153, 4.892587704187605, 5.87431372462179, 6.927864953470455, 7.86856884809639, 8.83900393539437, 9.769748254848235, 9.893459488804062, 8.87961915844018, 7.897594856087612, 6.941701215775523, 5.920013586986833, 4.895126553887016, 3.847593819047972, 2.8717216862954396, 1.9051338635269954, 0.9624069146245723, 0.0, 0.9348980336446466, 2.0034785934445614, 3.016058197271693, 3.9651508362199506, 4.928420911292375, 5.932305419546484, 6.932730188078205, 7.876168896897946, 8.94299212248232, 10.737690318855227, 9.698056110937442, 8.698291120160325, 7.723565369561208, 6.734168048887621, 5.728950231489009, 4.80386227998431, 3.844723230194417, 2.849684980113954, 1.8887899190590154, 1.0623538673787156, 1.99347343740246, 2.950085137485659, 3.8951665680871885, 4.85540146297108, 5.820616006073127, 6.850256641723243, 7.857748992957889, 8.810094443587664, 9.764087771589235, 11.63307113016958, 10.598868387311184, 9.616001585264172, 8.653566289234643, 7.684940041087875, 6.740839210661232, 5.80474860672524, 4.82866461753813, 3.8149022466785545, 2.8737572872387327, 2.1298246115831274, 2.932807652592639, 3.903415304825964, 4.863271035070667, 5.781490873143219, 6.788443742138625, 7.813170692816594, 8.800766523800087, 9.744874217880014, 10.753626326007984, 12.596783113691467, 11.52406968883056, 10.546045763413685, 9.638457988757848, 8.685769103053342, 7.6734380754089, 6.764067813673213, 5.793822692617585, 4.806831752479315, 3.8137799334162485, 3.1089263027653744, 3.945692752738058, 4.864980598914109, 5.820207930083003, 6.807365136134594, 7.766576963361462, 8.720027845700365, 9.68932349891152, 10.645987298610638, 11.679805762354173, 13.522438435444707, 12.57325519139416, 11.559008045814377, 10.593539804511611, 9.702669262933286, 8.720846797547434, 7.736174849111158, 6.798299784560164, 5.784051425150224, 4.841985721610174, 4.042127918930023, 4.969892196732837, 5.867946478565834, 6.84406895499552, 7.801586379571184, 8.723521194728804, 9.77377444049098, 10.656203735666482, 11.665112253377805, 12.65029401130374, 13.587840902164363, 13.585826061053043, 12.631802553804341, 11.566212710724905, 10.614300837506189, 9.680164888328253, 8.709280846999924, 7.741415093925965, 6.744906318553227, 5.830052848672286, 5.065033679100809, 5.977363848783036, 6.883709980665669, 7.830167265721034, 8.76953963091256, 9.700269520595548, 10.722919603610132, 11.667130526826218, 12.657024496617366, 13.577553450030837, 12.631790132983735, 13.597435110201916, 13.559519056961832, 12.587055162456444, 11.582048602718428, 10.607663340733492, 9.689925092377475, 8.67558247540194, 7.709773003104883, 6.786510834882122, 6.010983751554671, 6.966174661515323, 7.881417112548114, 8.802054747383712, 9.743680248317899, 10.693988867565556, 11.625903385821864, 12.598808587569797, 13.670434490791791, 13.563308812865934, 11.701248990292095, 12.671563856655753, 13.698560464679542, 13.568297612080668, 12.558908746665725, 11.614711860617955, 10.682879984072393, 9.723331389551655, 8.766939863567696, 7.821129611618726, 7.001542105146485, 7.902253558618302, 8.84652069603241, 9.766647157625219, 10.670418070298515, 11.61945379540572, 12.57747266864445, 13.519529170801901, 13.639188295423713, 12.706990620832052, 10.786152177483334, 11.847388025017404, 12.793558614633262, 13.79112143929544, 13.548369417899897, 12.553148538751008, 11.621030878968634, 10.716446700512872, 9.7240530527441, 8.796594360952922, 8.01423270896746, 8.863546502703596, 9.837549222774904, 10.79575524088132, 11.736495671159407, 12.623184565863113, 13.530346407381838, 13.822159620528463, 12.798485202360428, 11.793990420664146, 9.970051976224834, 11.030935387903503, 12.072314631324792, 13.091098533090388, 14.087461152323371, 13.545254709849573, 12.59042145993658, 11.655545536382052, 10.661434530273464, 9.871343824885983, 8.957477723119535, 9.901933687898683, 10.878214213173305, 11.795805107101234, 12.747811683877437, 13.586940970040578, 13.862903546086665, 12.898641496469454, 11.916598251734875, 10.857886711725529, 10.794931820682416, 11.770922067624818, 12.77998861650423, 13.831827519432295, 14.558469531455888, 13.528695131257786, 12.611804946674125, 11.890445748355168, 10.912183262061758, 10.086604148397472, 10.005170044792017, 10.92934342136346, 11.820165304932571, 12.844958700424176, 13.689558661783986, 14.62390740636446, 14.873979764184558, 13.84668703684738, 12.779163707550705, 11.746659681089934, 11.694063990094445, 12.70820241321538, 13.659169739775454, 14.594083868563375, 13.58177011951716, 12.597093275667309, 11.66298923663668, 10.831864054852721, 9.880389434152095, 9.109524002643674, 9.958529916871221, 10.818519945066264, 11.682629538293742, 12.61422364655063, 13.586826649728563, 14.63344573892213, 15.578655972835591, 14.680142642132898, 13.678955157591526, 12.615516677491723, 12.645697761263964, 13.61928466186257, 14.55183974658884, 13.624234924570084, 12.641539262065768, 11.657723674001772, 10.724981396030218, 9.84866516976013, 8.84714762701227, 8.08753660080607, 9.001832514216124, 9.799307019528845, 10.747581226316308, 11.733218500994171, 12.70048643926323, 13.642437695649924, 14.630018543561617, 15.592084973269184, 14.53112624518414, 13.544571256087934, 13.547571092912753, 14.58988080395432, 13.62834352266092, 12.677734386972723, 11.732926577233762, 10.659242277530787, 9.723911138370823, 8.778897251488532, 7.8492899836625245, 7.160932247960516, 8.005337052324348, 8.78065733308329, 9.756293498433225, 10.70010920310125, 11.639894330962688, 12.639479796892989, 13.649174267469286, 14.625581578370154, 15.486321842646381, 14.598048610526368, 14.47525672654693, 13.66475624051028, 12.654660483162807, 11.672542876191466, 10.735936443699604, 9.710097699208116, 8.766238597681648, 7.813637155063954, 6.836034692892385, 6.089234967579913, 6.95761193989093, 7.777969955219147, 8.708891214346908, 9.735157377932802, 10.678115728267448, 11.64952901495563, 12.66314587841816, 13.574375528341502, 14.525567863492707, 15.55082412039039], [15.51034727369471, 14.531591379950882, 13.569871502553575, 12.614874953037274, 11.632180718905103, 10.629456991753408, 9.692691966146128, 8.675623417070897, 7.666588188570166, 6.81662027391206, 5.914498770124933, 4.950153138190993, 5.88013282341204, 6.890594383054039, 7.833950603704273, 8.843273598737634, 9.771979300957728, 10.701183473829099, 11.719651845617507, 12.677591791075614, 14.546014880642586, 13.588721046272573, 12.632385735136712, 11.64239376389499, 10.609055419504408, 9.655627848183359, 8.696674512160271, 7.683435971936632, 6.7381347495924055, 5.777569421813282, 4.845139840772155, 3.9123217069588936, 4.965060385796899, 5.963261843408205, 6.99650100453297, 7.8904716725617075, 8.735279490129376, 9.701358330600064, 10.725092790653957, 11.656471931063738, 13.57764445745506, 12.72833935028845, 11.724693173412382, 10.6942021158226, 9.639267164284117, 8.657610038204325, 7.701535952722106, 6.805401311455807, 5.821174228388114, 4.8232487376115865, 3.8888804281607054, 2.9469140923157946, 3.984037396762716, 4.978300372347776, 5.971417725616844, 6.951073084126528, 7.764005865486693, 8.751606554548395, 9.711087174367904, 10.708235516746813, 12.609625149859975, 11.718927770622747, 10.765374195956277, 9.705774929575831, 8.652406615320198, 7.65923348310546, 6.702342370165784, 5.786827083736269, 4.807759837067125, 3.8495787769361725, 2.8634114190024498, 1.984767555440501, 3.033583707719607, 3.9965446940073193, 5.008717539853873, 5.896049391063717, 6.826734770610322, 7.818222835254935, 8.74559499314552, 9.72425577496771, 11.678189467935868, 10.707936445786078, 9.772241181512346, 8.853471325152668, 7.794317811698533, 6.8063329753798945, 5.73540526178563, 4.83764300428665, 3.8811947741753756, 2.8350841669016837, 1.9338455899256395, 1.031964441155149, 2.017580377598096, 3.0413874137035055, 3.957689670542958, 4.939415690977143, 5.992966919825808, 6.933670814451743, 7.9041059017497215, 8.834850221203586, 10.828357522448707, 9.814517192084825, 8.832492889732258, 7.8765992494201695, 6.85491162063148, 5.830024587531662, 4.782491852692618, 3.806619719940086, 2.840031897171642, 1.8973049482692188, 0.9348980336446466, 0.0, 1.0685805597999145, 2.081160163627046, 3.0302528025753035, 3.9935228776477274, 4.997407385901837, 5.997832154433557, 6.9412708632532985, 8.008094088837673, 11.672588352499874, 10.632954144582088, 9.633189153804972, 8.658463403205854, 7.669066082532267, 6.663848265133654, 5.738760313628956, 4.779621263839063, 3.7845830137586005, 2.823687952703662, 1.9917421668744373, 1.0585754037578134, 2.0151871038410123, 2.960268534442542, 3.920503429326433, 4.8857179724284805, 5.915358608078597, 6.922850959313241, 7.8751964099430145, 8.829189737944587, 12.567969163814226, 11.53376642095583, 10.550899618908819, 9.58846432287929, 8.619838074732522, 7.675737244305879, 6.739646640369887, 5.763562651182777, 4.749800280323202, 3.8086553208833793, 2.9746832972789763, 1.9979096189479921, 2.968517271181317, 3.9283730014260207, 4.846592839498572, 5.853545708493979, 6.878272659171947, 7.865868490155439, 8.809976184235365, 9.818728292363335, 13.531681147336114, 12.458967722475206, 11.480943797058332, 10.573356022402495, 9.62066713669799, 8.608336109053548, 7.69896584731786, 6.728720726262232, 5.741729786123962, 4.748677967060895, 3.946285571131919, 3.0107947190934112, 3.930082565269462, 4.885309896438357, 5.8724671024899475, 6.831678929716816, 7.785129812055718, 8.754425465266873, 9.711089264965992, 10.744907728709526, 13.597079866879765, 13.508153225038807, 12.493906079459023, 11.528437838156258, 10.637567296577934, 9.65574483119208, 8.671072882755805, 7.73319781820481, 6.718949458794871, 5.77688375525482, 4.879487187296569, 4.03499416308819, 4.933048444921187, 5.909170921350873, 6.866688345926537, 7.788623161084158, 8.838876406846335, 9.721305702021835, 10.730214219733158, 11.715395977659094, 12.652942868519716, 13.689453187957344, 13.566700587448988, 12.501110744369551, 11.549198871150837, 10.615062921972902, 9.644178880644573, 8.676313127570612, 7.679804352197873, 6.764950882316932, 5.902392947467353, 5.04246581513839, 5.948811947021023, 6.895269232076387, 7.834641597267913, 8.765371486950901, 9.788021569965487, 10.732232493181572, 11.722126462972719, 12.64265541638619, 11.696892099339088, 12.66253707655727, 13.650395559574477, 13.521953196101093, 12.516946636363077, 11.54256137437814, 10.624823126022122, 9.610480509046587, 8.64467103674953, 7.721408868526769, 6.848343019921216, 6.031276627870676, 6.946519078903467, 7.867156713739066, 8.808782214673252, 9.75909083392091, 10.691005352177218, 11.66391055392515, 12.735536457147145, 13.601968638435233, 10.766350956647447, 11.736665823011105, 12.763662431034893, 13.711538675131907, 13.493806780310372, 12.549609894262602, 11.61777801771704, 10.658229423196302, 9.701837897212343, 8.756027645263373, 7.838901373513029, 6.967355524973655, 7.911622662387763, 8.831749123980572, 9.735520036653869, 10.684555761761073, 11.642574634999804, 12.584631137157254, 13.584188527916918, 13.641888654476698, 9.851254143838686, 10.912489991372755, 11.858660580988614, 12.856223405650791, 13.8510461470338, 13.488046572395655, 12.55592891261328, 11.651344734157519, 10.658951086388747, 9.731492394597568, 8.851591977334005, 7.928648469058949, 8.902651189130255, 9.860857207236673, 10.80159763751476, 11.688286532218466, 12.595448373737192, 13.569851809559252, 13.733383236005073, 12.728888454308791, 9.035153942580187, 10.096037354258856, 11.137416597680145, 12.156200499445742, 13.152563118678724, 13.647063715464634, 12.70338824388568, 11.93939742156614, 10.92084420139329, 10.80624185853063, 9.79483699148608, 8.967035654254037, 9.943316179528656, 10.860907073456588, 11.81291365023279, 12.652042936395931, 13.65924828614966, 13.833539530114098, 12.85149628537952, 11.792784745370174, 9.860033787037768, 10.83602403398017, 11.845090582859582, 12.896929485787647, 13.623571497811241, 12.593797097613137, 11.676906913029478, 10.955547714710521, 9.977285228417111, 10.874480373070705, 10.842529313158561, 9.994445387718814, 10.885267271287923, 11.910060666779529, 12.754660628139339, 13.689009372719813, 14.67381991908574, 14.781585070492026, 13.714061741195351, 12.68155771473458, 10.759165956449799, 11.773304379570734, 12.724271706130807, 13.659185834918727, 12.646872085872511, 11.66219524202266, 10.728091202992033, 9.896966021208074, 8.945491400507448, 9.897400227316908, 10.774880996202192, 11.048691626091315, 11.816621317279969, 12.748215425536857, 13.72081842871479, 14.72940100250606, 15.642259210977667, 15.615040675777545, 14.613853191236172, 13.55041471113637, 11.710799727619317, 12.684386628217924, 13.616941712944191, 12.689336890925436, 11.70664122842112, 10.722825640357124, 9.790083362385571, 8.913767136115483, 7.912249593367622, 8.875412825479303, 9.818183593547095, 10.670719512430347, 11.61899371921781, 12.604630993895674, 13.57189893216473, 14.513850188551425, 15.501431036463117, 16.504039333680794, 15.466024278828787, 14.479469289732581, 12.612673059268106, 13.65498277030967, 12.69344548901627, 11.742836353328073, 10.798028543589112, 9.724344243886138, 8.789013104726177, 7.843999217843885, 6.914391950017878, 7.948808472633749, 8.876749545225849, 9.652069825984793, 10.627705991334725, 11.571521696002751, 12.511306823864189, 13.510892289794489, 14.520586760370787, 15.50033145940631, 16.421219876291026, 15.532946644171014, 13.540358692902283, 12.729858206865632, 11.719762449518159, 10.737644842546818, 9.801038410054955, 8.775199665563468, 7.831340564037002, 6.878739121419307, 5.901136659247738, 6.930782745589922, 7.82902443279243, 8.649382448120647, 9.580303707248408, 10.606569870834303, 11.558368522842526, 12.561917930940224, 13.575534794402753, 14.509273561986149, 15.460465897137354, 16.485722154035034], [16.578927833494628, 15.600171939750798, 14.63845206235349, 13.68345551283719, 12.650902096223641, 11.591407859642546, 10.637124973034615, 9.620056423959383, 8.611021195458653, 7.761053280800547, 6.85893177701342, 5.894586145079479, 5.02450190664052, 5.891872589606064, 6.8352288102562975, 7.827994485434519, 8.703398741157812, 9.632602914029183, 10.651071285817592, 11.609011231275698, 15.614595440442502, 14.657301606072489, 13.700966294936627, 12.710974323694906, 11.677635979304323, 10.674810060832383, 9.662376624590593, 8.627868978825118, 7.682567756480893, 6.722002428701769, 5.789572847660642, 4.856754713847381, 4.030144841038899, 4.894681283608291, 5.927920444733056, 6.821891112761793, 7.666698930329461, 8.63277777080015, 9.656512230854043, 10.587891371263822, 14.646225017254975, 13.796919910088366, 12.793273733212297, 11.762782675622516, 10.707847724084033, 9.72619059800424, 8.770116512522021, 7.867734463280874, 6.88350738021318, 5.8855818894366525, 4.9512135799857715, 3.8913470992042813, 3.0008841961458774, 3.909719812547862, 4.90283716581693, 5.882492524326613, 6.695425305686778, 7.68302599474848, 8.642506614567989, 9.639654956946897, 13.67820570965989, 12.787508330422662, 11.833954755756192, 10.774355489375747, 9.720987175120113, 8.727814042905376, 7.7709229299657, 6.855407643536184, 5.87634039686704, 4.918159336736087, 3.931991978802365, 2.9292005623289876, 2.021619937407052, 2.9279641342074054, 3.9401369800539587, 4.827468831263802, 5.758154210810408, 6.74964227545502, 7.677014433345605, 8.655675215167795, 12.746770027735783, 11.776517005585994, 10.840821741312263, 9.922051884952584, 8.86289837149845, 7.87491353517981, 6.803985821585545, 5.906223564086565, 4.949775333975291, 3.9036647267015985, 3.0024261497255544, 1.9763974480436355, 0.9489998177981817, 1.9728068539035915, 2.8891091107430436, 3.8708351311772287, 4.924386360025894, 5.865090254651828, 6.835525341949807, 7.766269661403673, 11.896938082248626, 10.883097751884744, 9.901073449532175, 8.945179809220086, 7.923492180431396, 6.898605147331578, 5.851072412492534, 4.875200279740001, 3.908612456971557, 2.9658855080691335, 2.0034785934445614, 1.0685805597999145, 0.0, 1.0125796038271315, 1.9616722427753892, 2.924942317847813, 3.9288268261019224, 4.929251594633643, 5.872690303453384, 6.939513529037758, 12.741168912299791, 11.701534704382006, 10.70176971360489, 9.727043963005771, 8.737646642332184, 7.73242882493357, 6.807340873428871, 5.848201823638979, 4.853163573558516, 3.8922685125035765, 2.9456873775620185, 2.0125206144453944, 0.9466065440410978, 1.8916879746426274, 2.8519228695265184, 3.817137412628566, 4.846778048278683, 5.854270399513327, 6.806615850143101, 7.760609178144673, 13.636549723614142, 12.602346980755746, 11.619480178708734, 10.657044882679205, 9.688418634532438, 8.744317804105792, 7.808227200169801, 6.832143210982691, 5.818380840123115, 4.877235880683294, 3.874191708085597, 2.897418029754613, 1.9268103775212881, 2.886666107765992, 3.778012279698658, 4.784965148694065, 5.809692099372033, 6.797287930355525, 7.741395624435452, 8.750147732563422, 13.499913777809784, 13.527548282275122, 12.549524356858248, 11.64193658220241, 10.689247696497905, 9.676916668853462, 8.66330259216993, 7.693057471114304, 6.706066530976034, 5.713014711912967, 4.757886146045364, 3.8223952940068564, 2.8883756716094333, 3.8436030027783277, 4.803886542690033, 5.763098369916901, 6.7165492522558035, 7.685844905466958, 8.642508705166076, 9.67632716890961, 12.52849930707985, 13.477682551130396, 13.562486639258939, 12.597018397956173, 11.67038620878758, 10.684971776271194, 9.635409627607876, 8.679846546316929, 7.6157759155458695, 6.673710212005819, 5.691087762210014, 4.846594738001635, 3.891341551261159, 4.867464027690845, 5.798107786126623, 6.720042601284243, 7.7702958470464205, 8.65272514222192, 9.661633659933242, 10.646815417859179, 11.5843623087198, 12.620872628157429, 13.509531502932052, 13.475137644135234, 12.446025327901836, 11.5118893787239, 10.541005337395571, 9.573139584321611, 8.576630808948872, 7.661777339067931, 6.7139935223807985, 5.854066390051835, 4.907105053360994, 5.85356233841636, 6.7929347036078855, 7.696790927150986, 8.719441010165571, 9.663651933381656, 10.653545903172803, 11.574074856586275, 10.628311539539173, 11.593956516757354, 12.581814999774561, 13.624200564956217, 13.413773093114076, 12.439387831129139, 11.52164958277312, 10.507306965797586, 9.541497493500529, 8.618235325277768, 7.659943594834661, 6.842877202784122, 5.904812185243439, 6.825449820079038, 7.767075321013225, 8.690510274120996, 9.622424792377304, 10.595329994125237, 11.666955897347231, 12.533388078635317, 9.697770396847533, 10.668085263211191, 11.69508187123498, 12.642958115331993, 13.69462532999756, 13.446436351013602, 12.47989743738074, 11.520348842860002, 10.563957316876044, 9.603048035429868, 8.650501948426474, 7.7789560998871, 6.894839208246764, 7.790042230320545, 8.693813142993841, 9.642848868101046, 10.600867741339776, 11.542924243497227, 12.542481634256891, 13.474679308848552, 8.782673584038772, 9.843909431572841, 10.7900800211887, 11.787642845850877, 12.782465587233887, 13.663880028375496, 12.674057031405653, 12.0228653406638, 11.521070506052448, 10.578512784764063, 9.663192552247448, 8.740249043972394, 7.885867734989257, 8.819150313576648, 9.759890743854733, 10.646579638558439, 11.553741480077164, 12.528144915899224, 13.503201293906088, 13.79746901410871, 7.966573382780273, 9.027456794458942, 10.068836037880232, 11.087619939645828, 12.08398255887881, 12.648341922016659, 11.704666450437706, 11.083766504794621, 11.865277208281777, 11.653262248697125, 10.606437566399523, 9.778636229167482, 8.92653272538766, 9.819200179796562, 10.771206756572763, 11.610336042735904, 12.617541392489633, 13.551988002635444, 13.92007684517944, 12.861365305170093, 8.791453227237854, 9.767443474180256, 10.776510023059668, 11.828348925987733, 12.624849704363264, 11.595075304165162, 10.678185119581505, 10.099916797939002, 10.921718235305597, 11.818913379959191, 11.654129888072005, 10.80604596263226, 9.868483817146926, 10.868353773119503, 11.712953734479312, 12.647302479059785, 13.632113025425713, 14.622394865323384, 14.782642300995267, 13.750138274534496, 9.690585396649883, 10.704723819770818, 11.655691146330891, 12.601645118844065, 11.648150292424535, 10.663473448574685, 9.72936940954406, 9.041335104436556, 9.889924407395934, 10.841833234205394, 11.719314003090679, 11.769595633290237, 10.799837863138972, 11.73143197139586, 12.686744591856439, 13.687694108846033, 14.60055231731764, 15.550439649548348, 15.682433751036088, 14.618995270936285, 10.642219167819402, 11.615806068418008, 12.55509126263085, 11.69061509747746, 10.707919434973144, 9.724103846909149, 8.791361568937598, 8.058136219343965, 8.856682600256109, 9.81984583236779, 10.762616600435582, 11.615152519318832, 11.734886175116406, 12.72052344979427, 13.754783839547867, 14.67870215211824, 15.558968360468107, 16.56785640203472, 16.534604838628702, 15.548049849532497, 11.54409249946819, 12.601359820058816, 11.668433635678044, 10.717824499989847, 9.799306750141138, 8.725622450438163, 7.790291311278202, 6.988368301072366, 7.858824956906364, 8.893241479522235, 9.821182552114337, 10.596502832873277, 11.572138998223211, 12.515954702891237, 13.455739830752675, 14.455325296682975, 15.465019767259273, 16.444764466294796, 17.479630503051776, 16.60152720397093, 12.471778133102367, 11.677861810602806, 10.675699186182012, 9.698711102093677, 8.78575929675184, 7.776477872115493, 6.8326187705890264, 6.023108204647787, 6.845569666136225, 7.875215752478408, 8.773457439680918, 9.593815455009134, 10.524736714136894, 11.551002877722789, 12.502801529731013, 13.50635093782871, 14.519967801291239, 15.536912950478644, 16.48810528562985, 17.554302713834954], [17.591507437321756, 16.612751543577925, 15.65103166618062, 14.69603511666432, 13.663481700050772, 12.603987463469677, 11.649704576861746, 10.632636027786514, 9.623600799285784, 8.773632884627677, 7.863334894812955, 6.819734230641979, 5.889754545420932, 4.879292985778933, 5.822649206429166, 6.815414881607388, 7.690819137330681, 8.620023310202052, 9.63849168199046, 10.596431627448567, 16.62717504426963, 15.669881209899618, 14.713545898763757, 13.723553927522035, 12.690215583131453, 11.687389664659515, 10.674956228417724, 9.64044858265225, 8.695147360308024, 7.7345820325289, 6.802152451487773, 5.869334317674512, 4.928876486514147, 3.8821016797811594, 4.915340840905924, 5.809311508934662, 6.654119326502329, 7.620198166973018, 8.643932627026912, 9.575311767436691, 15.658804621082107, 14.809499513915496, 13.805853337039427, 12.775362279449645, 11.720427327911162, 10.73877020183137, 9.78269611634915, 8.880314067108005, 7.896086984040312, 6.8981614932637845, 5.9637931838129035, 4.903926703031413, 3.941316748887659, 2.8971402087207303, 3.8902575619897983, 4.869912920499482, 5.682845701859646, 6.670446390921348, 7.629927010740857, 8.627075353119766, 14.690785313487021, 13.800087934249794, 12.846534359583321, 11.786935093202876, 10.733566778947242, 9.740393646732505, 8.783502533792829, 7.867987247363314, 6.888920000694171, 5.930738940563218, 4.944571582629496, 3.941780166156119, 2.9620524901488334, 1.915384530380274, 2.9275573762268268, 3.814889227436671, 4.745574606983276, 5.737062671627888, 6.664434829518473, 7.643095611340663, 13.759349631562914, 12.789096609413125, 11.853401345139392, 10.934631488779713, 9.875477975325579, 8.88749313900694, 7.8165654254126755, 6.918803167913695, 5.962354937802421, 4.9162443305287296, 4.0150057535526855, 2.988977051870767, 1.9615794216253133, 0.9602272500764599, 1.876529506915912, 2.8582555273500976, 3.9118067561987626, 4.852510650824697, 5.822945738122676, 6.7536900575765415, 12.909517686075754, 11.895677355711872, 10.913653053359305, 9.957759413047215, 8.936071784258525, 7.911184751158707, 6.863652016319664, 5.8877798835671316, 4.921192060798687, 3.9784651118962646, 3.0160581972716924, 2.081160163627046, 1.0125796038271315, 0.0, 0.9490926389482578, 1.9123627140206818, 2.916247222274791, 3.9166719908065115, 4.860110699626253, 5.926933925210627, 13.75374851612692, 12.714114308209135, 11.714349317432019, 10.7396235668329, 9.750226246159313, 8.7450084287607, 7.819920477256002, 6.860781427466109, 5.865743177385646, 4.904848116330708, 3.939444358170821, 3.006277595054197, 1.9403635246498998, 0.9952820940483702, 1.942961952199107, 2.8666886705846606, 3.896329306234777, 4.841690795686196, 5.79403624631597, 6.748029574317542, 13.54465946043021, 13.614926584582875, 12.632059782535864, 11.669624486506335, 10.700998238359567, 9.74191711031397, 8.80582650637798, 7.829742517190869, 6.8159801463312935, 5.874835186891472, 4.8679486886943995, 3.891175010363415, 2.92056735813009, 2.024951733613804, 2.8690513623712466, 3.834516406650159, 4.859243357328127, 5.784708326528394, 6.7288160206083205, 7.73756812873629, 12.566008726528526, 13.585725539664843, 13.562103960685377, 12.65451618602954, 11.686847002706083, 10.67451597506164, 9.657059572778733, 8.686814451723105, 7.699823511584836, 6.7067716925217695, 5.751643126654167, 4.816152274615659, 3.8821326522182353, 2.9818886286261397, 3.8949256253626214, 4.854137452589489, 5.807588334928392, 6.7519398541857, 7.6875073881047635, 8.721325851848297, 11.573497990018536, 12.522681234069083, 13.536928379648867, 13.609598001783302, 12.664143189396384, 11.678728756879998, 10.629166608216678, 9.673603526925731, 8.609532896154672, 7.667467192614621, 6.684844742818816, 5.840351718610438, 4.885098531869961, 4.053433121797452, 4.8891468687992115, 5.811081683956831, 6.861334929719009, 7.718820090940661, 8.727728608651985, 9.71291036657792, 10.629360991658487, 11.655531046053024, 12.497240842316895, 13.567795156522699, 13.439782308510638, 12.505646359332703, 11.534762318004374, 10.566896564930413, 9.570387789557675, 8.655534319676732, 7.707750502989601, 6.847823370660637, 5.900862033969796, 5.039531432522967, 5.910969023299811, 6.787830009823574, 7.81048009283816, 8.729746882100397, 9.719640851891544, 10.640169805305018, 9.673310222477859, 10.581665856142196, 11.569524339159404, 12.611620961129084, 13.6166275208671, 13.433144811737941, 12.515406563381923, 11.501063946406388, 10.535254474109331, 9.611992305886568, 8.653700575443462, 7.836634183392924, 6.898569165852241, 6.011418914185645, 6.9068673435097185, 7.781549356793583, 8.713463875049891, 9.686369076797824, 10.757994980019818, 11.59948302735406, 8.6851907930204, 9.655505659384058, 10.682502267407846, 11.63037851150486, 12.682045726170426, 13.573822635441191, 12.599628322474762, 12.514105823468805, 11.557714297484846, 10.59680501603867, 9.644258929035276, 8.772713080495903, 7.888596188855566, 6.976011324427152, 7.833605165490335, 8.78264089059754, 9.74065976383627, 10.67298304925694, 11.672540440016604, 12.604738114608265, 7.770093980211641, 8.83132982774571, 9.77750041736157, 10.775063242023746, 11.769885983406756, 12.651300424548365, 11.661477427578522, 12.604543524643235, 12.51482748666125, 11.572269765372866, 10.65694953285625, 9.734006024581197, 8.879624715598059, 8.005119407683255, 8.899682766351226, 9.786371661054933, 10.693533502573658, 11.658203721658937, 12.6332600996658, 13.637754881362083, 6.953993778953142, 8.014877190631811, 9.0562564340531, 10.075040335818697, 11.07140295505168, 11.635762318189528, 10.692086846610575, 11.665444688774055, 12.623720729200075, 12.647019229305927, 11.600194547008325, 10.772393209776283, 9.92028970599646, 9.005169273903169, 9.910998779069256, 10.750128065232397, 11.757333414986126, 12.682046808395157, 13.602945505490768, 13.87394490899722, 7.778873623410723, 8.754863870353125, 9.763930419232537, 10.815769322160602, 11.612270100536133, 10.58249570033803, 9.665605515754374, 10.712384552612168, 11.680161756223896, 12.605865510111478, 12.647886868680807, 11.79980294324106, 10.862240797755726, 10.05432286722611, 10.852745756975805, 11.787094501556279, 12.771905047922207, 13.752453671083098, 14.574288561951798, 14.762717878361627, 8.678005792822752, 9.692144215943687, 10.64311154250376, 11.589065515016934, 10.635570688597404, 9.650893844747554, 8.716789805716928, 9.675974036934145, 10.648367928314233, 11.62878536435768, 12.605517059111161, 12.763352613899038, 11.793594843747773, 11.10893295765152, 11.826536614352932, 12.827486131342527, 13.740344339814133, 14.680498455308062, 15.571833728488297, 15.631574874763416, 9.62963956399227, 10.603226464590877, 11.542511658803718, 10.678035493650329, 9.695339831146013, 8.711524243082017, 7.778781965110467, 8.747923828463275, 9.742885656276592, 10.706048888388272, 11.648819656456064, 12.627732123145963, 12.728643155725207, 12.174480002446831, 12.894575862044361, 13.818494174614733, 14.6987603829646, 15.707648424531214, 16.581102174456298, 16.560629453359628, 10.53151289564106, 11.588780216231685, 10.655854031850913, 9.705244896162716, 8.786727146314007, 7.713042846611032, 6.777711707451071, 7.7472029573789625, 8.745028012926847, 9.779444535542718, 10.75844378666827, 11.609082436700408, 12.584718602050343, 13.246367511175434, 13.955167970344903, 14.821452073371669, 15.679604659056931, 16.659349358092452, 17.536297771918537, 17.61410680779806, 11.459198529275236, 10.665282206775675, 9.66311958235488, 8.686131498266546, 7.7731796929247094, 6.7638982682883615, 5.820039166761895, 6.846399621664842, 7.770717751698724, 8.800363838040909, 9.786037043508047, 10.606395058836265, 11.537316317964025, 12.56358248154992, 13.515381133558144, 14.518930541655841, 15.53254740511837, 16.549492554305775, 17.50068488945698, 18.56688231766208], [18.540600076270014, 17.561844182526183, 16.60012430512888, 15.64512775561258, 14.61257433899903, 13.553080102417935, 12.598797215810004, 11.581728666734772, 10.572693438234042, 9.722725523575935, 8.796608055655089, 7.753007391484112, 6.8230277062630655, 5.812566146621066, 5.115017747055845, 5.8663222426591295, 6.741726498382424, 7.670930671253795, 8.689399043042203, 9.647338988500309, 17.57626768321789, 16.618973848847876, 15.662638537712017, 14.672646566470295, 13.639308222079713, 12.636482303607773, 11.624048867365982, 10.589541221600507, 9.644239999256282, 8.683674671477158, 7.751245090436031, 6.81842695662277, 5.86214964735628, 4.815374840623293, 4.067362206114403, 4.8602188699864035, 5.705026687554072, 6.671105528024761, 7.694839988078654, 8.626219128488435, 16.607897260030363, 15.758592152863756, 14.754945975987686, 13.724454918397905, 12.669519966859422, 11.68786284077963, 10.73178875529741, 9.829406706056263, 8.845179622988569, 7.847254132212043, 6.912885822761162, 5.853019341979671, 4.874589909729793, 3.830413369562864, 3.042278927198277, 3.920820281551224, 4.733753062911389, 5.721353751973091, 6.6808343717926, 7.67798271417151, 15.63987795243528, 14.749180573198052, 13.795626998531581, 12.736027732151136, 11.682659417895502, 10.689486285680765, 9.732595172741089, 8.817079886311573, 7.838012639642429, 6.879831579511476, 5.893664221577754, 4.890872805104377, 3.8953256509909675, 2.8486576912224075, 1.9784647372785693, 2.865796588488413, 3.7964819680350184, 4.787970032679631, 5.715342190570216, 6.694002972392406, 14.708442270511172, 13.738189248361383, 12.80249398408765, 11.883724127727971, 10.824570614273837, 9.8365857779552, 8.765658064360935, 7.867895806861953, 6.911447576750679, 5.865336969476988, 4.964098392500944, 3.9380696908190247, 2.910672060573571, 1.8935004109185938, 0.9274368679676543, 1.9091628884018397, 2.9627141172505045, 3.9034180118764388, 4.873853099174418, 5.804597418628283, 13.858610325024012, 12.84476999466013, 11.862745692307563, 10.906852051995473, 9.885164423206783, 8.860277390106965, 7.812744655267922, 6.83687252251539, 5.8702846997469456, 4.927557750844523, 3.9651508362199506, 3.030252802575304, 1.9616722427753892, 0.9490926389482578, 0.0, 0.963270075072424, 1.9671545833265331, 2.9675793518582534, 3.9110180606779945, 4.977841286262369, 13.580121035500651, 13.663206947157393, 12.663441956380277, 11.688716205781159, 10.699318885107571, 9.694101067708958, 8.76901311620426, 7.809874066414367, 6.814835816333904, 5.853940755278966, 4.888536997119078, 3.9553702340024546, 2.8894561635981577, 1.944374732996628, 0.9938693132508493, 1.917596031636403, 2.947236667286519, 3.8925981567379373, 4.8449436073677115, 5.798936935369284, 12.59556682148195, 13.60731217070761, 13.576538940294409, 12.61410364426488, 11.645477396118112, 10.662178166096492, 9.726087562160501, 8.750003572973391, 7.736241202113815, 6.795096242673994, 5.78820974447692, 4.811436066145936, 3.840828413912612, 2.880972683667908, 1.9199587234229887, 2.8854237677019015, 3.91015071837987, 4.835615687580135, 5.7797233816600615, 6.788475489788031, 11.616916087580266, 12.636632900716585, 13.6007980231013, 13.598995343788085, 12.607108058488604, 11.594777030844162, 10.577320628561255, 9.607075507505627, 8.620084567367357, 7.627032748304291, 6.6719041824366885, 5.736413330398181, 4.802393708000757, 3.8379095786802435, 2.9458329864143638, 3.905044813641232, 4.858495695980134, 5.802847215237442, 6.7384147491565045, 7.772233212900038, 10.624405351070278, 11.573588595120825, 12.587835740700609, 13.56898882325869, 13.584404245178906, 12.59898981266252, 11.5494276639992, 10.593864582708253, 9.529793951937194, 8.587728248397143, 7.605105798601338, 6.76061277439296, 5.805359587652482, 4.909454071851556, 3.9400542298509538, 4.861989045008574, 5.9122422907707515, 6.769727451992403, 7.778635969703726, 8.763817727629661, 9.680268352710229, 10.706438407104766, 11.548148203368637, 12.618702517574441, 13.635282647131081, 13.425907415115224, 12.455023373786895, 11.487157620712935, 10.490648845340196, 9.575795375459254, 8.628011558772123, 7.768084426443159, 6.821123089752318, 5.895552382577071, 4.9618763843515525, 5.838737370875317, 6.861387453889902, 7.780654243152139, 8.770548212943286, 9.691077166356758, 8.724217583529601, 9.632573217193938, 10.620431700211146, 11.662528322180826, 12.667534881918842, 13.645175522613082, 13.435667619164445, 12.42132500218891, 11.455515529891853, 10.53225336166909, 9.573961631225984, 8.756895239175446, 7.818830221634762, 6.867439864239749, 5.95777470456146, 6.832456717845326, 7.764371236101634, 8.737276437849566, 9.80890234107156, 10.6503903884058, 7.736098154072142, 8.7064130204358, 9.733409628459588, 10.681285872556602, 11.732953087222167, 12.677149973269938, 13.532901483316893, 13.434366879251327, 12.477975353267368, 11.517066071821192, 10.564519984817798, 9.692974136278425, 8.808857244638087, 7.832032274481256, 6.884512526542077, 7.833548251649281, 8.791567124888012, 9.723890410308682, 10.723447801068346, 11.655645475660007, 6.821001341263383, 7.882237188797453, 8.828407778413313, 9.82597060307549, 10.8207933444585, 11.816014223607388, 12.594750588420652, 13.537816685485366, 13.435088542443772, 12.492530821155388, 11.577210588638772, 10.654267080363718, 9.79988577138058, 8.861140357737359, 7.950590127402968, 8.837279022106674, 9.7444408636254, 10.70911108271068, 11.684167460717543, 12.688662242413825, 6.0049011400048835, 7.065784551683553, 8.107163795104842, 9.125947696870439, 10.122310316103421, 10.928130858816207, 11.625360007452706, 12.598717849616186, 13.556993890042207, 13.567280285088449, 12.520455602790847, 11.692654265558804, 10.788391137011148, 9.861190223957273, 8.961906140120998, 9.80103542628414, 10.808240776037868, 11.732954169446899, 12.65385286654251, 13.624765951352442, 6.829780984462465, 7.805771231404867, 8.814837780284279, 9.866676683212344, 10.82691628975834, 9.87486424096471, 10.598878676596506, 11.645657713454302, 12.613434917066028, 13.53913867095361, 13.568147924463329, 12.675510943350382, 11.730342228770414, 10.862750269614722, 9.903653118027547, 10.83800186260802, 11.822812408973949, 12.80336103213484, 13.62519592300354, 14.569979480589957, 7.728913153874494, 8.743051576995429, 9.694018903555502, 10.639972876068676, 9.927939229224084, 8.943262385374233, 9.65006296655906, 10.609247197776277, 11.581641089156365, 12.562058525199813, 13.538790219953293, 13.631454044913726, 12.66169627476246, 11.850046978582606, 10.877443975404674, 11.878393492394268, 12.791251700865875, 13.731405816359803, 14.622741089540039, 15.546429067400595, 8.680546925044013, 9.654133825642619, 10.59341901985546, 9.779028355838506, 8.932804693929313, 8.003892783708697, 8.712055125952599, 9.681196989305409, 10.676158817118724, 11.639322049230405, 12.582092817298197, 13.561083778227305, 13.596744586739895, 12.915594023377917, 11.945483223096103, 12.869401535666475, 13.749667744016342, 14.758555785582956, 15.63200953550804, 16.475483645996807, 9.582420256692803, 10.639687577283429, 9.706761392902656, 8.75615225721446, 7.872186709682682, 7.00541138723771, 7.710984868293204, 8.680476118221096, 9.678301173768979, 10.71271769638485, 11.691716947510402, 12.558175075648666, 13.5338112409986, 13.945860459258082, 13.006075331396644, 13.87235943442341, 14.730512020108673, 15.710256719144196, 16.58720513297028, 17.528375544163513, 10.51010589032698, 9.716189567827417, 8.714026943406623, 7.737038859318289, 6.824087053976451, 6.05626680891504, 6.7533123276040286, 7.779672782506975, 8.703990912540856, 9.733636998883041, 10.735129682456305, 11.555487697784523, 12.486408956912284, 13.512675120498178, 13.97829748645928, 14.868914871383067, 15.751482778143417, 16.761462769172848, 17.604955228708555, 18.590022407385202], [18.528393392571218, 17.654497942948097, 16.739413338222615, 15.784416788706315, 14.924498937969739, 14.51635017749036, 13.562067290882428, 12.544998741807197, 11.535963513306466, 10.685995598648361, 9.759878130727511, 8.716277466556535, 7.78629778133549, 6.77583622169349, 6.039652343383702, 5.0303293483503415, 5.905733604073636, 6.834937776945007, 7.853406148733415, 8.81134609419152, 17.456707635218194, 17.582243923920302, 16.625908612784443, 15.63591664154272, 14.602578297152137, 13.599752378680199, 12.587318942438408, 11.552811296672932, 10.607510074328706, 9.646944746549583, 8.714515165508455, 7.781697031695194, 6.8254197224287045, 5.778644915695717, 5.030632281186826, 4.0242259756776155, 4.869033793245284, 5.835112633715973, 6.8588470937698665, 7.790226234179648, 16.45092584800155, 16.72186222793618, 15.71821605106011, 14.68772499347033, 13.632790041931846, 12.651132915852054, 11.695058830369835, 10.792676781128687, 9.808449698060993, 8.810524207284466, 7.876155897833586, 6.816289417052095, 5.837859984802217, 4.793683444635288, 4.0055490022707, 3.0848273872424365, 3.897760168602601, 4.885360857664303, 5.844841477483812, 6.841989819862722, 15.487807677165524, 15.712450648270474, 14.758897073604006, 13.69929780722356, 12.645929492967927, 11.65275636075319, 10.695865247813513, 9.780349961383997, 8.801282714714853, 7.843101654583901, 6.856934296650178, 5.854142880176801, 4.858595726063391, 3.8119277662948314, 2.941734812350993, 2.0298036941796256, 2.9604890737262304, 3.951977138370843, 4.879349296261428, 5.824620127202273, 14.556371995241417, 14.701459323433806, 13.765764059160075, 12.846994202800396, 11.787840689346261, 10.799855853027625, 9.728928139433359, 8.831165881934378, 7.8747176518231035, 6.828607044549412, 5.927368467573368, 4.901339765891449, 3.8739421356459953, 2.8567704859910177, 1.8907069430400782, 1.0731699940930521, 2.036636576395763, 2.9401479368040153, 3.9105830241019945, 4.84132734355586, 13.57202324137004, 13.808040069732556, 12.826015767379987, 11.870122127067898, 10.848434498279207, 9.82354746517939, 8.776014730340346, 7.800142597587814, 6.83355477481937, 5.890827825916947, 4.928420911292375, 3.9935228776477283, 2.9249423178478136, 1.9123627140206818, 0.963270075072424, 0.0, 1.0038845082541092, 2.00430927678583, 2.947747985605571, 4.014571211189946, 12.616850960428229, 13.600680081402295, 13.626712031452701, 12.651986280853583, 11.662588960179995, 10.657371142781383, 9.732283191276684, 8.773144141486792, 7.778105891406328, 6.8172108303513905, 5.823937658672368, 4.890770895555744, 3.824856825151447, 2.8797753945499176, 1.9195404996660266, 0.9543259565639789, 1.9839665922140952, 2.929328081665514, 3.881673532295288, 4.83566686029686, 11.632296746409528, 12.644042095635188, 13.567572126178389, 13.539774830680056, 12.571148582533288, 11.587849352511668, 10.651758748575677, 9.675674759388567, 8.661912388528991, 7.72076742908917, 6.713880930892097, 5.737107252561113, 4.766499600327789, 3.806643870083085, 2.845629909838166, 1.9221536926294776, 2.9468806433074457, 3.8723456125077114, 4.816453306587638, 5.825205414715607, 10.653646012507844, 11.673362825644162, 12.637527948028875, 13.56080056394003, 13.53277924490378, 12.520448217259338, 11.502991814976435, 10.532746693920807, 9.545755753782537, 8.552703934719469, 7.5975753688518655, 6.662084516813358, 5.728064894415934, 4.763580765095421, 3.8715041728295407, 2.941834608751866, 3.8952854910907684, 4.839577140165018, 5.775144674084081, 6.8089631378276145, 9.661135275997854, 10.6103185200484, 11.624565665628184, 12.605718748186266, 13.607303117943637, 13.5246609990777, 12.47509885041438, 11.51953576912343, 10.45546513835237, 9.51339943481232, 8.530776985016514, 7.686283960808137, 6.73103077406766, 5.835125258266734, 4.86572541626613, 3.898778840119208, 4.949032085881385, 5.806457376919979, 6.815365894631301, 7.8005476525572375, 8.716998277637805, 9.743168332032342, 10.584878128296213, 11.655432442502017, 12.672012572058657, 13.606148521236593, 13.380694560202071, 12.412828807128111, 11.416320031755372, 10.50146656187443, 9.553682745187299, 8.693755612858336, 7.7467942761674955, 6.809215116443793, 5.869842751252268, 4.875527165985951, 5.898177249000536, 6.817384168079714, 7.807278137870861, 8.727807091284335, 7.760947508457177, 8.669303142121514, 9.657161625138722, 10.699258247108402, 11.704264806846417, 12.681905447540657, 13.68793605397587, 13.346996188604086, 12.38118671630703, 11.457924548084266, 10.49963281764116, 9.682566425590624, 8.74450140804994, 7.781102598106472, 6.8657410714621765, 5.86924651295596, 6.801161031212268, 7.7740662329602, 8.845692136182194, 9.687120313333377, 6.772828078999718, 7.743142945363376, 8.770139553387164, 9.718015797484178, 10.769683012149745, 11.713879898197515, 12.688074211163944, 13.647622805684682, 13.403646539682544, 12.442737258236368, 11.490191171232974, 10.618645322693602, 9.734528431053265, 8.745695008347978, 7.792478893442793, 6.936885988540779, 7.836468447541712, 8.760680205419316, 9.76023759617898, 10.692435270770641, 5.85773126619096, 6.918967113725031, 7.865137703340889, 8.862700528003067, 9.857523269386077, 10.852744148534965, 11.842567145504809, 12.853891148510643, 13.846284796279415, 13.418202007570564, 12.502881775053948, 11.579938266778896, 10.725556957795758, 9.77480309160408, 8.858556494303684, 7.940616758998171, 8.7893421862791, 9.745900877821313, 10.720957255828178, 11.72545203752446, 5.04163106493246, 6.1025144766111294, 7.143893720032418, 8.162677621798014, 9.159040241030997, 10.124895365188777, 11.07972861510177, 12.05308645726525, 13.092635835846426, 14.119996598255035, 13.446126789206023, 12.618325451973984, 11.702053870877869, 10.774852957823994, 9.860878703447598, 8.904373163175636, 9.853142098691569, 10.769743964557533, 11.690642661653145, 12.661555746463078, 5.866510909390041, 6.842501156332444, 7.851567705211856, 8.903406608139921, 9.863646214685918, 10.799498837292568, 11.56214875166893, 12.608927788526724, 13.576704992138453, 14.502408746026035, 14.493819110878505, 13.589173677217104, 12.644004962637135, 11.761722832941322, 10.802625681354147, 9.941339599499518, 10.86771373162765, 11.840150827245473, 12.661985718114176, 13.606769275700593, 6.859530308684361, 7.79192679403138, 8.742894120591455, 9.688848093104628, 9.147908571978663, 9.86789698170209, 10.613333041631485, 11.572517272848701, 12.54491116422879, 13.525328600272237, 14.502060295025718, 14.545116778780447, 13.575359008629182, 12.749019541909206, 11.776416538731274, 10.981731229285765, 11.836153023519575, 12.768195611470437, 13.659530884650675, 14.583218862511231, 7.81116407985388, 8.784750980452486, 9.724036174665327, 8.943035461529716, 8.096811799620525, 8.928527380036554, 9.675325201025023, 10.644467064377832, 11.639428892191148, 12.602592124302829, 13.54536289237062, 14.52435385329973, 14.510407320606616, 13.814566586704517, 12.844455786422703, 11.972739272557972, 12.794569066670043, 13.803457108236657, 14.668799330618675, 15.512273441107443, 8.746427362384017, 9.803694682974642, 8.870768498593867, 7.920159362905671, 7.036193815373894, 7.9300459835655674, 8.674254943365629, 9.64374619329352, 10.641571248841403, 11.675987771457274, 12.654987022582826, 13.521445150721092, 14.497081316071025, 14.844833022584682, 13.905047894723245, 12.975697171314907, 13.775413342762374, 14.755158041797896, 15.623994928080917, 16.565165339274152, 9.674112996018193, 8.880196673518629, 7.878034049097835, 6.901045965009501, 5.988094159667663, 6.980901405242897, 7.716582402676453, 8.7429428575794, 9.66726098761328, 10.696907073955465, 11.698399757528732, 12.518757772856947, 13.449679031984708, 14.475945195570603, 14.87727004978588, 13.972252608274564, 14.796384100797118, 15.806364091826548, 16.64174502381919, 17.62681220249584], [17.529410021076167, 16.702539402688117, 15.8648961918353, 14.909899642319, 15.849613819729694, 15.520234685744468, 14.565951799136537, 13.548883250061305, 12.539848021560575, 11.689880106902468, 10.76376263898162, 9.720161974810644, 8.790182289589598, 7.7797207299475994, 6.90975819974213, 5.900435204708769, 4.915492322244562, 5.844696495115933, 6.8631648669043415, 7.821104812362448, 16.457724263723144, 17.402744221821088, 16.872372802703005, 15.882380831461283, 15.606462805406244, 14.603636886934305, 13.591203450692515, 12.55669580492704, 11.611394582582815, 10.650829254803691, 9.718399673762564, 8.785581539949304, 7.829304230682814, 6.782529423949827, 5.906930107452245, 4.894331832036043, 3.8787925114162096, 4.844871351886899, 5.8686058119407924, 6.799984952350574, 15.451942476506499, 16.39767048233345, 16.722100559314217, 15.691609501724436, 14.636674550185953, 13.65501742410616, 12.698943338623941, 11.796561289382797, 10.812334206315104, 9.814408715538576, 8.880040406087694, 7.820173925306204, 6.841744493056327, 5.7975679528893975, 4.890790357330813, 3.954933243600864, 2.907518886773527, 3.8951195758352286, 4.854600195654738, 5.851748538033648, 14.483923168911414, 15.453006504062525, 15.762781581858112, 14.703182315477667, 13.649814001222033, 12.656640869007296, 11.69974975606762, 10.784234469638104, 9.805167222968961, 8.846986162838009, 7.860818804904286, 6.8580273884309095, 5.862480234317501, 4.815812274548941, 3.8269761674111056, 2.9009331714437616, 1.9702477918971564, 2.961735856541769, 3.889108014432354, 4.820735618948163, 13.552487486987307, 14.522740509137096, 14.769648567414182, 13.850878711054502, 12.791725197600368, 11.803740361281731, 10.732812647687465, 9.835050390188485, 8.878602160077211, 7.83249155280352, 6.931252975827476, 5.905224274145557, 4.877826643900104, 3.860654994245127, 2.8945914512941875, 2.0770545023471616, 1.0327520681416533, 1.936263428549906, 2.906698515847885, 3.8374428353017502, 12.56813873311593, 13.581979063479812, 13.829900275634094, 12.874006635322004, 11.852319006533314, 10.827431973433496, 9.779899238594453, 8.804027105841921, 7.837439283073478, 6.8947123341710554, 5.932305419546483, 4.997407385901837, 3.9288268261019224, 2.916247222274791, 1.9671545833265331, 1.0038845082541092, 0.0, 1.0004247685317205, 1.9438634773514614, 3.0106867029358355, 11.612966452174119, 12.596795573148185, 13.51406216114433, 13.65587078910769, 12.666473468434102, 11.66125565103549, 10.73616769953079, 9.777028649740899, 8.781990399660437, 7.821095338605499, 6.827822166926477, 5.894655403809853, 4.8287413334055564, 3.8836599028040273, 2.923425007920136, 1.9582104648180882, 0.9838766775573875, 1.9254435734114044, 2.8777890240411783, 3.8317823520427505, 10.628412238155418, 11.640157587381077, 12.56368761792428, 13.52612291395381, 13.575033090787398, 12.591733860765778, 11.655643256829787, 10.679559267642677, 9.665796896783101, 8.72465193734328, 7.717765439146207, 6.740991760815223, 5.770384108581899, 4.810528378337195, 3.8495144180922756, 2.926038200883587, 1.9467907286507382, 2.868461104253602, 3.812568798333529, 4.821320906461498, 9.649761504253734, 10.669478317390052, 11.633643439774767, 12.556916055685921, 13.59470024360798, 13.524332725513448, 12.506876323230545, 11.536631202174917, 10.549640262036647, 9.55658844297358, 8.601459877105976, 7.665969025067468, 6.731949402670044, 5.767465273349531, 4.836545543226691, 3.877333715999823, 2.9238828336609206, 3.835692631910909, 4.771260165829972, 5.805078629573505, 8.657250767743745, 9.606434011794292, 10.620681157374076, 11.601834239932158, 12.603418609689529, 13.588833042205914, 13.47898335866849, 12.52342027737754, 11.45934964660648, 10.51728394306643, 9.534661493270624, 8.690168469062247, 7.73491528232177, 6.815893904348467, 5.822458044262101, 4.834277947367165, 3.983628920792756, 4.80257286866587, 5.811481386377193, 6.796663144303129, 7.713113769383696, 8.739283823778232, 9.580993620042102, 10.651547934247906, 11.668128063804549, 12.602264012982484, 13.573148054310813, 13.416713315382221, 12.420204540009482, 11.50535107012854, 10.557567253441409, 9.69567067835149, 8.710478516675739, 7.7447142236917506, 6.805341858500225, 5.811026273233908, 4.932774083911907, 5.813499659825606, 6.803393629616752, 7.723922583030226, 6.757063000203067, 7.665418633867404, 8.653277116884611, 9.695373738854293, 10.700380298592309, 11.678020939286549, 12.68405154572176, 13.698394162697294, 13.38507122456114, 12.461809056338376, 11.50351732589527, 10.683320615839765, 9.708185648558183, 8.716601705354428, 7.801240178710133, 6.804745620203917, 5.926643884824952, 6.822107692700221, 7.877745653213632, 8.683235805079267, 5.768943570745609, 6.7392584371092665, 7.766255045133056, 8.71413128923007, 9.765798503895635, 10.709995389943405, 11.684189702909833, 12.643738297430572, 13.60012982341453, 13.446621766490479, 12.494075679487084, 11.619399512942744, 10.698212671561508, 9.681194115595934, 8.727978000690749, 7.8723850957887365, 6.9619513011543965, 7.808721665159337, 8.808279055919, 9.710389397167404, 4.85384675793685, 5.9150826054709205, 6.861253195086779, 7.858816019748956, 8.853638761131966, 9.848859640280855, 10.838682637250699, 11.850006640256533, 12.842400288025305, 13.875935144324629, 13.506766283308059, 12.580692457028038, 11.689241198304002, 10.710302198852036, 9.79405560155164, 8.87611586624613, 7.914825039891784, 8.793942337561335, 9.768998715568198, 10.75822343433514, 4.03774655667835, 5.098629968357019, 6.140009211778308, 7.158793113543904, 8.155155732776887, 9.121010856934667, 10.07584410684766, 11.04920194901114, 12.088751327592316, 13.116112090000925, 14.180293175110126, 13.619079642223124, 12.637552978125825, 11.71035206507195, 10.796377810695557, 9.839872270423594, 8.978624952304253, 9.817785424297554, 10.738684121393165, 11.694327143273757, 4.862626401135932, 5.838616648078334, 6.847683196957746, 7.899522099885811, 8.859761706431808, 9.889536106629912, 10.942500805628374, 11.98927984248617, 12.982138579311803, 13.927187871084747, 14.974827110612944, 14.52467278446506, 13.579504069885092, 12.69722194018928, 11.738124788602105, 10.876838706747478, 9.993196585240334, 10.888192286985495, 11.710027177854196, 12.63954067251127, 5.855645800430251, 6.78804228577727, 7.739009612337345, 8.684963584850518, 9.697277333896734, 10.681954177746585, 11.617217549885593, 12.57640178110281, 13.548795672482898, 14.529213108526346, 15.505944803279826, 15.480615886028403, 14.510858115877138, 13.684518649157164, 12.711915645979232, 11.90684611104572, 10.96163587713226, 11.816237071210459, 12.707572344390694, 13.615990259321908, 6.80727957159977, 7.780866472198376, 8.720151666411217, 7.952794179700643, 8.93534387506219, 9.79863323639498, 10.679209709279132, 11.648351572631942, 12.643313400445257, 13.606476632556937, 14.54924740062473, 15.528238361553838, 15.445906427854572, 14.750065693952475, 13.779954893670661, 12.897854154317926, 11.920051920282727, 12.87869789406775, 13.716840790358695, 14.54504483791812, 7.756186080554942, 8.813453401145567, 7.8805272167647935, 6.929918081076597, 7.874725890815558, 8.800151839923995, 9.678139451619737, 10.647630701547628, 11.645455757095512, 12.679872279711383, 13.658871530836935, 14.525329658975199, 15.500965824325133, 15.78033212983264, 14.840547001971203, 13.900812053074862, 12.900896196375058, 13.88064089541058, 14.672036387820937, 15.609577975216023, 8.683871714189118, 7.889955391689556, 6.8877927672687616, 5.910804683180427, 6.847411115672289, 7.851007261601325, 8.720466910930561, 9.746827365833507, 10.671145495867389, 11.700791582209574, 12.702284265782838, 13.522642281111056, 14.453563540238816, 15.479829703824711, 15.812769157033838, 14.897367490034519, 13.921866954409802, 14.931846945439233, 15.68978648355921, 16.671224838437713], [16.528985252544448, 15.702114634156395, 14.872589109271738, 15.681352642892277, 16.62106682030297, 16.508807188846166, 15.554524302238235, 14.537455753163004, 13.528420524662273, 12.678452610004168, 11.687108961558362, 10.643508297387386, 9.713528612166341, 8.703067052524341, 7.7597108318741075, 6.750387836840747, 5.76544495437654, 5.173032028773914, 5.973077578323849, 6.86838991375427, 15.457299495191425, 16.402319453289365, 15.912754761952513, 16.65383383203456, 16.606887573937968, 15.592209390036006, 14.579775953794215, 13.545268308028739, 12.599967085684513, 11.63940175790539, 10.706972176864262, 9.774154043051002, 8.764607735618815, 7.717832928885828, 6.756882739584223, 5.744284464168021, 4.7287451435481875, 4.115374046673503, 4.923576713439554, 5.809148037454484, 14.451517707974778, 15.397245713801729, 16.400891890677798, 16.69203427025616, 15.637099318717675, 14.655442192637883, 13.699368107155664, 12.785133792484494, 11.8009067094168, 10.802981218640273, 9.868612909189393, 8.808746428407902, 7.777047997992328, 6.732871457825399, 5.74074298946279, 4.804885875732841, 3.7574715189055046, 3.047856218505674, 3.884908705491995, 4.860911623137558, 13.483498400379693, 14.452581735530805, 15.480274741891863, 15.70360708400939, 14.650238769753756, 13.657065637539018, 12.700174524599342, 11.784659238169827, 10.805591991500682, 9.84741093136973, 8.861243573436008, 7.846599891532609, 6.797783739253503, 5.751115779484943, 4.676928799543083, 3.7508858035757386, 2.820200424029134, 2.010001686032013, 2.919416524269611, 3.8203108504164427, 12.552062718455586, 13.522315740605375, 14.448585430762929, 14.851303479586225, 13.79214996613209, 12.804165129813454, 11.733237416219188, 10.835475158720207, 9.879026928608933, 8.83291632133524, 7.931677744359197, 6.905649042677278, 5.878251412431824, 4.861079762776848, 3.895016219825908, 2.9362559291222956, 1.8827047002736306, 0.9358386600181856, 1.9062737473161644, 2.83701806677003, 11.56771396458421, 12.581554294948091, 13.508837138982841, 13.874431403853727, 12.852743775065036, 11.827856741965219, 10.780324007126175, 9.804451874373644, 8.8378640516052, 7.895137102702776, 6.932730188078204, 5.997832154433557, 4.929251594633643, 3.9166719908065115, 2.967579351858254, 2.00430927678583, 1.0004247685317205, 0.0, 0.943438708819741, 2.0102619344041153, 10.612541683642398, 11.596370804616466, 12.51363739261261, 13.488363143211728, 13.666898236965825, 12.661680419567212, 11.736592468062513, 10.777453418272621, 9.78241516819216, 8.82152010713722, 7.828246935458198, 6.895080172341574, 5.829166101937277, 4.8840846713357475, 3.9238497764518567, 2.958635233349809, 1.9685937276212844, 0.9250188048796839, 1.8773642555094578, 2.83135758351103, 9.627987469623697, 10.639732818849359, 11.56326284939256, 12.525698145422089, 13.494324393568856, 13.592158629297499, 12.656068025361508, 11.679984036174398, 10.666221665314822, 9.725076705875, 8.718190207677928, 7.741416529346944, 6.77080887711362, 5.810953146868916, 4.849939186623996, 3.903356977761472, 2.8703730395302363, 1.8680363357218814, 2.812144029801808, 3.8208961379297772, 8.649336735722013, 9.669053548858333, 10.633218671243046, 11.5564912871542, 12.594275475076259, 13.606606502720702, 13.497581605871124, 12.527336484815496, 11.540345544677226, 10.547293725614159, 9.592165159746555, 8.656674307708048, 7.7226546853106255, 6.74542382425131, 5.717226226156113, 4.7580143989292445, 3.8045635165903424, 2.835267863379188, 3.7708353972982516, 4.8046538610417855, 7.656825999212025, 8.606009243262571, 9.620256388842355, 10.601409471400437, 11.602993841157808, 12.588408273674194, 13.637157170503519, 13.514125560018119, 12.45005492924706, 11.507989225707009, 10.525366775911204, 9.680873751702826, 8.672697063707574, 7.696574587277889, 6.703138727191522, 5.714958630296587, 4.755081921366036, 3.8021481001341497, 4.811056617845472, 5.796238375771408, 6.7126890008519755, 7.738859055246511, 8.580568851510382, 9.651123165716186, 10.667703295272828, 11.601839244450764, 12.572723285779093, 13.540589038853053, 13.410909822650062, 12.49605635276912, 11.524827413029458, 10.57635136128091, 9.591159199605158, 8.625394906621171, 7.686022541429646, 6.69170695616333, 5.704227084485186, 4.813074891293885, 5.802968861085032, 6.723497814498505, 5.756638231671348, 6.664993865335683, 7.652852348352891, 8.694948970322573, 9.699955530060588, 10.677596170754828, 11.68362677719004, 12.697969394165575, 13.656871915345624, 13.452514338978956, 12.47077748548332, 11.564001298769185, 10.588866331487603, 9.59728238828385, 8.673659566705956, 7.63001140365454, 6.698096885398232, 5.8216829241685, 6.877320884681911, 7.682811036547546, 4.7685188022138885, 5.738833668577546, 6.765830276601335, 7.713706520698349, 8.765373735363916, 9.709570621411686, 10.683764934378114, 11.643313528898853, 12.599705054882811, 13.560614336328987, 13.435550325727775, 12.500080195872163, 11.578893354490928, 10.561874798525356, 9.600397388686572, 8.691423174966406, 7.733404301727676, 6.808296896627616, 7.807854287387279, 8.709964628635683, 3.8534219894051294, 4.9146578369392, 5.8608284265550585, 6.858391251217236, 7.853213992600245, 8.848434871749133, 9.838257868718976, 10.84958187172481, 11.841975519493582, 12.875510375792906, 13.805361389010006, 13.461373139957457, 12.569921881233421, 11.566710366625953, 10.596508271308032, 9.651940592663948, 8.686278040465062, 7.793517569029614, 8.768573947036476, 9.757798665803419, 3.0373217881466297, 4.098205199825299, 5.139584443246587, 6.1583683450121836, 7.154730964245167, 8.120586088402948, 9.07541933831594, 10.048777180479421, 11.088326559060597, 12.115687321469206, 13.179868406578407, 14.215929667800022, 13.493961145899743, 12.566760232845867, 11.572202537113375, 10.615696996841413, 9.75007795287753, 8.817360655765833, 9.738259352861443, 10.693902374742036, 3.8622016326042115, 4.8381918795466134, 5.847258428426025, 6.89909733135409, 7.859336937900087, 8.88911133809819, 9.942076037096651, 10.988855073954447, 11.98171381078008, 12.926763102553025, 13.974402342081222, 15.014087890914446, 14.435912237659009, 13.473046666607098, 12.513949515019924, 11.652663433165294, 10.764649585813611, 9.887767518453774, 10.709602409322473, 11.639115903979551, 4.855221031898531, 5.7876175172455495, 6.738584843805624, 7.684538816318797, 8.696852565365013, 9.681529409214864, 10.725855090651221, 11.685039321868437, 12.657433213248526, 13.637850649291973, 14.711923402277463, 15.755856365101337, 15.367266283651055, 14.460343375574983, 13.48774037239705, 12.678299111618998, 11.733088877705537, 10.815812302678738, 11.707147575858972, 12.615565490790189, 5.80685480306805, 6.780441703666657, 7.7197268978794975, 8.647331719898254, 9.63002738240257, 10.613842970466566, 11.580671657050495, 12.549813520403305, 13.565596886371178, 14.52982295513368, 15.472593723201472, 16.45158468413058, 16.30231459562849, 15.525890420370294, 14.55577962008848, 13.669307154891204, 12.691504920856005, 11.87827312553603, 12.716416021826973, 13.5446200693864, 6.7653491656588525, 7.822616486249478, 7.277000384727817, 7.779870713208575, 8.724678522947535, 9.650104472055972, 10.60148577419648, 11.570977024124371, 12.568802079672254, 13.603218602288125, 14.582217853413677, 15.508249580314006, 16.489538327426832, 16.55615685625046, 15.616371728389021, 14.67226505364814, 13.672349196948336, 12.881980999810512, 13.671611619289214, 14.609153206684304, 7.693034799293028, 6.999868103109064, 6.2161283009267425, 6.7607573153124045, 7.697363747804267, 8.700959893733302, 9.643813233507304, 10.670173688410252, 11.594491818444132, 12.624137904786316, 13.630402569059084, 14.511214784212754, 15.442136043340515, 16.46840220692641, 16.588593883451658, 15.668820490607796, 14.69331995498308, 13.933187049839164, 14.689361715027488, 15.670800069905992], [15.697759394681032, 15.031473329355688, 15.816027818091479, 16.62479135171202, 17.564505529122712, 17.452245897665907, 16.497963011057976, 15.480894461982745, 14.471859233482014, 13.62189131882391, 12.630547670378103, 11.586947006207128, 10.656967320986082, 9.646505761344082, 8.703149540693849, 7.693826545660488, 6.70888366319628, 6.0481072412925165, 5.029638869504108, 5.924951204934529, 14.626073637328009, 15.571093595425952, 16.527428906561813, 17.517420877803534, 17.55032628275771, 16.535648098855745, 15.523214662613956, 14.48870701684848, 13.543405794504254, 12.58284046672513, 11.650410885684003, 10.717592751870743, 9.708046444438557, 8.66127163770557, 7.700321448403964, 6.687723172987762, 5.672183852367928, 5.003872464673707, 3.980138004619813, 4.865709328634743, 13.620291850111363, 14.566019855938313, 15.569666032814382, 16.574340269516767, 16.58053802753742, 15.598880901457624, 14.642806815975405, 13.728572501304235, 12.744345418236541, 11.746419927460014, 10.812051618009134, 9.752185137227643, 8.72048670681207, 7.67631016664514, 6.684181698282531, 5.7483245845525826, 4.700910227725245, 3.941204505814116, 2.9414699966722537, 3.917472914317817, 12.652272542516277, 13.621355877667389, 14.626470041456185, 15.559721446309812, 15.593677478573497, 14.60050434635876, 13.643613233419083, 12.728097946989568, 11.749030700320423, 10.790849640189471, 9.80468228225575, 8.79003860035235, 7.741222448073244, 6.694554488304684, 5.620367508362824, 4.69432451239548, 3.763639132848875, 2.903349973340455, 1.9759778154498697, 2.8768721415967016, 11.72083686059217, 12.69108988274196, 13.594780730327251, 14.612186017469583, 14.735588674951831, 13.747603838633195, 12.676676125038929, 11.778913867539949, 10.822465637428675, 9.776355030154981, 8.875116453178938, 7.849087751497019, 6.8216901212515655, 5.804518471596588, 4.838454928645649, 3.8796946379420367, 2.8261434090933717, 1.8792773688379265, 0.9628350384964234, 1.8935793579502889, 10.736488106720794, 11.750328437084676, 12.655032438547163, 13.610926078859253, 13.796182483884778, 12.77129545078496, 11.723762715945917, 10.747890583193385, 9.781302760424941, 8.838575811522517, 7.876168896897945, 6.9412708632532985, 5.872690303453384, 4.860110699626253, 3.9110180606779945, 2.9477479856055706, 1.9438634773514614, 0.943438708819741, 0.0, 1.0668232255843744, 9.781315825778982, 10.742566104180788, 11.659832692176932, 12.63455844277605, 13.591291685333433, 13.605119128386953, 12.680031176882254, 11.720892127092363, 10.7258538770119, 9.76495881595696, 8.77168564427794, 7.838518881161315, 6.772604810757018, 5.827523380155489, 4.867288485271597, 3.9020739421695496, 2.9120324364410255, 1.868457513699425, 0.9889914267961033, 1.9429847547976755, 8.796761611760282, 9.78592811841368, 10.709458148956882, 11.671893444986411, 12.640519693133179, 13.623818923154799, 13.599506734181249, 12.623422744994139, 11.609660374134563, 10.668515414694742, 9.66162891649767, 8.684855238166685, 7.71424758593336, 6.754391855688656, 5.7933778954437365, 4.846795686581213, 3.8138117483499774, 2.8114750445416226, 1.9965319668374009, 2.961054639486279, 7.818110877858598, 8.815248848422655, 9.779413970807369, 10.702686586718523, 11.740470774640581, 12.752801802285024, 13.749422707497965, 13.470775193635237, 12.483784253496967, 11.490732434433902, 10.535603868566298, 9.600113016527791, 8.666093394130367, 7.688862533071051, 6.660664934975854, 5.701453107748986, 4.748002225410083, 3.7787065721989292, 2.9552233343338443, 3.9723668741214295, 6.803021298776347, 7.7522045428268935, 8.766451688406677, 9.74760477096476, 10.743152342714309, 11.728566775230695, 12.77731567206002, 13.72486221980871, 13.393493638066802, 12.451427934526752, 11.468805484730947, 10.62431246052257, 9.616135772527315, 8.64001329609763, 7.646577436011263, 6.658397339116328, 5.698520630185777, 4.745586808953891, 4.017738750539979, 4.965012517907994, 5.858884300416298, 6.879017556803013, 7.720727353066884, 8.791281667272688, 9.807861796829329, 10.741997746007264, 11.712881787335593, 12.680747540409554, 13.677256315782293, 13.439495061588863, 12.468266121849199, 11.519790070100651, 10.5345979084249, 9.568833615440912, 8.629461250249387, 7.635145664983071, 6.6476657933049275, 5.756513600113626, 5.014567449682015, 5.89227195663509, 4.902833531235669, 5.805152366892185, 6.793010849909392, 7.835107471879073, 8.84011403161709, 9.81775467231133, 10.823785278746541, 11.838127895722076, 12.797030416902125, 13.735391614622092, 13.41421619430306, 12.507440007588926, 11.532305040307344, 10.54072109710359, 9.617098275525695, 8.57345011247428, 7.641535594217973, 6.765121632988241, 6.088919473278894, 6.8515851786841315, 3.90867730377039, 4.8789921701340475, 5.905988778157836, 6.853865022254849, 7.905532236920416, 8.849729122968187, 9.823923435934615, 10.783472030455354, 11.739863556439312, 12.700772837885488, 13.653318924888882, 13.443518904691905, 12.52233206331067, 11.505313507345097, 10.543836097506311, 9.634861883786147, 8.676843010547417, 7.751735605447357, 7.137212982586572, 7.878738770772269, 2.965049160691775, 4.0262850082258455, 4.972455597841704, 5.970018422503881, 6.964841163886891, 7.960062043035778, 8.949885040005622, 9.961209043011456, 10.953602690780228, 11.987137547079552, 12.916988560296652, 13.943951275235392, 13.513360590053162, 12.510149075445694, 11.539946980127773, 10.595379301483689, 9.629716749284803, 8.736956277849355, 8.097932642235769, 8.926572807940005, 2.093883079326889, 3.1547664910055584, 4.196145734426847, 5.214929636192442, 6.211292255425426, 7.177147379583207, 8.1319806294962, 9.10533847165968, 10.144887850240856, 11.172248612649465, 12.236429697758666, 13.272490958980281, 14.267913563026827, 13.510198941665609, 12.515641245933116, 11.559135705661154, 10.693516661697272, 9.760799364585575, 9.067618048060735, 9.862676516878622, 2.9187629237844703, 3.8947531707268728, 4.903819719606285, 5.95565862253435, 6.915898229080347, 7.94567262927845, 8.998637328276912, 10.045416365134706, 11.03827510196034, 11.983324393733284, 13.03096363326148, 14.070649182094705, 15.015817896674672, 14.41648537542684, 13.457388223839665, 12.596102141985035, 11.708088294633352, 10.831206227273515, 10.038961104521766, 10.807890046116135, 3.91178232307879, 4.844178808425808, 5.795146134985883, 6.741100107499056, 7.753413856545272, 8.738090700395123, 9.78241638183148, 10.741600613048696, 11.713994504428785, 12.694411940472232, 13.768484693457722, 14.812417656281596, 15.782175426432861, 15.403782084394724, 14.431179081216792, 13.621737820438739, 12.676527586525278, 11.75925101149848, 11.036506271058265, 11.784339632926773, 4.863416094248309, 5.837002994846916, 6.776288189059756, 7.703893011078512, 8.686588673582827, 9.670404261646823, 10.637232948230752, 11.60637481158356, 12.622158177551434, 13.646110103388692, 14.588880871456483, 15.567871832385592, 16.516146039173055, 16.469329129190037, 15.49921832890822, 14.612745863710945, 13.634943629675746, 12.82171183435577, 12.045774717026266, 12.713394211522985, 5.821910456839111, 6.879177777429737, 7.822554112408593, 8.723309422028315, 9.668117231767276, 10.593543180875713, 11.54492448301622, 12.514415732944112, 13.512240788491996, 14.546657311107866, 15.525656562233419, 16.451688289133745, 17.432977036246573, 17.499595565070198, 16.55981043720876, 15.61570376246788, 14.615787905768077, 13.825419708630253, 13.000970314488507, 13.777927348820889, 6.749596090473287, 6.056429394289323, 7.066525151636795, 7.704196024132145, 8.640802456624007, 9.644398602553043, 10.587251942327045, 11.613612397229993, 12.537930527263873, 13.567576613606057, 14.573841277878826, 15.454653493032495, 16.385574752160256, 17.41184091574615, 17.532032592271396, 16.612259199427537, 15.636758663802821, 14.876625758658905, 14.01872041022678, 14.839574212042576], [14.743213258104543, 15.559417792527771, 16.597484835478557, 17.535355930369327, 18.536233509056668, 18.519069123250283, 17.56478623664235, 16.54771768756712, 15.538682459066386, 14.688714544408281, 13.697370895962479, 12.653770231791503, 11.723790546570457, 10.713328986928458, 9.769972766278224, 8.760649771244863, 7.775706888780655, 7.005222721908154, 5.986754350119746, 5.02881440466164, 13.67152750075152, 14.616547458849462, 15.572882769985323, 16.562874741227045, 17.51310820965597, 17.602471324440117, 16.590037888198328, 15.555530242432852, 14.610229020088626, 13.649663692309502, 12.717234111268375, 11.784415977455115, 10.774869670022929, 9.728094863289941, 8.767144673988337, 7.754546398572136, 6.739007077952302, 5.969224303308549, 4.945489843254655, 3.9695725283618546, 12.665745713534873, 13.611473719361824, 14.615119896237893, 15.619794132940275, 16.54331995443568, 16.665704127041998, 15.70963004155978, 14.795395726888607, 13.811168643820913, 12.813243153044386, 11.878874843593506, 10.819008362812015, 9.787309932396443, 8.743133392229513, 7.751004923866906, 6.815147810136956, 5.76773345330962, 4.9065563444489575, 3.9068218353070954, 3.0213361140449284, 11.697726405939788, 12.6668097410909, 13.671923904879694, 14.60517530973332, 15.481746800152672, 15.667327571943135, 14.710436459003459, 13.794921172573943, 12.815853925904799, 11.857672865773846, 10.871505507840123, 9.856861825936722, 8.808045673657617, 7.761377713889058, 6.687190733947198, 5.761147737979854, 4.830462358433249, 3.8687018119752965, 2.9413296540847114, 1.980735341323813, 10.76629072401568, 11.73654374616547, 12.64023459375076, 13.657639880893091, 14.520891270401073, 14.81442706421757, 13.743499350623305, 12.845737093124324, 11.88928886301305, 10.843178255739357, 9.941939678763312, 8.915910977081396, 7.888513346835941, 6.871341697180963, 5.9052781542300234, 4.946517863526411, 3.8929666346777463, 2.946100594422301, 1.9281868771312654, 0.9974425576774, 9.781941970144304, 10.795782300508186, 11.700486301970672, 12.656379942282761, 13.58148507933402, 13.838118676369335, 12.790585941530292, 11.81471380877776, 10.848125986009316, 9.905399037106893, 8.94299212248232, 8.008094088837673, 6.939513529037759, 5.926933925210627, 4.977841286262369, 4.014571211189945, 3.0106867029358355, 2.0102619344041153, 1.0668232255843744, 0.0, 8.826769689202493, 9.788019967604297, 10.705286555600441, 11.68001230619956, 12.636745548756942, 13.641963366155554, 13.74685440246663, 12.787715352676738, 11.792677102596276, 10.831782041541336, 9.837604657352639, 8.904437894236015, 7.838523823831717, 6.893442393230187, 5.933207498346296, 4.967992955244249, 3.938352319594132, 2.8947773968525317, 1.9424319462227575, 0.9884386182211855, 7.842215475183791, 8.83138198183719, 9.754912012380391, 10.71734730840992, 11.685973556556688, 12.669272786578308, 13.605363390514299, 13.689341758068837, 12.675579387209261, 11.73443442776944, 10.727547929572367, 9.750774251241383, 8.780166599008059, 7.820310868763355, 6.859296908518435, 5.87311556973432, 4.840131631503084, 3.837794927694729, 2.949972486264055, 2.0065085029097887, 6.863564741282107, 7.860702711846163, 8.824867834230878, 9.748140450142031, 10.78592463806409, 11.798255665708533, 12.784296836390478, 13.754541957446106, 13.510104136650074, 12.517052317587009, 11.561923751719405, 10.626432899680898, 9.692413277283475, 8.715182416224158, 7.686984818128961, 6.727772990902093, 5.77432210856319, 4.805026455352036, 3.9086638537604985, 3.0178207375449393, 5.848475162199856, 6.797658406250402, 7.811905551830186, 8.793058634388268, 9.778026471606822, 10.763440904123208, 11.812189800952533, 12.759736348701223, 13.672985338077808, 13.477747817679859, 12.495125367884054, 11.650632343675676, 10.642455655680422, 9.666333179250737, 8.67289731916437, 7.684717222269435, 6.724840513338883, 5.771906692106997, 4.971179269966633, 4.0104663813315025, 4.904338163839807, 5.924471420226523, 6.766181216490395, 7.836735530696199, 8.842735925721842, 9.776871874899777, 10.747755916228106, 11.715621669302067, 12.712130444674806, 13.72672372972444, 13.494586005002306, 12.546109953253758, 11.560917791578007, 10.59515349859402, 9.655781133402494, 8.661465548136178, 7.6739856764580345, 6.7828334832667325, 5.968007969108669, 4.937725820058599, 3.9482873946591788, 4.850606230315695, 5.838464713332903, 6.869981600771586, 7.874988160509602, 8.852628801203842, 9.858659407639054, 10.873002024614589, 11.831904545794638, 12.770265743514605, 13.678751407373209, 13.533759890742033, 12.558624923460451, 11.567040980256698, 10.643418158678804, 9.599769995627389, 8.66785547737108, 7.791441516141347, 6.823566620619011, 5.89703904210764, 2.9541311671939, 3.9244460335575577, 4.940862907050349, 5.888739151147362, 6.940406365812929, 7.884603251860699, 8.858797564827128, 9.818346159347866, 10.774737685331825, 11.735646966778, 12.688193053781395, 13.623663183637007, 13.548651946463776, 12.531633390498204, 11.57015598065942, 10.661181766939254, 9.703162893700524, 8.778055488600463, 7.856390308787439, 6.924192634195778, 1.9808857409601188, 3.0421215884941892, 3.9882921781100484, 4.985855002772226, 5.980677744155235, 6.975898623304124, 7.965721620273967, 8.9770456232798, 9.969439271048572, 11.002974127347898, 11.932825140564997, 12.959787855503738, 14.011579704746799, 13.536468958598801, 12.56626686328088, 11.621699184636796, 10.65603663243791, 9.76327616100246, 8.817109968436636, 7.972026671363515, 1.0270598537425144, 2.087943265421184, 3.1293225088424723, 4.148106410608069, 5.144469029841052, 6.1103241539988336, 7.065157403911825, 8.038515246075306, 9.078064624656482, 10.10542538706509, 11.16960647217429, 12.205667733395906, 13.201090337442452, 14.128291250496327, 13.541961129086223, 12.585455588814261, 11.719836544850379, 10.768838618996181, 9.786795374261603, 8.908130380302133, 2.0226261235115817, 2.998616370453984, 4.007682919333396, 5.059521822261461, 6.019761428807458, 7.049535829005561, 8.091638734768026, 9.022364952930925, 10.015223689756558, 10.960272981529503, 12.0079122210577, 13.047597769890924, 13.992766484470891, 15.024476932741113, 14.483708106992772, 13.622422025138142, 12.73440817778646, 11.825661760019308, 10.758138430722633, 9.853343909539646, 3.015645522805901, 3.94804200815292, 4.899009334712995, 5.844963307226168, 6.857277056272384, 7.841953900122235, 8.886279581558592, 9.845463812775808, 10.817857704155896, 11.798275140199344, 12.872347893184834, 13.916280856008708, 14.886038626159973, 15.817632734416861, 15.457498964369899, 14.648057703591846, 13.702847469678385, 12.753706544244272, 11.755683597259132, 10.829793496350284, 3.9672792939754196, 4.940866194574026, 5.880151388786866, 6.807756210805622, 7.790451873309937, 8.774267461373933, 9.741096147957862, 10.710238011310672, 11.726021377278546, 12.749973303115803, 13.692744071183595, 14.671735032112704, 15.620009238900167, 16.60564651357803, 16.525538212061328, 15.639065746864052, 14.661263512828853, 13.806361792127746, 12.745403064042701, 11.758848074946496, 4.925773656566223, 5.983040977156849, 6.926417312135703, 7.830632309429668, 8.775440119168628, 9.772748857844919, 10.738591431391217, 11.708082681319109, 12.705907736866992, 13.676577655961358, 14.65557690708691, 15.581608633987239, 16.60139130714318, 17.545207011811208, 17.586130320361868, 16.642023645620988, 15.642107788921184, 14.735464698261923, 13.700598661504943, 12.8233812122444, 5.853459290200399, 6.806827587033082, 7.816923344380554, 8.77101924971652, 9.707625682208382, 10.711221828137418, 11.65407516791142, 12.673342777743686, 13.604753752848248, 14.634399839190433, 15.640664503463201, 16.521476718616867, 17.452397977744628, 18.478664141330523, 18.558352475424503, 17.638579082580645, 16.663078546955926, 15.669541092394422, 14.718348757243216, 13.885028075466087], [5.916443568902048, 6.732648103325278, 7.770715146276064, 8.708586241166836, 9.778167046435355, 10.792276544440377, 11.746559431048308, 12.76362798012354, 13.642138554482095, 14.5945476365046, 15.637610584276532, 16.577329589369945, 17.50730927459099, 18.51777083423299, 18.372252515516507, 17.362929520483146, 16.37798663801894, 15.785573712416314, 14.81095469528309, 13.855584093864131, 4.844757811549026, 5.789777769646969, 6.7461130807828305, 7.736105052024553, 8.769443396415134, 9.818447400870328, 10.773276290726592, 11.76838389316011, 12.713685115504335, 13.674250443283459, 14.606680024324586, 15.539498158137846, 16.59223683697585, 17.63585019590808, 17.369424423226622, 16.35682614781042, 15.341286827190586, 14.727915730315903, 13.761453830398795, 12.796342217564346, 3.83897602433238, 4.784704030159331, 5.7883502070354, 6.818841264625181, 7.873776216163664, 8.820429590891294, 9.778137731288428, 10.753566222514781, 11.737793305582475, 12.696147656700374, 13.630515966151254, 14.61950244481567, 15.656625749262592, 16.65088872484765, 16.35328467310519, 15.417427559375241, 14.370013202547904, 13.660397902148073, 12.722785822451236, 11.848105803247421, 2.8709567167372954, 3.8400400518884066, 4.877158632365643, 5.821615768825544, 6.828879903577692, 7.82205303579243, 8.778944148732107, 9.721762247134002, 10.760054933729391, 11.718235993860343, 12.666203704213032, 13.657355907940376, 14.706172060219481, 15.669133046507195, 15.289470483185482, 14.363427487218138, 13.432742107671533, 12.622543369674412, 11.757293641228852, 10.807505030526306, 1.9395210348131884, 2.909774056962978, 3.8454693212367097, 4.874080339985315, 5.868024373826093, 6.92423851070951, 7.843009908900267, 8.772578167684383, 9.783244645025242, 10.71306262286312, 11.736637875136221, 12.704552793655024, 13.690168730097971, 14.713975766203381, 14.507557903468307, 13.548797612764695, 12.49524638391603, 11.548380343660584, 10.744150864275406, 9.824212246879894, 0.9551722809418117, 1.9690126113056932, 2.9510369136582613, 3.9069305539703505, 4.92861818275904, 5.953505215858858, 6.890096499807256, 7.865968632559788, 8.832556455328232, 9.775283404230656, 10.737690318855229, 11.672588352499876, 12.74116891229979, 13.75374851612692, 13.580121035500651, 12.616850960428227, 11.612966452174119, 10.612541683642398, 9.781315825778982, 8.826769689202493, 0.0, 1.0396342079177863, 2.039399198694902, 3.0141249492940196, 4.003522269967607, 5.00874008736622, 5.933828038870918, 6.900686639736701, 7.895724889817164, 8.962599353931466, 9.994833766464712, 10.928000529581336, 11.993914599985633, 12.938996030587163, 12.611195856203647, 11.687529008001151, 10.686575629577897, 9.687522878762714, 8.79232439898288, 7.838331070981308, 0.9845542140187009, 1.9962721936848933, 2.9791389957319048, 3.9415742917614347, 4.910200539908202, 5.893499769929823, 6.829590373865815, 7.805674363052925, 8.8194367339125, 9.760581693352322, 10.767468191549394, 11.744241869880378, 12.714849522113703, 12.644366676147666, 11.685106446031508, 10.719701271935653, 9.723661578484545, 8.744505347920516, 7.80145878289753, 6.820261186292704, 1.963204947920385, 2.966951463675919, 3.9091831738814182, 4.879833576676146, 5.917617764598203, 6.826098634677492, 7.8407284725482045, 8.810973593603833, 9.797964533742103, 10.700604339529837, 11.655732905397441, 12.591223757435948, 12.644777341920289, 11.68742978113533, 10.659232183040134, 9.700020355813265, 8.746569473474363, 7.7772738202632095, 6.842767415401087, 5.808948951657554, 3.032169645440575, 3.981352889491122, 4.922145456282109, 5.8349153924299095, 6.88359848938344, 7.869012921899825, 8.812835507986149, 9.815450685546413, 10.781261388126648, 11.723327091666699, 12.58893452156209, 12.638018781823302, 11.641811462268564, 10.665688985838878, 9.783798167227006, 8.80317152166921, 7.763327404740134, 6.810393583508248, 5.801485065796926, 4.81630330787099, 3.9763066438006236, 4.993923759150005, 5.994939964272074, 6.8075882986432035, 7.81888903526842, 8.753024984446355, 9.723909025774685, 10.691774778848645, 11.688283554221384, 12.71139421872881, 12.57902318152165, 11.630547129773102, 10.645354968097351, 9.679590675113364, 8.761976012726407, 7.826423195802466, 6.869874047833578, 5.920504218994247, 4.9306102492031005, 3.889043869143893, 4.932357412981252, 5.898002390199433, 6.88586087321664, 7.855751149152632, 8.78663680048066, 9.680523436851594, 10.719934157750808, 11.66484933591506, 12.630658808212116, 12.7561024298809, 11.721162660950828, 10.75581487809013, 9.780679910808548, 8.707703193450685, 7.766077692516499, 6.832703848832457, 5.900789330576149, 4.927884128828216, 3.856258225606222, 2.9297306470948516, 5.926513640446531, 6.82416258695757, 7.851159194981358, 8.799035439078372, 9.77978158384768, 10.687571956736058, 11.661766269702486, 12.621314864223224, 12.682392934590471, 11.721483653144295, 10.7689375661409, 9.83346743628529, 8.889200298871181, 7.865079875139632, 6.839339870535883, 5.890304145428678, 4.932285272189947, 3.990228770032497, 2.990671379272834, 2.058473704681173, 6.978715635476891, 7.880821944300931, 8.803729923921658, 9.77446195656121, 10.769284697944219, 11.62600863486911, 12.599917164598727, 13.093704567339419, 12.101310919570647, 11.067776063271321, 10.137925050054221, 9.110962335115481, 8.05917048587242, 6.990828487420841, 6.02062639210292, 5.076058713458835, 4.110396161259949, 3.0951438021372892, 2.071469383969254, 1.0669746022729718, 7.932541522694495, 8.935713945399954, 9.815831216254635, 10.734252602647, 11.730615221879983, 12.641716665832512, 13.569307745566674, 14.032803403208598, 12.997151087544303, 11.969790325135694, 10.905609240026493, 9.869547978804878, 8.87412537475833, 7.946924461704455, 6.889480541439044, 5.932975001167081, 4.924616338224415, 3.960354288607204, 2.9783110438726252, 1.9195995038632794, 8.978704652086833, 9.954694899029235, 10.7601479954509, 11.661786791856834, 12.62202639840283, 13.651800798600934, 14.595789076422875, 14.786477998057563, 13.79361926123193, 12.848569969458985, 11.800930729930789, 10.761245181097564, 9.816076466517597, 8.790324670932767, 7.8312275193455925, 6.969941437490964, 5.939187971160495, 4.96484038885824, 3.8973170595615647, 2.8648130331007935, 10.022515892011473, 10.90412053672817, 11.729474233710329, 12.664435358397162, 13.660561780703974, 14.583402654191412, 15.54460478646032, 15.749790301541704, 14.777396410161616, 13.796978974118169, 12.722906221132678, 11.678973258308805, 10.70921548815754, 9.777621379900651, 8.80501837672272, 7.852837496965881, 6.9076272630524205, 5.876372242654866, 4.875184758113494, 3.81174627801369, 10.974149663180992, 11.9312757834331, 12.800903605744221, 13.719427452532669, 14.702123115036985, 15.522772255856948, 16.482612627066782, 16.554035027724467, 15.538251661756595, 14.514299735919337, 13.571528967851545, 12.592538006922437, 11.644263800134974, 10.843168424695962, 9.87135631224701, 8.83730548557699, 7.797202615357765, 6.788314573791151, 5.727355845706107, 4.740800856609901, 11.94410150172238, 12.979903694279413, 13.847169529093058, 14.742303551156715, 15.687111360895676, 16.521253652327935, 17.48368288472618, 17.473145666928648, 16.475320611380763, 15.440904088764892, 14.535857348053185, 13.609825621152856, 12.590042947996913, 11.646227243328887, 10.70644211546745, 9.70685664953715, 8.697162178960852, 7.717417479925329, 6.682551443168348, 5.805333993907805, 12.871787135356557, 13.825155432189241, 14.835251189536715, 15.761416949052885, 16.698023381544747, 17.470398230650606, 18.44004375286015, 18.438405763353227, 17.488575902150902, 16.512601369145496, 15.572697678388653, 14.568366491210991, 13.63744523208323, 12.630462922538308, 11.678664270530085, 10.682055886707763, 9.668439023245234, 8.651493874057827, 7.700301538906623, 6.866980857129493], [6.956077776819835, 6.084375043742481, 7.0828093053729955, 7.914575413941524, 8.863376022349547, 9.772285954308234, 10.726568840916165, 11.743637389991397, 12.61908506621781, 13.571494148240316, 14.614557096012247, 15.55427610110566, 16.484255786326706, 17.494717345968706, 17.409971244290492, 16.654112144642763, 15.755053261769445, 14.97042852143903, 14.191375333452427, 14.763434520826955, 5.884392019466812, 5.141504710064172, 6.04264365269222, 6.94209422479924, 7.840250722948851, 8.798456810738186, 9.75328570059445, 10.745330404895824, 11.69063162724005, 12.651196955019174, 13.5836265360603, 14.516444669873561, 15.569183348711565, 16.596215987990295, 17.629455149115056, 17.340655268784484, 16.325115948164655, 15.71174485128997, 14.722704108800597, 13.757592495966149, 4.878610232250166, 4.136430970576534, 4.976327727923567, 5.9142725681169495, 6.870462467728561, 7.800439000759152, 8.758147141156286, 9.730512734250496, 10.71473981731819, 11.656513448782588, 12.590881758233468, 13.579868236897882, 14.616991541344804, 15.611254516929865, 16.604371870198932, 16.401256680349306, 15.35384232352197, 14.64422702312214, 13.684036100853039, 12.809356081649224, 3.9105909246550814, 3.0736296257435303, 3.9664023400563675, 4.899653744909995, 5.80888931344555, 6.802062445660288, 7.758953558599964, 8.682128039216217, 9.720420725811605, 10.678601785942558, 11.626569496295245, 12.617721700022589, 13.666537852301694, 14.629498838589408, 15.64167168443596, 15.347256608192204, 14.4165712286456, 13.606372490648479, 12.718543919630655, 11.768755308928109, 2.9791552427309744, 2.0626383009068627, 2.934713028927434, 3.9521183160697655, 4.848033783693951, 5.903012019555482, 6.803375700982481, 7.7329439597665965, 8.743610437107455, 9.673428414945334, 10.697003667218434, 11.664918585737237, 12.650534522180184, 13.674341558285594, 14.590643815125045, 14.532626733738761, 13.479075504890096, 12.53220946463465, 11.705401142677209, 10.785462525281696, 1.994806488859598, 1.0591907388043873, 1.9949647371473467, 2.950858377459436, 3.908627592626898, 4.913935043167268, 5.850462291889469, 6.826334424642002, 7.792922247410446, 8.735649196312869, 9.698056110937442, 10.632954144582088, 11.701534704382002, 12.714114308209133, 13.663206947157391, 13.600680081402295, 12.596795573148185, 11.596370804616464, 10.742566104180785, 9.788019967604296, 1.0396342079177863, 0.0, 0.9997649907771157, 1.9744907413762334, 2.9638880620498202, 3.969105879448433, 4.894193830953132, 5.861052431818915, 6.856090681899378, 7.922965146013681, 8.955199558546926, 9.88836632166355, 10.954280392067847, 11.899361822669377, 12.859596717553268, 12.692454394755272, 11.691501016332017, 10.67135199973678, 9.753574677384682, 8.79958134938311, 1.9908407286255037, 0.956637985767107, 1.9395047878141185, 2.901940083843648, 3.8705663319904158, 4.853865562012037, 5.789956165948029, 6.766040155135139, 7.779802525994715, 8.720947485434536, 9.727833983631609, 10.704607661962593, 11.675215314195917, 12.63507104444062, 12.690031832785628, 11.724626658689774, 10.728586965238666, 9.728334468894582, 8.784226774814655, 7.781511464694507, 2.9694914625271878, 1.9273172557581328, 2.8695489659636317, 3.840199368758359, 4.877983556680417, 5.786464426759705, 6.801094264630418, 7.771339385686046, 8.758330325824316, 9.660970131612052, 10.616098697479655, 11.551589549518162, 12.485609171915586, 12.69235516788945, 11.664157569794254, 10.704945742567386, 9.751494860228483, 8.78219920701733, 7.825535407318212, 6.791716943574679, 3.9395448054044406, 2.9903615613538936, 3.8825112483643234, 4.795281184512122, 5.843964281465652, 6.829378713982037, 7.773201300068363, 8.775816477628625, 9.74162718020886, 10.683692883748911, 11.549300313644304, 12.57578899351294, 12.648097976875368, 11.671975500445683, 10.790084681833811, 9.809458036276013, 8.769613919346938, 7.816680098115051, 6.807771580403728, 5.822589822477792, 4.883681803764489, 4.002932431012776, 4.955305756354289, 5.767954090725416, 6.779254827350632, 7.713390776528568, 8.684274817856897, 9.652140570930857, 10.648649346303596, 11.671760010811022, 12.572206073815089, 12.636833644379907, 11.651641482704155, 10.685877189720168, 9.768262527333212, 8.832709710409269, 7.876160562440381, 6.92679073360105, 5.936896763809903, 4.895330383750696, 5.839732572945117, 5.076797620923604, 5.8830222595117805, 6.816116941234845, 7.747002592562872, 8.640889228933807, 9.680299949833021, 10.625215127997272, 11.591024600294329, 12.612256875042307, 12.727449175557634, 11.762101392696936, 10.786966425415354, 9.71398970805749, 8.772364207123303, 7.83899036343926, 6.907075845182952, 5.934170643435019, 4.862544740213025, 3.9360171617016544, 6.833888800410396, 6.002957817681741, 6.870449831373428, 7.797359390859068, 8.740147375929892, 9.647937748818268, 10.622132061784697, 11.581680656305435, 12.538072182289394, 12.7277701677511, 11.775224080747705, 10.839753950892094, 9.895486813477985, 8.871366389746436, 7.845626385142687, 6.896590660035482, 5.938571786796751, 4.9965152846393, 3.9969578938796366, 3.064760219287976, 7.886090795440755, 7.059617175025102, 7.8230205603137275, 8.772785908341906, 9.763251904385239, 10.586374426951322, 11.560282956680938, 12.571606959686772, 13.140945127488429, 12.107410271189105, 11.177559257972005, 10.150596543033265, 9.098804693790203, 8.030462695338626, 7.0602606000207055, 6.1156929213766205, 5.150030369177735, 4.134778010055075, 3.11110359188704, 2.106608810190758, 8.83991668265836, 8.114509176124125, 8.835121852646704, 9.732576554427697, 10.72893917366068, 11.602082457914722, 12.529673537648884, 13.503031379812365, 14.036785295462089, 13.00942453305348, 11.945243447944279, 10.909182186722663, 9.913759582676116, 8.98655866962224, 7.92911474935683, 6.972609209084868, 5.9642505461422015, 4.99998849652499, 4.017945251790412, 2.9592337117810654, 9.8860798120507, 9.16965474617654, 9.77943863184297, 10.66011074363753, 11.620350350183527, 12.650124750381629, 13.556154868505086, 14.486881086667983, 14.833253469149716, 13.888204177376771, 12.840564937848574, 11.80087938901535, 10.855710674435382, 9.829958878850553, 8.870861727263378, 8.00957564540875, 6.978822179078281, 6.004474596776026, 4.93695126747935, 3.9044472410185795, 10.92989105197534, 10.119080383875476, 10.748764870102399, 11.662759310177858, 12.65888573248467, 13.581726605972106, 14.504970578542531, 15.464154809759748, 15.817030618079402, 14.836613182035954, 13.762540429050464, 12.71860746622659, 11.748849696075325, 10.817255587818437, 9.844652584640505, 8.892471704883667, 7.947261470970207, 6.9160064505726515, 5.914818966031279, 4.851380485931476, 11.881524823144858, 11.146235630580405, 11.82019424213629, 12.717751404313365, 13.70044706681768, 14.521096207637642, 15.442978419148993, 16.412120282501803, 16.577885869674382, 15.553933943837123, 14.611163175769331, 13.632172214840223, 12.68389800805276, 11.882802632613748, 10.910990520164795, 9.876939693494776, 8.83683682327555, 7.827948781708937, 6.766990053623893, 5.780435064527687, 12.851476661686247, 12.194863541426718, 12.866460165485128, 13.74062750293741, 14.685435312676372, 15.519577604108628, 16.44404867680839, 17.41353992673628, 17.51495481929855, 16.480538296682678, 15.530598430532764, 14.604566703632436, 13.61166571205902, 12.667850007390994, 11.728064879529557, 10.746490857454935, 9.736796386878638, 8.757051687843115, 7.722185651086134, 6.844968201825591, 13.779162295320424, 13.164584808667213, 13.927332249286202, 14.759740900833581, 15.696347333325443, 16.468722182431296, 17.401721217497563, 17.482862084333973, 16.505259622162406, 15.590162971393454, 14.583898307120686, 13.60187932576829, 12.710502111136988, 11.707641376475145, 10.755842724466921, 9.815622352044722, 8.90260810185072, 8.02221136480557, 7.097127962871389, 7.906615065047278], [7.817818858662698, 6.892380045259668, 6.083044314595879, 6.914810423164409, 7.8636110315724315, 8.77252096353112, 9.726803850139051, 10.743872399214283, 11.619320075440696, 12.571729157463201, 13.614792105235132, 14.554511110328546, 15.484490795549592, 16.49495235519159, 16.420840999696424, 15.664981900048696, 14.765923017175377, 13.981298276844962, 14.782896901645355, 15.558283844040954, 6.746133101309676, 5.949509711581359, 5.042878661915104, 5.942329234022125, 6.840485732171736, 7.798691819961071, 8.753520709817336, 9.74556541411871, 10.690866636462935, 11.65143196424206, 12.583861545283186, 13.516679679096447, 14.56941835793445, 15.596450997213177, 16.629690158337944, 16.671085272721424, 15.802622828003729, 15.038956258945372, 15.639970696796743, 14.602527113104614, 5.74035131409303, 4.9444359720937205, 3.9765627371464514, 4.914507577339834, 5.870697476951445, 6.800674009982036, 7.758382150379171, 8.730747743473382, 9.714974826541075, 10.656748458005472, 11.591116767456352, 12.580103246120768, 13.61722655056769, 14.611489526152749, 15.604606879421818, 16.584262237931505, 16.271108911518116, 15.561493611118287, 14.601302688849184, 13.70314362630193, 4.772332006497946, 3.881634627260717, 2.9666373492792517, 3.8998887541328795, 4.809124322668435, 5.802297454883172, 6.759188567822848, 7.682363048439101, 8.720655735034489, 9.678836795165441, 10.62680450551813, 11.617956709245474, 12.66677286152458, 13.629733847812293, 14.641906693658846, 15.529238544868692, 15.333837816641747, 14.523639078644626, 13.6358105076268, 12.686021896924254, 3.840896324573839, 2.8706433024240496, 1.9349480381503181, 2.95235332529265, 3.848268792916835, 4.903247028778367, 5.8036107102053665, 6.733178968989482, 7.74384544633034, 8.673663424168218, 9.69723867644132, 10.665153594960122, 11.65076953140307, 12.67457656750848, 13.590878824347932, 14.572604844782118, 14.396342092886243, 13.449476052630798, 12.622667730673355, 11.702729113277842, 2.99106437908668, 1.9772240487227988, 0.9951997463702309, 1.9510933866823201, 2.9088626018497816, 3.914170052390153, 4.850697301112355, 5.826569433864887, 6.793157256633331, 7.735884205535754, 8.698291120160327, 9.633189153804974, 10.701769713604888, 11.714349317432019, 12.663441956380277, 13.626712031452701, 13.514062161144333, 12.513637392612612, 11.65983269217693, 10.705286555600441, 2.039399198694902, 0.9997649907771157, 0.0, 0.9747257505991177, 1.9641230712727045, 2.9693408886713177, 3.8944288401760168, 4.861287441041799, 5.8563256911222625, 6.9232001552365645, 7.955434567769809, 8.888601330886432, 9.95451540129073, 10.899596831892259, 11.85983172677615, 12.825046269878198, 12.608767604328166, 11.588618587732928, 10.670841265380828, 9.716847937379256, 2.9674440881254585, 1.9332413452670616, 0.9503745432200501, 1.9128098392495798, 2.8814360873963474, 3.8647353174179684, 4.80082592135396, 5.77690991054107, 6.790672281400646, 7.731817240840467, 8.73870373903754, 9.715477417368524, 10.686085069601848, 11.645940799846551, 12.60695476009147, 12.641893246685923, 11.645853553234815, 10.64560105689073, 9.701493362810803, 8.698778052690653, 3.9311560716473446, 2.8584426467864374, 1.8804187213695633, 2.8510691241642907, 3.888853312086349, 4.7973341821656375, 5.811964020036349, 6.782209141091977, 7.769200081230247, 8.671839887017983, 9.626968452885587, 10.562459304924094, 11.496478927321517, 12.473709788380834, 12.581424157790403, 11.622212330563535, 10.668761448224632, 9.699465795013477, 8.742801995314359, 7.708983531570825, 4.856811393400585, 3.907628149350039, 2.893381003770255, 3.806150939918054, 4.854834036871585, 5.84024846938797, 6.7840710554742945, 7.786686233034556, 8.752496935614792, 9.694562639154842, 10.560170069050235, 11.586658748918872, 12.499444806973242, 12.648578859945637, 11.759302742291103, 10.771122645396169, 9.731278528467094, 8.778344707235208, 7.769436189523885, 6.784254431597949, 5.800948391760635, 4.920199019008922, 3.96617551176022, 4.778823846131347, 5.790124582756565, 6.724260531934501, 7.695144573262829, 8.663010326336789, 9.659519101709527, 10.682629766216953, 11.58307582922102, 12.531551880969568, 12.62824484220411, 11.662480549220122, 10.744865886833166, 9.794374319529425, 8.837825171560539, 7.888455342721207, 6.898561372930061, 5.8569949928708525, 6.7569991609412625, 5.881750497934919, 4.893892014917712, 5.826986696640776, 6.757872347968805, 7.6517589843397396, 8.691169705238952, 9.636084883403203, 10.60189435570026, 11.623126630448239, 12.529025901674881, 12.73870475219689, 11.763569784915308, 10.690593067557444, 9.748967566623257, 8.800654972559416, 7.868740454303108, 6.895835252555176, 5.824209349333182, 4.897681770821811, 7.751155388406541, 6.8079106946930565, 5.881319586779359, 6.808229146264999, 7.751017131335825, 8.658807504224203, 9.633001817190632, 10.59255041171137, 11.548941937695329, 12.509851219141504, 12.75182744024766, 11.816357310392048, 10.87209017297794, 9.84796974924639, 8.822229744642641, 7.873194019535436, 6.915175146296705, 5.973118644139254, 4.973561253379591, 4.04136357878793, 8.803357383436902, 7.780060905335517, 6.833890315719659, 7.783655663747837, 8.774121659791172, 9.597244182357256, 10.571152712086873, 11.582476715092707, 12.506055126871733, 13.107175261966221, 12.177324248749121, 11.150361533810381, 10.09856968456732, 9.030227686115742, 8.06002559079782, 7.115457912153737, 6.149795359954851, 5.134543000832191, 4.110868582664156, 3.106373800967874, 9.757183270654506, 8.83495290643454, 7.8459916080526355, 8.743446309833628, 9.73980892906661, 10.612952213320657, 11.540543293054819, 12.5139011352183, 13.443436604401096, 14.005682423280565, 12.941501338171363, 11.905440076949748, 10.910017472903201, 9.982816559849326, 8.925372639583914, 7.968867099311951, 6.960508436369285, 5.996246386752073, 5.014203142017494, 3.9554916020081476, 10.775365183070715, 9.799374936128313, 8.790308387248901, 9.670980499043461, 10.631220105589458, 11.66099450578756, 12.56702462391102, 13.497750842073918, 14.386995577377276, 14.884462067603856, 13.83682282807566, 12.797137279242435, 11.851968564662467, 10.826216769077638, 9.867119617490463, 9.005833535635833, 7.971584654467176, 6.944291927129997, 5.876768597833322, 4.844264571372551, 11.724740375189338, 10.710601952068403, 9.75963462550833, 10.673629065583789, 11.669755487890601, 12.592596361378037, 13.515840333948466, 14.475024565165683, 15.418789405286939, 15.832871072263039, 14.758798319277549, 13.714865356453675, 12.74510758630241, 11.813513478045522, 10.84091047486759, 9.779641102972187, 8.834430869058727, 7.777747532415516, 6.776560047874144, 5.7131215677743405, 12.676374146358857, 11.737757198773332, 10.831063997542222, 11.728621159719296, 12.711316822223612, 13.531965963043573, 14.453848174554928, 15.422990037907738, 16.43877340387561, 16.436437043726755, 15.527328901647424, 14.552606815846381, 13.604332609058918, 12.739972525342482, 11.772731602007656, 10.738680775337638, 9.698577905118414, 8.6896898635518, 7.628731135466756, 6.642176146370551, 13.646325984900246, 12.786385109619646, 11.877329920891059, 12.751497258343342, 13.696305068082303, 14.53044735951456, 15.454918432214322, 16.424409682142212, 16.518749922155433, 15.5098326908812, 14.530833439755648, 13.60480171285532, 12.611900721281906, 11.66808501661388, 10.728299888752442, 9.812412798227262, 8.92381386910835, 8.073652424057105, 8.583926732928997, 7.706709283668454, 14.574011618534422, 13.75610637686014, 12.938202004692133, 13.770610656239512, 14.707217088731374, 15.47959193783723, 16.412590972903498, 16.48309709355686, 15.505494631385291, 14.59039798061634, 13.584133316343571, 12.602114334991176, 11.710737120359873, 10.70787638569803, 9.756077733689807, 8.815857361267605, 7.902843111073606, 7.022446374028454, 7.905132964388576, 8.768356146890142], [8.767517905920883, 7.842079092517851, 6.907718739314713, 5.952722189798413, 6.888885280973314, 7.7977952129320025, 8.752078099539935, 9.769146648615166, 10.644594324841577, 11.597003406864083, 12.640066354636014, 13.579785359729428, 14.509765044950473, 15.520226604592473, 15.56263240853551, 14.845442462981959, 13.94638358010864, 14.87558775298001, 15.757622652244473, 16.53300959464007, 7.69583214856786, 6.899208758839542, 5.970232971897851, 4.980241000656129, 5.8657599815726185, 6.823966069361954, 7.778794959218217, 8.770839663519592, 9.716140885863817, 10.676706213642941, 11.609135794684068, 12.541953928497328, 13.594692607335332, 14.621725246614057, 15.654964407738824, 15.851545835654685, 14.983083390936992, 15.93324573508042, 16.61469644739586, 15.577252863703732, 6.690050361351213, 5.8941350193519035, 4.926261784404634, 3.9524193439738378, 4.895971726352328, 5.825948259382919, 6.783656399780053, 7.756021992874263, 8.740249075941957, 9.682022707406354, 10.616391016857236, 11.605377495521648, 12.64250079996857, 13.636763775553629, 14.629881128822698, 15.609536487332383, 15.954357015579674, 16.536219361717407, 15.576028439448303, 14.677869376901048, 5.722031053756129, 4.8313336745189, 3.9163363965374343, 2.937800520766883, 3.8343985720693174, 4.827571704284055, 5.784462817223731, 6.707637297839983, 7.745929984435372, 8.704111044566323, 9.652078754919012, 10.643230958646354, 11.69204711092546, 12.655008097213173, 13.667180943059726, 14.554512794269572, 15.485198173816176, 15.498364829243744, 14.610536258225919, 13.660747647523372, 4.790595371832022, 3.8203423496822326, 2.884647085408501, 1.9902650919266542, 2.8735430423177175, 3.928521278179249, 4.828884959606248, 5.758453218390364, 6.769119695731222, 7.698937673569101, 8.722512925842201, 9.690427844361002, 10.67604378080395, 11.69985081690936, 12.616153073748812, 13.597879094182998, 14.651430323031663, 14.424201803229916, 13.597393481272473, 12.67745486387696, 3.940763426344863, 2.9269230959809813, 1.9448987936284134, 0.9890051533163243, 1.9341368512506643, 2.9394443017910357, 3.8759715505132366, 4.851843683265769, 5.818431506034213, 6.761158454936636, 7.723565369561208, 8.658463403205854, 9.727043963005768, 10.739623566832899, 11.688716205781157, 12.651986280853581, 13.655870789107691, 13.48836314321173, 12.634558442776049, 11.68001230619956, 3.0141249492940196, 1.9744907413762334, 0.9747257505991177, 0.0, 0.9893973206735869, 1.9946151380722, 2.919703089576899, 3.8865616904426816, 4.881599940523145, 5.948474404637448, 6.980708817170693, 7.913875580287317, 8.979789650691615, 9.924871081293144, 10.885105976177035, 11.850320519279084, 12.8799611549292, 12.563344338332046, 11.645567015979946, 10.691573687978375, 3.942169838724576, 2.907967095866179, 1.9251002938191677, 1.046637987574347, 1.940169312873841, 2.923468542895462, 3.859559146831454, 4.8356431360185645, 5.84940550687814, 6.790550466317962, 7.797436964515034, 8.774210642846018, 9.744818295079343, 10.704674025324046, 11.665687985568965, 12.716804239462926, 12.620579303833932, 11.620326807489848, 10.676219113409921, 9.67350380328977, 4.905881822246462, 3.8331683973855553, 2.855144471968681, 2.0315296870975526, 2.974500960446133, 3.856067407643131, 4.870697245513844, 5.840942366569472, 6.827933306707742, 7.7305731124954775, 8.685701678363081, 9.621192530401588, 10.555212152799012, 11.532443013858328, 12.560640611953525, 12.596938081162651, 11.643487198823749, 10.674191545612596, 9.717527745913477, 8.683709282169943, 5.831537143999704, 4.882353899949156, 3.868106754369373, 2.986611502851316, 3.991401120326077, 4.903476129781664, 5.842804280951789, 6.84541945851205, 7.811230161092286, 8.753295864632337, 9.61890329452773, 10.645391974396366, 11.558178032450737, 12.534300508880422, 12.73402849289022, 11.745848395995285, 10.70600427906621, 9.753070457834324, 8.744161940123002, 7.7589801821970665, 6.775674142359753, 5.894924769608039, 4.940901262359338, 3.9592844090646095, 4.926691666211057, 5.860827615388993, 6.831711656717321, 7.79957740979128, 8.772085054495289, 9.741362991694448, 10.641809054698514, 11.590285106447062, 12.573941534550572, 12.63720629981924, 11.719591637432284, 10.769100070128543, 9.812550922159657, 8.863181093320325, 7.8732871235291775, 6.83172074346997, 7.731724911540381, 6.856476248534038, 5.86861776551683, 5.007447259574038, 5.894439431423297, 6.788326067794231, 7.827736788693444, 8.772651966857696, 9.736951739046946, 10.697820977904284, 11.587759127152376, 12.553106910013074, 12.738295535514425, 11.665318818156562, 10.723693317222375, 9.775380723158534, 8.843466204902226, 7.870561003154293, 6.798935099932299, 5.872407521420929, 8.72588113900566, 7.782636445292175, 6.856045337378477, 5.988689709198262, 6.8875842147903175, 7.795374587678694, 8.769568900645123, 9.72911749516586, 10.68550902114982, 11.646418302595995, 12.57831748074419, 12.791083060991166, 11.846815923577058, 10.822695499845508, 9.79695549524176, 8.847919770134554, 7.889900896895823, 6.947844394738373, 5.9482870039787095, 5.016089329387048, 9.77808313403602, 8.754786655934636, 7.808616066318777, 6.964116226681099, 7.9106887432456645, 8.733811265811747, 9.707719795541363, 10.719043798547197, 11.642622210326223, 12.62188305193019, 13.152049999348238, 12.125087284409497, 11.073295435166436, 10.004953436714858, 9.034751341396937, 8.090183662752853, 7.124521110553968, 6.109268751431308, 5.085594333263273, 4.081099551566991, 10.731909021253625, 9.809678657033658, 8.820717358651754, 7.923906872766891, 8.912469549231115, 9.749519296775148, 10.67711037650931, 11.65046821867279, 12.580003687855587, 13.607364450264196, 13.891200385429546, 12.85513912420793, 11.859716520161383, 10.932515607107508, 9.875071686842096, 8.918566146570134, 7.910207483627467, 6.945945434010255, 5.963902189275677, 4.905190649266331, 11.750090933669833, 10.774100686727431, 9.76503413784802, 8.851441061976724, 9.81168066852272, 10.802785914626645, 11.703591707365511, 12.634317925528409, 13.523562660831766, 14.46861195260471, 14.786521875333841, 13.746836326500617, 12.80166761192065, 11.77591581633582, 10.816818664748645, 9.955532582894016, 8.921283701725358, 7.89399097438818, 6.826467645091505, 5.793963618630734, 12.699466125788456, 11.685327702667522, 10.734360376107448, 9.854089628517052, 10.850216050823864, 11.734387770217122, 12.652407417402957, 13.611591648620173, 14.55535648874143, 15.445692098358508, 15.509300553703405, 14.5344129405885, 13.564655170437234, 12.763212525303704, 11.790609522125772, 10.729340150230371, 9.78412991631691, 8.7274465796737, 7.726259095132327, 6.6628206150325235, 13.651099896957975, 12.71248294937245, 11.80578974814134, 10.909081722652559, 11.891777385156875, 12.673757371882658, 13.590415258009418, 14.559557121362229, 15.575340487330102, 15.461711293127639, 14.552603151048308, 13.577881065247263, 12.6296068584598, 11.765246774743364, 10.814166246453865, 9.84064494638508, 8.942569911834685, 9.639388910809984, 8.57843018272494, 7.591875193628734, 14.621051735499364, 13.761110860218764, 12.852055671490177, 11.931957821276605, 12.876765631015566, 13.672238768353644, 14.591485515668813, 15.560976765596704, 15.544024171556313, 14.535106940282084, 13.556107689156532, 12.630075962256203, 11.637174970682787, 10.693359266014761, 9.753574138153324, 8.837687047628144, 7.961725635742354, 8.89832684877594, 9.533625780187181, 8.656408330926638, 15.54873736913354, 14.730832127459259, 13.912927755291252, 12.951071219172775, 13.887677651664637, 14.621383346676314, 15.549158056357989, 15.50837134295774, 14.530768880786173, 13.615672230017221, 12.609407565744453, 11.627388584392058, 10.736011369760757, 9.733150635098912, 8.781351983090689, 7.841131610668488, 6.94075487770761, 7.847120798747287, 8.798313133898493, 9.718055194148326], [9.744939911970325, 8.798898621345504, 7.837178743948196, 6.882182194431897, 5.8994879602997266, 6.808397892258415, 7.762680778866347, 8.779749327941579, 9.65519700416799, 10.607606086190495, 11.650669033962426, 12.59038803905584, 13.520367724276886, 14.530829283918886, 14.573235087861924, 14.118832509595272, 14.819143832881315, 15.748348005752685, 16.693871694528852, 17.47145307233552, 8.673254154617302, 7.856028287667196, 6.899692976531335, 5.909701005289612, 4.876362660899031, 5.834568748688366, 6.78939763854463, 7.781442342846004, 8.72674356519023, 9.687308892969353, 10.61973847401048, 11.55255660782374, 12.605295286661745, 13.632327925940471, 14.665567087065238, 15.124935882267998, 15.855843643709667, 16.806005987853098, 17.571429689953245, 16.515696341399185, 7.667472367400656, 6.871557025401346, 5.903683790454076, 4.905453487145449, 3.9065744056787404, 4.8365509387093315, 5.794259079106466, 6.766624672200676, 7.75085175526837, 8.692625386732766, 9.626993696183646, 10.615980174848062, 11.653103479294984, 12.647366454880043, 13.640483808149112, 14.620139166658797, 15.433071948018961, 16.420672637080663, 16.532761682005685, 15.6163128545965, 6.699453059805571, 5.808755680568343, 4.893758402586877, 3.8908346639384943, 2.84500125139573, 3.8381743836104674, 4.795065496550143, 5.718239977166395, 6.756532663761784, 7.714713723892737, 8.662681434245425, 9.653833637972768, 10.702649790251874, 11.665610776539587, 12.67778362238614, 13.565115473595986, 14.49580085314259, 15.487288917787202, 15.567269500783302, 14.617480890080756, 5.768017377881464, 4.797764355731675, 3.8620690914579434, 2.943299235098265, 1.8841457216441304, 2.939123957505662, 3.839487638932661, 4.769055897716776, 5.779722375057634, 6.709540352895514, 7.7331156051686145, 8.701030523687416, 9.686646460130364, 10.710453496235774, 11.626755753075226, 12.608481773509412, 13.662033002358077, 14.602736896984013, 14.554126723829857, 13.634188106434344, 4.9181854323943055, 3.9043451020304243, 2.9223207996778564, 1.9664271593657672, 0.9447395305770774, 1.9500469811174486, 2.8865742298396495, 3.862446362592182, 4.8290341853606265, 5.771761134263049, 6.734168048887621, 7.669066082532268, 8.737646642332182, 9.750226246159313, 10.699318885107571, 11.662588960179995, 12.666473468434106, 13.666898236965826, 13.591291685333433, 12.636745548756943, 4.003522269967607, 2.9638880620498202, 1.9641230712727045, 0.9893973206735869, 0.0, 1.005217817398613, 1.9303057689033118, 2.8971643697690945, 3.8922026198495576, 4.9590770839638605, 5.991311496497105, 6.924478259613729, 7.990392330018026, 8.935473760619555, 9.895708655503446, 10.860923198605494, 11.89056383425561, 12.93413875699721, 12.60230025853733, 11.648306930535758, 4.89890308128196, 3.864700338423563, 2.8818335363765515, 1.9193982403470216, 0.9507719922002541, 1.934071222221875, 2.870161826157867, 3.846245815344977, 4.860008186204553, 5.801153145644374, 6.808039643841447, 7.784813322172431, 8.755420974405755, 9.715276704650458, 10.676290664895378, 11.727406918789338, 12.760390857020575, 12.577060050047232, 11.632952355967305, 10.630237045847155, 5.862615064803846, 4.789901639942939, 3.811877714526065, 2.9042899398702273, 1.9851036397725461, 2.8666700869695436, 3.881299924840256, 4.851545045895884, 5.838535986034154, 6.74117579182189, 7.696304357689493, 8.631795209728, 9.565814832125424, 10.543045693184741, 11.571243291279938, 12.530455118506806, 12.600220441381133, 11.63092478816998, 10.674260988470861, 9.640442524727327, 6.7882703865570875, 5.839087142506541, 4.824839996926757, 3.859371755623991, 3.00200379965249, 3.914078809108077, 4.8534069602782015, 5.856022137838463, 6.821832840418699, 7.763898543958749, 8.629505973854142, 9.655994653722779, 10.56878071177715, 11.544903188206835, 12.538339048293201, 12.702581638552669, 11.662737521623596, 10.70980370039171, 9.700895182680387, 8.715713424754451, 7.732407384917137, 6.851658012165424, 5.897634504916722, 4.832044661837284, 3.9372943455374707, 4.871430294715407, 5.842314336043735, 6.8101800891176945, 7.782687733821701, 8.75196567102086, 9.652411734024927, 10.600887785773475, 11.584544213876985, 12.53100149893235, 12.676324879989666, 11.725833312685927, 10.76928416471704, 9.819914335877709, 8.830020366086561, 7.788453986027354, 8.688458154097765, 7.813209491091421, 6.825351008074214, 5.880207512346713, 4.905042110749711, 5.798928747120645, 6.838339468019858, 7.78325464618411, 8.747554418373358, 9.708423657230696, 10.598361806478788, 11.563709589339487, 12.538844556621068, 12.622052060713944, 11.680426559779757, 10.732113965715918, 9.80019944745961, 8.827294245711677, 7.755668342489683, 6.829140763978312, 9.682614381563043, 8.739369687849559, 7.809326206067951, 6.861449961970937, 5.898186894116731, 6.805977267005108, 7.780171579971538, 8.739720174492277, 9.696111700476235, 10.657020981922411, 11.588920160070602, 12.499788486442466, 12.80354916613444, 11.77942874240289, 10.753688737799141, 9.804653012691936, 8.846634139453206, 7.904577637295756, 6.905020246536093, 5.972822571944432, 10.734816376593404, 9.70806752462411, 8.76189693500825, 7.836876479453775, 6.921291422572078, 7.74441394513816, 8.718322474867778, 9.729646477873612, 10.65322488965264, 11.632485731256606, 12.562336744473706, 13.114484605083087, 12.062692755840025, 10.994350757388448, 10.024148662070527, 9.07958098342644, 8.113918431227555, 7.098666072104896, 6.074991653936861, 5.070496872240579, 11.688642263811008, 10.762959525723131, 9.773998227341227, 8.796667125539566, 7.923072228557529, 8.760121976101562, 9.687713055835724, 10.661070897999204, 11.590606367182001, 12.61796712959061, 13.50558175862578, 13.832561130257371, 12.837138526210826, 11.90993761315695, 10.852493692891539, 9.895988152619577, 8.88762948967691, 7.923367440059698, 6.9413241953251195, 5.882612655315773, 12.703371802359307, 11.727381555416905, 10.718315006537493, 9.724201314749399, 8.962717903665808, 9.813388593953059, 10.714194386691926, 11.644920604854823, 12.53416534015818, 13.479214631931125, 14.526853871459322, 14.45178061033566, 13.506611895755693, 12.753337822385262, 11.794240670798088, 10.882647298769948, 9.8987057077748, 8.871412980437622, 7.803889651140947, 6.7713856246801765, 13.637909603483909, 12.623771180362974, 11.6728038538029, 10.726849881289727, 10.001253285966952, 10.744990449543536, 11.663010096729371, 12.622194327946588, 13.565959168067844, 14.456294777684922, 14.519903233029815, 13.545015619914912, 12.575257849763647, 11.841396498865087, 10.892808173471707, 9.8422556689837, 10.761551922366353, 9.704868585723142, 8.70368110118177, 7.640242621081966, 14.589543374653427, 13.648731991656831, 12.70944679744399, 11.781841975425234, 11.05235005832509, 11.684360051209072, 12.601017937335833, 13.570159800688643, 14.585943166656516, 14.47231397245405, 13.563205830374718, 12.588483744573676, 11.640209537786212, 10.775849454069776, 9.824768925780278, 8.851247625711494, 9.838828473623186, 10.616810916859427, 9.555852188774383, 8.569297199678177, 15.559495213194817, 14.697359902503145, 13.755327209737477, 12.80471807404928, 12.11296804257172, 12.682841447680058, 13.602088194995227, 14.571579444923119, 14.554626850882725, 13.545709619608495, 12.566710368482942, 11.640678641582614, 10.6477776500092, 9.703961945341174, 8.764176817479736, 7.848289726954557, 8.857984197530856, 9.827786853409423, 10.511047786236624, 9.63383033697608, 16.48718084682899, 15.66708116974364, 14.805949078916791, 13.82383147194545, 13.16106769827795, 13.631986026002728, 14.559760735684403, 14.518974022284153, 13.541371560112585, 12.626274909343634, 11.620010245070866, 10.63799126371847, 9.746614049087169, 8.743753314425325, 7.791954662417101, 6.8517342899949005, 7.865351153457429, 8.77658080338077, 9.727773138531976, 10.695477200197768], [10.750157729368938, 9.804116438744119, 8.842396561346812, 7.887400011830511, 6.90470577769834, 5.944104633138659, 6.838005090435369, 7.805349869834231, 8.649979186769377, 9.602388268791882, 10.645451216563814, 11.585170221657227, 12.515149906878273, 13.525611466520273, 13.746294003823046, 14.755616998856407, 15.80740333218677, 16.736607505058142, 17.699089511927465, 18.476670889734137, 9.678471972015915, 8.86124610506581, 7.904910793929949, 6.914918822688227, 5.881580478297645, 4.9702754895686105, 5.7955390719086886, 6.776224525447391, 7.721525747791617, 8.68209107557074, 9.614520656611868, 10.547338790425128, 11.600077469263132, 12.627110108541862, 13.660349269666629, 14.554319937695363, 15.39912775526303, 16.36520659573372, 17.388941055787615, 17.5209141587978, 8.672690184799269, 7.876774842799959, 6.908901607852689, 5.910671304544062, 4.911792223077354, 3.9722576795895757, 4.8004005124705245, 5.761406854802063, 6.745633937869757, 7.6874075693341535, 8.621775878785034, 9.61076235744945, 10.647885661896373, 11.642148637481434, 12.635265990750502, 13.614921349260184, 14.427854130620348, 15.41545481968205, 16.37493543950156, 16.621530671995114, 7.704670877204184, 6.8139734979669555, 5.89897621998549, 4.896052481337107, 3.8502190687943436, 2.9738811244907115, 3.801206929914202, 4.713022159767783, 5.751314846363171, 6.709495906494124, 7.657463616846812, 8.648615820574157, 9.697431972853263, 10.660392959140976, 11.672565804987528, 12.559897656197373, 13.490583035743978, 14.48207110038859, 15.409443258279175, 15.622698707479369, 6.773235195280077, 5.802982173130288, 4.867286908856556, 3.9485170524968782, 2.8893635390427437, 1.933906140107049, 2.8342698215340483, 3.7638380803181635, 4.7745045576590215, 5.704322535496901, 6.727897787770002, 7.695812706288804, 8.68142864273175, 9.705235678837163, 10.621537935676614, 11.6032639561108, 12.656815184959465, 13.5975190795854, 14.567954166883379, 14.639405923832957, 5.923403249792918, 4.909562919429037, 3.9275386170764692, 2.97164497676438, 1.9499573479756904, 0.9448291637188355, 1.8813564124410367, 2.857228545193569, 3.823816367962013, 4.766543316864436, 5.728950231489009, 6.663848265133655, 7.73242882493357, 8.745008428760702, 9.69410106770896, 10.657371142781384, 11.661255651035493, 12.661680419567213, 13.605119128386955, 13.641963366155556, 5.00874008736622, 3.9691058794484335, 2.9693408886713177, 1.9946151380722, 1.005217817398613, 0.0, 0.9250879515046989, 1.8919465523704817, 2.886984802450945, 3.953859266565247, 4.986093679098492, 5.9192604422151165, 6.985174512619413, 7.930255943220943, 8.890490838104833, 9.855705381206882, 10.885346016856998, 11.928920939598598, 12.881266390228372, 12.653524747934371, 5.904120898680573, 4.869918155822177, 3.8870513537751648, 2.924616057745635, 1.9559898095988673, 1.0632370601013124, 1.9276143413318296, 2.9036983305189397, 3.8924914062112252, 4.8336363656510475, 5.84052286384812, 6.817296542179104, 7.7879041944124285, 8.747759924657132, 9.708773884902051, 10.759890138796012, 11.792874077027246, 12.795210780835601, 12.638170173365918, 11.635454863245767, 6.867832882202459, 5.795119457341552, 4.817095531924678, 3.90950775726884, 2.9903214571711594, 1.9958359248489812, 2.938752440014219, 3.908997561069847, 4.895988501208117, 5.773659011828563, 6.728787577696166, 7.664278429734674, 8.598298052132098, 9.575528913191414, 10.603726511286611, 11.56293833851348, 12.516389220852382, 12.636142605568592, 11.679478805869474, 10.64566034212594, 7.7934882039557, 6.844304959905154, 5.83005781432537, 4.864589573022604, 4.007221617051103, 3.0432446469875147, 3.910859475452164, 4.913474653012425, 5.879285355592661, 6.801864800022488, 7.661989193860816, 8.688477873729452, 9.601263931783823, 10.577386408213508, 11.570822268299874, 12.51988256988082, 12.667955339022209, 11.715021517790323, 10.706113000079, 9.720931242153064, 8.73762520231575, 7.856875829564037, 6.902852322315335, 5.837262479235898, 4.942512162936083, 4.044489210676532, 4.975293360176591, 5.943159113250551, 6.840140248995664, 7.7899319270846, 8.6848949540316, 9.633371005780148, 10.617027433883658, 11.563484718939023, 12.502857084130548, 12.73105113008454, 11.774501982115654, 10.825132153276321, 9.835238183485174, 8.793671803425967, 9.693675971496377, 8.818427308490035, 7.8305688254728265, 6.885425329745327, 5.910259928148323, 4.97198766308177, 5.971318492152714, 6.9162336703169665, 7.80500693354732, 8.746389913294436, 9.630845026485462, 10.59619280934616, 11.571327776627742, 12.535372200601701, 12.685644377178372, 11.73733178311453, 10.805417264858223, 9.83251206311029, 8.760886159888296, 7.834358581376925, 10.687832198961656, 9.744587505248173, 8.814544023466564, 7.86666777936955, 6.903404711515343, 5.979036182966233, 6.9532304959326625, 7.912779090453402, 8.862173794010133, 9.78100869003104, 10.621403380077275, 11.532271706449139, 12.476538843863247, 12.784646559801505, 11.758906555197756, 10.809870830090551, 9.85185195685182, 8.90979545469437, 7.910238063934706, 6.978040389343045, 11.740034193992017, 10.713285342022722, 9.767114752406863, 8.842094296852387, 7.912693740248173, 6.917472861099285, 7.8913813908289026, 8.902705393834736, 9.819286983186537, 10.756473439365235, 11.63409398389825, 12.493564650534433, 13.067910573238638, 11.99956857478706, 11.02936647946914, 10.084798800825054, 9.119136248626168, 8.103883889503509, 7.080209471335474, 6.075714689639192, 12.693860081209621, 11.768177343121744, 10.77921604473984, 9.801884942938178, 8.899036016220467, 7.933180892062686, 8.860771971796849, 9.83412981396033, 10.7566684607159, 11.78402922312451, 12.577338998050324, 13.531951835729519, 13.584269728395205, 12.915155430555563, 11.857711510290152, 10.90120597001819, 9.892847307075522, 8.92858525745831, 7.946542012723732, 6.887830472714386, 13.70858961975792, 12.732599372815518, 11.723532823936106, 10.729419132148012, 9.938681691328746, 8.986447509914182, 9.88725330265305, 10.817979520815948, 11.70022743369208, 12.645276725465024, 13.625031319722806, 13.587487351215906, 12.642318636635938, 11.961402923316252, 11.002305771729077, 11.88786511616856, 10.903923525173413, 9.876630797836235, 8.80910746853956, 7.776603442078789, 14.643127420882522, 13.628988997761587, 12.678021671201513, 11.73206769868834, 10.90272620935451, 9.91804936550466, 10.836069012690496, 11.795253243907712, 12.732021261601743, 13.622356871218821, 13.514685415631202, 12.673323436166974, 11.710964590643892, 10.977103239745333, 10.02851491435195, 10.847473486382313, 11.766769739764964, 10.710086403121753, 9.708898918580381, 8.645460438480578, 15.59476119205204, 14.653949809055444, 13.714664614842603, 12.787059792823847, 11.841234555234191, 10.857418967170196, 11.774076853296958, 12.743218716649768, 13.759002082617641, 13.467096155055437, 12.557988012976105, 11.654110510629556, 10.775916278666458, 9.911556194950021, 8.960475666660521, 9.856465443110107, 10.8440462910218, 11.62202873425804, 10.561070006172995, 9.57451501707679, 16.56471303059343, 15.702577719901758, 14.76054502713609, 13.809935891447893, 12.901852539480823, 11.855900363641181, 12.775147110956352, 13.744638360884244, 13.549409033484112, 12.540491802209882, 11.56149255108433, 10.635460824184001, 9.783484390889445, 8.839668686221419, 7.8998835583599805, 8.853507544353171, 9.863202014929469, 10.833004670808037, 11.516265603635237, 10.639048154374693, 17.492398664227608, 16.672298987142252, 15.798063381032375, 14.815945774061033, 13.879339341569171, 12.805044941963851, 13.732819651645528, 13.51375620488554, 12.536153742713973, 11.621057091945021, 10.614792427672253, 9.632773446319858, 8.772214590979821, 7.879460055305568, 6.927661403297345, 7.856952107393514, 8.870568970856043, 9.781798620779385, 10.73299095593059, 11.70069501759638], [11.675245680873639, 10.7053679881946, 9.743648110797293, 8.788651561280993, 7.805957327148822, 6.803233599997127, 5.912917138930671, 6.880261918329532, 7.724891235264678, 8.677300317287184, 9.720363265059115, 10.660082270152529, 11.590061955373574, 12.600523515015574, 13.543879735665808, 14.55320273069917, 15.510739614586686, 16.43994378745806, 17.458412159246468, 18.416352104704576, 10.603559923520615, 9.762497654516292, 8.80616234338043, 7.816170372138709, 6.782832027748126, 5.829404456427079, 4.87045112040399, 5.851136573942693, 6.796437796286918, 7.757003124066042, 8.68943270510717, 9.62225083892043, 10.674989517758434, 11.702022157037161, 12.735261318161928, 13.629231986190666, 14.474039803758334, 15.440118644229022, 16.463853104282915, 17.3952322446927, 9.597778136303969, 8.801862794304657, 7.833989559357388, 6.835759256048761, 5.813043772527836, 4.831386646448044, 3.875312560965826, 4.836318903297364, 5.820545986365058, 6.762319617829455, 7.696687927280336, 8.685674405944752, 9.722797710391674, 10.717060685976733, 11.710178039245802, 12.689833397755487, 13.502766179115651, 14.490366868177354, 15.449847487996863, 16.446995830375773, 8.629758828708884, 7.739061449471654, 6.824064171490188, 5.821140432841807, 4.775307020299042, 3.8330100913491796, 2.8761189784095036, 3.787934208263084, 4.826226894858473, 5.784407954989425, 6.732375665342113, 7.723527869069458, 8.772344021348564, 9.735305007636278, 10.747477853482831, 11.634809704692676, 12.56549508423928, 13.556983148883893, 14.484355306774479, 15.46301608859667, 7.698323146784776, 6.7280701246349865, 5.792374860361255, 4.873605004001577, 3.8144514905474423, 2.8589940916117476, 1.9091818700293492, 2.8387501288134644, 3.849416606154323, 4.779234583992203, 5.802809836265303, 6.770724754784106, 7.756340691227053, 8.780147727332464, 9.696449984171917, 10.678176004606103, 11.731727233454768, 12.672431128080703, 13.642866215378682, 14.573610534832547, 6.848491201297617, 5.834650870933736, 4.852626568581168, 3.8967329282690786, 2.875045299480389, 1.8699171152235343, 0.9562684609363377, 1.93214059368887, 2.898728416457314, 3.8414553653597374, 4.80386227998431, 5.738760313628957, 6.807340873428871, 7.819920477256003, 8.769013116204261, 9.732283191276686, 10.736167699530796, 11.736592468062517, 12.680031176882258, 13.746854402466631, 5.933828038870919, 4.8941938309531325, 3.8944288401760168, 2.919703089576899, 1.9303057689033118, 0.9250879515046989, 0.0, 0.9668586008657828, 1.9618968509462458, 3.028771315060548, 4.061005727593793, 4.994172490710417, 6.060086561114714, 7.0051679917162435, 7.965402886600135, 8.930617429702183, 9.9602580653523, 11.0038329880939, 11.956178438723674, 12.910171766725245, 6.829208850185271, 5.795006107326874, 4.812139305279863, 3.8497040092503334, 2.881077761103566, 1.9386169937631226, 1.0025263898271308, 1.9786103790142409, 2.967403454706526, 3.9085484141463476, 4.915434912343421, 5.892208590674405, 6.862816242907729, 7.822671973152433, 8.783685933397352, 9.834802187291313, 10.86778612552255, 11.870122829330905, 12.814230523410831, 12.560542814750466, 7.792920833707157, 6.7202074088462505, 5.742183483429376, 4.834595708773539, 3.883546886155234, 2.8712158585107916, 2.0136644885095203, 2.9839096095651483, 3.970900549703418, 4.848571060323864, 5.803699626191467, 6.7391904782299745, 7.673210100627398, 8.650440961686714, 9.678638559781911, 10.637850387008779, 11.591301269347682, 12.560596922558837, 12.604566757374172, 11.570748293630638, 8.718576155460399, 7.769392911409852, 6.755145765830068, 5.789677524527303, 4.900447046035178, 3.918624580649325, 2.9857715239474656, 3.988386701507727, 4.954197404087963, 5.876776848517789, 6.736901242356116, 7.7633899222247535, 8.676175980279124, 9.65229845670881, 10.645734316795176, 11.59479461837612, 12.645047864138297, 12.640109469295021, 11.631200951583699, 10.646019193657763, 9.662713153820448, 8.781963781068734, 7.827940273820033, 6.762350430740597, 5.835737591920158, 4.919869144338342, 4.050205408671893, 5.018071161745852, 5.915052297490965, 6.864843975579901, 7.759807002526902, 8.70828305427545, 9.69193948237896, 10.638396767434324, 11.57776913262585, 12.571542944242864, 12.699589933620352, 11.75022010478102, 10.760326134989873, 9.718759754930666, 10.618763923001076, 9.743515259994732, 8.755656776977524, 7.808491916870414, 6.8034853571323985, 5.847367596743581, 5.046230540648016, 5.991145718812268, 6.879918982042621, 7.821301961789738, 8.705757074980763, 9.671104857841462, 10.646239825123043, 11.610284249097003, 12.55190975003119, 12.66241973461923, 11.730505216362921, 10.757600014614988, 9.685974111392994, 8.759446532881624, 11.612920150466355, 10.66967545675287, 9.737610610591652, 8.789734366494638, 7.796630140499419, 6.854416116628044, 6.046092383459942, 7.005640977980681, 7.937085842505434, 8.855920738526342, 9.696315428572577, 10.60718375494444, 11.551450892358549, 12.574876659338509, 12.683994506702454, 11.73495878159525, 10.77693990835652, 9.834883406199069, 8.835326015439405, 7.9031283408477435, 12.665122145496715, 11.63635192914781, 10.690181339531952, 9.765160883977476, 8.788073673909985, 7.792852794761096, 6.984243278356182, 7.995567281362016, 8.894199031681838, 9.831385487860537, 10.709006032393551, 11.568476699029734, 12.542479419101042, 12.924656526291757, 11.954454430973836, 11.009886752329752, 10.044224200130866, 9.028971841008207, 8.005297422840172, 7.000802641143891, 13.61894803271432, 12.691243930246833, 11.702282631864929, 10.724951530063267, 9.774415949882279, 8.808560825724497, 7.953633859324129, 8.92699170148761, 9.8315805092112, 10.858941271619809, 11.652251046545626, 12.606863884224822, 12.695314261067201, 12.215161778895022, 12.78279946179485, 11.826293921522888, 10.81793525858022, 9.85367320896301, 8.87162996422843, 7.812918424219085, 14.631656206883008, 13.655665959940606, 12.646599411061194, 11.6524857192731, 10.814061624990558, 9.861827443575994, 8.98011519018033, 9.910841408343229, 10.77513948218738, 11.720188773960324, 12.699943368218108, 12.698531883887902, 11.753363169307935, 11.16600818557208, 11.861434738587546, 12.789116665619042, 11.829011476678112, 10.801718749340933, 9.734195420044259, 8.701691393583488, 15.56619400800761, 14.552055584886675, 13.601088258326602, 12.655134285813428, 11.778106143016322, 10.79342929916647, 9.928930900217775, 10.888115131434992, 11.806933310097042, 12.697268919714121, 12.589597464126506, 11.748235484662278, 10.822009123315889, 10.11139809514667, 10.887643881210419, 11.748725035832795, 12.691857691269664, 11.635174354626454, 10.633986870085081, 9.570548389985278, 16.51782777917713, 15.566200167631916, 14.626914973419074, 13.699310151400319, 12.716614488896003, 11.732798900832007, 10.866938740824237, 11.836080604177045, 12.840175117236868, 12.54200820355074, 11.632900061471409, 10.729022559124859, 9.886960811338454, 9.04585105035136, 9.81960463351899, 10.757716992560589, 11.745297840472281, 12.54711668576274, 11.486157957677696, 10.49960296858149, 17.487779617718516, 16.61482807847823, 15.672649418569792, 14.722040282881595, 13.777232473142634, 12.731280297302993, 11.868008998483631, 12.837500248411523, 12.624321081979414, 11.615403850705185, 10.636404599579633, 9.710372872679304, 8.894528923561442, 7.973963541622757, 8.759012525218449, 9.754759093803653, 10.76445356437995, 11.73425622025852, 12.441353555139937, 11.564136105879394, 18.415465251352693, 17.584549345718724, 16.673443314694186, 15.691325707722845, 14.754719275230983, 13.680424875625663, 12.825681539172807, 12.588668253380842, 11.611065791209274, 10.695969140440322, 9.689704476167554, 8.70768549481516, 7.847126639475124, 6.966990802788913, 7.786790370155813, 8.758203656843996, 9.771820520306525, 10.683050170229867, 11.634242505381073, 12.625782969101081], [12.642104281739421, 11.672226589060383, 10.710506711663076, 9.755510162146775, 8.772815928014603, 7.770092200862909, 6.879775739796453, 6.071099826050557, 6.915729142985704, 7.86813822500821, 8.832096542415577, 9.729774402030058, 10.659754087251104, 11.670215646893103, 12.613571867543337, 13.622894862576699, 14.551600564796793, 15.480804737668164, 16.49927310945657, 17.45721305491468, 11.570418524386398, 10.729356255382074, 9.773020944246213, 8.783028973004491, 7.749690628613909, 6.796263057292861, 5.837309721269772, 5.0419744816637175, 5.987275704007944, 6.830308032021672, 7.762737613062799, 8.691942970797959, 9.744681649635963, 10.742883107247268, 11.776122268372035, 12.670092936400772, 13.51490075396844, 14.480979594439129, 15.504714054493022, 16.436093194902803, 10.564636737169751, 9.768721395170441, 8.800848160223172, 7.8026178569145435, 6.779902373393618, 5.798245247313826, 4.842171161831608, 4.027156811018389, 5.011383894086082, 5.8125018070768295, 6.7468701165277105, 7.726535356154859, 8.76365866060178, 9.75792163618684, 10.751038989455909, 11.730694347965594, 12.543627129325758, 13.53122781838746, 14.490708438206969, 15.487856780585878, 9.596617429574666, 8.705920050337438, 7.790922772355971, 6.787999033707589, 5.742165621164824, 4.799868692214962, 3.842977579275286, 2.978772115984109, 3.9901149392134654, 4.834590144236799, 5.77323661555222, 6.7643888192795645, 7.813204971558671, 8.776165957846384, 9.788338803692938, 10.675670654902783, 11.606356034449387, 12.597844099093999, 13.525216256984585, 14.503877038806776, 8.665181747650559, 7.69492872550077, 6.759233461227038, 5.8404636048673595, 4.781310091413225, 3.8258526924775302, 2.876040470895132, 2.0295880365344896, 2.980752243671155, 3.8200955342023097, 4.84367078647541, 5.811585704994212, 6.79720164143716, 7.82100867754257, 8.737310934382023, 9.71903695481621, 10.772588183664874, 11.71329207829081, 12.683727165588788, 13.614471485042653, 7.8153498021634, 6.801509471799519, 5.819485169446951, 4.863591529134862, 3.841903900346172, 2.836775716089317, 1.9231270618021203, 0.9985647521879257, 1.9395893666674215, 2.882316315569845, 3.844723230194417, 4.779621263839063, 5.848201823638978, 6.86078142746611, 7.809874066414368, 8.773144141486792, 9.777028649740902, 10.777453418272623, 11.720892127092364, 12.787715352676738, 6.9006866397367, 5.861052431818914, 4.8612874410417986, 3.886561690442681, 2.8971643697690945, 1.8919465523704817, 0.9668586008657828, 0.0, 0.9950382500804631, 2.0619127141947655, 3.0941471267280107, 4.027313889844635, 5.093227960248932, 6.038309390850461, 6.9985442857343525, 7.9637588288364, 8.993399464486515, 10.036974387228115, 10.98931983785789, 11.943313165859461, 7.796067451051054, 6.7618647081926575, 5.778997906145646, 4.816562610116116, 3.8479363619693485, 2.9054755946289057, 1.9693849906929137, 1.0339538617181732, 2.0005448538407435, 2.9416898132805653, 3.9485763114776384, 4.925349989808622, 5.895957642041947, 6.855813372286651, 7.81682733253157, 8.86794358642553, 9.900927524656765, 10.90326422846512, 11.847371922545047, 12.856124030673017, 8.759779434572941, 7.687066009712034, 6.7090420842951595, 5.801454309639322, 4.850405487021018, 3.8380744593765748, 2.980523089375303, 2.084594421937919, 3.062981237138695, 3.881712459458081, 4.836841025325684, 5.772331877364192, 6.706351499761616, 7.683582360820932, 8.711779958916129, 9.670991786142997, 10.6244426684819, 11.593738321693053, 12.550402121392171, 12.53760689449642, 9.685434756326181, 8.736251512275635, 7.722004366695851, 6.756536125393085, 5.867305646900961, 4.885483181515108, 3.952630124813248, 3.089071513880498, 4.04627809152324, 4.909918247652006, 5.770042641490334, 6.796531321358971, 7.709317379413342, 8.685439855843027, 9.678875715929394, 10.62793601751034, 11.678189263272516, 12.560618558448015, 12.598059552449483, 11.612877794523547, 10.62957175468623, 9.748822381934517, 8.794798874685815, 7.729209031606379, 6.802596192785941, 5.886727745204125, 5.017064009537675, 4.133186193279655, 5.007132984926242, 5.897985374714118, 6.7929484016611195, 7.7414244534096674, 8.725080881513177, 9.671538166568542, 10.610910531760068, 11.604684343377084, 12.627334426391668, 12.717078705646804, 11.727184735855657, 10.68561835579645, 11.585622523866858, 10.710373860860514, 9.722515377843306, 8.775350517736197, 7.770343957998181, 6.814226197609363, 6.013089141513798, 5.10626075034607, 5.971999669477898, 6.854443360923955, 7.738898474114982, 8.704246256975681, 9.679381224257263, 10.64342564823122, 11.585051149165407, 12.598403690347093, 12.697363817228705, 11.724458615480772, 10.652832712258778, 9.726305133747408, 12.579778751332137, 11.636534057618652, 10.704469211457434, 9.75659296736042, 8.763488741365201, 7.821274717493826, 7.012950984325724, 6.175247532261679, 7.029166529940712, 7.889062137660559, 8.729456827706795, 9.64032515407866, 10.584592291492768, 11.608018058472727, 12.511788971146023, 12.701817382461032, 11.743798509222302, 10.80174200706485, 9.802184616305187, 8.869986941713526, 12.96537757175356, 12.603210530013593, 11.657039940397734, 10.732019484843258, 9.754932274775767, 8.759711395626878, 7.951101879221964, 7.218131957226123, 7.986279719117116, 8.864526886994755, 9.74214743152777, 10.601618098163954, 11.575620818235262, 12.637126141728828, 12.92131303183962, 11.976745353195534, 11.011082800996649, 9.99583044187399, 8.972156023705955, 7.967661242009672, 13.814775206419252, 13.658102531112615, 12.669141232730711, 11.69181013092905, 10.74127455074806, 9.775419426590279, 8.92049246018991, 8.157230793095303, 8.923661196646478, 9.939276350927816, 10.685392445679843, 11.640005283359041, 11.886152168788225, 12.8133530818421, 13.749658062660632, 12.79315252238867, 11.784793859446003, 10.820531809828791, 9.838488565094213, 8.779777025084867, 14.639655050876835, 14.622524560806388, 13.613458011926976, 12.619344320138882, 11.780920225856338, 10.828686044441776, 9.946973791046112, 9.141080499950922, 9.867220169622657, 10.812269461395601, 11.733084767352326, 11.889369791608928, 10.944201077028959, 11.97591152529918, 12.828293339453328, 13.755975266484825, 12.795870077543896, 11.768577350206717, 10.701054020910043, 9.668549994449272, 15.538787220288864, 15.518914185752458, 14.567946859192384, 13.62199288667921, 12.744964743882104, 11.760287900032253, 10.895789501083557, 10.199662193453369, 10.89901399753232, 11.789349607149399, 11.780435371847531, 10.939073392383303, 10.012847031036912, 10.9444411392938, 11.854502482076201, 12.715583636698577, 13.658716292135447, 12.602032955492236, 11.600845470950864, 10.53740699085106, 16.490420991458382, 16.533058768497696, 15.593773574284857, 14.6661687522661, 13.683473089761785, 12.69965750169779, 11.833797341690019, 11.18286107854596, 11.932255804672145, 11.732846111271765, 10.823737969192434, 9.919860466845885, 9.077798719059478, 10.012709651217142, 10.786463234384772, 11.724575593426371, 12.712156441338063, 13.513975286628522, 12.453016558543478, 11.466461569447272, 17.392294323107173, 17.58168667934401, 16.639508019435574, 15.688898883747378, 14.744091074008416, 13.698138898168775, 12.834867599349414, 12.252628996817558, 11.694013213856943, 10.80624175842621, 9.827242507300658, 8.90121078040033, 8.085366831282466, 8.940822142488539, 9.72587112608423, 10.721617694669435, 11.731312165245733, 12.701114821124301, 13.40821215600572, 12.530994706745176, 18.31997995674135, 17.509479470704697, 16.499383713357226, 15.517266106385883, 14.58065967389402, 13.554820929402531, 12.610961827876066, 11.658360385258371, 10.680757923086803, 9.871356463319085, 8.880542383888582, 7.898523402536185, 7.0379645471961485, 7.933849403654695, 8.753648971021596, 9.725062257709778, 10.738679121172307, 11.64990877109565, 12.601101106246855, 13.592641569966863], [13.614866493110027, 12.636110599366198, 11.67439072196889, 10.71939417245259, 9.736699938320418, 8.733976211168725, 7.843659750102268, 6.9659995075057255, 5.956964279004994, 6.874320634039986, 7.837058292335113, 8.734736151949592, 9.664715837170638, 10.675177396812638, 11.618533617462871, 12.627856612496233, 13.556562314716327, 14.485766487587698, 15.504234859376107, 16.462174804834213, 12.56545677446686, 11.693240265687889, 10.736904954552028, 9.746912983310306, 8.713574638919724, 7.760147067598676, 6.801193731575587, 5.954548668831194, 5.028510840027234, 5.835269781941208, 6.767699362982335, 7.696904720717494, 8.749643399555499, 9.747844857166804, 10.78108401829157, 11.675054686320307, 12.519862503887975, 13.485941344358663, 14.509675804412556, 15.441054944822337, 11.559674987250213, 10.763759645250904, 9.795886410303634, 8.797656106995007, 7.743786383699433, 6.762129257619641, 5.806055172137423, 4.9397309981858655, 4.04660221731868, 4.8174635569963655, 5.7518318664472465, 6.731497106074395, 7.768620410521316, 8.762883386106376, 9.756000739375445, 10.735656097885128, 11.548588879245292, 12.536189568306995, 13.495670188126503, 14.492818530505412, 10.591655679655128, 9.7009583004179, 8.785961022436435, 7.783037283788052, 6.7372038712452875, 5.763752702520777, 4.806861589581101, 3.8913463031515856, 2.9950766891330023, 3.8395518941563354, 4.778198365471757, 5.769350569199101, 6.818166721478208, 7.781127707765919, 8.793300553612474, 9.680632404822317, 10.611317784368921, 11.602805849013533, 12.53017800690412, 13.50883878872631, 9.660219997731021, 8.689966975581232, 7.754271711307501, 6.835501854947823, 5.776348341493688, 4.820890942557994, 3.8399244812009465, 2.942162223701966, 1.985713993590692, 2.8250572841218466, 3.8486325363949465, 4.816547454913749, 5.802163391356697, 6.825970427462106, 7.742272684301558, 8.723998704735743, 9.777549933584408, 10.718253828210344, 11.688688915508322, 12.619433234962187, 8.810388052243864, 7.796547721879982, 6.814523419527414, 5.858629779215325, 4.836942150426635, 3.83181396616978, 2.887011072107935, 1.9111389393554026, 0.9445511165869586, 1.8872780654893817, 2.849684980113954, 3.7845830137586005, 4.853163573558515, 5.865743177385646, 6.814835816333904, 7.778105891406328, 8.781990399660437, 9.782415168192157, 10.725853877011899, 11.792677102596272, 7.8957248898171635, 6.856090681899377, 5.856325691122262, 4.881599940523144, 3.8922026198495576, 2.886984802450945, 1.9618968509462458, 0.9950382500804631, 0.0, 1.0668744641143024, 2.0991088766475476, 3.0322756397641717, 4.098189710168469, 5.043271140769998, 6.003506035653889, 6.968720578755937, 7.998361214406053, 9.041936137147653, 9.994281587777428, 10.948274915778999, 8.791105701131517, 7.756902958273121, 6.774036156226109, 5.811600860196579, 4.842974612049812, 3.9005138447093683, 2.9644232407733764, 2.0192689746198558, 1.0055066037602802, 1.946651563200102, 2.9535380613971753, 3.9303117397281593, 4.900919391961484, 5.860775122206188, 6.821789082451107, 7.872905336345067, 8.905889274576303, 9.908225978384658, 10.852333672464585, 11.861085780592555, 9.754817684653405, 8.682104259792498, 7.704080334375623, 6.796492559719785, 5.84544373710148, 4.833112709457037, 3.9755613394557656, 3.054933927196502, 2.067942987058232, 2.886674209377618, 3.841802775245221, 4.777293627283728, 5.711313249681152, 6.688544110740468, 7.716741708835665, 8.675953536062533, 9.629404418401435, 10.59870007161259, 11.555363871311709, 12.589182335055243, 10.680473006406645, 9.731289762356099, 8.717042616776315, 7.751574375473549, 6.862343896981423, 5.88052143159557, 4.947668374893711, 4.05941101913908, 3.0512398414427766, 3.9148799975715427, 4.77500439140987, 5.801493071278507, 6.714279129332878, 7.690401605762564, 8.68383746584893, 9.632897767429874, 10.68315101319205, 11.565580308367553, 12.574488826078875, 12.60791604460401, 11.624610004766694, 10.74386063201498, 9.78983712476628, 8.724247281686843, 7.7976344428664035, 6.881765995284587, 5.9764692632924765, 5.008603510218517, 4.012094734845779, 4.902947124633655, 5.7979101515806555, 6.7463862033292035, 7.730042631432713, 8.676499916488078, 9.615872281679604, 10.609646093296618, 11.632296176311202, 12.576507099527289, 12.72222298593612, 11.680656605876914, 12.580660773947322, 11.705412110940978, 10.71755362792377, 9.770388767816659, 8.765382208078643, 7.809264447689825, 6.957113508670026, 5.942770891694492, 4.976961419397435, 5.8594051108434915, 6.743860224034518, 7.709208006895217, 8.684342974176799, 9.648387398150756, 10.590012899084943, 11.603365440266627, 12.535279958522935, 12.719496865561236, 11.647870962339242, 10.721343383827872, 12.808708444876666, 12.631572307699116, 11.699507461537896, 10.751631217440883, 9.758526991445663, 8.816312967574287, 7.950068400364945, 6.9905198058442055, 6.034128279860248, 6.894023887580095, 7.7344185776263314, 8.645286903998196, 9.589554041412304, 10.612979808392263, 11.51675072106556, 12.465786446172764, 12.738836759302766, 11.796780257145315, 10.79722286638565, 9.86502519179399, 11.970339321673098, 13.031575169207168, 12.652078190478196, 11.72705773492372, 10.749970524856229, 9.75474964570734, 8.888219295261186, 7.983635116805424, 6.991241469036652, 7.869488636914291, 8.747109181447307, 9.60657984808349, 10.580582568154798, 11.642087891648364, 12.582828321926451, 12.971783603275997, 12.00612105107711, 10.990868691954452, 9.967194273786417, 8.962699492090135, 12.819736956338787, 13.880620368017455, 13.664179482811173, 12.686848381009511, 11.736312800828522, 10.770457676670741, 9.857609876229132, 8.922733952674603, 7.928622946566015, 8.944238100847352, 9.690354195599381, 10.644967033278576, 11.621247558553199, 12.548448471607074, 13.594144334644483, 13.788190772469134, 12.779832109526467, 11.815570059909255, 10.833526815174677, 9.77481527516533, 13.644616800796369, 14.62060704773877, 14.608496262007439, 13.614382570219345, 12.7759584759368, 11.823724294522238, 10.884091207085334, 9.865040656367828, 8.872181919542195, 9.81723121131514, 10.738046517271863, 11.034554766775095, 11.775772167622119, 12.80748261589234, 13.72240609044202, 14.71985927679064, 13.790908327624358, 12.76361560028718, 11.696092270990505, 10.663588244529734, 14.543748970208398, 15.557887393329333, 15.562985109272846, 14.617031136759673, 13.740002993962566, 12.755326150112715, 11.832906917122779, 10.876369638831946, 9.903975747451858, 10.794311357068937, 10.82167050786682, 9.980308528402594, 10.844418121630072, 11.77601222988696, 12.748615233064893, 13.679467647004392, 14.624677880917853, 13.597071205572698, 12.595883721031326, 11.532445240931523, 15.495382741377917, 16.468969641976525, 16.58881182436532, 15.661207002346563, 14.678511339842247, 13.694695751778251, 12.77091475772924, 11.859568523924537, 10.937217554591683, 10.774081247291054, 9.864973105211723, 8.961095602865175, 9.909369809652638, 10.895007084330501, 11.75034724469059, 12.688459603732186, 13.676040451643878, 14.509013536708984, 13.44805480862394, 12.461499819527734, 16.397256073026707, 17.439565784068268, 16.47802850277487, 15.527419367086672, 14.582611557347711, 13.508927257644736, 12.573596118484776, 11.628582231602483, 10.698974963776477, 9.8474768944455, 8.868477643319947, 7.9424459164196195, 8.918082081769553, 9.861897786437579, 10.689755136390048, 11.68550170497525, 12.695196175551548, 13.664998831430117, 14.403250406086181, 13.526032956825638, 17.324941706660884, 16.51444122062423, 15.504345463276758, 14.522227856305417, 13.585621423813555, 12.559782679322065, 11.6159235777956, 10.663322135177905, 9.685719673006338, 8.876318213238621, 7.886724792920356, 6.939758538555475, 7.870679797683236, 8.89694596126913, 9.717532981327413, 10.688946268015593, 11.702563131478122, 12.613792781401465, 13.56498511655267, 14.587679820047326], [14.539425329859935, 13.560669436116106, 12.598949558718799, 11.643953009202498, 10.661258775070326, 9.658535047918631, 8.768218586852177, 7.772428716143884, 6.763393487643153, 5.913425572985047, 6.876163231280175, 7.7738410908946545, 8.7038207761157, 9.7142823357577, 10.657638556407933, 11.666961551441295, 12.59566725366139, 13.52487142653276, 14.543339798321169, 15.501279743779275, 13.57509293680781, 12.617799102437797, 11.661463791301935, 10.671471820060214, 9.638133475669632, 8.684705904348583, 7.725752568325495, 6.7802412710096185, 5.834940048665393, 4.874374720886269, 5.8068043019273965, 6.736009659662556, 7.788748338500561, 8.786949796111866, 9.820188957236633, 10.714159625265369, 11.558967442833037, 12.525046283303725, 13.548780743357618, 14.4801598837674, 12.606722513620282, 11.757417406453675, 10.753771229577605, 9.723280171987824, 8.668345220449341, 7.686688094369549, 6.730614008887331, 5.838721069785647, 4.854493986717954, 3.856568495941427, 4.790936805392308, 5.770602045019457, 6.807725349466378, 7.801988325051438, 8.795105678320507, 9.77476103683019, 10.587693818190354, 11.575294507252057, 12.534775127071565, 13.531923469450474, 11.638703206025196, 10.748005826787969, 9.794452252121502, 8.734852985741057, 7.681484671485422, 6.688311539270685, 5.731420426331009, 4.815905139901493, 3.836837893232349, 2.8786568331013966, 3.8173033044168188, 4.808455508144164, 5.85727166042327, 6.8202326467109815, 7.832405492557536, 8.71973734376738, 9.650422723313984, 10.641910787958595, 11.569282945849181, 12.547943727671372, 10.70726752410109, 9.7370145019513, 8.80131923767757, 7.882549381317891, 6.8233958678637565, 5.835411031545119, 4.764483317950854, 3.866721060451874, 2.9102728303406, 1.864162223066908, 2.8877374753400082, 3.8556523938588114, 4.841268330301759, 5.865075366407168, 6.7813776232466205, 7.763103643680806, 8.81665487252947, 9.757358767155406, 10.727793854453385, 11.65853817390725, 9.857435578613932, 8.84359524825005, 7.8615709458974825, 6.905677305585393, 5.883989676796704, 4.859102643696886, 3.8115699088578427, 2.8356977761053104, 1.8691099533368662, 0.9263830044344431, 1.8887899190590154, 2.8236879527036622, 3.892268512503577, 4.904848116330708, 5.853940755278966, 6.8172108303513905, 7.8210953386055, 8.82152010713722, 9.76495881595696, 10.831782041541334, 8.962599353931466, 7.92296514601368, 6.9232001552365645, 5.948474404637447, 4.9590770839638605, 3.953859266565247, 3.028771315060548, 2.0619127141947655, 1.0668744641143024, 0.0, 1.032234412533245, 1.9654011756498688, 3.0313152460541657, 3.9763966766556953, 4.9366315715395865, 5.901846114641634, 6.93148675029175, 7.97506167303335, 8.927407123663125, 9.881400451664696, 9.783479610705545, 8.749276867847147, 7.766410065800135, 6.803974769770605, 5.835348521623837, 4.852049291602216, 3.9159586876662247, 2.9398746984791146, 1.926112327619539, 0.9849673681797173, 1.9918538663767904, 2.9047353908400475, 3.8753430430733724, 4.835198773318076, 5.796212733562996, 6.847328987456956, 7.880312925688192, 8.882649629496546, 9.826757323576473, 10.835509431704443, 10.747191594227429, 9.674478169366521, 8.696454243949647, 7.7888664692938105, 6.796979183994328, 5.784648156349885, 4.875277894614198, 3.90503277355857, 2.9180418334203, 1.9249900143572334, 2.880118580224836, 3.815609432263344, 4.749629054660767, 5.726859915720083, 6.75505751381528, 7.714269341042148, 8.66772022338105, 9.637015876592205, 10.593679676291323, 11.627498140034858, 11.672846915980669, 10.723663671930122, 9.709416526350338, 8.743948285047574, 7.813879343874271, 6.832056878488418, 5.847384930052144, 4.909509865501149, 3.8952615060912086, 2.953195802551158, 3.813320196389485, 4.839808876258123, 5.7525949343124925, 6.7287174107421786, 7.722153270828545, 8.67121357240949, 9.721466818171667, 10.603896113347167, 11.61280463105849, 12.597986388984426, 12.616983914340718, 11.736234541589004, 10.782211034340303, 9.716621191260868, 8.725510918447172, 7.791374969269237, 6.8204909279409085, 5.852625174866949, 4.856116399494211, 3.94126292961327, 4.83622595656027, 5.784702008308818, 6.768358436412328, 7.7148157214676925, 8.654188086659218, 9.647961898276233, 10.670611981290818, 11.614822904506903, 12.60471687429805, 12.673030515450938, 12.57948251066442, 12.697786020515002, 11.709927537497794, 10.698265243397428, 9.693258683659412, 8.718873421674475, 7.801135173318458, 6.786792556342924, 5.820983084045867, 4.897720915823107, 5.782176029014132, 6.7475238118748315, 7.722658779156413, 8.68670320313037, 9.628328704064558, 10.641681245246241, 11.57359576350255, 12.546500965250482, 12.640244871913266, 11.713717293401896, 11.783132095988554, 12.753446962352212, 12.627383937118665, 11.679507693021652, 10.670118827606707, 9.725921941558937, 8.794090065013377, 7.8345414704926375, 6.87814994450868, 5.932339692559712, 6.772734382605946, 7.68360270897781, 8.627869846391919, 9.651295613371877, 10.555066526045174, 11.504102251152378, 12.462121124391109, 12.789154166719342, 11.789596775959678, 10.857399101368017, 10.903464857558795, 11.964700705092865, 12.910871294708723, 12.654402240223888, 11.659579498840879, 10.66435861969199, 9.732240959909618, 8.827656781453856, 7.835263133685084, 6.907804441893907, 7.785424986426921, 8.644895653063104, 9.618898373134412, 10.680403696627979, 11.621144126906065, 12.507833021609772, 13.072995515191414, 12.057743156068755, 11.03406873790072, 10.029573956204437, 11.8572907447764, 12.918174156455068, 13.9229725870417, 13.614192886309679, 12.622319914948338, 11.656464790790556, 10.701631540877564, 9.766755617323035, 8.772644611214446, 7.982553905826968, 8.728670000578996, 9.68328283825819, 10.659563363532813, 11.586764276586688, 12.632460139624097, 13.471589425787236, 13.826879635896535, 12.862617586279324, 11.880574341544746, 10.8218628015354, 12.683721739741431, 13.659711986683833, 14.668778535563245, 14.541727075519512, 13.661965590056617, 12.709731408642053, 11.728112871733764, 10.709062321016258, 9.716203584190625, 9.053458224161432, 9.776362322251478, 10.710692571722968, 11.60151445529208, 12.6332249035623, 13.574207117530646, 14.50855586211112, 14.837955853994426, 13.810663126657248, 12.743139797360573, 11.710635770899803, 13.58285390915346, 14.596992332274395, 15.547959658834468, 15.54437564205984, 14.626010108082381, 13.64133326423253, 12.67692858177121, 11.720391303480376, 10.747997412100288, 10.030538369915229, 9.926747708845708, 10.786737737040752, 11.650847330268231, 12.58244143852512, 13.555044441703052, 14.601663530896618, 15.546873764810078, 14.644118731942767, 13.642931247401394, 12.579492767301591, 14.534487680322979, 15.508074580921585, 16.44062966564785, 15.513024843629095, 14.53032918112478, 13.546513593060784, 12.613771315089233, 11.737455088819143, 10.735937546071284, 9.879158448269942, 8.970050306190611, 9.767524811503334, 10.715799018290797, 11.70143629296866, 12.668704231237717, 13.610655487624411, 14.598236335536104, 15.556061063079053, 14.495102334994009, 13.508547345897803, 15.436361011971767, 16.47867072301333, 15.517133441719931, 14.566524306031734, 13.621716496292773, 12.548032196589798, 11.612701057429838, 10.667687170547545, 9.73807990272154, 8.952554095424388, 7.973554844298836, 8.74887512505778, 9.724511290407712, 10.668326995075738, 11.608112122937175, 12.607697588867476, 13.617392059443773, 14.589557668180024, 15.45029793245625, 14.562024700336238, 16.364046645605942, 15.553546159569294, 14.54345040222182, 13.561332795250479, 12.624726362758617, 11.598887618267128, 10.655028516740662, 9.702427074122967, 8.7248246119514, 7.915423152183683, 6.925829731865417, 7.746187747193634, 8.677109006321395, 9.70337516990729, 10.642091818077319, 11.613505104765501, 12.62712196822803, 13.538351618151372, 14.489543953302578, 15.51480021020026], [15.57165974239318, 14.592903848649351, 13.631183971252044, 12.676187421735744, 11.693493187603572, 10.690769460451877, 9.800452999385422, 8.804663128677129, 7.795627900176398, 6.945659985518292, 6.112328914055121, 6.9418953050654295, 7.871874990286476, 8.818737343949753, 9.762093564599986, 10.754859239778208, 11.630263495501502, 12.559467668372873, 13.577936040161282, 14.535875985619388, 14.607327349341055, 13.650033514971042, 12.693698203835181, 11.70370623259346, 10.670367888202877, 9.716940316881828, 8.75798698085874, 7.812475683542864, 6.867174461198638, 5.906609133419514, 5.042969984702343, 5.904063873833331, 6.956802552671336, 7.82154603795198, 8.854785199076744, 9.748755867105482, 10.59356368467315, 11.559642525143838, 12.58337698519773, 13.514756125607512, 13.638956926153531, 12.78965181898692, 11.786005642110851, 10.75551458452107, 9.700579632982587, 8.718922506902794, 7.762848421420576, 6.870955482318893, 5.886728399251199, 4.888802908474672, 4.016336261894775, 4.938656259190232, 5.946571573707896, 6.836584566891551, 7.829701920160619, 8.809357278670303, 9.622290060030467, 10.60989074909217, 11.569371368911678, 12.566519711290587, 12.670937618558446, 11.780240239321218, 10.826686664654746, 9.7670873982743, 8.713719084018667, 7.720545951803929, 6.7636548388642534, 5.848139552434739, 4.869072305765594, 3.910891245634642, 2.990867252736519, 3.9765097223149386, 4.96730731496907, 5.854828888551094, 6.867001734397649, 7.754333585607492, 8.685018965154097, 9.676507029798708, 10.603879187689294, 11.582539969511485, 11.739501936634339, 10.76924891448455, 9.833553650210817, 8.914783793851136, 7.855630280397002, 6.867645444078364, 5.796717730484099, 4.8989554729851195, 3.942507242873845, 2.896396635600153, 2.0613014236597085, 3.0237066080295865, 3.8946871953602002, 4.899671608247281, 5.815973865086733, 6.7976998855209185, 7.851251114369584, 8.764085595476384, 9.734520682774363, 10.665265002228228, 10.889669991147178, 9.875829660783296, 8.893805358430729, 7.937911718118639, 6.916224089329949, 5.891337056230132, 4.8438043213910875, 3.8679321886385556, 2.9013443658701115, 1.9586174169676882, 1.0623538673787156, 1.9917421668744373, 2.9456873775620185, 3.939444358170821, 4.888536997119079, 5.823937658672368, 6.827822166926477, 7.828246935458198, 8.77168564427794, 9.837604657352637, 9.99483376646471, 8.955199558546925, 7.955434567769809, 6.980708817170692, 5.991311496497105, 4.986093679098492, 4.061005727593794, 3.0941471267280107, 2.0991088766475476, 1.032234412533245, 0.0, 0.9331667631166239, 1.999080833520921, 2.9441622641224505, 3.9043971590063418, 4.869611702108389, 5.899252337758505, 6.942827260500106, 7.89517271112988, 8.849166039131452, 10.815714023238787, 9.781511280380391, 8.79864447833338, 7.83620918230385, 6.867582934157083, 5.884283704135462, 4.94819310019947, 3.97210911101236, 2.958346740152784, 2.0172017807129623, 1.067470744204412, 1.8725009783068027, 2.8431086305401276, 3.8029643607848316, 4.763978321029751, 5.815094574923711, 6.848078513154946, 7.850415216963301, 8.794522911043227, 9.803275019171197, 11.779426006760675, 10.706712581899767, 9.728688656482893, 8.821100881827055, 7.829213596527573, 6.8168825688831305, 5.907512307147442, 4.937267186091814, 3.9502762459535448, 2.957224426890478, 2.046572435386659, 2.8853860784522216, 3.804673924628273, 4.759901255797168, 5.788098853892365, 6.747310681119233, 7.700761563458135, 8.670057216669289, 9.626721016368407, 10.660539480111941, 12.705081328513915, 11.755898084463368, 10.741650938883584, 9.776182697580818, 8.846113756407517, 7.864291291021663, 6.8796193425853875, 5.941744278034393, 4.904462204887164, 3.962396501347113, 2.979774051551308, 3.909585522447, 4.807639804279999, 5.783762280709685, 6.7771981407960515, 7.704254912486575, 8.754508158248752, 9.63693745342425, 10.645845971135573, 11.63102772906151, 12.568574619922131, 12.76846895412225, 11.814445446873549, 10.748855603794112, 9.734711617243129, 8.800575668065193, 7.829691626736864, 6.861825873662904, 5.865317098290166, 4.950463628409225, 4.002679811722093, 4.9170571744972, 5.823403306379834, 6.769860591435199, 7.709232956626725, 8.681003238353318, 9.703653321367904, 10.647864244583987, 11.637758214375134, 12.558287167788606, 11.612523850741503, 12.578168827959685, 12.74216195003104, 11.707465942193384, 10.702459382455368, 9.728074120470431, 8.810335872114415, 7.79599325513888, 6.830183782841822, 5.906921614619062, 4.948629884175955, 5.905867987229486, 6.821110438262279, 7.741748073097877, 8.683373574032064, 9.674722585323327, 10.606637103579635, 11.579542305327568, 12.651168208549562, 12.745951705935141, 10.750897683455308, 11.721212549818967, 12.748209157842755, 12.688708391817608, 11.679319526402665, 10.735122640354895, 9.768583726722035, 8.809035132201297, 7.852643606217339, 6.891734324771162, 5.939188237767769, 6.841946884332465, 7.786214021746573, 8.706340483339384, 9.61011139601268, 10.559147121119885, 11.517165994358615, 12.459222496516066, 12.82183118849292, 11.88963351390126, 9.871230445025551, 10.93246629255962, 11.87863688217548, 12.876199706837657, 12.668780197636837, 11.673559318487948, 10.706734621618276, 9.802150443162514, 8.809756795393742, 7.867199074105358, 6.951878841588744, 7.803239828417759, 8.777242548489065, 9.735448566595485, 10.676188996873572, 11.562877891577278, 12.470039733096002, 13.089977568601999, 12.066303150433964, 11.061808368737681, 10.825056332243156, 11.885939743921824, 12.890738174508456, 13.835990352923448, 13.596813576656995, 12.630958452499215, 11.676125202586222, 10.741249279031694, 9.747138272923106, 8.94194853803842, 7.8951238557408185, 8.841627013612847, 9.817907538887466, 10.7354984328154, 11.687505009591604, 12.526634295754743, 13.53383964550847, 13.89485199881257, 12.912808754077991, 11.854097214068645, 11.69044856806241, 12.666438815004812, 13.675505363884223, 14.727344266812288, 14.636459251765274, 13.684225070350712, 12.702606533442424, 11.683555982724918, 10.690697245899285, 9.990455416941497, 8.9428161774133, 9.869036747077624, 10.759858630646733, 11.78465202613834, 12.629251987498153, 13.563600732078626, 14.54841127844455, 14.842897539190497, 13.775374209893823, 12.742870183433052, 12.617450150993573, 13.615864452703747, 14.56683177926382, 15.512785751776994, 14.575015046768225, 13.590338202918375, 12.656234163887747, 11.88870818808251, 10.937233567381885, 10.171877870022392, 9.982051849744233, 10.923282985450125, 11.691212676638779, 12.622806784895667, 13.5954097880736, 14.603992361864874, 15.516850570336477, 15.676353144476016, 14.675165659934644, 13.61172717983484, 13.569083922163092, 14.542670822761698, 15.48195601697454, 14.61747985182115, 13.634784189316834, 12.650968601252838, 11.718226323281286, 10.90550930298992, 9.903991760242059, 9.149890468184788, 10.002284718723857, 10.79975922403658, 11.748033430824043, 12.733670705501906, 13.700938643770963, 14.642889900157657, 15.63047074806935, 16.588295475612302, 15.527336747527258, 14.540781758431052, 14.47095725381188, 15.528224574402506, 14.595298390021734, 13.644689254333537, 12.726171504484828, 11.652487204781853, 10.717156065621891, 9.835741384718322, 8.906134116892314, 8.223286115339233, 9.005789256832081, 9.781109537591025, 10.756745702940957, 11.700561407608983, 12.640346535470421, 13.639932001400721, 14.649626471977019, 15.62179208071327, 16.482532344989497, 15.594259112869484, 15.398642887446057, 14.604726564946496, 13.602563940525702, 12.625575856437367, 11.71262405109553, 10.703342626459182, 9.759483524932715, 8.870481288293744, 7.892878826122175, 7.15158883495863, 7.958064144398662, 8.77842215972688, 9.70934341885464, 10.735609582440535, 11.674326230610564, 12.645739517298747, 13.659356380761276, 14.570586030684618, 15.521778365835823, 16.547034622733506], [16.504826505509804, 15.526070611765975, 14.564350734368668, 13.609354184852368, 12.626659950720196, 11.623936223568501, 10.733619762502045, 9.73419882082871, 8.725163592327979, 7.875195677669873, 6.973074173882746, 6.0087285419488055, 6.938708227169852, 7.885570580833129, 8.828926801483362, 9.821692476661584, 10.697096732384878, 11.62630090525625, 12.644769277044658, 13.602709222502764, 15.54049411245768, 14.583200278087666, 13.626864966951805, 12.636872995710084, 11.603534651319501, 10.650107079998453, 9.691153743975363, 8.742011375694444, 7.796710153350219, 6.836144825571095, 5.903715244529968, 4.970897110716707, 6.023635789554712, 6.888379274835356, 7.92161843596012, 8.815589103988858, 9.660396921556526, 10.626475762027214, 11.650210222081107, 12.581589362490888, 14.572123689270155, 13.722818582103544, 12.719172405227475, 11.688681347637694, 10.63374639609921, 9.652089270019419, 8.696015184537199, 7.804122245435517, 6.819895162367823, 5.821969671591296, 4.94745583191852, 4.005489496073608, 5.013404810591272, 5.903417803774927, 6.896535157043995, 7.876190515553678, 8.689123296913843, 9.676723985975546, 10.636204605795054, 11.633352948173963, 13.60410438167507, 12.713407002437842, 11.75985342777137, 10.700254161390925, 9.646885847135291, 8.653712714920553, 7.6968216019808775, 6.781306315551362, 5.802239068882217, 4.844058008751265, 3.9219868227602634, 3.0433429591983145, 4.034140551852446, 4.92166212543447, 5.933834971281024, 6.821166822490867, 7.7518522020374725, 8.743340266682084, 9.67071242457267, 10.649373206394861, 12.672668699750963, 11.702415677601174, 10.766720413327441, 9.847950556967762, 8.788797043513627, 7.800812207194988, 6.729884493600723, 5.832122236101743, 4.875674005990469, 3.8295633987167768, 2.992420993683453, 2.0905398449129624, 2.961520432243576, 3.9665048451306566, 4.8828071019701085, 5.864533122404294, 6.918084351252959, 7.830918832359759, 8.801353919657739, 9.732098239111604, 11.822836754263802, 10.80899642389992, 9.826972121547353, 8.871078481235264, 7.849390852446573, 6.824503819346756, 5.776971084507712, 4.801098951755179, 3.834511128986735, 2.891784180084312, 1.99347343740246, 1.0585754037578134, 2.0125206144453944, 3.006277595054197, 3.9553702340024546, 4.890770895555744, 5.894655403809853, 6.895080172341574, 7.838518881161315, 8.904437894236013, 10.928000529581336, 9.88836632166355, 8.888601330886434, 7.913875580287316, 6.924478259613729, 5.9192604422151165, 4.994172490710418, 4.027313889844635, 3.0322756397641712, 1.9654011756498688, 0.9331667631166239, 0.0, 1.0659140704042969, 2.0109955010058265, 2.9712303958897177, 3.9364449389917655, 4.966085574641882, 6.009660497383482, 6.962005948013256, 7.915999276014828, 11.721506634244061, 10.687303891385664, 9.704437089338652, 8.742001793309123, 7.773375545162356, 6.790076315140735, 5.853985711204743, 4.877901722017633, 3.8641393511580575, 2.9229943917182357, 1.9161078935211626, 0.9393342151901787, 1.9099418674235036, 2.8697975976682075, 3.8308115579131266, 4.881927811807087, 5.914911750038322, 6.9172484538466765, 7.861356147926603, 8.870108256054573, 12.685218617765948, 11.61250519290504, 10.634481267488166, 9.726893492832328, 8.735006207532846, 7.7226751798884035, 6.793126613498673, 5.822881492443045, 4.835890552304775, 3.842838733241708, 2.8877101673741055, 1.9522193153355976, 2.8715071615116488, 3.826734492680543, 4.8549320907757405, 5.814143918002609, 6.767594800341511, 7.7368904535526655, 8.693554253251783, 9.727372716995317, 12.579544855165556, 12.661690695468641, 11.647443549888857, 10.681975308586091, 9.75190636741279, 8.770083902026936, 7.7652336489366185, 6.80967056764567, 5.74559993687461, 4.80353423333456, 3.8209117835387545, 2.976418759330376, 3.8744730411633745, 4.85059551759306, 5.844031377679427, 6.771088149369951, 7.821341395132128, 8.703770690307627, 9.71267920801895, 10.697860965944885, 11.635407856805507, 12.671918176243135, 12.675515979669779, 11.604961665463975, 10.575849349230575, 9.64171340005264, 8.67082935872431, 7.702963605650351, 6.706454830277613, 5.791601360396672, 4.843817543709539, 3.9838904113805755, 4.890236543263209, 5.836693828318575, 6.7760661935101005, 7.747836475236694, 8.77048655825128, 9.714697481467363, 10.70459145125851, 11.625120404671982, 10.67935708762488, 11.64500206484306, 12.632860547860268, 12.54860367418083, 11.543597114442814, 10.569211852457878, 9.651473604101861, 8.637130987126326, 7.671321514829269, 6.748059346606508, 5.7897676161634015, 4.972701224112862, 5.887943675145654, 6.808581309981253, 7.75020681091544, 8.741555822206703, 9.67347034046301, 10.646375542210944, 11.718001445432938, 12.584433626721024, 9.817730920338684, 10.788045786702343, 11.815042394726131, 12.762918638823145, 12.52045725839011, 11.57626037234234, 10.609721458709481, 9.650172864188743, 8.693781338204785, 7.732872056758609, 6.780325969755215, 5.908780121215841, 6.853047258629949, 7.77317372022276, 8.676944632896056, 9.625980358003261, 10.583999231241991, 11.526055733399442, 12.525613124159106, 12.795426124906534, 8.938063681908927, 9.999299529442997, 10.945470119058855, 11.943032943721033, 12.937855685104042, 12.514697050475393, 11.547872353605722, 10.64328817514996, 9.650894527381189, 8.708336806092804, 7.793016573576191, 6.870073065301135, 7.844075785372442, 8.802281803478863, 9.743022233756948, 10.629711128460654, 11.536872969979378, 12.51127640580144, 12.99946991355059, 11.994975131854307, 9.891889569126532, 10.9527729808052, 11.957571411391832, 12.902823589806824, 13.899186209039806, 13.472096184486661, 12.517262934573669, 11.58238701101914, 10.58827600491055, 9.783086270025866, 8.736261587728265, 7.908460250496222, 8.884740775770844, 9.802331669698777, 10.75433824647498, 11.593467532638119, 12.600672882391846, 13.535119492537659, 13.845975517194615, 12.787263977185269, 10.757281804945785, 11.733272051888187, 12.7423386007676, 13.794177503695664, 14.61854769559033, 13.588773295392228, 12.671883110808569, 12.014123118468333, 11.035860632174924, 10.831593148928944, 9.783953909400747, 8.935869983960998, 9.82669186753011, 10.851485263021718, 11.696085224381529, 12.630433968962002, 13.615244515327927, 14.6055263552256, 14.708540973010447, 13.676036946549676, 11.684283387876949, 12.682697689587123, 13.633665016147196, 14.57961898866037, 13.641848283651601, 12.65717143980175, 11.723067400771123, 10.955541424965887, 10.00406680426526, 10.95597563107472, 10.823189581731679, 9.9901162223335, 10.758045913522157, 11.689640021779045, 12.662243024956977, 13.67082559874825, 14.583683807219852, 15.533571139450563, 15.608332423051268, 14.544893942951465, 12.635917159046468, 13.609504059645074, 14.548789253857915, 13.684313088704526, 12.70161742620021, 11.717801838136214, 10.785059560164662, 9.972342539873296, 8.970824997125435, 9.933988229237116, 10.876758997304908, 11.009329147870918, 11.69309422549959, 12.678731500177454, 13.730282272648406, 14.661833642020456, 15.54209985037032, 16.550987891936934, 16.460503510643882, 15.473948521547676, 13.537790490695256, 14.595057811285882, 13.66213162690511, 12.711522491216913, 11.793004741368204, 10.719320441665229, 9.783989302505267, 8.902574621601698, 7.97296735377569, 9.007383876391561, 9.935324948983663, 10.710645229742603, 11.686281395092537, 12.630097099760563, 13.569882227622001, 14.569467693552301, 15.579162164128599, 16.554958843829894, 17.41569910810612, 16.527425875986108, 14.465476124329433, 13.671559801829872, 12.669397177409078, 11.692409093320743, 10.779457287978905, 9.770175863342558, 8.826316761816091, 7.937314525177119, 6.959712063005551, 7.989358149347734, 8.887599836550244, 9.70795785187846, 10.63887911100622, 11.665145274592115, 12.607492993727188, 13.57890628041537, 14.5925231438779, 15.503752793801242, 16.454945128952446, 17.48020138585013], [17.525534377535724, 16.546778483791893, 15.585058606394586, 14.630062056878286, 13.597508640264738, 12.538014403683643, 11.583731517075712, 10.56666296800048, 9.55762773949975, 8.707659824841645, 7.8055383210545175, 6.841192689120577, 5.971108450681617, 6.819656510428832, 7.7630127310790655, 8.755778406257289, 9.631182661980583, 10.560386834851954, 11.578855206640362, 12.536795152098469, 16.561201984483596, 15.603908150113584, 14.647572838977723, 13.657580867736002, 12.62424252334542, 11.621416604873483, 10.608983168631692, 9.574475522866216, 8.62917430052199, 7.668608972742867, 6.736179391701739, 5.803361257888478, 4.9767513850799965, 5.822465204431059, 6.855704365555823, 7.749675033584562, 8.59448285115223, 9.560561691622919, 10.584296151676812, 11.515675292086593, 15.592831561296071, 14.743526454129462, 13.739880277253393, 12.709389219663612, 11.654454268125129, 10.672797142045336, 9.716723056563117, 8.814341007321971, 7.830113924254278, 6.832188433477751, 5.89782012402687, 4.837953643245379, 3.947490740186975, 4.83750373337063, 5.830621086639698, 6.810276445149382, 7.623209226509547, 8.610809915571249, 9.57029053539076, 10.567438877769668, 14.624812253700986, 13.734114874463758, 12.780561299797288, 11.720962033416843, 10.667593719161209, 9.674420586946471, 8.717529474006795, 7.802014187577281, 6.822946940908137, 5.864765880777185, 4.878598522843462, 3.875807106370085, 2.9682264814481494, 3.8557480550301735, 4.867920900876727, 5.755252752086571, 6.6859381316331765, 7.677426196277789, 8.604798354168375, 9.583459135990566, 13.693376571776879, 12.72312354962709, 11.787428285353359, 10.86865842899368, 9.809504915539545, 8.821520079220907, 7.750592365626642, 6.8528301081276615, 5.8963818780163875, 4.850271270742696, 3.949032693766652, 2.923003992084733, 1.8956063618392793, 2.9005907747263597, 3.816893031565812, 4.798619051999998, 5.852170280848663, 6.7650047619554625, 7.735439849253441, 8.666184168707307, 12.843544626289722, 11.82970429592584, 10.847679993573271, 9.891786353261182, 8.870098724472491, 7.845211691372674, 6.79767895653363, 5.821806823781098, 4.855219001012654, 3.912492052110231, 2.950085137485659, 2.0151871038410123, 0.9466065440410978, 1.9403635246498998, 2.8894561635981577, 3.8248568251514476, 4.8287413334055564, 5.829166101937277, 6.772604810757018, 7.838523823831717, 11.993914599985633, 10.954280392067847, 9.954515401290731, 8.979789650691613, 7.990392330018025, 6.9851745126194125, 6.060086561114714, 5.093227960248931, 4.098189710168468, 3.0313152460541657, 1.999080833520921, 1.0659140704042969, 0.0, 0.9450814306015296, 1.9053163254854208, 2.8705308685874686, 3.900171504237585, 4.943746426979185, 5.896091877608959, 6.850085205610531, 12.732983904767398, 11.698781161909, 10.715914359861989, 9.75347906383246, 8.784852815685692, 7.801553585664071, 6.865462981728079, 5.889378992540969, 4.875616621681393, 3.934471662241572, 2.927585164044499, 1.950811485713515, 0.9802038334801902, 1.940059563724894, 2.8314057356575604, 3.838358604652967, 4.863085555330936, 5.86542225913929, 6.809529953219217, 7.818282061347186, 12.553307233768686, 12.623982463428376, 11.645958538011502, 10.738370763355665, 9.746483478056183, 8.73415245041174, 7.716696048128834, 6.746450927073206, 5.759459986934936, 4.7664081678718695, 3.8112796020042667, 2.875788749965759, 1.9417691275683353, 2.8969964587372297, 3.8572799986489352, 4.816491825875803, 5.769942708214706, 6.73923836142586, 7.695902161124978, 8.729720624868511, 11.58189276303875, 12.531076007089297, 12.658920820412193, 11.693452579109428, 10.723779664746484, 9.738365232230098, 8.688803083566778, 7.733240002275831, 6.669169371504772, 5.727103667964721, 4.744481218168916, 3.899988193960538, 2.944735007220061, 3.9208574836497467, 4.851501242085526, 5.773436057243146, 6.823689303005323, 7.706118598180821, 8.715027115892145, 9.700208873818081, 10.637755764678701, 11.67426608411633, 12.562924958890953, 12.528531100094138, 11.499418783860738, 10.565282834682803, 9.594398793354474, 8.626533040280513, 7.6300242649077745, 6.715170795026833, 5.767386978339701, 4.907459846010737, 3.960498509319896, 4.906955794375261, 5.846328159566786, 6.750184383109889, 7.772834466124474, 8.717045389340557, 9.706939359131704, 10.627468312545178, 9.681704995498073, 10.647349972716254, 11.635208455733462, 12.692334893739982, 12.467166549072978, 11.492781287088041, 10.575043038732023, 9.560700421756488, 8.594890949459431, 7.67162878123667, 6.713337050793563, 5.896270658743024, 4.9582056412023405, 5.878843276037939, 6.820468776972126, 7.743903730079897, 8.675818248336205, 9.648723450084137, 10.720349353306132, 11.58678153459422, 8.765904725631298, 9.736219591994956, 10.763216200018745, 11.711092444115758, 12.762759658781324, 12.499829806972503, 11.533290893339643, 10.573742298818905, 9.617350772834946, 8.65644149138877, 7.703895404385377, 6.832349555846003, 5.9482326642056655, 6.843435686279446, 7.747206598952742, 8.696242324059947, 9.654261197298677, 10.596317699456128, 11.595875090215792, 12.528072764807453, 7.87214961150463, 8.9333854590387, 9.879556048654559, 10.877118873316736, 11.871941614699745, 12.867162493848634, 12.471441788235884, 11.566857609780122, 10.57446396201135, 9.631906240722966, 8.716586008206352, 7.7936424999312965, 6.939261190948159, 7.8725437695355485, 8.813284199813634, 9.69997309451734, 10.607134936036065, 11.581538371858125, 12.556594749864988, 13.060889202258604, 8.825975498722235, 9.886858910400903, 10.891657340987535, 11.836909519402527, 12.83327213863551, 13.576125842839428, 12.632450371260472, 12.030373048835719, 11.511845439540714, 10.706655704656027, 9.659831022358427, 8.832029685126383, 7.979926181346561, 8.872593635755463, 9.824600212531664, 10.663729498694805, 11.670934848448534, 12.605381458594344, 13.526280155689955, 13.807971849211189, 9.691367734541489, 10.66735798148389, 11.676424530363303, 12.728263433291367, 13.552633625186033, 12.522859224987931, 11.605969040404272, 11.0465233419801, 11.868324779346695, 11.755162583559105, 10.707523344030909, 9.85943941859116, 8.921877273105828, 9.921747229078404, 10.766347190438212, 11.700695935018686, 12.685506481384614, 13.675788321282285, 14.497623212150986, 14.696744818575592, 10.618369317472654, 11.616783619182826, 12.5677509457429, 13.513704918256073, 12.575934213247304, 11.591257369397454, 10.657153330366826, 9.987941648477653, 10.836530951437032, 11.788439778246492, 11.74675901636184, 10.82298908924914, 9.853231319097874, 10.784825427354763, 11.74013804781534, 12.741087564804934, 13.65394577327654, 14.603833105507249, 15.495168378687485, 15.56560181497738, 11.570003088642173, 12.543589989240779, 13.48287518345362, 12.618399018300229, 11.635703355795913, 10.651887767731917, 9.719145489760365, 9.004742763385062, 9.803289144297207, 10.766452376408887, 11.70922314447668, 11.736553837862772, 10.788279631075309, 11.773916905753172, 12.808177295506768, 13.73209560807714, 14.612361816427008, 15.621249857993622, 16.504436824655485, 16.494656393573592, 12.471876420290961, 13.529143740881587, 12.596217556500815, 11.645608420812618, 10.727090670963907, 9.653406371260932, 8.71807523210097, 7.934974845113463, 8.805431500947462, 9.839848023563333, 10.767789096155434, 11.543109376914376, 11.780711518852321, 12.724527223520347, 13.664312351381785, 14.663897817312085, 15.593206092519338, 16.57295079155486, 17.459632422117725, 17.548133748012024, 13.399562053925138, 12.605645731425577, 11.603483107004783, 10.626495022916448, 9.71354321757461, 8.704261792938262, 7.7604026914117945, 6.969714748688885, 7.792176210177322, 8.821822296519507, 9.720063983722016, 10.540421999050231, 11.471343258177992, 12.497609421763887, 13.44940807377211, 14.452957481869808, 15.466574345332337, 16.483519494519744, 17.43471182967095, 18.50090925787605], [18.470615808137254, 17.491859914393423, 16.530140036996116, 15.575143487479817, 14.542590070866268, 13.483095834285173, 12.528812947677242, 11.51174439860201, 10.50270917010128, 9.652741255443175, 8.750619751656046, 7.786274119722107, 6.885036639469302, 5.874575079827302, 6.817931300477536, 7.810696975655758, 8.686101231379052, 9.615305404250423, 10.633773776038831, 11.591713721496937, 17.50628341508513, 16.548989580715116, 15.592654269579254, 14.602662298337533, 13.56932395394695, 12.566498035475012, 11.554064599233222, 10.519556953467745, 9.57425573112352, 8.613690403344396, 7.681260822303269, 6.748442688490008, 5.921832815681526, 4.877383773829529, 5.910622934954294, 6.804593602983032, 7.6494014205507, 8.61548026102139, 9.639214721075282, 10.570593861485062, 16.5379129918976, 15.688607884730994, 14.684961707854924, 13.654470650265143, 12.59953569872666, 11.617878572646868, 10.661804487164648, 9.7594224379235, 8.775195354855807, 7.777269864079281, 6.8429015546283996, 5.783035073846909, 4.892572170788505, 3.8924223027691003, 4.885539656038168, 5.865195014547853, 6.678127795908018, 7.665728484969719, 8.625209104789228, 9.622357447168136, 15.569893684302516, 14.679196305065288, 13.72564273039882, 12.666043464018374, 11.61267514976274, 10.619502017548003, 9.662610904608327, 8.747095618178811, 7.768028371509667, 6.809847311378714, 5.823679953444992, 4.820888536971615, 3.913307912049679, 2.910666624428644, 3.922839470275197, 4.810171321485042, 5.740856701031647, 6.73234476567626, 7.659716923566845, 8.638377705389034, 14.638458002378409, 13.66820498022862, 12.732509715954889, 11.81373985959521, 10.754586346141075, 9.766601509822438, 8.695673796228172, 7.797911538729191, 6.841463308617917, 5.795352701344226, 4.894114124368182, 3.8680854226862627, 2.840687792440809, 1.9555093441248301, 2.8718116009642825, 3.853537621398468, 4.907088850247133, 5.819923331353933, 6.790358418651912, 7.7211027381057775, 13.788626056891252, 12.77478572652737, 11.7927614241748, 10.836867783862711, 9.815180155074021, 8.790293121974203, 7.74276038713516, 6.766888254382628, 5.8003004316141835, 4.857573482711761, 3.8951665680871885, 2.960268534442542, 1.8916879746426274, 0.9952820940483702, 1.944374732996628, 2.8797753945499176, 3.883659902804027, 4.8840846713357475, 5.827523380155489, 6.893442393230187, 12.938996030587163, 11.899361822669377, 10.89959683189226, 9.924871081293142, 8.935473760619555, 7.930255943220942, 7.0051679917162435, 6.03830939085046, 5.043271140769997, 3.9763966766556953, 2.9441622641224505, 2.0109955010058265, 0.9450814306015296, 0.0, 0.9602348948838911, 1.9254494379859388, 2.955090073636055, 3.9986649963776553, 4.951010447007429, 5.905003775009002, 12.58687653706884, 12.643862592510528, 11.660995790463517, 10.698560494433988, 9.72993424628722, 8.7466350162656, 7.810544412329609, 6.834460423142499, 5.820698052282923, 4.879553092843102, 3.8726665946460286, 2.8958929163150446, 1.9252852640817197, 1.0296696395654341, 1.8863243050560305, 2.8932771740514376, 3.9180041247294053, 4.920340828537761, 5.864448522617687, 6.873200630745656, 11.608225803167155, 12.649038882083527, 12.59103996861303, 11.683452193957192, 10.691564908657712, 9.67923388101327, 8.661777478730365, 7.691532357674736, 6.704541417536466, 5.711489598473399, 4.756361032605796, 3.8208701805672884, 2.886850558169865, 1.9866065345777697, 2.9121985680474056, 3.8714103952742738, 4.824861277613176, 5.794156930824331, 6.750820730523448, 7.7846391942669815, 10.63681133243722, 11.585994576487767, 12.600241722067551, 12.638534009710956, 11.668861095348014, 10.683446662831628, 9.63388451416831, 8.678321432877361, 7.614250802106302, 6.672185098566251, 5.689562648770446, 4.8450696245620675, 3.8898164378215907, 3.058151027749082, 3.9064198114839956, 4.828354626641616, 5.878607872403793, 6.761037167579292, 7.769945685290614, 8.75512744321655, 9.692674334077171, 10.7291846535148, 11.617843528289423, 12.688397842495228, 12.444500214462268, 11.510364265284332, 10.539480223956003, 9.571614470882043, 8.575105695509304, 7.660252225628363, 6.7124684089412305, 5.852541276612267, 4.9055799399214255, 4.0442493384745966, 4.928241965984594, 5.805102952508359, 6.827753035522944, 7.771963958739027, 8.761857928530175, 9.682386881943646, 8.736623564896544, 9.702268542114725, 10.690127025131932, 11.74725346313845, 12.752260022876467, 12.43786271768957, 11.520124469333552, 10.505781852358018, 9.539972380060961, 8.6167102118382, 7.658418481395093, 6.841352089344554, 5.90328707180387, 5.016136820137275, 5.924140286194502, 6.798822299478368, 7.730736817734676, 8.703642019482608, 9.775267922704602, 10.641700103992688, 7.820823295029768, 8.791138161393425, 9.818134769417213, 10.766011013514227, 11.817678228179794, 12.761875114227564, 12.478372323941175, 11.518823729420436, 10.562432203436478, 9.601522921990302, 8.648976834986907, 7.777430986447532, 6.893314094807195, 5.980729230378782, 6.850878108175118, 7.799913833282323, 8.757932706521053, 9.690255991941724, 10.689813382701388, 11.622011057293049, 6.927068180903101, 7.988304028437171, 8.93447461805303, 9.932037442715208, 10.926860184098217, 11.922081063247106, 12.656759521626888, 12.511939040381653, 11.519545392612882, 10.576987671324497, 9.661667438807882, 8.738723930532826, 7.884342621549688, 7.009837313634884, 7.91695570903601, 8.803644603739716, 9.710806445258441, 10.675476664343721, 11.650533042350585, 12.655027824046867, 7.880894068120705, 8.941777479799374, 9.946575910386008, 10.891828088800999, 11.888190708033981, 12.631044412237896, 11.687368940658942, 12.660726782822422, 12.456926870142244, 11.651737135257559, 10.604912452959956, 9.777111115727912, 8.92500761194809, 8.009887179854799, 8.92827172175404, 9.767401007917181, 10.77460635767091, 11.69931975107994, 12.620218448175551, 13.591131532985484, 8.746286303939959, 9.722276550882361, 10.731343099761773, 11.783182002689838, 12.607552194584503, 11.5777777943864, 10.660887609802742, 11.707666646660538, 12.675443850272265, 12.700244014160635, 11.652604774632438, 10.80452084919269, 9.866958703707356, 9.05904077317774, 9.870018699660589, 10.804367444241063, 11.78917799060699, 12.769726613767881, 13.591561504636582, 14.536345062222999, 9.673287886871123, 10.671702188581296, 11.62266951514137, 12.568623487654543, 11.630852782645773, 10.646175938795922, 9.712071899765297, 10.671256130982513, 11.643650022362602, 12.62406745840605, 12.69184044696337, 11.768070519850667, 10.798312749699402, 10.11365086360315, 10.843809557037716, 11.84475907402731, 12.757617282498916, 13.697771397992845, 14.58910667117308, 15.512794649033637, 10.624921658040641, 11.598508558639248, 12.537793752852089, 11.673317587698698, 10.690621925194382, 9.706806337130386, 8.774064059158835, 9.743205922511645, 10.73816775032496, 11.701330982436641, 12.644101750504433, 12.6816352684643, 11.733361061676836, 11.17919790839846, 11.911848804729145, 12.835767117299516, 13.716033325649384, 14.724921367215998, 15.598375117141082, 16.44184922762985, 11.52679498968943, 12.584062310280055, 11.651136125899283, 10.700526990211086, 9.782009240362374, 8.7083249406594, 7.772993801499441, 8.742485051427332, 9.740310106975215, 10.774726629591086, 11.712870526756964, 12.488190807515906, 12.725792949453849, 12.251085417127063, 12.972440913029686, 13.838725016056452, 14.696877601741715, 15.676622300777238, 16.55357071460332, 17.494741125796555, 12.454480623323606, 11.660564300824046, 10.658401676403251, 9.681413592314916, 8.768461786973079, 7.759180362336731, 6.815321260810265, 7.841681715713212, 8.737257640778852, 9.766903727121036, 10.665145414323545, 11.48550342965176, 12.416424688779522, 13.258058155960907, 13.944663068092321, 14.835280453016109, 15.71784835977646, 16.72782835080589, 17.571320810341597, 18.556387989018244], [18.497734284209734, 17.623838834586614, 16.700642702318063, 15.745646152801763, 14.827291887827394, 13.967984943367117, 13.489047842561133, 12.471979293485902, 11.462944064985171, 10.612976150327064, 9.710854646539937, 8.746509014605998, 7.816897019513915, 6.806435459871915, 6.108887060306694, 6.860191555909979, 7.735595811633273, 8.664799984504644, 9.683268356293052, 10.641208301751158, 17.42604852685671, 17.509224475599005, 16.552889164463146, 15.562897193221424, 14.529558848830842, 13.526732930358902, 12.514299494117111, 11.479791848351637, 10.534490626007411, 9.573925298228287, 8.64149571718716, 7.708677583373899, 6.85601896060713, 5.809244153874142, 5.061231519365252, 5.854088183237253, 6.69889600080492, 7.664974841275609, 8.688709301329503, 9.620088441739282, 16.420266739640066, 16.648842779614885, 15.645196602738816, 14.614705545149034, 13.559770593610551, 12.578113467530759, 11.62203938204854, 10.719657332807394, 9.7354302497397, 8.737504758963173, 7.803136449512291, 6.7432699687308, 5.852807065672396, 4.824282682813713, 4.036148240449126, 4.9146895948020735, 5.727622376162238, 6.715223065223939, 7.674703685043449, 8.671852027422357, 15.482152572940945, 15.63943119994918, 14.68587762528271, 13.626278358902265, 12.572910044646632, 11.579736912431894, 10.622845799492218, 9.707330513062702, 8.728263266393558, 7.770082206262606, 6.783914848328883, 5.781123431855506, 4.87354280693357, 3.842527004473257, 2.972334050529419, 3.859665901739262, 4.790351281285867, 5.7818393459304795, 6.709211503821065, 7.687872285643254, 14.550716891016839, 14.628439875112512, 13.69274461083878, 12.7739747544791, 11.714821241024966, 10.72683640470633, 9.655908691112064, 8.758146433613083, 7.801698203501808, 6.755587596228117, 5.854349019252073, 4.828320317570154, 3.8009226873247, 2.887369724169443, 1.9213061812185037, 2.903032201652689, 3.956177076061789, 4.859688436470042, 5.8301235237680205, 6.760867843221886, 13.566368137145462, 13.735020621411259, 12.752996319058692, 11.797102678746603, 10.775415049957912, 9.750528016858095, 8.702995282019051, 7.727123149266519, 6.760535326498075, 5.817808377595652, 4.85540146297108, 3.920503429326433, 2.8519228695265184, 1.942961952199107, 0.9938693132508493, 1.9195404996660266, 2.9234250079201356, 3.9238497764518563, 4.867288485271597, 5.933207498346296, 12.61119585620365, 12.859596717553268, 11.859831726776152, 10.885105976177034, 9.895708655503446, 8.890490838104833, 7.965402886600135, 6.998544285734352, 6.0035060356538885, 4.9366315715395865, 3.9043971590063418, 2.9712303958897177, 1.9053163254854208, 0.9602348948838911, 0.0, 0.9652145431020477, 1.994855178752164, 3.0384301014937645, 3.990775552123538, 4.94476888012511, 11.62664164218495, 12.659483257190663, 12.58266962704356, 11.62023433101403, 10.651608082867263, 9.668308852845643, 8.732218248909652, 7.756134259722542, 6.742371888862966, 5.801226929423144, 4.794340431226072, 3.8175667528950874, 2.8469591006617625, 1.8871033704170586, 0.9260894101721394, 1.9330422791675463, 2.957769229845515, 3.9601059336538698, 4.904213627733796, 5.912965735861765, 10.647990908283266, 11.688803987199638, 12.652969109584351, 12.605126030537235, 11.613238745237755, 10.600907717593312, 9.583451315310407, 8.61320619425478, 7.6262152541165085, 6.633163435053442, 5.678034869185839, 4.742544017147331, 3.8085243947499077, 2.844040265429394, 1.9519636731635144, 2.9111755003903825, 3.864626382729285, 4.833922035940439, 5.790585835639557, 6.82440429938309, 9.67657643755333, 10.625759681603876, 11.64000682718366, 12.621159909741742, 12.590534931928058, 11.605120499411672, 10.555558350748353, 9.599995269457404, 8.535924638686344, 7.593858935146294, 6.611236485350489, 5.76674346114211, 4.811490274401633, 3.9155847586007066, 2.9461849166001044, 3.8681197317577247, 4.918372977519902, 5.8008022726954005, 6.809710790406723, 7.794892548332659, 8.73243943919328, 9.768949758630908, 10.657608633405532, 11.728162947611336, 12.757275263844736, 12.432038101864375, 11.461154060536046, 10.493288307462086, 9.496779532089347, 8.581926062208405, 7.634142245521273, 6.77421511319231, 5.827253776501468, 4.901683069326221, 3.968007071100703, 4.844868057624468, 5.867518140639053, 6.811729063855136, 7.801623033646282, 8.722151987059757, 7.776388670012652, 8.742033647230834, 9.729892130248041, 10.78701856825456, 11.792025127992575, 12.769665768686815, 12.441798305913595, 11.42745568893806, 10.461646216641004, 9.53838404841824, 8.580092317975135, 7.763025925924596, 6.824960908383913, 5.8735705509889, 4.963905391310611, 5.838587404594477, 6.770501922850785, 7.743407124598717, 8.81503302782071, 9.681465209108799, 6.860588400145876, 7.830903266509534, 8.857899874533322, 9.805776118630336, 10.857443333295901, 11.801640219343671, 12.7758345323101, 12.440497566000477, 11.484106040016519, 10.523196758570343, 9.570650671566948, 8.699104823027575, 7.814987931387238, 6.838162961230407, 5.890643213291227, 6.839678938398432, 7.797697811637163, 8.730021097057833, 9.729578487817497, 10.661776162409158, 5.9668332860192095, 7.02806913355328, 7.974239723169139, 8.971802547831317, 9.966625289214326, 10.961846168363214, 11.951669165333058, 12.962993168338892, 12.441219229192923, 11.498661507904538, 10.583341275387923, 9.660397767112869, 8.806016458129731, 7.867271044486509, 6.956720814152119, 7.843409708855824, 8.75057155037455, 9.71524176945983, 10.690298147466695, 11.694792929162977, 6.920659173236814, 7.981542584915483, 8.986341015502116, 9.931593193917108, 10.92795581315009, 11.893810937307872, 12.619229320703557, 13.592587162867037, 13.378600706722285, 12.5734109718376, 11.526586289539997, 10.698784952307957, 9.794521823760299, 8.867320910706423, 7.96803682687015, 8.80716611303329, 9.814371462787019, 10.73908485619605, 11.659983553291662, 12.630896638101595, 7.786051409056068, 8.76204165599847, 9.771108204877882, 10.822947107805946, 11.783186714351944, 10.86873355421556, 11.592747989847355, 12.63952702670515, 13.607304230316878, 13.621917850740676, 12.57427861121248, 11.681641630099534, 10.736472915519565, 9.868880956363872, 8.909783804776698, 9.844132549357173, 10.828943095723098, 11.80949171888399, 12.631326609752692, 13.57611016733911, 8.722782467125343, 9.711467293697405, 10.662434620257478, 11.608388592770652, 10.921808542474933, 9.937131698625082, 10.64393227980991, 11.603116511027126, 12.575510402407215, 13.555927838450662, 13.613514283543411, 12.637584731662876, 11.667826961511611, 10.856177665331757, 9.883574662153825, 10.88452417914342, 11.797382387615023, 12.737536503108954, 13.628871776289191, 14.552559754149748, 9.674416238294862, 10.648003138893468, 11.58728833310631, 10.772897669089353, 9.926674007180162, 8.997762096959546, 9.705924439203448, 10.675066302556257, 11.670028130369573, 12.633191362481254, 13.575962130549046, 13.551149480276509, 12.602875273489046, 11.921724710127068, 10.951613909845253, 11.875532222415627, 12.755798430765491, 13.764686472332105, 14.638140222257192, 15.48161433274596, 10.57628956994365, 11.633556890534276, 10.700630706153504, 9.750021570465307, 8.866056022933531, 7.999280700488559, 8.704854181544054, 9.674345431471945, 10.672170487019828, 11.7065870096357, 12.673105421640853, 13.448425702399796, 13.595307161266058, 12.951991146007233, 12.012206018145795, 12.878490121172563, 13.736642706857822, 14.716387405893345, 15.593335819719433, 16.53450623091267, 11.503975203577827, 10.710058881078266, 9.707896256657472, 8.730908172569137, 7.817956367227301, 7.050136122165889, 7.747181640854878, 8.773542095757826, 9.697492535662743, 10.727138622004928, 11.625380309207435, 12.445738324535652, 13.376659583663413, 13.936226825216654, 12.98442817320843, 13.87504555813222, 14.757613464892566, 15.767593455921997, 16.611085915457707, 17.59615309413436], [17.574067436007237, 16.700171986384117, 15.785087381658634, 14.830090832142334, 13.970172981405762, 14.906500863380588, 14.45426238566318, 13.437193836587948, 12.428158608087218, 11.57819069342911, 10.676069189641984, 9.670603423120514, 8.740623737899469, 7.730162178257469, 6.993978299947681, 5.9846553049143205, 6.860059560637615, 7.789263733508986, 8.807732105297394, 9.7656720507555, 16.502381678654213, 17.447401636752158, 16.79256399252634, 15.802572021284618, 14.993298280806457, 14.491947473460948, 13.479514037219158, 12.445006391453683, 11.499705169109458, 10.539139841330334, 9.606710260289207, 8.673892126475947, 7.7797456789926835, 6.732970872259696, 5.984958237750805, 4.9785519322415945, 5.823359749809263, 6.789438590279952, 7.8131730503338455, 8.744552190743626, 15.496599891437567, 16.44232789726452, 16.61041114584086, 15.57992008825108, 14.524985136712598, 13.543328010632806, 12.587253925150586, 11.68487187590944, 10.700644792841747, 9.70271930206522, 8.768350992614337, 7.708484511832847, 6.7921859413661965, 5.748009401199267, 4.959874958834679, 4.039153343806415, 4.85208612516658, 5.839686814228282, 6.799167434047791, 7.796315776426701, 14.558485724738448, 15.52756905988956, 15.651092168384757, 14.591492902004312, 13.538124587748678, 12.54495145553394, 11.588060342594265, 10.672545056164749, 9.693477809495606, 8.735296749364654, 7.74912939143093, 6.746337974957553, 5.812921682627371, 4.766253722858811, 3.896060768914972, 2.984129650743604, 3.9148150302902094, 4.906303094934822, 5.833675252825407, 6.778946083766251, 13.627050042814341, 14.59730306496413, 14.657959153940826, 13.739189297581147, 12.680035784127012, 11.692050947808376, 10.62112323421411, 9.72336097671513, 8.766912746603856, 7.720802139330164, 6.81956356235412, 5.793534860672201, 4.7661372304267475, 3.8110964425549967, 2.8450328996040573, 2.027495950657031, 2.990962532959742, 3.8944738933679943, 4.864908980665973, 5.795653300119838, 12.642701288942964, 13.656541619306847, 13.718210862160738, 12.76231722184865, 11.740629593059959, 10.715742559960141, 9.668209825121098, 8.692337692368566, 7.725749869600122, 6.783022920697699, 5.820616006073127, 4.8857179724284805, 3.8171374126285658, 2.8666886705846606, 1.917596031636403, 0.9543259565639789, 1.9582104648180882, 2.958635233349809, 3.90207394216955, 4.967992955244249, 11.687529008001153, 12.692454394755273, 12.8250462698782, 11.850320519279082, 10.860923198605494, 9.855705381206882, 8.930617429702183, 7.9637588288364, 6.968720578755937, 5.901846114641634, 4.869611702108389, 3.936444938991765, 2.870530868587468, 1.9254494379859388, 0.9652145431020477, 0.0, 1.0296406356501162, 2.0732155583917167, 3.025561009021491, 3.979554337023063, 10.702974793982452, 11.735816408988166, 12.659346439531369, 12.585448874116079, 11.616822625969311, 10.633523395947691, 9.6974327920117, 8.72134880282459, 7.707586431965014, 6.766441472525193, 5.759554974328119, 4.782781295997135, 3.8121736437638103, 2.8523179135191064, 1.891303953274187, 0.9678277360654985, 1.992554686743467, 2.994891390551822, 3.9389990846317486, 4.947751192759718, 9.724324060080768, 10.76513713899714, 11.729302261381855, 12.65257487729301, 12.578453288339803, 11.56612226069536, 10.548665858412454, 9.578420737356826, 8.591429797218556, 7.59837797815549, 6.643249412287887, 5.707758560249379, 4.773738937851956, 3.809254808531442, 2.9171782162655617, 1.987508652187887, 2.9409595345267894, 3.9102551877379437, 4.866918987437061, 5.900737451180595, 8.752909589350834, 9.70209283340138, 10.716339978981164, 11.697493061539246, 12.729848895987748, 12.570335042513719, 11.520772893850399, 10.565209812559452, 9.501139181788393, 8.559073478248342, 7.576451028452537, 6.7319580042441585, 5.776704817503681, 4.880799301702755, 3.9113994597021517, 2.944452883555229, 3.9947061293174064, 4.877135424492905, 5.886043942204227, 6.8712257001301635, 7.808772590990785, 8.845282910428413, 9.707423906340322, 10.777978220546126, 11.794558350102768, 12.728694299280704, 12.426368603638094, 11.458502850564134, 10.461994075191395, 9.547140605310453, 8.599356788623322, 7.739429656294358, 6.7924683196035165, 5.854889159879814, 4.915516794688289, 3.921201209421972, 4.943851292436557, 5.88806221565264, 6.877956185443787, 7.79848513885726, 6.852721821810157, 7.791848920165624, 8.779707403182831, 9.821804025152513, 10.826810584890529, 11.804451225584769, 12.81048183201998, 12.392670232040109, 11.426860759743052, 10.503598591520289, 9.545306861077183, 8.728240469026645, 7.790175451485961, 6.826776641542493, 5.9114151148981975, 4.914920556391981, 5.846835074648289, 6.819740276396221, 7.891366179618215, 8.757798360906301, 5.895373857043829, 6.865688723407486, 7.8926853314312755, 8.84056157552829, 9.892228790193855, 10.836425676241625, 11.810619989208053, 12.770168583728791, 12.449320583118567, 11.488411301672391, 10.535865214668997, 9.664319366129623, 8.780202474489286, 7.791369051784, 6.838152936878814, 5.9825600319768, 6.882142490977733, 7.806354248855337, 8.805911639615001, 9.738109314206662, 5.001618742917163, 6.062854590451233, 7.009025180067092, 8.00658800472927, 9.00141074611228, 9.996631625261168, 10.986454622231012, 11.997778625236846, 12.990172273005617, 12.463876051006586, 11.548555818489971, 10.625612310214917, 9.77123100123178, 8.820477135040102, 7.904230537739705, 6.986290802434192, 7.83501622971512, 8.791574921257334, 9.766631299264198, 10.77112608096048, 5.955444630134767, 7.016328041813437, 8.02112647240007, 8.966378650815061, 9.962741270048044, 10.928596394205826, 11.883429644118818, 12.856787486282299, 13.896336864863475, 13.538625514939648, 12.491800832642046, 11.663999495410003, 10.747727914313892, 9.820527001260016, 8.90655274688362, 7.950047206611657, 8.89881614212759, 9.815418007993554, 10.736316705089164, 11.707229789899097, 6.8208368659540195, 7.7968271128964215, 8.805893661775833, 9.857732564703898, 10.817972171249895, 11.753824793856545, 12.51647470823291, 13.563253745090705, 14.531030948702432, 14.587132393842724, 13.539493154314528, 12.634847720653127, 11.689679006073158, 10.807396876377343, 9.848299724790168, 8.98701364293554, 9.913387775063669, 10.885824870681494, 11.707659761550195, 12.652443319136612, 7.813856265248339, 8.746252750595357, 9.69722007715543, 10.643174049668604, 10.102234528542642, 10.822222938266068, 11.567658998195464, 12.52684322941268, 13.499237120792769, 14.479654556836216, 14.57872882664546, 13.59079082221647, 12.621033052065204, 11.794693585345227, 10.822090582167295, 10.027405272721788, 10.881827066955594, 11.813869654906458, 12.705204928086694, 13.62889290594725, 8.765490036417859, 9.739076937016465, 10.678362131229306, 9.897361418093695, 9.051137756184504, 9.882853336600531, 10.629651157589002, 11.598793020941812, 12.593754848755127, 13.556918080866808, 14.4996888489346, 14.504355570830102, 13.556081364042639, 12.860240630140538, 11.890129829858724, 11.018413315993994, 11.840243110106062, 12.849131151672676, 13.714473374054695, 14.557947484543462, 9.700753318947994, 10.75802063953862, 9.825094455157846, 8.874485319469649, 7.990519771937873, 8.884371940129546, 9.628580899929608, 10.598072149857499, 11.595897205405382, 12.630313728021253, 13.609312979146805, 14.413640245501842, 14.548513251819651, 13.890507066020703, 12.950721938159266, 12.02137121475093, 12.821087386198393, 13.800832085233916, 14.669668971516936, 15.610839382710171, 10.62843895258217, 9.834522630082608, 8.832360005661814, 7.85537192157348, 6.942420116231642, 7.935227361806876, 8.670908359240432, 9.697268814143378, 10.62158694417726, 11.651233030519444, 12.590594852309481, 13.410952867637699, 14.34187412676546, 14.874742745230124, 13.9229440932219, 13.017926651710587, 13.842058144233137, 14.852038135262568, 15.68741906725521, 16.67248624593186], [16.603019198479945, 15.776148580091895, 14.881019514277913, 13.926022964761612, 14.865737142172307, 15.812449249635137, 15.483903021313298, 14.466834472238066, 13.457799243737336, 12.607831329079229, 11.705709825292102, 10.70024405877063, 9.770264373549585, 8.759802813907585, 7.893634877299518, 6.884311882266157, 5.8993689998019505, 6.828573172673321, 7.84704154446173, 8.804981489919836, 15.531333441126923, 16.476353399224866, 15.888496125145618, 14.898504153903897, 15.888862441573002, 15.521588109111066, 14.509154672869276, 13.474647027103801, 12.529345804759576, 11.568780476980452, 10.636350895939325, 9.703532762126065, 8.809386314642799, 7.762611507909812, 6.890806785009634, 5.878208509593431, 4.862669188973598, 5.828748029444287, 6.852482489498181, 7.77774176507577, 14.525551653910277, 15.471279659737228, 16.4749258366133, 15.926325810586187, 15.554625772362716, 14.572968646282924, 13.616894560800704, 12.714512511559558, 11.730285428491865, 10.732359937715337, 9.797991628264455, 8.738125147482965, 7.821826577016312, 6.777650036849383, 5.8746670348882, 4.938809921158252, 3.891395564330915, 4.878996253392616, 5.838476873212126, 6.8295053507588435, 13.557532346315192, 14.526615681466303, 15.563734261943539, 15.62113353765443, 14.567765223398796, 13.574592091184059, 12.617700978244383, 11.702185691814867, 10.723118445145724, 9.764937385014772, 8.778770027081048, 7.7759786106076705, 6.842562318277486, 5.795894358508926, 4.810852844968493, 3.884809849001149, 2.9541244694545443, 3.9456125340991566, 4.872984691989742, 5.7889045780377275, 12.626096664391085, 13.596349686540874, 14.532044950814605, 14.768829933231265, 13.70967641977713, 12.721691583458494, 11.650763869864228, 10.753001612365248, 9.796553382253974, 8.750442774980282, 7.849204198004237, 6.823175496322318, 5.795777866076865, 4.8407370782051125, 3.8746735352541735, 3.0571365863071476, 2.016628745699041, 2.9044323876394698, 3.874867474937449, 4.805611794391314, 11.641747910519708, 12.65558824088359, 13.603967350698394, 13.791957857498767, 12.770270228710077, 11.745383195610259, 10.697850460771216, 9.721978328018684, 8.75539050525024, 7.812663556347816, 6.850256641723244, 5.915358608078598, 4.846778048278683, 3.896329306234777, 2.947236667286519, 1.9839665922140952, 0.9838766775573875, 1.9685937276212844, 2.9120324364410255, 3.9383523195941317, 10.686575629577897, 11.691501016332019, 12.608767604328163, 12.879961154929196, 11.890563834255609, 10.885346016856996, 9.960258065352297, 8.993399464486515, 7.998361214406053, 6.931486750291751, 5.899252337758506, 4.966085574641882, 3.900171504237585, 2.9550900736360552, 1.994855178752164, 1.0296406356501162, 0.0, 1.0435749227416005, 1.9959203733713744, 2.9499137013729464, 9.702021415559196, 10.734863030564911, 11.658393061108113, 12.620828357137642, 12.646463261619425, 11.663164031597805, 10.727073427661814, 9.750989438474704, 8.737227067615128, 7.796082108175307, 6.7891956099782345, 5.8124219316472505, 4.841814279413926, 3.8819585491692226, 2.9209445889243035, 1.9958979893245863, 0.9629140510933507, 1.9652507549017055, 2.9093584489816324, 3.9181105571096015, 8.723370681657512, 9.764183760573886, 10.7283488829586, 11.651621498869753, 12.689405686791812, 12.595762896345475, 11.578306494062572, 10.608061373006944, 9.621070432868674, 8.628018613805606, 7.672890047938003, 6.737399195899495, 5.803379573502071, 4.838895444181558, 3.8526688656693038, 2.8934570384424356, 1.940006156103533, 2.9093018093146874, 3.865965609013805, 4.899784072757338, 7.7519562109275775, 8.701139454978124, 9.715386600557908, 10.69653968311599, 11.700208260337632, 12.685622692854018, 12.550413529500517, 11.594850448209566, 10.530779817438507, 9.588714113898456, 8.606091664102651, 7.761598639894274, 6.8063454531537975, 5.83201722679108, 4.838581366704713, 3.850401269809778, 2.9997522432353687, 3.8761820460696486, 4.885090563780971, 5.870272321706907, 6.807819212567528, 7.836073474426335, 8.677783270690206, 9.74833758489601, 10.764917714452652, 11.699053663630588, 12.669937704958917, 12.488143486214248, 11.49163471084151, 10.576781240960567, 9.628997424273436, 8.711794000794102, 7.726601839118351, 6.760837546134363, 5.8214651809428375, 4.827149595676521, 3.94889740635452, 4.887108837229384, 5.8770028070205305, 6.797531760434004, 5.8517684433869, 6.762208284515507, 7.750066767532715, 8.792163389502397, 9.797169949240413, 10.774810589934653, 11.780841196369865, 12.7951838133454, 12.456501395393166, 11.533239227170403, 10.574947496727297, 9.699443938282378, 8.724308971000797, 7.732725027797041, 6.817363501152746, 5.82086894264653, 4.942767207267566, 5.895716870103999, 6.95135483061741, 7.756844982483045, 4.865733221393713, 5.83604808775737, 6.863044695781159, 7.810920939878173, 8.86258815454374, 9.80678504059151, 10.780979353557939, 11.740527948078677, 12.696919474062636, 12.518051937322506, 11.565505850319111, 10.635522835385357, 9.714335994004122, 8.697317438038548, 7.744101323133362, 6.888508418231349, 5.97807462359701, 6.882330842563115, 7.881888233322778, 8.783998574571182, 3.971978107267046, 5.033213954801116, 5.979384544416975, 6.976947369079152, 7.971770110462161, 8.96699098961105, 9.956813986580894, 10.968137989586728, 11.9605316373555, 12.994066493654824, 12.578196454140086, 11.596815779470651, 10.705364520746615, 9.726425521294649, 8.810178923994254, 7.892239188688741, 6.930948362334397, 7.867551514965113, 8.842607892971976, 9.831832611738918, 4.92580399448465, 5.98668740616332, 6.991485836749952, 7.936738015164944, 8.933100634397928, 9.898955758555708, 10.8537890084687, 11.82714685063218, 12.866696229213357, 13.894056991621966, 13.52144146829216, 12.635202964665737, 11.653676300568439, 10.726475387514563, 9.812501133138168, 8.855995592866206, 7.994748274746867, 8.891394601701332, 9.812293298796943, 10.767936320677535, 5.830795360225496, 6.806785607167898, 7.81585215604731, 8.864272204374776, 9.824511810920773, 10.854286211118875, 11.880270339324902, 12.8109965574878, 13.803855294313433, 14.748904586086377, 14.569133789964642, 13.540796106907674, 12.595627392327705, 11.713345262631892, 10.754248111044717, 9.892962029190087, 9.009319907682947, 9.961801464389273, 10.783636355257974, 11.713149849915048, 6.8238147595198155, 7.756211244866834, 8.707178571426908, 9.653132543940082, 10.665446292986298, 11.650123136836148, 12.59729963384558, 13.556483865062797, 14.528877756442885, 15.509295192486332, 15.54067217129489, 14.496739208471016, 13.526981438319751, 12.700641971599776, 11.728038968421844, 10.922969433488333, 9.977759199574873, 10.889846248614237, 11.781181521794473, 12.689599436725686, 7.775448530689334, 8.749035431287941, 9.688320625500783, 8.936670857258031, 9.919220552619578, 10.782509913952369, 11.659291793239118, 12.628433656591927, 13.623395484405243, 14.586558716516924, 15.529329484584716, 15.410303957084649, 14.462029750297186, 13.766189016395087, 12.796078216113273, 11.91397747676054, 10.93617524272534, 11.945063284291955, 12.790449967762473, 13.618654015321898, 8.733942893280139, 9.791210213870764, 8.864403894322182, 7.913794758633985, 8.858602568372946, 9.784028517481383, 10.658221535579724, 11.627712785507615, 12.625537841055499, 13.65995436367137, 14.638953614796922, 15.44328088115196, 15.454461638074198, 14.796455452275252, 13.856670324413814, 12.916935375517475, 11.917019518817671, 12.896764217853194, 13.745645565224715, 14.683187152619801, 9.661628526914315, 8.873832069246944, 7.87166944482615, 6.894681360737815, 7.831287793229677, 8.834883939158713, 9.700548994890548, 10.726909449793496, 11.651227579827376, 12.68087366616956, 13.620235487959599, 14.440593503287817, 15.371514762415577, 15.780691131484673, 14.82889247947645, 13.913490812477132, 12.937990276852416, 13.947970267881846, 14.763395660962988, 15.744834015841489], [15.603966447664764, 14.77709582927671, 13.947570304392054, 14.756333838012592, 15.696048015423287, 16.64713184873066, 16.47954310711792, 15.462474558042688, 14.453439329541958, 13.603471414883852, 12.612127766438046, 11.56852710226707, 10.638547417046025, 9.628085857404026, 8.684729636753792, 7.675406641720431, 6.6904637592562235, 6.0980508336535975, 6.898096383203533, 7.793408718633954, 14.53228069031174, 15.477300648409683, 14.987735957072829, 15.728815027154877, 16.719173314823983, 16.51722819491569, 15.5047947586739, 14.470287112908423, 13.524985890564198, 12.564420562785074, 11.631990981743947, 10.699172847930686, 9.6896265404985, 8.642851733765513, 7.681901544463908, 6.669303269047705, 5.653763948427871, 5.040392851553187, 5.848595518319238, 6.734166842334168, 13.526498903095094, 14.472226908922044, 15.475873085798113, 16.50312616507276, 16.56211812359736, 15.580460997517568, 14.624386912035348, 13.710152597364178, 12.725925514296485, 11.728000023519957, 10.793631714069077, 9.733765233287587, 8.702066802872013, 7.6578902627050836, 6.665761794342474, 5.729904680612526, 4.6824903237851885, 3.972875023385358, 4.809927510371678, 5.785930428017242, 12.558479595500009, 13.52756293065112, 14.555255937012179, 15.488507341865805, 15.57525757463344, 14.582084442418703, 13.625193329479027, 12.70967804304951, 11.730610796380367, 10.772429736249414, 9.786262378315692, 8.771618696412293, 7.722802544133187, 6.676134584364627, 5.601947604422767, 4.675904608455423, 3.7452192289088178, 2.935020490911697, 3.8444353291492948, 4.745329655296127, 11.627043913575902, 12.59729693572569, 13.523566625883245, 14.540971913025576, 14.717168771011774, 13.729183934693138, 12.658256221098872, 11.760493963599892, 10.804045733488618, 9.757935126214925, 8.856696549238881, 7.830667847556962, 6.803270217311509, 5.786098567656531, 4.820035024705591, 3.861274734001979, 2.8077235051533145, 1.8608574648978695, 2.8312925521958485, 3.762036871649714, 10.642695159704525, 11.656535490068407, 12.583818334103157, 13.539711974415246, 13.77776257994472, 12.752875546844903, 11.70534281200586, 10.729470679253328, 9.762882856484884, 8.82015590758246, 7.857748992957888, 6.922850959313242, 5.854270399513327, 4.841690795686195, 3.8925981567379373, 2.9293280816655134, 1.9254435734114044, 0.9250188048796839, 1.868457513699425, 2.8947773968525317, 9.687522878762714, 10.671351999736782, 11.588618587732926, 12.563344338332044, 12.93413875699721, 11.928920939598598, 11.0038329880939, 10.036974387228117, 9.041936137147653, 7.975061673033351, 6.942827260500106, 6.009660497383482, 4.943746426979185, 3.9986649963776557, 3.0384301014937645, 2.0732155583917167, 1.0435749227416005, 0.0, 0.9523454506297739, 1.906338778631346, 8.702968664744013, 9.714714013969674, 10.638244044512875, 11.600679340542404, 12.569305588689172, 12.706738954339407, 11.770648350403416, 10.794564361216306, 9.78080199035673, 8.839657030916909, 7.832770532719835, 6.855996854388851, 5.885389202155527, 4.925533471910823, 3.964519511665904, 2.978338172881788, 1.9453542346505523, 0.9430175308421975, 1.8871252249221242, 2.8958773330500938, 7.724317930842329, 8.744034743978649, 9.708199866363362, 10.631472482274516, 11.669256670196575, 12.681587697841017, 12.57256280099144, 11.602317679935812, 10.615326739797542, 9.622274920734476, 8.667146354866873, 7.731655502828366, 6.797635880430942, 5.820405019371626, 4.792207421276429, 3.832995594049561, 2.8795447117106585, 1.9102490584995042, 2.8458165924185677, 3.879635056162101, 6.73180719433234, 7.680990438382887, 8.69523758396267, 9.676390666520753, 10.677975036278124, 11.66338946879451, 12.712138365623835, 12.589106755138436, 11.525036124367377, 10.582970420827326, 9.600347971031521, 8.755854946823144, 7.747678258827891, 6.771555782398205, 5.778119922311839, 4.789939825416903, 3.8300631164863512, 2.8771292952544654, 3.886037812965788, 4.871219570891724, 5.787670195972291, 6.813840250366828, 7.655550046630699, 8.726104360836503, 9.742684490393144, 10.67682043957108, 11.647704480899408, 12.615570233973369, 12.48589101777038, 11.571037547889437, 10.599808608149775, 9.651332556401227, 8.666140394725476, 7.7003761017414885, 6.761003736549963, 5.766688151283646, 4.779208279605502, 3.888056086414201, 4.877950056205347, 5.798479009618821, 4.831619426791663, 5.739975060456, 6.727833543473207, 7.769930165442888, 8.774936725180904, 9.752577365875144, 10.758607972310356, 11.772950589285891, 12.73185311046594, 12.527495534099273, 11.545758680603637, 10.638982493889502, 9.66384752660792, 8.672263583404167, 7.7486407618262705, 6.704992598774855, 5.773078080518547, 4.896664119288816, 5.952302079802227, 6.757792231667862, 3.843499997334205, 4.813814863697862, 5.840811471721651, 6.788687715818664, 7.840354930484231, 8.784551816532002, 9.75874612949843, 10.718294724019168, 11.674686250003127, 12.635595531449303, 12.510531520848092, 11.57506139099248, 10.653874549611245, 9.636855993645673, 8.675378583806888, 7.766404370086723, 6.8083854968479915, 5.883278091747932, 6.882835482507595, 7.784945823755999, 2.9284031845254455, 3.9896390320595154, 4.935809621675374, 5.933372446337551, 6.9281951877205605, 7.923416066869448, 8.913239063839292, 9.924563066845126, 10.916956714613898, 11.950491570913222, 12.880342584130322, 12.536354335077775, 11.644903076353739, 10.641691561746269, 9.671489466428348, 8.726921787784264, 7.761259235585379, 6.86849876414993, 7.843555142156792, 8.832779860923734, 3.88222907174305, 4.943112483421719, 5.947910914008351, 6.893163092423343, 7.889525711656327, 8.855380835814108, 9.8102140857271, 10.78357192789058, 11.823121306471757, 12.850482068880364, 13.823587598282396, 13.564364945066604, 12.568942341020058, 11.641741427966183, 10.64718373223369, 9.690678191961728, 8.825059147997848, 7.892341850886149, 8.813240547981758, 9.768883569862352, 4.787220437483896, 5.763210684426298, 6.77227723330571, 7.8206972816331755, 8.780936888179172, 9.810711288377274, 10.8366954165833, 11.7674216347462, 12.760280371571833, 13.705329663344777, 14.752968902872974, 14.456062147359294, 13.510893432779325, 12.548027861727414, 11.58893071014024, 10.72764462828561, 9.839630780933927, 8.96274871357409, 9.784583604442789, 10.714097099099867, 5.780239836778215, 6.712636322125234, 7.663603648685308, 8.609557621198482, 9.621871370244698, 10.606548214094548, 11.650873895530905, 12.610058126748122, 13.58245201812821, 14.562869454171658, 15.636942207157148, 15.412005248922636, 14.442247478771371, 13.535324570695298, 12.562721567517366, 11.753280306739313, 10.808070072825853, 9.890793497799054, 10.782128770979288, 11.690546685910505, 6.731873607947733, 7.70546050854634, 8.644745702759181, 9.572350524777937, 10.555046187282253, 11.538861775346248, 12.505690461930177, 13.474832325282986, 14.49061569125086, 15.454841760013364, 16.397612528081154, 16.325569997536267, 15.377295790748805, 14.60087161549061, 13.630760815208795, 12.74428835001152, 11.76648611597632, 10.953254320656345, 11.791397216947288, 12.619601264506716, 7.690367970538536, 8.747635291129162, 8.2020191896075, 8.704889518088258, 9.64969732782722, 10.575123276935656, 11.526504579076164, 12.495995829004055, 13.493820884551939, 14.52823740716781, 15.507236658293362, 16.43326838519369, 16.369727678525816, 15.631138051370774, 14.691352923509337, 13.747246248768455, 12.747330392068651, 11.956962194930828, 12.74659281440953, 13.68413440180462, 8.618053604172712, 7.924886907988746, 7.141147105806425, 7.685776120192088, 8.62238255268395, 9.625978698612986, 10.568832038386988, 11.595192493289936, 12.519510623323816, 13.549156709666, 14.555421373938769, 15.436233589092438, 16.3671548482202, 16.615373730580195, 15.663575078571972, 14.743801685728112, 13.768301150103396, 13.00816824495948, 13.764342910147803, 14.745781265026308], [14.708767967884931, 14.042481902559583, 14.899915755021826, 15.708679288642367, 16.64839346605306, 17.599477299360434, 17.431888557747694, 16.41482000867246, 15.405784780171729, 14.555816865513624, 13.564473217067821, 12.520872552896845, 11.5908928676758, 10.5804313080338, 9.637075087383566, 8.627752092350205, 7.642809209885997, 7.037098668088619, 6.018630296300211, 6.913942631730633, 13.637082210531908, 14.58210216862985, 15.538437479765712, 16.528429451007433, 17.47866291943636, 17.46957364554546, 16.45714020930367, 15.422632563538194, 14.477331341193969, 13.516766013414845, 12.584336432373718, 11.651518298560458, 10.64197199112827, 9.595197184395284, 8.63424699509368, 7.621648719677478, 6.606109399057645, 5.9927383021829606, 4.969129431415916, 5.854700755430847, 12.631300423315261, 13.577028429142212, 14.580674606018281, 15.585348842720663, 16.50887466421607, 16.53280644814734, 15.576732362665123, 14.66249804799395, 13.678270964926256, 12.680345474149728, 11.745977164698848, 10.686110683917358, 9.654412253501786, 8.610235713334855, 7.618107244972248, 6.682250131242299, 5.634835774414962, 4.9252204740151315, 3.9304614234683566, 4.906464341113921, 11.663281115720176, 12.632364450871288, 13.63747861466008, 14.570730019513707, 15.447301509933059, 15.534429893048477, 14.577538780108801, 13.662023493679285, 12.682956247010141, 11.724775186879189, 10.738607828945465, 9.723964147042064, 8.675147994762959, 7.6284800349944, 6.554293055052541, 5.628250059085197, 4.6975646795385915, 3.8873659415414705, 2.964969242245973, 3.865863568392805, 10.73184543379607, 11.702098455945858, 12.605789303531147, 13.623194590673478, 14.48644598018146, 14.681529385322913, 13.610601671728647, 12.712839414229666, 11.756391184118392, 10.7102805768447, 9.809041999868654, 8.783013298186738, 7.755615667941283, 6.738444018286305, 5.772380475335366, 4.813620184631754, 3.7600689557830886, 2.8132029155276435, 1.9518264652925268, 2.882570784746392, 9.747496679924692, 10.761337010288575, 11.666041011751059, 12.621934652063148, 13.547039789114406, 13.705220997474678, 12.657688262635634, 11.681816129883103, 10.715228307114659, 9.772501358212235, 8.810094443587662, 7.875196409943016, 6.8066158501431016, 5.79403624631597, 4.8449436073677115, 3.8816735322952876, 2.8777890240411783, 1.8773642555094578, 0.9889914267961033, 1.9424319462227575, 8.792324398982881, 9.753574677384684, 10.670841265380828, 11.645567015979946, 12.602300258537328, 12.881266390228372, 11.956178438723674, 10.989319837857892, 9.994281587777428, 8.927407123663125, 7.89517271112988, 6.962005948013256, 5.896091877608959, 4.951010447007429, 3.9907755521235386, 3.025561009021491, 1.9959203733713744, 0.9523454506297739, 0.0, 0.9539933280015721, 7.80777018496418, 8.796936691617576, 9.720466722160777, 10.682902018190306, 11.651528266337074, 12.634827496358694, 12.722993801033189, 11.746909811846079, 10.733147440986503, 9.792002481546682, 8.785115983349609, 7.808342305018626, 6.837734652785302, 5.877878922540598, 4.916864962295678, 3.9306836235115616, 2.897699685280326, 1.8953629814719715, 1.0075405400412976, 1.9720632126901756, 6.829119451062495, 7.82625742162655, 8.790422544011264, 9.713695159922418, 10.751479347844477, 11.76381037548892, 12.760431280701862, 12.554663130565586, 11.567672190427317, 10.574620371364249, 9.619491805496645, 8.684000953458138, 7.749981331060716, 6.7727504700014, 5.744552871906203, 4.785341044679335, 3.8318901623404322, 2.862594509129278, 1.966231907537741, 2.9833754473253267, 5.814029871980242, 6.763213116030789, 7.777460261610573, 8.758613344168655, 9.754160915918206, 10.739575348434592, 11.788324245263917, 12.735870793012607, 12.47738157499715, 11.5353158714571, 10.552693421661294, 9.708200397452917, 8.700023709457664, 7.723901233027979, 6.730465372941612, 5.742285276046677, 4.782408567116125, 3.829474745884239, 3.0287473237438753, 3.9760210911118903, 4.869892873620194, 5.89002613000691, 6.731735926270781, 7.8022902404765855, 8.818870370033226, 9.753006319211162, 10.72389036053949, 11.691756113613451, 12.68826488898619, 12.52338299851921, 11.552154058779548, 10.603678007031, 9.618485845355249, 8.652721552371261, 7.713349187179737, 6.71903360191342, 5.731553730235277, 4.840401537043975, 4.025576022885911, 4.903280529838987, 3.9138421044395657, 4.816160940096082, 5.8040194231132896, 6.846116045082971, 7.851122604820986, 8.828763245515226, 9.834793851950439, 10.849136468925973, 11.808038990106022, 12.746400187825989, 12.49810413123341, 11.591327944519275, 10.616192977237693, 9.62460903403394, 8.700986212456046, 7.65733804940463, 6.725423531148322, 5.849009569918589, 5.099928046482789, 5.862593751888029, 2.919685876974287, 3.8900007433379447, 4.916997351361733, 5.8648735954587465, 6.916540810124313, 7.860737696172083, 8.834932009138512, 9.79448060365925, 10.75087212964321, 11.711781411089385, 12.66432749809278, 12.527406841622254, 11.606220000241018, 10.589201444275446, 9.627724034436662, 8.718749820716496, 7.760730947477766, 6.835623542377705, 6.148221555790467, 6.8897473439761665, 1.9760577338956717, 3.0372935814297417, 3.983464171045601, 4.9810269957077775, 5.975849737090787, 6.971070616239675, 7.960893613209518, 8.972217616215351, 9.964611263984123, 10.998146120283447, 11.927997133500547, 12.954959848439287, 12.597248526983511, 11.594037012376043, 10.623834917058122, 9.679267238414038, 8.713604686215152, 7.8208442147797035, 7.108941215439665, 7.937581381143903, 2.929883621113276, 3.990767032791945, 4.995565463378578, 5.940817641793569, 6.937180261026553, 7.903035385184334, 8.857868635097326, 9.831226477260806, 10.870775855841982, 11.89813661825059, 12.871242147652621, 13.907303408874236, 13.521287791649833, 12.594086878595958, 11.599529182863465, 10.643023642591503, 9.777404598627621, 8.844687301515922, 8.07862662126463, 8.873685090082521, 3.907754350580574, 4.883744597522977, 5.892811146402389, 6.868351831003402, 7.828591437549399, 8.858365837747503, 9.884349965953525, 10.815076184116425, 11.807934920942058, 12.752984212715003, 13.8006234522432, 14.840309001076424, 14.4632388834091, 13.500373312357189, 12.541276160770014, 11.679990078915385, 10.791976231563702, 9.915094164203863, 9.049969677725661, 9.818898619320034, 4.900773749874893, 5.833170235221913, 6.7841375617819875, 7.730091534295161, 8.742405283341377, 9.727082127191228, 10.771407808627584, 11.730592039844801, 12.70298593122489, 13.683403367268337, 14.757476120253827, 15.8014090830777, 15.394592929401146, 14.487670021325073, 13.51506701814714, 12.705625757369088, 11.760415523455627, 10.843138948428827, 10.04751484426216, 10.795348206130672, 5.8524075210444115, 6.825994421643019, 7.765279615855859, 8.692884437874616, 9.675580100378932, 10.659395688442928, 11.626224375026856, 12.595366238379665, 13.611149604347538, 14.635101530184796, 15.577872298252588, 16.556863259181696, 16.32964124137858, 15.553217066120384, 14.58310626583857, 13.696633800641294, 12.718831566606095, 11.905599771286118, 11.056783290230161, 11.724402784726884, 6.810901883635215, 7.8681692042258415, 8.811545539204696, 9.657234968718033, 10.602042778456994, 11.52746872756543, 12.478850029705939, 13.44834127963383, 14.446166335181713, 15.480582857797584, 16.459582108923136, 17.385613835823463, 17.322073129155594, 16.58348350200055, 15.643698374139111, 14.69959169939823, 13.699675842698426, 12.9093076455606, 12.011978887692402, 12.788935922024788, 7.738587517269391, 7.0454208210854254, 8.055516578432899, 8.638121570821863, 9.574728003313725, 10.57832414924276, 11.521177489016763, 12.54753794391971, 13.47185607395359, 14.501502160295775, 15.507766824568543, 16.38857903972221, 17.31950029884997, 17.56771918120997, 16.615920529201748, 15.696147136357887, 14.72064660073317, 13.960513695589253, 13.029728983430676, 13.850582785246475], [13.754774639883358, 14.570979174306586, 15.609046217257372, 16.546917312148143, 17.547794890835487, 18.456704822794176, 18.385881885749267, 17.368813336674034, 16.359778108173302, 15.509810193515197, 14.518466545069392, 13.474865880898417, 12.544886195677371, 11.534424636035371, 10.591068415385138, 9.581745420351776, 8.59680253788757, 7.991091996090191, 6.972623624301783, 6.017253022882826, 12.683088882530335, 13.628108840628277, 14.584444151764139, 15.57443612300586, 16.52466959143479, 17.482875679224126, 17.411133537305243, 16.376625891539767, 15.431324669195542, 14.470759341416418, 13.53832976037529, 12.60551162656203, 11.595965319129844, 10.549190512396857, 9.588240323095253, 8.57564204767905, 7.560102727059217, 6.946731630184533, 5.923122759417488, 4.95801114658304, 11.677307095313688, 12.623035101140639, 13.626681278016708, 14.63135551471909, 15.554881336214498, 16.48485786924509, 16.530725690666696, 15.616491375995523, 14.632264292927829, 13.634338802151301, 12.699970492700421, 11.64010401191893, 10.608405581503359, 9.564229041336429, 8.57210057297382, 7.636243459243872, 6.588829102416534, 5.879213802016704, 4.884454751469929, 4.009774732266114, 10.709287787718603, 11.678371122869715, 12.68348528665851, 13.616736691512136, 14.493308181931488, 15.486481314146225, 15.531532108110373, 14.616016821680857, 13.636949575011714, 12.678768514880762, 11.692601156947037, 10.677957475043637, 9.629141322764532, 8.582473362995973, 7.508286383054113, 6.582243387086769, 5.651558007540164, 4.841359269543043, 3.9189625702475452, 2.969173959544998, 9.777852105794496, 10.748105127944285, 11.651795975529575, 12.669201262671907, 13.532452652179888, 14.58743088804142, 14.564594999730218, 13.666832742231238, 12.710384512119964, 11.664273904846272, 10.763035327870226, 9.737006626188307, 8.709608995942855, 7.6924373462878775, 6.726373803336938, 5.767613512633326, 4.714062283784661, 3.7671962435292157, 2.905819793294099, 1.9858811758985855, 8.79350335192312, 9.807343682287001, 10.712047683749487, 11.667941324061577, 12.593046461112834, 13.598353911653206, 13.611681590637206, 12.635809457884674, 11.66922163511623, 10.726494686213806, 9.764087771589233, 8.829189737944587, 7.760609178144673, 6.748029574317542, 5.798936935369284, 4.835666860296859, 3.83178235204275, 2.83135758351103, 1.9429847547976755, 0.9884386182211855, 7.838331070981308, 8.79958134938311, 9.716847937379256, 10.691573687978375, 11.648306930535757, 12.65352474793437, 12.910171766725247, 11.943313165859465, 10.948274915779, 9.881400451664698, 8.849166039131452, 7.915999276014828, 6.850085205610531, 5.905003775009002, 4.94476888012511, 3.9795543370230626, 2.9499137013729464, 1.906338778631346, 0.9539933280015721, 0.0, 6.853776856962607, 7.842943363616004, 8.766473394159206, 9.728908690188735, 10.697534938335503, 11.680834168357123, 12.616924772293114, 12.700903139847652, 11.687140768988076, 10.745995809548255, 9.739109311351182, 8.762335633020198, 7.791727980786873, 6.831872250542169, 5.8708582902972495, 4.884676951513134, 3.8516930132818983, 2.8493563094735435, 1.9615338680428698, 1.0180698846886034, 5.875126123060923, 6.872264093624978, 7.836429216009693, 8.759701831920847, 9.797486019842905, 10.809817047487348, 11.806437952700291, 12.776683073755919, 12.52166551842889, 11.528613699365822, 10.573485133498219, 9.637994281459711, 8.703974659062288, 7.726743798002972, 6.698546199907775, 5.739334372680907, 4.785883490342004, 3.81658783713085, 2.9202252355393132, 2.0293821193237545, 4.860036543978671, 5.809219788029218, 6.8234669336090015, 7.804620016167084, 8.800167587916635, 9.78558202043302, 10.834330917262346, 11.781877465011036, 12.695126454387621, 12.489309199458672, 11.506686749662867, 10.66219372545449, 9.654017037459235, 8.67789456102955, 7.684458700943185, 6.696278604048249, 5.736401895117697, 4.783468073885811, 3.9827406517454476, 3.022027763110318, 3.915899545618622, 4.936032802005338, 5.77774259826921, 6.848296912475014, 7.8648770420316545, 8.79901299120959, 9.76989703253792, 10.73776278561188, 11.734271560984618, 12.748864846034254, 12.506147386781121, 11.557671335032573, 10.572479173356822, 9.606714880372834, 8.667342515181309, 7.673026929914992, 6.685547058236848, 5.794394865045547, 4.979569350887483, 3.9492872018374148, 2.9598487764379935, 3.86216761209451, 4.850026095111718, 5.892122717081399, 6.897129276819415, 7.874769917513655, 8.880800523948867, 9.895143140924402, 10.85404566210445, 11.792406859824418, 12.700892523683022, 12.545321272520848, 11.570186305239266, 10.578602362035513, 9.654979540457616, 8.6113313774062, 7.679416859149893, 6.8030028979201616, 5.835128002397827, 4.9086004238864565, 1.9656925489727146, 2.9360074153363724, 3.963004023360161, 4.910880267457175, 5.9625474821227415, 6.906744368170512, 7.880938681136941, 8.84048727565768, 9.796878801641638, 10.757788083087814, 11.710334170091208, 12.64580429994682, 12.560213328242591, 11.543194772277019, 10.581717362438232, 9.672743148718068, 8.714724275479337, 7.789616870379278, 6.8679516905662545, 5.935754015974593, 1.0220644058940995, 2.0833002534281695, 3.0294708430440287, 4.027033667706206, 5.0218564090892155, 6.017077288238104, 7.006900285207947, 8.01822428821378, 9.010617935982552, 10.044152792281878, 10.974003805498977, 12.000966520437718, 13.05275836968078, 12.548030340377617, 11.577828245059695, 10.633260566415611, 9.667598014216725, 8.774837542781276, 7.828671350215452, 6.98358805314233, 1.975890293111704, 3.036773704790373, 4.041572135377006, 4.986824313791998, 5.983186933024982, 6.949042057182763, 7.903875307095754, 8.877233149259235, 9.916782527840411, 10.94414329024902, 11.917248819651052, 12.953310080872667, 13.948732684919214, 13.54808020659753, 12.553522510865038, 11.597016970593076, 10.731397926629194, 9.780400000774996, 8.798356756040418, 7.919691762080947, 3.011064741732767, 3.9870549886751694, 4.985888914573271, 5.91435850300183, 6.8745981095478275, 7.90437250974593, 8.930356637951956, 9.861082856114853, 10.853941592940487, 11.798990884713431, 12.846630124241628, 13.886315673074852, 14.831484387654822, 14.454366640358762, 13.495269488771587, 12.633983406916958, 11.745969559565275, 10.837223141798123, 9.769699812501448, 8.864905291318461, 4.004084141027087, 4.936480626374105, 5.887447952934179, 6.833401925447353, 7.845715674493569, 8.83039251834342, 9.874718199779776, 10.833902430996993, 11.806296322377081, 12.776071030467229, 13.850143783452719, 14.894076746276593, 15.762838433646868, 15.441663349326646, 14.469060346148714, 13.659619085370661, 12.7144088514572, 11.765267926023087, 10.767244979037947, 9.8413548781291, 4.955717912196605, 5.929304812795213, 6.868590007008053, 7.796194829026809, 8.778890491531124, 9.76270607959512, 10.729534766179048, 11.698676629531857, 12.71445999549973, 13.738411921336988, 14.68118268940478, 15.660173650333888, 16.60844785712135, 16.507210394121955, 15.537099593840143, 14.650627128642867, 13.672824894607668, 12.81792317390656, 11.756964445821517, 10.77040945672531, 5.914212274787408, 6.9714795953780335, 7.9148559303568895, 8.819070927650854, 9.763878737389815, 10.761187476066105, 11.727030049612404, 12.696521299540295, 13.694346355088179, 14.665016274182543, 15.644015525308095, 16.570047252208422, 17.589829925364363, 17.537476830002124, 16.597691702140686, 15.653585027399803, 14.653669170699999, 13.747026080040738, 12.712160043283758, 11.834942594023214, 6.841897908421584, 7.795266205254267, 8.80536196260174, 9.592114898823434, 10.528721331315296, 11.532317477244334, 12.475170817018334, 13.50153127192128, 14.425849401955162, 15.455495488297347, 16.461760152570115, 17.342572367723783, 18.273493626851543, 18.521712509211543, 17.56991385720332, 16.65014046435946, 15.674639928734743, 14.681102474173237, 13.729910139022032, 12.896589457244902], [6.90099778292075, 7.71720231734398, 8.755269360294765, 9.693140455185539, 10.762721260454057, 11.707300973540375, 12.661583860148307, 13.678652409223538, 14.55410008544995, 15.506509167472455, 16.549572115244384, 17.4892911203378, 18.419270805558845, 18.33105452214804, 17.387698301497807, 16.378375306464445, 15.393432424000238, 14.801019498397613, 13.826400481264391, 12.87102987984543, 5.829312025567727, 6.774331983665671, 7.730667294801532, 8.720659266043254, 9.753997610433837, 10.733471829970327, 11.68830071982659, 12.680345424127964, 13.62564664647219, 14.586211974251313, 15.51864155529244, 16.4514596891057, 17.504198367943705, 17.345820398509527, 16.38487020920792, 15.372271933791719, 14.356732613171886, 13.743361516297202, 12.776899616380096, 11.811788003545646, 4.823530238351081, 5.769258244178032, 6.772904421054102, 7.803395478643884, 8.8054774869607, 9.735454019991293, 10.693162160388425, 11.665527753482635, 12.64975483655033, 13.591528468014728, 14.525896777465608, 15.514883256130021, 16.55200656057694, 16.360858927449097, 15.368730459086489, 14.43287334535654, 13.385458988529203, 12.675843688129373, 11.738231608432537, 10.86355158922872, 3.8555109307559965, 4.824594265907108, 5.861712846384344, 6.806169982844245, 7.7439043326776895, 8.737077464892428, 9.693968577832104, 10.617143058448356, 11.655435745043745, 12.613616805174697, 13.561584515527384, 14.552736719254728, 15.601552871533833, 15.379103249108642, 14.304916269166782, 13.378873273199437, 12.448187893652833, 11.637989155655712, 10.772739427210153, 9.822950816507605, 2.9240752488318895, 3.8943282709816787, 4.83002353525541, 5.8586345540040154, 6.78304880292609, 7.838027038787621, 8.738390720214621, 9.667958978998737, 10.678625456339596, 11.608443434177474, 12.632018686450573, 13.599933604969376, 14.585549541412323, 14.489067232400545, 13.523003689449606, 12.564243398745994, 11.510692169897329, 10.563826129641884, 9.759596650256707, 8.839658032861193, 1.9397264949605126, 2.953566825324394, 3.935591127676962, 4.891484767989051, 5.843642611859037, 6.848950062399408, 7.785477311121609, 8.76134944387414, 9.727937266642584, 10.670664215545008, 11.633071130169581, 12.567969163814228, 13.636549723614142, 13.544659460430209, 12.59556682148195, 11.632296746409526, 10.628412238155418, 9.627987469623697, 8.796761611760283, 7.842215475183793, 0.9845542140187009, 1.9908407286255037, 2.9674440881254585, 3.9421698387245763, 4.89890308128196, 5.904120898680572, 6.829208850185271, 7.796067451051054, 8.791105701131517, 9.783479610705543, 10.815714023238788, 11.721506634244061, 12.732983904767398, 12.586876537068838, 11.626641642184946, 10.70297479398245, 9.702021415559196, 8.702968664744013, 7.80777018496418, 6.853776856962607, 0.0, 1.0342027428583966, 2.017069544905408, 2.979504840934938, 3.9481310890817056, 4.931430319103327, 5.867520923039319, 6.843604912226429, 7.857367283086004, 8.798512242525826, 9.805398740722898, 10.782172419053882, 11.752780071287207, 11.659812462128965, 10.700552232012807, 9.735147057916953, 8.739107364465845, 7.759951133901815, 6.8169045688788295, 5.835706972274004, 0.9786507339016841, 2.0048820128494222, 2.9471137230549216, 3.917764125849649, 4.955548313771707, 5.864029183850995, 6.878659021721708, 7.848904142777336, 8.835895082915606, 9.738534888703342, 10.693663454570945, 11.629154306609452, 11.660223127901588, 10.70287556711663, 9.674677969021433, 8.715466141794565, 7.762015259455663, 6.792719606244509, 5.858213201382386, 4.824394737638853, 2.0476154314218737, 2.9967986754724207, 3.9600760054556132, 4.872845941603412, 5.921529038556942, 6.906943471073327, 7.850766057159653, 8.853381234719915, 9.81919193730015, 10.761257640840201, 11.626865070735594, 11.653464567804601, 10.657257248249863, 9.681134771820178, 8.799243953208306, 7.818617307650507, 6.7787731907214335, 5.825839369489548, 4.816930851778225, 3.831749093852289, 2.9917524297819225, 4.009369545131303, 5.0328705134455785, 5.845518847816706, 6.856819584441922, 7.790955533619858, 8.761839574948187, 9.729705328022147, 10.726214103394886, 11.749324767902312, 11.59446896750295, 10.645992915754402, 9.66080075407865, 8.695036461094663, 7.777421798707707, 6.841868981783764, 5.8853198338148776, 4.935950004975546, 3.9460560351844, 2.904489655125192, 3.947803198962551, 4.913448176180731, 5.901306659197939, 6.893681698326135, 7.824567349654162, 8.718453986025096, 9.75786470692431, 10.702779885088562, 11.668589357385619, 11.771548215862198, 10.736608446932127, 9.771260664071429, 8.796125696789847, 7.7231489794319845, 6.781523478497798, 5.848149634813756, 4.916235116557448, 3.943329914809515, 2.871704011587521, 1.9451764330761505, 4.94195942642783, 5.839608372938868, 6.8666049809626575, 7.814481225059671, 8.817712133021182, 9.72550250590956, 10.699696818875989, 11.659245413396727, 11.69783872057177, 10.736929439125594, 9.7843833521222, 8.848913222266589, 7.90464608485248, 6.880525661120931, 5.854785656517182, 4.905749931409977, 3.947731058171246, 3.005674556013796, 2.0061171652541328, 1.073919490662472, 5.994161421458189, 6.896267730282229, 7.819175709902957, 8.789907742542509, 9.784730483925518, 10.663939184042613, 11.63784771377223, 12.649171716778064, 12.654951909748174, 11.71239418845979, 10.797073955943175, 9.810206166351882, 8.849379121521103, 7.781037123069525, 6.810835027751604, 5.866267349107519, 4.900604796908633, 3.9905112430713654, 2.9668368249033303, 2.0515288162916727, 6.947987308675794, 7.951159731381251, 8.831277002235934, 9.7496983886283, 10.746061007861282, 11.679647215006014, 12.607238294740176, 13.580596136903656, 13.592333387277538, 12.787143652392851, 11.739771767611476, 10.70371050638986, 9.708287902343315, 8.78108698928944, 7.786529293556946, 6.8300237532849835, 5.882827525080087, 4.918565475462875, 3.936522230728297, 2.90415371788198, 7.994150438068132, 8.970140685010534, 9.7755937814322, 10.677232577838133, 11.63747218438413, 12.667246584582234, 13.633719625596378, 14.564445843759275, 14.535892360253717, 13.682732497043972, 12.635093257515775, 11.59540770868255, 10.650238994102581, 9.68737342305067, 8.728276271463494, 7.866990189608866, 6.897399158016166, 5.949394602876941, 4.881871273580265, 3.849367247119494, 9.037961677992772, 9.91956632270947, 10.744920019691628, 11.679881144378461, 12.676007566685273, 13.598848440172711, 14.582535335633823, 15.54171956685104, 15.56768618816338, 14.65981264279777, 13.595283773069767, 12.551350810245893, 11.581593040094628, 10.674670132018553, 9.702067128840621, 8.811048683821552, 7.865838449908092, 6.860926456673567, 5.859738972132194, 4.796300492032391, 9.989595449162291, 10.946721569414398, 11.81634939172552, 12.734873238513968, 13.717568901018284, 14.538218041838247, 15.505046728422176, 16.474188591774986, 16.41062921369368, 15.386677287856426, 14.443906519788634, 13.464915558859525, 12.516641352072062, 11.740217176813864, 10.77010637653205, 9.802056727093758, 8.781756829376466, 7.772868787809852, 6.711910059724808, 5.725355070628602, 10.95954728770368, 11.995349480260712, 12.862615315074358, 13.757749337138014, 14.702557146876975, 15.536699438309233, 16.50254201185553, 17.472033261783423, 17.34769816331785, 16.31328164070198, 15.409596972205408, 14.48356524530508, 13.509073239849075, 12.630781457347588, 11.69099632948615, 10.69141086355585, 9.681716392979553, 8.70197169394403, 7.667105657187049, 6.789888207926506, 11.887232921337857, 12.84060121817054, 13.850696975518014, 14.776862735034184, 15.713469167526046, 16.4858440166319, 17.455489538841444, 18.437293358208002, 18.36095345408799, 17.384978921082585, 16.457322084638825, 15.486252623169225, 14.556475523935392, 13.61501713655701, 12.663218484548786, 11.666610100726464, 10.652993237263935, 9.636048088076528, 8.684855752925323, 7.851535071148193], [7.912715762586942, 7.041013029509589, 8.016285659862941, 8.848051768431471, 9.764188298723289, 10.673098230681978, 11.627381117289909, 12.64444966636514, 13.519897342591552, 14.472306424614057, 15.515369372385988, 16.455088377479402, 17.385068062700448, 17.38582941271342, 16.453333258523386, 15.697474158875659, 14.79841527600234, 14.013790535671923, 13.23473734768532, 13.806796535059846, 6.84103000523392, 6.09814269583128, 6.976120007182166, 7.875570579289187, 8.741062999322594, 9.69926908711193, 10.654097976968192, 11.646142681269566, 12.591443903613792, 13.552009231392915, 14.484438812434043, 15.417256946247303, 16.469995625085307, 17.497028264364037, 17.396615558433584, 16.384017283017382, 15.368477962397547, 14.755106865522864, 13.766066123033491, 12.800954510199043, 5.835248218017274, 5.093068956343641, 5.909804082413513, 6.847748922606896, 7.771274744102303, 8.701251277132895, 9.658959417530028, 10.631325010624238, 11.615552093691932, 12.55732572515633, 13.49169403460721, 14.480680513271626, 15.517803817718548, 16.512066793303607, 16.38047580831215, 15.444618694582202, 14.397204337754864, 13.687589037355034, 12.727398115085933, 11.852718095882118, 4.867228910422189, 4.030267611510638, 4.899878694546313, 5.833130099399941, 6.709701589819293, 7.70287472203403, 8.659765834973706, 9.582940315589958, 10.621233002185347, 11.5794140623163, 12.527381772668988, 13.518533976396332, 14.567350128675438, 15.530311114963151, 15.316661618392441, 14.390618622425098, 13.459933242878494, 12.649734504881373, 11.761905933863549, 10.812117323161003, 3.9357932284980817, 3.01927628667397, 3.8681893834173797, 4.885594670559712, 5.748846060067693, 6.803824295929225, 7.704187977356224, 8.63375623614034, 9.644422713481198, 10.574240691319076, 11.597815943592177, 12.56573086211098, 13.551346798553928, 14.575153834659337, 14.534749038675269, 13.575988747971655, 12.52243751912299, 11.575571478867545, 10.748763156910103, 9.82882453951459, 2.951444474626705, 2.0158287245714943, 2.9284410916372927, 3.884334731949382, 4.809439869000641, 5.814747319541011, 6.751274568263212, 7.727146701015744, 8.693734523784189, 9.636461472686612, 10.598868387311185, 11.533766420955832, 12.602346980755746, 13.614926584582877, 13.607312170707614, 12.64404209563519, 11.64015758738108, 10.639732818849359, 9.785928118413679, 8.83138198183719, 1.9962721936848933, 0.956637985767107, 1.9332413452670616, 2.907967095866179, 3.864700338423563, 4.869918155822176, 5.795006107326874, 6.7618647081926575, 7.756902958273121, 8.749276867847147, 9.781511280380393, 10.687303891385666, 11.698781161909002, 12.643862592510532, 12.659483257190661, 11.735816408988166, 10.734863030564911, 9.714714013969674, 8.796936691617576, 7.842943363616005, 1.0342027428583966, 0.0, 0.9828668020470115, 1.9453020980765414, 2.913928346223309, 3.89722757624493, 4.833318180180922, 5.809402169368032, 6.823164540227608, 7.76430949966743, 8.771195997864503, 9.747969676195487, 10.718577328428811, 11.678433058673514, 11.733393847018522, 10.767988672922668, 9.77194897947156, 8.771696483127476, 7.8275887890475495, 6.824873478927401, 2.012853476760081, 0.9706792699910258, 1.9129109801965247, 2.8835613829912523, 3.92134557091331, 4.829826440992599, 5.844456278863311, 6.814701399918939, 7.801692340057209, 8.704332145844946, 9.65946071171255, 10.594951563751057, 11.52897118614848, 11.735717182122345, 10.707519584027148, 9.74830775680028, 8.794856874461377, 7.825561221250224, 6.8688974215511065, 5.835078957807573, 2.9829068196373334, 2.0337235755867864, 2.925873262597216, 3.838643198745016, 4.887326295698546, 5.872740728214931, 6.8165633143012565, 7.819178491861518, 8.784989194441755, 9.727054897981805, 10.592662327877198, 11.619151007745835, 11.69145999110826, 10.715337514678575, 9.833446696066703, 8.852820050508903, 7.81297593357983, 6.860042112347944, 5.851133594636622, 4.8659518367106855, 3.927043817997382, 3.0462944452456693, 3.9986677705871814, 4.811316104958309, 5.822616841583526, 6.756752790761462, 7.72763683208979, 8.69550258516375, 9.692011360536489, 10.715122025043916, 11.615568088047983, 11.6801956586128, 10.695003496937048, 9.72923920395306, 8.811624541566104, 7.876071724642161, 6.919522576673275, 5.970152747833944, 4.980258778042797, 3.938692397983589, 4.883094587178011, 4.120159635156497, 4.926384273744673, 5.859478955467738, 6.790364606795766, 7.684251243166701, 8.723661964065913, 9.668577142230165, 10.634386614527221, 11.6556188892752, 11.770811189790525, 10.805463406929826, 9.830328439648245, 8.757351722290382, 7.815726221356195, 6.882352377672152, 5.950437859415844, 4.977532657667912, 3.905906754445918, 2.9793791759345476, 5.87725081464329, 5.0463198319146345, 5.91381184560632, 6.840721405091962, 7.783509390162786, 8.691299763051163, 9.665494076017591, 10.62504267053833, 11.581434196522288, 11.771132181983992, 10.818586094980597, 9.883115965124986, 8.938848827710878, 7.914728403979328, 6.888988399375579, 5.939952674268374, 4.981933801029643, 4.0398772988721925, 3.0403199081125294, 2.1081222335208687, 6.929452809673649, 6.102979189257995, 6.86638257454662, 7.8161479225748, 8.806613918618133, 9.629736441184216, 10.603644970913832, 11.614968973919666, 12.538547385698692, 12.746596931318187, 11.831276698801572, 10.84440890921028, 9.8835818643795, 8.815239865927921, 7.845037770610001, 6.900470091965916, 5.93480753976703, 5.024713985929762, 4.001039567761727, 3.0632467959578653, 7.883278696891254, 7.157871190357017, 7.878483866879597, 8.77593856866059, 9.772301187893573, 10.645444472147616, 11.573035551881778, 12.546393394045259, 13.475928863228056, 13.821346395251249, 12.773974510469873, 11.737913249248258, 10.74249064520171, 9.815289732147836, 8.820732036415343, 7.864226496143381, 6.917030267938484, 5.952768218321273, 4.970724973586694, 3.9158716975481727, 8.929441826283592, 8.213016760409433, 8.822800646075862, 9.703472757870424, 10.663712364416421, 11.693486764614523, 12.59951688273798, 13.530243100900877, 14.419487836204235, 14.716935239902366, 13.66929600037417, 12.629610451540945, 11.684441736960977, 10.721576165909067, 9.762479014321892, 8.901192932467264, 7.931601900874564, 6.961112582543133, 5.893589253246457, 4.861085226785686, 9.973253066208231, 9.162442398108368, 9.79212688433529, 10.706121324410752, 11.702247746717564, 12.625088620205, 13.548332592775425, 14.507516823992642, 15.451281664113898, 15.694015385656163, 14.62948651592816, 13.585553553104289, 12.615795782953024, 11.70887287487695, 10.736269871699019, 9.845251426679951, 8.90004119276649, 7.872644436339759, 6.871456951798387, 5.808018471698584, 10.92488683737775, 10.189597644813297, 10.863556256369183, 11.761113418546259, 12.743809081050575, 13.564458221870536, 14.486340433381887, 15.455482296734697, 16.47126566270257, 16.42088003071482, 15.47810926264703, 14.499118301717921, 13.550844094930458, 12.774419919672262, 11.804309119390448, 10.833577679261882, 9.793474809042658, 8.784586767476044, 7.723628039391, 6.737073050294795, 11.89483867591914, 11.23822555565961, 11.90982217971802, 12.783989517170305, 13.728797326909266, 14.562939618341522, 15.487410691041282, 16.456901940969175, 17.45472699651706, 17.347484383560374, 16.431410706906505, 15.505378980006178, 14.512477988432764, 13.568662283764738, 12.6288771559033, 11.703128843222043, 10.693434372645745, 9.713689673610222, 8.678823636853242, 7.801606187592698, 12.822524309553316, 12.207946822900105, 12.970694263519094, 13.803102915066475, 14.739709347558337, 15.512084196664192, 16.445083231730457, 17.422162037393754, 17.406071898536148, 16.490975247767196, 15.484710583494428, 14.502691602142033, 13.611314387510731, 12.608453652848889, 11.656655000840665, 10.716434628418464, 9.836084456340668, 8.955687719295515, 8.053765948638496, 8.863253050814386], [8.76819340188275, 7.8427545884797185, 7.03341885781593, 7.86518496638446, 8.781321496676277, 9.690231428634966, 10.644514315242898, 11.66158286431813, 12.53703054054454, 13.489439622567046, 14.532502570338977, 15.47222157543239, 16.402201260653438, 16.40296261066641, 15.470466456476377, 14.714607356828648, 13.815548473955328, 13.030923733624913, 13.832522358425306, 14.607909300820904, 7.696507644529726, 6.899884254801409, 5.993253205135154, 6.8927037772421755, 7.758196197275582, 8.716402285064918, 9.67123117492118, 10.663275879222555, 11.60857710156678, 12.569142429345904, 13.501572010387031, 14.434390144200291, 15.487128823038296, 16.514161462317027, 16.51812199741782, 15.720710729501373, 14.85224828478368, 14.088581715725324, 14.689596153576693, 13.652152569884565, 6.690725857313081, 5.894810515313771, 4.926937280366501, 5.8648821205598844, 6.788407942055292, 7.718384475085883, 8.676092615483016, 9.648458208577226, 10.63268529164492, 11.574458923109319, 12.5088272325602, 13.497813711224614, 14.534937015671536, 15.529199991256597, 16.522317344525664, 16.3681487251254, 15.320734368298066, 14.611119067898235, 13.650928145629134, 12.752769083081882, 5.722706549717996, 4.8320091704807675, 3.9170118924993016, 4.85026329735293, 5.726834787772281, 6.720007919987019, 7.676899032926695, 8.600073513542947, 9.638366200138336, 10.596547260269288, 11.544514970621977, 12.53566717434932, 13.584483326628426, 14.54744431291614, 15.555003677572977, 15.3141486529683, 14.383463273421695, 13.573264535424574, 12.68543596440675, 11.735647353704204, 4.791270867793889, 3.8210178456441, 2.8853225813703682, 3.9027278685127005, 4.765979258020682, 5.820957493882213, 6.721321175309212, 7.650889434093328, 8.661555911434187, 9.591373889272067, 10.614949141545166, 11.582864060063969, 12.568479996506916, 13.592287032612326, 14.503975808262062, 14.499518778514856, 13.445967549666191, 12.499101509410746, 11.672293187453304, 10.752354570057792, 3.9343112766737165, 2.927598591942849, 1.945574289590281, 2.9014679299023705, 3.826573066953629, 4.831880517494, 5.7684077662162005, 6.744279898968733, 7.710867721737177, 8.6535946706396, 9.616001585264174, 10.55089961890882, 11.619480178708734, 12.632059782535865, 13.576538940294409, 13.56757212617839, 12.56368761792428, 11.56326284939256, 10.70945814895688, 9.754912012380391, 2.9791389957319048, 1.9395047878141185, 0.9503745432200501, 1.9251002938191677, 2.8818335363765515, 3.8870513537751643, 4.812139305279863, 5.778997906145646, 6.774036156226109, 7.766410065800134, 8.79864447833338, 9.704437089338652, 10.715914359861989, 11.660995790463518, 12.58266962704356, 12.659346439531367, 11.658393061108113, 10.638244044512875, 9.720466722160777, 8.766473394159206, 2.017069544905408, 0.9828668020470115, 0.0, 0.9624352960295298, 1.9310615441762973, 2.914360774197918, 3.85045137813391, 4.82653536732102, 5.840297738180595, 6.781442697620417, 7.788329195817489, 8.765102874148473, 9.735710526381798, 10.6955662566265, 11.65658021687142, 11.691518703465869, 10.695479010014761, 9.695226513670677, 8.75111881959075, 7.748403509470602, 2.9807815284272947, 1.9080681035663876, 0.9300441781495132, 1.9006945809442406, 2.9384787688662986, 3.846959638945587, 4.861589476816299, 5.831834597871927, 6.818825538010197, 7.721465343797933, 8.676593909665536, 9.612084761704043, 10.546104384101467, 11.523335245160784, 11.63104961457035, 10.671837787343481, 9.718386905004579, 8.749091251793425, 7.792427452094308, 6.758608988350774, 3.9064368501805355, 2.9572536061299886, 1.9430064605502049, 2.855776396698004, 3.9044594936515344, 4.88987392616792, 5.833696512254244, 6.836311689814505, 7.802122392394741, 8.744188095934792, 9.609795525830185, 10.636284205698821, 11.549070263753192, 11.698204316725587, 10.808928199071053, 9.820748102176118, 8.780903985247043, 7.8279701640151576, 6.819061646303835, 5.833879888377899, 4.850573848540584, 3.9698244757888714, 3.0158009685401703, 3.8284493029112974, 4.839750039536515, 5.773885988714451, 6.744770030042779, 7.712635783116738, 8.709144558489477, 9.732255222996903, 10.63270128600097, 11.581177337749518, 11.67787029898406, 10.712106006000072, 9.794491343613116, 8.843999776309374, 7.887450628340488, 6.938080799501157, 5.948186829710011, 4.906620449650802, 5.806624617721212, 4.93137595471487, 3.943517471697662, 4.8766121534207265, 5.807497804748754, 6.701384441119689, 7.740795162018902, 8.685710340183153, 9.65151981248021, 10.672752087228188, 11.578651358454831, 11.78833020897684, 10.813195241695258, 9.740218524337394, 8.798593023403207, 7.8502804293393655, 6.9183659110830575, 5.9454607093351255, 4.873834806113131, 3.947307227601761, 6.800780845186491, 5.857536151473007, 4.930945043559309, 5.8578546030449505, 6.800642588115775, 7.708432961004152, 8.682627273970581, 9.64217586849132, 10.598567394475278, 11.559476675921454, 11.801452897027609, 10.865982767171998, 9.92171562975789, 8.89759520602634, 7.871855201422591, 6.922819476315386, 5.964800603076655, 5.022744100919204, 4.023186710159541, 3.09098903556788, 7.852982840216851, 6.829686362115468, 5.883515772499609, 6.833281120527788, 7.823747116571122, 8.646869639137204, 9.620778168866822, 10.632102171872656, 11.555680583651682, 12.53494142525565, 12.814143500848584, 11.827275711257291, 10.86644866642651, 9.798106667974933, 8.827904572657012, 7.883336894012928, 6.917674341814042, 6.0075807879767735, 4.9839063698087385, 4.046113598004877, 8.806808727434456, 7.88457836321449, 6.895617064832586, 7.79307176661358, 8.789434385846564, 9.662577670100605, 10.590168749834769, 11.563526591998249, 12.493062061181046, 13.520422823589655, 13.756841312516883, 12.720780051295268, 11.725357447248722, 10.798156534194847, 9.803598838462355, 8.847093298190392, 7.899897069985496, 6.935635020368284, 5.953591775633705, 4.898738499595184, 9.824990639850666, 8.849000392908264, 7.839933844028852, 8.720605955823412, 9.68084556236941, 10.710619962567513, 11.61665008069097, 12.547376298853868, 13.436621034157225, 14.38167032593017, 14.652162802421183, 13.612477253587958, 12.667308539007989, 11.704442967956078, 10.745345816368904, 9.884059734514274, 8.914468702921575, 7.894666470350048, 6.827143141053372, 5.794639114592601, 10.77436583196929, 9.760227408848355, 8.809260082288281, 9.72325452236374, 10.719380944670553, 11.64222181815799, 12.565465790728416, 13.524650021945632, 14.468414862066888, 15.358750471683967, 15.612353317975174, 14.5684203551513, 13.598662585000035, 12.691739676923962, 11.71913667374603, 10.730015646192237, 9.784805412278777, 8.728122075635566, 7.726934591094194, 6.663496110994391, 11.725999603138808, 10.787382655553284, 9.880689454322173, 10.778246616499247, 11.760942279003563, 12.581591419823527, 13.503473631334877, 14.472615494687687, 15.488398860655561, 16.38073787352157, 16.445039366751267, 15.470317280950228, 14.522043074162765, 13.657682990446329, 12.70660246215683, 11.689055318557688, 10.648952448338465, 9.64006440677185, 8.579105678686807, 7.592550689590602, 12.695951441680197, 11.836010566399597, 10.92695537767101, 11.801122715123293, 12.745930524862255, 13.580072816294512, 14.504543888994272, 15.474035138922163, 16.471860194470047, 16.427543155985045, 15.448543904859493, 14.522512177959165, 13.529611186385752, 12.585795481717726, 11.646010353856289, 10.730123263331109, 9.874188412328401, 9.024026967277155, 9.534301276149048, 8.657083826888504, 13.623637075314374, 12.805731833640092, 11.987827461472085, 12.820236113019464, 13.756842545511326, 14.529217394617183, 15.462216429683448, 16.43929523534674, 16.423205096489134, 15.508108445720184, 14.501843781447416, 13.519824800095021, 12.62844758546372, 11.625586850801877, 10.673788198793654, 9.733567826371452, 8.853217654293656, 7.972820917248504, 8.855507507608626, 9.718730690110192], [9.73062869791228, 8.805189884509248, 7.954356726889059, 6.999360177372759, 7.818886200646749, 8.727796132605437, 9.682079019213369, 10.6991475682886, 11.574595244515011, 12.527004326537517, 13.570067274309448, 14.509786279402862, 15.439765964623907, 15.487159729245374, 14.55466357505534, 13.798804475407612, 12.899745592534293, 13.828949765405664, 14.774473454181832, 15.552054831988503, 8.658942940559257, 7.862319550830939, 6.955688501164684, 6.026878988230475, 6.795760901246053, 7.753966989035389, 8.708795878891653, 9.700840583193026, 10.646141805537251, 11.606707133316375, 12.539136714357502, 13.471954848170762, 14.524693527008766, 15.551726166287493, 15.602319115996782, 14.804907848080338, 13.936445403362645, 14.886607747506075, 15.652031449606223, 14.596298101052163, 7.6531611533426105, 6.857245811343301, 5.889372576396031, 4.999057331548185, 5.825972646025763, 6.755949179056354, 7.713657319453488, 8.686022912547697, 9.670249995615391, 10.612023627079788, 11.546391936530668, 12.535378415195083, 13.572501719642005, 14.566764695227064, 15.559882048496133, 15.744306436515517, 14.907719028005328, 15.573554363927768, 14.613363441658665, 13.69691461424948, 6.685141845747526, 5.794444466510297, 4.8794471885288315, 3.9844385083412304, 4.764399491742752, 5.75757262395749, 6.714463736897166, 7.637638217513417, 8.675930904108805, 9.634111964239757, 10.582079674592446, 11.57323187831979, 12.622048030598895, 13.585009016886609, 14.592568381543447, 15.479900232753293, 15.345898569451228, 14.535699831454107, 13.64787126043628, 12.698082649733735, 5.753706163823419, 4.78345314167363, 3.847757877399898, 3.036903079501001, 3.8035439619911524, 4.858522197852683, 5.758885879279682, 6.688454138063798, 7.699120615404656, 8.628938593242534, 9.652513845515635, 10.620428764034438, 11.606044700477385, 12.629851736582795, 13.541540512232533, 14.52326653266672, 14.408402845695724, 13.461536805440279, 12.634728483482835, 11.714789866087322, 4.896746572703247, 3.8900338879723786, 2.9080095856198107, 2.0356431408906714, 2.864137770924099, 3.8694452214644697, 4.805972470186671, 5.781844602939203, 6.748432425707647, 7.69115937461007, 8.653566289234643, 9.58846432287929, 10.657044882679203, 11.669624486506335, 12.61410364426488, 13.539774830680058, 13.526122913953813, 12.525698145422092, 11.671893444986411, 10.717347308409922, 3.9415742917614347, 2.901940083843648, 1.9128098392495798, 1.046637987574347, 1.9193982403470216, 2.9246160577456344, 3.8497040092503334, 4.816562610116116, 5.811600860196579, 6.803974769770605, 7.8362091823038496, 8.742001793309123, 9.75347906383246, 10.69856049443399, 11.62023433101403, 12.585448874116079, 12.620828357137645, 11.600679340542408, 10.682902018190308, 9.728908690188737, 2.979504840934938, 1.9453020980765414, 0.9624352960295298, 0.0, 0.9686262481467675, 1.9519254781683884, 2.88801608210438, 3.86410007129149, 4.8778624421510655, 5.819007401590888, 6.82589389978796, 7.802667578118944, 8.773275230352269, 9.733130960596972, 10.694144920841891, 11.745261174735852, 11.657914306044294, 10.65766180970021, 9.713554115620283, 8.710838805500133, 3.943216824456824, 2.870503399595917, 1.892479474179043, 0.9848916995232055, 2.0029578957190592, 2.884524342916057, 3.8991541807867693, 4.869399301842398, 5.856390241980668, 6.7590300477684035, 7.714158613636006, 8.649649465674514, 9.583669088071938, 10.560899949131255, 11.589097547226451, 11.634273083373014, 10.680822201034111, 9.711526547822958, 8.75486274812384, 7.721044284380305, 4.868872146210066, 3.9196889021595185, 2.9054417565797346, 1.939973515276969, 2.9886566122305, 3.9319330650545905, 4.871261216224714, 5.873876393784976, 6.839687096365212, 7.781752799905263, 8.647360229800656, 9.673848909669292, 10.586634967723663, 11.562757444153348, 11.771363495100582, 10.783183398205647, 9.743339281276574, 8.790405460044688, 7.781496942333365, 6.796315184407429, 5.813009144570115, 4.932259771818401, 3.9782362645697, 2.9126464214902628, 3.9239471581154803, 4.8580831072934165, 5.828967148621745, 6.796832901695704, 7.793341677068442, 8.769819926967374, 9.67026598997144, 10.618742041719988, 11.602398469823498, 11.674541302029603, 10.756926639642646, 9.806435072338905, 8.849885924370017, 7.900516095530686, 6.91062212573954, 5.869055745680332, 6.769059913750743, 5.893811250744399, 4.905952767727191, 3.9608092719996915, 4.89169492332772, 5.785581559698655, 6.8249922805978676, 7.76990745876212, 8.735716931059176, 9.72627791317721, 10.616216062425302, 11.581563845286, 11.775630537724787, 10.702653820366924, 9.761028319432738, 8.812715725368896, 7.880801207112588, 6.907896005364655, 5.836270102142661, 4.909742523631291, 7.763216141216022, 6.819971447502536, 5.889927965720929, 4.9420517216239155, 5.88483970669474, 6.792630079583118, 7.766824392549547, 8.726372987070286, 9.682764513054245, 10.64367379450042, 11.596219881503815, 11.828418063201529, 10.88415092578742, 9.86003050205587, 8.834290497452121, 7.885254772344917, 6.9272358991061855, 5.985179396948735, 4.985622006189072, 4.053424331597411, 8.815418136246382, 7.788669284277088, 6.842498694661229, 5.917478239106753, 6.9079442351500875, 7.73106675771617, 8.704975287445787, 9.716299290451621, 10.639877702230649, 11.619138543834616, 12.548989557051716, 12.789711007286822, 11.828883962456043, 10.760541964004465, 9.790339868686544, 8.845772190042458, 7.880109637843573, 6.970016084006304, 5.946341665838269, 5.008548894034407, 9.769244023463987, 8.84356128537611, 7.854599986994206, 6.877268885192545, 7.8736315044255285, 8.746774788679572, 9.674365868413734, 10.647723710577214, 11.577259179760013, 12.604619942168622, 13.49223457120379, 13.6832153473248, 12.687792743278255, 11.76059183022438, 10.766034134491886, 9.809528594219923, 8.862332366015027, 7.898070316397815, 6.916027071663236, 5.8611737956247145, 10.783973562012285, 9.807983315069883, 8.798916766190471, 7.804803074402377, 8.765042680948374, 9.794817081146476, 10.700847199269933, 11.631573417432833, 12.520818152736192, 13.465867444509136, 14.513506684037333, 14.57491254961749, 13.629743835037521, 12.666878263985609, 11.707781112398434, 10.846495030543807, 9.876903998951107, 8.857101766379577, 7.789578437082902, 6.757074410622131, 11.718511363136887, 10.704372940015952, 9.753405613455879, 8.807451640942705, 9.803578063249518, 10.726418936736954, 11.649662909307379, 12.608847140524595, 13.552611980645855, 14.442947590262934, 15.517020343248426, 15.464413860261935, 14.49465609011067, 13.654174972953493, 12.681571969775561, 11.692450942221768, 10.747240708308308, 9.690557371665097, 8.689369887123725, 7.625931407023921, 12.670145134306406, 11.72933375130981, 10.790048557096968, 9.862443735078212, 10.845139397582528, 11.66578853840249, 12.58767074991384, 13.55681261326665, 14.572595979234524, 15.464934992100538, 15.48260407072174, 14.507881984920699, 13.559607778133236, 12.6952476944168, 11.744167166127301, 10.770645866058516, 9.989207899409031, 10.602499702801381, 9.541540974716337, 8.554985985620132, 13.640096972847795, 12.777961662156123, 11.835928969390455, 10.885319833702258, 11.83012764344122, 12.664269934873476, 13.588741007573235, 14.558232257501126, 15.55605731304901, 15.465107859955516, 14.486108608829964, 13.560076881929636, 12.567175890356223, 11.623360185688197, 10.68357505782676, 9.76768796730158, 9.0083636233167, 9.944964836350286, 10.496736572178579, 9.619519122918035, 14.567782606481972, 13.747682929396618, 12.88655083856977, 11.904433231598428, 12.84103966409029, 13.613414513196146, 14.54641354826241, 15.523492353925704, 15.460769800459607, 14.545673149690655, 13.539408485417887, 12.557389504065492, 11.66601228943419, 10.663151554772348, 9.711352902764125, 8.771132530341923, 7.987392865281956, 8.893758786321634, 9.817942803638157, 10.681165986139723], [10.69571190417058, 9.74967061354576, 8.787950736148453, 7.832954186632152, 6.850259952499981, 7.75916988445867, 8.713452771066601, 9.730521320141833, 10.605968996368244, 11.55837807839075, 12.60144102616268, 13.541160031256094, 14.47113971647714, 14.54973492446711, 13.622463095661669, 13.16806051739502, 13.86837184068106, 14.797576013552431, 15.7430997023286, 16.52068108013527, 9.624026146817556, 8.806800279867451, 7.850464968731591, 6.860472997489868, 5.827134653099286, 6.785340740888621, 7.7401696307448855, 8.732214335046258, 9.677515557390484, 10.638080885169607, 11.570510466210735, 12.503328600023995, 13.556067278861999, 14.583099918140727, 14.67011863660311, 14.174163890067746, 14.905071651509413, 15.855233995652842, 16.620657697752993, 15.56492434919893, 8.61824435960091, 7.8223290176016, 6.85445578265433, 5.856225479345703, 4.857346397878995, 5.787322930909586, 6.7450310713067205, 7.71739666440093, 8.701623747468624, 9.643397378933022, 10.577765688383902, 11.566752167048316, 12.603875471495238, 13.598138447080299, 14.591255800349368, 15.113562478502924, 15.876345276152096, 16.542180612074535, 15.581989689805432, 14.665540862396247, 7.650225052005825, 6.759527672768597, 5.844530394787131, 4.841606656138748, 3.795773243595985, 4.788946375810722, 5.745837488750398, 6.66901196936665, 7.707304655962039, 8.665485716092991, 9.613453426445679, 10.604605630173022, 11.653421782452128, 12.616382768739841, 13.623942133396682, 14.511273984606527, 15.441959364153131, 15.504326079600874, 14.616497508583048, 13.666708897880502, 6.718789370081718, 5.748536347931929, 4.812841083658197, 3.8940712272985194, 2.834917713844385, 3.8898959497059162, 4.7902596311329155, 5.719827889917031, 6.730494367257889, 7.660312345095768, 8.683887597368868, 9.65180251588767, 10.637418452330618, 11.661225488436028, 12.572914264085767, 13.554640284519953, 14.607785158929053, 14.430163053587046, 13.603354731629603, 12.68341611423409, 5.865372820850014, 4.855117094230678, 3.8730927918781104, 2.917199151566021, 1.8955115227773316, 2.900818973317703, 3.837346222039904, 4.813218354792436, 5.77980617756088, 6.722533126463303, 7.684940041087875, 8.619838074732522, 9.688418634532436, 10.700998238359567, 11.645477396118112, 12.57114858253329, 13.5750330907874, 13.49432439356886, 12.640519693133179, 11.68597355655669, 4.910200539908202, 3.8705663319904158, 2.8814360873963474, 1.940169312873841, 0.9507719922002541, 1.9559898095988673, 2.8810777611035663, 3.847936361969349, 4.842974612049812, 5.835348521623837, 6.867582934157082, 7.773375545162356, 8.784852815685692, 9.729934246287222, 10.651608082867263, 11.616822625969311, 12.646463261619427, 12.569305588689176, 11.651528266337076, 10.697534938335505, 3.9481310890817056, 2.913928346223309, 1.9310615441762973, 0.9686262481467675, 0.0, 0.9832992300216209, 1.9193898339576128, 2.895473823144723, 3.909236194004299, 4.85038115344412, 5.857267651641193, 6.834041329972177, 7.804648982205501, 8.764504712450204, 9.725518672695124, 10.776634926589084, 11.809618864820319, 11.626288057846978, 10.682180363767051, 9.6794650536469, 4.911843072603592, 3.8391296477426846, 2.8611057223258105, 1.9535179476699729, 1.034331647572292, 1.9158980947692896, 2.930527932640002, 3.90077305369563, 4.8877639938339, 5.790403799621636, 6.745532365489239, 7.681023217527747, 8.61504283992517, 9.592273700984487, 10.620471299079684, 11.579683126306552, 11.64944844918088, 10.680152795969725, 9.723488996270607, 8.689670532527073, 5.8374983943568335, 4.888315150306286, 3.874068004726502, 2.9085997634237364, 2.0512318074522358, 2.963306816907823, 3.9026349680779475, 4.905250145638209, 5.871060848218445, 6.813126551758495, 7.678733981653888, 8.705222661522525, 9.618008719576896, 10.59413119600658, 11.587567056092947, 11.751809646352417, 10.71196552942334, 9.759031708191454, 8.750123190480132, 7.764941432554196, 6.781635392716883, 5.900886019965169, 4.946862512716468, 3.88127266963703, 2.9865223533372163, 3.920658302515152, 4.89154234384348, 5.85940809691744, 6.831915741621447, 7.801193678820607, 8.701639741824673, 9.650115793573221, 10.63377222167673, 11.580229506732096, 11.725552887789414, 10.775061320485673, 9.818512172516787, 8.869142343677455, 7.879248373886307, 6.8376819938271, 7.737686161897511, 6.862437498891167, 5.87457901587396, 4.929435520146459, 3.954270118549456, 4.8481567549203906, 5.887567475819603, 6.832482653983854, 7.796782426173103, 8.757651665030444, 9.647589814278534, 10.612937597139233, 11.588072564420814, 11.671280068513692, 10.729654567579505, 9.781341973515664, 8.849427455259356, 7.876522253511423, 6.804896350289429, 5.878368771778058, 8.73184238936279, 7.788597695649305, 6.858554213867697, 5.910677969770683, 4.947414901916477, 5.855205274804853, 6.829399587771283, 7.788948182292022, 8.74533970827598, 9.706248989722155, 10.638148167870348, 11.549016494242212, 11.852777173934188, 10.828656750202638, 9.802916745598889, 8.853881020491684, 7.895862147252953, 6.953805645095502, 5.954248254335839, 5.022050579744178, 9.78404438439315, 8.757295532423855, 7.8111249428079965, 6.886104487253521, 5.970519430371824, 6.7936419529379055, 7.767550482667523, 8.778874485673356, 9.702452897452384, 10.68171373905635, 11.61156475227345, 12.510309438327505, 12.797510210602809, 11.729168212151231, 10.75896611683331, 9.814398438189226, 8.84873588599034, 7.938642332153072, 6.914967913985037, 5.977175142181174, 10.737870271610754, 9.812187533522877, 8.823226235140973, 7.8458951333393125, 6.972300236357275, 7.809349983901306, 8.73694106363547, 9.71029890579895, 10.639834374981746, 11.667195137390355, 12.554809766425524, 13.548696623522591, 13.65641899142502, 12.729218078371145, 11.734660382638653, 10.77815484236669, 9.830958614161794, 8.866696564544583, 7.8846533198100035, 6.829800043771482, 11.752599810159053, 10.77660956321665, 9.767543014337239, 8.773429322549145, 8.011945911465554, 8.862616601752803, 9.76342239449167, 10.694148612654569, 11.583393347957925, 12.52844263973087, 13.576081879259066, 14.576106356987369, 14.457383887955949, 13.635504512132377, 12.676407360545202, 11.815121278690572, 10.845530247097873, 9.822184972637876, 8.754661643341201, 7.7221576168804305, 12.687137611283655, 11.67299918816272, 10.722031861602646, 9.776077889089473, 9.050481293766698, 9.79421845734328, 10.712238104529115, 11.671422335746332, 12.615187175867588, 13.505522785484667, 14.579595538470159, 14.495787612115167, 13.526029841963902, 12.792168491065343, 11.843580165671963, 10.793027661183954, 11.712323914566605, 10.655640577923394, 9.654453093382022, 8.59101461328222, 13.638771382453173, 12.697959999456577, 11.758674805243736, 10.83106998322498, 10.101578066124835, 10.733588059008817, 11.650245945135577, 12.619387808488387, 13.63517117445626, 14.527510187322271, 14.513977822574974, 13.539255736773931, 12.590981529986468, 11.726621446270032, 10.775540917980534, 9.802019617911748, 10.78960046582344, 11.56758290905968, 10.506624180974637, 9.52006919187843, 14.608723220994563, 13.74658791030289, 12.804555217537223, 11.853946081849026, 11.162196050371467, 11.732069455479802, 12.651316202794971, 13.620807452722863, 14.618632508270746, 14.49648161180875, 13.517482360683198, 12.59145063378287, 11.598549642209456, 10.65473393754143, 9.714948809679992, 8.799061719154812, 9.80875618973111, 10.778558845609679, 11.461819778436878, 10.584602329176334, 15.536408854628739, 14.716309177543385, 13.855177086716537, 12.873059479745196, 12.210295706077698, 12.681214033802473, 13.608988743484147, 14.58606754914744, 14.49214355231284, 13.577046901543888, 12.57078223727112, 11.588763255918725, 10.697386041287423, 9.69452530662558, 8.742726654617357, 7.802506282195155, 8.816123145657684, 9.727352795581027, 10.678545130732232, 11.646249192398022], [11.679011134192201, 10.73296984356738, 9.771249966170073, 8.816253416653772, 7.833559182521602, 7.007341693239971, 7.851534132693794, 8.818878912092654, 9.6635082290278, 10.615917311050305, 11.658980258822236, 12.59869926391565, 13.528678949136696, 13.610328772527179, 12.683056943721734, 13.692379938755096, 14.744166272085458, 15.673370444956829, 16.672722876740814, 17.4611204830961, 10.607325376839178, 9.790099509889071, 8.83376419875321, 7.843772227511488, 6.810433883120907, 6.033512549669922, 6.809068114167113, 7.789753567705814, 8.73505479005004, 9.695620117829163, 10.62804969887029, 11.56086783268355, 12.613606511521555, 13.62401879009513, 13.730712484663176, 14.698483311427822, 15.76287581404909, 16.72895465451978, 17.57209274552309, 16.505363752159763, 9.601543589622532, 8.80562824762322, 7.837755012675951, 6.839524709367324, 5.840645627900616, 5.035494739690887, 5.813929554728948, 6.774935897060486, 7.759162980128179, 8.700936611592578, 9.63530492104346, 10.622651336621674, 11.659774641068596, 12.639057319034702, 13.632174672303771, 14.582998447647716, 15.39593122900788, 16.383531918069583, 16.56528891982705, 15.60598026535708, 8.633524282027446, 7.742826902790218, 6.827829624808752, 5.824905886160369, 4.779072473617606, 4.037118184592023, 4.814735972172626, 5.726551202026206, 6.764843888621595, 7.723024948752547, 8.669352596019037, 9.66050479974638, 10.709320952025486, 11.657301640694245, 12.64064290337506, 13.527974754584905, 14.45866013413151, 15.450148198776121, 15.599796738604669, 14.650008127902122, 7.702088600103339, 6.73183557795355, 5.796140313679818, 4.87737045732014, 3.818216943866006, 2.997143200208361, 3.847798863792472, 4.777367122576587, 5.788033599917445, 6.7162115146691255, 7.739786766942226, 8.707701685461029, 9.693317621903976, 10.702144360390431, 11.589615034064146, 12.571341054498332, 13.624485928907431, 14.527997289315685, 14.586653961651223, 13.66671534425571, 6.8486720508716346, 5.838416324252299, 4.856392021899731, 3.900498381587642, 2.8788107527989526, 2.0080662238201477, 2.8948854546994602, 3.8707575874519926, 4.837345410220436, 5.7784322960366605, 6.740839210661233, 7.675737244305879, 8.744317804105794, 9.74191711031397, 10.662178166096492, 11.58784935251167, 12.591733860765778, 13.592158629297499, 13.623818923154799, 12.66927278657831, 5.893499769929823, 4.853865562012037, 3.864735317417968, 2.9234685428954617, 1.934071222221875, 1.0632370601013124, 1.9386169937631226, 2.9054755946289053, 3.9005138447093683, 4.852049291602217, 5.884283704135462, 6.790076315140736, 7.801553585664071, 8.7466350162656, 9.668308852845643, 10.633523395947691, 11.663164031597807, 12.706738954339407, 12.634827496358696, 11.680834168357125, 4.931430319103326, 3.8972275762449295, 2.914360774197918, 1.9519254781683884, 0.9832992300216209, 0.0, 0.9360906039359919, 1.912174593123102, 2.9259369639826778, 3.8670819234224996, 4.873968421619573, 5.850742099950557, 6.821349752183881, 7.781205482428585, 8.742219442673504, 9.793335696567464, 10.8263196347987, 11.828656338607056, 11.665479593788671, 10.66276428366852, 5.895142302625212, 4.822428877764305, 3.844404952347431, 2.936817177691594, 1.9449298923921112, 0.9325988647476688, 1.9472287026183812, 2.917473823674009, 3.904464763812279, 4.807104569600016, 5.762233135467619, 6.6977239875061265, 7.63174360990355, 8.608974470962867, 9.637172069058064, 10.596383896284932, 11.549834778623834, 11.663452025991345, 10.706788226292227, 9.672969762548693, 6.820797624378454, 5.871614380327907, 4.857367234748123, 3.8918989934453574, 2.961830052272055, 1.9800075868862022, 2.9193357380563265, 3.9219509156165877, 4.887761618196824, 5.829827321736874, 6.695434751632268, 7.7219234315009055, 8.634709489555275, 9.61083196598496, 10.604267826071327, 11.553328127652275, 11.695264759444962, 10.742330938213076, 9.733422420501753, 8.748240662575817, 7.764934622738503, 6.88418524998679, 5.930161742738088, 4.864571899658651, 3.8971205981570356, 2.9812521505752194, 3.9521361919035476, 4.920001944977507, 5.848616511599826, 6.817894448798986, 7.718340511803053, 8.6668165635516, 9.65047299165511, 10.596930276710475, 11.536302641902001, 11.758360550507293, 10.801811402538407, 9.852441573699075, 8.862547603907927, 7.82098122384872, 8.72098539191913, 7.8457367289127875, 6.85787824589558, 5.869874923107291, 4.8648683633692755, 3.908750602980458, 4.9481613238796704, 5.893076502043922, 6.813483196151482, 7.774352435008823, 8.664290584256914, 9.629638367117613, 10.604773334399194, 11.568817758373154, 11.712953797601124, 10.764641203537284, 9.832726685280976, 8.859821483533043, 7.788195580311049, 6.8616680017996785, 9.71514161938441, 8.771896925670925, 7.798993616828529, 6.851117372731515, 5.858013146736296, 4.915799122864921, 5.88999343583135, 6.849542030352089, 7.805933556336047, 8.766842837782223, 9.654848937848728, 10.565717264220591, 11.5099844016347, 11.811955980224257, 10.786215975620507, 9.837180250513303, 8.879161377274572, 7.9371048751171225, 6.937547484357459, 6.005349809765798, 10.758970782918757, 9.697734935384688, 8.751564345768829, 7.826543890214353, 6.8494566801468615, 5.854235800997973, 6.82814433072759, 7.839468333733423, 8.763046745512451, 9.742307587116418, 10.667539541669703, 11.527010208305885, 12.501012928377193, 12.71246744217285, 11.742265346854929, 10.797697668210844, 9.832035116011959, 8.921941562174691, 7.898267144006657, 6.960474372202795, 11.712796670136361, 10.75262693648371, 9.763665638101806, 8.786334536300144, 7.835798956119155, 6.869943831961374, 7.7975349116955375, 8.770892753859018, 9.700428223041815, 10.727788985450424, 11.610784555821777, 12.565397393500973, 13.541677918775594, 13.712517308392764, 12.717959612660271, 11.76145407238831, 10.814257844183413, 9.849995794566201, 8.867952549831623, 7.813099273793102, 12.693039213119885, 11.717048966177483, 10.707982417298071, 9.713868725509977, 8.875444631227435, 7.923210449812871, 8.824016242551739, 9.754742460714636, 10.643987196017994, 11.589036487790938, 12.636675727319135, 13.59280712696575, 13.691980163071054, 13.024639983417565, 12.06554283183039, 12.79842050871219, 11.828829477119491, 10.805484202659498, 9.737960873362823, 8.705456846902052, 13.627577014244487, 12.613438591123552, 11.662471264563479, 10.716517292050305, 9.839489149253199, 8.854812305403348, 9.772831952589184, 10.732016183806401, 11.675781023927657, 12.566116633544736, 13.640189386530228, 13.686852478425397, 12.760626117079008, 12.040340299846644, 11.091751974453263, 11.776326891205576, 12.695623144588227, 11.638939807945016, 10.637752323403644, 9.574313843303841, 14.579210785414006, 13.627583173868793, 12.688297979655951, 11.760693157637196, 10.77799749513288, 9.794181907068884, 10.710839793195646, 11.679981656548456, 12.69576502251633, 13.58810403538234, 13.571517055234528, 12.667639552887978, 11.825577805101574, 10.974793255051333, 10.023712726761834, 10.78531884793337, 11.772899695845062, 12.550882139081303, 11.489923410996258, 10.503368421900053, 15.549162623955395, 14.676211084715106, 13.734032424806669, 12.783423289118472, 11.838615479379511, 10.79266330353987, 11.71191005085504, 12.681401300782932, 13.679226356330815, 13.554020844468305, 12.575021593342752, 11.648989866442424, 10.833145917324561, 9.90290574632273, 8.963120618461293, 9.782360949176434, 10.792055419752732, 11.761858075631299, 12.4451190084585, 11.567901559197956, 16.47684825758957, 15.6459323519556, 14.734826320931063, 13.752708713959722, 12.81610228146786, 11.74180788186254, 12.669582591544216, 13.64666139720751, 13.549682784972395, 12.634586134203444, 11.628321469930675, 10.64630248857828, 9.785743633238244, 8.905607796552037, 7.990898463398657, 8.785805512216777, 9.799422375679306, 10.710652025602647, 11.661844360753852, 12.629548422419644], [12.615101738128194, 11.669060447503371, 10.707340570106064, 9.752344020589764, 8.769649786457594, 7.805759989824258, 6.915443528757803, 7.8827883081566625, 8.727417625091809, 9.679826707114314, 10.722889654886245, 11.662608659979659, 12.592588345200705, 12.763901330328638, 13.619147547657725, 14.628470542691087, 15.68025687602145, 16.609461048892822, 17.608813480676805, 18.39721108703209, 11.54341598077517, 10.726190113825062, 9.769854802689201, 8.77986283144748, 7.746524487056898, 6.83193084625421, 5.872977510231122, 6.853662963769823, 7.798964186114048, 8.759529513893172, 9.6919590949343, 10.62477722874756, 11.677515907585564, 12.687928186159136, 13.721167347283902, 14.586306432146904, 15.431114249714572, 16.39719309018526, 17.420927550239156, 17.441454356095754, 10.537634193558524, 9.741718851559213, 8.773845616611943, 7.775615313303316, 6.776736231836607, 5.833913036275175, 4.877838950792957, 5.8388452931244945, 6.823072376192188, 7.764846007656587, 8.699214317107469, 9.686560732685681, 10.723684037132603, 11.702966715098707, 12.696084068367776, 13.646907843711725, 14.45984062507189, 15.447441314133592, 16.4069219339531, 16.54207086929307, 9.56961488596344, 8.67891750672621, 7.763920228744744, 6.760996490096361, 5.715163077553597, 4.835536481176311, 3.8786453682366346, 4.790460598090215, 5.828753284685604, 6.786934344816556, 7.733261992083043, 8.724414195810388, 9.773230348089493, 10.721211036758252, 11.704552299439069, 12.591884150648914, 13.522569530195518, 14.51405759484013, 15.441429752730716, 15.586098731838113, 8.638179204039332, 7.667926181889542, 6.73223091761581, 5.813461061256132, 4.754307547801997, 3.861520481438878, 2.9117082598564803, 3.8412765186405955, 4.851942995981454, 5.780120910733133, 6.803696163006233, 7.771611081525036, 8.757227017967983, 9.766053756454438, 10.653524430128154, 11.63525045056234, 12.68839532497144, 13.591906685379694, 14.562341772677673, 14.602805948191701, 7.784762654807626, 6.774506928188291, 5.792482625835723, 4.836588985523634, 3.8149013567349446, 2.872443505050665, 1.9587948507634685, 2.9346669835160006, 3.9012548062844448, 4.842341692100668, 5.80474860672524, 6.7396466403698865, 7.808227200169801, 8.805826506377977, 9.726087562160501, 10.651758748575679, 11.655643256829787, 12.656068025361508, 13.599506734181249, 13.6053633905143, 6.829590373865814, 5.789956165948028, 4.80082592135396, 3.8595591468314536, 2.870161826157867, 1.9276143413318296, 1.0025263898271308, 1.9693849906929137, 2.964423240773377, 3.9159586876662242, 4.948193100199469, 5.853985711204743, 6.865462981728078, 7.810544412329608, 8.732218248909652, 9.6974327920117, 10.727073427661816, 11.770648350403416, 12.72299380103319, 12.616924772293116, 5.867520923039318, 4.833318180180921, 3.85045137813391, 2.88801608210438, 1.9193898339576128, 0.9360906039359919, 0.0, 0.97608398918711, 1.9898463600466856, 2.930991319486507, 3.9378778176835803, 4.914651496014564, 5.885259148247888, 6.845114878492592, 7.806128838737512, 8.857245092631471, 9.890229030862706, 10.892565734671061, 11.836673428750988, 11.598854887604512, 6.831232906561205, 5.758519481700297, 4.780495556283423, 3.8729077816275854, 2.881020496328103, 1.8686894686836606, 1.0111380986823892, 1.9813832197380172, 2.968374159876287, 3.871013965664023, 4.826142531531626, 5.761633383570134, 6.695653005967557, 7.672883867026873, 8.70108146512207, 9.660293292348937, 10.61374417468784, 11.583039827898993, 11.642878830228218, 10.609060366484684, 7.756888228314445, 6.807704984263898, 5.793457838684114, 4.8279895973813485, 3.897920656208047, 2.916098190822194, 1.9832451341203343, 2.9858603116805957, 3.951671014260832, 4.893736717800882, 5.759344147696275, 6.785832827564913, 7.6986188856192825, 8.674741362048968, 9.668177222135334, 10.61723752371628, 11.667490769478457, 11.678421542149069, 10.669513024437746, 9.68433126651181, 8.701025226674494, 7.820275853922781, 6.866252346674079, 5.800662503594642, 4.833211202093027, 3.917342754511211, 3.047679018844761, 4.01554477191872, 4.912525907663834, 5.881803844862994, 6.78224990786706, 7.730725959615608, 8.714382387719118, 9.660839672774483, 10.600212037966008, 11.593985849583024, 11.7379020064744, 10.788532177635068, 9.79863820784392, 8.757071827784713, 9.657075995855122, 8.78182733284878, 7.793968849831571, 6.805965527043282, 5.800958967305267, 4.84484120691645, 4.043704150820884, 4.988619328985136, 5.87739259221549, 6.838261831072831, 7.728199980320922, 8.693547763181622, 9.668682730463203, 10.63272715443716, 11.574352655371348, 11.700731807473277, 10.768817289216969, 9.795912087469036, 8.724286184247042, 7.797758605735671, 10.6512322233204, 9.707987529606918, 8.73508422076452, 7.787207976667506, 6.794103750672287, 5.851889726800913, 5.04356599363281, 6.003114588153549, 6.934559452678304, 7.872880607809435, 8.718758333912735, 9.6296266602846, 10.573893797698709, 11.597319564678667, 11.7223065795565, 10.773270854449295, 9.815251981210565, 8.873195479053114, 7.8736380882934505, 6.941440413701789, 11.695061386854748, 10.633825539320679, 9.68765494970482, 8.762634494150344, 7.785547284082853, 6.790326404933965, 5.98171688852905, 6.993040891534884, 7.891672641854708, 8.84834535714363, 9.73144893773371, 10.590919604369894, 11.564922324441202, 12.626427647934769, 12.678355950790923, 11.733788272146839, 10.768125719947953, 9.858032166110682, 8.834357747942647, 7.896564976138786, 12.648887274072353, 11.6887175404197, 10.699756242037797, 9.722425140236135, 8.771889560055147, 7.806034435897366, 6.951107469496997, 7.924465311660478, 8.829054119384072, 9.85641488179268, 10.674693951885784, 11.629306789564982, 12.605587314839603, 13.217688168722153, 13.654050216596266, 12.697544676324304, 11.750348448119404, 10.786086398502192, 9.804043153767614, 8.749189877729092, 13.629129817055876, 12.653139570113474, 11.644073021234062, 10.649959329445968, 9.811535235163426, 8.859301053748862, 7.977588800353198, 8.908315018516097, 9.77261309236025, 10.717662384133195, 11.722386273558266, 12.65671652302976, 12.755889559135063, 12.168534575399212, 12.863961128414678, 13.734511112648185, 12.764920081055482, 11.741574806595489, 10.674051477298814, 9.641547450838043, 14.563667618180478, 13.549529195059543, 12.59856186849947, 11.652607895986296, 10.77557975318919, 9.790902909339339, 8.926404510390643, 9.88558874160786, 10.804406920269914, 11.694742529886993, 12.761621945889198, 12.750761874489406, 11.824535513143017, 11.113924484973802, 11.890170271037551, 12.712417495141567, 13.63171374852422, 12.57503041188101, 11.573842927339637, 10.510404447239834, 15.515301389349997, 14.563673777804784, 13.624388583591942, 12.696783761573187, 11.71408809906887, 10.730272511004875, 9.864412350997105, 10.833554214349913, 11.83764872740974, 12.716729931724597, 12.635426451298537, 11.731548948951987, 10.889487201165583, 10.048377440178491, 10.822131023346122, 11.721409451869361, 12.708990299781053, 13.486972743017295, 12.426014014932251, 11.439459025836046, 16.485253227891384, 15.612301688651097, 14.67012302874266, 13.719513893054463, 12.774706083315502, 11.72875390747586, 10.8654826086565, 11.83497385858439, 12.832798914132274, 12.617930240532313, 11.638930989406761, 10.712899262506433, 9.89705531338857, 8.976489931449889, 9.76153891504558, 10.718451553112425, 11.728146023688723, 12.69794867956729, 13.381209612394493, 12.50399216313395, 17.41293886152556, 16.582022955891592, 15.670916924867054, 14.688799317895713, 13.75219288540385, 12.677898485798531, 11.823155149345675, 12.800233955008968, 12.613592181036404, 11.698495530267452, 10.692230865994684, 9.71021188464229, 8.849653029302253, 7.969517192616045, 8.789316759982945, 9.721896116152768, 10.735512979615297, 11.646742629538638, 12.597934964689843, 13.565639026355637], [13.591185727315303, 12.645144436690483, 11.683424559293176, 10.728428009776875, 9.745733775644704, 8.781843979011368, 7.891527517944913, 7.105053687768729, 7.949683004703875, 8.853300271464162, 9.816037929759288, 10.71371578937377, 11.643695474594816, 12.654157034236816, 13.59751325488705, 14.606836249920411, 15.491730071355814, 16.420934244227187, 17.439402616015595, 18.397342561473703, 12.519499969962279, 11.702274103012174, 10.745938791876313, 9.755946820634591, 8.722608476244009, 7.80801483544132, 6.849061499418232, 6.075928343381889, 7.021229565726115, 7.814249419365384, 8.74667900040651, 9.675884358141671, 10.728623036979675, 11.711844196972029, 12.745083358096796, 13.610222442959794, 14.455030260527462, 15.42110910099815, 16.444843561052043, 17.376222701461828, 11.513718182745633, 10.717802840746323, 9.749929605799053, 8.751699302490426, 7.752820221023717, 6.809997025462285, 5.853922939980067, 5.061110672736561, 6.045337755804255, 6.796443194420542, 7.730811503871423, 8.710476743498571, 9.747600047945493, 10.7268827259116, 11.72000007918067, 12.670823854524615, 13.48375663588478, 14.471357324946482, 15.43083794476599, 16.4279862871449, 10.545698875150547, 9.65500149591332, 8.740004217931855, 7.737080479283471, 6.691247066740707, 5.811620470363421, 4.854729357423745, 4.0127259777022815, 5.0143456637528585, 5.818531531580511, 6.757178002895933, 7.748330206623278, 8.797146358902383, 9.745127047571144, 10.728468310251959, 11.615800161461804, 12.546485541008408, 13.53797360565302, 14.465345763543606, 15.444006545365797, 9.61426319322644, 8.644010171076651, 7.70831490680292, 6.789545050443242, 5.730391536989107, 4.837604470625989, 3.8877922490435903, 3.0635418982526623, 4.004982968210548, 4.804036921546023, 5.827612173819123, 6.795527092337926, 7.781143028780873, 8.78996976726733, 9.677440440941044, 10.65916646137523, 11.71231133578433, 12.615822696192584, 13.586257783490563, 14.517002102944428, 8.760846643994737, 7.750590917375401, 6.768566615022833, 5.812672974710744, 4.790985345922055, 3.848527494237775, 2.9348788399505787, 2.032518613906099, 2.9638200912068142, 3.8662577029135576, 4.82866461753813, 5.763562651182776, 6.832143210982691, 7.829742517190869, 8.750003572973391, 9.675674759388569, 10.679559267642677, 11.679984036174398, 12.623422744994139, 13.689341758068837, 7.805674363052925, 6.766040155135139, 5.776909910541071, 4.835643136018564, 3.846245815344977, 2.9036983305189397, 1.9786103790142409, 1.0339538617181732, 2.0192689746198558, 2.9398746984791146, 3.97210911101236, 4.877901722017633, 5.889378992540969, 6.834460423142499, 7.756134259722542, 8.72134880282459, 9.750989438474706, 10.794564361216306, 11.74690981184608, 12.700903139847652, 6.843604912226429, 5.809402169368032, 4.8265353673210205, 3.8641000712914906, 2.895473823144723, 1.912174593123102, 0.97608398918711, 0.0, 1.0137623708595755, 1.9549073302993973, 2.9617938284964707, 3.9385675068274546, 4.909175159060779, 5.869030889305483, 6.8300448495504025, 7.881161103444363, 8.9141450416756, 9.916481745483955, 10.860589439563881, 11.869341547691851, 7.807316895748315, 6.734603470887408, 5.756579545470534, 4.848991770814696, 3.857104485515213, 2.8447734578707706, 1.9872220878694993, 1.0506405602197457, 2.0376315003580157, 2.8949299764769134, 3.850058542344516, 4.785549394383024, 5.719569016780447, 6.696799877839763, 7.72499747593496, 8.684209303161829, 9.637660185500732, 10.606955838711887, 11.563619638411005, 11.585144355671796, 8.732972217501556, 7.78378897345101, 6.769541827871226, 5.80407358656846, 4.874004645395157, 3.892182180009304, 2.9593291233074446, 2.0551176521623242, 3.0209283547425603, 3.923135764670838, 4.783260158509165, 5.809748838377803, 6.7225348964321725, 7.698657372861859, 8.692093232948224, 9.64115353452917, 10.691406780291347, 11.573836075466849, 11.645597013624856, 10.66041525569892, 9.677109215861606, 8.796359843109892, 7.842336335861191, 6.776746492781754, 5.809295191280137, 4.8934267436983205, 4.023763008031871, 3.099232331561481, 3.9817832481455624, 4.91120289173295, 5.80616591867995, 6.754641970428498, 7.738298398532008, 8.684755683587372, 9.624128048778898, 10.617901860395914, 11.640551943410498, 11.764616166822178, 10.77472219703103, 9.733155816971824, 10.633159985042234, 9.75791132203589, 8.770052839018682, 7.782049516230392, 6.777042956492377, 5.820925196103559, 5.019788140007994, 4.072306888627896, 4.946649932697219, 5.867660877942787, 6.752115991133812, 7.7174637739945116, 8.692598741276093, 9.65664316525005, 10.598268666184238, 11.611621207365923, 11.744901278404079, 10.771996076656146, 9.700370173434152, 8.773842594922781, 11.627316212507512, 10.684071518794028, 9.71116820995163, 8.763291965854616, 7.770187739859397, 6.827973715988022, 6.01964998281992, 5.141293670543504, 6.003816793160032, 6.902279654679392, 7.742674344725626, 8.65354267109749, 9.597809808511599, 10.621235575491557, 11.525006488164854, 11.749354843636407, 10.791335970397677, 9.849279468240226, 8.849722077480562, 7.917524402888901, 12.671145376041858, 11.609909528507789, 10.66373893889193, 9.738718483337454, 8.761631273269963, 7.766410394121074, 6.95780087771616, 6.184178095507948, 6.960929982336436, 7.877744404013587, 8.755364948546601, 9.614835615182784, 10.588838335254092, 11.650343658747659, 12.591084089025745, 12.709872261333949, 11.744209709135063, 10.834116155297796, 9.81044173712976, 8.872648965325897, 13.624971263259463, 12.66480152960681, 11.675840231224907, 10.698509129423245, 9.747973549242257, 8.782118425084475, 7.927191458684107, 7.123276931377128, 7.898311459865799, 8.925672222274407, 9.698609962698676, 10.653222800377872, 11.629503325652493, 12.556704238706368, 13.602400101743775, 13.673628665511414, 12.726432437306517, 11.762170387689306, 10.780127142954727, 9.725273866916204, 14.605213806242986, 13.629223559300584, 12.620157010421172, 11.626043318633078, 10.787619224350536, 9.835385042935972, 8.953672789540308, 8.107126638232748, 8.84187043284198, 9.786919724614924, 10.746302284371158, 11.68063253384265, 11.97815493874713, 13.009865387017351, 13.840045117601788, 14.710595101835295, 13.741004070242596, 12.717658795782599, 11.650135466485924, 10.617631440025153, 15.539751607367588, 14.525613184246653, 13.57464585768658, 12.628691885173406, 11.7516637423763, 10.766986898526449, 9.902488499577753, 9.165708331735194, 9.873664260751642, 10.763999870368721, 11.78553795670209, 11.973027254101474, 11.046800892755083, 11.978395001011972, 12.866254260224661, 13.688501484328677, 14.607797737711328, 13.551114401068117, 12.549926916526745, 11.486488436426942, 16.491385378537107, 15.539757766991894, 14.600472572779053, 13.672867750760297, 12.69017208825598, 11.706356500191985, 10.840496340184215, 10.148907216827785, 10.906906067891468, 11.785987272206325, 11.857691830910605, 10.953814328564055, 10.11175258077765, 11.024461429365601, 11.798215012533232, 12.697493441056471, 13.685074288968163, 14.463056732204404, 13.40209800411936, 12.415543015023154, 17.461337217078494, 16.588385677838207, 15.64620701792977, 14.695597882241573, 13.750790072502612, 12.704837896662971, 11.84156659784361, 11.218675135099383, 11.904763711241213, 11.840195620144382, 10.86119636901883, 9.935164642118501, 9.119320693000637, 9.952573920636999, 10.73762290423269, 11.694535542299535, 12.704230012875833, 13.674032668754402, 14.3572936015816, 13.480076152321057, 18.38902285071267, 17.558106945078702, 16.647000914054164, 15.664883307082823, 14.72827687459096, 13.653982474985641, 12.799239138532785, 12.18393523152396, 11.664699310430516, 10.855297850662796, 9.865704430344532, 8.932477264254356, 8.07191840891432, 8.945601181803156, 9.765400749170055, 10.697980105339878, 11.711596968802407, 12.62282661872575, 13.574018953876955, 14.541723015542745], [14.60494809817488, 13.64161720312648, 12.679897325729172, 11.724900776212872, 10.7422065420807, 9.739482814929005, 8.84916635386255, 7.971506111266006, 6.962470882765275, 7.839537900604586, 8.802275558899714, 9.699953418514196, 10.629933103735242, 11.640394663377242, 12.583750884027475, 13.593073879060837, 14.47796770049624, 15.407171873367611, 16.425640245156018, 17.383580190614126, 13.533262340821857, 12.69874686944817, 11.742411558312309, 10.752419587070587, 9.719081242680005, 8.765653671358956, 7.806700335335869, 6.9600552725914735, 6.034017443787515, 6.800487048505809, 7.732916629546936, 8.662121987282097, 9.714860666120101, 10.698081826112452, 11.731320987237218, 12.59646007210022, 13.441267889667888, 14.407346730138576, 15.431081190192469, 16.36246033060225, 12.52748055360521, 11.7315652116059, 10.763691976658631, 9.76546167335, 8.749292987459715, 7.7676358613799215, 6.811561775897704, 5.945237601946145, 5.052108821078961, 5.782680823560966, 6.717049133011847, 7.696714372638997, 8.73383767708592, 9.713120355052023, 10.706237708321092, 11.657061483665041, 12.469994265025205, 13.457594954086908, 14.417075573906416, 15.414223916285325, 11.559461246010125, 10.668763866772897, 9.75376658879143, 8.750842850143046, 7.705009437600283, 6.769259306281057, 5.812368193341381, 4.896852906911866, 4.000583292893283, 4.8047691607209355, 5.743415632036357, 6.734567835763703, 7.783383988042809, 8.731364676711568, 9.714705939392385, 10.60203779060223, 11.532723170148834, 12.524211234793446, 13.451583392684032, 14.430244174506223, 10.628025564086018, 9.657772541936229, 8.722077277662496, 7.803307421302818, 6.744153907848683, 5.826397546318274, 4.845431084961227, 3.9476688274622465, 2.9912205973509725, 3.7902745506864473, 4.813849802959547, 5.781764721478351, 6.767380657921298, 7.776207396407754, 8.66367807008147, 9.645404090515656, 10.698548964924752, 11.602060325333007, 12.572495412630985, 13.50323973208485, 9.774609014854311, 8.764353288234977, 7.782328985882409, 6.82643534557032, 5.80474771678163, 4.8373205699300605, 3.8925176758682154, 2.916645543115683, 1.950057720347239, 2.8524953320539823, 3.8149022466785545, 4.749800280323202, 5.818380840123116, 6.815980146331294, 7.736241202113815, 8.661912388528991, 9.6657968967831, 10.66622166531482, 11.609660374134561, 12.675579387209261, 8.8194367339125, 7.779802525994714, 6.790672281400646, 5.849405506878139, 4.860008186204553, 3.8924914062112252, 2.9674034547065262, 2.0005448538407435, 1.0055066037602802, 1.926112327619539, 2.958346740152784, 3.8641393511580575, 4.875616621681394, 5.820698052282924, 6.742371888862966, 7.707586431965013, 8.73722706761513, 9.78080199035673, 10.733147440986505, 11.687140768988076, 7.8573672830860035, 6.823164540227607, 5.840297738180595, 4.8778624421510655, 3.9092361940042983, 2.9259369639826773, 1.9898463600466856, 1.0137623708595755, 0.0, 0.9411449594398218, 1.948031457636895, 2.924805135967879, 3.8954127882012037, 4.855268518445907, 5.816282478690827, 6.867398732584787, 7.900382670816023, 8.902719374624377, 9.846827068704304, 10.855579176832274, 8.82107926660789, 7.748365841746983, 6.770341916330109, 5.862754141674271, 4.870866856374789, 3.8585358287303464, 3.000984458729075, 2.0494273234362215, 1.0624363832979515, 1.8811676056173376, 2.8362961714849404, 3.7717870235234483, 4.705806645920871, 5.683037506980187, 6.711235105075384, 7.670446932302252, 8.623897814641154, 9.59319346785231, 10.549857267551427, 11.583675731294962, 9.74673458836113, 8.797551344310584, 7.7833041987308, 6.817835957428034, 5.887767016254733, 4.905944550868879, 3.9730914941670203, 3.0539044153788, 2.045733237682496, 2.9093733938112623, 3.7694977876495894, 4.795986467518227, 5.708772525572597, 6.684895002002283, 7.678330862088649, 8.627391163669595, 9.677644409431771, 10.560073704607271, 11.568982222318594, 11.674177626558496, 10.69087158672118, 9.810122213969466, 8.856098706720765, 7.790508863641328, 6.823057562139713, 5.907189114557896, 4.970962659532196, 4.003096906458237, 3.0065881310854983, 3.8974405208733742, 4.792403547820374, 5.740879599568922, 6.724536027672432, 7.670993312727797, 8.610365677919322, 9.604139489536337, 10.626789572550923, 11.571000495767008, 11.788484567890606, 10.7469181878314, 11.646922355901808, 10.771673692895464, 9.783815209878256, 8.795811887089968, 7.790805327351952, 6.834687566963135, 5.951606904909745, 4.9372642879342115, 3.9714548156371543, 4.853898507083211, 5.7383536202742365, 6.703701403134936, 7.6788363704165175, 8.642880794390475, 9.584506295324662, 10.597858836506346, 11.529773354762654, 11.785758447515722, 10.714132544293728, 9.787604965782357, 11.803201841116385, 11.697833889653602, 10.724930580811206, 9.777054336714192, 8.783950110718973, 7.841736086847598, 6.944561796604664, 5.985013202083925, 5.028621676099967, 5.888517283819816, 6.72891197386605, 7.6397803002379145, 8.584047437652023, 9.607473204631981, 10.511244117305278, 11.460279842412483, 11.805098341257251, 10.8630418390998, 9.863484448340136, 8.931286773748475, 12.709205174882175, 12.623671899367364, 11.677501309751506, 10.75248085419703, 9.775393644129538, 8.78017276498065, 7.882712691500904, 6.978128513045143, 5.985734865276371, 6.863982033154011, 7.741602577687026, 8.601073244323208, 9.575075964394516, 10.636581287888083, 11.57732171816617, 12.464010612869876, 12.757972079994637, 11.84787852615737, 10.824204107989335, 9.886411336185471, 13.66303106209978, 13.678563900466386, 12.689602602084483, 11.71227150028282, 10.761735920101831, 9.79588079594405, 8.85210327246885, 7.917227348914323, 6.923116342805734, 7.938731497087073, 8.6848475918391, 9.639460429518294, 10.615740954792917, 11.542941867846793, 12.588637730884201, 13.42776701704734, 13.740194808166091, 12.77593275854888, 11.793889513814301, 10.739036237775778, 14.528423297919032, 14.64298593016016, 13.633919381280748, 12.639805689492654, 11.80138159521011, 10.849147413795547, 9.878584603325052, 8.859534052607547, 7.866675315781913, 8.811724607554858, 9.732539913511582, 10.666870162983072, 11.557692046552184, 12.589402494822405, 13.53038470879075, 14.464733453371224, 14.75476644110217, 13.731421166642177, 12.663897837345502, 11.631393810884731, 15.465154355988311, 15.53937555510623, 14.588408228546156, 13.642454256032982, 12.765426113235876, 11.780749269386025, 10.827400313362498, 9.870863035071665, 8.898469143691576, 9.788804753308655, 10.771775585842514, 10.985815132162873, 11.849924725390352, 12.78151883364724, 13.754121836825172, 14.684974250764673, 15.621560108570906, 14.564876771927695, 13.563689287386323, 12.50025080728652, 16.41678812715783, 16.553520137851468, 15.614234943638628, 14.686630121619872, 13.703934459115557, 12.720118871051561, 11.76540815396896, 10.854061920164256, 9.931710950831402, 10.81079215514626, 10.870479708972004, 9.966602206625454, 10.914876413412918, 11.900513688090781, 12.755853848450869, 13.693966207492467, 14.68154705540416, 15.476819103063981, 14.415860374978937, 13.429305385882731, 17.31866145880662, 17.60214804869778, 16.659969388789346, 15.70936025310115, 14.764552443362188, 13.718600267522547, 12.766478411628354, 11.923829838435854, 10.929568594181147, 10.85298349820578, 9.873984247080228, 8.9479525201799, 9.923588685529833, 10.867404390197859, 11.695261740150327, 12.691008308735531, 13.700702779311829, 14.670505435190398, 15.371055972441178, 14.493838523180635, 18.246347092440796, 17.45243076994123, 16.45026814552044, 15.473280061432105, 14.550838690378159, 13.52499994588667, 12.581140844360204, 11.62853940174251, 10.650936939570942, 9.841535479803222, 8.851942059484957, 7.945265142315756, 8.876186401443515, 9.90245256502941, 10.723039585087692, 11.694452871775875, 12.708069735238404, 13.619299385161746, 14.570491720312951, 15.555485386402323], [15.524392698039652, 14.545636804295823, 13.583916926898516, 12.628920377382215, 11.646226143250043, 10.643502416098348, 9.753185955031894, 8.757396084323602, 7.748360855822871, 6.898392941164765, 7.861130599459893, 8.758808459074372, 9.688788144295417, 10.699249703937417, 11.64260592458765, 12.651928919621012, 13.536822741056417, 14.466026913927788, 15.484495285716196, 16.442435231174304, 14.474407300261678, 13.602766470617514, 12.646431159481653, 11.656439188239931, 10.623100843849349, 9.6696732725283, 8.710719936505212, 7.765208639189337, 6.819907416845111, 5.859342089065987, 6.7917716701071145, 7.720977027842273, 8.773715706680278, 9.75693686667263, 10.790176027797397, 11.655315112660396, 12.500122930228065, 13.466201770698753, 14.489936230752646, 15.421315371162427, 13.468625513045032, 12.672710171045722, 11.704836936098452, 10.706606632789825, 9.653312588629058, 8.671655462549266, 7.715581377067048, 6.823688437965366, 5.839461354897672, 4.841535864121145, 5.775904173572026, 6.755569413199174, 7.792692717646095, 8.771975395612202, 9.76509274888127, 10.715916524225218, 11.528849305585382, 12.516449994647083, 13.475930614466593, 14.473078956845502, 12.500606205449946, 11.609908826212719, 10.694911548231252, 9.69198780958287, 8.646154397040105, 7.673278907450402, 6.716387794510726, 5.800872508081211, 4.821805261412067, 3.863624201281114, 4.802270672596536, 5.793422876323881, 6.842239028602987, 7.790219717271746, 8.773560979952563, 9.660892831162407, 10.591578210709011, 11.583066275353623, 12.51043843324421, 13.4890992150664, 11.56917052352584, 10.59891750137605, 9.663222237102318, 8.74445238074264, 7.6852988672885045, 6.767542505758096, 5.749450686130571, 4.851688428631592, 3.8952401985203173, 2.8491295912466255, 3.8727048435197258, 4.8406197620385285, 5.826235698481476, 6.835062436967932, 7.722533110641648, 8.704259131075833, 9.757404005484933, 10.660915365893187, 11.631350453191166, 12.56209477264503, 10.715753974294133, 9.705498247674797, 8.72347394532223, 7.767580305010141, 6.745892676221452, 5.778465529369882, 4.79653727703756, 3.820665144285028, 2.8540773215165838, 1.9113503726141605, 2.8737572872387327, 3.8086553208833793, 4.877235880683294, 5.874835186891472, 6.795096242673994, 7.720767429089171, 8.72465193734328, 9.725076705875, 10.668515414694742, 11.73443442776944, 9.760581693352322, 8.720947485434536, 7.731817240840468, 6.790550466317961, 5.801153145644374, 4.833636365651047, 3.9085484141463476, 2.941689813280565, 1.946651563200102, 0.9849673681797173, 2.0172017807129623, 2.9229943917182357, 3.934471662241572, 4.879553092843102, 5.801226929423144, 6.766441472525192, 7.796082108175308, 8.839657030916909, 9.792002481546684, 10.745995809548255, 8.798512242525826, 7.764309499667429, 6.781442697620418, 5.819007401590888, 4.85038115344412, 3.867081923422499, 2.930991319486507, 1.9549073302993973, 0.9411449594398218, 0.0, 1.006886498197073, 1.983660176528057, 2.954267828761382, 3.914123559006086, 4.875137519251005, 5.926253773144966, 6.959237711376201, 7.961574415184556, 8.905682109264482, 9.914434217392452, 9.762224226047714, 8.689510801186806, 7.711486875769931, 6.8038991011140935, 5.812011815814611, 4.799680788170168, 3.8903105264344804, 2.9200654053788524, 1.9330744652405825, 0.940022646177516, 1.8951512120451188, 2.8306420640836265, 3.76466168648105, 4.741892547540366, 5.770090145635563, 6.729301972862431, 7.6827528552013336, 8.652048508412488, 9.608712308111606, 10.64253077185514, 10.687879547800954, 9.738696303750407, 8.724449158170623, 7.758980916867857, 6.828911975694554, 5.847089510308701, 4.862417561872426, 3.924542497321431, 2.9102941379114915, 1.968228434371441, 2.828352828209768, 3.8548415080784055, 4.767627566132775, 5.7437500425624615, 6.737185902648828, 7.686246204229773, 8.73649944999195, 9.61892874516745, 10.627837262878773, 11.613019020804709, 11.632016546161003, 10.751267173409289, 9.797243666160588, 8.731653823081151, 7.740543550267455, 6.80640760108952, 5.835523559761191, 4.867657806687232, 3.8711490313144936, 2.956295561433553, 3.8512585883805532, 4.799734640129102, 5.783391068232611, 6.729848353287975, 7.669220718479501, 8.662994530096515, 9.685644613111101, 10.629855536327186, 11.619749506118334, 11.688063147271222, 11.594515142484703, 11.712818652335287, 10.724960169318079, 9.71329787521771, 8.708291315479695, 7.733906053494758, 6.816167805138741, 5.801825188163207, 4.83601571586615, 3.9127535476433897, 4.797208660834415, 5.762556443695114, 6.737691410976696, 7.701735834950654, 8.64336133588484, 9.656713877066524, 10.588628395322832, 11.561533597070765, 11.65527750373355, 10.72874992522218, 10.862056881676564, 11.832371748040222, 11.642416568938948, 10.694540324841935, 9.68515145942699, 8.74095457337922, 7.80912269683366, 6.84957410231292, 5.893182576328963, 4.9473723243799945, 5.787767014426229, 6.698635340798093, 7.642902478212201, 8.66632824519216, 9.570099157865457, 10.519134882972661, 11.477153756211392, 11.804186798539623, 10.80462940777996, 9.872431733188298, 11.768060215442354, 12.829296062976423, 12.594987297879248, 11.669434872044171, 10.674612130661162, 9.679391251512273, 8.7472735917299, 7.8426894132741385, 6.850295765505367, 5.92283707371419, 6.800457618247204, 7.659928284883387, 8.633931004954693, 9.695436328448261, 10.636176758726348, 11.522865653430054, 12.430027494948778, 12.789023485597191, 11.765349067429156, 10.827556295625293, 12.721886102659958, 13.782769514338627, 13.607088590212225, 12.629225518129962, 11.637352546768621, 10.67149742261084, 9.716664172697847, 8.781788249143318, 7.78767724303473, 6.997586537647251, 7.743702632399279, 8.698315470078473, 9.674595995353094, 10.60179690840697, 11.64749277144438, 12.48662205760752, 13.493827407361247, 13.717077717988701, 12.735034473254123, 11.6801811972156, 13.587278338479212, 14.563268585421614, 14.55140536940849, 13.556759707339795, 12.6769982218769, 11.724764040462336, 10.743145503554047, 9.724094952836543, 8.73123621601091, 8.068490855981715, 8.79139495407176, 9.72572520354325, 10.61654708711236, 11.648257535382582, 12.589239749350929, 13.523588493931403, 14.508399040297327, 14.672566126081998, 13.605042796785323, 12.572538770324552, 14.524009396548488, 15.51269422312055, 15.505362246393297, 14.559408273880123, 13.641042739902664, 12.656365896052813, 11.691961213591492, 10.73542393530066, 9.763030043920573, 9.045571001735512, 9.830630626402693, 10.779971441915752, 11.547901133104407, 12.479495241361295, 13.452098244539227, 14.517495761169057, 15.462705995082517, 15.506021731367516, 14.504834246826144, 13.441395766726341, 15.475643167718006, 16.449230068316613, 16.48985157030542, 15.562246748286661, 14.579551085782345, 13.59573549771835, 12.629969054197954, 11.718622820393252, 10.796271851060398, 10.067558403573116, 9.95501767437033, 10.75249217968305, 11.700766386470514, 12.686403661148377, 13.653671599417436, 14.59562285580413, 15.583203703715823, 16.417964062503803, 15.357005334418758, 14.370450345322553, 16.377516499366795, 17.43478381995742, 16.50185763557665, 15.551248499888452, 14.60668386447249, 13.532999564769515, 12.597668425609555, 11.652654538727262, 10.723047270901256, 9.937521463604106, 8.958522212478554, 9.733842493237496, 10.70947865858743, 11.653294363255457, 12.593079491116894, 13.592664957047194, 14.602359427623492, 15.574525036359741, 16.312200931880998, 15.434983482620456, 17.30520213300097, 16.51128581050141, 15.509123186080616, 14.532135101992282, 13.609693730938334, 12.583854986446845, 11.63999588492038, 10.687394442302685, 9.709791980131117, 8.9003905203634, 7.910797100045135, 8.731155115373353, 9.662076374501114, 10.688342538087008, 11.627059186257036, 12.598472472945218, 13.612089336407747, 14.52331898633109, 15.474511321482295, 16.496630345842146], [16.531279196236728, 15.552523302492897, 14.59080342509559, 13.63580687557929, 12.653112641447118, 11.650388914295423, 10.760072453228966, 9.764282582520673, 8.755247354019943, 7.905279439361838, 7.179799658259532, 7.9248364354699685, 8.854816120691014, 9.747241674473331, 10.690597895123565, 11.654531987136048, 12.529936242859343, 13.459140415730714, 14.477608787519122, 15.435548732977228, 15.48129379845875, 14.609652968814588, 13.653317657678727, 12.663325686437005, 11.629987342046423, 10.676559770725374, 9.717606434702285, 8.77209513738641, 7.826793915042184, 6.86622858726306, 6.110440728906754, 6.88700500423787, 7.904336549124496, 8.750050368475558, 9.783289529600323, 10.648428614463322, 11.49323643203099, 12.459315272501678, 13.483049732555571, 14.414428872965352, 14.475512011242104, 13.679596669242795, 12.711723434295525, 11.713493130986897, 10.660199086826132, 9.67854196074634, 8.72246787526412, 7.830574936162439, 6.846347853094745, 5.848422362318217, 5.083807006099186, 5.921597389594771, 6.875075904231474, 7.765088897415128, 8.758206250684196, 9.709030026028143, 10.521962807388308, 11.50956349645001, 12.469044116269519, 13.466192458648427, 13.507492703647019, 12.616795324409791, 11.701798046428326, 10.698874307779942, 9.653040895237178, 8.680165405647475, 7.723274292707799, 6.807759006278284, 5.828691759609139, 4.870510699478187, 4.058337996940931, 4.959450852719478, 5.895811645492649, 6.783333219074672, 7.76667448175549, 8.654006332965333, 9.584691712511937, 10.576179777156549, 11.503551935047135, 12.482212716869325, 12.576057021722912, 11.605803999573123, 10.670108735299392, 9.751338878939713, 8.692185365485578, 7.774429003955169, 6.756337184327645, 5.858574926828664, 4.90212669671739, 3.8560160894436986, 3.1287721678641205, 4.0066477384341255, 4.823191525883779, 5.828175938770858, 6.715646612444575, 7.69737263287876, 8.75051750728786, 9.654028867696113, 10.624463954994091, 11.555208274447956, 11.722640472491207, 10.712384745871873, 9.730360443519304, 8.774466803207215, 7.752779174418525, 6.785352027566955, 5.803423775234633, 4.827551642482101, 3.860963819713657, 2.9182368708112336, 2.1298246115831274, 2.9746832972789763, 3.874191708085597, 4.867948688694399, 5.78820974447692, 6.713880930892097, 7.7177654391462065, 8.718190207677926, 9.661628916497667, 10.727547929572365, 10.767468191549396, 9.72783398363161, 8.738703739037541, 7.797436964515034, 6.808039643841448, 5.84052286384812, 4.915434912343422, 3.9485763114776384, 2.9535380613971753, 1.9918538663767904, 1.067470744204412, 1.9161078935211626, 2.927585164044499, 3.8726665946460286, 4.794340431226071, 5.759554974328118, 6.7891956099782345, 7.8327705327198345, 8.785115983349609, 9.73910931135118, 9.8053987407229, 8.771195997864503, 7.788329195817491, 6.825893899787961, 5.857267651641194, 4.873968421619573, 3.9378778176835807, 2.9617938284964707, 1.948031457636895, 1.006886498197073, 0.0, 0.9767736783309839, 1.9473813305643088, 2.907237060809013, 3.868251021053932, 4.919367274947891, 5.952351213179127, 6.954687916987481, 7.898795611067408, 8.907547719195378, 10.769110724244786, 9.696397299383879, 8.718373373967005, 7.810785599311167, 6.818898314011683, 5.806567286367241, 4.884518137306815, 3.9142730162511863, 2.9272820761129164, 1.9342302570498497, 0.979101691182247, 1.914592543220755, 2.848612165618178, 3.8258430266774943, 4.854040624772692, 5.81325245199956, 6.766703334338462, 7.735998987549617, 8.692662787248734, 9.726481250992268, 11.694766045998026, 10.74558280194748, 9.731335656367696, 8.76586741506493, 7.835798473891627, 6.853976008505775, 5.85662517274476, 4.901062091453811, 3.8369914606827518, 2.894925757142701, 1.9123033073468962, 2.9387919872155335, 3.8515780452699038, 4.827700521699589, 5.821136381785956, 6.770196683366902, 7.820449929129079, 8.702879224304578, 9.7117877420159, 10.696969499941837, 11.634516390802458, 11.758153671606362, 10.76690750347792, 9.696353189272116, 8.667240873038716, 7.73310492386078, 6.762220882532452, 5.794355129458492, 4.797846354085754, 3.882992884204813, 2.9352090675176816, 3.88368511926623, 4.867341547369739, 5.813798832425103, 6.753171197616629, 7.746945009233645, 8.769595092248231, 9.713806015464314, 10.703699985255462, 11.624228938668933, 10.67846562162183, 11.644110598840012, 11.694624006635411, 10.639995197988972, 9.634988638250956, 8.66060337626602, 7.742865127910002, 6.728522510934468, 5.76271303863741, 4.83945087041465, 3.8811591399715435, 4.846506922832242, 5.821641890113824, 6.785686314087782, 7.727311815021968, 8.740664356203654, 9.672578874459962, 10.645484076207895, 11.717109979429889, 11.735636423419253, 9.85517038347949, 10.825485249843148, 11.852481857866936, 11.621237647613196, 10.611848782198251, 9.667651896150481, 8.701112982517625, 7.741564387996886, 6.785172862012928, 5.824263580566751, 4.871717493563358, 5.782585819935221, 6.726852957349329, 7.750278724329289, 8.654049637002585, 9.60308536210979, 10.56110423534852, 11.50316073750597, 11.811515905977034, 10.879318231385373, 10.76117371724528, 11.822409564779349, 12.768580154395208, 12.596132194815432, 11.601309453432423, 10.606088574283534, 9.639263877413866, 8.734679698958104, 7.742286051189332, 6.799728329900946, 5.884408097384333, 6.743878764020515, 7.717881484091822, 8.779386807585391, 9.720127237863476, 10.606816132567182, 11.513977974085908, 12.488381409907968, 12.772235565626232, 11.834442793822367, 11.714999604462884, 12.775883016141552, 13.780681446728185, 13.525705451685567, 12.529342832452585, 11.563487708294804, 10.608654458381812, 9.673778534827283, 8.679667528718696, 7.874477793834007, 6.8276531115364065, 7.782265949215602, 8.758546474490224, 9.6857473875441, 10.731443250581506, 11.570572536744647, 12.577777886498376, 13.512224496644187, 13.741920971451199, 12.687067695412674, 12.580391840282138, 13.55638208722454, 14.565448636103952, 14.4532396408954, 13.568988507560864, 12.616754326146301, 11.635135789238014, 10.616085238520508, 9.623226501694875, 8.922984672737083, 7.875345433208888, 8.809675682680378, 9.70049756624949, 10.732208014519712, 11.673190228488055, 12.607538973068529, 13.592349519434457, 14.582631359332128, 14.611929294982396, 13.579425268521625, 13.517122898351413, 14.505807724923475, 15.456775051483548, 15.455888207435729, 14.53303302558663, 13.548356181736779, 12.583951499275459, 11.627414220984626, 10.655020329604538, 9.90006481849088, 8.91458110553982, 9.86392192105288, 10.631851612241537, 11.563445720498425, 12.536048723676357, 13.601446240306187, 14.546656474219647, 15.510676143557092, 15.511720745023217, 14.448282264923414, 14.468756669520932, 15.442343570119538, 16.38162876433238, 15.545984182344727, 14.56328851984041, 13.579472931776415, 12.646730653804864, 11.888450433394457, 10.886932890646598, 10.217361212389198, 9.871278508194917, 10.850269469124026, 11.566899924218971, 12.552537198896834, 13.604087971367786, 14.592454283578393, 15.505072517370115, 16.51396055893673, 16.36389183261583, 15.377336843519625, 15.37063000116972, 16.427897321760348, 15.494971137379574, 14.544362001691377, 13.654675835008405, 12.58099153530543, 11.64566039614547, 10.818682515122859, 9.889075247296853, 9.290756859543643, 9.965408710675627, 10.740728991434569, 11.716365156784502, 12.660180861452528, 13.599965989313965, 14.599551455244265, 15.609245925820563, 16.581411534556814, 17.31908743007807, 16.44186998081753, 16.298315634803895, 15.504399312304336, 14.502236687883542, 13.525248603795207, 12.61229679845337, 11.63184695698276, 10.687987855456294, 9.853422418698282, 8.875819956526714, 8.21905957916304, 8.917683598242208, 9.738041613570424, 10.668962872698184, 11.69522903628408, 12.63394568445411, 13.605358971142293, 14.618975834604822, 15.530205484528164, 16.48139781967937, 17.50351684403922], [17.444160720699983, 16.465404826956153, 15.503684949558847, 14.548688400042547, 13.565994165910375, 12.56327043875868, 11.672953977692224, 10.673533036018888, 9.664497807518158, 8.814529892860051, 7.912408389072925, 6.948062757138985, 7.878042442360031, 8.770467996142347, 9.713824216792581, 10.677758308805064, 11.55316256452836, 12.482366737399731, 13.50083510918814, 14.458775054646246, 16.458067476789736, 15.522534493277846, 14.566199182141984, 13.576207210900263, 12.54286886650968, 11.589441295188632, 10.630487959165542, 9.681345590884623, 8.736044368540398, 7.775479040761274, 6.843049459720147, 5.910231325906886, 6.927562870793512, 7.773276690144574, 8.806515851269339, 9.671654936132338, 10.516462753700008, 11.482541594170696, 12.506276054224589, 13.43765519463437, 15.45228568957309, 14.65637034757378, 13.658506620417654, 12.628015562827873, 11.57308061128939, 10.591423485209598, 9.635349399727378, 8.743456460625696, 7.759229377558002, 6.761303886781475, 5.886790047108698, 4.944823711263787, 5.8983022259004905, 6.7883152190841445, 7.7814325723532125, 8.73225634769716, 9.545189129057325, 10.532789818119028, 11.492270437938537, 12.489418780317445, 14.484266381978005, 13.593569002740777, 12.67857172475931, 11.639588376581104, 10.58622006232547, 9.593046930110733, 8.636155817171057, 7.720640530741541, 6.741573284072397, 5.783392223941445, 4.861321037950442, 3.9826771743884932, 4.919037967161665, 5.806559540743688, 6.789900803424506, 7.6772326546343495, 8.607918034180955, 9.599406098825567, 10.526778256716153, 11.505439038538343, 13.552830700053898, 12.582577677904109, 11.646882413630376, 10.728112557270697, 9.668959043816562, 8.740146422385168, 7.669218708790902, 6.771456451291922, 5.815008221180648, 4.768897613906956, 3.931755208873632, 3.029874060103141, 3.846417847552795, 4.851402260439874, 5.738872934113591, 6.720598954547776, 7.773743828956877, 8.67725518936513, 9.64769027666311, 10.578434596116974, 12.699414150822191, 11.689158424202855, 10.707134121850288, 9.751240481538199, 8.729552852749508, 7.762125705897939, 6.716305299697891, 5.740433166945358, 4.773845344176914, 3.831118395274491, 2.932807652592639, 1.9979096189479921, 2.897418029754613, 3.8911750103634146, 4.811436066145936, 5.737107252561114, 6.740991760815223, 7.741416529346944, 8.684855238166685, 9.750774251241383, 11.74424186988038, 10.704607661962594, 9.715477417368525, 8.774210642846018, 7.784813322172432, 6.817296542179104, 5.8922085906744055, 4.925349989808622, 3.9303117397281593, 2.904735390840048, 1.8725009783068027, 0.9393342151901787, 1.950811485713515, 2.8958929163150446, 3.8175667528950874, 4.782781295997135, 5.812421931647251, 6.855996854388852, 7.808342305018626, 8.762335633020198, 10.782172419053882, 9.747969676195487, 8.765102874148475, 7.802667578118945, 6.834041329972178, 5.850742099950557, 4.914651496014565, 3.9385675068274546, 2.924805135967879, 1.983660176528057, 0.9767736783309839, 0.0, 0.9706076522333248, 1.9304633824780286, 2.891477342722948, 3.942593596616908, 4.975577534848144, 5.977914238656499, 6.922021932736426, 7.930774040864395, 11.74588440257577, 10.673170977714863, 9.695147052297989, 8.787559277642151, 7.795671992342667, 6.783340964698225, 5.853792398308494, 4.883547277252866, 3.896556337114596, 2.9035045180515295, 1.9483759521839268, 1.0128851001454189, 1.93217294632147, 2.8874002774903644, 3.9155978755855614, 4.8748097028124295, 5.828260585151332, 6.797556238362486, 7.754220038061604, 8.788038501805138, 11.640210639975377, 11.722356480278464, 10.70810933469868, 9.742641093395914, 8.81257215222261, 7.830749686836759, 6.825899433746439, 5.870336352455492, 4.806265721684432, 3.8642000181443814, 2.8815775683485763, 2.037084544140198, 2.935138825973196, 3.911261302402882, 4.904697162489248, 5.831753934179772, 6.882007179941949, 7.7644364751174475, 8.77334499282877, 9.758526750754706, 10.696073641615328, 11.732583961052956, 11.7361817644796, 10.665627450273796, 9.636515134040396, 8.70237918486246, 7.731495143534132, 6.7636293904601725, 5.767120615087435, 4.852267145206493, 3.9044833285193614, 3.0445561961903973, 3.950902328073031, 4.897359613128396, 5.836731978319921, 6.808502260046515, 7.831152343061101, 8.775363266277184, 9.765257236068331, 10.685786189481803, 9.7400228724347, 10.705667849652881, 11.69352633267009, 11.609269458990651, 10.604262899252635, 9.629877637267699, 8.712139388911682, 7.697796771936147, 6.731987299639091, 5.80872513141633, 4.850433400973223, 4.033367008922684, 4.948609459955476, 5.869247094791074, 6.810872595725261, 7.802221607016524, 8.734136125272832, 9.707041327020764, 10.778667230242759, 11.645099411530845, 8.878396705148507, 9.848711571512165, 10.875708179535954, 11.823584423632967, 11.58112304319993, 10.63692615715216, 9.670387243519304, 8.710838648998566, 7.754447123014607, 6.793537841568431, 5.840991754565037, 4.969445906025663, 5.9137130434397704, 6.833839505032581, 7.737610417705877, 8.686646142813082, 9.644665016051812, 10.586721518209263, 11.586278908968927, 11.856091909716355, 9.784400038914297, 10.845635886448367, 11.791806476064226, 12.789369300726403, 12.570583714434102, 11.575362835285214, 10.608538138415545, 9.703953959959783, 8.711560312191011, 7.769002590902625, 6.8536823583860125, 5.930738850110957, 6.904741570182264, 7.862947588288684, 8.803688018566769, 9.690376913270475, 10.597538754789198, 11.57194219061126, 12.546998568618125, 12.811216472153351, 10.738225926131902, 11.79910933781057, 12.803907768397202, 13.749159946812194, 13.498617093454264, 12.532761969296484, 11.577928719383491, 10.643052795828963, 9.648941789720375, 8.843752054835686, 7.796927372538086, 6.969126035306044, 7.945406560580666, 8.862997454508598, 9.8150040312848, 10.65413331744794, 11.661338667201667, 12.59578527734748, 13.516683974443092, 13.663841373743658, 11.603618161951156, 12.579608408893558, 13.58867495777297, 14.640513860701034, 14.538262768562543, 13.58602858714798, 12.604410050239693, 11.585359499522188, 10.592500762696554, 9.892258933738765, 8.844619694210568, 7.996535768770821, 8.887357652339933, 9.91215104783154, 10.75675100919135, 11.691099753771823, 12.675910300137748, 13.66619214003542, 14.488027030904123, 14.55619894685261, 12.540349220020431, 13.529034046592493, 14.480001373152566, 15.42595534566574, 14.52674569896082, 13.54206885511097, 12.607964816080342, 11.894875640156066, 10.94340101945544, 10.869339079492562, 9.8838553665415, 9.050782007143322, 9.81871169833198, 10.750305806588868, 11.7229088097668, 12.73149138355807, 13.644349592029673, 14.594236924260384, 15.485572197440622, 15.4250559432544, 13.49198299118995, 14.465569891788556, 15.404855086001398, 14.569210504013745, 13.586514841509429, 12.602699253445433, 11.66995697547388, 10.911676755063475, 9.910159212315614, 10.873322444427295, 10.840552769196597, 10.069994932680741, 10.753760010309414, 11.739397284987277, 12.790948057458229, 13.722499426830277, 14.602765635180141, 15.611653676746755, 16.494840643408622, 16.35411052185061, 14.393856322838738, 15.451123643429364, 14.518197459048592, 13.567588323360395, 12.677902156677423, 11.604217856974447, 10.668886717814486, 9.841908836791877, 8.91230156896587, 9.94671809158174, 10.87465916417384, 11.088644619126296, 11.746191898086426, 12.690007602754452, 13.62979273061589, 14.62937819654619, 15.583609911272472, 16.563354610307993, 17.450036240870862, 17.418643659148515, 15.321541956472915, 14.527625633973354, 13.52546300955256, 12.548474925464225, 11.635523120122386, 10.655073278651777, 9.71121417712531, 8.8766487403673, 7.89904627819573, 8.928692364537914, 9.826934051740421, 10.647292067068639, 11.5782133261964, 12.604479489782294, 13.546827208917367, 14.51824049560555, 15.531857359068079, 16.443087008991423, 17.394279344142628, 18.41953560104031], [18.414768372933306, 17.436012479189475, 16.474292601792172, 15.519296052275871, 14.5366018181437, 13.518218237163833, 12.563935350555901, 11.54686680148067, 10.53783157297994, 9.687863658321834, 8.785742154534706, 7.821396522600766, 6.9513122841618085, 7.799860343909022, 8.743216564559255, 9.707150656571741, 10.582554912295036, 11.511759085166407, 12.530227456954815, 13.488167402412921, 17.42867512902306, 16.493142145511168, 15.536806834375309, 14.546814863133587, 13.513476518743005, 12.560048947421956, 11.589187002111881, 10.554679356346405, 9.60937813400218, 8.648812806223056, 7.716383225181929, 6.783565091368668, 5.9569552185601875, 6.802669037911249, 7.835908199036014, 8.701047283899015, 9.545855101466683, 10.511933941937372, 11.535668401991265, 12.467047542401046, 16.422893341806414, 15.626977999807107, 14.629114272650979, 13.598623215061197, 12.543688263522714, 11.562031137442922, 10.605957051960702, 9.71406411285902, 8.729837029791327, 7.731911539014799, 6.857397699342022, 5.818157476725569, 4.927694573667166, 5.81770756685082, 6.810824920119888, 7.761648695463836, 8.574581476824001, 9.562182165885702, 10.521662785705212, 11.51881112808412, 15.45487403421133, 14.564176654974103, 13.649179376992636, 12.610196028814428, 11.556827714558795, 10.563654582344057, 9.606763469404381, 8.691248182974865, 7.712180936305722, 6.7539998761747695, 5.831928690183767, 4.856010939850275, 3.9484303149283404, 4.835951888510364, 5.819293151191181, 6.706625002401025, 7.63731038194763, 8.628798446592242, 9.556170604482828, 10.534831386305019, 14.523438352287224, 13.553185330137435, 12.617490065863702, 11.698720209504023, 10.639566696049888, 9.710754074618492, 8.639826361024227, 7.742064103525246, 6.785615873413972, 5.739505266140281, 4.9023628611069565, 3.9032078255649236, 2.87581019531947, 3.88079460820655, 4.768265281880266, 5.749991302314451, 6.803136176723552, 7.706647537131804, 8.677082624429783, 9.607826943883648, 13.670021803055514, 12.659766076436181, 11.677741774083614, 10.721848133771525, 9.700160504982835, 8.732733358131265, 7.686912951931215, 6.711040819178683, 5.744452996410239, 4.801726047507816, 3.9034153048259634, 2.968517271181317, 1.9268103775212881, 2.92056735813009, 3.840828413912612, 4.766499600327789, 5.770384108581898, 6.770808877113619, 7.71424758593336, 8.780166599008057, 12.714849522113703, 11.675215314195917, 10.686085069601848, 9.744818295079344, 8.755420974405757, 7.7879041944124285, 6.86281624290773, 5.895957642041947, 4.900919391961484, 3.8753430430733724, 2.8431086305401276, 1.9099418674235036, 0.9802038334801902, 1.9252852640817197, 2.8469591006617625, 3.8121736437638103, 4.841814279413926, 5.885389202155526, 6.8377346527853, 7.791727980786872, 11.752780071287205, 10.71857732842881, 9.735710526381798, 8.773275230352269, 7.804648982205502, 6.821349752183881, 5.885259148247889, 4.909175159060779, 3.8954127882012037, 2.954267828761382, 1.9473813305643088, 0.9706076522333248, 0.0, 0.9598557302447038, 1.920869690489623, 2.971985944383583, 4.004969882614819, 5.007306586423173, 5.9514142805031, 6.960166388631069, 11.641017458471985, 11.643778629948185, 10.665754704531311, 9.758166929875474, 8.766279644575992, 7.75394861693155, 6.736492214648644, 5.766247093593016, 4.779256153454746, 3.786204334391679, 2.831075768524076, 1.8955849164855685, 0.9615652940881452, 1.9167926252570395, 2.9449902233522365, 3.9042020505791046, 4.857652932918007, 5.826948586129161, 6.783612385828278, 7.817430849571812, 10.669602987742051, 11.618786231792598, 11.678716986932002, 10.713248745629237, 9.743575831266295, 8.758161398749909, 7.708599250086589, 6.75303616879564, 5.688965538024581, 4.74689983448453, 3.764277384688725, 2.9197843604803473, 1.964531173739871, 2.9406536501695566, 3.934089510255923, 4.861146281946446, 5.911399527708624, 6.793828822884122, 7.802737340595445, 8.78791909852138, 9.725465989382002, 10.76197630881963, 11.650635183594254, 11.548327266613946, 10.519214950380546, 9.58507900120261, 8.61419495987428, 7.6463292068003215, 6.6498204314275835, 5.734966961546642, 4.78718314485951, 3.9272560125305467, 2.9802946758397058, 3.926751960895071, 4.866124326086596, 5.8378946078131895, 6.8605446908277745, 7.804755614043858, 8.794649583835005, 9.715178537248477, 8.769415220201374, 9.735060197419555, 10.722918680436763, 11.783981410883182, 11.486962715592785, 10.512577453607848, 9.594839205251832, 8.580496588276297, 7.6146871159792395, 6.691424947756479, 5.733133217313372, 4.916066825262834, 3.978001807722151, 4.89863944255775, 5.8402649434919365, 6.831613954783198, 7.763528473039506, 8.736433674787438, 9.808059578009432, 10.674491759297519, 7.90778905291518, 8.878103919278837, 9.905100527302626, 10.85297677139964, 11.904643986065206, 11.51962597349231, 10.553087059859452, 9.593538465338714, 8.637146939354755, 7.67623765790858, 6.723691570905186, 5.852145722365813, 4.968028830725476, 5.863231852799257, 6.767002765472553, 7.716038490579757, 8.674057363818488, 9.616113865975938, 10.615671256735602, 11.547868931327264, 8.813792386680971, 9.87502823421504, 10.8211988238309, 11.818761648493076, 12.813584389876086, 12.458062651625363, 11.491237954755693, 10.586653776299931, 9.59426012853116, 8.651702407242775, 7.736382174726161, 6.813438666451106, 5.9590573574679695, 6.892339936055359, 7.833080366333444, 8.71976926103715, 9.626931102555876, 10.601334538377936, 11.5763909163848, 12.580885698081081, 9.767618273898576, 10.828501685577244, 11.833300116163876, 12.778552294578867, 13.77491491381185, 13.415461785636632, 12.46062853572364, 11.52575261216911, 10.531641606060521, 9.726451871175836, 8.679627188878236, 7.851825851646193, 6.9997223478663715, 7.892389802275273, 8.844396379051474, 9.683525665214615, 10.690731014968344, 11.625177625114155, 12.546076322209766, 13.516989407019699, 10.63301050971783, 11.609000756660231, 12.618067305539643, 13.669906208467708, 14.532837458666222, 13.50306305846812, 12.586172873884461, 12.02672717546029, 11.4752005790367, 10.774958750078914, 9.727319510550718, 8.87923558511097, 7.941673439625639, 8.941543395598215, 9.786143356958023, 10.720492101538497, 11.705302647904425, 12.695584487802096, 13.517419378670796, 14.462202936257214, 11.569741567787107, 12.558426394359167, 13.50939372091924, 14.455347693432413, 13.556138046727494, 12.571461202877643, 11.637357163847016, 10.968145481957842, 11.816734784917221, 11.752038895832712, 10.76655518288165, 9.84278525576895, 8.873027485617685, 9.804621593874574, 10.75993421433515, 11.760883731324745, 12.67374193979635, 13.62362927202706, 14.514964545207295, 15.438652523067852, 12.521375338956625, 13.494962239555232, 14.434247433768073, 13.598602851780418, 12.615907189276102, 11.632091601212107, 10.699349323240554, 9.984946596865251, 10.783492977777396, 11.746656209889077, 11.723252585536747, 10.756350004382583, 9.80807579759512, 10.793713072272983, 11.827973462026579, 12.75189177459695, 13.632157982946818, 14.641046024513432, 15.524232991175296, 16.367707101664063, 13.423248670605414, 14.48051599119604, 13.547589806815267, 12.59698067112707, 11.707294504444096, 10.633610204741121, 9.69827906558116, 8.915178678593653, 9.785635334427651, 10.820051857043522, 11.747992929635624, 11.774999690828137, 10.800507685372132, 11.744323390040158, 12.684108517901596, 13.683693983831896, 14.613002259039149, 15.592746958074672, 16.479428588637536, 17.42059899983077, 14.35093430423959, 13.55701798174003, 12.554855357319235, 11.5778672732309, 10.664915467889063, 9.68446562641845, 8.740606524891984, 7.949918582169076, 8.772380043657511, 9.802026129999696, 10.700267817202205, 11.52062583253042, 11.847909969458449, 12.751296128874001, 13.65633067296423, 14.659880081061928, 15.633973017073894, 16.643953008103324, 17.49717868437581, 18.48224586305246], [18.47165479114193, 17.59775934151881, 16.664829992513482, 15.709833442997182, 14.79147917802281, 13.932172233562532, 13.282462180253713, 12.506722531725375, 11.497687303224644, 10.64771938856654, 9.74559788477941, 8.781252252845471, 7.9111680144065115, 6.904244719392736, 7.84760094004297, 8.747294926327038, 9.622699182050333, 10.551903354921704, 11.570371726710112, 12.528311672168218, 17.399969033788906, 17.452997875755873, 16.496662564620014, 15.506670593378292, 14.47333224898771, 13.519904677666661, 12.549042732356586, 11.51453508659111, 10.569233864246884, 9.60866853646776, 8.676238955426633, 7.743420821613372, 6.916810948804891, 5.907053413394963, 6.940292574519727, 7.741191553654311, 8.58599937122198, 9.552078211692669, 10.575812671746561, 11.507191812156343, 16.394187246572262, 16.586833730051808, 15.588970002895683, 14.558478945305902, 13.503543993767419, 12.521886867687627, 11.565812782205407, 10.673919843103725, 9.689692760036031, 8.691767269259504, 7.817253429586726, 6.778013206970273, 5.887550303911869, 4.922091942334534, 5.915209295603602, 6.801792965219132, 7.614725746579297, 8.602326435640999, 9.561807055460509, 10.558955397839418, 15.467269822358338, 15.524032385218804, 14.60903510723734, 13.570051759059133, 12.5166834448035, 11.523510312588762, 10.566619199649086, 9.65110391321957, 8.672036666550426, 7.713855606419473, 6.7917844204284705, 5.815866670094979, 4.9082860451730435, 3.9403362639940775, 4.8594374209464775, 5.746769272156321, 6.677454651702926, 7.668942716347539, 8.596314874238125, 9.574975656060316, 14.553398921070016, 14.513041060382136, 13.577345796108405, 12.658575939748726, 11.599422426294591, 10.670609804863197, 9.599682091268932, 8.701919833769951, 7.745471603658676, 6.699360996384985, 5.8622185913516605, 4.863063555809627, 3.8356659255641734, 2.985178983690264, 3.8084095516355623, 4.790135572069747, 5.843280446478848, 6.7467918068871, 7.717226894185079, 8.647971213638945, 13.569244367955257, 13.619621806680886, 12.637597504328317, 11.681703864016228, 10.660016235227538, 9.69258908837597, 8.646768682175919, 7.670896549423387, 6.704308726654943, 5.76158177775252, 4.863271035070667, 3.9283730014260207, 2.8866661077659916, 2.024951733613804, 2.880972683667908, 3.8066438700830854, 4.810528378337194, 5.810953146868915, 6.754391855688656, 7.820310868763355, 12.644366676147667, 12.635071044440622, 11.645940799846553, 10.704674025324048, 9.71527670465046, 8.747759924657133, 7.822671973152434, 6.855813372286651, 5.860775122206188, 4.835198773318076, 3.8029643607848316, 2.8697975976682075, 1.940059563724894, 1.0296696395654341, 1.8871033704170586, 2.8523179135191064, 3.8819585491692226, 4.925533471910823, 5.877878922540597, 6.831872250542169, 11.659812462128967, 11.678433058673514, 10.695566256626503, 9.733130960596974, 8.764504712450206, 7.781205482428585, 6.845114878492593, 5.869030889305483, 4.855268518445907, 3.9141235590060854, 2.9072370608090123, 1.9304633824780286, 0.9598557302447038, 0.0, 0.9610139602449191, 2.012130214138879, 3.0451141523701146, 4.04745085617847, 4.991558550258397, 6.000310658386366, 10.681161728227282, 11.721974807143656, 11.625610434776016, 10.718022660120178, 9.726135374820696, 8.713804347176254, 7.696347944893348, 6.72610282383772, 5.73911188369945, 4.746060064636383, 3.7909314987687805, 2.8554406467302726, 1.9214210243328491, 0.9569368950123357, 1.9851344931075325, 2.9443463203344007, 3.8977972026733028, 4.867092855884457, 5.8237566555835745, 6.857575119327108, 9.709747257497348, 10.658930501547895, 11.673177647127678, 11.673104475873942, 10.703431561510996, 9.71801712899461, 8.668454980331292, 7.712891899040345, 6.648821268269286, 5.706755564729235, 4.72413311493343, 3.8796400907250517, 2.924386903984575, 2.028481388183648, 2.9793557365441226, 3.901290551701743, 4.95154379746392, 5.833973092639418, 6.842881610350741, 7.828063368276677, 8.765610259137299, 9.802120578574927, 10.690779453349549, 11.761333767555353, 11.479070680625252, 10.544934731447317, 9.574050690118987, 8.606184937045027, 7.609676161672288, 6.694822691791347, 5.747038875104215, 4.887111742775251, 3.9401504060844097, 3.0145796989091624, 3.953952064100688, 4.8780388775684855, 5.9006889605830715, 6.844899883799154, 7.8347938535903, 8.755322807003774, 7.80955948995667, 8.77520446717485, 9.763062950192058, 10.824125680638478, 11.829132240376493, 11.472433183852555, 10.554694935496537, 9.540352318521002, 8.574542846223945, 7.651280678001184, 6.692988947558077, 5.875922555507538, 4.937857537966854, 3.986467180571841, 4.928092681506027, 5.871758224538494, 6.803672742794802, 7.776577944542735, 8.84820384776473, 9.714636029052816, 6.947933322670477, 7.918248189034134, 8.945244797057923, 9.893121041154936, 10.944788255820502, 11.888985141868272, 11.512942790104157, 10.553394195583419, 9.59700266959946, 8.636093388153284, 7.683547301149891, 6.812001452610517, 5.927884560970179, 4.9510595908133475, 5.854830503486643, 6.803866228593848, 7.761885101832579, 8.70394160399003, 9.703498994749694, 10.635696669341355, 7.853936656436268, 8.915172503970338, 9.861343093586196, 10.858905918248373, 11.853728659631383, 12.827421820001325, 12.451093685000398, 11.546509506544636, 10.554115858775864, 9.61155813748748, 8.696237904970866, 7.77329439669581, 6.9189130877126725, 5.980167674069449, 6.920908104347534, 7.80759699905124, 8.714758840569967, 9.689162276392027, 10.66421865439889, 11.668713436095173, 8.807762543653872, 9.868645955332541, 10.873444385919173, 11.818696564334164, 12.815059183567147, 13.660714051803332, 12.717038580224376, 12.485608342413816, 11.491497336305226, 10.686307601420541, 9.63948291912294, 8.811681581890898, 7.9074184533432375, 6.980217540289363, 7.932224117065565, 8.771353403228705, 9.778558752982436, 10.713005363128246, 11.633904060223857, 12.60481714503379, 9.673154779473126, 10.649145026415528, 11.65821157529494, 12.710050478223005, 13.637221834149937, 12.607447433951835, 11.690557249368176, 12.737336286225972, 12.435056309281405, 11.73481448032362, 10.687175240795423, 9.794538259682472, 8.849369545102505, 8.029371133612305, 8.873971094972113, 9.808319839552588, 10.793130385918516, 11.783412225816187, 12.605247116684888, 13.550030674271305, 10.609885837542404, 11.598570664114463, 12.549537990674537, 13.49549196318771, 12.660522422211208, 11.675845578361358, 10.74174153933073, 11.700925770547947, 12.673319661928035, 12.711894626077417, 11.726410913126355, 10.750481361245816, 9.780723591094551, 9.083981224037714, 9.84776195234924, 10.848711469338836, 11.761569677810442, 12.711457010041151, 13.602792283221387, 14.526480261081943, 11.561519608711922, 12.535106509310529, 13.47439170352337, 12.660001039506414, 11.720291564759817, 10.736475976695822, 9.803733698724269, 10.772875562077079, 11.7433487080221, 12.706511940133781, 12.643037070788557, 11.664046109859449, 10.715771903071985, 10.149528268833025, 10.915801200040669, 11.839719512611042, 12.71998572096091, 13.728873762527524, 14.612060729189388, 15.455534839678155, 12.46339294036071, 13.520660260951336, 12.587734076570564, 11.637124940882368, 10.75315939335059, 9.737994580224836, 8.802663441064874, 9.772154690992766, 10.745491064672356, 11.779907587288227, 12.707848659880328, 12.682695796305003, 11.708203790848998, 11.221415777561628, 11.97639330834121, 12.842677411367978, 13.70082999705324, 14.680574696088764, 15.567256326651629, 16.508426737844864, 13.391078573994887, 12.597162251495327, 11.594999627074532, 10.618011542986197, 9.70505973764436, 8.788850001902166, 7.844990900375699, 8.871351355278644, 9.732235773902216, 10.7618818602444, 11.66012354744691, 12.480481562775125, 12.755606074935315, 12.228388516395471, 12.948615463403845, 13.839232848327635, 14.721800755087985, 15.731780746117416, 16.585006422389903, 17.570073601066554], [17.571644874037595, 16.697749424414475, 15.774553292145924, 14.819556742629624, 13.901202477655254, 13.04189553319498, 13.996178419802911, 13.39806870365804, 12.38903347515731, 11.539065560499203, 10.636944056712077, 9.672598424778139, 8.742986429686054, 7.732524870044054, 7.034976470478833, 7.786280966082118, 8.661685221805412, 9.590889394676783, 10.609357766465191, 11.567297711923297, 16.499959116684572, 17.444979074782516, 16.78202990301363, 15.792037931771908, 14.924327777055948, 14.015724676765029, 13.44038890428925, 12.405881258523776, 11.46058003617955, 10.500014708400426, 9.5675851273593, 8.63476699354604, 7.782108370779269, 6.7353335640462815, 5.9873209295373915, 6.780177593409392, 7.62498541097706, 8.591064251447749, 9.614798711501642, 10.546177851911422, 15.494177329467925, 16.439905335294878, 16.5499839631406, 15.51949290555082, 14.464557954012337, 13.482900827932545, 12.526826742450325, 11.634933803348643, 10.65070672028095, 9.652781229504422, 8.72922585968443, 7.669359378902939, 6.778896475844535, 5.750372092985852, 4.962237650621265, 5.8407790049742125, 6.6537117863343775, 7.641312475396079, 8.600793095215588, 9.597941437594496, 14.556063162768805, 15.525146497919916, 15.570049067482257, 14.53106571930405, 13.477697405048417, 12.48452427283368, 11.527633159894004, 10.612117873464488, 9.633050626795344, 8.674869566664391, 7.710004258501022, 6.707212842027645, 5.799632217105709, 4.768616414645396, 3.898423460701558, 4.785755311911402, 5.716440691458007, 6.7079287561026195, 7.635300913993205, 8.613961695815394, 13.624627480844698, 14.594880502994487, 14.538359756353323, 13.619589899993644, 12.560436386539509, 11.631623765108115, 10.56069605151385, 9.662933794014869, 8.706485563903595, 7.660374956629903, 6.780438429424212, 5.754409727742293, 4.727012097496839, 3.8134591343415822, 2.847395591390643, 3.829121611824828, 4.882266486233928, 5.785777846642181, 6.7562129339401595, 7.686957253394025, 12.640278726973321, 13.654119057337203, 13.598611464573235, 12.642717824261146, 11.621030195472455, 10.653603048620887, 9.607782642420837, 8.631910509668305, 7.665322686899861, 6.722595737997438, 5.781490873143219, 4.846592839498572, 3.7780122796986575, 2.8690513623712466, 1.9199587234229887, 2.845629909838166, 3.849514418092275, 4.849939186623995, 5.7933778954437365, 6.859296908518436, 11.68510644603151, 12.690031832785632, 12.60695476009147, 11.665687985568965, 10.676290664895378, 9.708773884902051, 8.783685933397352, 7.81682733253157, 6.821789082451107, 5.796212733562995, 4.76397832102975, 3.8308115579131266, 2.83140573565756, 1.8863243050560305, 0.9260894101721394, 1.891303953274187, 2.9209445889243035, 3.964519511665904, 4.916864962295678, 5.87085829029725, 10.700552232012809, 11.733393847018524, 11.65658021687142, 10.694144920841891, 9.725518672695124, 8.742219442673504, 7.8061288387375125, 6.8300448495504025, 5.816282478690827, 4.875137519251005, 3.868251021053932, 2.891477342722948, 1.920869690489623, 0.9610139602449191, 0.0, 1.05111625389396, 2.0841001921251956, 3.0864368959335504, 4.030544590013477, 5.039296698141446, 9.721901498111125, 10.762714577027499, 11.726879699412212, 11.679036620365096, 10.687149335065616, 9.674818307421173, 8.657361905138266, 7.687116784082638, 6.7001258439443685, 5.707074024881302, 4.751945459013699, 3.8164546069751912, 2.882434984577768, 1.9179508552572548, 1.0258742629913749, 1.985086090218243, 2.938536972557145, 3.9078326257682994, 4.864496425467417, 5.89831488921095, 8.75048702738119, 9.699670271431737, 10.71391741701152, 11.695070499569603, 11.664445521755916, 10.67903108923953, 9.629468940576212, 8.673905859285265, 7.609835228514204, 6.667769524974154, 5.685147075178349, 4.84065405096997, 3.885400864229494, 2.9894953484285676, 2.020095506427965, 2.942030321585585, 3.992283567347762, 4.8747128625232605, 5.883621380234583, 6.868803138160519, 7.806350029021141, 8.84286034845877, 9.731519223233391, 10.802073537439195, 11.831185853672594, 11.505948691692234, 10.535064650363905, 9.567198897289945, 8.570690121917206, 7.655836652036266, 6.708052835349134, 5.84812570302017, 4.901164366329329, 3.975593659154082, 3.041917660928564, 3.9187786474523283, 4.941428730466914, 5.885639653682996, 6.875533623474142, 7.796062576887616, 6.850299259840512, 7.815944237058693, 8.8038027200759, 9.86486545052232, 10.869872010260336, 11.847512650954576, 11.515708895741454, 10.50136627876592, 9.535556806468863, 8.612294638246102, 7.6540029078029965, 6.836936515752456, 5.898871498211774, 4.947481140816761, 4.037815981138472, 4.9124979944223375, 5.8444125126786455, 6.8173177144265775, 7.888943617648572, 8.755375798936658, 5.9869193624255574, 6.957234228789215, 7.984230836813003, 8.932107080910017, 9.983774295575582, 10.927971181623352, 11.90216549458978, 11.514408155828338, 10.55801662984438, 9.597107348398204, 8.64456126139481, 7.773015412855435, 6.888898521215099, 5.912073551058268, 4.964553803119088, 5.913589528226293, 6.871608401465024, 7.803931686885694, 8.803489077645358, 9.735686752237019, 6.89292269619135, 7.954158543725421, 8.90032913334128, 9.897891958003457, 10.892714699386467, 11.866407859756405, 12.840316389486022, 12.507523466789555, 11.515129819020784, 10.5725720977324, 9.657251865215784, 8.73430835694073, 7.879927047957592, 6.94118163431437, 6.03063140397998, 6.917320298683685, 7.824482140202411, 8.78915235928769, 9.764208737294556, 10.768703518990838, 7.846748583408955, 8.907631995087623, 9.912430425674257, 10.857682604089248, 11.854045223322231, 12.819900347480012, 13.545318730875696, 13.446622302658735, 12.452511296550146, 11.64732156166546, 10.600496879367858, 9.772695542135818, 8.86843241358816, 7.941231500534284, 7.041947416698011, 7.88107670286115, 8.88828205261488, 9.81299544602391, 10.733894143119523, 11.704807227929455, 8.712140819228207, 9.688131066170609, 10.69719761505002, 11.749036517978086, 12.709276124524083, 11.794822964387697, 12.518837400019494, 13.565616436877288, 13.396070269526325, 12.695828440568537, 11.64818920104034, 10.755552219927395, 9.810383505347426, 8.942791546191735, 7.9836943946045595, 8.918043139185032, 9.902853685550959, 10.883402308711851, 11.705237199580553, 12.65002075716697, 9.648871877297482, 10.637556703869544, 11.588524030429618, 12.534478002942791, 11.84789795264707, 10.86322110879722, 11.570021689982049, 12.529205921199265, 13.501599812579354, 13.672908586322334, 12.687424873371272, 11.711495321490737, 10.741737551339472, 9.93008825515962, 8.957485251981687, 9.95843476897128, 10.871292977442884, 11.811447092936815, 12.702782366117052, 13.626470343977608, 10.600505648467001, 11.574092549065607, 12.513377743278449, 11.698987079261492, 10.852763417352302, 9.923851507131683, 10.632013849375587, 11.601155712728396, 12.596117540541712, 13.559280772653393, 13.604051031033478, 12.62506007010437, 11.676785863316907, 10.99563529995493, 10.025524499673116, 10.949442812243486, 11.829709020593352, 12.838597062159966, 13.712050812085053, 14.55552492257382, 11.50237898011579, 12.559646300706415, 11.626720116325643, 10.676110980637446, 9.79214543310567, 8.925370110660698, 9.630943591716193, 10.600434841644084, 11.598259897191967, 12.632676419807838, 13.599194831812992, 13.643709756549924, 12.66921775109392, 12.025901735835095, 11.086116607973658, 11.952400711000422, 12.810553296685683, 13.790297995721206, 14.667246409547294, 15.60841682074053, 12.430064613749966, 11.636148291250406, 10.633985666829611, 9.656997582741276, 8.744045777399439, 7.976225532338028, 8.673271051027017, 9.699631505929965, 10.623581945834884, 11.653228032177068, 12.551469719379574, 13.371827734707791, 13.716620035180236, 13.010137415044516, 12.058338763036293, 12.948956147960079, 13.831524054720427, 14.841504045749858, 15.684996505285568, 16.67006368396222], [16.60623969994174, 15.732344250318619, 14.817259645593136, 13.862263096076836, 13.002345245340264, 13.93867312731509, 14.89295601392302, 14.405021572653448, 13.395986344152718, 12.546018429494612, 11.643896925707484, 10.638431159186013, 9.708451473964967, 8.697989914322967, 7.961806036013179, 6.952483040979819, 7.827887296703113, 8.757091469574485, 9.775559841362893, 10.733499786821, 15.534553942588715, 16.479573900686656, 15.824736256460842, 14.83474428521912, 14.025470544740958, 14.912502270885138, 14.44734177328466, 13.412834127519183, 12.467532905174957, 11.506967577395834, 10.574537996354707, 9.641719862541446, 8.747573415058183, 7.7007986083251945, 6.9527859738163045, 5.946379668307093, 6.791187485874761, 7.75726632634545, 8.781000786399343, 9.712379926809124, 14.528772155372069, 15.47450016119902, 16.47814633807509, 15.86256594190141, 14.995258799961249, 14.511155746698305, 13.555081661216086, 12.652699611974938, 11.668472528907245, 10.670547038130717, 9.736178728679837, 8.676312247898347, 7.760013677431695, 6.715837137264765, 5.927702694900178, 5.006981079871913, 5.819913861232078, 6.80751455029378, 7.766995170113289, 8.764143512492199, 13.59065798867295, 14.559741323824062, 15.596859904301299, 15.559320638069812, 14.505952323814178, 13.51277919159944, 12.555888078659764, 11.640372792230249, 10.661305545561104, 9.703124485430152, 8.71695712749643, 7.714165711023052, 6.780749418692869, 5.734081458924309, 4.863888504980471, 3.9519573868091027, 4.8826427663557075, 5.87413083100032, 6.801502988890905, 7.723667828177914, 12.659222306748843, 13.629475328898632, 14.565170593172365, 14.670706153887602, 13.611552640433468, 12.659878683873876, 11.58895097027961, 10.69118871278063, 9.734740482669356, 8.688629875395662, 7.787391298419619, 6.7613625967377, 5.7339649664922465, 4.778924178620495, 3.812860635669556, 2.9953236867225295, 3.95879026902524, 4.839195637779658, 5.809630725077636, 6.7403750445315005, 11.674873552877466, 12.688713883241348, 13.637092993056152, 13.693834078155104, 12.672146449366414, 11.683570296025641, 10.636037561186598, 9.660165428434066, 8.693577605665622, 7.750850656763198, 6.788443742138626, 5.8535457084939795, 4.784965148694065, 3.834516406650159, 2.8854237677019015, 1.9221536926294776, 2.926038200883587, 3.903356977761472, 4.8467956865812125, 5.87311556973432, 10.719701271935655, 11.724626658689775, 12.641893246685921, 12.716804239462924, 11.727406918789336, 10.75989013879601, 9.834802187291311, 8.867943586425529, 7.872905336345066, 6.847328987456955, 5.815094574923711, 4.881927811807087, 3.838358604652967, 2.8932771740514376, 1.9330422791675463, 0.9678277360654985, 1.9958979893245863, 2.978338172881788, 3.9306836235115616, 4.884676951513134, 9.735147057916954, 10.767988672922668, 11.69151870346587, 11.74526117473585, 10.776634926589082, 9.793335696567462, 8.857245092631471, 7.881161103444361, 6.867398732584785, 5.926253773144964, 4.919367274947891, 3.942593596616908, 2.971985944383583, 2.012130214138879, 1.05111625389396, 0.0, 1.0329839382312356, 2.0353206420395904, 2.979428336119517, 3.9881804442474866, 8.75649632401527, 9.797309402931642, 10.761474525316357, 11.684747141227511, 11.738265588959575, 10.725934561315132, 9.708478159032227, 8.738233037976599, 7.751242097838329, 6.758190278775262, 5.80306171290766, 4.867570860869152, 3.933551238471728, 2.9690671091512146, 1.9788927433492567, 1.0196809161223885, 1.9731317984612908, 2.942427451672445, 3.899091251371563, 4.9329097151150965, 7.785081853285336, 8.734265097335882, 9.748512242915666, 10.729665325473748, 11.770278147475517, 11.730147343133492, 10.680585194470172, 9.725022113179225, 8.660951482408166, 7.718885778868114, 6.736263329072309, 5.891770304863931, 4.934363580900718, 3.958241104471032, 2.964805244384666, 1.9766251474897307, 3.026878393251908, 3.9093076884274067, 4.918216206138729, 5.903397964064665, 6.8409448549252865, 7.877455174362915, 8.747853157828091, 9.818407472033895, 10.834987601590537, 11.769123550768473, 11.586180904257867, 10.618315151183907, 9.621806375811168, 8.706952905930226, 7.759169089243095, 6.838017878474055, 5.852825716798304, 4.887061423814316, 3.9476890586227906, 2.953373473356474, 3.976023556371059, 4.920234479587142, 5.910128449378289, 6.830657402791762, 5.8848940857446586, 6.8322781716533925, 7.8201366546706, 8.862233276640282, 9.867239836378298, 10.844880477072538, 11.850911083507748, 11.552482532659882, 10.586673060362825, 9.663410892140062, 8.705119161696956, 7.825667815962331, 6.850532848680749, 5.8589489054769945, 4.943587378832699, 3.947092820326483, 4.879007338582791, 5.851912540330723, 6.923538443552717, 7.789970624840803, 4.935803108531598, 5.906117974895255, 6.933114582919044, 7.880990827016058, 8.932658041681623, 9.876854927729394, 10.851049240695822, 11.81059783521656, 11.60913288373834, 10.648223602292164, 9.69567751528877, 8.76174671306531, 7.840559871684074, 6.823541315718502, 5.8703252008133155, 5.014732295911302, 5.914314754912235, 6.838526512789839, 7.838083903549502, 8.770281578141162, 5.906741357407233, 6.962777332238616, 7.885685311859344, 8.856417344498896, 9.851240085881905, 10.815291605862447, 11.789200135592063, 12.800524138597897, 12.566246072914744, 11.62368835162636, 10.708368119109744, 9.723039657150604, 8.831588398426566, 7.852649398974604, 6.936402801674207, 6.018463066368694, 6.867188493649622, 7.823747185191837, 8.7988035631987, 9.803298344894982, 6.860567244624837, 7.921450656303507, 8.897786604192321, 9.816207990584687, 10.81257060981767, 11.77842573397545, 12.733258983888442, 13.706616826051922, 13.503627550444108, 12.698437815559421, 11.651613133261819, 10.761426842345692, 9.779900178248393, 8.852699265194518, 7.938725010818121, 6.982219470546159, 7.930988406062092, 8.847590271928055, 9.768488969023666, 10.739402053833599, 7.765558610365682, 8.741548857308084, 9.750615406187496, 10.74374217979452, 11.703981786340517, 12.721652529922045, 13.484302444298407, 14.531081481156203, 14.447186523420287, 13.746944694462497, 12.6993054549343, 11.667019984587629, 10.72185127000766, 9.839569140311845, 8.88047198872467, 8.019185906870042, 8.94556003899817, 9.917997134615996, 10.739832025484697, 11.684615583071114, 8.758578009660003, 9.69097449500702, 10.641941821567093, 11.587895794080266, 11.07006226460814, 11.790050674331567, 12.535486734260962, 13.494670965478178, 14.467064856858267, 14.724024840216295, 13.666896048974845, 12.622963086150971, 11.653205315999706, 10.826865849279729, 9.854262846101797, 9.05957753665629, 9.913999330890096, 10.84604191884096, 11.737377192021196, 12.661065169881752, 9.710211780829521, 10.683798681428128, 11.623083875640969, 10.865189154159195, 10.018965492250002, 10.850681072666031, 11.5974788936545, 12.56662075700731, 13.561582584820625, 14.524745816932306, 14.515518795693712, 13.536527834764604, 12.58825362797714, 11.89241289407504, 10.922302093793226, 10.050585579928496, 10.872415374040564, 11.881303415607178, 12.746645637989197, 13.590119748477964, 10.668581055013492, 11.725848375604118, 10.792922191223346, 9.842313055535149, 8.95834750800337, 9.852199676195045, 10.596408635995106, 11.565899885922997, 12.56372494147088, 13.598141464086751, 14.577140715212304, 14.555177521210158, 13.580685515754153, 12.922679329955205, 11.982894202093767, 11.053543478685432, 11.853259650132895, 12.833004349168418, 13.701841235451438, 14.643011646644673, 11.596266688647669, 10.802350366148108, 9.800187741727314, 8.823199657638979, 7.9102478522971404, 8.903055097872375, 9.63873609530593, 10.665096550208876, 11.589414680242758, 12.619060766584942, 13.558422588374983, 14.378780603703198, 14.62808779984047, 13.906915009164626, 12.955116357156403, 12.050098915645089, 12.874230408167639, 13.88421039919707, 14.719591331189712, 15.704658509866361], [15.640105147386596, 14.813234528998542, 13.918105463184562, 12.963108913668261, 13.902823091078956, 14.849535198541787, 15.803818085149718, 15.429748523331414, 14.420713294830684, 13.570745380172578, 12.66862387638545, 11.663158109863982, 10.733178424642936, 9.722716865000937, 8.856548928392868, 7.847225933359508, 6.8622830508953, 7.791487223766671, 8.80995559555508, 9.738762953284505, 14.568419390033572, 15.513439348131515, 14.925582074052267, 13.935590102810545, 14.92594839047965, 15.823364342111836, 15.472068723962625, 14.437561078197149, 13.492259855852923, 12.5316945280738, 11.599264947032673, 10.666446813219412, 9.77230036573615, 8.725525559003163, 7.853720836102984, 6.841122560686782, 5.825583240066948, 6.791662080537637, 7.79394975296979, 8.67952107698472, 13.562637602816926, 14.508365608643876, 15.512011785519945, 14.963411759492836, 15.895736645699941, 15.535882697376273, 14.579808611894054, 13.677426562652904, 12.69319947958521, 11.695273988808683, 10.760905679357803, 9.701039198576312, 8.784740628109663, 7.740564087942734, 6.837581085981551, 5.901723972251602, 4.854309615424265, 5.841910304485967, 6.755281745022231, 7.731284662667795, 12.59461829522184, 13.563701630372952, 14.60082021085019, 15.54527734731009, 15.530679274492146, 14.537506142277408, 13.580615029337732, 12.665099742908216, 11.686032496239074, 10.727851436108121, 9.741684078174398, 8.73889266170102, 7.8054763693708376, 6.758808409602278, 5.773766896061844, 4.8477239000945, 3.917038520547895, 4.880374725562249, 5.789789563799847, 6.690683889946679, 11.663182613297733, 12.633435635447523, 13.569130899721255, 14.597741918469861, 14.644536578664704, 13.684605634551843, 12.613677920957578, 11.715915663458597, 10.759467433347323, 9.713356826073632, 8.812118249097587, 7.786089547415668, 6.758691917170214, 5.803651129298464, 4.837587586347524, 4.020050637400498, 2.9795427967923915, 3.806211699548422, 4.776646786846401, 5.707391106300266, 10.678833859426357, 11.692674189790239, 12.641053299605044, 13.596946939917133, 13.70513038759765, 12.708297246703609, 11.660764511864565, 10.684892379112034, 9.71830455634359, 8.775577607441166, 7.813170692816594, 6.878272659171947, 5.8096920993720325, 4.859243357328127, 3.9101507183798696, 2.9468806433074457, 1.9467907286507382, 2.8703730395302363, 3.8138117483499774, 4.840131631503084, 9.723661578484545, 10.72858696523867, 11.645853553234813, 12.620579303833932, 12.760390857020573, 11.792874077027246, 10.867786125522548, 9.900927524656765, 8.905889274576301, 7.88031292568819, 6.848078513154945, 5.914911750038321, 4.863085555330935, 3.9180041247294057, 2.9577692298455145, 1.992554686743467, 0.9629140510933507, 1.9453542346505523, 2.897699685280326, 3.8516930132818983, 8.739107364465845, 9.771948979471562, 10.695479010014763, 11.657914306044292, 11.809618864820319, 10.826319634798699, 9.890229030862708, 8.914145041675598, 7.900382670816022, 6.9592377113762005, 5.952351213179127, 4.975577534848143, 4.004969882614819, 3.0451141523701146, 2.0841001921251956, 1.0329839382312356, 0.0, 1.0023367038083548, 1.9464443978882815, 2.955196506016251, 7.760456630564161, 8.801269709480536, 9.76543483186525, 10.688707447776403, 11.726491635698462, 11.697725659254617, 10.670110194290965, 9.699865073235337, 8.712874133097067, 7.719822314034, 6.764693748166398, 5.82920289612789, 4.895183273730466, 3.91795241267115, 2.889754814575953, 1.9305429873490847, 0.9770921050101825, 1.946387758221337, 2.9030515579204543, 3.936870021663988, 6.789042159834228, 7.738225403884774, 8.752472549464558, 9.73362563202264, 10.737294209244281, 11.722708641760667, 11.64221722972891, 10.686654148437961, 9.622583517666902, 8.680517814126851, 7.697895364331047, 6.853402340122669, 5.845225652127414, 4.869103175697728, 3.875667315611362, 2.887487218716427, 2.0368381921420182, 2.913267994976298, 3.9221765126876207, 4.907358270613557, 5.844905161474179, 6.873159423332985, 7.7148692195968565, 8.78542353380266, 9.8020036633593, 10.736139612537237, 11.707023653865566, 11.579947186442643, 10.583438411069904, 9.668584941188962, 8.697356001449299, 7.748879949700751, 6.763687788025, 5.797923495041012, 4.858551129849486, 3.86423554458317, 2.9859833552611694, 3.9241947861360336, 4.91408875592718, 5.8346177093406535, 4.88885439229355, 5.799294233422157, 6.787152716439365, 7.829249338409046, 8.834255898147061, 9.811896538841301, 10.817927145276514, 11.832269762252048, 11.548305095621561, 10.625042927398798, 9.64330607390316, 8.736529887189025, 7.761394919907445, 6.76981097670369, 5.854449450059395, 4.857954891553179, 3.979853156174215, 4.932802819010648, 5.988440779524058, 6.793930931389695, 3.9028191703003623, 4.87313403666402, 5.900130644687808, 6.8480068887848216, 7.899674103450388, 8.843870989498159, 9.818065302464587, 10.777613896985326, 11.734005422969284, 11.56062500115101, 10.608078914147615, 9.672608784292004, 8.75142194291077, 7.734403386945197, 6.781187272040011, 5.9255943671379985, 5.015160572503659, 5.919416791469764, 6.9189741822294275, 7.821084523477833, 4.873757419175998, 5.929793394007381, 6.852701373628108, 7.823433406267659, 8.818256147650668, 9.782307667631212, 10.756216197360828, 11.767540200366662, 12.691118612145688, 12.536089750485205, 11.62076951796859, 10.633901728377298, 9.742450469653264, 8.7635114702013, 7.847264872900903, 6.929325137595391, 5.9680343112410466, 6.9046374638717625, 7.879693841878625, 8.868918560645568, 5.827583306393603, 6.888466718072272, 7.864802665961085, 8.78322405235345, 9.779586671586433, 10.745441795744213, 11.700275045657206, 12.673632887820686, 13.62850008967505, 13.610839214418267, 12.564014532120664, 11.672288913572384, 10.690762249475089, 9.763561336421214, 8.849587082044819, 7.8930815417728555, 7.031834223653516, 7.928480550607981, 8.849379247703592, 9.805022269584185, 6.732574672134447, 7.708564919076849, 8.717631467956261, 9.710758241563283, 10.67099784810928, 11.700772248307384, 12.726756376513407, 13.657482594676305, 14.57205906265123, 14.659346093321343, 13.611706853793146, 12.577882055814325, 11.632713341234355, 10.750431211538542, 9.791334059951367, 8.930047978096738, 8.046405856589596, 8.998887413295922, 9.820722304164622, 10.750235798821699, 7.725594071428767, 8.657990556775784, 9.608957883335858, 10.554911855849031, 11.567225604895247, 12.551902448745098, 13.560213684938931, 14.519397916156148, 15.491791807536236, 15.63642623907514, 14.57775812020154, 13.533825157377667, 12.564067387226402, 11.737727920506426, 10.765124917328494, 9.960055382394982, 9.014845148481522, 9.926932197520886, 10.818267470701121, 11.726685385632337, 8.677227842598287, 9.650814743196893, 10.590099937409734, 9.89958490835138, 10.882134603712927, 11.74542396504572, 12.62220584433247, 13.59134770768528, 14.586309535498595, 15.549472767610276, 15.426380866920407, 14.4473899059913, 13.499115699203836, 12.803274965301737, 11.833164165019923, 10.951063425667188, 9.97326119163199, 10.982149233198603, 11.82753591666912, 12.655739964228548, 9.635722205189088, 10.692989525779714, 9.827317945415531, 8.876708809727335, 9.821516619466296, 10.746942568574735, 11.621135586673075, 12.590626836600967, 13.58845189214885, 14.62286841476472, 15.601867665890273, 15.466039592436854, 14.491547586980849, 13.833541401181902, 12.893756273320465, 11.954021324424124, 10.95410546772432, 11.933850166759843, 12.782731514131362, 13.720273101526452, 10.563407838823265, 9.836746120340294, 8.8345834959195, 7.857595411831165, 8.794201844323027, 9.797797990252064, 10.6634630459839, 11.689823500886845, 12.614141630920727, 13.643787717262912, 14.583149539052949, 15.403507554381164, 15.538949871067166, 14.817777080391323, 13.8659784283831, 12.95057676138378, 11.975076225759064, 12.985056216788495, 13.800481609869635, 14.78191996474814], [14.660948916822568, 13.834078298434513, 13.004552773549856, 13.813316307170398, 14.753030484581092, 15.704114317888465, 16.658397204496396, 16.405492088884884, 15.396456860384152, 14.546488945726047, 13.555145297280244, 12.511544633109269, 11.581564947888223, 10.571103388246224, 9.62774716759599, 8.618424172562628, 7.633481290098421, 7.0410683644957945, 7.841113914045731, 8.736426249476152, 13.589263159469544, 14.534283117567487, 14.04471842623063, 14.785797496312682, 15.776155783981787, 16.677943461458515, 16.447812289516094, 15.413304643750617, 14.468003421406392, 13.507438093627268, 12.575008512586141, 11.64219037877288, 10.632644071340694, 9.585869264607707, 8.624919075306103, 7.612320799889901, 6.596781479270068, 5.983410382395384, 6.791613049161436, 7.677184373176366, 12.583481372252898, 13.529209378079848, 14.532855554955917, 15.560108634230563, 16.48363445572597, 16.523478528359764, 15.567404442877546, 14.653170128206373, 13.668943045138679, 12.671017554362152, 11.736649244911272, 10.676782764129781, 9.645084333714209, 8.600907793547279, 7.608779325184671, 6.672922211454722, 5.625507854627386, 4.915892554227555, 5.752945041213876, 6.72894795885944, 11.615462064657812, 12.584545399808924, 13.612238406169983, 14.545489811023609, 15.42206130144296, 15.5251019732609, 14.568210860321225, 13.652695573891709, 12.673628327222564, 11.715447267091612, 10.729279909157889, 9.714636227254488, 8.665820074975382, 7.619152115206823, 6.544965135264964, 5.61892213929762, 4.688236759751015, 3.878038021753894, 4.787452859991492, 5.688347186138325, 10.684026382733705, 11.654279404883495, 12.580549095041048, 13.59795438218338, 14.461205771691361, 14.672201465535336, 13.60127375194107, 12.70351149444209, 11.747063264330816, 10.700952657057123, 9.799714080081078, 8.773685378399161, 7.746287748153707, 6.7291160984987295, 5.76305255554779, 4.804292264844177, 3.750741035995512, 2.803874995740067, 3.774310083038046, 4.705054402491911, 9.699677628862329, 10.71351795922621, 11.64080080326096, 12.59669444357305, 13.521799580624307, 13.695893077687101, 12.648360342848058, 11.672488210095526, 10.705900387327082, 9.763173438424658, 8.800766523800085, 7.86586849015544, 6.797287930355525, 5.784708326528394, 4.835615687580136, 3.8723456125077114, 2.868461104253602, 1.8680363357218814, 2.8114750445416226, 3.8377949276947287, 8.744505347920517, 9.728334468894586, 10.64560105689073, 11.620326807489848, 12.57706005004723, 12.7952107808356, 11.870122829330901, 10.903264228465119, 9.908225978384657, 8.882649629496546, 7.850415216963301, 6.9172484538466765, 5.86542225913929, 4.920340828537761, 3.9601059336538698, 2.994891390551822, 1.9652507549017055, 0.9430175308421975, 1.8953629814719715, 2.8493563094735435, 7.759951133901816, 8.771696483127478, 9.69522651367068, 10.657661809700208, 11.626288057846976, 11.828656338607054, 10.892565734671063, 9.916481745483953, 8.902719374624377, 7.961574415184556, 6.954687916987482, 5.977914238656498, 5.007306586423174, 4.04745085617847, 3.0864368959335504, 2.0353206420395904, 1.0023367038083548, 0.0, 0.9441076940799267, 1.952859802207896, 6.781300400000132, 7.8010172131364515, 8.765182335521166, 9.68845495143232, 10.726239139354378, 11.738570166998821, 11.629545270149242, 10.659300149093614, 9.672309208955344, 8.679257389892278, 7.7241288240246755, 6.788637971986168, 5.854618349588744, 4.877387488529428, 3.849189890434231, 2.889978063207363, 1.936527180868461, 0.9672315276573067, 1.9027990615763701, 2.936617525319904, 5.788789663490144, 6.737972907540691, 7.752220053120475, 8.733373135678557, 9.734957505435926, 10.720371937952311, 11.769120834781637, 11.64608922429624, 10.58201859352518, 9.63995288998513, 8.657330440189325, 7.812837415980947, 6.804660727985693, 5.828538251556007, 4.835102391469641, 3.8469222945747052, 2.887045585644154, 1.934111764412268, 2.943020282123591, 3.928202040049527, 4.844652665130095, 5.8708227195246305, 6.712532515788502, 7.783086829994306, 8.799666959550946, 9.733802908728881, 10.70468695005721, 11.67255270313117, 11.542873486928183, 10.628020017047241, 9.656791077307577, 8.70831502555903, 7.723122863883279, 6.7573585708992905, 5.817986205707765, 4.823670620441448, 3.8361907487633053, 2.945038555572004, 3.93493252536315, 4.855461478776624, 3.888601895949466, 4.7969575296138025, 5.78481601263101, 6.82691263460069, 7.831919194338706, 8.809559835032946, 9.815590441468158, 10.829933058443693, 11.788835579623742, 11.584478003257077, 10.602741149761439, 9.695964963047306, 8.720829995765724, 7.729246052561969, 6.805623230984074, 5.761975067932659, 4.830060549676351, 3.9536465884466185, 5.009284548960029, 5.814774700825665, 2.900482466492007, 3.870797332855665, 4.8977939408794535, 5.845670184976467, 6.8973373996420335, 7.841534285689804, 8.815728598656232, 9.77527719317697, 10.731668719160929, 11.692578000607105, 11.567513990005896, 10.632043860150285, 9.71085701876905, 8.693838462803475, 7.7323610529646905, 6.8233868392445265, 5.865367966005795, 4.940260560905735, 5.939817951665398, 6.841928292913803, 3.871420715367643, 4.927456690199025, 5.850364669819753, 6.821096702459305, 7.815919443842314, 8.779970963822857, 9.753879493552473, 10.765203496558307, 11.688781908337333, 12.6680427499413, 12.58020459382687, 11.593336804235578, 10.701885545511542, 9.698674030904074, 8.728471935586153, 7.783904256942068, 6.8182417047431825, 5.925481233307733, 6.900537611314595, 7.889762330081539, 4.825246602585247, 5.886130014263917, 6.86246596215273, 7.780887348545097, 8.77724996777808, 9.74310509193586, 10.697938341848852, 11.671296184012332, 12.626163385866697, 13.653524148275306, 13.523449607978945, 12.62134741422441, 11.625924810177864, 10.698723897123989, 9.704166201391496, 8.747660661119534, 7.882041617155652, 6.949324320043951, 7.870223017139562, 8.825866039020156, 5.730237968326093, 6.706228215268496, 7.715294764147908, 8.70842153775493, 9.668661144300927, 10.69843554449903, 11.724419672705054, 12.655145890867951, 13.569722358842876, 14.51477165061582, 14.552730165350324, 13.5130446165171, 12.56787590193713, 11.60501033088522, 10.645913179298045, 9.784627097443416, 8.896613250091733, 8.019731182731892, 8.841566073600593, 9.771079568257669, 6.723257367620413, 7.655653852967432, 8.606621179527506, 9.55257515204068, 10.564888901086896, 11.549565744936746, 12.593891426373103, 13.55307565759032, 14.525469548970408, 15.491851796369618, 15.512920680904315, 14.468987718080442, 13.499229947929177, 12.592307039853104, 11.619704036675172, 10.810262775897119, 9.865052541983658, 8.947775966956856, 9.839111240137091, 10.747529155068307, 7.674891138789931, 8.648478039388538, 9.587763233601379, 10.515368055620135, 11.49806371812445, 12.481879306188446, 13.448707992772375, 14.417849856125184, 15.433633222093057, 16.39785929085556, 16.361543427623182, 15.382552466694074, 14.43427825990661, 13.657854084648415, 12.6877432843666, 11.801270819169325, 10.823468585134126, 10.010236789814147, 10.84837968610509, 11.676583733664518, 8.633385501380735, 9.69065282197136, 9.145036720449697, 9.647907048930456, 10.592714858669417, 11.518140807777854, 12.469522109918362, 13.439013359846253, 14.436838415394137, 15.471254938010008, 16.45025418913556, 16.40120215313963, 15.426710147683623, 14.68812052052858, 13.748335392667142, 12.80422871792626, 11.804312861226457, 11.01394466408863, 11.803575283567332, 12.741116870962422, 9.561071135014911, 8.867904438830944, 8.084164636648623, 8.628793651034286, 9.565400083526148, 10.568996229455184, 11.511849569229186, 12.538210024132134, 13.462528154166014, 14.492174240508199, 15.498438904780967, 16.379251119934633, 16.474112431769942, 15.672356199738001, 14.720557547729777, 13.800784154885918, 12.825283619261201, 12.065150714117282, 12.821325379305605, 13.80276373418411], [13.71790235179958, 13.034941362518286, 13.912782837973158, 14.757424001250323, 15.697138178661017, 16.64822201196839, 17.60250489857632, 17.349599782964813, 16.34056455446408, 15.490596639805972, 14.49925299136017, 13.455652327189194, 12.525672641968148, 11.515211082326148, 10.571854861675915, 9.562531866642553, 8.577588984178346, 7.985176058575721, 7.0261708363415085, 7.92148317177193, 12.646216594446557, 13.5912365525445, 14.54757186368036, 15.537563834922082, 16.509315016866335, 17.46752110465567, 17.391919983596022, 16.357412337830546, 15.412111115486319, 14.451545787707195, 13.519116206666068, 12.586298072852808, 11.576751765420623, 10.529976958687636, 9.56902676938603, 8.556428493969827, 7.540889173349995, 6.927518076475311, 5.976669971457214, 6.862241295472145, 11.64043480722991, 12.58616281305686, 13.58980898993293, 14.616000940150634, 15.539526761646043, 16.469503294676635, 16.511512136957474, 15.597277822286301, 14.613050739218608, 13.61512524844208, 12.680756938991198, 11.620890458209708, 10.589192027794136, 9.545015487627207, 8.552887019264599, 7.617029905534649, 6.569615548707312, 5.860000248307482, 4.938001963509654, 5.914004881155218, 10.672415499634825, 11.641498834785937, 12.668130712090054, 13.60138211694368, 14.477953607363032, 15.47112673957777, 15.512318554401151, 14.596803267971636, 13.617736021302493, 12.65955496117154, 11.673387603237815, 10.658743921334414, 9.609927769055309, 8.56325980928675, 7.489072829344891, 6.563029833377547, 5.6323444538309415, 4.822145715833821, 3.9725097822872706, 4.873404108434102, 9.740979817710718, 10.711232839860507, 11.63644140096112, 12.653846688103451, 13.517098077611433, 14.572076313472964, 14.545381446020997, 13.647619188522016, 12.691170958410742, 11.645060351137051, 10.743821774161004, 9.717793072479086, 8.690395442233633, 7.673223792578656, 6.707160249627717, 5.748399958924104, 4.694848730075439, 3.7479826898199935, 2.9593670053338244, 3.8901113247876897, 8.756631063839341, 9.770471394203224, 10.696693109181032, 11.652586749493121, 12.577691886544379, 13.58299933708475, 13.592468036927984, 12.616595904175453, 11.650008081407009, 10.707281132504585, 9.744874217880012, 8.809976184235365, 7.741395624435452, 6.7288160206083205, 5.779723381660062, 4.816453306587638, 3.812568798333529, 2.812144029801808, 1.9965319668374009, 2.9499724862640555, 7.80145878289753, 8.784226774814655, 9.701493362810801, 10.67621911340992, 11.632952355967301, 12.638170173365914, 12.81423052341083, 11.847371922545047, 10.852333672464583, 9.826757323576473, 8.794522911043227, 7.861356147926603, 6.809529953219217, 5.864448522617687, 4.904213627733796, 3.9389990846317486, 2.9093584489816324, 1.8871252249221242, 1.0075405400412976, 1.9615338680428698, 6.8169045688788295, 7.827588789047549, 8.75111881959075, 9.71355411562028, 10.682180363767047, 11.665479593788668, 11.83667342875099, 10.86058943956388, 9.846827068704304, 8.905682109264482, 7.898795611067409, 6.922021932736425, 5.9514142805031005, 4.991558550258397, 4.030544590013477, 2.979428336119517, 1.9464443978882815, 0.9441076940799267, 0.0, 1.0087521081279693, 5.838253834977145, 6.856909519056523, 7.821074641441237, 8.744347257352391, 9.78213144527445, 10.794462472918893, 11.797120176139655, 11.603407843173542, 10.616416903035272, 9.623365083972205, 8.668236518104601, 7.732745666066094, 6.798726043668671, 5.821495182609355, 4.793297584514158, 3.8340857572872897, 2.8806348749483877, 1.9113392217372334, 0.9586913674964433, 1.992509831239977, 4.844681969410216, 5.793865213460762, 6.808112359040546, 7.789265441598628, 8.790849811355999, 9.776264243872385, 10.82501314070171, 11.7725596884504, 11.526126287605106, 10.584060584065055, 9.60143813426925, 8.756945110060872, 7.74876842206562, 6.772645945635934, 5.779210085549567, 4.791029988654632, 3.831153279724081, 2.878219458492195, 2.021206783702578, 2.9851554750265406, 3.9005449710501674, 4.926715025444704, 5.768424821708575, 6.8389791359143794, 7.855559265471019, 8.789695214648955, 9.760579255977284, 10.728445009051244, 11.724953784423983, 11.572127711127166, 10.600898771387504, 9.652422719638956, 8.667230557963205, 7.701466264979217, 6.762093899787692, 5.767778314521375, 4.7802984428432325, 3.8891462496519305, 3.0180354828446134, 3.9124149137536373, 2.944494201869539, 3.852849835533876, 4.8407083185510835, 5.882804940520764, 6.887811500258779, 7.865452140953019, 8.871482747388232, 9.885825364363766, 10.844727885543817, 11.783089083263784, 11.546848843841365, 10.64007265712723, 9.66493768984565, 8.673353746641896, 7.749730925064001, 6.706082762012586, 5.774168243756278, 4.897754282526545, 4.092387506441492, 4.8717281358026785, 1.9563747724120806, 2.926689638775738, 3.953686246799527, 4.9015624908965405, 5.953229705562107, 6.897426591609877, 7.871620904576306, 8.831169499097046, 9.787561025081004, 10.74847030652718, 11.701016393530574, 11.57615155423021, 10.654964712848974, 9.637946156883402, 8.676468747044618, 7.767494533324453, 6.809475660085722, 5.884368254985661, 5.14068101574917, 5.898881727890815, 2.9835982739369693, 3.9833489961190987, 4.906256975739827, 5.876989008379378, 6.871811749762387, 7.835863269742929, 8.809771799472546, 9.82109580247838, 10.744674214257408, 11.723935055861375, 12.653786069078475, 12.537444498315503, 11.645993239591467, 10.642781724984, 9.672579629666078, 8.728011951021994, 7.762349398823109, 6.869588927387659, 6.101400675398367, 6.946715765058552, 3.9374241611545737, 4.998307572833243, 5.9183582680728035, 6.83677965446517, 7.8331422736981535, 8.798997397855935, 9.753830647768927, 10.727188489932407, 11.682055691786772, 12.709416454195381, 13.597031083230549, 13.565455108304334, 12.570032504257789, 11.642831591203914, 10.648273895471421, 9.691768355199459, 8.826149311235579, 7.893432014123878, 7.071086081223334, 7.882819473997169, 4.915294890621872, 5.8912851375642745, 6.86267504726907, 7.764313843675002, 8.724553450220998, 9.754327850419102, 10.780311978625129, 11.711038196788026, 12.625614664762951, 13.570663956535896, 14.618303196064092, 14.457152310597024, 13.511983596017055, 12.549118024965145, 11.59002087337797, 10.72873479152334, 9.840720944171657, 8.963838876811819, 8.042429137684366, 8.828033003234683, 5.9083142899161905, 6.840710775263211, 7.791678101823285, 8.737632074336458, 9.749945823382674, 10.68592970600958, 11.729127688662574, 12.68831191987979, 13.657408492672614, 14.547744102289693, 15.621816855275185, 15.413095412160366, 14.443337642009102, 13.536414733933029, 12.563811730755097, 11.754370469977044, 10.809160236063583, 9.891883661036783, 9.039974304220864, 9.804482590045321, 6.859948061085709, 7.833534961684316, 8.772820155897158, 9.700424977915914, 10.68312064042023, 11.625299307675116, 12.592127994259044, 13.561269857611855, 14.577053223579728, 15.569731504127297, 16.51250227219509, 16.326660160773997, 15.378385953986536, 14.60196177872834, 13.631850978446526, 12.74537851324925, 11.767576279214051, 10.954344483894074, 10.049242750188863, 10.733537168641533, 7.818442423676513, 8.875709744267139, 9.819086079245995, 10.592014743010381, 11.536822552749342, 12.462248501857779, 13.413629803998287, 14.383121053926178, 15.380946109474062, 16.415362632089934, 17.394361883215485, 17.345309847219553, 16.370817841763547, 15.632228214608505, 14.692443086747067, 13.748336412006186, 12.748420555306382, 11.958052358168556, 11.004438347651105, 11.798070305939437, 8.746128057310688, 8.052961361126723, 9.02827233072855, 9.57290134511421, 10.509507777606073, 11.513103923535109, 12.455957263309111, 13.482317718212059, 14.406635848245939, 15.436281934588123, 16.442546598860893, 17.32335881401456, 17.418220125849864, 16.616463893817926, 15.664665241809702, 14.744891848965842, 13.769391313341126, 12.973380778540584, 12.022188443389378, 12.859717169161124], [12.736704755194754, 13.552909289617983, 14.590976332568768, 15.52884742745954, 16.52972500614688, 17.438634938105572, 18.392917824713503, 18.358351891092777, 17.349316662592045, 16.499348747933944, 15.50800509948814, 14.464404435317164, 13.534424750096118, 12.523963190454118, 11.580606969803885, 10.571283974770523, 9.586341092306318, 8.993928166703691, 7.990693508990387, 7.0353229075714285, 11.665018997841731, 12.610038955939673, 13.566374267075535, 14.556366238317256, 15.506599706746185, 16.464805794535522, 17.419634684391784, 17.366164445958514, 16.420863223614287, 15.460297895835165, 14.527868314794038, 13.595050180980778, 12.585503873548591, 11.538729066815604, 10.577778877514, 9.565180602097797, 8.549641281477966, 7.936270184603281, 6.941192644106092, 5.976081031271643, 10.659237210625085, 11.604965216452035, 12.608611393328104, 13.613285630030486, 14.536811451525894, 15.466787984556486, 16.42449612495362, 16.60602993041427, 15.621802847346576, 14.623877356570048, 13.689509047119168, 12.629642566337678, 11.597944135922106, 10.553767595755176, 9.561639127392567, 8.625782013662619, 7.578367656835282, 6.868752356435452, 5.902524636158533, 5.027844616954717, 9.69121790303, 10.66030123818111, 11.665415401969906, 12.598666806823532, 13.475238297242884, 14.468411429457621, 15.425302542397297, 15.605555376099606, 14.626488129430461, 13.668307069299509, 12.682139711365785, 11.667496029462384, 10.618679877183279, 9.57201191741472, 8.49782493747286, 7.571781941505517, 6.6410965619589115, 5.830897823961791, 4.937032454936149, 3.987243844233601, 8.759782221105892, 9.730035243255681, 10.633726090840971, 11.651131377983303, 12.514382767491284, 13.569361003352816, 14.469724684779814, 14.656371296649986, 13.699923066538712, 12.65381245926502, 11.752573882288974, 10.726545180607058, 9.699147550361603, 8.681975900706625, 7.715912357755686, 6.757152067052074, 5.703600838203409, 4.7567347979479635, 3.9238896779827024, 3.0039510605871884, 7.775433467234516, 8.789273797598398, 9.693977799060884, 10.649871439372973, 11.57497657642423, 12.580284026964602, 13.516811275686802, 13.625348012303423, 12.658760189534979, 11.716033240632555, 10.753626326007982, 9.818728292363335, 8.750147732563422, 7.73756812873629, 6.7884754897880315, 5.825205414715607, 4.821320906461498, 3.8208961379297777, 2.961054639486279, 2.0065085029097887, 6.820261186292704, 7.781511464694507, 8.698778052690653, 9.67350380328977, 10.630237045847153, 11.635454863245766, 12.560542814750464, 12.856124030673016, 11.861085780592552, 10.835509431704443, 9.803275019171197, 8.870108256054573, 7.818282061347186, 6.873200630745656, 5.912965735861765, 4.947751192759718, 3.9181105571096015, 2.8958773330500938, 1.9720632126901756, 1.0180698846886034, 5.835706972274004, 6.8248734789274, 7.748403509470602, 8.710838805500131, 9.679465053646899, 10.662764283668519, 11.59885488760451, 11.869341547691848, 10.855579176832272, 9.91443421739245, 8.907547719195378, 7.930774040864395, 6.9601663886310705, 6.000310658386367, 5.039296698141447, 3.9881804442474866, 2.955196506016251, 1.952859802207896, 1.0087521081279693, 0.0, 4.857056238372319, 5.8541942089363745, 6.818359331321089, 7.741631947232243, 8.779416135154301, 9.791747162798744, 10.788368068011687, 11.758613189067315, 11.62516901116324, 10.632117192100175, 9.676988626232571, 8.741497774194064, 7.807478151796641, 6.830247290737325, 5.802049692642128, 4.84283786541526, 3.889386983076357, 2.920091329865203, 1.9674434756244126, 1.0113122346351509, 3.841966659290067, 4.791149903340614, 5.805397048920398, 6.78655013147848, 7.782097703228031, 8.767512135744417, 9.816261032573742, 10.763807580322432, 11.677056569699017, 11.592812692193025, 10.61019024239722, 9.765697218188842, 8.75752053019359, 7.781398053763904, 6.787962193677537, 5.799782096782602, 4.83990538785205, 3.886971566620164, 2.989139636347651, 2.0039578784217147, 2.8978296609300185, 3.9179629173167347, 4.759672713580606, 5.83022702778641, 6.846807157343051, 7.780943106520986, 8.751827147849315, 9.719692900923276, 10.716201676296015, 11.730794961345651, 11.609650879515474, 10.661174827766926, 9.675982666091175, 8.710218373107187, 7.770846007915662, 6.776530422649345, 5.789050550971201, 4.8978983577799, 3.9859683354896864, 2.9312173171488114, 1.9417788917493901, 2.8440977274059067, 3.8319562104231144, 4.874052832392795, 5.879059392130811, 6.856700032825051, 7.862730639260264, 8.877073256235798, 9.835975777415848, 10.774336975135816, 11.68282263899442, 11.6488247652552, 10.67368979797362, 9.682105854769866, 8.75848303319197, 7.714834870140554, 6.782920351884246, 5.888684020931217, 4.817058117709223, 3.8905305391978526, 0.9476226642841112, 1.917937530647769, 2.9449341386715577, 3.892810382768572, 4.944477597434139, 5.888674483481909, 6.862868796448338, 7.822417390969077, 8.778808916953036, 9.739718198399212, 10.692264285402606, 11.627734415258217, 11.663716820976944, 10.646698265011372, 9.685220855172586, 8.749514572033496, 7.791495698794765, 6.849439196637314, 5.849881805877651, 4.91768413128599, 1.999824659314471, 2.9745968879911295, 3.8975048676118575, 4.86823690025141, 5.863059641634419, 6.827111161614961, 7.801019691344578, 8.812343694350412, 9.73592210612944, 10.715182947733407, 11.645033960950506, 12.589027359343511, 12.654745347719437, 11.624801763693045, 10.654599668375123, 9.710031989731037, 8.744369437532152, 7.834275883694883, 6.810601465526848, 5.965518168453726, 2.9536505465320757, 4.014533958210745, 4.909606159944834, 5.828027546337202, 6.824390165570185, 7.790245289727967, 8.745078539640959, 9.71843638180444, 10.673303583658804, 11.700664346067413, 12.58827897510258, 13.624340236324196, 13.552052542966834, 12.624851629912959, 11.630293934180465, 10.673788393908502, 9.726592165703606, 8.762330116086394, 7.780286871351815, 6.901621877392343, 3.999813675924414, 4.975803922866817, 5.8539229391411, 6.755561735547034, 7.715801342093031, 8.745575742291134, 9.77155987049716, 10.702286088660058, 11.616862556634983, 12.561911848407927, 13.609551087936124, 14.649236636769349, 14.4940036347261, 13.531138063674188, 12.572040912087013, 11.710754830232386, 10.741163798639686, 9.819153257109521, 8.751629927812846, 7.846835406629857, 5.02215402571569, 5.925229560565753, 6.823249177400529, 7.758210302087362, 8.754336724394175, 9.677177597881611, 10.720375580534606, 11.679559811751822, 12.648656384544646, 13.538991994161725, 14.613064747147217, 15.65699770997109, 15.425357680718147, 14.518434772642072, 13.54583176946414, 12.654813324445072, 11.709603090531612, 10.747198041334485, 9.749175094349345, 8.823284993440495, 5.973787796885208, 6.947374697483815, 7.886659891696655, 8.813202396222868, 9.795898058727184, 10.616547199547147, 11.583375886131076, 12.552517749483886, 13.56830111545176, 14.560979395999329, 15.503750164067121, 16.48274112499623, 16.360405992695583, 15.583981817437383, 14.613871017155569, 13.645821367717279, 12.66801913368208, 11.799853289217957, 10.738894561132913, 9.752339572036707, 6.932282159476011, 7.989549480066637, 8.932925815045492, 9.836078494846914, 10.780886304585875, 11.615028596018133, 12.580871169564432, 13.550362419492323, 14.548187475040207, 15.487583748844884, 16.466582999970434, 17.39261472687076, 17.352837880472595, 16.588149860265954, 15.648364732404515, 14.648779266474214, 13.64886340977441, 12.728956195352135, 11.694090158595154, 10.81687270933461, 7.859967793110187, 8.81333608994287, 9.823431847290344, 10.581653453242183, 11.518259885734045, 12.52185603166308, 13.464709371437081, 14.491069826340027, 15.415387956373909, 16.44503404271609, 17.45129870698886, 18.332110922142526, 18.400240164558912, 17.572385539475373, 16.62058688746715, 15.645334703433871, 14.669834167809155, 13.663032589484633, 12.711840254333428, 11.878519572556298], [7.879648516822434, 8.695853051245663, 9.73392009419645, 10.671791189087221, 11.74137199435574, 12.671012957062262, 13.625295843670193, 14.642364392745424, 15.517812068971836, 16.47022115099434, 17.51328409876627, 18.453003103859686, 18.362865347888356, 17.352403788246356, 16.409047567596122, 15.39972457256276, 14.414781690098554, 13.822368764495929, 12.847749747362707, 11.892379145943746, 6.807962759469412, 7.752982717567355, 8.709318028703215, 9.699309999944937, 10.73264834433552, 11.697183813492213, 12.652012703348475, 13.64405740764985, 14.589358629994075, 15.5499239577732, 16.482353538814326, 17.415171672627586, 17.41394447134083, 16.367169664607843, 15.406219475306237, 14.393621199890035, 13.378081879270201, 12.764710782395518, 11.798248882478411, 10.833137269643961, 5.802180972252765, 6.747908978079717, 7.751555154955787, 8.782046212545568, 9.769189470482587, 10.699166003513179, 11.656874143910311, 12.629239737004522, 13.613466820072215, 14.555240451536614, 15.489608760987494, 16.47859523965191, 16.426384733714343, 15.382208193547413, 14.390079725184805, 13.454222611454856, 12.406808254627519, 11.697192954227688, 10.759580874530853, 9.884900855327036, 4.834161664657681, 5.8032449998087925, 6.840363580286028, 7.784820716745929, 8.707616316199577, 9.700789448414314, 10.65768056135399, 11.580855041970242, 12.61914772856563, 13.577328788696583, 14.52529649904927, 15.516448702776614, 15.447120474975517, 14.400452515206958, 13.326265535265097, 12.400222539297753, 11.469537159751148, 10.659338421754027, 9.794088693308469, 8.84430008260592, 3.9027259827335734, 4.872979004883363, 5.808674269157095, 6.8372852879057, 7.746760786447976, 8.801739022309507, 9.702102703736507, 10.631670962520623, 11.642337439861482, 12.57215541769936, 13.59573066997246, 14.563645588491262, 14.448913595607964, 13.510416498498861, 12.544352955547922, 11.58559266484431, 10.532041435995644, 9.5851753957402, 8.780945916355023, 7.861007298959509, 2.9183772288621967, 3.9322175592260784, 4.914241861578646, 5.8701355018907355, 6.807354595380923, 7.812662045921294, 8.749189294643495, 9.725061427396026, 10.69164925016447, 11.634376199066894, 12.596783113691467, 13.531681147336114, 13.499913777809782, 12.566008726528525, 11.616916087580266, 10.653646012507842, 9.649761504253734, 8.649336735722013, 7.818110877858599, 6.863564741282109, 1.963204947920385, 2.9694914625271878, 3.9311560716473446, 4.905881822246462, 5.862615064803846, 6.867832882202459, 7.792920833707157, 8.75977943457294, 9.754817684653403, 10.747191594227429, 11.779426006760675, 12.685218617765948, 12.553307233768685, 11.608225803167155, 10.647990908283264, 9.724324060080768, 8.723370681657512, 7.724317930842329, 6.829119451062495, 5.875126123060923, 0.9786507339016841, 2.012853476760081, 2.9807815284272943, 3.943216824456824, 4.911843072603592, 5.895142302625213, 6.831232906561205, 7.807316895748315, 8.82107926660789, 9.762224226047712, 10.769110724244785, 11.745884402575768, 11.641017458471985, 10.681161728227282, 9.721901498111125, 8.75649632401527, 7.760456630564161, 6.781300400000131, 5.838253834977145, 4.857056238372319, 0.0, 1.0727134248609071, 2.0507373502777813, 3.0213877530725086, 4.059171940994567, 5.07150296863901, 6.099118433602662, 7.06936355465829, 8.05635449479656, 9.049406313859627, 10.004534879727231, 10.940025731765738, 10.701455694274264, 9.724224833214947, 8.69602723511975, 7.736815407892881, 6.783364525553979, 5.814068872342824, 4.879562467480702, 3.845744003737168, 1.0689646975201899, 2.018147941570737, 3.0323950871505208, 3.976469568826272, 5.025152665779803, 6.010567098296188, 7.060129246959507, 8.07384064660087, 9.039651349181105, 9.981717052721155, 10.93773649589188, 10.75533430504986, 9.759126985495122, 8.783004509065437, 7.828146670643759, 6.839966573748823, 5.800122456819749, 4.847188635587863, 3.8382801178765407, 2.8530983599506046, 2.0131016958802386, 3.0307188112296197, 4.0633573148804025, 4.949142475039565, 5.960443211664783, 6.894579160842719, 7.865463202171047, 8.833328955245006, 9.829837730617745, 10.88265859529881, 10.696338704748209, 9.747862652999661, 8.76267049132391, 7.796906198339922, 6.857533833148397, 5.86321824788208, 4.906669099913193, 3.957299271073862, 2.9674053012827155, 1.9258389212235079, 2.969152465060867, 3.9347974422790477, 4.922655925296255, 5.983718655742675, 6.928190976877023, 7.8220776132479575, 8.86148833414717, 9.806403512311421, 10.772212984608478, 10.925828587808896, 9.868232032397817, 8.902884249537118, 7.927749282255537, 6.854772564897673, 5.913147063963486, 4.869498900912071, 3.9375843826557633, 2.964679180907831, 1.8930532776858366, 0.9665256991744664, 3.963308692526146, 4.860957639037185, 5.887954247060973, 6.835830491157987, 7.887497705823553, 8.82912613313242, 9.803320446098848, 10.762869040619586, 11.719260566603545, 11.656689239725727, 10.704143152722333, 9.768673022866722, 8.824405885452613, 7.800285461721064, 6.7745454571173145, 5.82550973201011, 4.8674908587713785, 3.925434356613928, 2.9258769658542647, 1.9936792912626038, 5.015510687556506, 5.917616996380546, 6.840524976001273, 7.811257008640824, 8.806079750023834, 9.767562811265472, 10.741471340995089, 11.752795344000923, 12.676373755779949, 12.632153989059923, 11.716833756543307, 10.729965966952015, 9.769138922121236, 8.700796923669657, 7.7305948283517365, 6.786027149707651, 5.820364597508766, 4.910271043671497, 3.8865966255034623, 3.030179550193357, 5.96933657477411, 6.972508997479568, 7.85262626833425, 8.771047654726615, 9.767410273959598, 10.733265398117378, 11.68809864803037, 12.661456490193851, 13.613755233309313, 13.706903452992984, 12.659531568211609, 11.623470306989994, 10.628047702943446, 9.700846789889571, 8.706289094157079, 7.749783553885116, 6.80258732568022, 5.838325276063008, 4.856282031328429, 3.8828044517836644, 7.015499704166448, 7.99148995110885, 8.796943047530515, 9.698581843936449, 10.658821450482446, 11.68859585068055, 12.714579978886572, 13.64530619704947, 14.557314206285492, 14.602492297644101, 13.554853058115905, 12.51516750928268, 11.569998794702713, 10.607133223650802, 9.648036072063627, 8.786749990209, 7.817158958616299, 6.895148417086136, 5.82762508778946, 4.828017981021178, 8.059310944091088, 8.940915588807785, 9.766269285789944, 10.701230410476777, 11.697356832783589, 12.620197706271027, 13.663395688924018, 14.622579920141234, 15.589108034195155, 15.579572443397899, 14.515043573669896, 13.471110610846024, 12.501352840694759, 11.594429932618686, 10.621826929440754, 9.730808484421686, 8.785598250508226, 7.823193201311101, 6.825170254325959, 5.774951225934076, 9.010944715260607, 9.968070835512714, 10.837698657823836, 11.756222504612284, 12.7389181671166, 13.559567307936563, 14.526395994520492, 15.495537857873302, 16.511321223841176, 16.306437088456555, 15.363666320388765, 14.384675359459656, 13.436401152672193, 12.659976977413997, 11.689866177132183, 10.721816527693893, 9.744014293658694, 8.751519521711536, 7.690560793626492, 6.704005804530286, 9.980896553801996, 11.016698746359028, 11.883964581172673, 12.77909860323633, 13.72390641297529, 14.558048704407549, 15.523891277953847, 16.49338252788174, 17.491207583429624, 17.23304144130211, 16.32935677280554, 15.403325045905211, 14.428833040449206, 13.609432191249272, 12.669647063387835, 11.670061597457535, 10.660367126881237, 9.680622427845714, 8.645756391088733, 7.76853894182819, 10.908582187436172, 11.861950484268856, 12.87204624161633, 13.7982120011325, 14.734818433624362, 15.507193282730219, 16.47683880493976, 17.458642624306318, 18.453613049694624, 18.304738721682714, 17.377081885238958, 16.406012423769354, 15.476235324535523, 14.593667870458694, 13.64186921845047, 12.645260834628148, 11.63164397116562, 10.614698821978212, 9.663506486827007, 8.830185805049878], [8.883395032577967, 8.011692299500615, 8.941486961382317, 9.773253069950847, 10.689389600242665, 11.598299532201354, 12.552582418809285, 13.569650967884517, 14.445098644110928, 15.397507726133433, 16.440570673905363, 17.38028967899878, 17.46140391757577, 16.45094235793377, 15.518446203743736, 14.762587104096008, 13.863528221222689, 13.078903480892274, 12.264058077694294, 12.836117265068822, 7.811709275224944, 7.0688219658223055, 7.901321308701542, 8.800771880808563, 9.66626430084197, 10.624470388631305, 11.579299278487568, 12.571343982788942, 13.516645205133168, 14.477210532912292, 15.409640113953419, 16.34245824776668, 17.395196926604683, 17.386886477744163, 16.425936288442557, 15.413338013026355, 14.397798692406521, 13.784427595531838, 12.795386853042467, 11.830275240208017, 6.805927488008298, 6.063748226334667, 6.835005383932889, 7.772950224126272, 8.69647604562168, 9.626452578652271, 10.584160719049404, 11.556526312143614, 12.540753395211308, 13.482527026675706, 14.416895336126586, 15.405881814791002, 16.443005119237924, 16.401925006683733, 15.409796538321125, 14.473939424591176, 13.426525067763839, 12.716909767364008, 11.756718845094909, 10.882038825891092, 5.837908180413214, 5.0009468815016636, 5.825079996065689, 6.758331400919317, 7.634902891338669, 8.628076023553406, 9.584967136493082, 10.508141617109334, 11.546434303704723, 12.504615363835676, 13.452583074188365, 14.443735277915708, 15.492551430194814, 15.420169328343277, 14.345982348401417, 13.419939352434072, 12.489253972887468, 11.679055234890347, 10.791226663872525, 9.841438053169977, 4.906472498489107, 3.9899555566649956, 4.793390684936756, 5.810795972079088, 6.6740473615870695, 7.729025597448601, 8.6293892788756, 9.558957537659715, 10.569624015000574, 11.499441992838452, 12.523017245111554, 13.490932163630356, 14.476548100073304, 14.530133311635181, 13.564069768684242, 12.60530947798063, 11.551758249131964, 10.60489220887652, 9.77808388691908, 8.858145269523565, 3.9221237446177306, 2.98650799456252, 3.853642393156669, 4.809536033468758, 5.734641170520017, 6.739948621060387, 7.676475869782588, 8.65234800253512, 9.618935825303565, 10.561662774205988, 11.524069688830561, 12.458967722475208, 13.527548282275122, 13.585725539664844, 12.636632900716586, 11.673362825644162, 10.669478317390054, 9.669053548858333, 8.815248848422655, 7.860702711846165, 2.966951463675919, 1.9273172557581328, 2.858442646786438, 3.8331683973855557, 4.789901639942939, 5.795119457341552, 6.7202074088462505, 7.687066009712034, 8.682104259792496, 9.674478169366523, 10.706712581899769, 11.612505192905042, 12.623982463428378, 12.649038882083527, 11.688803987199636, 10.76513713899714, 9.764183760573886, 8.744034743978649, 7.8262574216265515, 6.872264093624979, 2.0048820128494222, 0.9706792699910258, 1.9080681035663876, 2.8705033995959175, 3.839129647742685, 4.822428877764306, 5.758519481700298, 6.734603470887408, 7.748365841746984, 8.689510801186806, 9.696397299383879, 10.673170977714863, 11.643778629948187, 11.721974807143654, 10.762714577027497, 9.797309402931642, 8.801269709480534, 7.801017213136451, 6.856909519056524, 5.854194208936375, 1.0727134248609071, 0.0, 0.9780239254168742, 1.9486743282116015, 2.986458516133659, 3.9987895437781016, 5.026405008741754, 5.996650129797382, 6.983641069935652, 7.976692888998719, 8.931821454866322, 9.867312306904829, 10.801331929302252, 10.76503791213132, 9.736840314036122, 8.777628486809254, 7.824177604470353, 6.854881951259198, 5.898218151560081, 4.864399687816547, 2.012227549646308, 1.0630443055957608, 1.9909862078175657, 2.903756143965365, 3.9524392409188955, 4.9378536734352805, 5.987415822098599, 7.001127221739961, 7.966937924320197, 8.909003627860248, 9.86502307103097, 10.891511750899607, 10.831840410356028, 9.855717933926343, 8.900860095504665, 7.91267999860973, 6.872835881680656, 5.91990206044877, 4.910993542737447, 3.9258117848115113, 2.9563645480063565, 2.0756151752546437, 3.063780715807531, 3.8764290501786585, 4.887729786803876, 5.821865735981811, 6.7927497773101395, 7.760615530384099, 8.757124305756838, 9.809945170437903, 10.864187951863697, 10.820576077860567, 9.835383916184815, 8.869619623200828, 7.930247258009303, 6.935931672742987, 5.979382524774101, 5.0300126959347695, 4.040118726143623, 2.9985523460844146, 3.912415317186985, 3.1494803651654717, 3.991497218965023, 4.924591900688087, 5.855477552016115, 6.74936418838705, 7.788774909286262, 8.733690087450514, 9.69949955974757, 10.720731834495549, 10.940945457258724, 9.975597674398026, 9.000462707116444, 7.92748598975858, 6.985860488824393, 5.942212325772978, 5.01029780751667, 4.037392605768738, 2.965766702546744, 2.0392391240353733, 4.906571544652264, 4.075640561923609, 4.97892479082667, 5.905834350312311, 6.848622335383135, 7.756412708271513, 8.730607021237942, 9.69015561575868, 10.646547141742639, 11.607456423188815, 11.776856577583239, 10.841386447727627, 9.897119310313519, 8.87299888658197, 7.847258881978221, 6.898223156871016, 5.940204283632285, 4.9981477814748345, 3.9985903907151714, 3.0663927161235107, 5.958773539682624, 5.13229991926697, 5.93149551976697, 6.881260867795149, 7.871726863838482, 8.694849386404565, 9.668757916134183, 10.680081919140017, 11.603660330919043, 12.58292117252301, 12.789547181404213, 11.802679391812921, 10.841852346982144, 9.773510348530564, 8.803308253212643, 7.858740574568558, 6.893078022369672, 5.982984468532404, 4.959310050364369, 4.033926065948891, 6.912599426900228, 6.187191920365992, 6.943596812099947, 7.841051513880941, 8.837414133113924, 9.710557417367966, 10.63814849710213, 11.61150633926561, 12.541041808448405, 13.568402570857014, 13.732244993072516, 12.696183731850901, 11.700761127804354, 10.773560214750479, 9.779002519017986, 8.822496978746024, 7.875300750541125, 6.911038700923914, 5.928995456189336, 4.886550967539198, 7.958762556292566, 7.242337490418407, 7.887913591296213, 8.768585703090773, 9.72882530963677, 10.758599709834872, 11.66462982795833, 12.595356046121228, 13.484600781424584, 14.429650073197529, 14.627566482976812, 13.587880934143588, 12.64271221956362, 11.67984664851171, 10.720749496924535, 9.859463415069907, 8.889872383477204, 7.931791852534158, 6.864268523237483, 5.831764496776712, 9.002573796217206, 8.191763128117342, 8.857239829555642, 9.771234269631101, 10.767360691937913, 11.69020156542535, 12.613445537995775, 13.572629769212991, 14.516394609334247, 15.406730218951326, 15.587756998530804, 14.543824035706931, 13.574066265555667, 12.667143357479594, 11.694540354301662, 10.80352190928259, 9.85831167536913, 8.843323706330784, 7.842136221789412, 6.778697741689609, 9.954207567386725, 9.218918374822271, 9.928669201589534, 10.826226363766608, 11.808922026270924, 12.629571167090885, 13.551453378602236, 14.520595241955046, 15.53637860792292, 16.42871762078893, 16.436379745249674, 15.457388784320564, 14.5091145775331, 13.732690402274905, 12.76257960199309, 11.794529952554797, 10.764154079033682, 9.755266037467068, 8.694307309382024, 7.707752320285819, 10.924159405928114, 10.267546285668585, 10.974935124938371, 11.849102462390654, 12.793910272129615, 13.628052563561871, 14.55252363626163, 15.522014886189522, 16.519839941737406, 17.355321973634485, 17.35661200842588, 16.430580281525554, 15.43767928995214, 14.493863585284114, 13.554078457422676, 12.638191366897496, 11.664113642636769, 10.684368943601246, 9.649502906844265, 8.772285457583722, 11.85184503956229, 11.23726755290908, 12.035807208739445, 12.868215860286824, 13.804822292778686, 14.577197141884541, 15.510196176950807, 16.4872749826141, 17.482245408002406, 17.416176549286575, 16.409911885013805, 15.427892903661409, 14.536515689030107, 13.533654954368265, 12.581856302360041, 11.64163592993784, 10.761285757860044, 9.880889020814891, 9.024445218629523, 9.83393232080541], [9.698237580032263, 8.772798766629231, 7.963463035965443, 8.795229144533971, 9.71136567482579, 10.620275606784478, 11.57455849339241, 12.59162704246764, 13.467074718694054, 14.41948380071656, 15.46254674848849, 16.402265753581904, 16.483379992158895, 15.472918432516895, 14.540422278326862, 13.784563178679134, 12.885504295805815, 12.1008795554754, 12.902478180275793, 13.677865122671392, 8.62655182267924, 7.829928432950923, 6.923297383284668, 7.822747955391687, 8.688240375425096, 9.64644646321443, 10.601275353070694, 11.593320057372068, 12.538621279716294, 13.499186607495417, 14.431616188536545, 15.364434322349805, 16.41717300118781, 16.47010973851467, 15.588077819268303, 14.79066655135186, 13.922204106634167, 13.15853753757581, 13.75955197542718, 12.722108391735052, 7.620770035462594, 6.824854693463284, 5.856981458516015, 6.794926298709397, 7.718452120204804, 8.648428653235396, 9.60613679363253, 10.57850238672674, 11.562729469794434, 12.504503101258832, 13.438871410709712, 14.427857889374128, 15.46498119382105, 16.45924416940611, 16.373961660705838, 15.43810454697589, 14.390690190148552, 13.681074889748722, 12.72088396747962, 11.822724904932368, 6.6527507278675095, 5.762053348630281, 4.847056070648815, 5.780307475502442, 6.656878965921794, 7.650052098136531, 8.606943211076208, 9.53011769169246, 10.56841037828785, 11.526591438418802, 12.47455914877149, 13.465711352498834, 14.51452750477794, 15.477488491065653, 15.31014747078613, 14.384104474818786, 13.453419095272181, 12.64322035727506, 11.755391786257237, 10.80560317555469, 5.721315045943403, 4.751062023793613, 3.8153667595198817, 4.832772046662213, 5.6960234361701945, 6.751001672031727, 7.651365353458726, 8.580933612242841, 9.5916000895837, 10.521418067421578, 11.54499331969468, 12.512908238213482, 13.49852417465643, 14.52233121076184, 14.528234891068955, 13.569474600365343, 12.515923371516678, 11.569057331261233, 10.74224900930379, 9.822310391908278, 4.8643554548232295, 3.857642770092362, 2.8756184677397942, 3.8315121080518835, 4.756617245103142, 5.761924695643513, 6.698451944365714, 7.674324077118246, 8.64091189988669, 9.583638848789114, 10.546045763413687, 11.480943797058334, 12.549524356858248, 13.562103960685379, 13.6007980231013, 12.637527948028875, 11.633643439774767, 10.633218671243046, 9.779413970807367, 8.824867834230878, 3.9091831738814182, 2.8695489659636317, 1.8804187213695633, 2.855144471968681, 3.8118777145260645, 4.817095531924678, 5.742183483429376, 6.7090420842951595, 7.704080334375623, 8.696454243949647, 9.728688656482893, 10.634481267488166, 11.645958538011502, 12.591039968613032, 12.652969109584351, 11.729302261381855, 10.728348882958601, 9.708199866363362, 8.790422544011264, 7.836429216009693, 2.9471137230549216, 1.9129109801965247, 0.9300441781495132, 1.892479474179043, 2.8611057223258105, 3.8444049523474315, 4.780495556283423, 5.756579545470533, 6.770341916330109, 7.71148687576993, 8.718373373967003, 9.695147052297987, 10.665754704531311, 11.625610434776014, 11.726879699412212, 10.761474525316357, 9.76543483186525, 8.765182335521164, 7.821074641441237, 6.818359331321089, 2.0507373502777813, 0.9780239254168742, 0.0, 0.9706504027947274, 2.008434590716785, 3.0207656183612275, 4.04838108332488, 5.018626204380508, 6.005617144518778, 6.998668963581845, 7.953797529449448, 8.889288381487955, 9.823308003885378, 10.800538864944695, 10.701005436420838, 9.74179360919397, 8.788342726855067, 7.819047073643912, 6.862383273944794, 5.828564810201261, 2.976392672031022, 2.027209427980475, 1.0129622824006916, 1.9257322185484909, 2.9744153155020214, 3.9598297480184064, 5.009391896681725, 6.023103296323087, 6.988913998903323, 7.9309797024433735, 8.886999145614096, 9.913487825482733, 10.826273883537104, 10.833741859343217, 9.878884020921538, 8.890703924026603, 7.85085980709753, 6.897925985865644, 5.8890174681543215, 4.903835710228385, 3.920529670391071, 3.039780297639358, 2.085756790390657, 2.8984051247617844, 3.909705861387002, 4.843841810564938, 5.814725851893266, 6.782591604967226, 7.779100380339964, 8.831921245021029, 9.886164026446822, 10.83464007819537, 10.81340784160169, 9.847643548617702, 8.908271183426177, 7.913955598159861, 6.957406450190975, 6.008036621351644, 5.018142651560497, 3.9765762715012887, 4.876580439571699, 4.001331776565356, 3.0134732935481487, 3.946567975271213, 4.877453626599242, 5.771340262970177, 6.810750983869389, 7.755666162033641, 8.721475634330698, 9.742707909078677, 10.800304464489756, 10.9536215998149, 9.978486632533318, 8.905509915175454, 7.963884414241267, 6.920236251189852, 5.988321732933544, 5.015416531185612, 3.943790627963618, 3.0172630494522474, 5.870736667036978, 4.927491973323494, 4.000900865409796, 4.927810424895437, 5.870598409966262, 6.778388782854639, 7.752583095821069, 8.712131690341808, 9.668523216325767, 10.629432497771942, 11.581978584775337, 11.796026945321511, 10.851759807907403, 9.827639384175853, 8.801899379572104, 7.852863654464899, 6.894844781226168, 5.952788279068717, 4.953230888309054, 4.021033213717393, 6.922938662067337, 5.8996421839659545, 4.953471594350096, 5.903236942378275, 6.893702938421609, 7.716825460987692, 8.690733990717309, 9.702057993723143, 10.62563640550217, 11.604897247106138, 12.534748260323237, 12.757319889406805, 11.796492844576026, 10.728150846124448, 9.757948750806527, 8.813381072162441, 7.847718519963555, 6.937624966126287, 5.913950547958252, 4.97615777615439, 7.876764549284942, 6.9545341850649764, 5.965572886683073, 6.863027588464067, 7.85939020769705, 8.732533491951093, 9.660124571685255, 10.633482413848736, 11.563017883031534, 12.590378645440143, 13.477993274475311, 13.650824229444783, 12.655401625398238, 11.728200712344362, 10.733643016611868, 9.777137476339906, 8.82994124813501, 7.865679198517798, 6.883635953783219, 5.828782677744697, 8.894946461701153, 7.918956214758751, 6.909889665879339, 7.790561777673899, 8.750801384219896, 9.780575784417998, 10.686605902541455, 11.617332120704354, 12.506576856007714, 13.451626147780658, 14.499265387308855, 14.542521431737473, 13.597352717157504, 12.634487146105592, 11.675389994518417, 10.81410391266379, 9.84451288107109, 8.824710648499561, 7.7571873192028855, 6.724683292742115, 9.844321653819776, 8.830183230698841, 7.879215904138768, 8.793210344214227, 9.78933676652104, 10.712177640008475, 11.6354216125789, 12.594605843796117, 13.538370683917377, 14.428706293534455, 15.502779046519947, 15.498464533300815, 14.52870676314955, 13.621783855073476, 12.649180851895544, 11.66005982434175, 10.71484959042829, 9.65816625378508, 8.656978769243707, 7.593540289143904, 10.795955424989295, 9.85733847740377, 8.95064527617266, 9.848202438349734, 10.83089810085405, 11.651547241674011, 12.573429453185362, 13.542571316538172, 14.558354682506046, 15.45069369537206, 16.39346446343985, 16.400361459099738, 15.452087252312277, 14.58772716859584, 13.636646640306342, 12.619099496707204, 11.57899662648798, 10.570108584921366, 9.509149856836322, 8.522594867740116, 11.765907263530684, 10.905966388250084, 9.996911199521497, 10.87107853697378, 11.815886346712741, 12.650028638144997, 13.574499710844757, 14.543990960772648, 15.541816016320531, 16.377298048217614, 16.378588083009006, 15.45255635610868, 14.459655364535264, 13.515839659867238, 12.5760545320058, 11.660167441480622, 10.804232590477913, 9.954071145426669, 10.464345454298563, 9.58712800503802, 12.69359289716486, 11.875687655490578, 11.057783283322571, 11.89019193486995, 12.826798367361812, 13.599173216467667, 14.532172251533932, 15.509251057197226, 16.504221482585532, 16.438152623869698, 15.43188795959693, 14.449868978244535, 13.558491763613231, 12.555631028951389, 11.603832376943165, 10.663612004520965, 9.783261832443168, 8.902865095398017, 9.78555168575814, 10.648774868259707], [10.668887982826991, 9.74344916942396, 8.934113438760171, 7.984251876895966, 8.803777900169953, 9.71268783212864, 10.666970718736572, 11.684039267811803, 12.559486944038216, 13.511896026060722, 14.554958973832653, 15.494677978926067, 15.51272958936417, 14.50226802972217, 13.569771875532137, 12.813912775884406, 11.914853893011086, 12.844058065882457, 13.789581754658625, 14.567163132465296, 9.597202225473968, 8.80057883574565, 7.893947786079395, 7.011770687753682, 7.780652600769257, 8.738858688558592, 9.693687578414856, 10.68573228271623, 11.631033505060456, 12.59159883283958, 13.524028413880707, 14.456846547693967, 15.509585226531971, 15.499459335719944, 14.617427416473578, 13.820016148557132, 12.951553703839439, 13.901716047982868, 14.678135394892282, 13.611406401528956, 8.591420438257321, 7.795505096258012, 6.827631861310742, 5.983949031071391, 6.810864345548967, 7.740840878579558, 8.698549018976692, 9.670914612070902, 10.655141695138596, 11.596915326602995, 12.531283636053875, 13.52027011471829, 14.557393419165212, 15.551656394750271, 15.642510695389705, 14.75941473699231, 13.922827328482121, 14.604347505659875, 13.644156583390775, 12.712022914726273, 7.623401130662237, 6.732703751425008, 5.817706473443542, 4.969330207864436, 5.749291191265956, 6.742464323480694, 7.69935543642037, 8.622529917036623, 9.660822603632012, 10.619003663762964, 11.566971374115653, 12.558123577842997, 13.606939730122102, 14.569900716409816, 15.577460081066654, 15.30737709072994, 14.376691711183335, 13.566492973186214, 12.67866440216839, 11.728875791465844, 6.69196544873813, 5.721712426588341, 4.786017162314609, 4.021794779024207, 4.788435661514357, 5.843413897375889, 6.743777578802888, 7.673345837587004, 8.684012314927863, 9.61383029276574, 10.637405545038842, 11.605320463557645, 12.590936400000592, 13.614743436106002, 14.52643221175574, 14.492747216276497, 13.439195987427832, 12.492329947172387, 11.665521625214945, 10.745583007819432, 5.835005857617958, 4.82829317288709, 3.8462688705345216, 3.0205348404138768, 3.849029470447304, 4.854336920987675, 5.790864169709876, 6.766736302462409, 7.733324125230853, 8.676051074133277, 9.63845798875785, 10.573356022402496, 11.64193658220241, 12.654516186029541, 13.598995343788085, 13.560800563940031, 12.556916055685921, 11.5564912871542, 10.70268658671852, 9.748140450142031, 4.879833576676146, 3.840199368758359, 2.8510691241642907, 2.0315296870975526, 2.904289939870227, 3.90950775726884, 4.834595708773539, 5.801454309639322, 6.796492559719785, 7.78886646929381, 8.821100881827055, 9.726893492832328, 10.738370763355665, 11.683452193957194, 12.605126030537235, 12.652574877293008, 11.651621498869753, 10.631472482274516, 9.713695159922418, 8.759701831920847, 3.917764125849649, 2.8835613829912523, 1.9006945809442406, 0.9848916995232055, 1.9535179476699729, 2.936817177691594, 3.872907781627586, 4.8489917708146955, 5.862754141674271, 6.803899101114093, 7.810785599311165, 8.78755927764215, 9.758166929875474, 10.718022660120177, 11.679036620365096, 11.68474714122751, 10.688707447776402, 9.688454951432318, 8.744347257352391, 7.741631947232243, 3.0213877530725086, 1.9486743282116015, 0.9706504027947274, 0.0, 1.037784187922058, 2.0501152155665006, 3.077730680530153, 4.047975801585781, 5.034966741724051, 6.0280185607871175, 6.98314712665472, 7.918637978693228, 8.852657601090652, 9.829888462149968, 10.858086060245165, 10.665066225105122, 9.711615342766219, 8.742319689555066, 7.785655889855948, 6.751837426112415, 3.899665287942176, 2.950482043891629, 1.9362348983118456, 0.9550818157537635, 2.003764912707294, 2.989179345223679, 4.038741493886998, 5.0524528935283595, 6.0182635961085955, 6.960329299648646, 7.91634874281937, 8.942837422688006, 9.855623480742377, 10.831745957172062, 10.826756346879911, 9.838576249984976, 8.7883230042228, 7.835389182990914, 6.8264806652795915, 5.841298907353655, 4.843802286302225, 3.963052913550512, 2.998309036172861, 1.927754721967057, 2.9390554585922746, 3.8731914077702108, 4.844075449098539, 5.811941202172498, 6.808449977545236, 7.861270842226302, 8.915513623652096, 9.863989675400644, 10.849181837076395, 10.81829395141243, 9.878921586220905, 8.884606000954589, 7.928056852985701, 6.97868702414637, 5.988793054355224, 4.947226674296016, 5.799853055482853, 4.913884022347561, 3.926025539330353, 2.9759175724764857, 3.9068032238045145, 4.800689860175449, 5.840100581074662, 6.785015759238913, 7.75082523153597, 8.772057506283948, 9.829654061695027, 10.795001844555726, 10.949137035328047, 9.876160317970182, 8.934534817035996, 7.89088665398458, 6.958972135728272, 5.986066933980339, 4.914441030758345, 3.987913452246975, 6.794009282948132, 5.840044219105698, 4.905036266197723, 3.9571600221007093, 4.899948007171535, 5.807738380059912, 6.7819326930263415, 7.741481287547081, 8.697872813531038, 9.658782094977214, 10.611328181980609, 11.54679831183622, 11.822410210702131, 10.798289786970582, 9.772549782366832, 8.823514057259628, 7.865495184020896, 6.923438681863446, 5.923881291103783, 4.9916836165121214, 7.846211277978491, 6.803777584753882, 5.857606995138023, 4.932586539583547, 5.923052535626882, 6.746175058192964, 7.7200835879225815, 8.731407590928415, 9.654986002707442, 10.63424684431141, 11.564097857528509, 12.508091255921514, 12.767143247370754, 11.698801248919176, 10.728599153601255, 9.78403147495717, 8.818368922758284, 7.908275368921015, 6.88460095075298, 5.946808178949118, 8.800037165196096, 7.858669585852904, 6.869708287471, 5.892377185669339, 6.888739804902323, 7.761883089156365, 8.689474168890529, 9.66283201105401, 10.592367480236806, 11.619728242645415, 12.507342871680583, 13.543404132902198, 13.626052028192966, 12.69885111513909, 11.704293419406596, 10.747787879134634, 9.800591650929737, 8.836329601312526, 7.854286356577947, 6.799433080539425, 9.79908186248908, 8.823091615546678, 7.814025066667266, 6.8199113748791715, 7.780150981425169, 8.809925381623271, 9.71595549974673, 10.646681717909628, 11.535926453212985, 12.48097574498593, 13.528614984514126, 14.568300533347351, 14.568003119952232, 13.60513754890032, 12.646040397313145, 11.784754315458517, 10.815163283865818, 9.795361051294288, 8.727837721997613, 7.695333695536842, 10.73361966361368, 9.719481240492746, 8.768513913932672, 7.8225599414195, 8.818686363726313, 9.741527237213749, 10.664771209784176, 11.623955441001392, 12.567720281122648, 13.458055890739727, 14.532128643725219, 15.576061606549093, 15.479547789633873, 14.592434257868204, 13.619831254690272, 12.630710227136477, 11.685499993223017, 10.628816656579806, 9.627629172038434, 8.56419069193863, 11.685253434783199, 10.744442051786603, 9.805156857573762, 8.877552035555006, 9.860247698059322, 10.680896838879285, 11.602779050390637, 12.571920913743448, 13.587704279711321, 14.480043292577331, 15.422814060645123, 15.492773684443902, 14.544499477656439, 13.680139393940003, 12.729058865650504, 11.75553756558172, 10.974099598932238, 11.540758987716092, 10.479800259631048, 9.493245270534842, 12.655205273324588, 11.793069962632917, 10.851037269867248, 9.900428134179052, 10.845235943918013, 11.67937823535027, 12.603849308050032, 13.573340557977923, 14.571165613525807, 15.406647645422886, 15.47100030835317, 14.544968581452842, 13.552067589879426, 12.6082518852114, 11.668466757349963, 10.752579666824785, 9.993255322839907, 10.924721548221397, 11.43499585709329, 10.557778407832746, 13.582890906958765, 12.762791229873411, 11.901659139046563, 10.919541532075222, 11.856147964567084, 12.62852281367294, 13.561521848739208, 14.5386006544025, 15.533571079790809, 15.53056484921386, 14.524300184941092, 13.542281203588697, 12.650903988957394, 11.648043254295551, 10.696244602287328, 9.756024229865128, 8.972284564805163, 9.873515498192745, 10.756202088552868, 11.619425271054434], [11.70667217074905, 10.781233357346016, 9.822282383720744, 8.867285834204443, 7.884591600072273, 8.793501532030962, 9.747784418638894, 10.763808804484766, 11.608438121419912, 12.560847203442417, 13.603910151214349, 14.543629156307762, 14.525864836536819, 13.51540327689482, 12.588131448089378, 12.133728869822725, 12.86388135124978, 13.793085524121151, 14.73860921289732, 15.516190590703989, 10.634986413396026, 9.838363023667707, 8.88479661630388, 7.894804645062159, 6.8614663006715775, 7.819672388460913, 8.753998006559224, 9.734683460097926, 10.679984682442152, 11.640550010221276, 12.572979591262403, 13.505797725075663, 14.558536403913667, 14.512594582892593, 13.63578698903082, 13.139832242495451, 13.900581162078133, 14.850743506221562, 15.627162853130976, 14.56043385976765, 9.62920462617938, 8.833289284180069, 7.8654160492328, 6.890557126917995, 5.891678045451287, 6.821654578481878, 7.7588594471210595, 8.719865789452598, 9.704092872520292, 10.645866503984688, 11.58023481343557, 12.567581229013784, 13.604704533460707, 14.583987211426813, 14.660870267946946, 14.07923083093063, 14.871854786720816, 15.642131693581936, 14.658198715343875, 13.661050372964967, 8.661185318584295, 7.770487939347066, 6.8554906613656, 5.87593830371104, 4.8301048911682765, 5.823278023383014, 6.759665864564737, 7.671481094418318, 8.709773781013705, 9.667954841144658, 10.614282488411147, 11.605434692138491, 12.654250844417597, 13.602231533086357, 14.58557279576717, 15.134254523993441, 15.414475899105396, 14.604277161108275, 13.696218085156653, 12.717557303334463, 7.729749636660188, 6.7594966145103985, 5.823801350236667, 4.928402874870811, 3.8692493614166765, 4.924227597278208, 5.792728756184583, 6.7222970149686985, 7.7329634923095565, 8.661141407061237, 9.684716659334336, 10.652631577853139, 11.638247514296086, 12.647074252782543, 13.534544926456256, 14.516270946890442, 14.476980175349892, 13.530114135094447, 12.703305813137003, 11.773292886561954, 6.872790045540015, 5.866077360809148, 4.88405305845658, 3.951530799138313, 2.9298431703496233, 3.9351506208899947, 4.839815347091571, 5.815687479844104, 6.782275302612548, 7.723362188428771, 8.685769103053344, 9.62066713669799, 10.689247696497905, 11.686847002706083, 12.607108058488603, 13.53277924490378, 13.594700243607981, 12.59427547507626, 11.74047077464058, 10.78592463806409, 5.917617764598203, 4.877983556680417, 3.888853312086349, 2.974500960446133, 1.9851036397725461, 2.9903214571711594, 3.8835468861552336, 4.850405487021017, 5.84544373710148, 6.796979183994328, 7.829213596527572, 8.735006207532846, 9.746483478056183, 10.691564908657712, 11.613238745237753, 12.578453288339801, 12.689405686791813, 11.669256670196576, 10.751479347844477, 9.797486019842905, 4.955548313771707, 3.92134557091331, 2.9384787688662986, 2.0029578957190592, 1.034331647572292, 1.9449298923921112, 2.881020496328103, 3.857104485515213, 4.870866856374788, 5.812011815814611, 6.818898314011683, 7.795671992342667, 8.766279644575992, 9.726135374820695, 10.687149335065614, 11.738265588959575, 11.726491635698462, 10.726239139354378, 9.782131445274452, 8.779416135154301, 4.059171940994567, 2.986458516133659, 2.008434590716785, 1.037784187922058, 0.0, 1.0123310276444424, 2.0399464926080952, 3.0101916136637232, 3.997182553801993, 4.99023437286506, 5.9453629387326625, 6.88085379077117, 7.814873413168594, 8.79210427422791, 9.820301872323107, 10.779513699549975, 10.74939953068828, 9.780103877477126, 8.823440077778008, 7.789621614034473, 4.937449475864234, 3.988266231813687, 2.9740190862339033, 1.9928660036758215, 1.0169001598799439, 2.002314592396329, 3.0120535280460405, 4.014668705606302, 4.980479408186538, 5.922545111726588, 6.878564554897312, 7.9050532347659495, 8.81783929282032, 9.793961769250005, 10.787397629336372, 10.876360437907035, 9.826107192144859, 8.873173370912973, 7.86426485320165, 6.879083095275714, 5.881586474224283, 5.00083710147257, 4.036093224094919, 2.9655389098891147, 1.9521907057649242, 2.8863266549428603, 3.8572106962711885, 4.825076449345148, 5.821585224717886, 6.874406089398951, 7.901470315068098, 8.849946366816646, 9.833602794920155, 10.78006007997552, 10.916705774142963, 9.922390188876648, 8.965841040907762, 8.01647121206843, 7.026577242277282, 5.985010862218075, 6.837637243404911, 5.951668210269618, 4.963809727252411, 3.92494503071518, 2.919938470977164, 3.813825107348099, 4.853235828247311, 5.798151006411564, 6.76396047870862, 7.785192753456599, 8.842789308867678, 9.808137091728376, 10.783272059009958, 10.91394450589224, 9.972319004958054, 8.928670841906639, 7.996756323650331, 7.023851121902398, 5.952225218680404, 5.025697640169033, 7.83179347087019, 6.8778284070277556, 5.854063724436417, 4.906187480339403, 3.9130832543441842, 4.820873627232562, 5.795067940198991, 6.75461653471973, 7.711008060703688, 8.671917342149865, 9.62446342915326, 10.55993355900887, 11.504200696422979, 11.836073974892637, 10.810333970288887, 9.861298245181683, 8.903279371942952, 7.9612228697855025, 6.961665479025839, 6.029467804434178, 8.814040890526645, 7.752805042992575, 6.8066344533767165, 5.881613997822241, 4.936187782799531, 5.759310305365614, 6.733218835095231, 7.744542838101065, 8.668121249880091, 9.64738209148406, 10.57723310470116, 11.521226503094164, 12.495229223165472, 12.73658543684123, 11.766383341523309, 10.821815662879224, 9.856153110680339, 8.946059556843071, 7.922385138675037, 6.984592366871175, 9.76786677774425, 8.807697044091597, 7.818735745709693, 6.8414046439080325, 5.937968588784982, 6.775018336329015, 7.702609416063178, 8.67596725822666, 9.605502727409455, 10.632863489818064, 11.520478118853234, 12.556539380074849, 13.535894213563873, 13.736635303061144, 12.742077607328651, 11.78557206705669, 10.838375838851793, 9.874113789234581, 8.892070544500003, 7.837217268461482, 10.748109320727773, 9.77211907378537, 8.763052524905959, 7.768938833117865, 6.977614263893262, 7.8282849541805115, 8.729090746919379, 9.659816965082278, 10.549061700385634, 11.494110992158578, 12.541750231686775, 13.58143578052, 14.47784530532314, 14.642921736822375, 13.6838245852352, 12.82253850338057, 11.852947471787871, 10.833145239216345, 9.76562190991967, 8.733117883458899, 11.682647121852375, 10.66850869873144, 9.717541372171366, 8.771587399658193, 8.016149646194405, 8.75988680977099, 9.677906456956824, 10.637090688174041, 11.580855528295297, 12.471191137912376, 13.545263890897868, 14.589196853721742, 14.560361489536195, 13.826500138637636, 12.877911813244255, 11.827359308756247, 12.723284181145075, 11.666600844501865, 10.665413359960493, 9.60197487986069, 12.634280893021893, 11.693469510025297, 10.754184315812456, 9.8265794937937, 9.067246418552543, 9.699256411436526, 10.615914297563286, 11.585056160916096, 12.60083952688397, 13.49317853974998, 14.435949307817772, 14.573587384346224, 13.62531317755876, 12.760953093842325, 11.809872565552826, 10.83635126548404, 11.823932113395733, 12.578543175638151, 11.517584447553107, 10.531029458456901, 13.604232731563282, 12.74209742087161, 11.800064728105943, 10.849455592417746, 10.127864402799174, 10.697737807907512, 11.61698455522268, 12.586475805150572, 13.584300860698455, 14.419782892595535, 14.519951485734866, 13.593919758834538, 12.632881289781748, 11.689065585113722, 10.749280457252285, 9.833393366727105, 10.843087837303402, 11.81289049318197, 12.472780045015348, 11.595562595754805, 14.531918365197459, 13.711818688112105, 12.850686597285257, 11.868568990313916, 11.175964058505404, 11.646882386230182, 12.574657095911856, 13.55173590157515, 14.546706326963458, 14.579516026595556, 13.573251362322788, 12.591232380970393, 11.730673525630356, 10.728856954197873, 9.77705830218965, 8.836837929767448, 9.850454793229977, 10.761684443153317, 11.712876778304523, 12.657209458976492], [12.611609998939871, 11.665568708315048, 10.70384883091774, 9.74885228140144, 8.76615804726927, 7.93994055798764, 8.784132997441464, 9.751477776840323, 10.596107093775469, 11.548516175797975, 12.591579123569906, 13.53129812866332, 13.68819146742151, 12.67772990777951, 11.750458078974066, 12.759781074007428, 13.81156740733779, 14.740771580209161, 15.740124011993148, 16.52852161834843, 11.539924241586847, 10.722698374636739, 9.766363063500878, 8.776371092259156, 7.7430327478685745, 6.9661114144175915, 7.7416669789147825, 8.722352432453484, 9.667653654797709, 10.628218982576833, 11.56064856361796, 12.49346669743122, 13.546205376269224, 13.674921213777283, 12.798113619915508, 13.765884446680154, 14.830276949301423, 15.796355789772111, 16.63949388077542, 15.572764887412093, 10.534142454370201, 9.73822711237089, 8.77035387742362, 7.7721235741149926, 6.773244492648284, 5.968093604438557, 6.7465284194766175, 7.707534761808155, 8.691761844875849, 9.633535476340247, 10.567903785791128, 11.55525020136934, 12.592373505816262, 13.57165618378237, 13.823196898831634, 14.705283035115333, 15.75269739194267, 16.65446272122638, 15.670529742988318, 14.67338140060941, 9.566123146775116, 8.675425767537886, 7.76042848955642, 6.757504750908038, 5.7116713383652735, 4.9697170493396925, 5.747334836920295, 6.659150066773876, 7.697442753369264, 8.655623813500217, 9.601951460766704, 10.593103664494047, 11.641919816773152, 12.589900505441914, 13.573241768122728, 14.460573619332573, 15.391258998879177, 15.616608188752718, 14.708549112801096, 13.729888330978905, 8.634687464851009, 7.664434442701219, 6.728739178427487, 5.809969322067809, 4.750815808613674, 3.92974206495603, 4.780397728540141, 5.7099659873242565, 6.7206324646651145, 7.648810379416793, 8.672385631689894, 9.640300550208694, 10.625916486651642, 11.6347432251381, 12.522213898811813, 13.503939919246, 14.557084793655099, 14.54244516273889, 13.715636840781446, 12.785623914206397, 7.781270915619304, 6.771015188999968, 5.7889908866474, 4.833097246335311, 3.811409617546621, 2.9406650885678167, 3.8274843194471293, 4.803356452199662, 5.769944274968106, 6.711031160784328, 7.6734380754089, 8.608336109053546, 9.67691666885346, 10.67451597506164, 11.59477703084416, 12.520448217259338, 13.524332725513446, 13.606606502720703, 12.752801802285022, 11.798255665708533, 6.826098634677492, 5.786464426759705, 4.7973341821656375, 3.8560674076431303, 2.8666700869695436, 1.9958359248489812, 2.8712158585107916, 3.8380744593765743, 4.833112709457037, 5.784648156349885, 6.81688256888313, 7.7226751798884035, 8.73415245041174, 9.67923388101327, 10.60090771759331, 11.566122260695359, 12.595762896345475, 12.68158769784102, 11.76381037548892, 10.809817047487348, 5.864029183850995, 4.829826440992599, 3.846959638945587, 2.884524342916057, 1.9158980947692896, 0.9325988647476688, 1.8686894686836606, 2.8447734578707706, 3.8585358287303464, 4.799680788170168, 5.80656728636724, 6.783340964698224, 7.753948616931549, 8.713804347176252, 9.674818307421171, 10.725934561315132, 11.697725659254617, 11.738570166998821, 10.794462472918894, 9.791747162798744, 5.07150296863901, 3.998789543778102, 3.020765618361228, 2.0501152155665006, 1.0123310276444424, 0.0, 1.0276154649636526, 1.9978605860192806, 2.9848515261575503, 3.977903345220617, 4.93303191108822, 5.868522763126728, 6.802542385524151, 7.779773246583467, 8.807970844678664, 9.767182671905532, 10.720633554244435, 10.792434905121569, 9.83577110542245, 8.801952641678916, 5.949780503508677, 5.00059725945813, 3.986350113878346, 3.005197031320264, 2.0292311875243865, 1.0474087221385333, 1.9997225004015977, 3.0023376779618594, 3.968148380542095, 4.9102140840821455, 5.866233527252869, 6.892722207121507, 7.805508265175877, 8.781630741605563, 9.775066601691929, 10.724126903272875, 10.838438219789301, 9.885504398557416, 8.876595880846093, 7.891414122920157, 6.893917501868726, 6.0131681291170125, 5.048424251739362, 3.9778699375335576, 2.964521733409367, 2.0486532858275504, 3.019537327155879, 3.987403080229839, 4.9290032739450975, 5.8982812111442575, 6.889139287423655, 7.837615339172203, 8.821271767275713, 9.767729052331077, 10.707101417522603, 10.93472121652109, 9.978172068552205, 9.028802239712872, 8.038908269921725, 6.9973418898625175, 7.849968271049354, 6.963999237914061, 5.9761407548968535, 4.937276058359623, 3.932269498621607, 2.9761517382327893, 4.015562459132002, 4.960477637296254, 5.8938699584967535, 6.854739197354094, 7.835089359877517, 8.800437142738216, 9.775572110019798, 10.739616533993756, 10.984650032602497, 9.941001869551082, 9.009087351294774, 8.03618214954684, 6.964556246324847, 6.038028667813476, 8.844124498514633, 7.890159434672198, 6.8663947520808595, 5.918518507983846, 4.925414281988627, 3.983200258117252, 4.9573945710836815, 5.916943165604421, 6.873334691588378, 7.834243973034555, 8.78679006003795, 9.72226018989356, 10.66652732730767, 11.690647751039219, 11.718814840368179, 10.769779115260974, 9.811760242022244, 8.869703739864793, 7.870146349105129, 6.937948674513468, 9.826371918171088, 8.765136070637018, 7.818965481021159, 6.893945025466683, 5.916857815399192, 4.921636936250304, 5.895545465979922, 6.9068694689857555, 7.830447880764782, 8.80970872236875, 9.73955973558585, 10.683553133978855, 11.657555854050162, 12.71975583429532, 12.6748642116026, 11.730296532958516, 10.76463398075963, 9.854540426922362, 8.830866008754327, 7.893073236950464, 10.780197805388692, 9.82002807173604, 8.831066773354136, 7.853735671552475, 6.903200091371486, 5.937344967213705, 6.864936046947869, 7.83829388911135, 8.767829358294145, 9.795190120702753, 10.682804749737924, 11.71886601095954, 12.698220844448564, 13.625421757502439, 13.650558477407943, 12.69405293713598, 11.746856708931084, 10.782594659313872, 9.800551414579294, 8.74569813854077, 11.760440348372216, 10.784450101429814, 9.775383552550402, 8.781269860762308, 7.942845766479766, 6.990611585065202, 7.8914173778040695, 8.822143595966969, 9.711388331270324, 10.656437623043269, 11.704076862571466, 12.74376241140469, 13.64017193620783, 13.957238848165234, 12.99814169657806, 13.731019373459862, 12.761428341867163, 11.738083067407166, 10.67055973811049, 9.63805571164972, 12.694978149496817, 11.680839726375883, 10.72987239981581, 9.783918427302636, 8.90689028450553, 7.92221344065568, 8.840233087841515, 9.799417319058731, 10.743182159179987, 11.633517768797066, 12.707590521782556, 13.75152348460643, 13.693224981826678, 12.972939164594314, 12.024350839200933, 12.708925755953244, 13.628222009335897, 12.571538672692686, 11.570351188151314, 10.50691270805151, 13.646611920666336, 12.694984309121125, 11.755699114908284, 10.828094292889528, 9.845398630385212, 8.861583042321216, 9.778240928447977, 10.747382791800785, 11.763166157768659, 12.65550517063467, 13.598275938702463, 13.60023841763565, 12.758176669849243, 11.907392119799002, 10.956311591509504, 11.717917712681038, 12.70549856059273, 13.483481003828972, 12.422522275743928, 11.435967286647722, 14.616563759207725, 13.743612219967439, 12.801433560059001, 11.850824424370805, 10.906016614631843, 9.860064438792202, 10.779311186107371, 11.748802436035263, 12.746627491583146, 13.582109523480225, 13.507620458090424, 12.581588731190095, 11.76574478207223, 10.8355046110704, 9.895719483208962, 10.714959813924102, 11.7246542845004, 12.694456940378966, 13.37771787320617, 12.500500423945626, 15.544249392841902, 14.713333487207933, 13.802227456183395, 12.820109849212054, 11.883503416720192, 10.809209017114872, 11.736983726796547, 12.71406253245984, 13.709032957848148, 13.567184998951113, 12.560920334678345, 11.57890135332595, 10.718342497985914, 9.838206661299706, 8.923497328146327, 9.718404376964445, 10.732021240426974, 11.643250890350314, 12.59444322550152, 13.562147287167313], [13.626239836810583, 12.680198546185762, 11.718478668788455, 10.763482119272155, 9.780787885139983, 8.816898088506647, 7.926581627440192, 8.893926406839052, 9.738555723774198, 10.690964805796703, 11.734027753568634, 12.649118985508853, 12.763224791288248, 11.752763231646249, 12.696119452296482, 13.705442447329844, 14.757228780660206, 15.686432953531577, 16.69758166550704, 17.5050288253271, 12.55455407945756, 11.737328212507453, 10.780992901371592, 9.79100093012987, 8.757662585739288, 7.843068944936599, 6.884115608913511, 7.864801062452212, 8.810102284796438, 9.749652615500466, 10.682082196541593, 11.611287554276753, 12.664026233114758, 12.749954537644022, 13.743774993237924, 14.71154582000257, 15.775938322623839, 16.742017163094527, 17.61600108775409, 16.549272094390762, 11.548772292240914, 10.752856950241604, 9.784983715294334, 8.786753411985705, 7.787874330518997, 6.845051134957564, 5.888977049475346, 6.849983391806884, 7.834210474874578, 8.731846390555624, 9.666214700006506, 10.645879939633653, 11.664186788315812, 12.554199781499467, 13.547317134768535, 14.49814091011248, 15.311073691472645, 16.298674380534347, 16.647036949966985, 15.649888607588077, 10.580752984645828, 9.6900556054086, 8.775058327427134, 7.7721345887787505, 6.726301176235986, 5.8466745798587, 4.889783466919024, 5.801598696772604, 6.839891383367993, 7.7539347277155946, 8.692581199031016, 9.68373340275836, 10.684922529576985, 11.57244410315901, 12.555785365839824, 13.44311721704967, 14.373802596596274, 15.365290661240886, 15.685056319779763, 14.706395537957572, 9.649317302721721, 8.679064280571932, 7.7433690162982, 6.824599159938521, 5.765445646484387, 4.872658580121269, 3.9228463585388695, 4.852414617322985, 5.863081094663843, 6.739440117681106, 7.763015369954206, 8.730930288473008, 9.612302409968114, 10.617286822855196, 11.50475749652891, 12.486483516963096, 13.539628391372196, 14.43342026588931, 14.693407410919532, 13.762663091465667, 8.795900753490017, 7.7856450268706805, 6.803620724518113, 5.847727084206023, 4.826039455417334, 3.883581603733055, 2.969932949445858, 3.9458050821983903, 4.9123929049668345, 5.801660899048641, 6.764067813673213, 7.69896584731786, 8.663302592169932, 9.657059572778735, 10.577320628561255, 11.502991814976433, 12.506876323230543, 13.497581605871124, 13.749422707497965, 12.784296836390476, 7.8407284725482045, 6.801094264630418, 5.81196402003635, 4.870697245513843, 3.881299924840256, 2.9387524400142193, 2.0136644885095203, 2.980523089375303, 3.975561339455766, 4.8752778946141975, 5.907512307147442, 6.793126613498673, 7.716696048128834, 8.661777478730365, 9.583451315310406, 10.548665858412454, 11.57830649406257, 12.57256280099144, 12.760431280701862, 11.806437952700291, 6.878659021721708, 5.844456278863311, 4.8615894768163, 3.89915418078677, 2.930527932640002, 1.9472287026183812, 1.0111380986823892, 1.9872220878694993, 3.000984458729075, 3.8903105264344804, 4.884518137306815, 5.853792398308494, 6.736492214648644, 7.696347944893348, 8.657361905138266, 9.708478159032227, 10.670110194290965, 11.629545270149242, 11.797120176139657, 10.788368068011687, 6.099118433602662, 5.026405008741754, 4.04838108332488, 3.077730680530153, 2.0399464926080952, 1.0276154649636526, 0.0, 0.970245121055628, 1.957236061193898, 2.9502878802569645, 3.9054164461245673, 4.840907298163075, 5.774926920560499, 6.752157781619815, 7.780355379715012, 8.73956720694188, 9.693018089280782, 10.662313742491936, 10.863386570386103, 9.829568106642569, 6.9773959684723295, 6.028212724421783, 5.013965578841999, 4.032812496283917, 3.007083616617649, 2.021669184101264, 0.9721070354379451, 1.9747222129982067, 2.9405329155784425, 3.882598619118493, 4.838618062289217, 5.865106742157854, 6.777892800212225, 7.754015276641911, 8.747451136728277, 9.696511438309223, 10.7467646840714, 10.913119863521068, 9.904211345809745, 8.91902958788381, 7.921532966832379, 7.040783594080666, 6.041227541107839, 4.970673226902035, 3.9415609106686356, 3.0074249614907, 2.0365409201623716, 3.0044066732363315, 3.9013878089814447, 4.870665746180605, 5.861523822460002, 6.80999987420855, 7.79365630231206, 8.740113587367425, 9.67948595255895, 10.673259764175967, 11.005787533515857, 10.056417704676525, 9.066523734885378, 8.02495735482617, 8.877583736013007, 7.956802527282538, 6.9689440442653305, 5.914315235618892, 4.909308675880876, 3.9349234138959384, 3.0325660521384945, 3.9774812303027467, 4.866254493533101, 5.827123732390442, 6.807473894913865, 7.772821677774564, 8.747956645056146, 9.712001069030103, 10.65362656996429, 10.968617334514734, 10.036702816258426, 9.063797614510493, 7.992171711288499, 7.065644132777129, 9.840745403727576, 8.870430537363918, 7.843433929340129, 6.895557685243116, 5.886168819828171, 4.941971933780401, 4.032427894950421, 4.99197648947116, 5.923421353995915, 6.861742509127046, 7.798032248505678, 8.708900574877543, 9.653167712291651, 10.67659347927161, 11.580364391944906, 11.784408953131686, 10.826390079892956, 9.884333577735505, 8.884776186975841, 7.95257851238418, 10.803411095430357, 9.742175247896288, 8.79600465828043, 7.87045223244535, 6.875629491062341, 5.880408611913453, 4.970578789846661, 5.981902792852495, 6.880534543172319, 7.837207258461241, 8.76705827167834, 9.670193518962837, 10.644196239034144, 11.705701562527711, 12.646441992805798, 12.74492637082923, 11.779263818630344, 10.869170264793073, 9.845495846625038, 8.907703074821177, 11.757236982647962, 10.79706724899531, 9.808105950613406, 8.830242878531141, 7.860657744885381, 6.894802620727599, 5.939969370814608, 6.913327212978089, 7.817916020701682, 8.84527678311029, 9.710303285830415, 10.708580704157924, 11.684861229432546, 12.61206214248642, 13.657758005523828, 13.708682775006695, 12.761486546801795, 11.797224497184583, 10.815181252450005, 9.760327976411483, 12.737479525631485, 11.761489278689083, 10.752422729809672, 9.757777067740975, 8.90030341999366, 7.948069238579096, 6.966450701670809, 7.897176919833709, 8.761474993677862, 9.706524285450806, 10.754163524979003, 11.735990437622702, 12.626812321191812, 13.179672674081601, 13.875099227097067, 14.745649211330576, 13.776058179737873, 12.75271290527788, 11.685189575981205, 10.652685549520434, 13.671485356475484, 12.65734693335455, 11.706379606794476, 10.760425634281303, 9.864347938019424, 8.879671094169574, 7.915266411708254, 8.87445064292547, 9.793268821587525, 10.683604431204603, 11.757677184190094, 12.790236675995203, 12.835673611825406, 12.125062583656192, 12.90130836971994, 13.723555593823956, 14.64285184720661, 13.586168510563398, 12.584981026022026, 11.521542545922223, 14.623119127645003, 13.652441962635018, 12.713156768422177, 11.785551946403421, 10.802856283899105, 9.81904069583511, 8.853274252314716, 9.822416115667526, 10.82651062872735, 11.705591833042208, 12.64836260111, 12.742687047634378, 11.900625299847972, 11.05951553886088, 11.833269122028511, 12.73254755055175, 13.720128398463443, 14.498110841699685, 13.43715211361464, 12.450597124518435, 15.593070966186392, 14.701069873481332, 13.758891213572895, 12.808282077884698, 11.863474268145737, 10.817522092306096, 9.85434450997411, 10.823835759902002, 11.821660815449885, 12.632196185887762, 12.650069088089152, 11.724037361188824, 10.90819341207096, 9.987628030132278, 10.77267701372797, 11.729589651794814, 12.739284122371112, 13.70908677824968, 14.392347711076882, 13.515130261816338, 16.52075659982057, 15.670791140721827, 14.75968510969729, 13.77756750272595, 12.840961070234087, 11.766666670628766, 10.812017050663286, 11.789095856326579, 12.784066281714887, 12.709633628949842, 11.703368964677074, 10.721349983324679, 9.860791127984642, 8.980655291298435, 9.800454858665335, 10.733034214835158, 11.746651078297687, 12.657880728221029, 13.609073063372234, 14.576777125038026], [14.59648495786621, 13.65044366724139, 12.688723789844083, 11.733727240327783, 10.75103300619561, 9.787143209562275, 8.89682674849582, 8.155694247988475, 9.00032356492362, 9.818458346543618, 10.781196004838744, 11.678873864453227, 12.131900969311483, 12.723008352701877, 13.66636457335211, 14.675687568385472, 15.727473901715834, 16.656678074587205, 17.667826786562667, 18.47527394638273, 13.524799200513186, 12.707573333563081, 11.75123802242722, 10.761246051185498, 9.727907706794916, 8.813314065992227, 7.854360729969139, 7.126568903601635, 8.07187012594586, 8.77940749444484, 9.711837075485967, 10.641042433221127, 11.693781112059131, 12.568916131504265, 13.602155292629032, 14.467294377492033, 15.312102195059701, 16.27818103553039, 17.301915495584286, 17.519517215446392, 12.51901741329654, 11.72310207129723, 10.75522883634996, 9.756998533041333, 8.758119451574625, 7.815296256013192, 6.859222170530974, 6.111751232956307, 7.095978316024, 7.761601269499996, 8.695969578950876, 9.675634818578027, 10.693941667260182, 11.583954660443837, 12.577072013712906, 13.527895789056855, 14.340828570417019, 15.328429259478721, 16.28790987929823, 16.620133728643705, 11.550998105701455, 10.660300726464227, 9.745303448482762, 8.742379709834378, 7.696546297291614, 6.816919700914328, 5.860028587974652, 5.063366537922027, 6.050010616329504, 6.783689606659967, 7.722336077975388, 8.713488281702734, 9.714677408521355, 10.60219898210338, 11.585540244784198, 12.472872095994044, 13.403557475540648, 14.39504554018526, 15.322417698075846, 15.6766406590132, 10.619562423777348, 9.649309401627558, 8.713614137353828, 7.794844280994149, 6.735690767540015, 5.842903701176897, 4.8930914795944975, 4.114182458472408, 5.040647920787194, 5.769194996625478, 6.792770248898578, 7.760685167417381, 8.642057288912484, 9.647041701799566, 10.534512375473284, 11.51623839590747, 12.56938327031657, 13.463175144833684, 14.433610232131663, 14.732908212521295, 9.766145874545643, 8.755890147926308, 7.773865845573741, 6.817972205261651, 5.796284576472962, 4.853826724788683, 3.940178070501486, 3.0831591741258446, 3.9994850437834604, 4.831415777993013, 5.793822692617585, 6.728720726262232, 7.693057471114304, 8.686814451723105, 9.607075507505629, 10.532746693920807, 11.536631202174917, 12.527336484815498, 13.47077519363524, 13.754541957446104, 8.810973593603832, 7.771339385686046, 6.782209141091978, 5.840942366569471, 4.851545045895884, 3.9089975610698473, 2.9839096095651483, 2.084594421937919, 3.054933927196502, 3.9050327735585695, 4.937267186091814, 5.822881492443045, 6.746450927073206, 7.691532357674736, 8.61320619425478, 9.578420737356828, 10.608061373006944, 11.602317679935814, 12.554663130565588, 12.776683073755919, 7.848904142777336, 6.814701399918939, 5.831834597871928, 4.869399301842398, 3.90077305369563, 2.917473823674009, 1.9813832197380172, 1.0506405602197457, 2.0494273234362215, 2.9200654053788524, 3.9142730162511863, 4.883547277252866, 5.766247093593016, 6.72610282383772, 7.687116784082639, 8.738233037976599, 9.699865073235337, 10.659300149093616, 11.603407843173542, 11.758613189067315, 7.06936355465829, 5.996650129797382, 5.018626204380508, 4.047975801585781, 3.0101916136637232, 1.9978605860192806, 0.970245121055628, 0.0, 0.9869909401382699, 1.9800427592013365, 2.9351713250689393, 3.870662177107447, 4.804681799504871, 5.781912660564187, 6.810110258659384, 7.769322085886252, 8.722772968225154, 9.69206862143631, 10.648732421135428, 10.799813227698197, 7.9476410895279574, 6.998457845477411, 5.984210699897627, 5.003057617339545, 3.977328737673277, 2.991914305156892, 1.942352156493573, 1.0044770919425787, 1.9702877945228148, 2.9123534980628656, 3.8683729412335888, 4.894861621102226, 5.807647679156597, 6.783770155586283, 7.7772060156726495, 8.726266317253593, 9.77651956301577, 10.658948858191271, 10.874456466865373, 9.889274708939437, 8.891778087888007, 8.011028715136293, 7.011472662163467, 5.940918347957663, 4.9118060317242636, 3.977670082546328, 3.0067860412179996, 2.0485917713417354, 2.931142687925817, 3.900420625124977, 4.891278701404374, 5.839754753152922, 6.823411181256432, 7.769868466311797, 8.709240831503323, 9.703014643120337, 10.725664726134921, 11.026662825732153, 10.036768855941006, 8.995202475881799, 9.847828857068635, 8.927047648338167, 7.9391891653209585, 6.88456035667452, 5.879553796936504, 4.905168534951566, 4.0028111731941225, 3.0216663284081506, 3.896009372477473, 4.856878611334814, 5.837228773858237, 6.802576556718936, 7.777711524000518, 8.741755947974475, 9.683381448908662, 10.696733990090346, 11.006947937314054, 10.034042735566121, 8.962416832344127, 8.035889253832757, 10.810990524783204, 9.840675658419546, 8.813679050395757, 7.865802806298744, 6.856413940883799, 5.912217054836029, 5.002673016006049, 4.0906531103237596, 4.953176232940287, 5.891497388071418, 6.82778712745005, 7.738655453821915, 8.682922591236023, 9.706348358215982, 10.610119270889278, 11.559154995996483, 11.796635200948584, 10.854578698791133, 9.85502130803147, 8.922823633439808, 11.773656216485985, 10.712420368951916, 9.766249779336057, 8.840697353500978, 7.845874612117969, 6.850653732969081, 5.940823910902289, 5.133537535288204, 5.910289422116691, 6.866962137405613, 7.796813150622713, 8.699948397907209, 9.673951117978516, 10.735456441472083, 11.67619687175017, 12.562885766453876, 12.74950893968597, 11.839415385848703, 10.815740967680668, 9.877948195876803, 12.72748210370359, 11.767312370050938, 10.778351071669034, 9.80048799958677, 8.83090286594101, 7.865047741783227, 6.910214491870236, 6.072636371157383, 6.847670899646054, 7.875031662054662, 8.740058164774787, 9.738335583102295, 10.714616108376918, 11.641817021430793, 12.687512884468202, 13.526642170631341, 13.731731667857424, 12.767469618240213, 11.785426373505635, 10.73057309746711, 13.707724646687113, 12.731734399744711, 11.7226678508653, 10.728022188796603, 9.870548541049288, 8.918314359634724, 7.936695822726437, 7.056486078013003, 7.7912298726222335, 8.736279164395178, 9.783918403923375, 10.765745316567072, 11.656567200136184, 12.688277648406405, 13.62925986237475, 14.563608606955224, 14.746303300793503, 13.722958026333506, 12.655434697036831, 11.62293067057606, 14.641730477531112, 13.627592054410178, 12.676624727850104, 11.73067075533693, 10.834593059075052, 9.849916215225202, 8.885511532763882, 8.115067771515449, 8.823023700531897, 9.713359310148975, 10.787432063134467, 11.819991554939573, 12.097441452974829, 13.029035561231717, 13.871553490775568, 14.693800714879584, 15.613096968262235, 14.556413631619025, 13.555226147077652, 12.49178766697785, 15.593364248700631, 14.622687083690646, 13.683401889477805, 12.75579706745905, 11.773101404954733, 10.789285816890738, 9.823519373370344, 9.09826665660804, 9.856265507671722, 10.73534671198658, 11.678117480054372, 12.0044548887838, 11.162393140997395, 12.029760659916509, 12.80351424308414, 13.702792671607378, 14.69037351951907, 15.46835596275531, 14.407397234670267, 13.420842245574061, 16.563316087242022, 15.67131499453696, 14.729136334628523, 13.778527198940326, 12.833719389201365, 11.787767213361724, 10.824589631029738, 10.168034574879638, 10.854123151021467, 11.661951064832135, 11.878587617857407, 10.985805202338245, 10.169961253220382, 10.957873151187906, 11.742922134783598, 12.699834772850442, 13.70952924342674, 14.679331899305309, 15.362592832132508, 14.485375382871965, 17.4910017208762, 16.641036261777455, 15.729930230752917, 14.747812623781575, 13.811206191289713, 12.736911791684394, 11.782262171718914, 11.133294671304215, 11.867378441791606, 11.820455925742252, 10.830862505423989, 9.983117824474101, 9.122558969134065, 9.950900412354063, 10.770699979720963, 11.703279335890786, 12.716896199353315, 13.628125849276657, 14.579318184427862, 15.547022246093652], [15.583475898004483, 14.63743460737966, 13.675714729982353, 12.720718180466053, 11.73802394633388, 10.774134149700545, 9.88381768863409, 9.033942494563957, 8.024907266063227, 8.831467406405347, 9.794205064700472, 10.691882924314957, 11.621862609536002, 12.579116497363769, 13.522472718014003, 14.486406810026486, 15.36181106574978, 16.291015238621153, 17.30948361040956, 18.26742355586767, 14.51179014065146, 13.694564273701351, 12.73822896256549, 11.748236991323768, 10.714898646933186, 9.800305006130497, 8.841351670107409, 8.022491655889425, 7.096453827085466, 7.792416554306569, 8.724846135347695, 9.654051493082857, 10.706790171920861, 11.581925191365995, 12.615164352490762, 13.48030343735376, 14.325111254921428, 15.291190095392116, 16.31492455544601, 17.246303695855794, 13.506008353434813, 12.710093011435504, 11.742219776488234, 10.743989473179603, 9.745110391712895, 8.802287196151463, 7.846213110669244, 7.007673985244097, 6.114545204376912, 6.774610329361726, 7.708978638812607, 8.688643878439757, 9.706950727121912, 10.596963720305567, 11.590081073574636, 12.540904848918581, 13.353837630278745, 14.341438319340448, 15.300918939159956, 16.298067281538867, 12.537989045839728, 11.6472916666025, 10.732294388621034, 9.729370649972648, 8.683537237429885, 7.803910641052598, 6.847019528112922, 5.959289290209817, 5.063019676191234, 5.796698666521697, 6.735345137837118, 7.726497341564463, 8.727686468383085, 9.61520804196511, 10.598549304645925, 11.48588115585577, 12.416566535402374, 13.408054600046986, 14.335426757937572, 15.314087539759763, 11.606553363915621, 10.636300341765832, 9.7006050774921, 8.781835221132418, 7.7226817076782845, 6.829894641315166, 5.8800824197327675, 5.010105210760198, 4.053656980648924, 4.782204056487208, 5.805779308760308, 6.773694227279111, 7.655066348774215, 8.660050761661296, 9.54752143533501, 10.529247455769196, 11.582392330178296, 12.476184204695414, 13.446619291993393, 14.377363611447258, 10.753136814683913, 9.742881088064578, 8.760856785712011, 7.804963145399921, 6.783275516611232, 5.840817664926952, 4.927169010639756, 3.9790819264136346, 3.0124941036451904, 3.8444248378547425, 4.806831752479315, 5.741729786123962, 6.706066530976034, 7.699823511584836, 8.620084567367357, 9.545755753782535, 10.549640262036643, 11.540345544677228, 12.48378425349697, 13.510104136650074, 9.797964533742102, 8.758330325824316, 7.769200081230248, 6.827933306707741, 5.838535986034154, 4.895988501208117, 3.970900549703418, 3.062981237138695, 2.067942987058232, 2.9180418334202995, 3.9502762459535443, 4.835890552304775, 5.759459986934936, 6.704541417536466, 7.6262152541165085, 8.591429797218556, 9.621070432868672, 10.615326739797544, 11.567672190427318, 12.52166551842889, 8.835895082915606, 7.801692340057209, 6.818825538010198, 5.856390241980668, 4.8877639938339, 3.904464763812279, 2.968374159876287, 2.0376315003580157, 1.0624363832979515, 1.9330744652405825, 2.9272820761129164, 3.896556337114596, 4.779256153454746, 5.73911188369945, 6.700125843944369, 7.751242097838329, 8.712874133097067, 9.672309208955346, 10.616416903035272, 11.625169011163242, 8.05635449479656, 6.983641069935652, 6.005617144518778, 5.034966741724051, 3.9971825538019927, 2.9848515261575503, 1.957236061193898, 0.9869909401382699, 0.0, 0.9930518190630666, 1.9481803849306694, 2.8836712369691773, 3.817690859366601, 4.794921720425917, 5.823119318521114, 6.782331145747982, 7.735782028086884, 8.70507768129804, 9.661741480997158, 10.695559944740692, 8.934632029666227, 7.985448785615681, 6.971201640035897, 5.990048557477815, 4.964319677811547, 3.978905245295162, 2.9293430966318432, 1.9914680320808487, 0.9832968543845448, 1.9253625579245957, 2.881382001095319, 3.9078706809639563, 4.820656739018327, 5.796779215448013, 6.7902150755343795, 7.739275377115324, 8.789528622877501, 9.671957918053002, 10.680866435764324, 10.876265649077707, 9.878769028026277, 8.945851400830495, 7.913212897179712, 6.842658582973908, 5.813546266740509, 4.879410317562574, 3.9085262762342454, 2.9406605231602856, 1.9441517477875472, 2.913429684986707, 3.904287761266104, 4.852763813014652, 5.836420241118162, 6.782877526173527, 7.722249891365053, 8.716023702982067, 9.738673785996653, 10.682884709212738, 11.023759796079275, 9.982193416020069, 10.794432860572593, 9.828787883354412, 8.840929400337204, 7.786300591690765, 6.781294031952749, 5.806908769967812, 4.889170521611795, 3.8748279046362604, 2.909018432339203, 3.869887671196544, 4.850237833719966, 5.815585616580665, 6.790720583862247, 7.754765007836205, 8.696390508770392, 9.709743049952076, 10.641657568208384, 11.021033675704391, 9.949407772482397, 9.022880193971027, 11.712730759799449, 10.74241589343579, 9.715419285412002, 8.767543041314989, 7.758154175900045, 6.813957289852275, 5.882125413306714, 4.922576818785974, 3.9661852928020163, 4.904506447933148, 5.8407961873117795, 6.751664513683644, 7.695931651097752, 8.719357418077712, 9.623128330751008, 10.572164055858213, 11.530182929096943, 11.841569638929403, 10.84201224816974, 9.909814573578078, 12.67539645150223, 11.61416060396816, 10.667990014352302, 9.742437588517225, 8.747614847134216, 7.752393967985327, 6.820276308202954, 5.915692129747192, 4.92329848197842, 5.879971197267343, 6.809822210484443, 7.712957457768938, 8.686960177840245, 9.748465501333813, 10.6892059316119, 11.575894826315606, 12.48305666783433, 12.826406325986973, 11.802731907818938, 10.864939136015073, 13.629222338719835, 12.669052605067183, 11.680091306685279, 10.702228234603016, 9.710355263241674, 8.744500139083893, 7.789666889170901, 6.854790965616371, 5.860679959507783, 6.888040721916391, 7.753067224636517, 8.751344642964025, 9.727625168238646, 10.654826081292521, 11.700521944329932, 12.539651230493071, 13.546856580246798, 13.754460558378483, 12.772417313643905, 11.71756403760538, 14.609464881703358, 13.633474634760956, 12.624408085881544, 11.62976242381285, 10.750000938349952, 9.79776675693539, 8.816148220027102, 7.797097669309595, 6.804238932483962, 7.749288224256906, 8.796927463785103, 9.778754376428802, 10.669576259997912, 11.701286708268134, 12.64226892223648, 13.576617666816954, 14.561428213182879, 14.70994896647178, 13.642425637175105, 12.609921610714334, 15.543470712547359, 14.529332289426424, 13.57836496286635, 12.632410990353177, 11.714045456375718, 10.729368612525867, 9.764963930064548, 8.808426651773715, 7.836032760393626, 8.726368370010704, 9.800441122996194, 10.833000614801303, 11.600930305989959, 12.532524414246847, 13.505127417424779, 14.570524934054609, 15.515735167968069, 15.543404571757298, 14.542217087215926, 13.478778607116123, 16.47572638158992, 15.502139480991312, 14.562854286778471, 13.635249464759715, 12.6525538022554, 11.668738214191404, 10.70297177067101, 9.791625536866306, 8.869274567533452, 9.748355771848308, 10.6911265399161, 11.029038589923408, 11.977312796710871, 12.962950071388734, 13.79050518322241, 14.689783611745648, 15.67736445965734, 16.455346902893584, 15.39438817480854, 14.407833185712335, 17.445678220131306, 16.550767391837624, 15.608588731929188, 14.657979596240992, 13.71317178650203, 12.66721961066239, 11.704042028330404, 10.861393455137904, 9.867132210883197, 10.674960124693863, 10.891596677719136, 10.010388903477853, 10.986025068827786, 11.929840773495812, 12.729913074921868, 13.686825712988712, 14.69652018356501, 15.666322839443579, 16.34958377227078, 15.472366323010238, 18.373363853765483, 17.52048865907812, 16.609382628053584, 15.627265021082243, 14.69065858859038, 13.61636418898506, 12.66171456901958, 11.826653551562481, 10.880387501653336, 10.83346498560398, 9.843871565285717, 9.007701525613708, 9.938622784741469, 10.937891352492333, 11.757690919859233, 12.690270276029056, 13.703887139491584, 14.615116789414927, 15.566309124566132, 16.534013186231928], [16.46441534421717, 15.48565945047334, 14.523939573076033, 13.568943023559733, 12.586248789427561, 11.583525062275866, 10.69320860120941, 9.697418730501118, 8.688383502000388, 7.838415587342281, 8.801153245637408, 9.69883110525189, 10.628810790472935, 11.586064678300703, 12.529420898950937, 13.49335499096342, 14.368759246686714, 15.297963419558085, 16.316431791346492, 17.2743717368046, 15.414429946439196, 14.542789116795031, 13.58645380565917, 12.596461834417449, 11.563123490026866, 10.609695918705818, 9.650742582682728, 8.705231285366853, 7.759930063022627, 6.799364735243503, 7.73179431628463, 8.66099967401979, 9.713738352857794, 10.58887337230293, 11.622112533427696, 12.487251618290694, 13.332059435858362, 14.29813827632905, 15.321872736382943, 16.253251876792724, 14.40864815922255, 13.61273281722324, 12.64485958227597, 11.646629278967339, 10.593335234806576, 9.611678108726784, 8.655604023244564, 7.763711084142882, 6.779484001075188, 5.781558510298661, 6.715926819749542, 7.69559205937669, 8.713898908058844, 9.603911901242501, 10.59702925451157, 11.547853029855515, 12.36078581121568, 13.348386500277382, 14.30786712009689, 15.305015462475799, 13.440628851627464, 12.549931472390236, 11.63493419440877, 10.632010455760385, 9.58617704321762, 8.613301553627918, 7.6564104406882425, 6.740895154258727, 5.761827907589582, 4.80364684745863, 5.742293318774052, 6.7334455225013965, 7.734634649320019, 8.622156222902044, 9.605497485582859, 10.492829336792704, 11.423514716339309, 12.41500278098392, 13.342374938874507, 14.321035720696697, 12.509193169703357, 11.538940147553568, 10.603244883279835, 9.684475026920156, 8.625321513466021, 7.707565151935611, 6.689473332308088, 5.791711074809108, 4.835262844697834, 3.7891522374241413, 4.812727489697242, 5.780642408216044, 6.662014529711149, 7.666998942598229, 8.554469616271945, 9.53619563670613, 10.58934051111523, 11.483132385632349, 12.453567472930327, 13.384311792384192, 11.655776620471649, 10.645520893852314, 9.663496591499747, 8.707602951187658, 7.685915322398968, 6.718488175547398, 5.736559923215077, 4.760687790462544, 3.7940999676940996, 2.8513730187916764, 3.8137799334162485, 4.748677967060895, 5.713014711912967, 6.7067716925217695, 7.627032748304291, 8.552703934719467, 9.556588442973577, 10.547293725614162, 11.490732434433903, 12.517052317587009, 10.700604339529837, 9.660970131612052, 8.671839887017983, 7.730573112495477, 6.74117579182189, 5.7736590118285624, 4.848571060323864, 3.8817124594580807, 2.8866742093776177, 1.9249900143572334, 2.9572244268904786, 3.842838733241708, 4.7664081678718695, 5.711489598473399, 6.633163435053442, 7.598377978155489, 8.628018613805605, 9.622274920734478, 10.574620371364253, 11.528613699365824, 9.738534888703342, 8.704332145844944, 7.7214653437979335, 6.7590300477684035, 5.790403799621636, 4.807104569600015, 3.871013965664023, 2.894929976476913, 1.8811676056173376, 0.940022646177516, 1.9342302570498497, 2.9035045180515295, 3.7862043343916794, 4.746060064636383, 5.707074024881303, 6.758190278775263, 7.719822314034001, 8.67925738989228, 9.623365083972207, 10.632117192100177, 9.049406313859626, 7.976692888998718, 6.998668963581844, 6.028018560787117, 4.990234372865059, 3.977903345220617, 2.9502878802569645, 1.9800427592013365, 0.9930518190630666, 0.0, 0.9551285658676029, 1.8906194179061107, 2.824639040303534, 3.8018699013628505, 4.830067499458048, 5.789279326684916, 6.742730209023819, 7.712025862234973, 8.66868966193409, 9.702508125677625, 9.927683848729293, 8.978500604678747, 7.964253459098963, 6.983100376540881, 5.957371496874614, 4.971957064358229, 3.92239491569491, 2.984519851143915, 1.9702714917339756, 1.0282057881939248, 1.8883301820322522, 2.9148188619008897, 3.82760491995526, 4.803727396384946, 5.797163256471312, 6.746223558052258, 7.796476803814436, 8.678906098989934, 9.687814616701257, 10.672996374627193, 10.871820847089342, 9.932826038179924, 8.900187534529142, 7.8296332203233385, 6.8005209040899395, 5.866384954912004, 4.895500913583676, 3.927635160509716, 2.9311263851369778, 2.0162729152560366, 2.9112359422030374, 3.859711993951586, 4.843368422055095, 5.7898257071104595, 6.729198072301985, 7.722971883919001, 8.745621966933587, 9.68983289014967, 10.679726859940818, 10.975245235083134, 10.654492496307187, 10.81576252070384, 9.827904037686633, 8.773275229040195, 7.768268669302179, 6.793883407317242, 5.876145158961225, 4.861802541985691, 3.895993069688634, 2.972730901465873, 3.8571860146568993, 4.822533797517599, 5.79766876479918, 6.761713188773138, 7.703338689707325, 8.71669123088901, 9.648605749145318, 10.621510950893251, 10.942459591545463, 10.015932013034092, 11.579739856384288, 11.72939053078522, 10.702393922761432, 9.754517678664419, 8.745128813249476, 7.800931927201705, 6.869100050656144, 5.909551456135405, 4.953159930151447, 4.007349678202477, 4.847744368248713, 5.758612694620577, 6.702879832034685, 7.726305599014645, 8.63007651168794, 9.579112236795146, 10.537131110033876, 11.479187612191327, 11.744652053957475, 10.812454379365814, 12.550678105259923, 12.601135241317591, 11.654964651701732, 10.729412225866655, 9.734589484483646, 8.739368605334757, 7.807250945552384, 6.902666767096623, 5.910273119327851, 4.982814427536672, 5.860434972069688, 6.719905638705871, 7.693908358777178, 8.755413682270747, 9.696154112548832, 10.582843007252539, 11.490004848771264, 12.464408284593324, 12.705371713606674, 11.767578941802809, 13.504503992477527, 13.656027242416613, 12.667065944034709, 11.689202871952446, 10.697329900591104, 9.731474776433323, 8.776641526520331, 7.841765602965802, 6.847654596857214, 6.057563891469734, 6.803679986221763, 7.758292823900958, 8.73457334917558, 9.661774262229455, 10.707470125266862, 11.546599411430003, 12.553804761183732, 13.488251371329543, 13.67505711943164, 12.620203843393115, 14.409495358218374, 14.620449272110386, 13.611382723230975, 12.61673706116228, 11.736975575699383, 10.78474139428482, 9.803122857376533, 8.784072306659027, 7.791213569833394, 7.128468209804198, 7.851372307894244, 8.785702557365735, 9.676524440934847, 10.708234889205068, 11.649217103173411, 12.583565847753885, 13.568376394119813, 14.558658234017484, 14.54506544296284, 13.51256141650207, 15.355945902178785, 15.516306926775854, 14.565339600215781, 13.619385627702608, 12.701020093725148, 11.716343249875298, 10.751938567413978, 9.795401289123145, 8.823007397743057, 8.105548355557996, 8.890607980225177, 9.839948795738236, 10.607878486926893, 11.539472595183781, 12.512075598361713, 13.577473114991543, 14.522683348905003, 15.486703018242448, 15.444856893003662, 14.381418412903859, 16.307579673348304, 16.48911411834074, 15.549828924127901, 14.622224102109145, 13.63952843960483, 12.655712851540834, 11.68994640802044, 10.778600174215736, 9.856249204882882, 9.1275357573956, 9.847305382880274, 10.826296343809382, 11.542926798904327, 12.52856407358219, 13.580114846053142, 14.568481158263749, 15.481099392055471, 16.489987433622087, 16.297027980596276, 15.31047299150007, 17.209453004997094, 17.537742029187054, 16.59556336927862, 15.644954233590422, 14.70014642385146, 13.65419424801182, 12.691016665679834, 11.848368092487334, 10.854106848232627, 10.054140110241155, 9.89854485865607, 10.673865139415014, 11.649501304764946, 12.593317009432972, 13.53310213729441, 14.53268760322471, 15.542382073801008, 16.51454768253726, 17.252223578058516, 16.375006128797974, 18.13713863863127, 17.343222316131705, 16.341059691710914, 15.364071607622579, 14.451119802280742, 13.470669960810131, 12.526810859283666, 11.627417088480202, 10.649814626308634, 9.840413166540916, 8.850819746222651, 9.671177761550869, 10.60209902067863, 11.628365184264524, 12.567081832434553, 13.538495119122736, 14.552111982585265, 15.463341632508607, 16.41453396765981, 17.436652992019663], [17.419543910084773, 16.440788016340942, 15.479068138943635, 14.524071589427335, 13.541377355295163, 12.538653628143468, 11.648337167077012, 10.652547296368718, 9.643512067867988, 8.793544153209883, 8.158901349441779, 8.896438709322911, 9.782388052685885, 10.630936112433098, 11.574292333083331, 12.538226425095816, 13.41363068081911, 14.342834853690482, 15.36130322547889, 16.319243170936996, 16.3695585123068, 15.497917682662633, 14.541582371526772, 13.55159040028505, 12.518252055894468, 11.56482448457342, 10.60587114855033, 9.660359851234453, 8.715058628890228, 7.754493301111105, 7.089542420089002, 7.858607278090813, 8.788030987084264, 9.633744806435324, 10.66698396756009, 11.53212305242309, 12.376930869990758, 13.343009710461446, 14.36674417051534, 15.29812331092512, 15.363776725090153, 14.567861383090843, 13.599988148143574, 12.601757844834943, 11.548463800674178, 10.566806674594385, 9.610732589112166, 8.718839650010484, 7.73461256694279, 6.7366870761662625, 6.062908697281434, 6.893199663447714, 7.758770342191242, 8.648783335374896, 9.641900688643965, 10.592724463987912, 11.405657245348076, 12.393257934409778, 13.352738554229287, 14.349886896608195, 14.395757417495068, 13.50506003825784, 12.590062760276373, 11.587139021627989, 10.541305609085224, 9.56843011949552, 8.611539006555844, 7.696023720126329, 6.716956473457185, 5.758775413326233, 5.037439688123178, 5.9310531265724205, 6.779506083452416, 7.667027657034439, 8.650368919715257, 9.5377007709251, 10.468386150471705, 11.459874215116317, 12.387246373006903, 13.365907154829094, 13.46432173557096, 12.494068713421171, 11.558373449147439, 10.63960359278776, 9.580450079333625, 8.662693717803215, 7.64460189817569, 6.7468396406767095, 5.7903914105654355, 4.744280803291744, 4.107873859046368, 4.978250012287068, 5.706885963843546, 6.711870376730626, 7.599341050404342, 8.581067070838527, 9.634211945247626, 10.528003819764745, 11.498438907062724, 12.429183226516589, 12.610905186339252, 11.600649459719918, 10.618625157367351, 9.662731517055262, 8.641043888266571, 7.673616741415001, 6.691688489082678, 5.715816356330146, 4.749228533561702, 3.806501584659279, 3.108926302765375, 3.946285571131919, 4.757886146045364, 5.751643126654166, 6.671904182436688, 7.597575368851865, 8.601459877105974, 9.592165159746559, 10.5356038685663, 11.561923751719405, 11.655732905397441, 10.616098697479655, 9.626968452885587, 8.685701678363081, 7.696304357689494, 6.728787577696166, 5.8036996261914675, 4.836841025325684, 3.8418027752452213, 2.880118580224836, 2.046572435386659, 2.8877101673741055, 3.8112796020042663, 4.7563610326057955, 5.678034869185838, 6.643249412287886, 7.672890047938002, 8.667146354866874, 9.619491805496649, 10.57348513349822, 10.693663454570945, 9.659460711712548, 8.676593909665536, 7.714158613636007, 6.74553236548924, 5.762233135467619, 4.826142531531627, 3.8500585423445166, 2.836296171484941, 1.8951512120451188, 0.979101691182247, 1.9483759521839268, 2.831075768524076, 3.79093149876878, 4.751945459013699, 5.80306171290766, 6.764693748166398, 7.724128824024676, 8.668236518104603, 9.676988626232573, 10.00453487972723, 8.931821454866322, 7.953797529449448, 6.98314712665472, 5.9453629387326625, 4.93303191108822, 3.9054164461245673, 2.9351713250689393, 1.9481803849306694, 0.9551285658676029, 0.0, 0.9354908520385078, 1.869510474435931, 2.8467413354952473, 3.8749389335904443, 4.834150760817312, 5.787601643156215, 6.756897296367369, 7.713561096066487, 8.747379559810021, 10.882812414596897, 9.93362917054635, 8.919382024966566, 7.938228942408484, 6.912500062742216, 5.9270856302258315, 4.877523481562513, 3.921960400271565, 2.857889769500505, 1.9158240659604544, 0.9332016161646493, 1.9596902960332865, 2.872476354087657, 3.848598830517343, 4.842034690603709, 5.791094992184655, 6.841348237946832, 7.72377753312233, 8.732686050833653, 9.717867808759589, 10.655414699620211, 10.820444315946455, 9.787805812295673, 8.717251498089869, 7.688139181856469, 6.754003232678533, 5.783119191350205, 4.815253438276246, 3.8187446629035073, 2.903891193022566, 1.9561073763354344, 2.9045834280839826, 3.888239856187492, 4.834697141242858, 5.774069506434383, 6.767843318051398, 7.790493401065984, 8.734704324282067, 9.724598294073214, 10.645127247486686, 9.699363930439583, 10.665008907657764, 10.715522315453164, 9.660893506806724, 8.655886947068709, 7.681501685083772, 6.763763436727754, 5.7494208197522205, 4.783611347455164, 3.8603491792324025, 2.9020574487892965, 3.867405231649996, 4.8425401989315775, 5.806584622905536, 6.748210123839723, 7.7615626650214065, 8.693477183277714, 9.666382385025647, 10.738008288247642, 10.971060578901696, 10.624611290516684, 11.591169104415902, 11.590012200527962, 10.642135956430948, 9.632747091016004, 8.688550204968234, 7.722011291335377, 6.762462696814638, 5.8060711708306805, 4.845161889384504, 3.89261580238111, 4.803484128752975, 5.747751266167082, 6.771177033147043, 7.674947945820339, 8.623983670927544, 9.582002544166274, 10.524059046323725, 11.523616437083389, 11.767582945233418, 11.59554953939232, 12.647828461759262, 12.542582929468262, 11.617030503633185, 10.622207762250175, 9.626986883101287, 8.660162186231618, 7.755578007775856, 6.7631843600070845, 5.820626638718698, 4.905306406202086, 5.764777072838268, 6.738779792909575, 7.8002851164031455, 8.74102554668123, 9.627714441384937, 10.53487628290366, 11.509279718725722, 12.484336096732587, 12.722707507670412, 12.549375426609924, 13.610258838288592, 13.554684221801239, 12.54660376050332, 11.550241141270337, 10.584386017112557, 9.629552767199565, 8.694676843645036, 7.700565837536447, 6.89537610265176, 5.848551420354159, 6.803164258033355, 7.779444783307977, 8.706645696361852, 9.752341559399262, 10.591470845562402, 11.598676195316129, 12.533122805461941, 13.454021502557554, 13.575332409260719, 13.45436679235077, 14.430357039293172, 14.499001000997504, 13.474137949713153, 12.589886816378616, 11.637652634964054, 10.656034098055766, 9.63698354733826, 8.644124810512627, 7.943882981554837, 6.89624374202664, 7.830573991498133, 8.721395875067245, 9.753106323337466, 10.694088537305811, 11.628437281886285, 12.61324782825221, 13.603529668149882, 14.425364559018584, 14.467689982369674, 14.400817336311182, 15.379782676992107, 15.422740488766655, 14.476786516253481, 13.553931334404382, 12.569254490554531, 11.604849808093212, 10.648312529802379, 9.67591863842229, 8.920963127308635, 7.935479414357572, 8.884820229870634, 9.652749921059291, 10.58434402931618, 11.556947032494111, 12.622344549123941, 13.567554783037401, 14.531574452374846, 15.422909725555083, 15.336546978771462, 15.3524511074807, 16.32603800807931, 16.402740164807135, 15.475135342788379, 14.492439680284063, 13.508624092220067, 12.542857648699673, 11.63151141489497, 10.709160445562116, 9.83494758508046, 8.892176817012668, 9.871167777941777, 10.587798233036725, 11.573435507714589, 12.62498628018554, 13.613352592396147, 14.52597082618787, 15.534858867754483, 16.432178171523084, 16.265601557367674, 16.25432443912949, 17.311591759720116, 16.37866557533934, 15.428056439651145, 14.538370272968173, 13.464685973265198, 12.529354834105236, 11.74625444711773, 10.860677521149796, 10.269858550725889, 9.888672278904444, 10.814704005804773, 11.580230120813738, 12.524045825481764, 13.463830953343201, 14.463416419273502, 15.4731108898498, 16.45285558888532, 17.387373768985324, 17.330134694665578, 17.182010072763667, 16.388093750264105, 15.38593112584331, 14.408943041754975, 13.495991236413138, 12.515541394942527, 11.57168229341606, 10.780994350693152, 9.847422230379657, 9.198161270345286, 9.805948312090253, 10.626306327418469, 11.55722758654623, 12.583493750132124, 13.522210398302155, 14.493623684990338, 15.507240548452867, 16.41847019837621, 17.369662533527414, 18.391781557887267], [18.355034762123278, 17.376278868379448, 16.414558990982144, 15.459562441465843, 14.476868207333672, 13.474144480181977, 12.58382801911552, 11.588038148407227, 10.579002919906497, 9.729035005248392, 8.925293489218344, 7.960947857284404, 8.846897200647376, 9.69544526039459, 10.638801481044824, 11.602735573057307, 12.478139828780602, 13.407344001651973, 14.425812373440381, 15.383752318898487, 17.3050493643453, 16.43340853470114, 15.47707322356528, 14.48708125232356, 13.453742907932977, 12.500315336611928, 11.541362000588839, 10.595850703272962, 9.650549480928737, 8.689984153149613, 7.855934559865567, 6.923116426052306, 7.852540135045755, 8.698253954396817, 9.731493115521584, 10.596632200384581, 11.44144001795225, 12.407518858422938, 13.43125331847683, 14.362632458886612, 16.299267577128656, 15.503352235129348, 14.535479000182079, 13.537248696873451, 12.483954652712686, 11.502297526632894, 10.546223441150675, 9.654330502048992, 8.670103418981299, 7.672177928204771, 6.899675147254117, 5.957708811409207, 6.823279490152734, 7.713292483336389, 8.706409836605458, 9.657233611949403, 10.470166393309567, 11.45776708237127, 12.417247702190778, 13.414396044569687, 15.331248269533573, 14.440550890296345, 13.52555361231488, 12.522629873666496, 11.476796461123731, 10.50392097153403, 9.547029858594353, 8.631514572164837, 7.652447325495693, 6.694266265364741, 5.874206138095861, 4.9955622745339126, 5.844015231413908, 6.731536804995932, 7.714878067676749, 8.602209918886592, 9.532895298433196, 10.524383363077808, 11.451755520968394, 12.430416302790585, 14.399812587609466, 13.429559565459677, 12.493864301185946, 11.575094444826266, 10.515940931372132, 9.598184569841722, 8.580092750214199, 7.682330492715217, 6.725882262603943, 5.679771655330252, 4.944640309019051, 4.04275916024856, 4.771395111805038, 5.776379524692119, 6.663850198365834, 7.645576218800019, 8.69872109320912, 9.592512967726236, 10.562948055024215, 11.49369237447808, 13.54639603837776, 12.536140311758427, 11.554116009405858, 10.598222369093769, 9.576534740305078, 8.609107593453508, 7.627179341121186, 6.651307208368654, 5.68471938560021, 4.741992436697787, 3.945692752738058, 3.0107947190934112, 3.8223952940068564, 4.816152274615659, 5.73641333039818, 6.662084516813357, 7.665969025067466, 8.65667430770805, 9.600113016527791, 10.626432899680896, 12.591223757435948, 11.551589549518162, 10.562459304924094, 9.621192530401588, 8.631795209728, 7.664278429734673, 6.7391904782299745, 5.772331877364191, 4.777293627283728, 3.8156094322633436, 2.8853860784522216, 1.9522193153355976, 2.875788749965759, 3.8208701805672884, 4.74254401714733, 5.707758560249378, 6.737399195899494, 7.731655502828366, 8.68400095345814, 9.637994281459711, 11.62915430660945, 10.594951563751055, 9.612084761704043, 8.649649465674514, 7.681023217527747, 6.697723987506126, 5.761633383570134, 4.785549394383024, 3.7717870235234483, 2.8306420640836265, 1.914592543220755, 1.0128851001454189, 1.8955849164855685, 2.855440646730272, 3.8164546069751912, 4.867570860869151, 5.82920289612789, 6.788637971986168, 7.732745666066094, 8.741497774194064, 10.940025731765736, 9.867312306904829, 8.889288381487955, 7.918637978693227, 6.8808537907711695, 5.868522763126728, 4.840907298163075, 3.870662177107447, 2.8836712369691773, 1.8906194179061107, 0.9354908520385078, 0.0, 0.9340196223974233, 1.9112504834567394, 2.9394480815519364, 3.8986599087788045, 4.852110791117707, 5.821406444328861, 6.778070244027979, 7.811888707771512, 10.664060845941751, 10.869120022584857, 9.854872877005073, 8.873719794446991, 7.847990914780724, 6.862576482264339, 5.8130143336010205, 4.857451252310073, 3.793380621539013, 2.851314917998962, 1.868692468203157, 1.0241994439947788, 1.936985502049149, 2.913107978478835, 3.9065438385652014, 4.855604140146147, 5.905857385908324, 6.7882866810838225, 7.797195198795145, 8.78237695672108, 9.719923847581702, 10.75643416701933, 10.723296664334182, 9.652742350128378, 8.623630033894978, 7.689494084717041, 6.718610043388713, 5.750744290314754, 4.754235514942016, 3.8393820450610736, 2.891598228373942, 2.0316710960449784, 2.952749004148984, 3.8992062892043493, 4.838578654395874, 5.83235246601289, 6.855002549027475, 7.799213472243558, 8.789107442034705, 9.709636395448177, 8.763873078401074, 9.729518055619256, 10.717376538636463, 10.596384358845233, 9.591377799107217, 8.61699253712228, 7.699254288766263, 6.684911671790729, 5.719102199493672, 4.79584003127091, 3.837548300827804, 3.020481908777265, 3.950456136031429, 4.871093770867027, 5.812719271801214, 6.826071812982899, 7.757986331239207, 8.730891532987139, 9.802517436209133, 10.66894961749722, 9.689120438478176, 10.655678252377394, 11.682674860401182, 11.577626808469457, 10.568237943054513, 9.624041057006743, 8.657502143373884, 7.697953548853145, 6.7415620228691875, 5.780652741423011, 4.828106654419617, 3.9565608058802444, 4.9008279432943525, 5.835686181108534, 6.73945709378183, 7.688492818889035, 8.646511692127765, 9.588568194285216, 10.58812558504488, 11.520323259636541, 10.66005868735381, 11.712337609720754, 12.635245589341482, 12.552521355671693, 11.557698614288684, 10.562477735139796, 9.595653038270125, 8.691068859814363, 7.6986752120455915, 6.756117490757205, 5.840797258240593, 4.917853749965539, 5.891856470036846, 6.864794264364637, 7.805534694642722, 8.692223589346428, 9.599385430865151, 10.573788866687213, 11.548845244694078, 12.55334002639036, 11.613884574571415, 12.674767986250083, 13.647346881674459, 13.482094612541829, 12.485731993308846, 11.519876869151064, 10.565043619238072, 9.630167695683543, 8.636056689574954, 7.830866954690267, 6.784042272392666, 5.956240935160626, 6.932521460435248, 7.859722373489122, 8.816850707360754, 9.655979993523893, 10.66318534327762, 11.597631953423432, 12.518530650519045, 13.489443735328978, 12.518875940312261, 13.494866187254663, 14.503932736134075, 14.409628801751662, 13.525377668417125, 12.573143487002561, 11.591524950094271, 10.572474399376766, 9.579615662551133, 8.879373833593343, 7.831734594065147, 6.983650668625403, 7.874472552194515, 8.906183000464736, 9.758597685267302, 10.692946429847776, 11.6777569762137, 12.668038816111373, 13.489873706980076, 14.434657264566493, 13.465326484272673, 14.444291824953599, 15.395259151513672, 15.41227736829199, 14.489422186442889, 13.504745342593038, 12.540340660131717, 11.583803381840884, 10.611409490460796, 9.85645397934714, 8.870970266396078, 8.037896906997904, 8.805826598186561, 9.73742070644345, 10.710023709621382, 11.733338059634024, 12.646196268105626, 13.596083600336337, 14.487418873516575, 15.41110685137713, 14.416960255442191, 15.390547156040798, 16.32983235025364, 15.494187768265986, 14.51149210576167, 13.527676517697675, 12.594934239726124, 11.88053151335082, 10.923044312461034, 10.770438437118967, 9.827667669051175, 9.057109832535323, 9.740874910163996, 10.726512184841859, 11.77806295731281, 12.72434610290623, 13.604612311256094, 14.613500352822708, 15.496687319484575, 16.340161429973342, 15.31883358709098, 16.376100907681607, 15.443174723300833, 14.492565587612637, 13.602879420929664, 12.529195121226689, 11.593863982066729, 10.810763595079221, 9.925186669111289, 10.95960319172716, 10.824163130942951, 10.075759518980878, 10.733306797941008, 11.677122502609034, 12.616907630470472, 13.616493096400772, 14.585456587348425, 15.565201286383948, 16.451882916946815, 17.39305332814005, 16.246519220725155, 15.452602898225596, 14.450440273804801, 13.473452189716467, 12.56050038437463, 11.580050542904019, 10.636191441377553, 9.845503498654644, 8.91193137834115, 9.941577464683334, 10.741439164128762, 11.078446896845023, 11.780709082027325, 12.684095241442877, 13.589129785533107, 14.592679193630804, 15.606296057093333, 16.6164073364126, 17.46963301268509, 18.454700191361738], [18.422261759039696, 17.548366309416576, 16.615436960411245, 15.660440410894944, 14.650561116668959, 13.678322149034774, 12.843804498644099, 11.853209396515895, 11.499396867068086, 10.64942895240998, 9.747307448622852, 8.782961816688912, 7.912877578249953, 8.761425637997167, 9.7047818586474, 10.668715950659886, 11.54412020638318, 12.473324379254551, 13.49179275104296, 14.449732696501066, 17.350576001686672, 17.367428157098566, 16.411092845962706, 15.421100874720983, 14.3877625303304, 13.434334959009352, 12.475381622986262, 11.516244650434551, 10.570943428090326, 9.610378100311202, 8.677948519270075, 7.745130385456814, 6.918520512648332, 7.764234331999394, 8.797473493124158, 9.66261257798716, 10.507420395554828, 11.473499236025516, 12.497233696079409, 13.42861283648919, 16.344794214470028, 16.437371857526774, 15.469498622579504, 14.471268319270873, 13.41797427511011, 12.436317149030318, 11.480243063548098, 10.588350124446416, 9.604123041378722, 8.606197550602195, 7.818962993430167, 6.779722770813715, 5.88925986775531, 6.779272860938965, 7.772390214208033, 8.723213989551981, 9.536146770912145, 10.523747459973848, 11.483228079793356, 12.480376422172265, 15.417876790256104, 15.37457051269377, 14.459573234712304, 13.45664949606392, 12.410816083521155, 11.437940593931453, 10.481049480991777, 9.565534194562261, 8.586466947893117, 7.628285887762164, 6.793493984271912, 5.8175762339384205, 4.909995609016485, 5.797517182598509, 6.780858445279327, 7.66819029648917, 8.598875676035775, 9.590363740680386, 10.517735898570972, 11.496396680393163, 14.504005888967782, 14.363579187857102, 13.42788392358337, 12.50911406722369, 11.449960553769555, 10.532204192239147, 9.514112372611622, 8.616350115112642, 7.659901885001367, 6.6137912777276755, 5.863928155195102, 4.864773119653068, 3.8373754894076146, 4.842359902294695, 5.729830575968411, 6.7115565964025965, 7.764701470811697, 8.658493345328813, 9.628928432626791, 10.559672752080656, 13.519851335853023, 13.470159934155848, 12.488135631803281, 11.532241991491192, 10.510554362702502, 9.543127215850934, 8.56119896351861, 7.5853268307660775, 6.618739007997633, 5.676012059095211, 4.864980598914109, 3.930082565269462, 2.888375671609433, 3.8821326522182353, 4.802393708000757, 5.728064894415934, 6.731949402670043, 7.722654685310626, 8.666093394130367, 9.692413277283473, 12.644777341920292, 12.485609171915586, 11.496478927321517, 10.555212152799012, 9.565814832125424, 8.598298052132098, 7.673210100627398, 6.706351499761615, 5.711313249681152, 4.749629054660767, 3.804673924628273, 2.8715071615116488, 1.9417691275683353, 2.886850558169865, 3.8085243947499077, 4.773738937851955, 5.803379573502071, 6.797635880430942, 7.749981331060716, 8.703974659062288, 11.660223127901592, 11.528971186148478, 10.546104384101467, 9.583669088071938, 8.61504283992517, 7.631743609903549, 6.695653005967557, 5.719569016780447, 4.705806645920871, 3.7646616864810496, 2.848612165618178, 1.93217294632147, 0.9615652940881452, 1.9214210243328491, 2.882434984577768, 3.933551238471728, 4.895183273730466, 5.854618349588744, 6.798726043668671, 7.80747815179664, 10.701455694274264, 10.801331929302254, 9.82330800388538, 8.852657601090652, 7.814873413168593, 6.80254238552415, 5.774926920560498, 4.80468179950487, 3.8176908593666004, 2.8246390403035337, 1.869510474435931, 0.9340196223974233, 0.0, 0.9772308610593162, 2.0054284591545133, 2.9646402863813814, 3.9180911687202835, 4.887386821931438, 5.844050621630555, 6.877869085374089, 9.730041223544328, 10.679224467594874, 10.788892499402497, 9.807739416844415, 8.782010537178147, 7.796596104661762, 6.747033955998443, 5.791470874707496, 4.727400243936436, 3.785334540396385, 2.80271209060058, 1.9582190663922021, 1.0029658796517258, 1.9790883560814116, 2.972524216167778, 3.9215845177487236, 4.971837763510901, 5.854267058686399, 6.863175576397722, 7.848357334323658, 8.785904225184279, 9.822414544621907, 10.71107341939653, 10.5867619725258, 9.5576496562924, 8.623513707114464, 7.652629665786136, 6.684763912712176, 5.688255137339438, 4.773401667458497, 3.825617850771365, 2.9656907184424015, 2.0187293817515606, 2.965186666806926, 3.904559031998452, 4.898332843615467, 5.920982926630051, 6.8651938498461345, 7.855087819637281, 8.775616773050755, 7.829853456003651, 8.795498433221832, 9.78335691623904, 10.84441964668546, 10.525397421504639, 9.551012159519702, 8.633273911163686, 7.618931294188151, 6.653121821891094, 5.729859653668334, 4.771567923225227, 3.9545015311746887, 3.0164365136340057, 3.9370741484696046, 4.878699649403791, 5.892052190585476, 6.823966708841784, 7.796871910589717, 8.868497813811711, 9.734929995099797, 8.755100816080752, 9.72165862997997, 10.748655238003758, 11.696531482100772, 11.502257565451934, 10.558060679404164, 9.591521765771308, 8.63197317125057, 7.675581645266611, 6.714672363820434, 5.762126276817041, 4.8905804282776675, 4.006463536637331, 4.901666558711112, 5.8054374713844075, 6.754473196491612, 7.712492069730343, 8.654548571887794, 9.654105962647458, 10.58630363723912, 9.726039064956387, 10.77831798732333, 11.701225966944058, 12.67195799958361, 12.491718236686106, 11.496497357537217, 10.529672660667549, 9.625088482211787, 8.632694834443015, 7.690137113154629, 6.774816880638016, 5.851873372362961, 4.997492063379824, 5.930774641967213, 6.871515072245298, 7.758203966949004, 8.66536580846773, 9.639769244289791, 10.614825622296657, 11.619320403992939, 10.679864952173991, 11.74074836385266, 12.713327259277035, 13.6317486456694, 13.419751615706268, 12.453896491548488, 11.499063241635495, 10.564187318080966, 9.570076311972379, 8.76488657708769, 7.71806189479009, 6.890260557558048, 6.038157053778226, 6.930824508187127, 7.882831084963329, 8.72196037112647, 9.729165720880198, 10.66361233102601, 11.584511028121623, 12.555424112931556, 11.584856317914838, 12.56084656485724, 13.569913113736652, 14.559282834879234, 14.459397290814547, 13.507163109399984, 12.525544572491697, 11.506494021774191, 10.513635284948558, 9.813393455990768, 8.765754216462572, 7.917670291022826, 6.980108145537494, 7.97997810151007, 8.824578062869877, 9.75892680745035, 10.743737353816279, 11.734019193713952, 12.555854084582654, 13.500637642169071, 12.531306861875251, 13.510272202556175, 14.461239529116249, 15.407193501629422, 14.51770334081564, 13.533026496965789, 12.598922457935162, 11.929710776045987, 11.545429112858221, 10.790473601744566, 9.804989888793504, 8.881219961680804, 7.91146219152954, 8.84305629978643, 9.798368920247004, 10.799318437236598, 11.712176645708205, 12.662063977938915, 13.553399251119153, 14.477087228979709, 13.48294063304477, 14.456527533643376, 15.395812727856217, 14.560168145868564, 13.577472483364248, 12.593656895300253, 11.6609146173287, 10.946511890953396, 11.745058271865542, 11.704458059516393, 10.7616872914486, 9.794784710294438, 8.846510503506975, 9.832147778184838, 10.866408167938433, 11.790326480508805, 12.670592688858672, 13.679480730425286, 14.562667697087154, 15.40614180757592, 14.384813964693558, 15.442081285284184, 14.509155100903412, 13.558545965215215, 12.668859798532242, 11.595175498829267, 10.659844359669306, 9.876743972681798, 10.747200628515797, 11.781617151131668, 11.739466123640321, 10.813434396739993, 9.838942391283988, 10.782758095952014, 11.722543223813451, 12.722128689743752, 13.651436964951003, 14.631181663986526, 15.517863294549395, 16.45903370574263, 15.312499598327735, 14.518583275828174, 13.51642065140738, 12.539432567319045, 11.626480761977207, 10.646030920506597, 9.70217181898013, 8.91148387625722, 9.733945337745658, 10.763591424087842, 11.66183311129035, 11.816121774604138, 10.886344675370305, 11.789730834785857, 12.694765378876086, 13.698314786973784, 14.672407722985747, 15.682387714015178, 16.53561339028767, 17.52068056896432], [17.514717896129596, 16.640822446506476, 15.707893097501145, 14.752896547984845, 13.834542283010473, 12.975235338550199, 12.32552528524138, 12.76553390106857, 12.45462419823698, 11.604656283578873, 10.702534779791746, 9.738189147857808, 8.868104909418847, 7.861181614405072, 8.804537835055307, 9.704231821339373, 10.579636077062668, 11.508840249934039, 12.527308621722447, 13.485248567180554, 16.443032138776573, 17.388052096874517, 16.71536970836885, 15.725377737127129, 14.857667582411167, 13.949064482120248, 13.367991303768061, 12.471471981603445, 11.52617075925922, 10.565605431480096, 9.633175850438969, 8.700357716625708, 7.873747843817227, 6.863990308407299, 7.897229469532064, 8.698128448666647, 9.542936266234316, 10.509015106705004, 11.532749566758897, 12.464128707168678, 15.437250351559927, 16.38297835738688, 16.44672948363882, 15.448499180330188, 14.395205136169425, 13.413548010089633, 12.457473924607413, 11.565580985505731, 10.581353902438037, 9.58342841166151, 8.774190324599061, 7.734950101982609, 6.844487198924205, 5.87902883734687, 6.872146190615938, 7.758729860231468, 8.571662641591633, 9.559263330653334, 10.518743950472844, 11.515892292851753, 14.510332927346004, 15.479416262497116, 15.436804095771619, 14.433880357123234, 13.38804694458047, 12.415171454990768, 11.458280342051092, 10.542765055621576, 9.563697808952432, 8.60551674882148, 7.748721315440807, 6.772803565107315, 5.8652229401853795, 4.897273159006414, 5.8163743159588135, 6.703706167168657, 7.634391546715262, 8.625879611359874, 9.55325176925046, 10.53191255107265, 13.596462026057683, 14.566715048207472, 14.405114784642684, 13.486344928283005, 12.42719141482887, 11.509435053298462, 10.491343233670937, 9.593580976171957, 8.637132746060683, 7.591022138786991, 6.8191554863639965, 5.820000450821963, 4.792602820576509, 3.9421158787026, 4.765346446647898, 5.747072467082083, 6.800217341491184, 7.681262484269497, 8.651697571567476, 9.582441891021341, 12.612307472942923, 13.626147803306806, 13.465366492862596, 12.509472852550507, 11.487785223761817, 10.520358076910249, 9.538429824577925, 8.562557691825393, 7.595969869056949, 6.6532429201545265, 5.820207930083003, 4.885309896438357, 3.8436030027783277, 2.98188862862614, 3.8379095786802435, 4.763580765095421, 5.76746527334953, 6.745423824251311, 7.6888625330710525, 8.715182416224158, 11.687429781135332, 12.692355167889453, 12.473709788380832, 11.532443013858327, 10.54304569318474, 9.575528913191413, 8.650440961686714, 7.683582360820932, 6.688544110740469, 5.726859915720083, 4.759901255797167, 3.826734492680543, 2.8969964587372297, 1.9866065345777697, 2.844040265429394, 3.809254808531442, 4.838895444181558, 5.820405019371627, 6.772750470001401, 7.726743798002973, 10.702875567116632, 11.735717182122345, 11.523335245160782, 10.560899949131253, 9.592273700984485, 8.608974470962865, 7.672883867026874, 6.696799877839764, 5.683037506980188, 4.741892547540366, 3.8258430266774943, 2.8874002774903644, 1.9167926252570395, 0.9569368950123357, 1.9179508552572548, 2.969067109151215, 3.9179524126711502, 4.877387488529429, 5.821495182609356, 6.830247290737325, 9.724224833214947, 10.76503791213132, 10.800538864944695, 9.829888462149968, 8.79210427422791, 7.779773246583467, 6.752157781619815, 5.781912660564187, 4.794921720425917, 3.80186990136285, 2.8467413354952473, 1.9112504834567394, 0.9772308610593162, 0.0, 1.028197598095197, 1.987409425322065, 2.9408603076609676, 3.910155960872122, 4.866819760571239, 5.900638224314773, 8.752810362485013, 9.70199360653556, 10.716240752115343, 10.784970277903732, 9.759241398237464, 8.773826965721078, 7.72426481705776, 6.768701735766813, 5.7046311049957525, 4.762565401455702, 3.779942951659897, 2.9354499274515184, 1.9801967407110421, 1.0715444931713125, 2.022418841531787, 2.9443536566894073, 3.9946069024515847, 4.877036197627083, 5.885944715338406, 6.871126473264342, 7.808673364124964, 8.845183683562592, 9.733842558337214, 10.804396872543018, 10.534880517351718, 9.600744568173782, 8.629860526845453, 7.661994773771493, 6.665485998398755, 5.750632528517814, 4.802848711830682, 3.942921579501718, 2.9959602428108774, 2.057642803896827, 2.9970151690883524, 3.9211019825561504, 4.943752065570736, 5.887962988786819, 6.877856958577965, 7.7983859119914385, 6.852622594944335, 7.818267572162515, 8.806126055179723, 9.867188785626142, 10.872195345364158, 10.528243020579021, 9.610504772223003, 8.596162155247468, 7.630352682950411, 6.707090514727651, 5.748798784284545, 4.931732392234005, 3.9936673746933224, 3.029530285559505, 3.9711557864936915, 4.914821329526159, 5.846735847782467, 6.8196410495304, 7.891266952752394, 8.75769913404048, 7.777869955021436, 8.744427768920653, 9.771424376944442, 10.719300621041455, 11.770967835707022, 11.535291540463483, 10.568752626830625, 9.609204032309886, 8.652812506325928, 7.691903224879752, 6.739357137876358, 5.867811289336983, 4.983694397696648, 3.9941226958010123, 4.897893608474308, 5.846929333581513, 6.804948206820244, 7.747004708977695, 8.746562099737359, 9.67875977432902, 8.748808203897072, 9.801087126264013, 10.723995105884741, 11.694727138524293, 12.689549879907302, 12.473728218596536, 11.506903521726866, 10.602319343271104, 9.609925695502332, 8.667367974213947, 7.752047741697334, 6.829104233422277, 5.974722924439141, 5.023230779057114, 5.963971209335199, 6.850660104038905, 7.757821945557631, 8.732225381379692, 9.707281759386557, 10.71177654108284, 9.702634091114676, 10.763517502793345, 11.736096398217718, 12.654517784610084, 13.650880403843066, 13.431127352607804, 12.476294102694812, 11.541418179140283, 10.547307173031694, 9.742117438147009, 8.695292755849408, 7.867491418617364, 6.950481558330902, 6.023280645277028, 6.97528722205323, 7.81441650821637, 8.8216218579701, 9.756068468115911, 10.676967165211524, 11.647880250021457, 10.607625456855523, 11.583615703797925, 12.592682252677337, 13.582051973819917, 14.542291580365914, 13.564384328964172, 12.647494144380511, 12.483724882833506, 11.490866146007873, 10.790624317050087, 9.74298507752189, 8.837601364670139, 7.89243265009017, 7.07243423859997, 7.917034199959779, 8.851382944540251, 9.83619349090618, 10.826475330803852, 11.648310221672554, 12.593093779258972, 11.566822732554739, 12.53304134149686, 13.484008668056934, 14.429962640570107, 13.617459317223545, 12.632782473373695, 11.698678434343066, 12.657862665560282, 12.522659973917536, 11.767704462803884, 10.782220749852822, 9.793544466233481, 8.823786696082216, 8.12704432902538, 8.890825057336906, 9.891774574326499, 10.804632782798105, 11.754520115028816, 12.645855388209053, 13.56954336606961, 12.518456503724257, 13.492043404322864, 14.431328598535705, 13.616937934518749, 12.677228459772154, 11.693412871708158, 10.760670593736604, 11.729812457089412, 12.700285603034438, 12.628870943844014, 11.686100175776222, 10.707109214847113, 9.75883500805965, 9.192591373820692, 9.958864305028335, 10.882782617598705, 11.763048825948573, 12.771936867515187, 13.655123834177054, 14.498597944665821, 13.420329835373046, 14.477597155963672, 13.5446709715829, 12.594061835894703, 11.710096288362926, 10.694931475237173, 9.75960033607721, 10.7290915860051, 11.702427959684693, 12.736844482300564, 12.651790628192996, 11.725758901292668, 10.751266895836663, 10.264478882549295, 11.019456413328877, 11.885740516355641, 12.743893102040904, 13.723637801076427, 14.610319431639295, 15.551489842832531, 14.348015469007223, 13.554099146507662, 12.551936522086867, 11.574948437998533, 10.661996632656695, 9.745786896914503, 8.801927795388034, 9.828288250290981, 10.689172668914553, 11.718818755256738, 12.617060442459243, 12.728446279156813, 11.79866917992298, 11.271451621383138, 11.991678568391512, 12.882295953315298, 13.764863860075648, 14.774843851105079, 15.62806952737757, 16.61313670605422], [16.54577061104622, 15.671875161423099, 14.748679029154552, 13.793682479638251, 12.87532821466388, 12.016021270203606, 12.970304156811537, 13.663306860300459, 13.414907738148685, 12.56493982349058, 11.662818319703451, 10.698472687769513, 9.76886069267743, 8.75839913303543, 8.060850733470208, 8.812155229073493, 9.687559484796788, 10.616763657668159, 11.635232029456567, 12.58561613991038, 15.474084853693196, 16.419104811791136, 15.756155640022257, 14.766163668780536, 13.898453514064574, 12.989850413773654, 14.002283850015445, 13.43175552151515, 12.486454299170925, 11.525888971391801, 10.593459390350674, 9.660641256537414, 8.807982633770644, 7.761207827037657, 7.013195192528766, 7.806051856400767, 8.650859673968435, 9.616938514439124, 10.640672974493016, 11.526374263610595, 14.46830306647655, 15.4140310723035, 16.41767724917957, 15.793985325462826, 14.868241769284865, 13.987868223752688, 13.48567152270261, 12.593778583600928, 11.609551500533234, 10.611626009756707, 9.755100122675804, 8.695233641894314, 7.80477073883591, 6.776246355977228, 5.988111913612641, 6.866653267965588, 7.679586049325753, 8.667186738387453, 9.602134931648107, 10.57813784929367, 13.530188899777428, 14.49927223492854, 15.536390815405776, 15.462077955218431, 14.416244542675667, 13.443369053085965, 12.486477940146289, 11.570962653716773, 10.591895407047629, 9.633714346916676, 8.735878521492397, 7.73308710501902, 6.825506480097085, 5.794490677636771, 4.924297723692933, 5.811629574902777, 6.742314954449382, 7.727227912188125, 8.636642750425723, 9.537537076572555, 12.598753217853321, 13.56900624000311, 14.504701504276841, 14.514542526378202, 13.455389012924067, 12.53763265139366, 11.519540831766134, 10.621778574267154, 9.66533034415588, 8.619219736882188, 7.806312692415587, 6.780283990733668, 5.752886360488215, 4.8393333973329575, 3.873269854382018, 4.854995874816203, 5.869297611368345, 6.653064886174298, 7.623499973472277, 8.554244292926143, 11.614404463981945, 12.628244794345827, 13.576623904160632, 13.537670450645704, 12.515982821857014, 11.548555675005446, 10.566627422673122, 9.59075528992059, 8.624167467152146, 7.681440518249723, 6.807365136134594, 5.8724671024899475, 4.803886542690033, 3.8949256253626214, 2.9458329864143638, 3.871504172829541, 4.836545543226691, 5.717226226156113, 6.660664934975854, 7.686984818128961, 10.659232183040134, 11.664157569794256, 12.581424157790401, 12.560640611953524, 11.571243291279936, 10.60372651128661, 9.678638559781911, 8.711779958916129, 7.716741708835666, 6.75505751381528, 5.788098853892365, 4.8549320907757405, 3.8572799986489352, 2.9121985680474056, 1.9519636731635144, 2.917178216265562, 3.8526688656693038, 4.792207421276429, 5.744552871906203, 6.698546199907775, 9.674677969021433, 10.707519584027148, 11.631049614570351, 11.58909754722645, 10.620471299079682, 9.637172069058062, 8.701081465122071, 7.724997475934961, 6.711235105075385, 5.770090145635563, 4.854040624772692, 3.9155978755855614, 2.9449902233522365, 1.9851344931075325, 1.0258742629913749, 1.9788927433492567, 2.889754814575953, 3.8491898904342317, 4.793297584514159, 5.802049692642128, 8.696027235119749, 9.736840314036122, 10.701005436420838, 10.858086060245165, 9.820301872323107, 8.807970844678664, 7.780355379715012, 6.810110258659384, 5.823119318521114, 4.830067499458047, 3.8749389335904443, 2.9394480815519364, 2.0054284591545133, 1.028197598095197, 0.0, 0.9592118272268682, 1.9126627095657704, 2.881958362776925, 3.8386221624760424, 4.872440626219576, 7.724612764389816, 8.673796008440362, 9.688043154020146, 10.669196236578228, 10.78743899633266, 9.802024563816275, 8.752462415152957, 7.79689933386201, 6.7328287030909495, 5.790762999550899, 4.808140549755094, 3.9636475255467154, 2.963779579952642, 1.9876571035229562, 0.99422124343659, 1.9161560585942103, 2.9664093043563877, 3.848838599531886, 4.857747117243209, 5.842928875169145, 6.780475766029767, 7.816986085467395, 8.705644960242017, 9.776199274447821, 10.805311590681221, 10.62894216626898, 9.65805812494065, 8.69019237186669, 7.693683596493952, 6.778830126613011, 5.831046309925879, 4.906372217788453, 3.9211800561127026, 2.9554157631287143, 2.016043397937189, 2.8929043844609534, 3.915554467475539, 4.859765390691622, 5.849659360482768, 6.7701883138962415, 5.824424996849138, 6.790069974067318, 7.777928457084526, 8.838991187530945, 9.843997747268961, 10.821638387963201, 10.6387023703182, 9.624359753342665, 8.658550281045608, 7.735288112822848, 6.776996382379742, 5.894022155276729, 4.918887187995147, 3.9273032447913927, 3.011941718147097, 3.886623731430962, 4.81853824968727, 5.791443451435203, 6.863069354657197, 7.729501535945283, 6.749672356926239, 7.7162301708254555, 8.743226778849245, 9.691103022946258, 10.742770237611825, 11.686967123659596, 11.594966671189585, 10.635418076668847, 9.679026550684888, 8.718117269238713, 7.765571182235319, 6.830101052379708, 5.908914210998472, 4.8918956550329, 3.9386795401277137, 4.8877152652349185, 5.84573413847365, 6.778057423894319, 7.777614814653982, 8.709812489245643, 7.720610605801875, 8.772889528168816, 9.695797507789544, 10.666529540429096, 11.661352281812105, 12.625403801792649, 12.533117566085826, 11.628533387630064, 10.636139739861292, 9.693582018572908, 8.778261786056294, 7.791393996465001, 6.8999427377409654, 5.921003738289002, 5.004757140988605, 5.891446035692311, 6.798607877211037, 7.763278096296317, 8.73833447430318, 9.742829255999462, 8.67443649301948, 9.735319904698148, 10.707898800122521, 11.626320186514887, 12.62268280574787, 13.588537929905652, 13.502508147053772, 12.567632223499244, 11.573521217390656, 10.76833148250597, 9.721506800208369, 8.829781181660088, 7.848254517562791, 6.921053604508916, 6.016073153706636, 6.8552024398697755, 7.862407789623506, 8.787121183032536, 9.708019880128147, 10.67893296493808, 9.579427858760324, 10.555418105702726, 11.564484654582138, 12.55385437572472, 13.514093982270717, 12.820697227379073, 13.54471166301087, 13.509938927192469, 12.517080190366835, 11.816838361409047, 10.76919912188085, 9.735374323902025, 8.790205609322058, 7.916917283200361, 6.957820131613185, 7.892168876193658, 8.876979422559586, 9.857528045720477, 10.679362936589177, 11.624146494175594, 10.572447258054643, 11.504843743401661, 12.455811069961735, 13.401765042474908, 12.873772215638446, 11.889095371788596, 12.595895952973425, 13.555080184190642, 13.548874018276498, 12.793918507162845, 11.735250388289241, 10.69131742546537, 9.721559655314104, 8.904213992168245, 7.931610988990312, 8.932560505979906, 9.845418714451512, 10.78557282994544, 11.676908103125676, 12.600596080986232, 11.524081029224162, 12.497667929822768, 13.43695312403561, 12.724861342252868, 11.878637680343678, 10.94972577012306, 11.657888112366964, 12.627029975719772, 13.621991803533088, 13.526643903075902, 12.58387313500811, 11.604882174079002, 10.656607967291539, 9.969761036963556, 8.999650236681742, 9.923568549252112, 10.80383475760198, 11.812722799168593, 12.686176549093677, 13.529650659582444, 12.482575391814963, 13.539842712405589, 12.65259437931702, 11.701985243628823, 10.818019696097046, 9.951244373652074, 10.656817854707569, 11.62630910463546, 12.624134160183344, 13.658550682799214, 13.549563587424885, 12.623531860524556, 11.649039855068551, 11.00002747284372, 10.060242344982283, 10.926526448009048, 11.78467903369431, 12.764423732729833, 13.641372146555918, 14.582542557749154, 13.41026102544914, 12.662022554241782, 11.659859929820987, 10.682871845732652, 9.769920040390815, 9.002099795329404, 9.699145314018393, 10.72550576892134, 11.649456208826258, 12.679102295168443, 13.57734398237095, 13.6262192383887, 12.696442139154868, 11.984263152053142, 11.032464500044918, 11.923081884968704, 12.805649791729055, 13.815629782758485, 14.659122242294192, 15.644189420970841], [15.58655878381935, 14.712663334196229, 13.797578729470748, 12.842582179954448, 11.982664329217874, 12.918992211192702, 13.873275097800633, 14.575271604863671, 14.374119565375553, 13.524151650717446, 12.622030146930319, 11.657684514996381, 10.728072519904298, 9.717610960262299, 8.981486952135569, 7.972163957102208, 8.792826038244385, 9.722030211115756, 10.731091977253094, 11.626404312683512, 14.514873026466326, 15.459892984564268, 14.805055340338454, 13.815063369096732, 13.005789628618569, 13.89282135476275, 14.905254791004541, 14.390967348742018, 13.445666126397793, 12.485100798618669, 11.552671217577542, 10.619853083764282, 9.767194460997512, 8.720419654264525, 7.972407019755634, 6.966060584429482, 7.756126227416033, 8.722205067886721, 9.681591112368798, 10.567162436383727, 13.50909123924968, 14.45481924507663, 15.458465421952699, 14.842885025779022, 13.97557788383886, 14.890839164741784, 14.444883349929478, 13.552990410827798, 12.568763327760104, 11.570837836983577, 10.714311949902672, 9.654445469121182, 8.76398256606278, 7.735458183204096, 6.947323740839509, 6.026661995994303, 6.78485260277335, 7.772453291835052, 8.64292310442124, 9.618926022066802, 12.57097707255056, 13.540060407701672, 14.57717898817891, 15.52163612463881, 15.03715103812187, 14.402580880312833, 13.445689767373157, 12.530174480943641, 11.551107234274498, 10.592926174143546, 9.695090348719265, 8.692298932245889, 7.784718307323953, 6.753702504863639, 5.883509550919801, 4.971638302931492, 5.8475815078969795, 6.768016084961257, 7.677430923198855, 8.578325249345687, 11.639541390626453, 12.609794412776242, 13.545489677049975, 14.574100695798581, 14.414600840150936, 13.496844478620526, 12.478752658993002, 11.580990401494022, 10.624542171382748, 9.578431564109056, 8.765524519642454, 7.739495817960536, 6.712098187715083, 5.798545224559826, 4.832481681608886, 4.015004602844918, 4.910085784141477, 5.69385305894743, 6.664288146245409, 7.5950324656992745, 10.655192636755077, 11.669032967118959, 12.617412076933764, 13.573305717245853, 13.475194649083882, 12.507767502232312, 11.52583924989999, 10.549967117147458, 9.583379294379014, 8.64065234547659, 7.766576963361462, 6.831678929716816, 5.763098369916901, 4.85413745258949, 3.905044813641232, 2.941834608751866, 3.877333715999823, 4.7580143989292445, 5.701453107748986, 6.727772990902093, 9.700020355813265, 10.70494574256739, 11.622212330563533, 12.596938081162651, 12.530455118506804, 11.562938338513476, 10.637850387008777, 9.670991786142995, 8.675953536062533, 7.714269341042148, 6.747310681119233, 5.814143918002609, 4.816491825875803, 3.8714103952742738, 2.9111755003903825, 1.987508652187887, 2.8934570384424356, 3.8329955940495606, 4.785341044679335, 5.739334372680907, 8.715466141794565, 9.748307756800282, 10.671837787343483, 11.634273083373012, 11.57968312630655, 10.59638389628493, 9.660293292348939, 8.684209303161829, 7.670446932302253, 6.729301972862431, 5.81325245199956, 4.8748097028124295, 3.9042020505791046, 2.9443463203344007, 1.985086090218243, 1.0196809161223885, 1.9305429873490847, 2.889978063207363, 3.8340857572872897, 4.842837865415259, 7.736815407892881, 8.777628486809256, 9.74179360919397, 10.665066225105123, 10.779513699549975, 9.767182671905532, 8.73956720694188, 7.769322085886252, 6.782331145747982, 5.789279326684915, 4.834150760817312, 3.8986599087788045, 2.9646402863813814, 1.987409425322065, 0.9592118272268682, 0.0, 0.9534508823389023, 1.9227465355500566, 2.8794103352491742, 3.9132287989927077, 6.765400937162948, 7.714584181213494, 8.728831326793278, 9.70998440935136, 10.75866750630489, 10.761236391043145, 9.711674242379825, 8.756111161088878, 7.692040530317818, 6.749974826777767, 5.767352376981962, 4.9228593527735836, 3.9146826647783293, 2.938560188348643, 1.9451243282622772, 0.9569442313673422, 2.0071974771295196, 2.889626772305018, 3.8985352900163406, 4.883717047942277, 5.821263938802899, 6.857774258240527, 7.74643313301515, 8.816987447220953, 9.846099763454351, 10.780235712632287, 10.617269952167518, 9.649404199093558, 8.65289542372082, 7.738041953839879, 6.766813014100214, 5.818336962351666, 4.833144800675916, 3.8673805076919274, 2.928008142500402, 1.9336925572340853, 2.9563426402486708, 3.9005535634647535, 4.8904475332559, 5.810976486669373, 4.86521316962227, 5.83085814684045, 6.818716629857658, 7.879779360304077, 8.884785920042093, 9.862426560736333, 10.920035413678722, 10.583571580569533, 9.617762108272476, 8.694499940049715, 7.712763086554077, 6.805986899839942, 5.83085193255836, 4.839267989354606, 3.92390646271031, 2.927411904204094, 3.859326422460402, 4.832231624208335, 5.903857527430329, 6.770289708718415, 5.79046052969937, 6.757018343598587, 7.784014951622376, 8.73189119571939, 9.783558410384956, 10.727755296432726, 11.701949609399154, 11.54738282123206, 10.590991295248102, 9.630082013801927, 8.677535926798532, 7.742065796942921, 6.820878955561685, 5.803860399596113, 4.850644284690927, 3.9950513797889133, 4.894633838789846, 5.818845596667451, 6.818402987427114, 7.750600662018775, 6.761398778575007, 7.813677700941948, 8.736585680562676, 9.707317713202228, 10.702140454585237, 11.666191974565779, 12.640100504295395, 12.540498132193278, 11.548104484424506, 10.605546763136122, 9.690226530619507, 8.703358741028214, 7.8119074823041785, 6.832968482852214, 5.9167218855518176, 4.9987821502463055, 5.847507577527233, 6.804066269069449, 7.779122647076312, 8.783617428772594, 7.715224665792611, 8.77610807747128, 9.748686972895653, 10.667108359288019, 11.663470978521001, 12.629326102678782, 13.584159352591774, 13.479596968062458, 12.48548596195387, 11.680296227069183, 10.63347154477158, 9.741745926223302, 8.760219262126004, 7.833018349072129, 6.919044094695733, 5.96253855442377, 6.911307489939703, 7.827909355805668, 8.748808052901278, 9.719721137711211, 8.620216031533456, 9.596206278475858, 10.60527282735527, 11.594642548497852, 12.554882155043849, 13.584656555241953, 14.503923490237739, 14.421903671755683, 13.42904493493005, 12.72880310597226, 11.681163866444063, 10.64733906846524, 9.70217035388527, 8.819888224189457, 7.860791072602281, 6.999504990747653, 7.925879122875783, 8.898316218493608, 9.720151109362309, 10.664934666948724, 9.613235430827775, 10.545631916174793, 11.496599242734867, 12.44255321524804, 12.08974318073053, 12.809731590453957, 13.555107780200293, 14.51429201141751, 14.460838762839712, 13.705883251726057, 12.647215132852455, 11.603282170028582, 10.633524399877317, 9.807184933157341, 8.834581929979409, 8.0398966205339, 8.894318414767708, 9.826361002718572, 10.717696275898808, 11.641384253759362, 10.564869201997293, 11.5384561025959, 12.477741296808741, 11.830127895700466, 11.038646408372392, 11.87036198878842, 12.617099939593832, 13.586241802946642, 14.581203630759957, 14.438608647639114, 13.495837879571322, 12.516846918642214, 11.56857271185475, 10.872731977952652, 9.902621177670838, 9.030904663806107, 9.852734457918176, 10.86162249948479, 11.726964721866807, 12.570438832355574, 11.523363564588095, 12.58063088517872, 11.757860932764617, 10.80725179707642, 9.97802842412576, 10.871880592317435, 11.616029681934437, 12.585520931862328, 13.583345987410212, 14.617762510026083, 14.461528331988097, 13.535496605087769, 12.561004599631763, 11.902998413832817, 10.96321328597138, 10.033862562563042, 10.833578734010507, 11.81332343304603, 12.682160319329048, 13.623330730522284, 12.451049198222272, 11.757882502038308, 10.765126483268585, 9.78813839918025, 8.92992876841953, 9.922736013994765, 10.658357141245261, 11.684717596148207, 12.608668036053126, 13.638314122395311, 14.536555809597816, 14.538183982951914, 13.60840688371808, 12.887234093042238, 11.935435441034015, 11.0304179995227, 11.854549492045251, 12.864529483074682, 13.699910415067322, 14.684977593743971], [14.663013042376415, 13.83614242398836, 12.941013358174379, 11.986016808658079, 12.925730986068773, 13.872443093531603, 14.826725980139534, 15.528722487202574, 15.327570447714454, 14.477602533056348, 13.57548102926922, 12.611135397335282, 11.681523402243199, 10.6710618426012, 9.833641033403053, 8.824318038369691, 7.839375155905483, 8.768579328776854, 9.777641094914191, 10.672953430344611, 13.591327285023391, 14.536347243121334, 13.948489969042084, 12.958497997800363, 13.948856285469468, 14.846272237101651, 15.858705673343442, 15.344418231080919, 14.399117008736694, 13.43855168095757, 12.506122099916443, 11.573303966103182, 10.720645343336413, 9.673870536603426, 8.830812941113166, 7.818214665696964, 6.80267534507713, 7.768754185547819, 8.728140230029895, 9.613711554044826, 12.585545497806745, 13.531273503633695, 14.534919680509764, 13.986319654482653, 14.918644540689758, 15.844290047080685, 15.398334232268382, 14.5064412931667, 13.522214210099007, 12.52428871932248, 11.667762832241573, 10.607896351460083, 9.717433448401682, 8.688909065542997, 7.8146731909917335, 6.878816077261785, 5.831401720434448, 6.819002409496149, 7.689472222082337, 8.665475139727901, 11.61752619021166, 12.586609525362771, 13.623728105840007, 14.568185242299908, 15.445221692776862, 15.356031762651737, 14.399140649712061, 13.483625363282545, 12.504558116613401, 11.546377056482449, 10.648541231058168, 9.64574981458479, 8.738169189662855, 7.707153387202541, 6.750859001072026, 5.824816005104682, 4.894130625558077, 5.814565202622355, 6.723980040859953, 7.624874367006785, 10.686090508287553, 11.656343530437342, 12.592038794711073, 13.620649813459679, 14.484366163025262, 14.450295360959428, 13.432203541331907, 12.534441283832926, 11.577993053721652, 10.531882446447959, 9.718975401981357, 8.692946700299437, 7.665549070053984, 6.751996106898727, 5.785932563947788, 4.968455485183821, 3.956634901802574, 4.740402176608528, 5.710837263906506, 6.641581583360372, 9.701741754416176, 10.715582084780058, 11.663961194594862, 12.61985483490695, 13.544959971958209, 13.461218384571215, 12.479290132238894, 11.503417999486363, 10.536830176717919, 9.594103227815495, 8.720027845700365, 7.785129812055717, 6.716549252255803, 5.807588334928392, 4.8584956959801335, 3.8952854910907684, 2.9238828336609206, 3.8045635165903424, 4.748002225410083, 5.77432210856319, 8.746569473474365, 9.751494860228487, 10.66876144822463, 11.643487198823749, 12.600220441381131, 12.516389220852378, 11.59130126934768, 10.624442668481898, 9.629404418401435, 8.667720223381052, 7.7007615634581335, 6.767594800341509, 5.769942708214705, 4.824861277613175, 3.8646263827292846, 2.9409595345267894, 1.940006156103533, 2.8795447117106585, 3.8318901623404322, 4.785883490342004, 7.762015259455663, 8.794856874461379, 9.71838690500458, 10.68082220103411, 11.649448449180877, 11.549834778623833, 10.613744174687842, 9.637660185500732, 8.623897814641156, 7.6827528552013336, 6.766703334338462, 5.828260585151331, 4.857652932918007, 3.897797202673303, 2.938536972557145, 1.9731317984612908, 0.9770921050101825, 1.936527180868461, 2.8806348749483877, 3.889386983076357, 6.783364525553979, 7.824177604470353, 8.788342726855067, 9.71161534276622, 10.74939953068828, 10.720633554244435, 9.693018089280782, 8.722772968225154, 7.735782028086884, 6.742730209023818, 5.787601643156215, 4.852110791117707, 3.918091168720284, 2.9408603076609676, 1.9126627095657704, 0.9534508823389023, 0.0, 0.9692956532111543, 1.925959452910272, 2.9597779166538056, 5.811950054824045, 6.761133298874592, 7.775380444454376, 8.756533527012458, 9.805216623965988, 10.790631056482374, 10.665125124718728, 9.70956204342778, 8.645491412656721, 7.70342570911667, 6.720803259320864, 5.876310235112486, 4.868133547117232, 3.8920110706875457, 2.8985752106011797, 1.9103951137062445, 1.0597460871318358, 1.9361758899661157, 2.9450844076774385, 3.930266165603374, 4.867813056463996, 5.904323375901624, 6.792982250676248, 7.863536564882052, 8.892648881115452, 9.826784830293388, 10.797668871621717, 10.602855081432462, 9.606346306059724, 8.691492836178782, 7.720263896439117, 6.771787844690569, 5.786595683014818, 4.82083139003083, 3.8814590248393044, 2.887143439572988, 2.0088912502509872, 2.9471026811258514, 3.936996650916998, 4.857525604330471, 3.9117622872833677, 4.8774072645015485, 5.865265747518756, 6.926328477965176, 7.9313350377031915, 8.908975678397432, 9.966584531339821, 10.980927148315356, 10.57121299061138, 9.647950822388617, 8.66621396889298, 7.7594377821788445, 6.784302814897263, 5.792718871693508, 4.877357345049212, 3.8808627865429965, 3.0027610511640326, 3.9557107140004657, 5.011348674513877, 5.816838826379512, 4.8370096473604685, 5.803567461259686, 6.830564069283474, 7.778440313380488, 8.830107528046053, 9.774304414093823, 10.748498727060252, 11.70804732158099, 11.544442177587005, 10.583532896140829, 9.630986809137434, 8.695516679281823, 7.774329837900588, 6.757311281935015, 5.804095167029828, 4.948502262127816, 4.038068467493477, 4.942324686459582, 5.941882077219245, 6.84399241846765, 5.807947896236104, 6.860226818603047, 7.783134798223774, 8.753866830863325, 9.748689572246334, 10.712741092226876, 11.686649621956493, 12.697973624962327, 12.501555366763409, 11.558997645475024, 10.643677412958409, 9.656809623367117, 8.765358364643081, 7.786419365191117, 6.87017276789072, 5.952233032585208, 4.990942206230864, 5.92754535886158, 6.9026017368684425, 7.891826455635386, 6.761773783453709, 7.822657195132378, 8.79523609055675, 9.713657476949116, 10.710020096182099, 11.67587522033988, 12.630708470252872, 13.604066312416352, 13.438936844292773, 12.633747109408086, 11.586922427110483, 10.695196808562205, 9.713670144464906, 8.786469231411031, 7.872494977034635, 6.915989436762673, 6.0547421186433334, 6.951388445597798, 7.872287142693409, 8.827930164574003, 7.666765149194553, 8.642755396136955, 9.651821945016367, 10.64119166615895, 11.601431272704946, 12.63120567290305, 13.657189801109073, 14.58791601927197, 14.382495817268952, 13.682253988311162, 12.634614748782965, 11.600789950804142, 10.655621236224173, 9.773339106528358, 8.814241954941183, 7.952955873086555, 7.069313751579413, 8.02179530828574, 8.84363019915444, 9.773143693811516, 8.659784548488874, 9.59218103383589, 10.543148360395964, 11.489102332909138, 12.501416081955353, 13.486092925805204, 14.508558662539194, 15.46774289375641, 15.414289645178615, 14.65933413406496, 13.600666015191358, 12.556733052367484, 11.586975282216219, 10.760635815496242, 9.78803281231831, 8.9829632773848, 8.037753043471339, 8.949840092510703, 9.841175365690939, 10.749593280622154, 9.611418319658393, 10.585005220256999, 11.52429041446984, 10.876677013361563, 11.85922670872311, 12.722516070055903, 13.570550821932732, 14.53969268528554, 15.534654513098857, 15.392059529978017, 14.449288761910225, 13.470297800981117, 12.522023594193653, 11.826182860291553, 10.856072060009739, 9.973971320657006, 8.996169086621807, 10.00505712818842, 10.850443811658938, 11.678647859218366, 10.569912682249194, 11.62718000283982, 10.804410050425714, 9.853800914737517, 10.798608724476479, 11.724034673584917, 12.569480564273338, 13.53897181420123, 14.536796869749113, 15.571213392364983, 15.414979214327, 14.488947487426671, 13.514455481970666, 12.856449296171718, 11.91666416831028, 10.976929219413941, 9.977013362714137, 10.95675806174966, 11.805639409121179, 12.74318099651627, 11.497598315883371, 10.804431619699406, 9.811675600929682, 8.834687516841347, 9.77129394933321, 10.774890095262247, 11.611808023584162, 12.63816847848711, 13.562118918392027, 14.591765004734212, 15.490006691936719, 15.491634865290816, 14.561857766056983, 13.840684975381139, 12.888886323372915, 11.973484656373598, 10.997984120748882, 12.007964111778312, 12.823389504859453, 13.804827859737957], [13.69371738916526, 12.866846770777208, 12.03732124589255, 12.84608477951309, 13.785798956923784, 14.736882790231157, 15.691165676839088, 16.473745625258225, 16.29686610092561, 15.446898186267504, 14.52237682493755, 13.478776160766575, 12.54879647554553, 11.53833491590353, 10.594978695253296, 9.585655700219935, 8.600712817755728, 8.0082998921531, 8.808345441703038, 9.703657777133458, 12.622031631812236, 13.567051589910179, 13.077486898573325, 13.818565968655374, 14.80892425632448, 15.710711933801205, 16.723145370042996, 16.313713884292074, 15.368412661947849, 14.407847334168725, 13.475417753127598, 12.542599619314338, 11.599875598998002, 10.553100792265015, 9.592150602963411, 8.579552327547209, 7.564013006927375, 6.950641910052691, 7.758844576818743, 8.644415900833673, 11.61624984459559, 12.56197785042254, 13.56562402729861, 14.59611508488839, 15.537499193848717, 16.467475726879307, 16.367629885479538, 15.475736946377856, 14.491509863310162, 13.493584372533634, 12.637058485452728, 11.577192004671238, 10.612315861371517, 9.568139321204587, 8.576010852841979, 7.64015373911203, 6.592739382284693, 5.883124081884862, 6.720176568871183, 7.696179486516748, 10.648230537000504, 11.617313872151616, 12.654432452628852, 13.598889589088753, 14.475926039565707, 15.469099171780444, 15.368436302923214, 14.452921016493699, 13.473853769824556, 12.515672709693604, 11.617836884269321, 10.615045467795944, 9.63305160263269, 8.586383642864131, 7.512196662922271, 6.586153666954927, 5.655468287408322, 4.845269549411201, 5.754684387648799, 6.655578713795632, 9.716794855076397, 10.687047877226187, 11.622743141499917, 12.651354160248523, 13.515070509814107, 14.570048745675638, 14.40149919454306, 13.50373693704408, 12.547288706932806, 11.501178099659114, 10.68827105519251, 9.662242353510592, 8.63484472326514, 7.696347626156036, 6.730284083205096, 5.771523792501484, 4.717972563652819, 3.771106523397374, 4.741541610695353, 5.672285930149219, 8.73244610120502, 9.746286431568903, 10.694665541383706, 11.650559181695796, 12.575664318747053, 13.580971769287425, 13.448585785450048, 12.472713652697516, 11.506125829929072, 10.563398881026648, 9.689323498911518, 8.754425465266872, 7.685844905466958, 6.7519398541857, 5.802847215237442, 4.839577140165018, 3.8356926319109084, 2.835267863379188, 3.7787065721989292, 4.805026455352036, 7.7772738202632095, 8.78219920701733, 9.699465795013475, 10.674191545612594, 11.630924788169976, 12.636142605568589, 12.560596922558835, 11.593738321693053, 10.598700071612589, 9.637015876592205, 8.670057216669289, 7.736890453552665, 6.73923836142586, 5.794156930824331, 4.833922035940439, 3.9102551877379437, 2.9093018093146874, 1.9102490584995042, 2.862594509129278, 3.81658783713085, 6.792719606244509, 7.825561221250223, 8.749091251793425, 9.711526547822954, 10.680152795969722, 11.663452025991342, 11.583039827898995, 10.606955838711885, 9.59319346785231, 8.652048508412488, 7.735998987549616, 6.797556238362486, 5.826948586129162, 4.867092855884458, 3.9078326257683, 2.942427451672445, 1.946387758221337, 0.9672315276573067, 1.9113392217372334, 2.920091329865203, 5.814068872342824, 6.854881951259197, 7.819047073643912, 8.742319689555066, 9.780103877477124, 10.792434905121567, 10.662313742491937, 9.69206862143631, 8.70507768129804, 7.712025862234972, 6.756897296367369, 5.821406444328861, 4.887386821931438, 3.910155960872122, 2.881958362776925, 1.9227465355500566, 0.9692956532111543, 0.0, 0.9566637996991176, 1.9904822634426513, 4.84265440161289, 5.791837645663437, 6.8060847912432205, 7.787237873801303, 8.835920970754833, 9.821335403271219, 10.870897551934537, 10.678857696638934, 9.614787065867874, 8.672721362327824, 7.690098912532019, 6.84560588832364, 5.837429200328386, 4.8613067238987, 3.867870863812334, 2.879690766917399, 1.9198140579868475, 0.9668802367549614, 1.9757887544662842, 2.96097051239222, 3.898517403252842, 4.935027722690469, 5.823686597465094, 6.894240911670898, 7.923353227904297, 8.857489177082233, 9.828373218410562, 10.796238971484522, 10.575641959270877, 9.660788489389935, 8.689559549650271, 7.741083497901723, 6.7558913362259725, 5.790127043241984, 4.850754678050459, 3.856439092784142, 2.8689592211059987, 1.977807027914697, 2.9677009977058435, 3.8882299511193166, 2.9424666340722134, 3.908111611290394, 4.895970094307602, 5.957032824754021, 6.962039384492037, 7.939680025186277, 8.997288878128666, 10.0116314951042, 10.977440967401257, 10.61724647559977, 9.635509622104133, 8.728733435389998, 7.753598468108417, 6.762014524904663, 5.838391703326767, 4.794743540275352, 3.862829022019044, 2.9864150607893114, 4.042053021302722, 4.847543173168358, 3.867713994149314, 4.834271808048531, 5.8612684160723205, 6.809144660169334, 7.8608118748349005, 8.805008760882671, 9.7792030738491, 10.738751668369838, 11.695143194353797, 11.552828549351982, 10.600282462348588, 9.664812332492977, 8.743625491111743, 7.72660693514617, 6.765129525307383, 5.856155311587219, 4.898136438348488, 3.9730290332484275, 4.972586424008091, 5.874696765256495, 4.838652243024949, 5.890931165391892, 6.81383914501262, 7.784571177652172, 8.779393919035181, 9.743445439015725, 10.717353968745341, 11.728677971751175, 12.6522563835302, 12.528293298686178, 11.612973066169562, 10.62610527657827, 9.734654017854236, 8.731442503246766, 7.761240407928846, 6.816672729284761, 5.851010177085875, 4.9582497056504256, 5.933306083657288, 6.922530802424231, 5.792478130242554, 6.853361541921223, 7.825940437345597, 8.744361823737963, 9.740724442970945, 10.706579567128728, 11.66141281704172, 12.6347706592052, 13.589637861059565, 13.60304276261924, 12.556218080321637, 11.654115886567102, 10.658693282520556, 9.73149236946668, 8.736934673734188, 7.780429133462226, 6.914810089498345, 5.982092792386645, 6.902991489482255, 7.858634511362848, 6.6974694959834, 7.673459742925802, 8.682526291805214, 9.671896012947796, 10.632135619493793, 11.661910019691895, 12.687894147897921, 13.618620366060819, 14.533196834035744, 14.633137877221213, 13.585498637693016, 12.545813088859791, 11.600644374279822, 10.637778803227912, 9.678681651640737, 8.817395569786108, 7.9293817224344245, 7.052499655074585, 7.874334545943286, 8.803848040600363, 7.69048889527772, 8.622885380624737, 9.57385270718481, 10.519806679697984, 11.5321204287442, 12.51679727259405, 13.561122954030408, 14.520307185247624, 15.492701076627712, 15.61021802297501, 14.545689153247007, 13.501756190423134, 12.531998420271869, 11.625075512195796, 10.652472509017864, 9.84303124823981, 8.89782101432635, 7.98054443929955, 8.871879712479785, 9.780297627411, 8.64212266644724, 9.615709567045846, 10.554994761258687, 11.482599583277443, 12.465295245781759, 13.449110833845754, 14.415939520429683, 15.385081383782492, 16.400864749750365, 16.337082668033666, 15.394311899965874, 14.415320939036766, 13.467046732249303, 12.690622556991107, 11.720511756709293, 10.834039291512017, 9.856237057476818, 9.043005262156841, 9.881148158447786, 10.709352206007212, 9.600617029038041, 10.657884349628667, 10.112268248107004, 10.615138576587762, 11.559946386326724, 12.485372335435162, 13.436753637575668, 14.40624488750356, 15.404069943051443, 16.438486465667314, 16.360002352382647, 15.43397062548232, 14.459478620026315, 13.720888992871272, 12.781103865009834, 11.836997190268953, 10.837081333569149, 10.046713136431324, 10.836343755910027, 11.773885343305116, 10.528302662672218, 9.835135966488252, 9.05139616430593, 9.596025178691592, 10.532631611183454, 11.536227757112492, 12.479081096886492, 13.505441551789438, 14.42975968182332, 15.459405768165505, 16.459302345147876, 16.436658003346466, 15.506880904112633, 14.705124672080693, 13.75332602007247, 12.83355262722861, 11.858052091603893, 11.097919186459976, 11.854093851648301, 12.835532206526803], [12.759210984303138, 12.076249995021843, 12.954091470476715, 13.802748579212208, 14.742462756622903, 15.693546589930275, 16.647829476538206, 17.430409424957343, 17.253529900624727, 16.403561985966622, 15.457944358856613, 14.414343694685638, 13.484364009464592, 12.473902449822592, 11.530546229172359, 10.521223234138997, 9.536280351674792, 8.943867426072165, 7.984862203837952, 8.880174539268374, 11.687525226950115, 12.632545185048057, 13.588880496183918, 14.57887246742564, 15.550623649369891, 16.50882973715923, 17.46365862701549, 17.270377683991192, 16.325076461646965, 15.364511133867843, 14.432081552826716, 13.499263419013456, 12.535443132917065, 11.488668326184078, 10.527718136882473, 9.515119861466271, 8.49958054084644, 7.8862094439717545, 6.9353613389536575, 7.8209326629685885, 10.681743439733468, 11.627471445560419, 12.631117622436488, 13.657309572654192, 14.5808353941496, 15.510811927180193, 16.468520067577327, 16.432400746076972, 15.44817366300928, 14.450248172232753, 13.593722285151847, 12.533855804370356, 11.54788339529058, 10.50370685512365, 9.511578386761041, 8.575721273031093, 7.528306916203756, 6.8186916158039255, 5.896693331006098, 6.872696248651662, 9.713724132138383, 10.682807467289495, 11.709439344593612, 12.642690749447238, 13.51926223986659, 14.512435372081328, 15.469326485021003, 15.409584816192817, 14.430517569523674, 13.472336509392722, 12.574500683968438, 11.571709267495063, 10.568619136551753, 9.521951176783194, 8.447764196841334, 7.521721200873991, 6.591035821327385, 5.7808370833302645, 4.931201149783714, 5.832095475930546, 8.782288450214276, 9.752541472364065, 10.677750033464678, 11.69515532060701, 12.55840671011499, 13.613384945976522, 14.51374862740352, 14.460400736743198, 13.503952506631924, 12.457841899358232, 11.644934854891627, 10.61890615320971, 9.591508522964256, 8.6319151600751, 7.66585161712416, 6.707091326420548, 5.653540097571883, 4.706674057316437, 3.918058372830268, 4.848802692284133, 7.797939696342899, 8.811780026706781, 9.73800174168459, 10.693895381996679, 11.619000519047937, 12.624307969588308, 13.560835218310508, 13.429377452396634, 12.46278962962819, 11.520062680725767, 10.645987298610635, 9.711089264965988, 8.642508705166074, 7.6875073881047635, 6.738414749156505, 5.775144674084081, 4.771260165829972, 3.7708353972982516, 2.9552233343338443, 3.9086638537604985, 6.842767415401087, 7.825535407318213, 8.742801995314359, 9.717527745913477, 10.67426098847086, 11.679478805869472, 12.60456675737417, 12.550402121392171, 11.555363871311707, 10.593679676291323, 9.626721016368407, 8.693554253251783, 7.695902161124977, 6.750820730523447, 5.790585835639556, 4.866918987437062, 3.865965609013805, 2.8458165924185677, 1.966231907537741, 2.9202252355393132, 5.858213201382386, 6.8688974215511065, 7.792427452094309, 8.754862748123838, 9.723488996270605, 10.706788226292225, 11.642878830228216, 11.563619638411003, 10.549857267551427, 9.608712308111606, 8.692662787248734, 7.754220038061604, 6.783612385828279, 5.823756655583575, 4.864496425467417, 3.899091251371563, 2.9030515579204543, 1.9027990615763701, 0.9586913674964433, 1.9674434756244126, 4.879562467480702, 5.898218151560081, 6.862383273944795, 7.785655889855949, 8.823440077778008, 9.83577110542245, 10.863386570386103, 10.648732421135428, 9.661741480997158, 8.66868966193409, 7.713561096066487, 6.778070244027979, 5.844050621630555, 4.866819760571239, 3.8386221624760424, 2.8794103352491742, 1.925959452910272, 0.9566637996991176, 0.0, 1.0338184637435337, 3.885990601913773, 4.83517384596432, 5.849420991544104, 6.830574074102186, 7.879257171055716, 8.864671603572102, 9.914233752235422, 10.88368985118456, 10.571450865566991, 9.62938516202694, 8.646762712231135, 7.802269688022758, 6.794093000027504, 5.817970523597818, 4.824534663511452, 3.8363545666165164, 2.8764778576859653, 1.923544036454079, 1.0625154162061345, 2.0264641075300975, 2.9418536035537244, 3.978363922991352, 4.867022797765976, 5.93757711197178, 6.9666894282051794, 7.900825377383115, 8.871709418711443, 9.839575171785404, 10.836083947158142, 10.617452289089051, 9.64622334934939, 8.697747297600841, 7.71255513592509, 6.746790842941102, 5.807418477749576, 4.8131028924832595, 3.8256230208051165, 2.934470827613815, 2.0593441153481704, 2.9537235462571942, 1.985802834373096, 2.951447811591277, 3.9393062946084845, 5.000369025054904, 6.00537558479292, 6.983016225487161, 8.04062507842955, 9.054967695405084, 10.02077716770214, 11.04200944245012, 10.59217342180325, 9.685397235089116, 8.710262267807535, 7.71867832460378, 6.7950555030258855, 5.75140733997447, 4.819492821718162, 3.9430788604884297, 3.1336961389450493, 3.9130367683062355, 2.915066139908524, 3.8776080083494144, 4.904604616373203, 5.852480860470217, 6.904148075135783, 7.848344961183553, 8.822539274149982, 9.78208786867072, 10.738479394654679, 11.699388676100854, 11.556946262047706, 10.621476132192095, 9.70028929081086, 8.683270734845287, 7.721793325006502, 6.812819111286338, 5.8548002380476065, 4.929692832947546, 4.181989648252728, 4.940190360394373, 3.9422896414334128, 4.934267365692775, 5.857175345313503, 6.827907377953054, 7.822730119336064, 8.786781639316606, 9.760690169046223, 10.772014172052057, 11.695592583831083, 12.67485342543505, 12.56963686586868, 11.582769076277389, 10.691317817553353, 9.688106302945885, 8.717904207627964, 7.773336528983879, 6.807673976784994, 5.914913505349544, 5.142709307901925, 5.98802439756211, 4.896115528651017, 5.956998940329687, 6.86927663764648, 7.787698024038846, 8.784060643271829, 9.74991576742961, 10.704749017342602, 11.678106859506082, 12.632974061360446, 13.660334823769055, 13.512881880020755, 12.61077968626622, 11.615357082219674, 10.688156169165799, 9.693598473433306, 8.737092933161344, 7.871473889197463, 6.938756592085763, 6.112394713726892, 6.924128106500727, 5.873986258118315, 6.849976505060717, 7.813593416842746, 8.71523221324868, 9.675471819794677, 10.70524621999278, 11.731230348198803, 12.6619565663617, 13.576533034336626, 14.52158232610957, 14.542162437392134, 13.50247688855891, 12.55730817397894, 11.59444260292703, 10.635345451339855, 9.774059369485226, 8.886045522133543, 8.009163454773704, 7.083737770187923, 7.869341635738241, 6.867005657412634, 7.799402142759653, 8.750369469319727, 9.6963234418329, 10.708637190879116, 11.636848075583258, 12.680046058236249, 13.639230289453465, 14.608326862246289, 15.498662471863367, 15.502352952946126, 14.458419990122252, 13.488662219970987, 12.581739311894914, 11.609136308716982, 10.799695047938929, 9.854484814025469, 8.937208238998668, 8.081282936724422, 8.845791222548879, 7.818639428582153, 8.79222632918076, 9.731511523393602, 10.659116345412357, 11.641812007916673, 12.576217677248794, 13.543046363832723, 14.512188227185533, 15.527971593153406, 16.52064987370097, 16.350975699664993, 15.371984738735884, 14.423710531948421, 13.647286356690225, 12.677175556408411, 11.790703091211135, 10.812900857175936, 9.99966906185596, 9.090551382692421, 9.77484580114509, 8.777133791172957, 9.834401111763583, 10.777777446742439, 11.550706110506827, 12.495513920245788, 13.420939869354225, 14.37232117149473, 15.341812421422622, 16.339637476970506, 17.374053999586376, 17.316666152081766, 16.39063442518144, 15.416142419725434, 14.67755279257039, 13.737767664708953, 12.793660989968071, 11.793745133268267, 11.003376936130442, 10.045746980154663, 10.839378938442994, 9.704819424807134, 9.011652728623167, 9.986963698224994, 10.531592712610657, 11.468199145102519, 12.471795291031555, 13.414648630805555, 14.441009085708501, 15.365327215742383, 16.394973302084566, 17.401237966357336, 17.393321803045584, 16.463544703811753, 15.661788471779811, 14.709989819771588, 13.790216426927728, 12.814715891303011, 12.014689411044142, 11.063497075892936, 11.901025801664682], [11.725392520559604, 12.541597054982832, 13.579664097933618, 14.51753519282439, 15.539930485027051, 16.448840416985743, 17.403123303593674, 18.355792651069347, 18.287348364368256, 17.437380449710155, 16.491762822600148, 15.448162158429172, 14.518182473208126, 13.507720913566127, 12.564364692915893, 11.555041697882531, 10.570098815418325, 9.9776858898157, 9.002005743625539, 8.046635142206581, 10.65370676320658, 11.598726721304523, 12.555062032440384, 13.545054003682106, 14.516805185626357, 15.475011273415692, 16.429840163271955, 17.42188486757333, 17.358894925390498, 16.398329597611376, 15.465900016570249, 14.533081882756989, 13.569261596660597, 12.52248678992761, 11.561536600626008, 10.548938325209805, 9.533399004589972, 8.920027907715289, 7.952504878741244, 6.987393265906795, 9.647924975989934, 10.593652981816884, 11.597299158692953, 12.62349110891066, 13.547016930406066, 14.476993463436658, 15.43470160383379, 16.407067196928, 16.48199212675281, 15.484066635976285, 14.62754074889538, 13.567674268113889, 12.581701859034112, 11.537525318867182, 10.545396850504574, 9.609539736774627, 8.56212537994729, 7.852510079547459, 6.913836870793684, 6.039156851589869, 8.679905668394849, 9.64898900354596, 10.675620880850078, 11.608872285703704, 12.485443776123056, 13.478616908337793, 14.43550802127747, 15.358682501893721, 15.464336033267207, 14.506154973136255, 13.608319147711972, 12.605527731238595, 11.602437600295286, 10.555769640526727, 9.481582660584866, 8.555539664617523, 7.624854285070919, 6.814655547073798, 5.9483446895713, 4.998556078868753, 7.748469986470742, 8.71872300862053, 9.643931569721143, 10.661336856863475, 11.524588246371456, 12.579566482232988, 13.479930163659986, 14.409498422444102, 14.537770970375457, 13.491660363101765, 12.678753318635161, 11.652724616953243, 10.62532698670779, 9.665733623818634, 8.699670080867694, 7.740909790164081, 6.687358561315416, 5.740492521059971, 4.9352019126178535, 4.01526329522234, 6.764121232599365, 7.777961562963246, 8.704183277941056, 9.660076918253145, 10.585182055304402, 11.590489505844774, 12.527016754566974, 13.502888887319505, 13.496608093371723, 12.5538811444693, 11.67980576235417, 10.744907728709522, 9.676327168909609, 8.721325851848297, 7.77223321290004, 6.808963137827615, 5.805078629573506, 4.8046538610417855, 3.97236687412143, 3.01782073754494, 5.808948951657554, 6.79171694357468, 7.708983531570825, 8.683709282169943, 9.640442524727325, 10.645660342125938, 11.570748293630636, 12.537606894496419, 12.58918233505524, 11.627498140034856, 10.660539480111941, 9.727372716995317, 8.729720624868511, 7.7846391942669815, 6.82440429938309, 5.900737451180595, 4.899784072757339, 3.879635056162101, 2.9833754473253267, 2.0293821193237545, 4.824394737638853, 5.835078957807573, 6.758608988350774, 7.721044284380304, 8.689670532527071, 9.672969762548691, 10.609060366484682, 11.585144355671792, 11.58367573129496, 10.642530771855139, 9.726481250992267, 8.788038501805138, 7.817430849571813, 6.857575119327109, 5.898314889210951, 4.9329097151150965, 3.9368700216639883, 2.9366175253199036, 1.992509831239977, 1.0113122346351509, 3.8457440037371686, 4.864399687816547, 5.828564810201261, 6.751837426112415, 7.7896216140344725, 8.801952641678914, 9.829568106642567, 10.799813227698195, 10.69555994474069, 9.702508125677623, 8.74737955981002, 7.811888707771512, 6.877869085374089, 5.900638224314773, 4.872440626219576, 3.9132287989927077, 2.9597779166538056, 1.9904822634426513, 1.0338184637435337, 0.0, 2.852172138170239, 3.801355382220786, 4.81560252780057, 5.796755610358652, 6.845438707312182, 7.830853139828567, 8.880415288491886, 9.849871387441025, 10.76312037681761, 10.663203625770473, 9.680581175974668, 8.83608815176629, 7.827911463771038, 6.851788987341352, 5.858353127254985, 4.87017303036005, 3.910296321429499, 2.957362500197613, 1.9778274017124995, 0.9926456437865636, 1.9080351398101905, 2.944545459247818, 3.833204334022443, 4.903758648228247, 5.932870964461646, 6.867006913639582, 7.83789095496791, 8.80575670804187, 9.802265483414608, 10.855086348095673, 10.680041813092922, 9.731565761344374, 8.746373599668622, 7.780609306684635, 6.84123694149311, 5.846921356226793, 4.85944148454865, 3.9645500706456813, 2.974656100854535, 1.9199050825136603, 0.9519843706295622, 1.9176293478477429, 2.905487830864951, 3.9665505613113705, 4.971557121049386, 5.949197761743626, 7.006806614686015, 8.02114923166155, 8.986958703958607, 10.008190978706585, 11.065787534117664, 10.719215698832649, 9.744080731551067, 8.752496788347313, 7.825839669351723, 6.7821915063003075, 5.8502769880439995, 4.877371786296067, 3.8057458830740725, 2.879218304562702, 1.9461405980948412, 2.8437895446058805, 3.870786152629669, 4.818662396726683, 5.87032961139225, 6.81452649744002, 7.788720810406449, 8.748269404927187, 9.704660930911146, 10.665570212357322, 11.618116299360716, 11.655294595935628, 10.734107754554392, 9.7129780671093, 8.68723806250555, 7.738202337398345, 6.780183464159614, 5.838126962002163, 4.8385695712425, 3.9063718966508394, 2.998342593125201, 3.9004489019492414, 4.8233568815699694, 5.794088914209521, 6.78891165559253, 7.752963175573072, 8.72687170530269, 9.738195708308524, 10.66177412008755, 11.641034961691517, 12.570885974908617, 12.616587540020921, 11.68183152750947, 10.613489529057892, 9.643287433739971, 8.698719755095887, 7.733057202897001, 6.822963649059733, 5.799289230891698, 4.954205933818575, 3.9521684803428054, 4.955340903048263, 5.835458173902946, 6.753879560295313, 7.750242179528296, 8.716097303686077, 9.670930553599069, 10.64428839576255, 11.599155597616914, 12.626516360025523, 13.51413098906069, 13.536162912378227, 12.540740308331682, 11.613539395277806, 10.618981699545314, 9.662476159273352, 8.715279931068455, 7.751017881451244, 6.768974636716664, 5.890309642757193, 4.998331609735144, 5.9743218566775464, 6.779774953099212, 7.681413749505145, 8.641653356051142, 9.671427756249244, 10.69741188445527, 11.628138102618168, 12.542714570593093, 13.487763862366037, 14.535403101894234, 14.427860114670917, 13.482691400090948, 12.519825829039037, 11.560728677451863, 10.699442595597233, 9.729851564004534, 8.80784102247437, 7.740317693177696, 6.835523171994707, 6.033466260350841, 6.9237474943764825, 7.7491011913586405, 8.684062316045473, 9.680188738352285, 10.603029611839721, 11.646227594492716, 12.605411825709933, 13.574508398502756, 14.464844008119835, 15.538916761105327, 15.38380321623426, 14.414045446082994, 13.507122538006922, 12.53451953482899, 11.64350108980992, 10.69829085589646, 9.735885806699335, 8.737862859714195, 7.811972758805346, 6.98510003152036, 7.950902741081412, 8.820530563392532, 9.73905441018098, 10.721750072685296, 11.542399213505258, 12.509227900089186, 13.478369763441997, 14.49415312940987, 15.48683140995744, 16.42960217802523, 16.29736796484789, 15.349093758060429, 14.572669582802233, 13.602558782520418, 12.634509133082126, 11.656706899046927, 10.788541054582806, 9.727582326497762, 8.741027337401556, 7.943594394111163, 8.999530651927726, 9.86679648674137, 10.761930508805026, 11.706738318543987, 12.540880609976243, 13.506723183522542, 14.476214433450433, 15.474039488998317, 16.413435762802994, 17.392435013928544, 17.316017651293446, 16.34152564583744, 15.5768376256308, 14.637052497769362, 13.637467031839062, 12.637551175139258, 11.717643960716984, 10.682777923960003, 9.80556047469946, 8.871280027745339, 9.824648324578023, 10.834744081925496, 11.56541117635419, 12.502017608846051, 13.490025188298914, 14.44846709454909, 15.441474529875011, 16.399145679485915, 17.428791765828098, 18.435056430100868, 18.31870502915759, 17.388927929923756, 16.56107330484022, 15.609274652831997, 14.634022468798719, 13.658521933174002, 12.651720354849482, 11.700528019698277, 10.867207337921148], [8.948613214342624, 9.764817748765854, 10.80288479171664, 11.740755886607412, 12.687758346856814, 13.596668278815503, 14.550951165423434, 15.568019714498666, 16.443467390725075, 17.39587647274758, 18.43893942051951, 18.2632751125825, 17.333295427361456, 16.322833867719456, 15.379477647069223, 14.407213836052772, 13.422270953588566, 12.800298032669028, 11.78182966088062, 10.823889715422514, 7.8769274569896, 8.821947415087545, 9.778282726223406, 10.768274697465127, 11.66463304745612, 12.622839135245455, 13.577668025101717, 14.569712729403092, 15.515013951747317, 16.47557927952644, 17.408008860567566, 17.385254020927228, 16.421433734830842, 15.374658928097853, 14.413708738796249, 13.401110463380046, 12.385571142760213, 11.77220004588553, 10.78315930339616, 9.818047690561711, 6.871145669772955, 7.816873675599906, 8.820519852475975, 9.77131897074042, 10.694844792235829, 11.62482132526642, 12.582529465663553, 13.554895058757763, 14.539122141825457, 15.480895773289856, 16.415264082740737, 16.41984640628413, 15.433873997204355, 14.389697457037425, 13.397568988674816, 12.461711874944868, 11.41429751811753, 10.7046822177177, 9.7444912954486, 8.869811276244786, 5.90312636217787, 6.872209697328982, 7.823448742679838, 8.756700147533465, 9.633271637952818, 10.626444770167556, 11.583335883107232, 12.506510363723484, 13.544803050318873, 14.502984110449825, 15.450951820802512, 15.457699869408835, 14.454609738465528, 13.40794177869697, 12.333754798755109, 11.407711802787764, 10.47702642324116, 9.666827685244039, 8.778999114226217, 7.82921050352367, 4.971690680253763, 5.941943702403552, 6.791759431550904, 7.8091647186932365, 8.672416108201219, 9.72739434406275, 10.627758025489749, 11.557326284273865, 12.567992761614724, 13.4978107394526, 14.521385991725701, 14.504896755123482, 13.47749912487803, 12.517905761988873, 11.551842219037933, 10.593081928334321, 9.539530699485656, 8.592664659230211, 7.76585633727277, 6.8459177198772565, 3.987341926382386, 4.998735544208828, 5.852011139770817, 6.8079047800829064, 7.733009917134165, 8.738317367674536, 9.674844616396737, 10.650716749149268, 11.617304571917712, 12.560031520820136, 13.522438435444709, 13.597079866879762, 12.528499307079848, 11.573497990018536, 10.624405351070278, 9.661135275997854, 8.657250767743745, 7.656825999212025, 6.803021298776347, 5.848475162199857, 3.0321696454405744, 3.9395448054044406, 4.856811393400586, 5.831537143999704, 6.7882703865570875, 7.7934882039557, 8.718576155460399, 9.685434756326181, 10.680473006406643, 11.67284691598067, 12.705081328513916, 12.579544855165553, 11.58189276303875, 10.63681133243722, 9.67657643755333, 8.752909589350834, 7.7519562109275775, 6.73180719433234, 5.814029871980243, 4.860036543978671, 2.0476154314218737, 2.982906819637334, 3.906436850180536, 4.868872146210066, 5.8374983943568335, 6.8207976243784545, 7.7568882283144465, 8.732972217501556, 9.746734588361132, 10.687879547800954, 11.694766045998026, 11.640210639975374, 10.66960298774205, 9.709747257497346, 8.75048702738119, 7.785081853285336, 6.789042159834227, 5.788789663490142, 4.844681969410216, 3.841966659290067, 1.0689646975201899, 2.012227549646308, 2.9763926720310225, 3.899665287942176, 4.937449475864234, 5.949780503508677, 6.9773959684723295, 7.9476410895279574, 8.934632029666227, 9.927683848729295, 10.882812414596899, 10.664060845941751, 9.730041223544328, 8.752810362485011, 7.724612764389815, 6.765400937162947, 5.811950054824044, 4.84265440161289, 3.8859906019137727, 2.852172138170239, 0.0, 0.949183244050547, 1.9634303896303307, 2.9445834721884125, 3.993266569141943, 4.9786810016583285, 6.028243150321647, 7.0812332680103145, 8.145303898781375, 9.087369602321425, 10.06999205211723, 9.943673623250575, 8.896649395453789, 7.920526919024104, 6.927091058937737, 5.938910962042802, 4.888657716280624, 3.9357238950487385, 2.926815377337416, 1.9416336194114798, 0.9441369983600487, 1.9617541137094296, 2.9943926173602122, 3.917256378401706, 4.928557115026924, 5.862693064204859, 6.8335771055331875, 7.801442858607147, 8.797951633979885, 9.85077249866095, 9.956035065822256, 9.007559014073708, 8.022366852397957, 7.056602559413968, 6.117230194222443, 5.122914608956126, 4.071129136361606, 3.1217593075222743, 2.131865337731128, 1.0717390250006293, 1.900187767540677, 2.865832744758858, 3.853691227776066, 4.9147539582224855, 5.896304880239164, 6.790191516610098, 7.82960223750931, 8.774517415673563, 9.74032688797062, 10.761559162718598, 10.901985138276117, 9.967410797412322, 8.99227583013074, 7.919299112772878, 6.977673611838691, 5.934025448787276, 5.002110930530968, 4.029205728783035, 2.9575798255610413, 2.031052247049671, 2.894343995005956, 3.7919929415169955, 4.818989549540785, 5.766865793637798, 6.818533008303365, 7.762729894351135, 8.736924207317564, 9.696472801838302, 10.652864327822261, 11.613773609268437, 11.768669700597536, 10.833199570741925, 9.888932433327817, 8.864812009596267, 7.839072004992519, 6.890036279885314, 5.932017406646583, 4.989960904489132, 3.990403513729469, 3.058205839137808, 3.9465459900363156, 4.848652298860356, 5.771560278481084, 6.742292311120636, 7.737115052503645, 8.701166572484187, 9.675075102213805, 10.686399105219639, 11.609977516998665, 12.589238358602632, 12.781360304418511, 11.794492514827219, 10.83366546999644, 9.765323471544862, 8.795121376226941, 7.850553697582856, 6.88489114538397, 5.974797591546702, 4.951123173378667, 4.0991442477135465, 4.90037187725392, 5.903544299959378, 6.783661570814061, 7.702082957206428, 8.698445576439411, 9.664300700597192, 10.619133950510184, 11.592491792673664, 12.547358994528029, 13.574719756936638, 13.724058116086812, 12.687996854865197, 11.692574250818652, 10.765373337764776, 9.770815642032284, 8.814310101760322, 7.867113873555423, 6.902851823938212, 5.920808579203634, 4.951769149303853, 5.946535006646258, 6.92252525358866, 7.727978350010327, 8.62961714641626, 9.589856752962257, 10.619631153160359, 11.645615281366386, 12.576341499529283, 13.490917967504208, 14.435967259277152, 14.619379605991112, 13.579694057157887, 12.634525342577918, 11.671659771526008, 10.712562619938833, 9.851276538084203, 8.881685506491504, 7.959674964961341, 6.892151635664665, 5.8969826785413675, 6.990346246570898, 7.871950891287596, 8.697304588269755, 9.632265712956588, 10.6283921352634, 11.551233008750836, 12.594430991403831, 13.553615222621048, 14.522711795413871, 15.41304740503095, 15.579570121545103, 14.53563715872123, 13.565879388569964, 12.658956480493892, 11.68635347731596, 10.79533503229689, 9.85012479838343, 8.887719749186305, 7.889696802201164, 6.843915923454265, 7.941980017740416, 8.899106137992526, 9.768733960303647, 10.687257807092095, 11.669953469596411, 12.490602610416373, 13.457431297000301, 14.426573160353112, 15.442356526320985, 16.435034806868554, 16.42819286826397, 15.449201907334862, 14.500927700547399, 13.724503525289203, 12.754392725007389, 11.786343075569096, 10.808540841533897, 9.820484219231725, 8.75952549114668, 7.772970502050476, 8.911931856281806, 9.94773404883884, 10.814999883652485, 11.710133905716141, 12.654941715455102, 13.489084006887358, 14.454926580433657, 15.424417830361548, 16.422242885909434, 17.36163915971411, 17.393883320680743, 16.467851593780416, 15.493359588324411, 14.678396888769461, 13.738611760908023, 12.739026294977723, 11.729331824401426, 10.749587125365903, 9.714721088608922, 8.837503639348379, 9.839617489915982, 10.792985786748666, 11.80308154409614, 12.729247303612311, 13.665853736104173, 14.438228585210028, 15.40787410741957, 16.389677926786128, 17.384648352174434, 18.414294438516617, 18.408280631627953, 17.426261650275556, 16.53488443564426, 15.532023700982414, 14.58022504897419, 13.640004676551989, 12.700608668685806, 11.6836635194984, 10.732471184347196, 9.899150502570066], [9.89779645839317, 9.074736605096374, 9.990672463945918, 10.822438572514447, 11.738575102806266, 12.647485034764955, 13.601767921372886, 14.618836470448118, 15.494284146674529, 16.446693228697036, 17.489756176468966, 17.40463901137052, 16.474659326149474, 15.464197766507475, 14.520841545857241, 13.764982446209514, 12.865923563336194, 12.060332138394408, 11.201013772098534, 11.773072959473062, 8.826110701040147, 8.131866271418065, 8.950506811265143, 9.849957383372162, 10.715449803405571, 11.673655891194906, 12.628484781051169, 13.620529485352543, 14.565830707696769, 15.526396035475893, 16.458825616517018, 17.391643750330278, 17.370616978881387, 16.3238421721484, 15.362891982846795, 14.350293707430593, 13.33475438681076, 12.721383289936076, 11.732342547446706, 10.767230934612256, 7.820328913823501, 7.126792531930428, 7.88419088649649, 8.822135726689872, 9.74566154818528, 10.675638081215872, 11.633346221613005, 12.605711814707215, 13.589938897774909, 14.531712529239307, 15.46608083869019, 16.4550673173546, 16.3830572412549, 15.33888070108797, 14.346752232725361, 13.410895118995414, 12.363480762168077, 11.653865461768246, 10.693674539499147, 9.81899452029533, 6.852309606228417, 6.063991187097424, 6.87426549862929, 7.807516903482918, 8.68408839390227, 9.677261526117007, 10.634152639056683, 11.557327119672935, 12.595619806268324, 13.553800866399277, 14.501768576751964, 15.492920780479308, 15.403792982516073, 14.357125022747514, 13.282938042805654, 12.35689504683831, 11.426209667291706, 10.616010929294585, 9.728182358276763, 8.778393747574215, 5.92087392430431, 5.052999862260757, 5.842576187500357, 6.859981474642689, 7.7232328641506705, 8.778211100012202, 9.6785747814392, 10.608143040223316, 11.618809517564175, 12.548627495402052, 13.572202747675153, 14.540117666193956, 14.426682368928576, 13.467089006039421, 12.501025463088482, 11.542265172384868, 10.488713943536203, 9.541847903280757, 8.715039581323317, 7.795100963927803, 4.936525170432933, 4.049552300158281, 4.90282789572027, 5.858721536032359, 6.783826673083618, 7.789134123623988, 8.725661372346188, 9.70153350509872, 10.668121327867164, 11.610848276769588, 12.57325519139416, 13.508153225038807, 13.477682551130394, 12.522681234069085, 11.573588595120826, 10.610318520048402, 9.606434011794292, 8.606009243262571, 7.7522045428268935, 6.797658406250403, 3.981352889491122, 2.990361561353893, 3.907628149350039, 4.882353899949156, 5.83908714250654, 6.844304959905153, 7.769392911409851, 8.736251512275635, 9.731289762356099, 10.723663671930122, 11.755898084463368, 12.661690695468641, 12.531076007089297, 11.585994576487767, 10.625759681603876, 9.70209283340138, 8.701139454978126, 7.680990438382887, 6.76321311603079, 5.809219788029218, 2.996798675472421, 2.0337235755867864, 2.9572536061299886, 3.9196889021595185, 4.888315150306286, 5.871614380327907, 6.807704984263899, 7.783788973451009, 8.797551344310584, 9.738696303750405, 10.745582801947478, 11.722356480278462, 11.618786231792598, 10.658930501547895, 9.699670271431737, 8.734265097335882, 7.738225403884774, 6.73797290754069, 5.793865213460763, 4.791149903340614, 2.018147941570737, 1.0630443055957608, 2.027209427980475, 2.950482043891629, 3.988266231813687, 5.000597259458129, 6.028212724421781, 6.998457845477409, 7.985448785615679, 8.978500604678747, 9.93362917054635, 10.869120022584857, 10.679224467594876, 9.70199360653556, 8.673796008440362, 7.714584181213494, 6.761133298874592, 5.7918376456634375, 4.83517384596432, 3.801355382220786, 0.949183244050547, 0.0, 1.0142471455797837, 1.9954002281378656, 3.044083325091396, 4.029497757607781, 5.0790599062711, 6.132050023959767, 7.1961206547308265, 8.138186358270877, 9.120808808066682, 10.177354576844133, 9.845832639504335, 8.86971016307465, 7.876274302988284, 6.888094206093348, 5.837840960331171, 4.884907139099285, 3.8759986213879625, 2.890816863462027, 1.8933202424105957, 1.0125708696588827, 2.0452093733096652, 2.968073134351159, 3.9793738709763766, 4.913509820154313, 5.884393861482641, 6.8522596145566, 7.848768389929338, 8.901589254610403, 9.955832036036197, 9.956742258124255, 8.971550096448503, 8.005785803464516, 7.066413438272991, 6.0720978530066745, 5.020312380412153, 4.070942551572822, 3.0810485817816753, 2.0209222690511766, 2.849371011591224, 2.086436059569711, 2.9729258764671567, 4.016235984860588, 4.9471216361886166, 5.841008272559551, 6.880418993458764, 7.825334171623016, 8.791143643920073, 9.812375918668051, 10.86997247407913, 10.91659404146287, 9.941459074181289, 8.868482356823424, 7.926856855889238, 6.883208692837822, 5.951294174581514, 4.978388972833582, 3.9067630696115883, 2.980235491100218, 3.843527239056503, 3.0125962563278486, 3.960353448328804, 4.9082296924258175, 5.940266419555637, 6.848056792444014, 7.8222511054104436, 8.781799699931183, 9.738191225915141, 10.699100507361317, 11.651646594364712, 11.782382814792474, 10.838115677378365, 9.813995253646816, 8.788255249043067, 7.839219523935862, 6.881200650697131, 5.93914414853968, 4.939586757780017, 4.007389083188356, 4.895729234086863, 4.069255613671209, 4.912924177269104, 5.883656209908655, 6.878478951291664, 7.786493470577066, 8.760402000306684, 9.771726003312518, 10.695304415091545, 11.674565256695512, 12.604416269912612, 12.743675758877767, 11.782848714046988, 10.71450671559541, 9.74430462027749, 8.799736941633403, 7.834074389434518, 6.923980835597249, 5.900306417429214, 5.048327491764094, 5.849555121304467, 5.124147614770231, 5.9250254696020805, 6.843446855994447, 7.8398094752274305, 8.802201501540468, 9.72979258127463, 10.70315042343811, 11.63268589262091, 12.660046655029518, 13.547661284064686, 13.637180098915746, 12.6417574948692, 11.714556581815325, 10.71999888608283, 9.763493345810868, 8.816297117605972, 7.85203506798876, 6.869991823254181, 5.900952393354401, 6.895718250696806, 6.1792931848226464, 6.869342248798347, 7.770981045204279, 8.731220651750276, 9.760995051948377, 10.75627391213083, 11.687000130293729, 12.576244865597088, 13.521294157370033, 14.56893339689823, 14.528877301208436, 13.583708586628466, 12.620843015576554, 11.66174586398938, 10.800459782134752, 9.830868750542052, 8.908858209011887, 7.8413348797152125, 6.846165922591915, 7.939529490621446, 7.1287188225215825, 7.838668487057776, 8.773629611744607, 9.769756034051419, 10.692596907538855, 11.705089622168275, 12.664273853385492, 13.608038693506751, 14.49837430312383, 15.572447056109322, 15.484820402771778, 14.515062632620513, 13.608139724544438, 12.635536721366506, 11.744518276347439, 10.799308042433978, 9.836902993236851, 8.838880046251711, 7.793099167504812, 8.891163261790965, 8.155874069226511, 8.910097859091668, 9.828621705880114, 10.81131736838443, 11.631966509204391, 12.59879519578832, 13.56793705914113, 14.583720425109004, 15.520361704961434, 16.463132473029226, 16.39838515138541, 15.450110944597947, 14.67368676933975, 13.703575969057935, 12.735526319619645, 11.757724085584446, 10.769667463282273, 9.708708735197229, 8.722153746101023, 9.861115100332354, 9.204501980072825, 9.956363782440505, 10.85149780450416, 11.79630561424312, 12.630447905675377, 13.596290479221675, 14.565781729149567, 15.56360678469745, 16.44696605780699, 17.42596530893254, 17.417034837830965, 16.442542832374958, 15.543049087847715, 14.603263959986277, 13.687376869461097, 12.678515068451974, 11.69877036941645, 10.66390433265947, 9.786686883398927, 10.78880073396653, 10.17422324731332, 11.01723586624158, 11.87061120240033, 12.807217634892192, 13.579592483998047, 14.549238006207588, 15.531041825574144, 16.526012250962452, 17.518663338187594, 17.45909738757741, 16.47707840622501, 15.585701191593708, 14.582840456931866, 13.631041804923642, 12.69082143250144, 11.810471260423643, 10.930074523378492, 10.087489524225283, 10.848333746620614], [10.711199862432956, 9.785761049029922, 8.976425318366134, 9.808191426934664, 10.724327957226482, 11.633237889185171, 12.587520775793102, 13.604589324868334, 14.480037001094745, 15.43244608311725, 16.47550903088918, 16.432224146050824, 15.502244460829779, 14.49178290118778, 13.548426680537546, 12.792567580889814, 11.893508698016495, 11.087917273074707, 11.889515897875102, 12.664902840270699, 9.639514105079932, 8.842890715351613, 7.936259665685359, 8.83571023779238, 9.701202657825787, 10.659408745615123, 11.614237635471385, 12.60628233977276, 13.551583562116985, 14.512148889896109, 15.444578470937236, 16.377396604750498, 16.496601526431398, 15.488974207185553, 14.596082221478987, 13.79867095356254, 12.930208508844848, 12.145575255175117, 12.74658969302649, 11.709146109334359, 8.633732317863286, 7.8378169758639755, 6.869943740916706, 7.807888581110089, 8.731414402605497, 9.661390935636089, 10.619099076033221, 11.591464669127431, 12.575691752195125, 13.517465383659523, 14.451833693110405, 15.440820171774819, 16.47794347622174, 16.353127846667753, 15.360999378305145, 14.425142264575198, 13.377727907747861, 12.66811260734803, 11.707921685078931, 10.809762622531675, 7.665713010268201, 6.775015631030972, 5.860018353049506, 6.7932697579031345, 7.669841248322486, 8.663014380537224, 9.6199054934769, 10.543079974093152, 11.58137266068854, 12.539553720819493, 13.487521431172182, 14.478673634899526, 15.52748978717863, 15.371372168327298, 14.297185188385438, 13.371142192418095, 12.44045681287149, 11.63025807487437, 10.742429503856547, 9.792640893154, 6.734277328344094, 5.764024306194305, 4.828329041920573, 5.845734329062905, 6.7089857185708865, 7.763963954432418, 8.664327635859417, 9.593895894643532, 10.604562371984391, 11.534380349822271, 12.55795560209537, 13.525870520614173, 14.51148645705712, 14.481336151619205, 13.515272608668266, 12.556512317964652, 11.502961089115987, 10.556095048860541, 9.729286726903101, 8.809348109507587, 5.877317737223921, 4.870605052493054, 3.888580750140486, 4.844474390452575, 5.769579527503834, 6.774886978044204, 7.711414226766405, 8.687286359518938, 9.653874182287382, 10.596601131189805, 11.559008045814378, 12.493906079459025, 13.562486639258939, 13.536928379648868, 12.58783574070061, 11.624565665628186, 10.620681157374076, 9.620256388842355, 8.766451688406677, 7.811905551830187, 4.922145456282109, 3.882511248364323, 2.893381003770255, 3.868106754369373, 4.824839996926756, 5.830057814325369, 6.7551457658300675, 7.722004366695851, 8.717042616776315, 9.70941652635034, 10.741650938883586, 11.647443549888859, 12.658920820412195, 12.600241722067551, 11.64000682718366, 10.716339978981164, 9.71538660055791, 8.69523758396267, 7.777460261610574, 6.8234669336090015, 3.960076005455613, 2.925873262597216, 1.9430064605502049, 2.9054417565797346, 3.874068004726502, 4.857367234748123, 5.793457838684115, 6.769541827871225, 7.783304198730801, 8.724449158170623, 9.731335656367696, 10.70810933469868, 11.678716986932004, 11.673177647127678, 10.71391741701152, 9.748512242915666, 8.752472549464558, 7.752220053120474, 6.808112359040547, 5.8053970489203985, 3.0323950871505208, 1.9909862078175657, 1.0129622824006916, 1.9362348983118456, 2.9740190862339038, 3.986350113878346, 5.013965578841999, 5.984210699897627, 6.971201640035897, 7.9642534590989635, 8.919382024966566, 9.854872877005073, 10.788892499402497, 10.716240752115343, 9.688043154020146, 8.728831326793278, 7.775380444454376, 6.806084791243221, 5.849420991544104, 4.8156025278005705, 1.9634303896303307, 1.0142471455797837, 0.0, 0.981153082558082, 2.0298361795116127, 3.015250612027998, 4.064812760691317, 5.117802878379984, 6.181873509151044, 7.123939212691095, 8.1065616624869, 9.16310743126435, 10.210131659061137, 9.883957308654434, 8.890521448568068, 7.902341351673132, 6.852088105910955, 5.899154284679069, 4.890245766967746, 3.9050640090418107, 2.9075673879903796, 2.0268180152386663, 1.0727945079899652, 1.9538259887713756, 2.965126725396593, 3.899262674574529, 4.870146715902857, 5.8380124689768165, 6.834521244349554, 7.8873421090306195, 8.941584890456413, 9.890060942204961, 9.985797242028285, 9.020032949044298, 8.080660583852772, 7.086344998586457, 6.034559525991936, 5.085189697152605, 4.095295727361458, 3.03516941463096, 3.863618157171008, 2.9883694941646644, 2.0005110111474567, 3.0019888392808043, 3.932874490608833, 4.8267611269797674, 5.86617184787898, 6.811087026043232, 7.776896498340289, 8.798128773088267, 9.855725328499346, 10.821073111360045, 10.955706219761073, 9.882729502403208, 8.941104001469022, 7.897455838417606, 6.965541320161298, 5.992636118413366, 4.921010215191372, 3.9944826366800017, 4.857774384636287, 3.914529690922802, 2.987938583009104, 3.935814827106118, 4.926019273975854, 5.83380964686423, 6.80800395983066, 7.767552554351399, 8.723944080335357, 9.684853361781533, 10.637399448784928, 11.572869578640539, 11.852362822958149, 10.8282423992266, 9.80250239462285, 8.853466669515646, 7.8954477962769145, 6.953391294119464, 5.953833903359801, 5.0216362287681395, 5.909976379666647, 4.886679901565262, 3.9405093119494037, 4.911241344588956, 5.906064085971965, 6.772246324997282, 7.7461548547269, 8.757478857732734, 9.681057269511761, 10.660318111115728, 11.590169124332828, 12.534162522725833, 12.797095859626772, 11.728753861175194, 10.758551765857273, 9.813984087213187, 8.848321535014302, 7.938227981177033, 6.914553563008998, 5.9891200585550814, 6.863802266884251, 5.941571902664284, 4.9526106042823805, 5.871031990674748, 6.867394609907731, 7.787954355960683, 8.715545435694846, 9.688903277858326, 10.618438747041125, 11.645799509449734, 12.533414138484902, 13.569475399706517, 13.656004640448984, 12.728803727395109, 11.734246031662614, 10.777740491390652, 9.830544263185756, 8.866282213568544, 7.884238968833965, 6.841744960145388, 7.88198417930046, 6.905993932358058, 5.896927383478646, 6.79856617988458, 7.758805786430577, 8.78858018662868, 9.742026766551046, 10.672752984713945, 11.561997720017304, 12.507047011790249, 13.554686251318445, 14.59437180015167, 14.59795573220825, 13.635090161156338, 12.675993009569163, 11.814706927714536, 10.845115896121836, 9.837672930900252, 8.770149601603578, 7.737645575142806, 8.831359371419083, 7.817220948298149, 6.866253621738075, 7.801214746424908, 8.797341168731721, 9.720182042219157, 10.690842476588491, 11.650026707805708, 12.593791547926967, 13.484127157544046, 14.558199910529538, 15.602132873353412, 15.529309778200297, 14.622386870124222, 13.64978386694629, 12.673022106742442, 11.727811872828982, 10.67112853618577, 9.669941051644399, 8.606502571544596, 9.782993142588602, 8.844376195003079, 7.9376829937719675, 8.856206840560414, 9.83890250306473, 10.659551643884694, 11.626380330468622, 12.59552219382143, 13.611305559789304, 14.50611455938165, 15.448885327449442, 16.427876288378553, 16.464358090177733, 15.600689450996533, 14.649608922707035, 13.632061779107897, 12.591958908888671, 11.583070867322057, 10.522112139237013, 9.535557150140807, 10.75294498112999, 9.893004105849393, 8.983948917120804, 9.87908293918446, 10.823890748923422, 11.65803304035568, 12.623875613901978, 13.59336686382987, 14.591191919377753, 15.432718912227205, 16.411718163352756, 16.46551863850937, 15.472617646935957, 14.52880194226793, 13.589016814406493, 12.673129723881313, 11.817194872878606, 10.96703342782736, 11.477307736699254, 10.60009028743871, 11.680630614764167, 10.862725373089887, 10.044821000921878, 10.89819633708063, 11.834802769572493, 12.60717761867835, 13.57682314088789, 14.558626960254447, 15.553597385642755, 16.50441619260781, 16.44485024199762, 15.462831260645226, 14.571454046013924, 13.568593311352082, 12.616794659343858, 11.676574286921657, 10.796224114843861, 9.915827377798708, 10.79851396815883, 11.661737150660398], [11.623969798580756, 10.698530985177722, 9.889195254513934, 8.939333692649729, 9.758859715923716, 10.667769647882405, 11.622052534490336, 12.639121083565568, 13.51456875979198, 14.466977841814485, 15.510040789586416, 15.48762745883145, 14.557647773610405, 13.547186213968406, 12.614690059778372, 11.858830960130641, 10.959772077257321, 11.888976250128692, 12.834499938904862, 13.612081316711532, 10.552284041227733, 9.755660651499413, 8.84902960183316, 7.966852503507445, 8.735734416523021, 9.693940504312357, 10.64876939416862, 11.640814098469994, 12.58611532081422, 13.546680648593343, 14.47911022963447, 15.41192836344773, 15.552004839212026, 14.54437751996618, 13.662345600719814, 12.864934332803367, 11.996471888085674, 12.946634232229103, 13.723053579138519, 12.656324585775193, 9.546502254011086, 8.750586912011775, 7.782713677064505, 6.939030846825154, 7.765946161302731, 8.695922694333323, 9.653630834730455, 10.625996427824665, 11.610223510892359, 12.551997142356758, 13.48636545180764, 14.475351930472053, 15.512475234918975, 15.529338991026608, 14.68742887963594, 13.804332921238545, 12.967745512728357, 13.649265689906112, 12.689074767637011, 11.75694109897251, 8.578482946416, 7.687785567178771, 6.7727882891973055, 5.924412023618199, 6.70437300701972, 7.697546139234458, 8.654437252174134, 9.577611732790386, 10.615904419385775, 11.574085479516727, 12.522053189869416, 13.51320539359676, 14.562021545875865, 15.524982532163579, 15.278338270943522, 14.352295274976177, 13.421609895429572, 12.611411157432451, 11.723582586414627, 10.773793975712081, 7.647047264491893, 6.676794242342104, 5.741098978068372, 4.97687659477797, 5.743517477268121, 6.798495713129652, 7.698859394556651, 8.628427653340767, 9.639094130681626, 10.568912108519505, 11.592487360792605, 12.560402279311408, 13.546018215754355, 14.569825251859765, 14.496425691226346, 13.537665400522734, 12.484114171674069, 11.537248131418623, 10.710439809461182, 9.790501192065669, 6.790087673371721, 5.783374988640853, 4.801350686288285, 3.9756166561676403, 4.804111286201068, 5.8094187367414385, 6.745945985463639, 7.721818118216172, 8.688405940984616, 9.63113288988704, 10.593539804511613, 11.52843783815626, 12.597018397956173, 13.609598001783304, 13.56898882325869, 12.605718748186266, 11.601834239932158, 10.601409471400437, 9.747604770964758, 8.793058634388268, 5.834915392429909, 4.795281184512122, 3.806150939918054, 2.986611502851316, 3.8593717556239904, 4.864589573022603, 5.789677524527302, 6.756536125393085, 7.751574375473548, 8.743948285047574, 9.77618269758082, 10.681975308586093, 11.69345257910943, 12.638534009710959, 12.621159909741742, 11.697493061539246, 10.696539683115992, 9.676390666520753, 8.758613344168655, 7.804620016167084, 4.872845941603412, 3.8386431987450154, 2.855776396698004, 1.939973515276969, 2.9085997634237364, 3.8918989934453574, 4.827989597381349, 5.804073586568459, 6.817835957428035, 7.758980916867857, 8.76586741506493, 9.742641093395914, 10.713248745629238, 11.673104475873942, 11.695070499569603, 10.729665325473748, 9.73362563202264, 8.733373135678555, 7.789265441598628, 6.78655013147848, 3.976469568826272, 2.903756143965365, 1.9257322185484909, 0.9550818157537635, 1.9928660036758215, 3.0051970313202636, 4.032812496283916, 5.003057617339544, 5.990048557477814, 6.983100376540881, 7.938228942408483, 8.873719794446991, 9.807739416844415, 10.784970277903732, 10.669196236578228, 9.70998440935136, 8.756533527012458, 7.787237873801303, 6.830574074102185, 5.796755610358652, 2.9445834721884125, 1.9954002281378656, 0.981153082558082, 0.0, 1.0486830969535306, 2.034097529469916, 3.083659678133235, 4.136649795821902, 5.200720426592962, 6.142786130133013, 7.125408579928818, 8.181954348706268, 9.228978576503053, 10.205101052932738, 9.871674531126148, 8.883494434231213, 7.833241188469037, 6.880307367237151, 5.8713988495258285, 4.886217091599892, 3.8887204705484613, 3.007971097796748, 2.043227220419097, 0.9726729062132935, 1.983973642838511, 2.918109592016447, 3.888993633344775, 4.856859386418734, 5.853368161791472, 6.906189026472537, 7.960431807898331, 8.90890785964688, 9.89410002132263, 10.00118603160238, 9.061813666410854, 8.067498081144539, 7.015712608550018, 6.066342779710687, 5.07644880991954, 4.016322497189042, 4.84477123972909, 3.9588022065937967, 2.970943723576589, 2.020835756722722, 2.951721408050751, 3.8456080444216854, 4.885018765320898, 5.82993394348515, 6.795743415782207, 7.816975690530185, 8.874572245941264, 9.839920028801963, 10.815054996083544, 10.831242133723945, 9.889616632789759, 8.845968469738343, 7.914053951482035, 6.941148749734103, 5.869522846512109, 4.942995268000739, 5.8389274671943685, 4.884962403351934, 3.94995445044396, 3.0020782063469458, 3.944866191417771, 4.852656564306148, 5.8268508772725776, 6.786399471793317, 7.742790997777274, 8.703700279223451, 9.656246366226846, 10.591716496082457, 11.535983633496565, 11.753371602724343, 10.727631598120594, 9.778595873013389, 8.820576999774659, 7.878520497617209, 6.878963106857546, 5.9467654322658845, 6.891129462224728, 5.848695769000119, 4.90252517938426, 3.9775047238297834, 4.967970719873119, 5.7910932424392, 6.765001772168818, 7.7763257751746515, 8.699904186953678, 9.679165028557646, 10.609016041774746, 11.55300944016775, 12.527012160239059, 12.653883064672938, 11.683680969355017, 10.739113290710932, 9.773450738512047, 8.863357184674777, 7.839682766506743, 6.901889994702881, 7.8449553494423325, 6.903587770099141, 5.914626471717237, 4.937295369915575, 5.933657989148559, 6.806801273402601, 7.734392353136765, 8.707750195300246, 9.637285664483041, 10.66464642689165, 11.55226105592682, 12.588322317148435, 13.56767715063746, 13.653932930892852, 12.65937523516036, 11.702869694888397, 10.755673466683499, 9.791411417066287, 8.809368172331709, 7.7545148962931885, 8.844000046735317, 7.868009799792915, 6.858943250913503, 5.864829559125408, 6.825069165671405, 7.8548435658695075, 8.760873683992966, 9.691599902155865, 10.58084463745922, 11.525893929232165, 12.573533168760362, 13.613218717593586, 14.509628242396726, 14.560219364654083, 13.601122213066908, 12.739836131212279, 11.77024509961958, 10.75044286704805, 9.682919537751376, 8.650415511290605, 9.778537847859917, 8.764399424738983, 7.813432098178909, 6.867478125665736, 7.863604547972549, 8.786445421459986, 9.709689394030411, 10.668873625247628, 11.612638465368883, 12.502974074985962, 13.577046827971454, 14.620979790795328, 15.440982288388772, 15.547516073621967, 14.574913070444035, 13.585792042890242, 12.640581808976782, 11.583898472333571, 10.582710987792199, 9.519272507692396, 10.730171619029436, 9.78936023603284, 8.850075041819998, 7.922470219801242, 8.905165882305557, 9.725815023125522, 10.647697234636873, 11.616839097989683, 12.632622463957556, 13.524961476823567, 14.467732244891359, 15.446723205820467, 15.499581293410204, 14.635221209693768, 13.68414068140427, 12.710619381335484, 11.929181414686001, 12.495840803469857, 11.434882075384813, 10.448327086288607, 11.700123457570825, 10.837988146879153, 9.895955454113484, 8.945346318425287, 9.890154128164248, 10.724296419596508, 11.648767492296267, 12.618258742224159, 13.616083797772042, 14.451565829669121, 15.430565080794674, 15.500050397206603, 14.507149405633191, 13.563333700965165, 12.623548573103728, 11.707661482578548, 10.94833713859367, 11.87980336397516, 12.390077672847054, 11.512860223586511, 12.627809091205002, 11.807709414119648, 10.946577323292798, 9.964459716321457, 10.90106614881332, 11.673440997919178, 12.606440032985443, 13.583518838648736, 14.578489264037044, 15.523263110049724, 15.479382000694855, 14.49736301934246, 13.605985804711159, 12.603125070049316, 11.651326418041092, 10.711106045618891, 9.927366380558926, 10.828597313946508, 11.71128390430663, 12.574507086808199], [12.672652895534286, 11.747214082131254, 10.839182543600687, 9.884185994084387, 8.901491759952215, 9.810401691910904, 10.764684578518835, 11.78070896436471, 12.625338281299856, 13.577747363322361, 14.620810311094292, 14.43894436187792, 13.508964676656875, 12.498503117014875, 11.571231288209432, 11.116828709942784, 11.846981191369837, 12.776185364241208, 13.721709053017376, 14.499290430824047, 11.600967138181263, 10.804343748452945, 9.897712698786687, 8.911704804942103, 7.87836646055152, 8.836572548340856, 9.770898166439167, 10.75158361997787, 11.696884842322095, 12.65745017010122, 13.589879751142346, 14.522697884955607, 14.503321742258496, 13.49569442301265, 12.618886829150874, 12.12293208261551, 12.88368100219819, 13.833843346341618, 14.610262693251032, 13.543533699887707, 10.595185350964616, 9.799270008965307, 8.831396774018035, 7.907457286797938, 6.90857820533123, 7.838554738361821, 8.775759607001003, 9.736765949332542, 10.720993032400235, 11.662766663864634, 12.597134973315516, 13.584481388893728, 14.62160469334065, 14.480655894073077, 13.643970108067, 13.062330671050688, 13.854954626840872, 14.64114174666382, 13.641298555463932, 12.644150213085023, 9.627166043369531, 8.736468664132303, 7.8214713861508365, 6.892838463590984, 5.847005051048219, 6.840178183262957, 7.776566024444682, 8.688381254298262, 9.726673940893651, 10.684855001024603, 11.631182648291091, 12.622334852018435, 13.67115100429754, 14.579527719776657, 14.707784297986708, 14.117354364113499, 14.423194265186945, 13.606690083167296, 12.67931792527671, 11.700657143454519, 8.695730361445424, 7.725477339295635, 6.789782075021903, 5.945303034750754, 4.88614952129662, 5.941127757158152, 6.809628916064527, 7.739197174848643, 8.749863652189502, 9.678041566941179, 10.70161681921428, 11.669531737733083, 12.619386026585762, 13.624370439472843, 14.511841113146556, 14.539249770280106, 13.485698541431441, 12.538832501175996, 11.687137046135877, 10.756392726682012, 7.838770770325251, 6.832058085594384, 5.850033783241816, 4.9684309590182565, 3.946743330229567, 4.952050780769938, 5.856715506971516, 6.832587639724048, 7.799175462492492, 8.740262348308715, 9.702669262933288, 10.637567296577934, 11.67038620878758, 12.664143189396382, 13.584404245178902, 13.60730311794364, 12.60341860968953, 11.60299384115781, 10.743152342714309, 9.778026471606822, 6.88359848938344, 5.843964281465653, 4.854834036871585, 3.991401120326077, 3.0020037996524898, 4.007221617051103, 4.900447046035178, 5.867305646900961, 6.862343896981424, 7.813879343874271, 8.846113756407517, 9.75190636741279, 10.723779664746482, 11.668861095348012, 12.590534931928053, 12.72984889598775, 11.700208260337634, 10.677975036278125, 9.754160915918206, 8.800167587916635, 5.921529038556943, 4.887326295698546, 3.904459493651535, 2.9886566122305, 2.0512318074522358, 2.961830052272055, 3.897920656208047, 4.874004645395157, 5.887767016254733, 6.828911975694554, 7.835798473891627, 8.81257215222261, 9.743575831266291, 10.703431561510994, 11.664445521755914, 11.77027814747552, 10.737294209244283, 9.734957505435927, 8.790849811356, 7.782097703228032, 5.025152665779803, 3.9524392409188955, 2.9744153155020214, 2.003764912707294, 1.0169001598799439, 2.0292311875243865, 3.007083616617649, 3.977328737673277, 4.964319677811547, 5.957371496874614, 6.912500062742216, 7.847990914780724, 8.782010537178147, 9.759241398237464, 10.78743899633266, 10.758667506304889, 9.805216623965986, 8.835920970754833, 7.879257171055715, 6.845438707312182, 3.993266569141943, 3.044083325091396, 2.0298361795116127, 1.0486830969535306, 0.0, 0.9854144325163852, 2.034976581179704, 3.087966698868371, 4.15203732963943, 5.094103033179481, 6.076725482975286, 7.133271251752737, 8.180295479549521, 9.156417955979206, 10.149853816065573, 9.932177531184744, 8.881924285422567, 7.928990464190681, 6.920081946479359, 5.9349001885534225, 4.937403567501992, 4.056654194750279, 3.034957176324183, 1.9644028621183796, 0.9352905458849804, 1.8694264950629162, 2.840310536391245, 3.8081762894652047, 4.804685064837943, 5.857505929519009, 6.911748710944803, 7.860224762693351, 8.845416924369102, 9.81118121735309, 10.110496763364386, 9.11618117809807, 8.06439570550355, 7.115025876664218, 6.125131906873071, 5.065005594142573, 5.89345433668262, 4.950532162498883, 3.962673679481675, 2.908044870835236, 1.9030383110972204, 2.7969249474681552, 3.8363356683673677, 4.78125084653162, 5.747060318828677, 6.768292593576655, 7.825889148987734, 8.791236931848433, 9.766371899130014, 10.783068699015768, 10.93829972974329, 9.894651566691875, 8.962737048435567, 7.989831846687634, 6.91820594346564, 5.99167836495427, 6.83447503894392, 5.864160172580263, 4.837163564556474, 3.88928732045946, 2.8961830944642406, 3.803973467352618, 4.778167780319047, 5.737716374839787, 6.694107900823744, 7.655017182269921, 8.607563269273315, 9.543033399128927, 10.487300536543035, 11.511420960274585, 11.776314695074126, 10.82727896996692, 9.86926009672819, 8.92720359457074, 7.927646203811076, 6.995448529219415, 7.797140730646703, 6.7359048831126325, 5.789734293496774, 4.864713837942298, 3.9192876229195877, 4.74241014548567, 5.7163186752152875, 6.727642678221121, 7.651221090000148, 8.630481931604116, 9.560332944821216, 10.50432634321422, 11.478329063285528, 12.540529043530686, 12.732364066308548, 11.787796387664464, 10.822133835465578, 9.912040281628308, 8.888365863460272, 7.950573091656412, 8.750966617864307, 7.790796884211654, 6.801835585829751, 5.82450448402809, 4.921068428905039, 5.758118176449071, 6.685709256183235, 7.659067098346716, 8.588602567529511, 9.615963329938118, 10.50357795897329, 11.539639220194905, 12.51899405368393, 13.446194966737805, 13.708058332113891, 12.75155279184193, 11.804356563637029, 10.840094514019817, 9.85805126928524, 8.803197993246718, 9.73120916084783, 8.755218913905429, 7.746152365026017, 6.752038673237922, 5.960714104013318, 6.811384794300568, 7.712190587039435, 8.642916805202335, 9.53216154050569, 10.477210832278635, 11.524850071806831, 12.564535620640056, 13.460945145443196, 14.492655593713417, 14.64980531002044, 13.78851922816581, 12.818928196573108, 11.79912596400158, 10.731602634704906, 9.699098608244135, 10.665746961972431, 9.651608538851496, 8.700641212291423, 7.75468723977825, 6.999249486314462, 7.742986649891046, 8.66100629707688, 9.620190528294097, 10.563955368415353, 11.454290978032432, 12.528363731017922, 13.572296693841796, 14.392299191435242, 14.843400298517578, 13.894811973124197, 12.844259468636189, 13.689264905930312, 12.632581569287101, 11.631394084745729, 10.567955604645926, 11.61738073314195, 10.676569350145353, 9.737284155932512, 8.809679333913756, 8.050346258672601, 8.682356251556582, 9.599014137683342, 10.56815600103615, 11.583939367004024, 12.476278379870037, 13.419049147937828, 14.398040108866937, 14.642213337438703, 13.777853253722267, 12.826772725432768, 11.853251425363982, 12.840832273275675, 13.544523900423387, 12.483565172338343, 11.497010183242137, 12.587332571683339, 11.725197260991667, 10.783164568225999, 9.832555432537802, 9.110964242919232, 9.680837648027568, 10.600084395342737, 11.569575645270628, 12.567400700818512, 13.402882732715591, 14.381881983841144, 14.61081991871448, 13.64978144966169, 12.705965744993664, 11.766180617132227, 10.850293526607047, 11.859987997183344, 12.829790653061913, 13.438760769800584, 12.561543320540041, 13.515018205317515, 12.694918528232161, 11.833786437405314, 10.851668830433972, 10.159063898625462, 10.629982226350238, 11.557756936031913, 12.534835741695206, 13.529806167083514, 14.474580013096194, 14.590151522202731, 13.608132540850336, 12.7475736855103, 11.745757114077815, 10.793958462069591, 9.85373808964739, 10.867354953109919, 11.778584603033261, 12.729776938184466, 13.623190183761729], [13.65806732805067, 12.712977430453583, 11.751257553056275, 10.796261003539975, 9.813566769407803, 8.987349280126173, 9.831541719579997, 10.798886498978856, 11.643515815914002, 12.595924897936507, 13.638987845708439, 13.570762430504022, 12.640782745282976, 11.630321185640977, 10.703049356835532, 11.712372351868893, 12.764158685199256, 13.693362858070627, 14.692715289854613, 15.484704863340433, 12.586381570697647, 11.770107096775273, 10.813771785639412, 9.82377981439769, 8.790441470007108, 8.013520136556124, 8.789075701053315, 9.769761154592016, 10.715062376936242, 11.675627704715366, 12.608057285756493, 13.540875419569753, 13.635139810884597, 12.62751249163875, 11.750704897776973, 12.71847572454162, 13.782868227162888, 14.748947067633576, 15.595677125767418, 14.528948132404093, 11.580599783481, 10.78468444148169, 9.816811206534421, 8.819532296253525, 7.820653214786817, 7.01550232657709, 7.79393714161515, 8.754943483946688, 9.739170567014382, 10.68094419847878, 11.615312507929662, 12.602658923507875, 13.639782227954797, 13.612473962699179, 12.7757881766931, 13.657874312976798, 14.705288669804135, 15.626556179180206, 14.626712987980317, 13.629564645601409, 10.612580475885915, 9.721883096648687, 8.806885818667222, 7.804913473046571, 6.759080060503806, 6.017125771478226, 6.794743559058828, 7.7065587889124085, 8.744851475507797, 9.70303253563875, 10.649360182905237, 11.640512386632581, 12.689328538911687, 13.594113287260274, 13.839602366612807, 14.712898006039609, 15.408608697703329, 14.592104515683681, 13.664732357793095, 12.686071575970905, 9.681144793961808, 8.710891771812019, 7.775196507538288, 6.8573780442063414, 5.798224530752207, 4.977150787094564, 5.827806450678674, 6.757374709462789, 7.768041186803647, 8.696219101555325, 9.719794353828426, 10.68770927234723, 11.63397159406938, 12.63895600695646, 13.526426680630173, 14.50815270106436, 14.471112973947825, 13.52424693369238, 12.672551478652261, 11.741807159198396, 8.824185202841637, 7.817472518110769, 6.835448215758201, 5.880505968473844, 4.858818339685154, 3.98807381070635, 4.874893041585662, 5.8507651743381945, 6.817352997106639, 7.758439882922861, 8.720846797547434, 9.65574483119208, 10.684971776271198, 11.67872875688, 12.59898981266252, 13.524660999077698, 13.588833042205914, 12.588408273674194, 11.728566775230693, 10.763440904123206, 7.869012921899825, 6.829378713982038, 5.84024846938797, 4.903476129781664, 3.914078809108077, 3.0432446469875147, 3.9186245806493245, 4.885483181515108, 5.880521431595571, 6.832056878488418, 7.8642912910216625, 8.770083902026936, 9.7383652322301, 10.68344666283163, 11.60512049941167, 12.570335042513719, 12.685622692854018, 11.66338946879451, 10.73957534843459, 9.785582020433019, 6.906943471073328, 5.872740728214931, 4.88987392616792, 3.9319330650545905, 2.963306816907823, 1.9800075868862022, 2.916098190822194, 3.892182180009304, 4.905944550868879, 5.847089510308701, 6.853976008505773, 7.830749686836757, 8.758161398749909, 9.718017128994612, 10.679031089239531, 11.730147343133492, 11.722708641760667, 10.720371937952311, 9.776264243872385, 8.767512135744415, 6.010567098296189, 4.937853673435281, 3.959829748018407, 2.9891793452236795, 2.002314592396329, 1.0474087221385333, 2.021669184101264, 2.991914305156892, 3.978905245295162, 4.971957064358229, 5.9270856302258315, 6.862576482264339, 7.796596104661763, 8.77382696572108, 9.802024563816277, 10.761236391043145, 10.790631056482376, 9.82133540327122, 8.864671603572102, 7.830853139828568, 4.9786810016583285, 4.029497757607782, 3.015250612027998, 2.034097529469916, 0.9854144325163852, 0.0, 1.0495621486633189, 2.102552266351986, 3.166622897123046, 4.108688600663097, 5.091311050458902, 6.1478568192363525, 7.194881047033138, 8.171003523462824, 9.16443938354919, 10.152619480444125, 9.867338717938953, 8.914404896707067, 7.905496378995744, 6.920314621069808, 5.922818000018378, 5.042068627266665, 4.020371608840568, 2.9498172946347645, 1.9207049784013654, 1.001244563689017, 1.9721286050173454, 2.939994358091305, 3.9365031334640435, 4.9893239981451085, 6.043566779570902, 6.99204283131945, 7.977234992995201, 8.94299928597919, 9.882371651170715, 10.101595610614456, 9.049810138019936, 8.100440309180604, 7.110546339389456, 6.050420026658958, 6.878868769199006, 5.935946595015268, 4.94808811199806, 3.893459303351621, 2.8884527436136054, 1.9287430160942558, 2.9681537369934685, 3.9130689151577203, 4.878878387454778, 5.900110662202756, 6.9577072176138355, 7.923055000474535, 8.898189967756116, 9.914886767641867, 10.856512268576054, 10.880065999208261, 9.948151480951953, 8.97524627920402, 7.903620375982026, 6.977092797470656, 7.819889471460304, 6.849574605096647, 5.822577997072859, 4.874701752975845, 3.8799884220264884, 2.9357915359787183, 3.909985848945148, 4.869534443465887, 5.825925969449845, 6.786835250896021, 7.739381337899415, 8.674851467755026, 9.619118605169135, 10.643239028900684, 11.668979033504433, 11.812693402483307, 10.854674529244576, 9.912618027087126, 8.913060636327462, 7.9808629617358005, 8.782555163163087, 7.721319315629017, 6.775148726013159, 5.850128270458683, 4.869449093260659, 3.8742282141117705, 4.848136743841388, 5.859460746847221, 6.783039158626249, 7.762300000230216, 8.692151013447315, 9.63614441184032, 10.610147131911628, 11.672347112156785, 12.642549207474707, 12.77321082018085, 11.807548267981964, 10.897454714144693, 9.873780295976658, 8.935987524172797, 9.736381050380691, 8.77621131672804, 7.7872500183461355, 6.809918916544475, 5.855791369232953, 4.889936245075171, 5.817527324809335, 6.790885166972816, 7.720420636155612, 8.74778139856422, 9.63539602759939, 10.671457288821005, 11.650812122310029, 12.578013035363904, 13.635456955629316, 13.736967224358315, 12.789770996153415, 11.825508946536203, 10.843465701801625, 9.788612425763104, 10.716623593364215, 9.740633346421813, 8.731566797542401, 7.737453105754307, 6.895437044341232, 5.943202862926668, 6.844008655665536, 7.774734873828436, 8.663979609131792, 9.609028900904736, 10.656668140432933, 11.696353689266157, 12.592763214069295, 13.624473662339517, 14.045550418716592, 14.773933660682196, 13.804342629089493, 12.784540396517967, 11.717017067221292, 10.684513040760521, 11.651161394488817, 10.637022971367882, 9.686055644807809, 8.740101672294635, 7.859481562366996, 6.8748047185171455, 7.792824365702981, 8.752008596920197, 9.695773437041455, 10.586109046658533, 11.660181799644025, 12.7041147624679, 13.524117260061342, 14.020347886732846, 13.071759561339466, 13.756334478091777, 14.674679338446696, 13.617996001803485, 12.616808517262113, 11.55337003716231, 12.602795165658335, 11.64757558698259, 10.708290392769749, 9.780685570750993, 8.797989908246677, 7.814174320182682, 8.730832206309444, 9.699974069662254, 10.715757435630128, 11.608096448496138, 12.55086721656393, 13.529858177493038, 13.805585391987776, 12.954800841937535, 12.003720313648037, 12.76532643481957, 13.752907282731263, 14.529938332939771, 13.468979604854727, 12.482424615758521, 13.572747004199725, 12.696203497828904, 11.754024837920467, 10.80341570223227, 9.858607892493309, 8.812655716653667, 9.731902463968838, 10.70139371389673, 11.699218769444613, 12.534700801341693, 13.513700052467245, 13.628997453328626, 12.813153504210764, 11.882913333208933, 10.943128205347495, 11.762368536062635, 12.772063006638932, 13.741865662517501, 14.424175202316968, 13.546957753056425, 14.500432637833901, 13.665924765069398, 12.75481873404486, 11.77270112707352, 10.836094694581657, 9.761800294976338, 10.689575004658014, 11.666653810321307, 12.661624235709615, 13.606398081722295, 13.608329056816878, 12.626310075464483, 11.765751220124447, 10.885615383438239, 9.97090605028486, 10.765813099102978, 11.779429962565507, 12.690659612488849, 13.641851947640054, 14.608604616278113], [14.598346872248527, 13.652305581623708, 12.6905857042264, 11.7355891547101, 10.752894920577928, 9.789005123944593, 8.898688662878138, 9.866033442276997, 10.710662759212143, 11.663071841234649, 12.70613478900658, 12.721097441071349, 11.791117755850303, 10.780656196208303, 11.724012416858537, 12.733335411891899, 13.785121745222261, 14.714325918093632, 15.725474630069096, 16.532921789889155, 13.526661114895504, 12.709435247945398, 11.753099936809537, 10.763107965567816, 9.729769621177233, 8.815175980374544, 7.8562226443514565, 8.836908097890158, 9.782209320234383, 10.721759650938413, 11.65418923197954, 12.583394589714699, 12.785474821451924, 11.777847502206077, 12.771667957799979, 13.739438784564625, 14.803831287185893, 15.769910127656582, 16.643894052316142, 15.577165058952817, 12.520879327678857, 11.724963985679548, 10.757090750732278, 9.75886044742365, 8.759981365956943, 7.817158170395509, 6.8610840849132915, 7.822090427244829, 8.806317510312523, 9.70395342599357, 10.63832173544445, 11.617986975071599, 12.636293823753757, 12.762808973266505, 13.755926326535574, 14.678837372999803, 15.72625172982714, 16.674773105728928, 15.674929914529041, 14.677781572150133, 11.552860020083772, 10.662162640846544, 9.74716536286508, 8.744241624216695, 7.698408211673931, 6.818781615296645, 5.861890502356969, 6.77370573221055, 7.811998418805938, 8.726041763153539, 9.664688234468962, 10.655840438196305, 11.65702956501493, 12.544551138596955, 13.527892401277768, 14.415224252487613, 15.345909632034218, 15.640321442232406, 14.71294928434182, 13.734288502519629, 10.621424338159665, 9.651171316009876, 8.715476051736145, 7.7967061953764665, 6.737552681922332, 5.844765615559213, 4.894953393976815, 5.8245216527609305, 6.8351881301017885, 7.711547153119051, 8.73512240539215, 9.703037323910953, 10.58440944540606, 11.58939385829314, 12.476864531966854, 13.45859055240104, 14.511735426810139, 14.572995830521707, 13.721300375481587, 12.790556056027722, 9.76800778892796, 8.757752062308626, 7.775727759956058, 6.819834119643969, 5.798146490855279, 4.8556886391709995, 3.942039984883803, 4.917912117636335, 5.884499940404779, 6.773767934486586, 7.736174849111158, 8.671072882755805, 9.635409627607878, 10.62916660821668, 11.5494276639992, 12.475098850414378, 13.478983358668486, 13.63715717050352, 12.77731567206002, 11.812189800952531, 8.812835507986149, 7.773201300068362, 6.7840710554742945, 5.842804280951788, 4.8534069602782015, 3.910859475452164, 2.985771523947465, 3.952630124813248, 4.947668374893711, 5.847384930052143, 6.8796193425853875, 7.7652336489366185, 8.68880308356678, 9.63388451416831, 10.55555835074835, 11.520772893850399, 12.550413529500515, 12.712138365623836, 11.788324245263917, 10.834330917262346, 7.850766057159652, 6.816563314301256, 5.833696512254244, 4.871261216224714, 3.902634968077947, 2.919335738056326, 1.9832451341203343, 2.9593291233074446, 3.9730914941670203, 4.862417561872426, 5.85662517274476, 6.825899433746439, 7.708599250086589, 8.668454980331292, 9.629468940576212, 10.680585194470172, 11.64221722972891, 11.769120834781639, 10.825013140701712, 9.816261032573742, 7.060129246959507, 5.987415822098599, 5.009391896681725, 4.038741493886998, 3.01205352804604, 1.9997225004015977, 0.9721070354379451, 1.942352156493573, 2.9293430966318432, 3.92239491569491, 4.877523481562513, 5.8130143336010205, 6.747033955998444, 7.72426481705776, 8.752462415152957, 9.711674242379825, 10.665125124718728, 10.870897551934538, 9.91423375223542, 8.880415288491886, 6.0282431503216465, 5.0790599062711, 4.064812760691316, 3.0836596781332344, 2.034976581179704, 1.0495621486633189, 0.0, 1.0529901176886673, 2.1170607484597275, 3.059126451999778, 4.041748901795583, 5.098294670573034, 6.145318898369819, 7.121441374799505, 8.11487723488587, 9.103057331780805, 10.153310577542982, 9.963967045370385, 8.955058527659062, 7.969876769733126, 6.972380148681696, 6.091630775929983, 5.069120505669894, 3.99856619146409, 2.969453875230691, 2.0353179260527554, 1.0644338847244268, 2.0322996377983866, 3.028808413171125, 4.04719357906189, 5.064654661966369, 6.013130713714917, 6.998322875390667, 7.964087168374656, 8.903459533566181, 9.897775118832497, 10.099372286683254, 9.150002457843922, 8.160108488052774, 7.099982175322276, 7.928430917862324, 6.984695491844594, 5.996837008827386, 4.942208200180947, 3.937201640442931, 2.962816378457994, 2.0604590167005497, 3.005374194864802, 3.971183667161859, 4.992415941909837, 6.010604734420231, 6.9759525172809305, 7.951087484562512, 8.935974650037334, 9.87760015097152, 10.891494465802506, 10.997713629615271, 10.024808427867338, 8.953182524645344, 8.026654946133974, 8.86863836828963, 7.898323501925972, 6.871326893902184, 5.92345064980517, 4.914061784390227, 3.9698648983424567, 3.0603208595124753, 4.0198694540332145, 4.976260980017172, 5.937170261463349, 6.8897163484667425, 7.825186478322354, 8.769453615736461, 9.79357403946801, 10.804337972952137, 11.753373698059342, 11.7984971153309, 10.856440613173449, 9.856883222413785, 8.924685547822124, 9.831304059992412, 8.770068212458343, 7.823897622842484, 6.898345197007407, 5.9035224556243975, 4.908301576475509, 3.9984717544087154, 5.009795757414549, 5.933374169193576, 6.912635010797544, 7.842486024014644, 8.786479422407648, 9.760482142478955, 10.822682122724112, 11.792884218042033, 12.737451896686117, 12.751370854068288, 11.841277300231017, 10.817602882062982, 9.87981011025912, 10.785129947210017, 9.824960213557365, 8.83599891517546, 7.858135843093199, 6.888550709447435, 5.922695585289654, 4.967862335376663, 5.941220177540144, 6.870755646722939, 7.898116409131547, 8.785731038166718, 9.821792299388333, 10.801147132877356, 11.72834804593123, 12.785791966196642, 13.701208300863582, 13.733593582239738, 12.769331532622527, 11.787288287887948, 10.732435011849427, 11.76537249019354, 10.789382243251138, 9.780315694371726, 8.785670032303031, 7.928196384555715, 6.975962203141151, 5.994343666232863, 6.925069884395763, 7.814314619699118, 8.759363911472063, 9.80700315100026, 10.846688699833484, 11.743098224636622, 12.774808672906843, 13.727538944103191, 14.738174737187464, 14.748165215175817, 13.724819940715824, 12.657296611419149, 11.624792584958378, 12.69937832103754, 11.685239897916606, 10.734272571356533, 9.78831859884336, 8.892240902581479, 7.907564058731628, 6.943159376270309, 7.902343607487524, 8.846108447608781, 9.73644405722586, 10.81051681021135, 11.854449773035224, 12.674452270628668, 13.097169619094137, 13.873415405157886, 14.695662629261902, 15.614958882644553, 14.558275546001342, 13.55708806145997, 12.493649581360167, 13.65101209220706, 12.680334927197073, 11.741049732984232, 10.813444910965476, 9.83074924846116, 8.846933660397164, 7.88116721687677, 8.850309080229579, 9.866092446197452, 10.758431459063464, 11.701202227131256, 12.680193188060365, 12.872732335285917, 12.031622574298826, 12.805376157466457, 13.704654585989696, 14.692235433901388, 15.470217877137628, 14.409259149052584, 13.422704159956378, 14.620963930748449, 13.728962838043387, 12.78678417813495, 11.836175042446753, 10.891367232707792, 9.84541505686815, 8.882237474536165, 9.851728724464056, 10.84955378001194, 11.68503581190902, 12.664035063034571, 12.696144396626767, 11.880300447508905, 10.959735065570223, 11.744784049165915, 12.70169668723276, 13.711391157809057, 14.681193813687626, 15.364454746514825, 14.487237297254282, 15.548649564382625, 14.698684105283881, 13.787578074259343, 12.805460467288002, 11.86885403479614, 10.79455963519082, 9.83991001522534, 10.816988820888634, 11.811959246276942, 12.756733092289622, 12.675476000115019, 11.693457018762624, 10.832898163422588, 9.95276232673638, 10.77256189410328, 11.705141250273103, 12.718758113735632, 13.629987763658974, 14.58118009881018, 15.54888416047597], [15.600962049808789, 14.654920759183968, 13.69320088178666, 12.73820433227036, 11.755510098138188, 10.791620301504853, 9.901303840438398, 9.160171339931054, 10.0048006568662, 10.822935438486198, 11.785673096781323, 11.905351299133509, 11.127423877368905, 11.728202743956993, 12.671558964607227, 13.680881959640589, 14.732668292970951, 15.661872465842322, 16.673021177817784, 17.48046833763784, 14.529276292455766, 13.712050425505659, 12.755715114369798, 11.765723143128076, 10.732384798737494, 9.817791157934805, 8.858837821911717, 8.131045995544214, 9.07634721788844, 9.783884586387419, 10.716314167428546, 11.645519525163705, 12.121780942970526, 12.725394049954767, 13.719214505548669, 14.686985332313315, 15.751377834934583, 16.717456675405273, 17.591440600064832, 16.524711606701505, 13.52349450523912, 12.72757916323981, 11.75970592829254, 10.761475624983913, 9.762596543517203, 8.81977334795577, 7.863699262473553, 7.116228324898886, 8.10045540796658, 8.766078361442576, 9.700446670893456, 10.680111910520605, 11.68073074246281, 12.570743735646463, 13.563861088915532, 14.514684864259477, 15.327617645619641, 16.315218334681344, 16.62247646227773, 15.625328119898821, 12.555475197644034, 11.664777818406806, 10.749780540425341, 9.746856801776957, 8.701023389234193, 7.821396792856906, 6.86450567991723, 6.067843629864606, 7.054487708272083, 7.788166698602545, 8.726813169917968, 9.717965373645312, 10.701466483723983, 11.588988057306006, 12.572329319986821, 13.459661171196666, 14.39034655074327, 15.381834615387882, 15.660495832090508, 14.681835050268317, 11.624039515719927, 10.653786493570138, 9.718091229296407, 8.799321372936728, 7.740167859482593, 6.847380793119474, 5.897568571537076, 5.1186595504149865, 6.045125012729772, 6.773672088568056, 7.797247340841157, 8.76516225935996, 9.628846364115113, 10.633830777002192, 11.521301450675907, 12.503027471110093, 13.556172345519192, 14.44996422003631, 14.668846923230277, 13.738102603776412, 10.770622966488222, 9.760367239868888, 8.778342937516319, 7.82244929720423, 6.80076166841554, 5.858303816731261, 4.9446551624440644, 4.087636266068423, 5.003962135726039, 5.835892869935591, 6.798299784560164, 7.73319781820481, 8.67984654631693, 9.673603526925731, 10.593864582708253, 11.519535769123431, 12.52342027737754, 13.514125560018124, 13.72486221980871, 12.759736348701221, 9.815450685546411, 8.775816477628625, 7.7866862330345565, 6.845419458512049, 5.856022137838463, 4.913474653012425, 3.988386701507727, 3.0890715138804974, 4.05941101913908, 4.909509865501148, 5.941744278034393, 6.8096705676456715, 7.733240002275832, 8.678321432877361, 9.599995269457404, 10.565209812559452, 11.594850448209568, 12.58910675513844, 12.735870793012607, 11.781877465011036, 8.853381234719915, 7.819178491861518, 6.836311689814506, 5.873876393784976, 4.905250145638209, 3.9219509156165877, 2.9858603116805957, 2.0551176521623242, 3.0539044153788, 3.924542497321431, 4.901062091453813, 5.870336352455492, 6.753036168795642, 7.712891899040346, 8.673905859285265, 9.725022113179225, 10.686654148437963, 11.646089224296242, 11.772559688450402, 10.763807580322432, 8.073840646600868, 7.001127221739961, 6.023103296323087, 5.0524528935283595, 4.014668705606302, 3.0023376779618594, 1.9747222129982067, 1.0044770919425787, 1.9914680320808487, 2.984519851143915, 3.9219604002715656, 4.8574512523100735, 5.791470874707497, 6.768701735766813, 7.79689933386201, 8.756111161088878, 9.70956204342778, 10.678857696638936, 10.88368985118456, 9.849871387441025, 7.081233268010314, 6.132050023959767, 5.117802878379983, 4.136649795821901, 3.087966698868371, 2.102552266351986, 1.0529901176886673, 0.0, 1.06407063077106, 2.006136334311111, 2.988758784106916, 4.0453045528843665, 5.092328780681152, 6.068451257110838, 7.061887117197204, 8.05006721409214, 9.100320459854316, 10.053254281086202, 10.00804864534773, 9.022866887421793, 8.025370266370363, 7.049305557069366, 6.016667053418583, 4.946112739212779, 3.9170004229793802, 2.9828644738014445, 2.0119804324731163, 1.0441146793991567, 2.024925524174062, 2.994203461373223, 4.011664544277702, 4.96014059602625, 5.945332757702, 6.911097050685989, 7.850469415877514, 8.84478500114383, 9.89657047373835, 10.20299257553259, 9.213098605741443, 8.152972293010944, 8.897887016811463, 7.932242039593283, 6.944383556576075, 5.889754747929636, 4.884748188191621, 3.910362926206683, 3.008005564449239, 2.0171892364655717, 2.982998708762629, 3.9506614475830597, 4.957614616731564, 5.922962399592263, 6.898097366873845, 7.882984532348667, 8.824610033282854, 9.838504348113839, 10.770418866370147, 11.038519827508699, 9.966893924286705, 9.040366345775334, 9.81618491603832, 8.845870049674662, 7.818873441650874, 6.87099719755386, 5.861608332138916, 4.917411446091146, 4.007867407261165, 3.0861760183811806, 4.040165569225442, 4.9852802243196646, 5.937826311323058, 6.859041296695242, 7.80330843410935, 8.827428857840898, 9.75134785526347, 10.700383580370675, 11.658402453609405, 11.859055790733713, 10.859498399974049, 9.927300725382388, 10.778850607741102, 9.717614760207033, 8.771444170591174, 7.845891744756095, 6.851069003373086, 5.855848124224198, 4.946018302157405, 4.129060443345625, 4.997278758401846, 5.96074497365386, 6.890595986870959, 7.820334240780536, 8.794336960851842, 9.856536941097, 10.817425456124361, 11.704114350828068, 12.611276192346793, 12.843892477791282, 11.820218059623247, 10.882425287819382, 11.732676494958707, 10.772506761306055, 9.78354546292415, 8.805682390841886, 7.836097257196125, 6.870242133038344, 5.915408883125353, 5.068159279214805, 5.934660235931209, 6.962020998339817, 7.833841001023034, 8.858721425975624, 9.835001951250243, 10.762202864304118, 11.81964678456953, 12.667870755005533, 13.675076104759261, 13.771946710182792, 12.789903465448214, 11.735050189409689, 12.71291903794223, 11.736928790999828, 10.727862242120416, 9.73321658005172, 8.875742932304405, 7.923508750889841, 6.941890213981553, 6.052008986070424, 6.878219208907389, 7.823268500680333, 8.87090774020853, 9.886131159440401, 10.77695304300951, 11.80866349127973, 12.761393762476079, 13.704837191329414, 14.689647737695342, 14.727435118276086, 13.65991178897941, 12.62740776251864, 13.646924868786229, 12.632786445665294, 11.68181911910522, 10.735865146592047, 9.839787450330169, 8.855110606480318, 7.890705924018999, 7.110590679572871, 7.910013036817053, 8.80034864643413, 9.87442139941962, 10.918354362243495, 11.708307089001556, 12.639901197258444, 13.612504200436376, 14.677901717066206, 15.623111950979666, 15.560890723561604, 14.559703239020232, 13.496264758920429, 14.598558639955748, 13.627881474945763, 12.688596280732922, 11.760991458714166, 10.77829579620985, 9.794480208145854, 8.82871376462546, 8.093789564665462, 8.943254843956879, 9.822336048271735, 10.765106816339527, 11.744097777268635, 12.166870232939974, 13.034237751859086, 13.807991335026717, 14.707269763549956, 15.694850611461648, 16.47283305469789, 15.411874326612846, 14.42531933751664, 15.568510478497137, 14.676509385792077, 13.73433072588364, 12.783721590195443, 11.838913780456481, 10.79296160461684, 9.829784022284855, 9.16355748293706, 9.941112487306624, 10.74894040111729, 11.727939652242842, 11.990282294280824, 11.174438345162962, 11.962350243130484, 12.747399226726175, 13.70431186479302, 14.714006335369318, 15.683808991247886, 16.367069924075086, 15.489852474814544, 16.49619611213131, 15.646230653032571, 14.735124622008033, 13.753007015036692, 12.81640058254483, 11.74210618293951, 10.78745656297403, 10.128817579361638, 10.954367778076763, 11.820637681497892, 11.835339597366568, 10.98759491641668, 10.127036061076645, 10.95537750429664, 11.77517707166354, 12.707756427833363, 13.721373291295892, 14.632602941219234, 15.58379527637044, 16.551499338036233], [16.566772752389028, 15.620731461764205, 14.659011584366898, 13.704015034850597, 12.721320800718425, 11.75743100408509, 10.867114543018634, 10.0172393489485, 9.00820412044777, 9.808687079076257, 10.771424737371383, 10.848074168325537, 11.778053853546583, 12.619163895617996, 13.56252011626823, 14.571843111301591, 15.623629444631954, 16.552833617503325, 17.563982329478787, 18.374339224887468, 15.495086995036004, 14.677861128085896, 13.721525816950034, 12.731533845708313, 11.69819550131773, 10.783601860515041, 9.824648524491952, 9.00578851027397, 8.07975068147001, 8.769636226977479, 9.702065808018606, 10.631271165753766, 11.64592075658477, 12.491634575935832, 13.524873737060599, 14.390012821923596, 15.234820639491264, 16.200899479961954, 17.22463394001585, 17.41858249395113, 14.489305207819358, 13.693389865820048, 12.725516630872779, 11.727286327564148, 10.72840724609744, 9.785584050536007, 8.829509965053788, 7.990970839628641, 7.097842058761457, 7.751830002032635, 8.686198311483516, 9.665863551110666, 10.616660111691749, 11.506673104875404, 12.499790458144473, 13.450614233488418, 14.263547014848582, 15.251147703910284, 16.210628323729793, 16.519199007148444, 13.521285900224273, 12.630588520987045, 11.715591243005578, 10.712667504357194, 9.66683409181443, 8.787207495437142, 7.830316382497466, 6.942586144594362, 6.046316530575779, 6.773918339192606, 7.712564810508027, 8.703717014235373, 9.637395852952922, 10.524917426534946, 11.508258689215761, 12.395590540425607, 13.326275919972211, 14.317763984616823, 15.245136142507409, 15.595084039644902, 12.589850218300166, 11.619597196150377, 10.683901931876644, 9.765132075516965, 8.70597856206283, 7.81319149569971, 6.863379274117312, 5.993402065144743, 5.036953835033469, 5.759423729158117, 6.782998981431217, 7.75091389995002, 8.564775733344051, 9.569760146231133, 10.457230819904847, 11.438956840339033, 12.492101714748133, 13.385893589265248, 14.356328676563226, 14.651351593152995, 11.736433669068457, 10.726177942449123, 9.744153640096556, 8.788259999784467, 7.766572370995776, 6.824114519311497, 5.9104658650243005, 4.962378780798179, 3.995790958029735, 4.821644510525652, 5.784051425150224, 6.718949458794871, 7.6157759155458695, 8.609532896154672, 9.529793951937194, 10.455465138352372, 11.45934964660648, 12.450054929247061, 13.393493638066802, 13.672985338077805, 10.781261388126646, 9.74162718020886, 8.752496935614792, 7.811230161092285, 6.821832840418699, 5.879285355592661, 4.954197404087963, 4.04627809152324, 3.0512398414427766, 3.8952615060912086, 4.904462204887164, 5.74559993687461, 6.669169371504772, 7.614250802106302, 8.535924638686344, 9.501139181788393, 10.530779817438509, 11.525036124367377, 12.477381574997152, 12.69512645438762, 9.81919193730015, 8.784989194441753, 7.802122392394742, 6.839687096365212, 5.871060848218445, 4.887761618196824, 3.951671014260832, 3.0209283547425603, 2.045733237682496, 2.9102941379114915, 3.836991460682752, 4.806265721684432, 5.688965538024582, 6.648821268269286, 7.609835228514205, 8.660951482408166, 9.622583517666902, 10.582018593525179, 11.526126287605106, 11.677056569699015, 9.039651349181105, 7.966937924320197, 6.988913998903323, 6.0182635961085955, 4.980479408186538, 3.968148380542095, 2.9405329155784425, 1.9702877945228148, 0.9832968543845448, 1.9702714917339756, 2.857889769500505, 3.793380621539013, 4.727400243936437, 5.7046311049957525, 6.7328287030909495, 7.692040530317818, 8.64549141265672, 9.614787065867873, 10.571450865566991, 10.76312037681761, 8.145303898781375, 7.196120654730828, 6.181873509151044, 5.200720426592962, 4.152037329639431, 3.1666228971230463, 2.1170607484597275, 1.06407063077106, 0.0, 0.9420657035400508, 1.924688153335856, 2.981233922113306, 4.028258149910092, 5.004380626339778, 5.997816486426144, 6.9859965833210795, 8.036249829083257, 8.989183650315143, 9.998092168026465, 9.99656148693501, 8.999064865883579, 7.962554546445951, 6.929916042795168, 5.859361728589364, 4.830249412355965, 3.896113463178029, 2.9252294218497004, 1.9573636687757405, 0.9608548934030022, 1.9301328306021626, 2.9475939135066413, 3.89606996525519, 4.881262126930941, 5.847026419914929, 6.786398785106455, 7.780714370372771, 8.832499842967293, 9.781869671806625, 10.277169236512503, 9.217042923782005, 9.811136006188049, 8.845491028969867, 7.85763254595266, 6.80300373730622, 5.797997177568204, 4.8236119155832675, 3.905873667227249, 2.8915310502517153, 1.9257215779546584, 2.8865908168119994, 3.893543985960503, 4.858891768821202, 5.834026736102784, 6.8189139015776075, 7.760539402511794, 8.77443371734278, 9.706348235599089, 10.679253437347022, 10.932704626866942, 10.006177048355571, 10.729433905414904, 9.759119039051246, 8.732122431027458, 7.784246186930444, 6.7748573215155, 5.83066043546773, 4.898828558922168, 3.939279964401429, 2.982888438417471, 3.9212095935486038, 4.873755680551998, 5.794970665924181, 6.7392378033382885, 7.763358227069837, 8.68727722449241, 9.636312949599615, 10.594331822838345, 11.536388324995796, 11.825309102554284, 10.893111427962623, 11.692099597117686, 10.630863749583616, 9.684693159967757, 8.75914073413268, 7.764317992749671, 6.7690971136007825, 5.836979453818408, 4.932395275362647, 3.9400016275938747, 4.896674342882799, 5.826525356099898, 6.756263610009475, 7.730266330080782, 8.792466310325938, 9.753354825353302, 10.640043720057008, 11.547205561575733, 12.521608997397793, 12.786028762203483, 11.848235990399617, 12.64592548433529, 11.685755750682638, 10.696794452300734, 9.718931380218471, 8.727058408857129, 7.761203284699347, 6.806370034786355, 5.871494111231827, 4.877383105123238, 5.904743867531846, 6.7697703702519725, 7.794650795204562, 8.770931320479184, 9.698132233533059, 10.75557615379847, 11.603800124234473, 12.611005473988202, 13.545452084134013, 13.75571416802845, 12.700860891989924, 13.626168027318814, 12.650177780376412, 11.641111231497, 10.646465569428305, 9.766704083965408, 8.814469902550844, 7.832851365642556, 6.813800814925051, 5.820942078099417, 6.765991369872362, 7.813630609400558, 8.82206052866934, 9.71288241223845, 10.744592860508671, 11.69732313170502, 12.640766560558355, 13.625577106924283, 14.615858946821954, 14.62572249155965, 13.593218465098879, 14.560173858162814, 13.54603543504188, 12.595068108481806, 11.649114135968633, 10.730748601991172, 9.746071758141321, 8.781667075680001, 7.82512979738917, 6.852735906009081, 7.74307151562616, 8.817144268611651, 9.861077231435523, 10.644236458230496, 11.575830566487385, 12.548433569665317, 13.613831086295146, 14.559041320208607, 15.543903731046917, 15.52551394160047, 14.462075461500667, 15.492429527205372, 14.518842626606766, 13.579557432393925, 12.651952610375169, 11.669256947870853, 10.685441359806857, 9.719674916286463, 8.808328682481761, 7.8859777131489075, 8.765058917463765, 9.707829685531557, 10.686820646460665, 11.57928477020793, 12.564922044885794, 13.616472817356746, 14.604839129567353, 15.517457363359075, 16.52634540492569, 16.377685029193085, 15.39113004009688, 16.46238136574676, 15.56747053745308, 14.625291877544642, 13.674682741856445, 12.729874932117484, 11.683922756277843, 10.720745173945858, 9.87809660075336, 8.883835356498652, 9.69166327030932, 10.670662521434872, 10.993685757862394, 11.969321923212329, 12.913137627880355, 13.713209929306412, 14.670122567373257, 15.679817037949555, 16.64961969382812, 17.332880626655324, 16.455663177394783, 17.390066999380938, 16.537191804693574, 15.626085773669036, 14.643968166697695, 13.707361734205833, 12.633067334600513, 11.678417714635033, 10.843356697177937, 9.897090647268792, 10.763360550689923, 10.821091237956628, 9.990998379998251, 10.921919639126012, 11.921188206876876, 12.740987774243777, 13.6735671304136, 14.687183993876129, 15.598413643799471, 16.549605978950677, 17.517310040616472], [17.492621132411095, 16.513865238667265, 15.552145361269957, 14.597148811753657, 13.614454577621485, 12.61173085046979, 11.721414389403334, 10.72562451869504, 9.71658929019431, 8.866621375536205, 9.82935903383133, 10.727036893445815, 11.65701657866686, 12.546760178393553, 13.490116399043787, 14.45405049105627, 15.329454746779565, 16.258658919650937, 17.277127291439346, 18.235067236897454, 16.437152698576053, 15.570994904988956, 14.614659593853094, 13.624667622611373, 12.59132927822079, 11.637901706899742, 10.678948370876652, 9.733437073560776, 8.78813585121655, 7.827570523437427, 8.760000104478554, 9.689205462213716, 10.703855053044718, 11.54956887239578, 12.582808033520546, 13.447947118383544, 14.292754935951212, 15.2588337764219, 16.282568236475793, 17.213947376885578, 15.431370911359407, 14.635455569360097, 13.667582334412828, 12.6693520311042, 11.6215410230005, 10.639883896920708, 9.683809811438488, 8.791916872336806, 7.807689789269112, 6.809764298492585, 7.744132607943466, 8.723797847570616, 9.674594408151696, 10.564607401335351, 11.55772475460442, 12.508548529948365, 13.32148131130853, 14.309082000370232, 15.26856262018974, 16.26571096256865, 14.463351603764321, 13.572654224527094, 12.657656946545629, 11.654733207897245, 10.60889979535448, 9.641507341821843, 8.684616228882167, 7.769100942452651, 6.7900336957835075, 5.831852635652555, 6.770499106967977, 7.7616513106953215, 8.69533014941287, 9.582851722994894, 10.566192985675709, 11.453524836885554, 12.384210216432159, 13.37569828107677, 14.303070438967357, 15.281731220789547, 13.531915921840215, 12.561662899690425, 11.625967635416695, 10.707197779057015, 9.64804426560288, 8.735770940129536, 7.717679120502012, 6.819916863003032, 5.863468632891758, 4.817358025618066, 5.840933277891167, 6.808848196409969, 7.622710029804, 8.62769444269108, 9.515165116364795, 10.49689113679898, 11.55003601120808, 12.443827885725199, 13.414262973023177, 14.345007292477042, 12.678499372608508, 11.668243645989175, 10.686219343636607, 9.730325703324517, 8.708638074535827, 7.746693963741323, 6.764765711409001, 5.788893578656468, 4.822305755888024, 3.879578806985601, 4.841985721610174, 5.77688375525482, 6.673710212005818, 7.6674671926146205, 8.587728248397141, 9.51339943481232, 10.517283943066428, 11.507989225707012, 12.451427934526754, 13.477747817679859, 11.723327091666697, 10.683692883748911, 9.694562639154842, 8.753295864632337, 7.763898543958749, 6.8018648000224875, 5.876776848517789, 4.909918247652006, 3.9148799975715427, 2.953195802551158, 3.962396501347113, 4.80353423333456, 5.7271036679647205, 6.67218509856625, 7.593858935146293, 8.55907347824834, 9.588714113898456, 10.582970420827328, 11.535315871457103, 12.489309199458674, 10.7612576408402, 9.727054897981803, 8.744188095934792, 7.781752799905263, 6.813126551758495, 5.829827321736874, 4.893736717800882, 3.923135764670838, 2.9093733938112627, 1.968228434371441, 2.894925757142701, 3.864200018144381, 4.74689983448453, 5.706755564729234, 6.667769524974154, 7.718885778868113, 8.680517814126851, 9.63995288998513, 10.584060584065057, 11.592812692193027, 9.981717052721155, 8.909003627860248, 7.9309797024433735, 6.960329299648646, 5.922545111726588, 4.910214084082146, 3.8825986191184936, 2.9123534980628656, 1.9253625579245957, 1.0282057881939248, 1.9158240659604544, 2.851314917998962, 3.785334540396385, 4.762565401455701, 5.790762999550898, 6.749974826777766, 7.703425709116669, 8.672721362327824, 9.629385162026942, 10.663203625770477, 9.087369602321425, 8.138186358270879, 7.123939212691095, 6.142786130133013, 5.094103033179482, 4.108688600663097, 3.059126451999778, 2.006136334311111, 0.9420657035400508, 0.0, 0.9826224497958052, 2.0391682185732556, 3.086192446370041, 4.062314922799727, 5.0557507828860935, 6.043930879781029, 7.094184125543206, 8.047117946775092, 9.056026464486415, 10.041208222412351, 9.94113056942363, 8.904620249986001, 7.871981746335218, 6.801427432129414, 5.772315115896015, 4.83817916671808, 3.8672951253897514, 2.8994293723157916, 1.9029205969430532, 0.9880671270621117, 2.0055282099665903, 2.9540042617151387, 3.93919642339089, 4.904960716374878, 5.844333081566403, 6.83864866683272, 7.89043413942724, 8.839803968266573, 9.82969793805772, 10.159108627322055, 10.7532017097281, 9.787556732509918, 8.79969824949271, 7.745069440846271, 6.740062881108255, 5.765677619123318, 4.847939370767301, 3.8335967537917663, 2.867787281494709, 1.9445251132719483, 2.951478282420452, 3.9168260652811515, 4.891961032562733, 5.876848198037556, 6.818473698971743, 7.8323680138027285, 8.764282532059037, 9.73718773380697, 10.808813637028964, 10.948242751895622, 11.671499608954955, 10.701184742591296, 9.674188134567508, 8.726311890470495, 7.716923025055551, 6.772726139007781, 5.8408942624622195, 4.88134566794148, 3.9249541419575222, 2.9791438900085527, 3.9316899770119464, 4.85290496238413, 5.797172099798238, 6.821292523529786, 7.745211520952359, 8.694247246059563, 9.652266119298293, 10.594322621455744, 11.593880012215408, 11.835177131502672, 12.634165300657736, 11.572929453123667, 10.626758863507808, 9.701206437672731, 8.706383696289722, 7.711162817140833, 6.77904515735846, 5.874460978902698, 4.882067331133926, 3.9546086393427475, 4.884459652559848, 5.814197906469424, 6.788200626540731, 7.850400606785888, 8.81128912181325, 9.697978016516956, 10.605139858035681, 11.579543293857741, 12.554599671864604, 12.790301693939668, 13.58799118787534, 12.627821454222689, 11.638860155840785, 10.660997083758522, 9.669124112397181, 8.7032689882394, 7.748435738326407, 6.813559814771877, 5.819448808663289, 5.0293581032758095, 5.827704666711922, 6.852585091664511, 7.828865616939133, 8.756066529993008, 9.81351045025842, 10.66173442069442, 11.66893977044815, 12.60338638059396, 13.524285077689571, 13.642926595529975, 14.568233730858864, 13.592243483916462, 12.58317693503705, 11.588531272968355, 10.70876978750546, 9.756535606090896, 8.774917069182607, 7.755866518465101, 6.763007781639468, 6.100262421610274, 6.875396988384403, 7.879994825129288, 8.7708167086984, 9.80252715696862, 10.755257428164969, 11.698700857018302, 12.68351140338423, 13.673793243281901, 14.495628134150602, 14.535284168638928, 15.502239561702865, 14.48810113858193, 13.537133812021857, 12.591179839508683, 11.672814305531224, 10.688137461681373, 9.723732779220052, 8.76719550092922, 7.794801609549132, 7.077342567364072, 7.914632660715335, 8.934241063501789, 9.702170754690446, 10.633764862947334, 11.606367866125266, 12.671765382755096, 13.616975616668556, 14.601838027506865, 15.4931733006871, 15.404141165040716, 16.434495230745426, 15.460908330146818, 14.521623135933977, 13.594018313915221, 12.611322651410905, 11.62750706334691, 10.661740619826514, 9.750394386021812, 8.828043416688958, 8.099329969201676, 8.871330063370433, 9.850321024299541, 10.63721906666788, 11.622856341345743, 12.674407113816695, 13.662773426027302, 14.575391659819024, 15.584279701385638, 16.5024417466551, 16.333195743636928, 17.404447069286817, 16.509536240993132, 15.567357581084694, 14.616748445396498, 13.671940635657537, 12.625988459817895, 11.662810877485908, 10.82016230429341, 9.825901060038703, 9.025934322047231, 9.867825525262209, 10.793857252162537, 11.629650954444893, 12.573466659112919, 13.513251786974356, 14.512837252904657, 15.522531723480954, 16.502276422516477, 17.45763734411734, 17.39772888093483, 18.332132702920994, 17.479257508233626, 16.56815147720909, 15.586033870237747, 14.649427437745885, 13.575133038140565, 12.620483418175084, 11.785422400717987, 10.839156350808842, 10.097631602427834, 9.879025534416575, 10.699383549744791, 11.630304808872552, 12.656570972458447, 13.595287620628477, 14.56670090731666, 15.580317770779189, 16.49154742070253, 17.442739755853736, 18.45937574415652], [18.35274552624942, 17.37398963250559, 16.412269755108284, 15.457273205591985, 14.474578971459813, 13.471855244308118, 12.581538783241662, 11.58574891253337, 10.57671368403264, 9.726745769374535, 9.092102965606427, 9.829640325487562, 10.715589668850534, 11.564137728597748, 12.507493949247982, 13.471428041260467, 14.346832296983761, 15.276036469855132, 16.29450484164354, 17.25244478710165, 17.302760128471444, 16.431119298827284, 15.474783987691422, 14.4847920164497, 13.451453672059118, 12.49802610073807, 11.53907276471498, 10.593561467399105, 9.64826024505488, 8.687694917275756, 8.02274403625365, 8.791808894255462, 9.721232603248913, 10.566946422599974, 11.600185583724741, 12.46532466858774, 13.310132486155409, 14.276211326626097, 15.29994578667999, 16.231324927089773, 16.2969783412548, 15.501062999255492, 14.533189764308222, 13.534959460999591, 12.481665416838828, 11.500008290759036, 10.543934205276816, 9.652041266175134, 8.66781418310744, 7.669888692330913, 6.996110313446082, 7.826401279612362, 8.691971958355891, 9.581984951539546, 10.575102304808615, 11.525926080152562, 12.338858861512726, 13.326459550574427, 14.285940170393937, 15.283088512772846, 15.328959033659716, 14.438261654422488, 13.523264376441022, 12.520340637792637, 11.474507225249873, 10.50163173566017, 9.544740622720495, 8.629225336290979, 7.650158089621835, 6.691977029490882, 5.970641304287827, 6.864254742737069, 7.712707699617065, 8.600229273199089, 9.583570535879906, 10.470902387089751, 11.401587766636355, 12.393075831280967, 13.320447989171553, 14.299108770993744, 14.39752335173561, 13.42727032958582, 12.491575065312087, 11.572805208952408, 10.513651695498273, 9.595895333967864, 8.57780351434034, 7.680041256841359, 6.723593026730085, 5.6774824194563935, 5.0410754752110165, 5.911451628451717, 6.640087580008195, 7.645071992895275, 8.532542666568991, 9.514268687003177, 10.567413561412275, 11.461205435929394, 12.431640523227372, 13.362384842681237, 13.5441068025039, 12.533851075884566, 11.551826773532, 10.59593313321991, 9.57424550443122, 8.60681835757965, 7.624890105247328, 6.6490179724947955, 5.682430149726351, 4.739703200823929, 4.042127918930023, 4.879487187296568, 5.691087762210013, 6.684844742818815, 7.605105798601337, 8.530776985016514, 9.534661493270622, 10.525366775911207, 11.468805484730948, 12.495125367884054, 12.58893452156209, 11.549300313644304, 10.560170069050235, 9.61890329452773, 8.629505973854142, 7.661989193860815, 6.736901242356116, 5.770042641490333, 4.77500439140987, 3.813320196389485, 2.979774051551308, 3.8209117835387545, 4.744481218168915, 5.689562648770445, 6.611236485350488, 7.576451028452535, 8.606091664102651, 9.600347971031523, 10.552693421661298, 11.506686749662869, 11.626865070735594, 10.592662327877196, 9.609795525830185, 8.647360229800656, 7.678733981653888, 6.695434751632267, 5.759344147696275, 4.783260158509165, 3.76949778764959, 2.828352828209768, 1.9123033073468962, 2.881577568348576, 3.764277384688725, 4.724133114933429, 5.685147075178349, 6.736263329072308, 7.697895364331046, 8.657330440189325, 9.601438134269252, 10.610190242397222, 10.937736495891878, 9.86502307103097, 8.886999145614096, 7.916348742819369, 6.878564554897311, 5.866233527252869, 4.838618062289217, 3.8683729412335888, 2.881382001095319, 1.8883301820322522, 0.9332016161646493, 1.868692468203157, 2.80271209060058, 3.7799429516598964, 4.808140549755093, 5.767352376981961, 6.7208032593208635, 7.690098912532018, 8.646762712231135, 9.68058117597467, 10.06999205211723, 9.120808808066684, 8.1065616624869, 7.125408579928818, 6.076725482975287, 5.091311050458902, 4.041748901795583, 2.988758784106916, 1.924688153335856, 0.9826224497958052, 0.0, 1.0565457687774504, 2.103569996574236, 3.079692473003922, 4.073128333090288, 5.061308429985224, 6.111561675747401, 7.064495496979287, 8.07340401469061, 9.058585772616546, 10.056082393667976, 9.887242699781805, 8.854604196131023, 7.7840498819252195, 6.7549375656918205, 5.820801616513885, 4.8499175751855566, 3.8820518221115967, 2.8855430467388583, 1.970689576857917, 1.0229057601707852, 1.9713818119193336, 2.9565739735950847, 3.922338266579073, 4.861710631770598, 5.856026217036915, 6.907811689631435, 7.8571815184707665, 8.847075488261913, 9.90720180099241, 10.632565546604232, 10.770179182305721, 9.782320699288514, 8.727691890642076, 7.72268533090406, 6.748300068919123, 5.830561820563106, 4.816219203587572, 3.8504097312905143, 2.9271475630677535, 1.968855832624647, 2.9342036154853464, 3.909338582766928, 4.894225748241752, 5.8358512491759384, 6.849745564006923, 7.781660082263231, 8.754565284011164, 9.826191187233158, 10.752718765744529, 11.557812906681333, 11.683807192387102, 10.656810584363313, 9.7089343402663, 8.699545474851357, 7.755348588803586, 6.788809675170728, 5.829261080649989, 4.872869554666031, 3.9119602732198544, 2.9594141862164607, 3.8702825125883256, 4.814549650002434, 5.838670073733983, 6.762589071156555, 7.711624796263759, 8.66964366950249, 9.61170017165994, 10.611257562419604, 11.543455237011266, 12.528751155556968, 12.555551902919472, 11.609381313303613, 10.683828887468536, 9.689006146085527, 8.693785266936638, 7.726960570066968, 6.822376391611207, 5.829982743842435, 4.88742502255405, 3.972104790037436, 4.83157545667362, 5.805578176744927, 6.867778156990084, 7.828666672017446, 8.715355566721152, 9.622517408239876, 10.596920844061938, 11.571977222068803, 12.576472003765085, 13.482577042774572, 13.610443904018494, 12.62148260563659, 11.613402144338671, 10.617039525105689, 9.651184400947907, 8.696351151034914, 7.761475227480386, 6.767364221371798, 5.962174486487111, 4.9153498041895105, 5.869962641868707, 6.846243167143329, 7.773444080197203, 8.830888000462615, 9.679111970898617, 10.686317320652345, 11.620763930798157, 12.54166262789377, 13.512575712703702, 14.387568408515419, 14.574865933712267, 13.565799384832856, 12.540936333548505, 11.656685200213968, 10.704451018799404, 9.722832481891114, 8.70378193117361, 7.710923194347977, 7.010681365390188, 5.963042125861992, 6.897372375333484, 7.788194258902596, 8.819904707172817, 9.772634978369164, 10.7160784072225, 11.700888953588425, 12.691170793486098, 13.5130056843548, 14.457789241941217, 15.334018952475832, 15.44050619916208, 14.489538872602006, 13.543584900088833, 12.620729718239732, 11.63605287438988, 10.67164819192856, 9.715110913637728, 8.74271702225764, 7.987761511143987, 7.002277798192924, 7.9516186137059846, 8.719548304894642, 9.65114241315153, 10.623745416329463, 11.689142932959292, 12.634353166872753, 13.619215577711062, 14.510550850891299, 15.434238828751855, 16.285652723645352, 16.408823742855326, 15.469538548642484, 14.541933726623729, 13.559238064119413, 12.575422476055417, 11.609656032535021, 10.69830979873032, 9.775958829397466, 8.901745968915812, 7.958975200848021, 8.93796616177713, 9.654596616872077, 10.64023389154994, 11.691784664020892, 12.680150976231499, 13.59276921002322, 14.601657251589835, 15.5198192968593, 16.363293407348067, 17.187526055294143, 17.45745165370164, 16.5152729937932, 15.564663858105005, 14.619856048366044, 13.573903872526403, 12.610726290194416, 11.768077717001917, 10.77381647274721, 9.828350321761366, 8.955470662739796, 9.881502389640124, 10.64702850464909, 11.590844209317115, 12.530629337178553, 13.530214803108853, 14.53990927368515, 15.519653972720674, 16.47501489432154, 17.416185305514773, 18.11521168892832, 17.321295366428753, 16.31913274200796, 15.342144657919626, 14.429192852577788, 13.448743011107176, 12.50488390958071, 11.714195966857801, 10.780623846544307, 10.131362886509935, 10.003195775173214, 10.884189767504267, 11.694430788735406, 12.597816948150959, 13.502851492241188, 14.506400900338885, 15.520017763801414, 16.53696291298882, 17.488155248140025, 18.477832168736462], [18.415503198942705, 17.541607749319585, 16.525125850524052, 15.570129301007752, 14.520726079331201, 13.548487111697016, 12.713969461306341, 11.723374359178138, 11.037041712400722, 10.75323444924317, 9.949492933213122, 8.985147301279182, 9.871096644642156, 10.719644704389369, 11.663000925039603, 12.626935017052087, 13.502339272775382, 14.431543445646753, 15.450011817435161, 16.40795176289327, 17.34381744158968, 17.45760797869592, 16.50127266756006, 15.511280696318337, 14.477942351927755, 13.524514780606706, 12.565561444583617, 11.62005014726774, 10.674748924923515, 9.714183597144391, 8.880134003860345, 7.947315870047084, 8.876739579040535, 9.722453398391595, 10.755692559516362, 11.620831644379361, 12.46563946194703, 13.431718302417718, 14.45545276247161, 15.386831902881392, 16.338035654373037, 16.527551679124127, 15.559678444176857, 14.56144814086823, 13.508154096707464, 12.526496970627672, 11.570422885145453, 10.67852994604377, 9.694302862976077, 8.69637737219955, 7.923874591248896, 6.981908255403985, 7.847478934147513, 8.737491927331167, 9.730609280600236, 10.681433055944183, 11.494365837304347, 12.481966526366048, 13.441447146185558, 14.438595488564467, 15.411118230159113, 15.464750334291123, 14.549753056309658, 13.546829317661274, 12.50099590511851, 11.528120415528807, 10.571229302589131, 9.655714016159616, 8.676646769490471, 7.71846570935952, 6.89840558209064, 6.019761718528692, 6.868214675408687, 7.7557362489907105, 8.739077511671528, 9.626409362881372, 10.557094742427976, 11.548582807072588, 12.475954964963174, 13.454615746785365, 14.497247328870792, 14.453759009454455, 13.518063745180724, 12.599293888821045, 11.54014037536691, 10.622384013836502, 9.604292194208977, 8.706529936709996, 7.750081706598722, 6.703971099325031, 5.96883975301383, 5.066958604243339, 5.795594555799817, 6.800578968686897, 7.688049642360613, 8.669775662794798, 9.722920537203898, 10.616712411721016, 11.587147499018995, 12.51789181847286, 13.513092775756032, 13.560339755753205, 12.578315453400636, 11.622421813088547, 10.600734184299856, 9.633307037448288, 8.651378785115964, 7.675506652363433, 6.708918829594989, 5.766191880692566, 4.969892196732837, 4.03499416308819, 4.846594738001635, 5.840351718610437, 6.760612774392959, 7.686283960808136, 8.690168469062245, 9.68087375170283, 10.624312460522571, 11.650632343675676, 12.638018781823304, 12.57578899351294, 11.586658748918872, 10.645391974396366, 9.655994653722779, 8.688477873729452, 7.7633899222247535, 6.79653132135897, 5.801493071278507, 4.839808876258123, 3.9095855224470006, 2.9764187593303766, 3.8999881939605374, 4.845069624562067, 5.766743461142109, 6.731958004244157, 7.761598639894273, 8.755854946823145, 9.70820039745292, 10.662193725454491, 11.653464567804603, 11.619151007745833, 10.636284205698821, 9.673848909669292, 8.705222661522525, 7.721923431500905, 6.785832827564913, 5.809748838377803, 4.795986467518227, 3.854841508078405, 2.9387919872155335, 2.037084544140198, 2.9197843604803473, 3.8796400907250512, 4.84065405096997, 5.891770304863931, 6.853402340122669, 7.8128374159809475, 8.756945110060874, 9.765697218188844, 10.75533430504986, 10.89151175089961, 9.913487825482736, 8.942837422688008, 7.9050532347659495, 6.892722207121507, 5.865106742157854, 4.894861621102226, 3.907870680963956, 2.9148188619008892, 1.9596902960332865, 1.0241994439947788, 1.9582190663922021, 2.9354499274515184, 3.9636475255467154, 4.9228593527735836, 5.876310235112486, 6.84560588832364, 7.802269688022758, 8.836088151766292, 9.943673623250575, 10.177354576844133, 9.163107431264349, 8.181954348706267, 7.133271251752737, 6.147856819236352, 5.098294670573033, 4.045304552884366, 2.981233922113306, 2.0391682185732556, 1.0565457687774504, 0.0, 1.0470242277967854, 2.0231467042264715, 3.016582564312838, 4.004762661207773, 5.055015906969951, 6.007949728201837, 7.016858245913159, 8.002040003839095, 8.999536624890526, 10.036046944328154, 9.911149964908473, 8.840595650702669, 7.81148333446927, 6.877347385291334, 5.906463343963006, 4.938597590889047, 3.9420888155163083, 3.010190485224542, 1.9559477037987478, 1.0074716520501994, 1.9926638137259505, 2.9584281067099387, 3.8978004719014643, 4.89211605716778, 5.943901529762302, 6.893271358601633, 7.88316532839278, 8.929299442566192, 9.788072522395854, 10.753717499614035, 10.838866468065964, 9.784237659419526, 8.77923109968151, 7.804845837696573, 6.887107589340556, 5.872764972365022, 4.906955500067965, 3.959494331663689, 2.9018977762526097, 1.9962824647824864, 2.971417432064068, 3.930315588372617, 4.871941089306803, 5.885835404137789, 6.817749922394097, 7.790655124142029, 8.862281027364023, 9.788808605875394, 10.713319882472955, 11.679877696372174, 11.615161638472124, 10.66728539437511, 9.615618179709543, 8.671421293661773, 7.697226980695343, 6.737678386174604, 5.781286860190646, 4.82037757874447, 3.867831491741076, 2.9323613618854654, 3.8766284992995734, 4.894907998614124, 5.7986789112874195, 6.747714636394624, 7.7057335096333555, 8.647790011790805, 9.64734740255047, 10.57954507714213, 11.68425813134859, 12.736537053715534, 12.567732367412423, 11.599901592326724, 10.605078850943714, 9.609857971794826, 8.635377875591583, 7.730793697135822, 6.73840004936705, 5.795842328078665, 4.880522095562052, 3.8936543059707596, 4.867657026042067, 5.924016081870226, 6.864756512148311, 7.751445406852016, 8.658607248370743, 9.633010684192802, 10.608067062199666, 11.612561843895948, 12.638084018566195, 13.698967430244863, 13.540603351628883, 12.521819449863287, 11.525456830630304, 10.559601706472522, 9.60476845655953, 8.669892533005003, 7.675781526896413, 6.8705917920117265, 5.823767109714126, 4.932041491165847, 5.908322016440469, 6.835522929494343, 7.876072524866342, 8.715201811029482, 9.722407160783211, 10.656853770929022, 11.577752468024633, 12.548665552834565, 13.543075384307041, 14.519065631249443, 14.484920130825149, 13.44935363907312, 12.565102505738583, 11.612868324324019, 10.63124978741573, 9.612199236698226, 8.619340499872592, 7.919098670914804, 6.871459431386607, 5.959451224630624, 6.850273108199736, 7.881983556469957, 8.81781950277289, 9.752168247353364, 10.736978793719292, 11.727260633616963, 12.549095524485663, 13.49387908207208, 14.489525928267453, 15.468491268948378, 15.397956178126622, 14.452002205613448, 13.529147023764347, 12.544470179914496, 11.580065497453175, 10.623528219162344, 9.651134327782255, 8.896178816668602, 7.910695103717539, 7.013697463003124, 7.781627154191782, 8.713221262448672, 9.685824265626604, 10.751221782256433, 11.696432016169894, 12.655305417841927, 13.546640691022162, 14.470328668882718, 15.441159699436971, 16.414746600035578, 16.3779558541671, 15.450351032148344, 14.467655369644028, 13.483839781580032, 12.518073338059637, 11.606727104254935, 10.684376134922081, 9.810163274440427, 8.867392506372635, 8.032910388540543, 8.716675466169217, 9.70231274084708, 10.753863513318032, 11.74222982552864, 12.654848059320361, 13.663736100886975, 14.555909136990163, 15.39938324747893, 16.34303303108576, 17.400300351676385, 16.467374167295613, 15.516765031607417, 14.627078864924442, 13.553394565221467, 12.618063426061507, 11.834963039074001, 10.949386113106067, 10.736767627285982, 9.863887968264411, 9.051560074986098, 9.70910735394623, 10.652923058614256, 11.592708186475694, 12.592293652405994, 13.601988122982291, 14.581732822017814, 15.511104734452404, 16.45227514564564, 17.270718664719936, 16.476802342220374, 15.474639717799581, 14.497651633711246, 13.58469982836941, 12.604249986898797, 11.660390885372331, 10.869702942649424, 9.936130822335928, 10.965776908678112, 10.91161308069783, 10.054247452850241, 10.756509638032547, 11.6598957974481, 12.564930341538329, 13.568479749636026, 14.582096613098555, 15.59904176228596, 16.528854830190678, 17.51392200886733], [17.419295879387967, 16.545400429764847, 15.61247108075952, 14.657474531243219, 13.647595237017232, 12.675356269383046, 11.840838618992372, 10.850243516864168, 11.79595015450289, 11.652394832061706, 10.750273328274577, 9.78592769634064, 8.915843457901678, 9.764391517648892, 10.707747738299126, 11.671681830311611, 12.547086086034906, 13.476290258906277, 14.494758630694685, 15.452698576152791, 16.347610122034943, 17.292630080132888, 16.619947691627225, 15.629955720385503, 14.670720536417926, 13.649185412953095, 12.883304637519053, 11.879368861251008, 11.573909307742051, 10.613343979962927, 9.6809143989218, 8.74809626510854, 7.921486392300058, 8.767200211651119, 9.800439372775886, 10.665578457638885, 11.510386275206553, 12.476465115677241, 13.500199575731134, 14.431578716140915, 15.341828334818297, 16.28755634064525, 16.472464502231226, 15.474234198922598, 14.420940154761835, 13.439283028682043, 12.483208943199823, 11.591316004098141, 10.607088921030448, 9.60916343025392, 8.821928873081895, 7.78268865046544, 6.8922257474070365, 7.7822387405906905, 8.77535609385976, 9.726179869203706, 10.53911265056387, 11.526713339625573, 12.486193959445082, 13.48334230182399, 14.414910910604375, 15.383994245755487, 15.462539114364027, 14.459615375715643, 13.413781963172879, 12.440906473583178, 11.484015360643502, 10.568500074213986, 9.589432827544842, 8.63125176741389, 7.796459863923638, 6.820542113590147, 5.912961488668211, 6.800483062250234, 7.783824324931052, 8.671156176140896, 9.6018415556875, 10.593329620332112, 11.520701778222698, 12.493007914124018, 13.501040009316053, 14.471293031465843, 14.430849803235093, 13.512079946875414, 12.452926433421279, 11.535170071890871, 10.517078252263348, 9.619315994764367, 8.662867764653093, 7.616757157379401, 6.866894034846828, 5.867738999304795, 4.840341369059341, 5.84532578194642, 6.732796455620137, 7.714522476054322, 8.767667350463421, 9.608535723725762, 10.57897081102374, 11.509715130477606, 12.516885456201294, 13.530725786565176, 13.491101511455005, 12.535207871142916, 11.513520242354225, 10.546093095502657, 9.564164843170335, 8.588292710417804, 7.621704887649359, 6.678977938746936, 5.867946478565835, 4.933048444921188, 3.891341551261159, 4.885098531869961, 5.805359587652482, 6.731030774067659, 7.734915282321769, 8.672697063707576, 9.616135772527317, 10.642455655680422, 11.641811462268565, 12.648097976875368, 12.49944480697324, 11.558178032450735, 10.568780711777148, 9.601263931783821, 8.676175980279123, 7.70931737941334, 6.714279129332877, 5.7525949343124925, 4.807639804279998, 3.8744730411633745, 2.944735007220061, 3.8898164378215907, 4.811490274401633, 5.77670481750368, 6.806345453153797, 7.747678258827891, 8.700023709457666, 9.654017037459237, 10.657257248249865, 11.69145999110826, 11.54907026375319, 10.586634967723661, 9.618008719576894, 8.634709489555274, 7.6986188856192825, 6.7225348964321725, 5.708772525572597, 4.767627566132775, 3.8515780452699038, 2.935138825973196, 1.964531173739871, 2.924386903984575, 3.885400864229494, 4.934363580900718, 5.845225652127414, 6.804660727985693, 7.74876842206562, 8.75752053019359, 9.759126985495122, 10.83184041035603, 10.826273883537105, 9.855623480742377, 8.817839292820318, 7.8055082651758765, 6.777892800212224, 5.807647679156596, 4.820656739018326, 3.8276049199552595, 2.872476354087657, 1.936985502049149, 1.0029658796517258, 1.9801967407110421, 2.963779579952642, 3.9146826647783293, 4.868133547117232, 5.837429200328386, 6.7940930000275035, 7.827911463771037, 8.896649395453789, 9.845832639504335, 10.210131659061135, 9.228978576503053, 8.180295479549523, 7.194881047033138, 6.145318898369819, 5.092328780681152, 4.028258149910092, 3.086192446370041, 2.103569996574236, 1.0470242277967854, 0.0, 0.9761224764296859, 1.969558336516052, 2.957738433410987, 4.0079916791731645, 4.96092550040505, 5.969834018116373, 6.955015776042309, 7.95251239709374, 8.989022716531368, 10.02166122018215, 9.887619878499454, 8.858507562266055, 7.92437161308812, 6.9534875717597915, 5.985621818685832, 4.989113043313094, 4.0036744969499285, 2.9494317155241343, 2.000955663775586, 1.015763502099835, 1.9622207871552002, 2.9015931523467255, 3.895908737613042, 4.947694210207564, 5.897064039046895, 6.886958008838041, 7.882275214769406, 8.7798958344006, 9.745540811618781, 10.733399294635989, 10.83126188721631, 9.826255327478295, 8.851870065493358, 7.934131817137341, 6.919789200161807, 5.95397972786475, 4.952978343389075, 3.895381787977996, 2.9886056012638615, 2.01347063398228, 2.9341082688178783, 3.8757337697520646, 4.889628084583051, 5.821542602839359, 6.794447804587291, 7.866073707809285, 8.792601286320656, 9.705143194477701, 10.67170100837692, 11.698697616400707, 11.659608530856485, 10.607941316190917, 9.663744430143147, 8.689550117176719, 7.7300015226559795, 6.773609996672022, 5.812700715225845, 4.8601546282224515, 3.9246844983668407, 3.003497656985605, 3.8987006790593854, 4.802471591732681, 5.751507316839886, 6.709526190078617, 7.651582692236068, 8.651140082995731, 9.583337757587392, 10.676081443353336, 11.72836036572028, 12.651268345341007, 12.592224728808098, 11.597401987425089, 10.6021811082762, 9.62770101207296, 8.723116833617198, 7.730723185848426, 6.7881654645600396, 5.872845232043427, 4.885977442452135, 3.994526183728098, 4.927808762315488, 5.868549192593573, 6.755238087297278, 7.662399928816004, 8.636803364638066, 9.611859742644928, 10.61635452434121, 11.62990733057094, 12.69079074224961, 13.663369637673984, 13.514142586344661, 12.517779967111679, 11.551924842953898, 10.597091593040906, 9.662215669486377, 8.66810466337779, 7.862914928493101, 6.8160902461955, 5.924364627647222, 5.0351911741265, 5.927858628535402, 6.879865205311604, 7.718994491474743, 8.726199841228473, 9.660646451374285, 10.581545148469894, 11.552458233279827, 12.534898696311787, 13.510888943254189, 14.519955492133601, 14.441676775554495, 13.557425642219957, 12.605191460805395, 11.623572923897108, 10.604522373179602, 9.611663636353969, 8.911421807396177, 7.863782567867982, 6.922310980465736, 5.977142265885767, 6.977012221858344, 7.821612183218153, 8.755960927798625, 9.740771474164553, 10.731053314062226, 11.552888204930925, 12.497671762517342, 13.527918095606106, 14.460314580953124, 15.411281907513198, 15.444325342094823, 14.521470160245723, 13.536793316395872, 12.572388633934553, 11.61585135564372, 10.643457464263632, 9.888501953149975, 8.903018240198914, 7.878254082029078, 6.908496311877814, 7.840090420134703, 8.79540304059528, 9.796352557584873, 10.70921076605648, 11.65909809828719, 12.550433371467424, 13.47412134932798, 14.479551866775624, 15.45313876737423, 16.39242396158707, 15.56313402552029, 14.580438363015974, 13.596622774951978, 12.663880496980426, 11.949477770605121, 11.676699271403457, 10.713580559639611, 9.77080979157182, 8.791818830642711, 7.843544623855248, 8.829181898533111, 9.86344228828671, 10.78736060085708, 11.667626809206947, 12.676514850773561, 13.559701817435425, 14.403175927924192, 15.387779844345284, 16.44504716493591, 15.512120980555137, 14.56151184486694, 13.671825678183968, 12.598141378480992, 11.662810239321031, 10.879709852333523, 11.750166508167524, 11.640184912485166, 10.736500243988594, 9.810468517088266, 8.83597651163226, 9.779792216300287, 10.719577344161724, 11.719162810092024, 12.648471085299278, 13.6282157843348, 14.514897414897666, 15.456067826090901, 16.31546547797946, 15.5215491554799, 14.519386531059105, 13.54239844697077, 12.629446641628933, 11.648996800158322, 10.705137698631855, 9.914449755908946, 10.736911217397385, 11.76655730373957, 11.784225356422013, 10.81315589495241, 9.883378795718578, 10.78676495513413, 11.69179949922436, 12.695348907322057, 13.669441843334022, 14.679421834363453, 15.53264751063594, 16.51771468931259], [16.44317340295828, 15.56927795333516, 14.636348604329832, 13.681352054813532, 12.762997789839162, 11.903690845378886, 11.253980792070069, 11.69398940789726, 12.639696045535981, 12.62851730849139, 11.726395804704262, 10.762050172770325, 9.891965934331365, 8.932726107576384, 9.876082328226618, 10.775776314510685, 11.65118057023398, 12.58038474310535, 13.598853114893759, 14.556793060351865, 15.371487645605256, 16.316507603703197, 15.643825215197538, 14.653833243955816, 13.786123089239856, 12.877519988948935, 12.29644681059675, 12.723114752284099, 12.550031784171736, 11.589466456392612, 10.657036875351485, 9.724218741538225, 8.897608868729744, 7.935534801578611, 8.968773962703375, 9.769672941837959, 10.614480759405627, 11.580559599876315, 12.604294059930208, 13.505722624732371, 14.36570585838861, 15.31143386421556, 16.31508004109163, 15.681654900638106, 14.755911344460147, 13.875537798927969, 13.291585370034914, 12.567438480527828, 11.583211397460135, 10.585285906683607, 9.79805134951158, 8.758811126895125, 7.868348223836722, 6.950573330518182, 7.94369068378725, 8.83027435340278, 9.643207134762944, 10.630807823824647, 11.581483292769883, 12.557486210415446, 13.438788434174688, 14.4078717693258, 15.452177206130708, 15.43573785214533, 14.389904439602565, 13.417028950012863, 12.460137837073187, 11.544622550643671, 10.565555303974529, 9.607374243843577, 8.772582340353324, 7.796664590019832, 6.889083965097896, 5.968817652177726, 6.8879188091301256, 7.775250660339969, 8.705936039886573, 9.697424104531185, 10.6159911115475, 11.51688543769433, 12.524917532886366, 13.495170555036156, 14.430865819309886, 14.4882024233051, 13.429048909850966, 12.511292548320558, 11.493200728693033, 10.595438471194052, 9.638990241082778, 8.592879633809087, 7.843016511276513, 6.84386147573448, 5.816463845489026, 5.013660371873912, 5.83689093981921, 6.8186169602533955, 7.84864597249012, 8.632413247296075, 9.602848334594054, 10.533592654047919, 11.540762979771609, 12.55460331013549, 13.536627612488058, 13.511330347572603, 12.489642718783912, 11.522215571932344, 10.54028731960002, 9.564415186847489, 8.597827364079045, 7.655100415176622, 6.84406895499552, 5.909170921350873, 4.867464027690844, 4.053433121797452, 4.909454071851556, 5.835125258266733, 6.815893904348466, 7.696574587277889, 8.64001329609763, 9.666333179250735, 10.665688985838878, 11.671975500445681, 12.648578859945635, 12.534300508880422, 11.544903188206835, 10.577386408213508, 9.65229845670881, 8.685439855843027, 7.690401605762564, 6.7287174107421786, 5.783762280709684, 4.85059551759306, 3.9208574836497467, 3.058151027749082, 3.9155847586007066, 4.880799301702754, 5.832017226791079, 6.771555782398204, 7.723901233027978, 8.67789456102955, 9.681134771820178, 10.715337514678573, 11.698204316725585, 11.562757444153348, 10.59413119600658, 9.61083196598496, 8.67474136204897, 7.6986573728618595, 6.684895002002284, 5.7437500425624615, 4.82770052169959, 3.9112613024028815, 2.9406536501695566, 2.028481388183648, 2.989495348428567, 3.958241104471032, 4.869103175697728, 5.828538251556006, 6.772645945635933, 7.781398053763902, 8.783004509065437, 9.855717933926345, 10.833741859343219, 10.831745957172064, 9.793961769250005, 8.781630741605563, 7.75401527664191, 6.783770155586282, 5.796779215448012, 4.803727396384946, 3.848598830517343, 2.913107978478835, 1.9790883560814116, 1.0715444931713125, 1.9876571035229562, 2.9385601883486436, 3.8920110706875457, 4.8613067238987, 5.817970523597817, 6.851788987341351, 7.920526919024102, 8.869710163074648, 9.883957308654432, 10.205101052932738, 9.156417955979208, 8.171003523462822, 7.121441374799504, 6.068451257110837, 5.004380626339778, 4.062314922799727, 3.079692473003922, 2.0231467042264715, 0.9761224764296859, 0.0, 0.9934358600863662, 1.9816159569813014, 3.0318692027434784, 3.9848030239753642, 4.993711541686687, 5.978893299612623, 6.976389920664054, 8.012900240101681, 9.045538743752463, 10.116093057958267, 9.834630038695742, 8.900494089517807, 7.929610048189478, 6.961744295115518, 5.96523551974278, 4.939773598559596, 3.885530817133802, 2.9370547653852537, 1.9518626037095026, 0.9860983107255143, 1.92547067591704, 2.9197862611833565, 3.9715717337778775, 4.920941562617209, 5.910835532408355, 6.90615273833972, 7.803773357970913, 8.769418335189094, 9.757276818206302, 10.818339548652721, 10.802377803907982, 9.827992541923045, 8.890461809019312, 7.876119192043777, 6.910309719746721, 5.889077444998743, 4.831480889587664, 3.9247047028735293, 2.9495697355919477, 1.9579857923881927, 2.899611293322379, 3.9135056081533657, 4.845420126409674, 5.818325328157606, 6.8899512313796, 7.81647880989097, 8.729020718048012, 9.695578531947232, 10.72257513997102, 11.670451384068034, 11.544040417800584, 10.599843531752814, 9.625649218786386, 8.666100624265647, 7.70970909828169, 6.748799816835513, 5.796253729832119, 4.860783599976508, 3.9395967585952727, 2.9225782026297, 3.8263491153029956, 4.7753848404102, 5.733403713648931, 6.675460215806382, 7.675017606566045, 8.607215281157705, 9.69995896692365, 10.752237889290592, 11.67514586891132, 12.645877901550872, 12.533501089034756, 11.538280209885867, 10.563800113682627, 9.659215935226865, 8.666822287458093, 7.724264566169708, 6.808944333653095, 5.822076544061802, 4.930625285337766, 3.9516862858858017, 4.892426716163887, 5.779115610867592, 6.686277452386318, 7.66068088820838, 8.635737266215243, 9.640232047911525, 10.653784854141254, 11.714668265819922, 12.687247161244297, 13.605668547636663, 13.453879068721346, 12.488023944563565, 11.533190694650573, 10.598314771096044, 9.604203764987457, 8.79901403010277, 7.752189347805169, 6.860463729256889, 5.878937065159591, 4.951736152105717, 5.903742728881918, 6.742872015045057, 7.750077364798788, 8.684523974944598, 9.60542267204021, 10.576335756850142, 11.5587762198821, 12.534766466824502, 13.543833015703914, 14.533202736846496, 14.493524743829624, 13.541290562415062, 12.559672025506774, 11.540621474789269, 10.547762737963636, 9.847520909005848, 8.799881669477651, 7.766056871498827, 6.820888156918858, 6.000889745428659, 6.845489706788467, 7.779838451368939, 8.764648997734866, 9.75493083763254, 10.57676572850124, 11.521549286087655, 12.551795619176419, 13.484192104523437, 14.43515943108351, 15.381113403596684, 14.689003810394855, 13.704326966545004, 12.770222927514379, 12.551950457253387, 11.579556565873299, 10.824601054759645, 9.765932935886042, 8.72199997306217, 7.752242202910905, 7.055499835854069, 7.819280564165593, 8.820230081155188, 9.733088289626792, 10.682975621857503, 11.574310895037739, 12.497998872898293, 13.503429390345937, 14.477016290944544, 15.416301485157385, 14.68848242769006, 13.748772952943463, 12.764957364879468, 11.832215086907917, 12.801356950260725, 12.58127837650996, 11.557326450672702, 10.61455568260491, 9.635564721675802, 8.687290514888339, 8.12104688064938, 8.887319811857022, 9.811238124427394, 10.69150433277726, 11.700392374343874, 12.583579341005738, 13.427053451494505, 14.46192375293674, 15.519191073527365, 14.61621546475421, 13.665606329066014, 12.781640781534236, 11.766475968408482, 10.831144829248522, 11.800636079176414, 12.72628898459721, 12.483930803518257, 11.580246135021685, 10.654214408121357, 9.679722402665352, 9.192934389377983, 9.947911920157564, 10.81419602318433, 11.67234860886959, 12.652093307905114, 13.538774938467979, 14.479945349661214, 15.389609386570916, 14.625643639678973, 13.623481015258179, 12.646492931169844, 11.733541125828006, 10.817331390085812, 9.873472288559347, 10.890572232338632, 11.71303369382707, 12.742679780169254, 12.627971247455104, 11.6569017859855, 10.727124686751669, 10.199907128211827, 10.920134075220199, 11.810751460143987, 12.693319366904335, 13.703299357933766, 14.556525034206253, 15.541592212882902], [15.561282584346408, 14.687387134723288, 13.754457785717962, 12.799461236201662, 11.88110697122729, 11.021800026767014, 11.976082913374945, 12.66908561686387, 13.614792254502593, 13.559161066927171, 12.657039563140042, 11.692693931206104, 10.76308193611402, 9.75262037647202, 9.055071976906797, 9.806376472510083, 10.681780728233377, 11.610984901104748, 12.629453272893157, 13.57152864094579, 14.489596826993385, 15.434616785091327, 14.761934396585668, 13.771942425343946, 12.904232270627984, 11.995629170337063, 13.008062606578854, 13.698210961250709, 13.480675542607516, 12.520110214828392, 11.587680633787265, 10.654862499974005, 9.802203877207234, 8.755429070474246, 8.007416435965355, 8.800273099837357, 9.645080917405025, 10.611159757875713, 11.626715440631076, 12.512286764646005, 13.483815039776738, 14.429543045603689, 15.433189222479758, 14.799764082026236, 13.874020525848275, 12.993646980316097, 14.003201166017018, 13.560874340614193, 12.5766472575465, 11.578721766769972, 10.749321366112396, 9.689454885330905, 8.7989919822725, 7.770467599413817, 6.98233315704923, 7.860874511402177, 8.673807292762342, 9.661407981824045, 10.588047432683517, 11.56405035032908, 12.556897615562816, 13.525980950713928, 14.570286387518836, 15.52512144828685, 14.935593680131285, 13.992023535414962, 13.453573697159554, 12.538058410730038, 11.558991164060894, 10.600810103929941, 9.730099764928989, 8.727308348455612, 7.819727723533675, 6.788711921073361, 5.918518967129523, 6.8058508183393664, 7.736536197885972, 8.713140413223535, 9.622555251461133, 10.523449577607964, 11.643026714274495, 12.613279736424284, 13.548975000698015, 14.57758601944662, 14.422484769937332, 13.504728408406924, 12.4866365887794, 11.588874331280419, 10.632426101169145, 9.586315493895452, 8.800533935852178, 7.774505234170259, 6.747107603924805, 5.833554640769547, 4.867491097818608, 5.849217118252793, 6.855210112403753, 7.6389773872097075, 8.609412474507687, 9.540156793961552, 10.658872161159737, 11.672712491523619, 12.654736793876186, 13.610630434188275, 13.483078578870279, 12.51565143201871, 11.533723179686387, 10.557851046933855, 9.591263224165411, 8.648536275262988, 7.801586379571185, 6.866688345926538, 5.798107786126623, 4.8891468687992115, 3.9400542298509538, 4.865725416266131, 5.8224580442621, 6.703138727191522, 7.646577436011263, 8.672897319164369, 9.783798167227006, 10.79008468183381, 11.759302742291105, 12.734028492890223, 12.538339048293201, 11.570822268299874, 10.645734316795176, 9.678875715929394, 8.68383746584893, 7.722153270828545, 6.777198140796051, 5.844031377679427, 4.851501242085526, 3.9064198114839956, 2.9461849166001044, 3.911399459702152, 4.838581366704712, 5.778119922311838, 6.7304653729416115, 7.684458700943184, 8.799243953208306, 9.833446696066702, 10.808928199071055, 11.771363495100584, 11.587567056092947, 10.604267826071327, 9.668177222135336, 8.692093232948226, 7.67833086208865, 6.737185902648828, 5.821136381785957, 4.9046971624892475, 3.934089510255923, 2.9793557365441226, 2.020095506427965, 2.9648052443846655, 3.875667315611362, 4.83510239146964, 5.7792100855495665, 6.787962193677536, 7.8281466706437595, 8.900860095504667, 9.878884020921541, 10.826756346879913, 10.787397629336372, 9.775066601691929, 8.747451136728277, 7.777206015672649, 6.790215075534379, 5.797163256471312, 4.842034690603709, 3.9065438385652014, 2.972524216167778, 2.022418841531787, 0.99422124343659, 1.9451243282622772, 2.8985752106011793, 3.8678708638123336, 4.824534663511451, 5.8583531272549845, 6.927091058937737, 7.876274302988284, 8.890521448568068, 9.87167453112615, 10.149853816065576, 9.16443938354919, 8.11487723488587, 7.0618871171972035, 5.997816486426144, 5.0557507828860935, 4.073128333090288, 3.0165825643128374, 1.969558336516052, 0.9934358600863662, 0.0, 0.9881800968949351, 2.0384333426571124, 2.9913671638889987, 4.000275681600321, 4.985457439526257, 5.982954060577688, 7.019464380015316, 8.052102883666098, 9.122657197871902, 10.1517695141053, 9.893929949604173, 8.923045908275844, 7.955180155201885, 6.958671379829147, 5.914869807526205, 4.860627026100412, 3.9121509743518637, 2.9269588126761126, 1.9611945196921243, 1.021822154500599, 1.9649284227616781, 2.9875785057762636, 3.936948334615595, 4.926842304406741, 5.912716878253354, 6.810337497884547, 7.775982475102727, 8.763840958119935, 9.824903688566355, 10.82991024830437, 10.821428402009412, 9.865558017985922, 8.851215401010387, 7.885405928713331, 6.864173653965353, 5.806577098554274, 4.899800911840139, 3.9246659445585577, 2.9330820013548027, 2.017720474710507, 2.9586477697316873, 3.8905622879879953, 4.863467489735928, 5.935093392957922, 6.861620971469293, 7.735584857961647, 8.702142671860864, 9.729139279884652, 10.677015523981666, 11.728682738647233, 11.574939740719424, 10.600745427752996, 9.641196833232257, 8.684805307248299, 7.723896025802123, 6.771349938798729, 5.835879808943118, 4.914692967561883, 3.89767441159631, 2.9444582966911237, 3.893494021798328, 4.851512895037059, 5.79356939719451, 6.793126787954173, 7.725324462545834, 8.706523106837283, 9.758802029204224, 10.681710008824952, 11.652442041464504, 12.647264782847513, 12.513376418852477, 11.538896322649236, 10.634312144193474, 9.641918496424703, 8.699360775136318, 7.784040542619705, 6.797172753028412, 5.905721494304376, 4.926782494852412, 4.010535897552015, 4.89722479225572, 5.804386633774446, 6.778790069596508, 7.753846447603371, 8.758341229299653, 9.660348994054887, 10.721232405733556, 11.693811301157929, 12.612232687550295, 13.608595306783277, 13.463120153530175, 12.508286903617183, 11.573410980062654, 10.579299973954065, 9.77411023906938, 8.727285556771779, 7.835559938223499, 6.854033274126201, 5.926832361072327, 5.021851910270046, 5.860981196433185, 6.868186546186916, 7.8026331563327265, 8.723531853428337, 9.69444493823827, 10.565340359795734, 11.541330606738136, 12.550397155617548, 13.539766876760128, 14.500006483306125, 13.81491847081566, 13.534768234473383, 12.515717683755877, 11.522858946930244, 10.822617117972458, 9.774977878444261, 8.741153080465438, 7.795984365885468, 6.92269603976377, 5.963598888176595, 6.8979476327570675, 7.8827581791229955, 8.873040019020667, 9.694874909889368, 10.639658467475783, 11.558359759090052, 12.49075624443707, 13.441723570997144, 14.387677543510318, 13.867993459075034, 12.883316615225183, 13.590117196410015, 13.527046666219995, 12.554652774839907, 11.799697263726255, 10.741029144852654, 9.69709618202878, 8.727338411877515, 7.9099927487316535, 6.9373897455537215, 7.938339262543315, 8.851197471014922, 9.801084803245631, 10.692420076425867, 11.616108054286421, 12.509993530259571, 13.483580430858177, 14.422865625071019, 13.719082585689458, 12.872858923780266, 11.943947013559647, 12.652109355803553, 13.621251219156363, 13.55637458547657, 12.532422659639312, 11.58965189157152, 10.610660930642412, 9.662386723854949, 8.975539793526965, 8.00542899324515, 8.929347305815522, 9.80961351416539, 10.818501555732004, 11.701688522393866, 12.545162632882633, 13.468487892850373, 14.525755213440998, 13.646815622753609, 12.696206487065412, 11.812240939533634, 10.945465617088662, 11.651039098144159, 12.62053034807205, 13.618355403619933, 13.459027012484867, 12.555342343988295, 11.629310617087967, 10.654818611631962, 10.00580622940713, 9.066021101545692, 9.932305204572458, 10.79045779025772, 11.770202489293244, 12.656884119856107, 13.598054531049343, 14.39617352648455, 13.656243797678371, 12.654081173257577, 11.677093089169242, 10.764141283827405, 9.996321038765991, 10.693366557454983, 11.719727012357929, 12.64367745226285, 13.673323538605034, 13.603067456421714, 12.631997994952112, 11.702220895718279, 10.99004190861655, 10.038243256608327, 10.928860641532115, 11.811428548292465, 12.821408539321896, 13.67463421559438, 14.65970139427103], [14.629614552452008, 13.755719102828888, 12.840634498103407, 11.885637948587107, 11.025720097850533, 11.96204797982536, 12.916330866433292, 13.61832737349633, 14.564034011135053, 14.48109588208479, 13.578974378297662, 12.614628746363724, 11.68501675127164, 10.67455519162964, 9.938431183502912, 8.92910818846955, 9.749770269611728, 10.6789744424831, 11.688036208620437, 12.583348544050855, 13.557928795098984, 14.502948753196927, 13.848111108971112, 12.85811913772939, 12.048845397251227, 12.935877123395409, 13.9483105596372, 14.64745271788317, 14.402610357765136, 13.442045029986012, 12.509615448944885, 11.576797315131625, 10.724138692364853, 9.677363885631866, 8.929351251122977, 7.9230048157968245, 8.713070458783376, 9.679149299254064, 10.638535343736141, 11.52410666775107, 12.552147007882338, 13.497875013709288, 14.501521190585358, 13.885940794411681, 13.018633652471518, 13.933894933374443, 14.943449119075364, 14.50993464219514, 13.525707559127445, 12.527782068350918, 11.671256181270016, 10.611389700488525, 9.720926797430122, 8.692402414571438, 7.904267972206851, 6.983606227361645, 7.741796834140692, 8.729397523202394, 9.599867335788582, 10.575870253434145, 11.625229583668416, 12.594312918819528, 13.638618355624436, 14.59345341639245, 14.080206806754529, 14.932271488473308, 14.4026339987405, 13.487118712310984, 12.50805146564184, 11.549870405510887, 10.652034580086607, 9.649243163613232, 8.741662538691296, 7.710646736230982, 6.840453782287144, 5.928582534298834, 6.804525739264322, 7.7249603163286, 8.634375154566198, 9.53526948071303, 10.711358682380094, 11.681611704529884, 12.617306968803614, 13.64591798755222, 14.5867273601968, 14.453788709987867, 13.435696890360346, 12.537934632861365, 11.581486402750091, 10.535375795476398, 9.722468751009796, 8.69644004932788, 7.669042419082425, 6.755489455927168, 5.789425912976228, 4.97194883421226, 5.867030015508819, 6.650797290314773, 7.621232377612752, 8.551976697066618, 9.727204129265337, 10.741044459629219, 11.723068761981786, 12.678962402293875, 13.647321169129746, 13.464711733599653, 12.482783481267333, 11.506911348514802, 10.540323525746357, 9.597596576843934, 8.723521194728804, 7.788623161084158, 6.720042601284243, 5.811081683956832, 4.861989045008574, 3.898778840119208, 4.834277947367165, 5.714958630296588, 6.658397339116329, 7.684717222269435, 8.803171521669208, 9.80945803627601, 10.771122645396169, 11.745848395995287, 12.702581638552669, 12.519882569880817, 11.594794618376119, 10.627936017510336, 9.632897767429874, 8.67121357240949, 7.704254912486574, 6.77108814936995, 5.773436057243146, 4.828354626641616, 3.8681197317577247, 2.944452883555229, 3.850401269809778, 4.789939825416903, 5.742285276046677, 6.696278604048249, 7.818617307650507, 8.852820050508903, 9.820748102176118, 10.783183398205647, 11.751809646352415, 11.553328127652271, 10.61723752371628, 9.64115353452917, 8.627391163669595, 7.686246204229773, 6.770196683366901, 5.831753934179771, 4.861146281946446, 3.901290551701743, 2.942030321585585, 1.9766251474897307, 2.887487218716427, 3.8469222945747057, 4.791029988654632, 5.799782096782601, 6.839966573748823, 7.912679998609731, 8.890703924026605, 9.838576249984976, 10.876360437907035, 10.724126903272873, 9.696511438309221, 8.726266317253593, 7.739275377115324, 6.746223558052257, 5.791094992184655, 4.855604140146147, 3.9215845177487236, 2.9443536566894073, 1.9161560585942103, 0.9569442313673422, 1.9103951137062445, 2.879690766917399, 3.8363545666165164, 4.87017303036005, 5.938910962042801, 6.888094206093347, 7.902341351673131, 8.883494434231213, 9.932177531184744, 10.152619480444123, 9.103057331780805, 8.050067214092138, 6.985996583321079, 6.043930879781028, 5.061308429985223, 4.0047626612077725, 2.957738433410987, 1.9816159569813014, 0.9881800968949351, 0.0, 1.0502532457621772, 2.0031870669940632, 3.012095584705386, 3.997277342631322, 4.994773963682753, 6.03128428312038, 7.063922786771163, 8.134477100976966, 9.163589417210364, 10.0977253663883, 9.88130695728643, 8.91344120421247, 7.916932428839731, 6.864111564158666, 5.809868782732872, 4.861392730984324, 3.8762005693085735, 2.9104362763245852, 1.9710639111330597, 0.9767483258667431, 1.9993984088813284, 2.94876823772066, 3.9386622075118063, 4.924536781358419, 5.822157400989612, 6.787802378207792, 7.775660861225, 8.836723591671419, 9.841730151409434, 10.819370792103674, 10.814799774618383, 9.800457157642848, 8.834647685345791, 7.8134154105978135, 6.755818855186734, 5.8490426684726, 4.873907701191018, 3.8823237579872636, 2.966962231342968, 1.970467672836752, 2.90238219109306, 3.8752873928409923, 4.946913296062986, 5.8734408745743565, 6.747404761066712, 7.7139625749659295, 8.740959182989718, 9.688835427086731, 10.740502641752297, 11.684699527800067, 11.549987184385456, 10.590438589864718, 9.63404706388076, 8.673137782434583, 7.72059169543119, 6.7851215655755786, 5.863934724194343, 4.846916168228771, 3.8937000533235846, 3.0381071484215716, 3.937689607422504, 4.861901365300109, 5.861458756059772, 6.793656430651433, 7.718343009942348, 8.77062193230929, 9.693529911930018, 10.664261944569569, 11.659084685952578, 12.62313620593312, 12.488138079281697, 11.583553900825935, 10.591160253057163, 9.648602531768779, 8.733282299252165, 7.746414509660872, 6.854963250936836, 5.876024251484873, 4.959777654184476, 4.041837918878964, 4.890563346159891, 5.847122037702107, 6.8221784157089695, 7.826673197405252, 8.672168897159953, 9.733052308838621, 10.705631204262994, 11.62405259065536, 12.620415209888343, 13.586270334046123, 13.457528660249643, 12.522652736695115, 11.528541730586525, 10.72335199570184, 9.67652731340424, 8.78480169485596, 7.803275030758662, 6.876074117704787, 5.962099863328391, 5.005594323056429, 5.954363258572361, 6.870965124438326, 7.791863821533936, 8.76277690634387, 9.577160262900799, 10.553150509843201, 11.562217058722613, 12.551586779865193, 13.51182638641119, 14.541600786609294, 14.484009991105843, 13.464959440388338, 12.472100703562704, 11.771858874604918, 10.724219635076722, 9.690394837097898, 8.745226122517929, 7.862943992822116, 6.90384684123494, 6.0425607593803115, 6.96893489150844, 7.941371987126266, 8.763206877994968, 9.707990435581383, 10.570179662195118, 11.502576147542136, 12.45354347410221, 13.399497446615383, 13.04668741209787, 13.766675821821298, 14.512052011567635, 14.476288422852456, 13.503894531472367, 12.748939020358716, 11.690270901485114, 10.64633793866124, 9.676580168509975, 8.85024070179, 7.877637698612067, 7.082952389166559, 7.937374183400366, 8.869416771351231, 9.760752044531467, 10.684440022392021, 11.521813433364636, 12.495400333963243, 13.434685528176084, 12.787072127067809, 11.995590639739733, 12.827306220155762, 13.574044170961173, 14.543186034313983, 14.50561634210903, 13.481664416271773, 12.538893648203981, 11.559902687274873, 10.61162848048741, 9.91578774658531, 8.945676946303497, 8.073960432438765, 8.895790226550835, 9.904678268117449, 10.770020490499466, 11.613494600988233, 12.480307795955438, 13.537575116546064, 12.71480516413196, 11.764196028443763, 10.934972655493102, 11.828824823684776, 12.572973913301778, 13.54246516322967, 14.540290218777553, 14.408268769117328, 13.504584100620756, 12.578552373720427, 11.604060368264422, 10.946054182465476, 10.006269054604038, 9.076918331195701, 9.876634502643165, 10.856379201678688, 11.725216087961707, 12.666386499154942, 13.407993429589615, 12.714826733405651, 11.722070714635928, 10.745082630547593, 9.886872999786872, 10.879680245362106, 11.615301372612603, 12.641661827515549, 13.56561226742047, 14.595258353762654, 14.552309213054174, 13.581239751584572, 12.65146265235074, 11.930289861674897, 10.978491209666673, 10.073473768155358, 10.89760526067791, 11.90758525170734, 12.74296618369998, 13.72803336237663], [13.661450184444114, 12.787554734820993, 11.881267271042542, 10.926270721526242, 11.865984898936937, 12.817068732244309, 13.77135161885224, 14.553931567271377, 15.499638204910099, 15.531349127846966, 14.629227624059837, 13.664881992125899, 12.735269997033816, 11.724808437391816, 10.893387120534886, 9.884064125501524, 8.899121243037317, 9.828325415908688, 10.728159499689884, 11.623471835120302, 12.58976442709109, 13.534784385189033, 12.888743881910248, 11.898751910668526, 12.889110198337631, 13.790897875814357, 14.803331312056148, 15.583056911658216, 15.45286360352731, 14.492298275748187, 13.55986869470706, 12.6270505608938, 11.77439193812703, 10.727617131394043, 9.890559028245, 8.877960752828798, 7.862421432208966, 8.828500272679655, 9.678658634805588, 10.564229958820517, 11.583982639874444, 12.529710645701394, 13.533356822577463, 12.926573567350816, 13.858898453557922, 14.788915685793391, 15.798469871494312, 15.560187887957317, 14.575960804889624, 13.578035314113096, 12.72150942703219, 11.6616429462507, 10.771180043192299, 9.742655660333615, 8.87441927812357, 7.93856216439362, 6.891147807566283, 7.802938139871709, 8.63999062685803, 9.615993544503592, 10.63428412147743, 11.603367456628542, 12.640486037105779, 13.58494317356568, 14.507738773019325, 15.500911905234062, 15.452887244502678, 14.537371958073162, 13.558304711404018, 12.600123651273066, 11.702287825848785, 10.699496409375406, 9.791915784453472, 8.760899981993159, 7.810605088203862, 6.884562092236518, 5.953876712689913, 6.765083607398048, 7.6744984456356455, 8.575392771782477, 9.702848439553323, 10.673101461703112, 11.608796725976845, 12.63740774472545, 13.546883243267725, 14.601861479129257, 14.485950136122524, 13.588187878623543, 12.63173964851227, 11.585629041238576, 10.772721996771974, 9.746693295090054, 8.719295664844601, 7.805742701689345, 6.839679158738406, 6.022202079974438, 5.01638098893441, 5.690920581384221, 6.6613556686822, 7.592099988136065, 8.718499685681946, 9.732340016045828, 10.714364318398395, 11.670257958710485, 12.607477052200672, 13.612784502741043, 13.533036727029511, 12.55716459427698, 11.590576771508536, 10.647849822606112, 9.773774440490982, 8.838876406846335, 7.7702958470464205, 6.86133492971901, 5.9122422907707515, 4.949032085881385, 3.983628920792756, 4.755081921366036, 5.698520630185777, 6.724840513338884, 7.763327404740134, 8.769613919346938, 9.731278528467094, 10.706004279066212, 11.662737521623594, 12.667955339022207, 12.645047864138297, 11.678189263272515, 10.683151013192052, 9.721466818171669, 8.754508158248752, 7.821341395132128, 6.823689303005323, 5.878607872403793, 4.918372977519902, 3.994706129317407, 2.9997522432353687, 3.8300631164863517, 4.782408567116126, 5.736401895117698, 6.7787731907214335, 7.81297593357983, 8.780903985247043, 9.743339281276572, 10.71196552942334, 11.69526475944496, 11.667490769478459, 10.691406780291349, 9.677644409431773, 8.736499449991951, 7.820449929129079, 6.882007179941949, 5.911399527708625, 4.951543797463921, 3.9922835673477626, 3.0268783932519083, 2.0368381921420182, 2.887045585644154, 3.831153279724081, 4.83990538785205, 5.800122456819749, 6.872835881680656, 7.85085980709753, 8.7883230042228, 9.826107192144859, 10.838438219789301, 10.7467646840714, 9.776519563015771, 8.789528622877501, 7.796476803814435, 6.841348237946832, 5.905857385908324, 4.971837763510901, 3.9946069024515847, 2.9664093043563877, 2.0071974771295196, 1.0597460871318358, 1.9198140579868475, 2.8764778576859653, 3.910296321429499, 4.888657716280624, 5.837840960331171, 6.852088105910955, 7.833241188469037, 8.881924285422567, 9.867338717938953, 10.153310577542983, 9.100320459854316, 8.036249829083257, 7.094184125543205, 6.1115616757474, 5.05501590696995, 4.0079916791731645, 3.0318692027434784, 2.0384333426571124, 1.0502532457621772, 0.0, 0.9529338212318861, 1.961842338943209, 2.9470240968691446, 3.9445207179205757, 4.981031037358203, 6.013669541008986, 7.08422385521479, 8.11333617144819, 9.047472120626125, 10.018356161954454, 9.9376235140594, 8.941114738686661, 7.888293874005596, 6.834051092579801, 5.885575040831253, 4.900382879155503, 3.9346185861715144, 2.995246220979989, 2.0009306357136722, 0.9491451631191512, 1.8985149919584827, 2.8884089617496294, 3.8742835355962413, 4.862280692059061, 5.827925669277241, 6.815784152294449, 7.876846882740868, 8.881853442478885, 9.859494083173125, 10.917102936115514, 10.824639467489778, 9.858829995192721, 8.837597720444743, 7.780001165033664, 6.873224978319529, 5.898090011037947, 4.860203146274107, 3.91857764533992, 2.8749294822885045, 1.9430149640321968, 2.9071230248330973, 3.9627609853465082, 4.8335967576452825, 5.787528052136161, 6.754085866035378, 7.781082474059167, 8.72895871815618, 9.780625932821746, 10.724822818869516, 11.699017131835944, 11.59850014195041, 10.642108615966452, 9.681199334520276, 8.728653247516881, 7.793183117661271, 6.848915980247163, 5.824795556515614, 4.845315467320536, 3.9363412536003715, 2.9783223803616408, 3.893736997292214, 4.893294388051877, 5.825492062643538, 6.758466301011797, 7.810745223378739, 8.733653202999466, 9.704385235639018, 10.699207977022027, 11.663259497002569, 12.637168026732185, 12.591615452911627, 11.599221805142856, 10.656664083854471, 9.741343851337856, 8.754476061746566, 7.8399445069896565, 6.811628445259919, 5.841426349941998, 4.896858671297913, 3.931196119099028, 4.878957669694212, 5.8540140477010745, 6.858508829397357, 7.7122921882294015, 8.77317559990807, 9.745754495332443, 10.664175881724809, 11.660538500957792, 12.626393625115572, 13.581226875028564, 13.530714288780807, 12.536603282672218, 11.731413547787533, 10.68458886548993, 9.734301828580257, 8.73887922453371, 7.8116783114798345, 6.81712061574734, 5.860615075475378, 4.994996031511497, 5.90280075643043, 6.823699453526041, 7.794612538335974, 8.617283553970246, 9.593273800912648, 10.60234034979206, 11.591710070934642, 12.55194967748064, 13.581724077678743, 14.607708205884766, 14.47302099247403, 13.480162255648397, 12.713323819234365, 11.665684579706168, 10.625999030872944, 9.680830316292976, 8.717964745241064, 7.758867593653889, 6.8975815117992605, 6.009567664447577, 6.97320761911837, 7.795042509987073, 8.739826067573489, 9.610302953264565, 10.542699438611583, 11.493666765171657, 12.43962073768483, 13.451934486731046, 14.436611330580897, 15.480937012017254, 15.484349974938148, 14.51195608355806, 13.690403964988162, 12.62587509526016, 11.581942132436287, 10.612184362285022, 9.705261454208948, 8.732658451031016, 7.923217190252963, 6.978006956339502, 7.901252403343335, 8.79258767652357, 9.716275654384127, 10.561936724434084, 11.53552362503269, 12.474808819245531, 11.936423100493398, 12.918972795854945, 13.782262157187738, 14.62429741672335, 15.593439280076158, 15.441220535884078, 14.41726861004682, 13.474497841979028, 12.49550688104992, 11.547232674262457, 10.770808499004259, 9.800697698722445, 8.914225233525169, 7.936422999489971, 8.945311041056586, 9.801856122491571, 10.645330232980339, 11.520431087024885, 12.577698407615511, 11.864156137557549, 10.913547001869352, 11.858354811608313, 12.783780760716752, 13.623227159063955, 14.592718408991846, 15.59054346453973, 15.343872962892375, 14.440188294395803, 13.514156567495474, 12.53966456203947, 11.801074934884424, 10.861289807022986, 9.917183132282105, 8.9172672755823, 9.897011974617824, 10.757051719953813, 11.698222131147048, 12.448116720659062, 11.754950024475098, 10.871421688061517, 9.894433603973182, 10.831040036465044, 11.834636182394082, 12.66555461837478, 13.691915073277727, 14.615865513182644, 15.645511599524829, 15.487913406829222, 14.516843945359618, 13.587066846125786, 12.785310614093845, 11.833511962085622, 10.913738569241762, 9.938238033617045, 10.948218024646476, 11.774801815692086, 12.759868994368736], [12.7268371524103, 11.899966534022248, 11.070441009137587, 11.87920454275813, 12.818918720168822, 13.770002553476195, 14.724285440084126, 15.506865388503263, 16.452572026141986, 16.413778423022464, 15.489257061692511, 14.445656397521535, 13.51567671230049, 12.50521515265849, 11.561858932008256, 10.552535936974895, 9.56759305451069, 8.975180128908063, 9.775225678457998, 10.670538013888418, 11.655151395057276, 12.600171353155218, 12.110606661818363, 12.851685731900414, 13.842044019569517, 14.743831697046243, 15.756265133288034, 16.535990732890102, 16.335292898702807, 15.374727570923685, 14.442297989882558, 13.509479856069298, 12.566755835752963, 11.519981029019975, 10.559030839718371, 9.546432564302169, 8.530893243682337, 7.917522146807652, 8.725724813573702, 9.611296137588633, 10.64936960784063, 11.59509761366758, 12.598743790543649, 13.62923484813343, 14.61637810607045, 15.546354639101041, 16.504062779498174, 16.442617183132814, 15.458390100065122, 14.460464609288595, 13.603938722207689, 12.544072241426198, 11.579196098126477, 10.535019557959547, 9.542891089596939, 8.60703397586699, 7.559619619039654, 6.850004318639823, 7.687056805626144, 8.663059723271708, 9.681350300245544, 10.650433635396656, 11.687552215873891, 12.632009352333792, 13.554804951787439, 14.547978084002176, 15.504869196941852, 15.41980125324866, 14.440734006579516, 13.482552946448564, 12.584717121024282, 11.581925704550905, 10.59993183938765, 9.553263879619092, 8.479076899677231, 7.553033903709888, 6.622348524163283, 5.812149786166162, 6.72156462440376, 7.622458950550592, 8.749914618321437, 9.720167640471226, 10.655862904744957, 11.684473923493563, 12.59394942203584, 13.64892765789737, 14.54929133932437, 14.470617173799042, 13.514168943687768, 12.468058336414074, 11.65515129194747, 10.629122590265553, 9.6017249600201, 8.663227862910997, 7.6971643199600575, 6.738404029256445, 5.68485280040778, 4.737986760152335, 5.708421847450313, 6.639166166904179, 7.7655658644500605, 8.779406194813943, 9.761430497166511, 10.7173241374786, 11.654543230968786, 12.659850681509157, 13.596377930231357, 13.439593889452478, 12.473006066684034, 11.53027911778161, 10.656203735666478, 9.721305702021832, 8.652725142221918, 7.718820090940661, 6.769727451992403, 5.806457376919979, 4.8025728686658695, 3.8021481001341493, 4.74558680895389, 5.771906692106997, 6.810393583508248, 7.816680098115051, 8.778344707235208, 9.753070457834326, 10.709803700391708, 11.715021517790321, 12.64010946929502, 12.560618558448013, 11.56558030836755, 10.603896113347167, 9.63693745342425, 8.703770690307627, 7.7061185981808205, 6.761037167579291, 5.8008022726954, 4.877135424492906, 3.8761820460696486, 2.8771292952544654, 3.829474745884239, 4.783468073885811, 5.825839369489548, 6.860042112347944, 7.8279701640151576, 8.790405460044687, 9.759031708191454, 10.742330938213074, 11.678421542149065, 11.573836075466847, 10.560073704607271, 9.61892874516745, 8.702879224304578, 7.7644364751174475, 6.793828822884123, 5.833973092639419, 4.8747128625232605, 3.9093076884274067, 2.913267994976298, 1.934111764412268, 2.878219458492195, 3.886971566620164, 4.847188635587863, 5.91990206044877, 6.897925985865644, 7.835389182990914, 8.873173370912973, 9.885504398557416, 10.913119863521068, 10.65894885819127, 9.671957918053, 8.678906098989934, 7.72377753312233, 6.7882866810838225, 5.854267058686399, 4.877036197627083, 3.848838599531886, 2.889626772305018, 1.9361758899661157, 0.9668802367549614, 1.923544036454079, 2.957362500197613, 3.9357238950487385, 4.884907139099285, 5.899154284679069, 6.880307367237151, 7.928990464190681, 8.914404896707067, 9.963967045370385, 10.053254281086202, 8.989183650315143, 8.047117946775092, 7.064495496979286, 6.007949728201836, 4.96092550040505, 3.9848030239753642, 2.9913671638889983, 2.0031870669940632, 0.9529338212318861, 0.0, 1.0089085177113228, 1.9940902756372587, 2.99158689668869, 4.0280972161263175, 5.0607357197771, 6.131290033982904, 7.1604023502163034, 8.09453829939424, 9.065422340722568, 10.033288093796529, 9.894048559918547, 8.841227695237482, 7.786984913811687, 6.838508862063139, 5.8533167003873885, 4.8875524074034, 3.9481800422118747, 2.953864456945558, 1.9020789843510373, 1.0109267911597357, 2.0008207609508823, 2.9213497143643554, 3.909346870827175, 4.874991848045355, 5.862850331062563, 6.923913061508983, 7.928919621246998, 8.90656026194124, 9.964169114883628, 10.978511731859163, 10.811763816424607, 9.790531541676629, 8.73293498626555, 7.826158799551415, 6.851023832269833, 5.813136967505993, 4.871511466571806, 3.827863303520391, 2.895948785264083, 2.0195348240343503, 3.075172784547761, 3.8806629364133967, 4.834594230904275, 5.801152044803493, 6.828148652827281, 7.776024896924294, 8.827692111589862, 9.771888997637632, 10.74608331060406, 11.705631905124799, 11.59504243719834, 10.634133155752163, 9.681587068748769, 8.746116938893158, 7.801849801479049, 6.7777293777475, 5.798249288552422, 4.889275074832258, 3.931256201593527, 3.0061487964934663, 4.005706187253129, 4.9078165285015345, 5.805532479779911, 6.8578114021468535, 7.780719381767581, 8.751451414407132, 9.746274155790141, 10.710325675770685, 11.684234205500301, 12.695558208506135, 12.552155626374743, 11.609597905086359, 10.694277672569743, 9.707409882978451, 8.792878328221542, 7.764562266491806, 6.794360171173885, 5.8497924925298, 4.884129940330914, 3.991369468895464, 4.966425846902327, 5.955650565669271, 6.759358366997516, 7.820241778676185, 8.792820674100557, 9.711242060492923, 10.707604679725906, 11.673459803883688, 12.62829305379668, 13.60165089596016, 13.489537103904105, 12.68434736901942, 11.637522686721818, 10.687235649812141, 9.691813045765596, 8.76461213271172, 7.770054436979227, 6.813548896707265, 5.947929852743384, 5.015212555631683, 5.936111252727294, 6.891754274607888, 7.66434973273836, 8.640339979680762, 9.649406528560174, 10.638776249702756, 11.599015856248753, 12.628790256446855, 13.654774384652882, 14.58550060281578, 14.433096076880284, 13.666257640466252, 12.618618400938056, 11.578932852104831, 10.633764137524862, 9.67089856647295, 8.711801414885775, 7.850515333031147, 6.962501485679463, 6.085619418319623, 6.907454309188325, 7.836967803845402, 8.65736913203268, 9.589765617379697, 10.540732943939771, 11.486686916452944, 12.49900066549916, 13.483677509349011, 14.528003190785368, 15.487187422002584, 15.464889904789947, 14.64333778622005, 13.578808916492047, 12.534875953668173, 11.565118183516908, 10.658195275440834, 9.685592272262902, 8.876151011484849, 7.930940777571389, 7.013664202544588, 7.904999475724824, 8.81341739065604, 9.6090029032022, 10.582589803800806, 11.521874998013647, 12.449479820032403, 13.432175482536719, 14.415991070600715, 15.382819757184643, 16.351961620537452, 16.394154357115966, 15.370202431278706, 14.427431663210914, 13.448440702281806, 12.500166495494343, 11.723742320236145, 10.75363151995433, 9.867159054757055, 8.889356820721858, 8.076125025401879, 8.914267921692824, 9.742471969252252, 10.567497265793001, 11.624764586383627, 11.079148484861966, 11.582018813342724, 12.526826623081686, 13.452252572190122, 14.403633874330628, 15.37312512425852, 16.370950179806403, 16.29680678412426, 15.393122115627689, 14.46709038872736, 13.492598383271355, 12.75400875611631, 11.814223628254872, 10.87011695351399, 9.870201096814188, 9.079832899676362, 9.869463519155065, 10.807005106550156, 11.495182899427178, 10.802016203243213, 10.018276401060891, 10.562905415446554, 11.499511847938416, 12.503107993867452, 13.445961333641453, 14.472321788544399, 15.39663991857828, 16.426286004920463, 16.440847228061106, 15.469777766591505, 14.540000667357672, 13.738244435325731, 12.786445783317507, 11.866672390473648, 10.891171854848933, 10.131038949705014, 10.887213614893339, 11.868651969771843], [11.717928634698977, 11.013734578815711, 11.891576054270582, 12.846572603786882, 13.81166369499966, 14.762747528307033, 15.717030414914964, 16.4996103633341, 17.44531700097282, 17.422686940733787, 16.498165579403835, 15.454564915232858, 14.524585230011812, 13.514123670369813, 12.570767449719579, 11.561444454686217, 10.57650157222201, 9.984088646619385, 9.047377620044086, 9.942689955474506, 10.646242877345953, 11.591262835443896, 12.547598146579757, 13.537590117821479, 14.570928462212061, 15.535463931368753, 16.490292821225015, 17.48233752552639, 17.34420141641413, 16.383636088635008, 15.45120650759388, 14.51838837378062, 13.575664353464285, 12.528889546731298, 11.567939357429694, 10.555341082013491, 9.539801761393658, 8.926430664518975, 7.997876755159791, 8.883448079174721, 9.640461090129307, 10.586189095956257, 11.589835272832326, 12.620326330422108, 13.607469588359127, 14.537446121389719, 15.495154261786851, 16.46751985488106, 16.467298617776443, 15.469373126999917, 14.612847239919011, 13.55298075913752, 12.5881046158378, 11.54392807567087, 10.551799607308261, 9.615942493578313, 8.568528136750976, 7.858912836351146, 6.959208747212232, 7.935211664857796, 8.672441782534221, 9.641525117685333, 10.678643698162569, 11.62310083462247, 12.545896434076116, 13.539069566290854, 14.49596067923053, 15.419135159846782, 15.449642524290839, 14.491461464159887, 13.593625638735604, 12.590834222262227, 11.608840357098973, 10.562172397330414, 9.487985417388554, 8.561942421421211, 7.631257041874606, 6.821058303877485, 5.993716565989848, 6.89461089213668, 7.7410061006101145, 8.711259122759904, 9.646954387033635, 10.67556540578224, 11.585040904324517, 12.640019140186048, 13.540382821613047, 14.469951080397163, 14.52307746139909, 13.476966854125397, 12.664059809658793, 11.638031107976875, 10.610633477731422, 9.672136380622321, 8.706072837671382, 7.747312546967768, 6.693761318119103, 5.746895277863658, 4.980573789036401, 5.911318108490267, 6.756657346738738, 7.770497677102619, 8.752521979455187, 9.708415619767276, 10.645634713257463, 11.650942163797835, 12.587469412520035, 13.563341545272566, 13.481914584395357, 12.539187635492933, 11.665112253377801, 10.730214219733154, 9.66163365993324, 8.727728608651985, 7.778635969703727, 6.815365894631302, 5.811481386377193, 4.811056617845472, 4.017738750539978, 4.971179269966633, 5.801485065796926, 6.807771580403728, 7.769436189523885, 8.744161940123004, 9.700895182680386, 10.706113000078998, 11.631200951583697, 12.59805955244948, 12.574488826078873, 11.61280463105849, 10.645845971135573, 9.71267920801895, 8.715027115892143, 7.7699456852906135, 6.809710790406722, 5.886043942204228, 4.885090563780972, 3.8860378129657884, 3.0287473237438753, 3.9827406517454476, 4.816930851778225, 5.851133594636622, 6.819061646303835, 7.781496942333365, 8.750123190480132, 9.733422420501752, 10.669513024437743, 11.645597013624853, 11.568982222318594, 10.627837262878773, 9.7117877420159, 8.77334499282877, 7.802737340595446, 6.842881610350742, 5.883621380234583, 4.918216206138729, 3.922176512687621, 2.943020282123591, 2.021206783702578, 2.9891396363476503, 3.8382801178765407, 4.910993542737447, 5.8890174681543215, 6.8264806652795915, 7.864264853201649, 8.876595880846091, 9.904211345809744, 10.874456466865372, 10.680866435764322, 9.687814616701257, 8.732686050833653, 7.797195198795145, 6.863175576397722, 5.885944715338406, 4.857747117243209, 3.8985352900163406, 2.9450844076774385, 1.9757887544662842, 1.0625154162061345, 1.9778274017124995, 2.9268153773374155, 3.8759986213879625, 4.890245766967746, 5.8713988495258285, 6.920081946479359, 7.9054963789957435, 8.955058527659062, 10.00804864534773, 9.998092168026465, 9.056026464486415, 8.07340401469061, 7.016858245913159, 5.969834018116374, 4.993711541686688, 4.000275681600321, 3.012095584705386, 1.961842338943209, 1.0089085177113228, 0.0, 0.9851817579259359, 1.9826783789773668, 3.0191886984149945, 4.051827202065777, 5.122381516271581, 6.15149383250498, 7.085629781682916, 8.056513823011244, 9.024379576085204, 10.020888351457943, 9.850136212948804, 8.79589343152301, 7.847417379774462, 6.862225218098711, 5.896460925114723, 4.957088559923197, 3.962772974656881, 2.91098750206236, 1.986722668933182, 0.9968286991420356, 1.9124411966530328, 2.929811772342062, 3.8954567495602426, 4.88331523257745, 5.94437796302387, 6.949384522761886, 7.9270251634561255, 8.984634016398514, 9.997454133151619, 10.963263605448676, 10.799440059387951, 9.741843503976872, 8.835067317262737, 7.859932349981156, 6.822045485217315, 5.880419984283129, 4.8367718212317135, 3.9048573029754055, 2.995330701807797, 2.0711807227389145, 2.871754418702074, 3.9239679998073407, 4.82161694631838, 5.848613554342169, 6.7964897984391826, 7.848157013104749, 8.79235389915252, 9.766548212118948, 10.726096806639687, 11.682488332623645, 11.643041673463486, 10.690495586460091, 9.75502545660448, 8.810758319190372, 7.7866378954588225, 6.807157806263745, 5.882020049663095, 4.924001176424364, 3.981944674266913, 3.119474232046593, 3.8989080107902114, 4.976169994837701, 5.878276303661741, 6.801184283282469, 7.77191631592202, 8.76673905730503, 9.730790577285573, 10.70469910701519, 11.716023110021023, 12.63960152180005, 12.618506422797681, 11.703186190281066, 10.716318400689774, 9.801786845932865, 8.757307241322643, 7.787105146004722, 6.8425374673606365, 5.876874915161751, 4.967165346668911, 4.0801938916957905, 4.946742047957947, 5.929995882055305, 6.933168304760763, 7.813285575615446, 8.731706962007811, 9.728069581240794, 10.693924705398576, 11.648757955311568, 12.622115797475049, 13.576982999329413, 13.693255886730743, 12.64643120443314, 11.67998062464298, 10.684558020596432, 9.757357107542557, 8.762799411810064, 7.806293871538101, 6.94067482757422, 5.9910084334051295, 5.049879297520757, 5.882845756896565, 6.9365016743244485, 7.9124919212668505, 8.757602354811711, 9.659241151217644, 10.619480757763641, 11.649255157961743, 12.67523928616777, 13.605965504330667, 14.520541972305592, 14.659002615297087, 13.61136337576889, 12.571677826935666, 11.626509112355699, 10.663643541303788, 9.704546389716613, 8.843260307861984, 7.9552464605103, 7.061415296093069, 6.021222353981789, 6.828059286134079, 7.929521073618768, 8.861917558965786, 9.72692859307114, 10.661889717757973, 11.658016140064785, 12.58085701355222, 13.624054996205215, 14.583239227422432, 15.552335800215255, 15.636082761050885, 14.571553891322882, 13.52762092849901, 12.557863158347745, 11.650940250271672, 10.67833724709374, 9.868895986315687, 8.923685752402227, 7.989460080318034, 7.018767520518288, 7.804508872944718, 8.881154844788288, 9.854741745386894, 10.794026939599735, 11.71688181189348, 12.699577474397795, 13.520226615217757, 14.487055301801686, 15.456197165154496, 16.47198053112237, 16.36294740610954, 15.42017663804175, 14.441185677112642, 13.49291147032518, 12.716487295066983, 11.746376494785169, 10.859904029587893, 9.882101795552694, 9.051920903175326, 8.028035966486287, 8.73356345154093, 9.83964920737909, 10.896916527969715, 11.840292862948573, 12.590927331054045, 13.535735140793006, 14.461161089901445, 15.412542392041951, 16.38203364196984, 17.379858697517726, 17.289551758955096, 16.385867090458525, 15.459835363558197, 14.485343358102192, 13.746753730947148, 12.80696860308571, 11.862861928344829, 10.862946071645025, 10.01809760070551, 8.983231563948529, 9.798096588838833, 10.767334841013266, 10.0741681448293, 11.027184918772214, 11.571813933157875, 12.508420365649737, 13.512016511578775, 14.454869851352775, 15.481230306255721, 16.405548436289603, 17.435194522631786, 17.433592202891944, 16.46252274142234, 15.532745642188509, 14.73098941015657, 13.779190758148346, 12.859417365304486, 11.88391682967977, 10.952173994838008, 10.000981659686802, 10.85974345206052], [10.73274687677304, 11.548951411196269, 12.587018454147055, 13.524889549037827, 14.59362315470733, 15.524111317012867, 16.478394203620798, 17.363147007282787, 18.30885364492151, 18.407868698659723, 17.48334733732977, 16.439746673158794, 15.509766987937748, 14.499305428295749, 13.555949207645515, 12.546626212612153, 11.561683330147947, 10.969270404545322, 9.994651387412102, 9.039280785993144, 9.661061119420017, 10.60608107751796, 11.562416388653821, 12.552408359895542, 13.585746704286125, 14.550282173442818, 15.505111063299081, 16.497155767600454, 17.44245698994468, 17.368817846560944, 16.436388265519817, 15.503570131706557, 14.560846111390221, 13.514071304657234, 12.55312111535563, 11.540522839939428, 10.524983519319594, 9.911612422444911, 8.945150522527806, 7.980038909693358, 8.65527933220337, 9.601007338030321, 10.60465351490639, 11.635144572496172, 12.622287830433192, 13.552264363463784, 14.509972503860917, 15.482338096955127, 16.46656518002282, 16.45455488492585, 15.598028997844947, 14.538162517063457, 13.573286373763736, 12.529109833596806, 11.536981365234197, 10.601124251504249, 9.553709894676912, 8.844094594277081, 7.906482514580247, 7.031802495376432, 7.687260024608285, 8.656343359759397, 9.693461940236633, 10.637919076696534, 11.560714676150182, 12.55388780836492, 13.510778921304595, 14.433953401920848, 15.472246088516236, 15.476643222085823, 14.57880739666154, 13.576015980188163, 12.59402211502491, 11.54735415525635, 10.47316717531449, 9.547124179347145, 8.616438799800541, 7.80624006180342, 6.940990333357863, 5.991201722655316, 6.755824342684178, 7.726077364833968, 8.661772629107698, 9.690383647856304, 10.599859146398583, 11.654837382260114, 12.555201063687113, 13.484769322471228, 14.495435799812087, 14.462148612051333, 13.64924156758473, 12.623212865902811, 11.595815235657358, 10.657318138548254, 9.691254595597314, 8.732494304893702, 7.678943076045038, 6.732077035789593, 5.927847556404417, 5.007908939008903, 5.771475588812802, 6.785315919176683, 7.767340221529251, 8.72323386184134, 9.660452955331529, 10.6657604058719, 11.6022876545941, 12.578159787346632, 13.544747610115076, 13.524369393418867, 12.650294011303737, 11.71539597765909, 10.646815417859177, 9.712910366577919, 8.763817727629661, 7.8005476525572375, 6.796663144303128, 5.7962383757714075, 4.965012517907994, 4.010466381331503, 4.81630330787099, 5.822589822477792, 6.78425443159795, 7.758980182197067, 8.715713424754451, 9.720931242153064, 10.646019193657763, 11.612877794523545, 12.607916044604007, 12.597986388984424, 11.63102772906151, 10.697860965944885, 9.70020887381808, 8.75512744321655, 7.794892548332658, 6.871225700130164, 5.870272321706907, 4.871219570891724, 3.9760210911118903, 3.022027763110318, 3.831749093852289, 4.8659518367106855, 5.8338798883779, 6.79631518440743, 7.764941432554197, 8.748240662575817, 9.684331266511808, 10.660415255698918, 11.674177626558494, 11.613019020804707, 10.696969499941835, 9.758526750754706, 8.787919098521382, 7.828063368276678, 6.868803138160519, 5.903397964064665, 4.907358270613557, 3.9282020400495266, 2.985155475026541, 2.0039578784217147, 2.8530983599506046, 3.9258117848115117, 4.903835710228386, 5.841298907353655, 6.879083095275713, 7.891414122920155, 8.919029587883808, 9.889274708939435, 10.876265649077705, 10.672996374627191, 9.717867808759587, 8.78237695672108, 7.848357334323658, 6.871126473264342, 5.842928875169145, 4.883717047942277, 3.930266165603374, 2.96097051239222, 2.0264641075300975, 0.9926456437865636, 1.9416336194114798, 2.890816863462027, 3.9050640090418103, 4.886217091599892, 5.9349001885534225, 6.920314621069807, 7.969876769733126, 9.022866887421793, 9.99656148693501, 10.041208222412351, 9.058585772616546, 8.002040003839095, 6.95501577604231, 5.978893299612624, 4.985457439526257, 3.997277342631322, 2.9470240968691446, 1.9940902756372587, 0.9851817579259359, 0.0, 0.997496621051431, 2.034006940489059, 3.0666454441398416, 4.137199758345646, 5.166312074579045, 6.1004480237569805, 7.071332065085309, 8.039197818159268, 9.035706593532007, 10.088527458213072, 9.781075189448947, 8.832599137700399, 7.847406976024647, 6.881642683040659, 5.942270317849133, 4.947954732582817, 3.8961692599882958, 2.971904426859118, 1.9820104570679715, 0.9272594387270968, 1.9446300144161257, 2.9102749916343065, 3.898133474651514, 4.959196205097934, 5.9642027648359495, 6.941843405530189, 7.999452258472578, 9.012272375225683, 9.97808184752274, 10.999314122270718, 10.727025261902808, 9.820249075188674, 8.845114107907092, 7.774819526499345, 6.833194025565159, 5.7895458625137435, 4.8576313442574355, 3.884726142509503, 2.813100239287509, 1.8865726607761384, 2.9387862418814046, 3.836435188392444, 4.863431796416233, 5.8113080405132465, 6.862975255178813, 7.807172141226583, 8.781366454193012, 9.74091504871375, 10.69730657469771, 11.658215856143885, 11.624190114324005, 10.688719984468394, 9.744452847054285, 8.720332423322736, 7.694592418718987, 6.745556693611782, 5.787537820373051, 4.8454813182156, 3.8459239274559365, 2.913726252864276, 3.9909882369117646, 4.893094545735805, 5.816002525356533, 6.786734557996084, 7.781557299379093, 8.745608819359635, 9.719517349089253, 10.730841352095087, 11.654419763874113, 12.63368060547808, 12.63688071814498, 11.650012928553688, 10.689185883722907, 9.620843885271329, 8.650641789953408, 7.706074111309324, 6.740411559110438, 5.830318005273169, 4.806643587105134, 3.961560290032012, 4.944814124129369, 5.9479865468348265, 6.8281038176895095, 7.746525204081876, 8.74288782331486, 9.70874294747264, 10.663576197385632, 11.636934039549113, 12.591801241403477, 13.619162003812086, 13.57957852981328, 12.543517268591664, 11.548094664545118, 10.620893751491243, 9.62633605575875, 8.669830515486789, 7.72263428728189, 6.758372237664679, 5.7763289929301, 4.897663998970629, 5.990977253521708, 6.96696750046411, 7.772420596885775, 8.674059393291708, 9.634298999837705, 10.664073400035807, 11.690057528241834, 12.620783746404731, 13.535360214379656, 14.4804095061526, 14.474900019717579, 13.435214470884354, 12.490045756304385, 11.527180185252474, 10.5680830336653, 9.70679695181067, 8.73720592021797, 7.8151953786878074, 6.747672049391132, 5.8428775282081435, 7.026111904137404, 7.916393138163046, 8.741746835145204, 9.676707959832036, 10.672834382138848, 11.595675255626285, 12.63887323827928, 13.598057469496496, 14.567154042289319, 15.457489651906398, 15.43509053527157, 14.391157572447696, 13.421399802296431, 12.514476894220358, 11.541873891042426, 10.650855446023357, 9.705645212109896, 8.743240162912771, 7.745217215927631, 6.819327115018782, 7.977745675306923, 8.943548384867976, 9.813176207179096, 10.731700053967543, 11.71439571647186, 12.53504485729182, 13.50187354387575, 14.47101540722856, 15.486798773196433, 16.479477053744002, 16.283713281990437, 15.304722321061329, 14.356448114273865, 13.58002393901567, 12.609913138733855, 11.641863489295563, 10.664061255260364, 9.795895410796243, 8.734936682711199, 7.748381693614993, 8.936240037897727, 9.99217629571429, 10.859442130527933, 11.75457615259159, 12.69938396233055, 13.533526253762806, 14.499368827309105, 15.468860077236997, 16.46668513278488, 17.406081406589557, 17.24940373440721, 16.323372007506883, 15.348880002050878, 14.584191981844237, 13.6444068539828, 12.644821388052499, 11.644905531352695, 10.72499831693042, 9.69013228017344, 8.812914830912897, 9.863925671531904, 10.817293968364588, 11.827389725712061, 12.556995691083811, 13.493602123575673, 14.482670832085477, 15.440051609278711, 16.434120173661576, 17.39073019421554, 18.420376280557722, 18.29712884684063, 17.32605938537103, 16.396282286137197, 15.568427661053658, 14.616629009045434, 13.641376825012156, 12.66587628938744, 11.65907471106292, 10.707882375911714, 9.874561694134584], [9.892750212702673, 10.708954747125903, 11.747021790076689, 12.68489288496746, 13.631895345216861, 14.54080527717555, 15.495088163783482, 16.512156712858715, 17.387604389085126, 18.340013471107632, 18.36273877839343, 17.319138114222454, 16.38915842900141, 15.378696869359409, 14.435340648709175, 13.463076837692723, 12.478133955228516, 11.85616103430898, 10.837692662520572, 9.879752717062466, 8.82106445534965, 9.766084413447594, 10.722419724583455, 11.712411695825176, 12.608770045816167, 13.566976133605502, 14.521805023461765, 15.51384972776314, 16.459150950107368, 17.41971627788649, 17.37393515638044, 16.44111702256718, 15.47729673647079, 14.430521929737802, 13.4695717404362, 12.456973465019997, 11.441434144400164, 10.82806304752548, 9.83902230503611, 8.873910692201662, 7.815282668133004, 8.761010673959955, 9.764656850836024, 10.715455969100468, 11.638981790595876, 12.568958323626468, 13.5266664640236, 14.499032057117812, 15.483259140185506, 16.425032771649903, 16.53557588870557, 15.47570940792408, 14.489736998844304, 13.445560458677374, 12.453431990314765, 11.517574876584819, 10.470160519757481, 9.76054521935765, 8.800354297088552, 7.925674277884736, 6.847263360537919, 7.816346695689031, 8.767585741039886, 9.700837145893514, 10.577408636312866, 11.570581768527603, 12.527472881467279, 13.450647362083533, 14.488940048678922, 15.447121108809874, 15.516354287522162, 14.513562871048787, 13.510472740105477, 12.463804780336918, 11.389617800395058, 10.463574804427715, 9.53288942488111, 8.72269068688399, 7.8348621158661675, 6.8850735051636205, 5.915827678613812, 6.886080700763602, 7.7358964299109525, 8.753301717053285, 9.616553106561266, 10.6715313424228, 11.571895023849798, 12.501463282633914, 13.512129759974773, 14.44194773781265, 14.586788458445351, 13.560759756763435, 12.53336212651798, 11.573768763628825, 10.607705220677886, 9.648944929974272, 8.595393701125607, 7.648527660870163, 6.821719338912721, 5.901780721517207, 4.931478924742436, 5.942872542568876, 6.7961481381308655, 7.752041778442955, 8.677146915494212, 9.682454366034586, 10.618981614756786, 11.594853747509317, 12.561441570277761, 13.504168519180185, 13.58784090216436, 12.652942868519713, 11.584362308719799, 10.629360991658489, 9.68026835271023, 8.716998277637806, 7.713113769383698, 6.712689000851977, 5.858884300416298, 4.904338163839808, 3.9763066438006236, 4.883681803764489, 5.800948391760635, 6.775674142359752, 7.732407384917136, 8.73762520231575, 9.662713153820448, 10.62957175468623, 11.624610004766694, 12.616983914340718, 12.56857461992213, 11.635407856805505, 10.637755764678701, 9.692674334077171, 8.73243943919328, 7.808772590990786, 6.807819212567529, 5.787670195972293, 4.869892873620194, 3.915899545618622, 2.991752429781923, 3.927043817997382, 4.850573848540584, 5.813009144570114, 6.781635392716882, 7.764934622738503, 8.701025226674494, 9.677109215861604, 10.69087158672118, 11.632016546161001, 11.634516390802458, 10.696073641615326, 9.725465989382002, 8.765610259137299, 7.806350029021141, 6.840944854925287, 5.844905161474179, 4.844652665130095, 3.900544971050168, 2.8978296609300185, 2.0131016958802386, 2.9563645480063565, 3.9205296703910713, 4.843802286302225, 5.8815864742242825, 6.893917501868724, 7.921532966832377, 8.891778087888005, 9.878769028026275, 10.871820847089342, 10.655414699620211, 9.719923847581704, 8.78590422518428, 7.808673364124964, 6.780475766029767, 5.821263938802899, 4.867813056463996, 3.898517403252842, 2.9418536035537244, 1.9080351398101905, 0.9441369983600487, 1.8933202424105957, 2.9075673879903796, 3.8887204705484617, 4.937403567501992, 5.922818000018377, 6.972380148681696, 8.025370266370363, 8.999064865883577, 9.941130569423628, 10.056082393667976, 8.999536624890526, 7.952512397093741, 6.9763899206640545, 5.982954060577688, 4.994773963682753, 3.9445207179205752, 2.9915868966886894, 1.9826783789773668, 0.997496621051431, 0.0, 1.0365103194376277, 2.06914882308841, 3.139703137294214, 4.168815453527613, 5.102951402705549, 6.073835444033877, 7.0417011971078365, 8.038209972480574, 9.09103083716164, 10.145273618587433, 9.83009575875183, 8.844903597076078, 7.87913930409209, 6.939766938900564, 5.9454513536342475, 4.893665881039727, 3.969401047910549, 2.9795070781194024, 1.9247560597785278, 0.9560507691806284, 1.9216957463988091, 2.909554229416017, 3.9706169598624363, 4.975623519600452, 5.953264160294692, 7.010873013237081, 8.014775754174252, 8.980585226471309, 10.001817501219287, 11.059414056630366, 10.817745696240104, 9.842610728958523, 8.772316147550777, 7.83069064661659, 6.787042483565175, 5.855127965308867, 4.882222763560934, 3.81059686033894, 2.8840692818275695, 1.9502069966459072, 2.847855943156947, 3.8748525511807355, 4.822728795277749, 5.8743960099433155, 6.8185928959910855, 7.792787208957515, 8.752335803478253, 9.708727329462212, 10.669636610908388, 11.622182697911782, 11.686216605519824, 10.741949468105716, 9.717829044374167, 8.692089039770417, 7.743053314663213, 6.785034441424481, 5.842977939267031, 4.843420548507368, 3.911222873915707, 3.0024089916762673, 3.9045153005003073, 4.827423280121035, 5.798155312760587, 6.792978054143596, 7.757029574124138, 8.730938103853756, 9.74226210685959, 10.665840518638616, 11.645101360242583, 12.574952373459682, 12.647509549605118, 11.686682504774339, 10.618340506322761, 9.64813841100484, 8.703570732360754, 7.7379081801618685, 6.8278146263246, 5.804140208156565, 4.959056911083443, 3.9562348788938717, 4.959407301599329, 5.839524572454012, 6.757945958846379, 7.754308578079362, 8.720163702237144, 9.674996952150137, 10.648354794313617, 11.603221996167978, 12.630582758576587, 13.518197387611757, 13.541013889643096, 12.54559128559655, 11.618390372542676, 10.623832676810181, 9.66732713653822, 8.720130908333322, 7.755868858716111, 6.773825613981532, 5.89516062002206, 5.00239800828621, 5.978388255228612, 6.783841351650278, 7.685480148056211, 8.645719754602208, 9.675494154800312, 10.701478283006338, 11.632204501169236, 12.546780969144157, 13.491830260917101, 14.539469500445298, 14.432711091935786, 13.487542377355817, 12.524676806303905, 11.56557965471673, 10.704293572862102, 9.734702541269403, 8.812691999739238, 7.745168670442563, 6.840374149259574, 6.04620924821085, 6.927813892927548, 7.753167589909706, 8.68812871459654, 9.684255136903351, 10.607096010390789, 11.650293993043784, 12.609478224261, 13.57857479705382, 14.468910406670899, 15.54298315965639, 15.388654193499129, 14.418896423347864, 13.511973515271789, 12.539370512093857, 11.64835206707479, 10.703141833161329, 9.740736783964202, 8.742713836979062, 7.788052921814314, 6.997843019380369, 7.954969139632478, 8.824596961943598, 9.743120808732046, 10.725816471236362, 11.546465612056325, 12.513294298640254, 13.482436161993064, 14.498219527960938, 15.490897808508503, 16.433668576576295, 16.30221894211276, 15.353944735325298, 14.5775205600671, 13.607409759785286, 12.639360110346995, 11.661557876311797, 10.764621217591776, 9.703662489506732, 8.717107500410526, 7.967794857921758, 9.003597050478792, 9.870862885292436, 10.765996907356092, 11.710804717095053, 12.544947008527311, 13.51078958207361, 14.480280832001501, 15.478105887549384, 16.417502161354058, 17.39650141247961, 17.320868628558316, 16.34637662310231, 15.58168860289567, 14.641903475034232, 13.642318009103931, 12.642402152404127, 11.693724123725953, 10.658858086968973, 9.78164063770843, 8.895480491555935, 9.848848788388619, 10.858944545736092, 11.785110305252262, 12.721716737744124, 13.494091586849981, 14.463737109059522, 15.445540928426079, 16.440511353814387, 17.47015744015657, 18.444226524913027, 18.32355600642246, 17.393778907188626, 16.47616069934246, 15.524362047334238, 14.584141674912036, 13.644745667045857, 12.627800517858452, 11.676608182707247, 10.843287500930117], [10.910367328052056, 10.087307474755256, 11.003243333604802, 11.83500944217333, 12.75114597246515, 13.660055904423839, 14.61433879103177, 15.631407340107002, 16.50685501633341, 17.459264098355916, 17.435668805882617, 16.39206814171164, 15.462088456490594, 14.451626896848595, 13.50827067619836, 12.752411576550632, 11.853352693677312, 11.047761268735526, 10.188442902439652, 10.89988597344918, 9.838681570699032, 9.144437141076947, 9.963077680924027, 10.862528253031046, 11.728020673064455, 12.68622676085379, 13.641055650710053, 14.633100355011427, 15.578401577355653, 16.538966905134775, 17.4713964861759, 17.42989957294374, 16.456445522092213, 15.448818202846368, 14.495741794830737, 13.483143519414535, 12.467604198794701, 11.854233101920018, 10.859155561422826, 9.894043948588378, 8.832899783482386, 8.139363401589309, 8.896761756155373, 9.834706596348756, 10.758232417844164, 11.688208950874756, 12.645917091271889, 13.618282684366099, 14.602509767433792, 15.544283398898191, 16.478651708349073, 16.51221972736171, 15.515907053238841, 14.471730513071911, 13.479602044709303, 12.543744930979356, 11.496330574152019, 10.786715273752188, 9.820487553475267, 8.945807534271452, 7.8648804758873005, 7.076562056756306, 7.886836368288173, 8.8200877731418, 9.696659263561154, 10.689832395775891, 11.646723508715567, 12.56989798933182, 13.608190675927208, 14.56637173605816, 15.514339446410848, 15.550073190486415, 14.536642794500015, 13.489974834731456, 12.415787854789595, 11.489744858822252, 10.559059479275648, 9.748860741278527, 8.854995372252883, 7.905206761550336, 6.933444793963194, 6.065570731919639, 6.85514705715924, 7.872552344301572, 8.735803733809554, 9.790781969671086, 10.691145651098084, 11.6207139098822, 12.631380387223059, 13.561198365060935, 14.584773617334037, 14.597270076201063, 13.569872445955609, 12.599938818023363, 11.633875275072423, 10.67511498436881, 9.621563755520144, 8.6746977152647, 7.841852595299437, 6.921913977903923, 5.949096040091817, 5.062123169817164, 5.915398765379153, 6.871292405691242, 7.7963975427425005, 8.801704993282872, 9.738232242005072, 10.714104374757603, 11.680692197526048, 12.623419146428471, 13.585826061053044, 13.68945318795734, 12.620872628157427, 11.655531046053026, 10.706438407104768, 9.743168332032344, 8.739283823778234, 7.738859055246513, 6.879017556803014, 5.924471420226523, 4.993923759150005, 4.002932431012776, 4.920199019008922, 5.894924769608039, 6.851658012165423, 7.856875829564036, 8.781963781068734, 9.748822381934517, 10.743860632014979, 11.736234541589006, 12.768468954122252, 12.671918176243134, 11.67426608411633, 10.7291846535148, 9.768949758630908, 8.845282910428413, 7.836073474426336, 6.8138402503668285, 5.89002613000691, 4.936032802005338, 4.009369545131304, 3.0462944452456693, 3.9698244757888714, 4.932259771818401, 5.900886019965169, 6.88418524998679, 7.820275853922782, 8.796359843109892, 9.810122213969468, 10.751267173409289, 11.758153671606362, 11.732583961052955, 10.76197630881963, 9.802120578574927, 8.84286034845877, 7.877455174362915, 6.873159423332986, 5.8708227195246305, 4.926715025444704, 3.9179629173167347, 3.0307188112296197, 2.0756151752546437, 3.039780297639358, 3.963052913550512, 5.00083710147257, 6.0131681291170125, 7.040783594080665, 8.011028715136293, 8.945851400830495, 9.932826038179925, 10.820444315946455, 10.756434167019332, 9.822414544621909, 8.845183683562592, 7.816986085467394, 6.857774258240526, 5.904323375901623, 4.935027722690469, 3.9783639229913517, 2.944545459247818, 1.9617541137094296, 1.0125708696588827, 2.0268180152386663, 3.0079710977967484, 4.056654194750279, 5.042068627266664, 6.091630775929983, 7.049305557069366, 7.96255454644595, 8.904620249986001, 9.887242699781806, 10.036046944328152, 8.989022716531368, 8.012900240101683, 7.019464380015316, 6.031284283120381, 4.981031037358203, 4.0280972161263175, 3.019188698414995, 2.034006940489059, 1.0365103194376277, 0.0, 1.0326385036507826, 2.1031928178565864, 3.1323051340899855, 4.066441083267922, 5.03732512459625, 6.005190877670209, 7.001699653042947, 8.054520517724013, 9.108763299149807, 10.057239350898355, 9.881413916513704, 8.915649623529717, 7.976277258338192, 6.981961673071876, 5.930176200477355, 5.005911367348177, 4.016017397557031, 2.9612663792161555, 1.992561088618256, 1.073865189910828, 1.9603550068082742, 3.0214177372546933, 4.026424296992709, 4.99393953567316, 6.033350256572373, 6.978265434736624, 7.944074907033681, 8.96530718178166, 10.022903737192738, 10.988251520053437, 10.879121048396149, 9.808826466988403, 8.867200966054217, 7.823552803002801, 6.891638284746493, 5.918733082998561, 4.847107179776567, 3.920579601265197, 2.9703402530326235, 2.0000253866689657, 2.9477825786699214, 3.8956588227669355, 4.947326037432502, 5.891522923480272, 6.865717236446701, 7.8252658309674406, 8.7816573569514, 9.742566638397575, 10.69511272540097, 11.63058285525658, 11.778459787543344, 10.754339363811795, 9.728599359208046, 8.77956363410084, 7.82154476086211, 6.879488258704659, 5.879930867944996, 4.947733193353335, 4.022542248062983, 3.056684744012326, 3.9003533076102213, 4.871085340249773, 5.865908081632782, 6.829959601613324, 7.803868131342941, 8.815192134348775, 9.738770546127803, 10.71803138773177, 11.64788240094887, 12.591875799341874, 12.723192824211967, 11.65485082576039, 10.684648730442468, 9.740081051798382, 8.774418499599497, 7.864324945762228, 6.840650527594193, 5.995567230521071, 4.9763681352805875, 4.111576745111348, 4.9124545999431986, 5.830875986335565, 6.827238605568549, 7.79309372972633, 8.747926979639322, 9.721284821802803, 10.676152023657167, 11.703512786065776, 12.591127415100944, 13.62718867632256, 13.582101605034179, 12.654900691980304, 11.66034299624781, 10.703837455975847, 9.75664122777095, 8.79237917815374, 7.81033593341916, 6.913523263013285, 6.022531264672926, 5.166722315163764, 5.856771379139465, 6.758410175545397, 7.718649782091394, 8.748424182289497, 9.774408310495524, 10.705134528658421, 11.619710996633346, 12.56476028840629, 13.612399527934487, 14.652085076767712, 14.524052696793445, 13.561187125741533, 12.602089974154358, 11.74080389229973, 10.771212860707031, 9.849202319176866, 8.781678989880191, 7.858736792250799, 7.066342504597566, 6.1161479528627, 6.826097617398894, 7.7610587420857255, 8.757185164392538, 9.680026037879975, 10.72322402053297, 11.682408251750186, 12.651504824543009, 13.541840434160088, 14.61591318714558, 15.659846149969454, 15.455406742785492, 14.548483834709417, 13.575880831531485, 12.684862386512417, 11.739652152598957, 10.77724710340183, 9.77922415641669, 8.805670037163695, 8.017976275767085, 7.1433031995676295, 7.897526989432786, 8.816050836221232, 9.798746498725547, 10.61939563954551, 11.58622432612944, 12.55536618948225, 13.571149555450123, 14.563827835997692, 15.506598604065484, 16.485589564994594, 16.390455054762928, 15.614030879504728, 14.643920079222914, 13.675870429784624, 12.698068195749425, 11.782238332941157, 10.721279604856113, 9.734724615759907, 8.987928114308474, 8.191931110413943, 8.943792912781623, 9.838926934845277, 10.783734744584239, 11.617877036016496, 12.583719609562795, 13.553210859490687, 14.55103591503857, 15.490432188843247, 16.469431439968798, 17.395463166869124, 17.38288694253994, 16.5556199575066, 15.615834829645161, 14.67882832854156, 13.678912471841755, 12.711341239075335, 11.676475202318354, 10.79925775305781, 9.91561374794265, 9.161652377654438, 10.004664996582697, 10.858040332741448, 11.79464676523331, 12.567021614339167, 13.536667136548708, 14.518470955915264, 15.513441381303572, 16.543087467645755, 17.517156552402216, 17.48964927588389, 16.598272061252594, 15.59541132659075, 14.643612674582526, 13.703392302160324, 12.823042130082527, 11.942645393037376, 11.100060393884164, 11.860904616279498], [11.783994370422922, 10.858555557019889, 10.049219826356099, 10.88098593492463, 11.797122465216448, 12.706032397175138, 13.660315283783069, 14.6773838328583, 15.552831509084712, 16.505240591107217, 16.403030302231837, 15.35942963806086, 14.429449952839814, 13.418988393197814, 12.47563217254758, 11.71977307289985, 10.82071419002653, 10.015122765084742, 10.816721389885137, 11.592108332280734, 10.712308613069899, 9.91568522334158, 9.009054173675324, 9.908504745782345, 10.773997165815754, 11.732203253605089, 12.687032143461352, 13.679076847762726, 14.624378070106951, 15.584943397886075, 16.517372978927202, 16.39726106929296, 15.423807018441435, 14.416179699195588, 13.523287713489022, 12.725876445572576, 11.857414000854883, 11.072780747185153, 11.700865357686698, 10.636351601344394, 9.706526825853253, 8.910611483853941, 7.942738248906672, 8.880683089100055, 9.804208910595463, 10.734185443626055, 11.691893584023187, 12.664259177117398, 13.648486260185091, 14.59025989164949, 15.52462820110037, 16.513614679764785, 16.357616849502712, 15.313440309335782, 14.321311840973173, 13.385454727243227, 12.33804037041589, 11.628425070016059, 10.66219734973914, 9.73696811454171, 8.738507518258167, 7.847810139020938, 6.932812861039472, 7.8660642658931, 8.742635756312453, 9.73580888852719, 10.692700001466866, 11.615874482083118, 12.654167168678507, 13.61234822880946, 14.560315939162146, 15.55146814288949, 15.378352590763885, 14.331684630995326, 13.257497651053466, 12.331454655086123, 11.400769275539519, 10.590570537542398, 9.696705168516756, 8.746916557814208, 7.807071836334059, 6.83681881418427, 5.901123549910539, 6.918528837052871, 7.781780226560852, 8.836758462422383, 9.737122143849383, 10.666690402633499, 11.677356879974358, 12.607174857812236, 13.630750110085335, 14.598665028604138, 14.458531320730232, 13.441648614287233, 12.475585071336294, 11.51682478063268, 10.463273551784015, 9.51640751152857, 8.68356239156331, 7.763623774167796, 6.950112245213887, 5.943399560483019, 4.9613752581304515, 5.917268898442541, 6.842374035493799, 7.84768148603417, 8.78420873475637, 9.760080867508902, 10.726668690277346, 11.66939563917977, 12.631802553804343, 13.56670058744899, 13.50953150293205, 12.497240842316897, 11.548148203368639, 10.584878128296214, 9.580993620042104, 8.580568851510384, 7.720727353066886, 6.766181216490396, 5.994939964272075, 4.955305756354289, 3.9661755117602207, 4.940901262359338, 5.897634504916722, 6.902852322315335, 7.827940273820033, 8.794798874685815, 9.78983712476628, 10.782211034340305, 11.81444544687355, 12.675515979669775, 12.562924958890953, 11.617843528289423, 10.657608633405532, 9.707423906340324, 8.677783270690208, 7.655550046630699, 6.731735926270782, 5.77774259826921, 5.0328705134455785, 3.998667770587182, 3.0158009685401703, 3.9782362645697003, 4.946862512716468, 5.930161742738089, 6.866252346674081, 7.842336335861191, 8.856098706720767, 9.797243666160588, 10.766907503477919, 11.736181764479596, 11.650635183594254, 10.69077945334955, 9.731519223233393, 8.747853157828093, 7.7148692195968565, 6.712532515788502, 5.768424821708575, 4.759672713580606, 4.0633573148804025, 3.063780715807531, 2.085756790390657, 2.9983090361728606, 4.036093224094919, 5.048424251739361, 6.041227541107839, 7.011472662163467, 7.9132128971797115, 8.900187534529142, 9.787805812295671, 10.723296664334178, 10.711073419396532, 9.733842558337216, 8.705644960242019, 7.746433133015151, 6.792982250676248, 5.823686597465094, 4.867022797765976, 3.8332043340224424, 2.9943926173602122, 2.0452093733096652, 1.0727945079899652, 2.043227220419097, 3.0349571763241836, 4.020371608840569, 5.069120505669893, 6.016667053418583, 6.929916042795167, 7.8719817463352175, 8.854604196131023, 9.911149964908473, 10.02166122018215, 9.045538743752465, 8.052102883666098, 7.063922786771163, 6.013669541008985, 5.0607357197770995, 4.051827202065777, 3.066645444139841, 2.06914882308841, 1.0326385036507826, 0.0, 1.0705543142058038, 2.099666630439203, 3.033802579617139, 4.004686620945467, 4.972552374019426, 5.969061149392164, 7.021882014073229, 8.076124795499023, 9.024600847247571, 10.009793008923323, 9.948288127180499, 9.008915761988973, 8.014600176722658, 6.962814704128137, 6.038549870998959, 5.0486559012078125, 3.993904882866938, 2.8812199633928803, 1.9155749861746996, 0.9277165031574917, 1.988779233603911, 2.993785793341927, 3.9613010320223774, 5.00071175292159, 5.945626931085842, 6.911436403382899, 7.932668678130877, 8.990265233541956, 9.955613016402655, 10.930747983684237, 10.841464970639187, 9.899839469705, 8.856191306653585, 7.924276788397277, 6.951371586649344, 5.87974568342735, 4.95321810491598, 3.812050049296495, 2.8417351829328372, 1.915144075019139, 2.863020319116153, 3.9146875337817195, 4.85888441982949, 5.8330787327959195, 6.792627327316659, 7.749018853300616, 8.709928134746793, 9.662474221750188, 10.597944351605799, 11.542211489019907, 11.786977867462575, 10.761237862858826, 9.81220213775162, 8.85418326451289, 7.912126762355441, 6.912569371595778, 5.9803716970041165, 4.864252044326855, 3.813885393575298, 2.867714803959439, 3.838446836598991, 4.8332695779820005, 5.797321097962542, 6.7712296276921595, 7.782553630697993, 8.70613204247702, 9.685392884080988, 10.615243897298088, 11.559237295691092, 12.5332400157624, 12.68748932941117, 11.717287234093249, 10.772719555449164, 9.807057003250279, 8.89696344941301, 7.873289031244975, 7.028205734171853, 5.818077931544459, 4.8687773946743205, 3.8798160962924158, 4.798237482684783, 5.794600101917767, 6.760455226075548, 7.715288475988539, 8.68864631815202, 9.643513520006383, 10.670874282414992, 11.558488911450162, 12.594550172671777, 13.573905006160802, 13.687539195631084, 12.692981499898591, 11.73647595962663, 10.78927973142173, 9.82501768180452, 8.842974437069941, 7.914539468135355, 6.809189671310495, 5.833199424368093, 4.824132875488681, 5.7257716718946154, 6.6860112784406125, 7.715785678638715, 8.74176980684474, 9.67249602500764, 10.587072492982562, 11.532121784755507, 12.579761024283703, 13.619446573116928, 14.515856097920068, 14.593825629392315, 13.63472847780514, 12.77344239595051, 11.803851364357811, 10.881840822827646, 9.814317493530972, 8.810440083132772, 7.758564863429118, 6.744426440308184, 5.79345911374811, 6.728420238434944, 7.7245466607417566, 8.647387534229193, 9.690585516882186, 10.649769748099402, 11.618866320892225, 12.509201930509304, 13.583274683494796, 14.62720764631867, 15.447210143912114, 15.581122338360199, 14.608519335182267, 13.717500890163198, 12.772290656249737, 11.743923044175737, 10.742735559634365, 9.679297079534562, 8.710198634598637, 7.771581687013114, 6.864888485782003, 7.78341233257045, 8.766107995074766, 9.586757135894729, 10.553585822478658, 11.522727685831466, 12.53851105179934, 13.531189332346909, 14.4739601004147, 15.452951061343809, 16.38225845588955, 16.646669383155512, 15.676558582873696, 14.704856287097861, 13.664753416878638, 12.655865375312024, 11.59490664722698, 10.608351658130774, 9.680150473140026, 8.820209597859428, 7.911154409130839, 8.806288431194496, 9.751096240933457, 10.585238532365715, 11.551081105912013, 12.520572355839905, 13.518397411387788, 14.457793685192463, 15.436792936318016, 16.362824663218344, 16.545412154925923, 15.601596450257897, 14.66181132239646, 13.74592423187128, 12.88998938086857, 12.039827935817325, 12.55010224468922, 11.672884795428677, 10.607836106774203, 9.789930865099922, 8.972026492931914, 9.825401829090666, 10.762008261582528, 11.534383110688385, 12.504028632897926, 13.485832452264482, 14.48080287765279, 15.510448963994975, 16.484518048751433, 16.535625768635192, 15.644248554003891, 14.641387819342048, 13.689589167333825, 12.749368794911623, 11.869018622833826, 10.988621885788673, 11.871308476148798, 12.734531658650365], [12.59664270479405, 11.671203891391016, 10.861868160727228, 9.912006598863023, 10.73153262213701, 11.6404425540957, 12.59472544070363, 13.611793989778862, 14.487241666005273, 15.439650748027779, 15.569415283249333, 14.525814619078357, 13.595834933857311, 12.585373374215312, 11.642017153565078, 10.886158053917349, 9.98709917104403, 10.9163033439154, 11.861827032691568, 12.639408410498241, 11.524956947441027, 10.728333557712707, 9.821702508046453, 8.939525409720739, 9.708407322736315, 10.66661341052565, 11.621442300381913, 12.613487004683288, 13.558788227027513, 14.519353554806637, 15.451783135847764, 15.563646050310457, 14.590191999458932, 13.582564680213085, 12.68967269450652, 11.892261426590075, 11.023798981872382, 11.97396132601581, 12.750380672925226, 11.683651679561901, 10.51917516022438, 9.723259818225069, 8.755386583277799, 7.911703753038449, 8.738619067516025, 9.668595600546617, 10.626303740943749, 11.59866933403796, 12.582896417105653, 13.524670048570052, 14.459038358020933, 15.448024836685347, 15.617110712263603, 14.567526151273514, 13.714755973422646, 12.831660015025253, 11.995072606515064, 12.698979384221863, 11.732751663944944, 10.784268192759217, 9.551155852629295, 8.660458473392065, 7.745461195410599, 6.897084929831494, 7.677045913233014, 8.670219045447752, 9.627110158387428, 10.55028463900368, 11.588577325599069, 12.546758385730021, 13.49472609608271, 14.485878299810054, 15.496757581542287, 15.40223894520113, 14.32805196525927, 13.402008969291927, 12.471323589745323, 11.661124851748202, 10.76725948272256, 9.817470872020012, 8.619720170705188, 7.649467148555398, 6.713771884281666, 5.949549500991265, 6.716190383481415, 7.771168619342946, 8.671532300769945, 9.60110055955406, 10.61176703689492, 11.5415850147328, 12.565160267005899, 13.533075185524702, 14.424137461933416, 14.512202928493037, 13.546139385542098, 12.587379094838484, 11.533827865989819, 10.586961825734374, 9.754116705769114, 8.8341780883736, 7.762760579585015, 6.756047894854147, 5.774023592501579, 4.948289562380935, 5.776784192414362, 6.782091642954732, 7.718618891676933, 8.694491024429466, 9.66107884719791, 10.603805796100334, 11.566212710724907, 12.501110744369553, 13.475137644135234, 13.5677951565227, 12.618702517574443, 11.655432442502018, 10.651547934247908, 9.651123165716188, 8.79128166727269, 7.8367355306962, 6.807588298643203, 5.767954090725416, 4.778823846131348, 3.95928440906461, 4.832044661837284, 5.837262479235897, 6.762350430740596, 7.729209031606379, 8.724247281686843, 9.716621191260868, 10.748855603794114, 11.604961665463975, 12.528531100094137, 12.688397842495228, 11.728162947611336, 10.777978220546128, 9.748337584896012, 8.726104360836503, 7.802290240476586, 6.848296912475014, 5.845518847816706, 4.811316104958309, 3.828449302911298, 2.9126464214902628, 3.8812726696370303, 4.864571899658651, 5.800662503594643, 6.776746492781753, 7.790508863641329, 8.731653823081151, 9.696353189272116, 10.665627450273796, 11.548327266613946, 11.761333767555355, 10.802073537439197, 9.818407472033897, 8.78542353380266, 7.783086829994306, 6.8389791359143794, 5.83022702778641, 4.949142475039565, 3.8764290501786585, 2.8984051247617844, 1.927754721967057, 2.9655389098891147, 3.977869937533557, 4.9706732269020355, 5.9409183479576635, 6.842658582973908, 7.829633220323339, 8.717251498089869, 9.652742350128376, 10.5867619725258, 10.80439687254302, 9.776199274447823, 8.816987447220955, 7.863536564882052, 6.894240911670898, 5.93757711197178, 4.903758648228247, 3.917256378401706, 2.968073134351159, 1.9538259887713756, 0.9726729062132935, 1.9644028621183796, 2.949817294634765, 3.99856619146409, 4.94611273921278, 5.859361728589364, 6.801427432129414, 7.7840498819252195, 8.84059565070267, 9.887619878499457, 10.116093057958267, 9.1226571978719, 8.134477100976966, 7.084223855214789, 6.1312900339829035, 5.122381516271581, 4.137199758345645, 3.139703137294214, 2.1031928178565864, 1.0705543142058038, 0.0, 1.029112316233399, 1.963248265411335, 2.9341323067396634, 3.9019980598136232, 4.898506835186361, 5.951327699867427, 7.005570481293221, 7.954046533041769, 8.93923869471752, 9.905002987701508, 10.034486572624148, 9.040170987357833, 7.988385514763312, 7.039015685923981, 6.049121716132834, 4.988995403402336, 3.9517742775986844, 2.9861293003805036, 1.9982708173632955, 1.0481628505094287, 1.996860081445639, 2.8907467178165738, 3.9301574387157863, 4.875072616880038, 5.840882089177095, 6.862114363925073, 7.919710919336152, 8.88505870219685, 9.860193669478432, 10.876890469364186, 10.862289539003052, 9.818641375951637, 8.88672685769533, 7.913821655947396, 6.842195752725402, 5.915668174214032, 4.882604363502299, 3.9122894971386413, 2.9772815442306664, 2.0294053001336523, 2.990004864812659, 3.8977952377010365, 4.8719895506674655, 5.831538145188205, 6.787929671172162, 7.748838952618339, 8.701385039621734, 9.636855169477345, 10.581122306891453, 11.605242730623003, 11.70030450433389, 10.751268779226685, 9.793249905987954, 8.851193403830504, 7.85163601307084, 6.919438338479178, 5.934806358532659, 4.876022862786825, 3.929852273170966, 3.0048318176164903, 3.9996545589995, 4.836231915834089, 5.810140445563706, 6.8214644485695395, 7.745042860348566, 8.724303701952534, 9.654154715169634, 10.598148113562639, 11.572150833633946, 12.634350813879104, 12.65635387556831, 11.711786196924226, 10.74612364472534, 9.836030090888073, 8.812355672720038, 7.874562900916175, 6.888632245750263, 5.930914863885847, 4.941953565503943, 3.964622463702282, 4.960985082935266, 5.85193994679749, 6.779531026531653, 7.752888868695134, 8.68242433787793, 9.709785100286538, 10.597399729321708, 11.633460990543323, 12.612815824032348, 13.540016737086223, 13.632048141373653, 12.675542601101691, 11.728346372896794, 10.764084323279583, 9.782041078545005, 8.727187802506482, 7.871327140522023, 6.895336893579621, 5.886270344700209, 4.8921566529121145, 5.852396259458112, 6.882170659656214, 7.8060123573878535, 8.736738575550753, 9.625983310854108, 10.571032602627053, 11.61867184215525, 12.658357390988474, 13.554766915791614, 14.586477364061835, 14.573795119280202, 13.712509037425573, 12.742918005832873, 11.723115773261346, 10.655592443964672, 9.6230884175039, 8.805864941646625, 7.7917265185256905, 6.840759191965616, 5.894805219452443, 6.890931641759256, 7.813772515246692, 8.754828067425299, 9.714012298642515, 10.657777138763771, 11.54811274838085, 12.622185501366342, 13.666118464190216, 14.48612096178366, 15.417715070040549, 15.547585976657329, 14.558464949103536, 13.613254715190076, 12.556571378546865, 11.555383894005493, 10.49194541390569, 9.757498712816144, 8.816687329819546, 7.8774021356067045, 6.949797313587949, 7.932492976092264, 8.753142116912228, 9.69283590803176, 10.66197777138457, 11.677761137352444, 12.570100150218455, 13.512870918286247, 14.491861879215355, 15.421169273761095, 15.607894115907062, 14.656813587617563, 13.683292287548777, 12.901854320899295, 13.468513709683151, 12.407554981598107, 11.420999992501901, 10.727450551357533, 9.86531524066586, 8.923282547900191, 7.972673412211995, 8.917481221950956, 9.751623513383214, 10.693906165691155, 11.663397415619047, 12.66122247116693, 13.49670450306401, 14.475703754189562, 15.40173548108989, 15.479822311846485, 14.536006607178459, 13.596221479317022, 12.680334388791842, 11.921010044806964, 12.852476270188454, 13.362750579060348, 12.485533129799805, 11.65513618499171, 10.835036507906354, 9.973904417079506, 8.991786810108165, 9.928393242600027, 10.700768091705884, 11.65157870638033, 12.628657512043624, 13.623627937431932, 14.568401783444612, 15.52342886662298, 15.470035925555754, 14.578658710924453, 13.57579797626261, 12.623999324254386, 11.683778951832185, 10.90003928677222, 11.801270220159802, 12.683956810519923, 13.547179993021492], [13.607943441419266, 12.682504628016234, 11.774473089485669, 10.819476539969369, 9.836782305837197, 10.745692237795884, 11.699975124403815, 12.71599951024969, 13.560628827184836, 14.513037909207341, 14.547254480163916, 13.50365381599294, 12.573674130771895, 11.563212571129895, 10.635940742324454, 10.181538164057805, 10.911690645484855, 11.840894818356226, 12.786418507132396, 13.563999884939065, 12.536257684066243, 11.739634294337925, 10.83300324467167, 9.846995350827084, 8.813657006436502, 9.771863094225836, 10.706188712324147, 11.68687416586285, 12.632175388207076, 13.5927407159862, 14.525170297027326, 14.54148524722504, 13.568031196373516, 12.56040387712767, 11.683596283265896, 11.187641536730531, 11.948390456313208, 12.898552800456637, 13.674972147366052, 12.608243154002727, 11.530475896849596, 10.734560554850287, 9.766687319903017, 8.84274783268292, 7.843868751216211, 8.773845284246802, 9.711050152885983, 10.672056495217522, 11.656283578285215, 12.582079414388604, 13.516447723839484, 14.496112963466631, 14.594949909178187, 13.545365348188097, 12.708679562182022, 12.12704012516571, 12.91966408095589, 13.70585120077884, 12.706008009578952, 11.708859667200043, 10.562456589254511, 9.671759210017283, 8.756761932035817, 7.828129009475965, 6.7822955969332, 7.775468729147938, 8.711856570329662, 9.623671800183242, 10.661964486778631, 11.604167751548573, 12.542814222863994, 13.533966426591338, 14.467645265308889, 14.527121026528555, 13.77249375210173, 13.18206381822852, 13.487903719301965, 12.671399537282316, 11.74402737939173, 10.765366597569539, 9.631020907330404, 8.660767885180615, 7.725072620906883, 6.880593580635735, 5.821440067181601, 6.876418303043132, 7.744919461949507, 8.674487720733623, 9.685154198074482, 10.589673141514083, 11.613248393787183, 12.581163312305986, 13.395025145700018, 14.400009558587099, 14.562719515098738, 13.603959224395126, 12.550407995546461, 11.603541955291016, 10.751846500250897, 9.821102180797032, 8.774061316210231, 7.767348631479364, 6.785324329126796, 5.903721504903237, 4.882033876114548, 5.887341326654918, 6.792006052856496, 7.767878185609028, 8.734466008377472, 9.651893922881618, 10.61430083750619, 11.549198871150837, 12.446025327901836, 13.439782308510638, 13.635282647131083, 12.672012572058659, 11.66812806380455, 10.66770329527283, 9.807861796829329, 8.842735925721842, 7.81888903526842, 6.779254827350633, 5.790124582756565, 4.926691666211057, 3.9372943455374703, 4.942512162936083, 5.835737591920158, 6.802596192785941, 7.797634442866404, 8.725510918447174, 9.734711617243129, 10.575849349230577, 11.499418783860738, 12.444500214462268, 12.757275263844734, 11.79455835010277, 10.764917714452654, 9.742684490393145, 8.818870370033226, 7.8648770420316545, 6.856819584441923, 5.822616841583526, 4.839750039536515, 3.92394715811548, 2.9865223533372163, 3.897120598157035, 4.833211202093027, 5.809295191280137, 6.823057562139713, 7.740543550267456, 8.667240873038716, 9.636515134040398, 10.519214950380547, 11.47907068062525, 11.831185853672595, 10.834987601590537, 9.802003663359303, 8.799666959550947, 7.85555926547102, 6.846807157343051, 5.960443211664783, 4.8877297868038765, 3.909705861387002, 2.9390554585922746, 1.9521907057649242, 2.9645217334093665, 3.9415609106686365, 4.911806031724264, 5.813546266740509, 6.80052090408994, 7.68813918185647, 8.623630033894978, 9.557649656292401, 10.534880517351718, 10.805311590681221, 9.846099763454353, 8.89264888111545, 7.923353227904296, 6.966689428205179, 5.932870964461645, 4.9285571150269245, 3.979373870976377, 2.965126725396593, 1.983973642838511, 0.9352905458849804, 1.9207049784013654, 2.969453875230691, 3.917000422979381, 4.830249412355965, 5.772315115896015, 6.7549375656918205, 7.811483334469271, 8.858507562266055, 9.83463003869574, 10.1517695141053, 9.163589417210366, 8.11333617144819, 7.1604023502163034, 6.151493832504981, 5.166312074579045, 4.168815453527614, 3.132305134089986, 2.099666630439203, 1.029112316233399, 0.0, 0.934135949177936, 1.9050199905062644, 2.872885743580224, 3.8693945189529626, 4.922215383634028, 5.976458165059823, 6.924934216808371, 7.910126378484121, 8.87589067146811, 9.815263036659635, 10.051471723983052, 8.999686251388532, 8.0503164225492, 7.060422452758052, 6.000296140027554, 4.980886593832083, 4.015241616613903, 3.027383133596695, 1.972754324950256, 0.9677477652122399, 1.8616344015831747, 2.901045122482387, 3.8459603006466394, 4.811769772943697, 5.833002047691675, 6.890598603102754, 7.8559463859634535, 8.831081353245034, 9.847778153130788, 10.789403654064975, 10.829942112576855, 9.898027594320547, 8.925122392572614, 7.85349648935062, 6.92696891083925, 5.899184493058939, 4.928869626695282, 3.9018730186714934, 2.9539967745744793, 1.96089254857926, 2.8686829214676375, 3.8428772344340665, 4.802425828954806, 5.758817354938763, 6.71972663638494, 7.672272723388334, 8.607742853243945, 9.552009990658053, 10.576130414389603, 11.601870418993352, 11.7625695158519, 10.80455064261317, 9.86249414045572, 8.862936749696056, 7.930739075104395, 6.861850184761723, 5.800614337227652, 4.854443747611794, 3.929423292057317, 2.9839970770346076, 3.80711959960069, 4.7810281293303065, 5.7923521323361395, 6.715930544115167, 7.695191385719134, 8.625042398936234, 9.569035797329239, 10.543038517400547, 11.605238497645704, 12.575440592963625, 12.723086933549443, 11.757424381350557, 10.84733082751329, 9.823656409345254, 8.88586363754139, 7.815676071979327, 6.855506338326674, 5.8665450399447705, 4.889213938143109, 3.9857778830200585, 4.822827630564091, 5.750418710298254, 6.723776552461735, 7.65331202164453, 8.680672784053138, 9.568287413088308, 10.604348674309923, 11.583703507798948, 12.510904420852823, 13.568348341118234, 13.686843337726907, 12.73964710952201, 11.7753850599048, 10.793341815170221, 9.738488539131698, 8.79591861496285, 7.819928368020449, 6.810861819141037, 5.816748127352941, 5.025423558128338, 5.876094248415588, 6.776900041154454, 7.707626259317355, 8.59687099462071, 9.541920286393655, 10.589559525921851, 11.629245074755076, 12.525654599558214, 13.557365047828435, 14.510095319024783, 14.723809774050789, 13.75421874245809, 12.734416509886563, 11.666893180589888, 10.634389154129117, 9.730456416087451, 8.716317992966516, 7.765350666406443, 6.819396693893269, 6.063958940429482, 6.807696104006066, 7.7257157511919, 8.684899982409116, 9.628664822530373, 10.519000432147452, 11.593073185132944, 12.637006147956818, 13.45700864555026, 14.388602753807149, 14.830102519009177, 13.77955001452117, 14.624555451815292, 13.567872115172081, 12.566684630630709, 11.503246150530906, 10.68209018725697, 9.741278804260373, 8.801993610047532, 7.874388788028775, 7.11505571278762, 7.747065705671602, 8.663723591798362, 9.632865455151173, 10.648648821119046, 11.540987833985056, 12.483758602052848, 13.462749562981957, 14.392056957527695, 14.713143799607247, 13.762063271317748, 12.788541971248964, 13.776122819160657, 14.479814446308367, 13.418855718223323, 12.432300729127117, 11.652042025798359, 10.789906715106687, 9.847874022341017, 8.89726488665282, 8.175673697034252, 8.745547102142588, 9.664793849457757, 10.634285099385648, 11.632110154933532, 12.467592186830611, 13.446591437956164, 14.372623164856492, 14.58507199554667, 13.641256290878644, 12.701471163017207, 11.785584072492028, 12.795278543068326, 13.765081198946895, 14.374051315685564, 13.496833866425021, 12.579727659432535, 11.759627982347181, 10.898495891520332, 9.91637828454899, 9.223773352740483, 9.694691680465258, 10.622466390146933, 11.599545195810226, 12.594515621198534, 13.539289467211214, 14.494316550389582, 14.543423086735316, 13.68286423139528, 12.681047659962795, 11.729249007954571, 10.789028635532372, 11.8026454989949, 12.713875148918243, 13.665067484069448, 14.558480729646709], [14.542079390597202, 13.61664057719417, 12.708609038663603, 11.753612489147303, 10.77091825501513, 9.98859384381519, 10.832786283269014, 11.800131062667875, 12.64476037960302, 13.597169461625526, 13.61311853098598, 12.569517866815005, 11.63953818159396, 10.62907662195196, 9.701804793146518, 10.71112778817988, 11.762914121510242, 12.692118294381613, 13.691470726165598, 14.4976038638364, 13.470393633244178, 12.673770243515861, 11.767139193849605, 10.781131300005018, 9.747792955614436, 9.014764700245141, 9.790320264742332, 10.771005718281035, 11.71630694062526, 12.665749690155508, 13.598179271196635, 13.607349298047104, 12.63389524719558, 11.626267927949733, 10.74946033408796, 11.717231160852606, 12.781623663473875, 13.747702503944563, 14.608576126263387, 13.541847132900061, 12.464611846027532, 11.668696504028222, 10.700823269080953, 9.776883781860853, 8.778004700394145, 8.016746890266107, 8.795181705304168, 9.756188047635707, 10.7404151307034, 11.647943465210664, 12.582311774661544, 13.561977014288694, 13.660813960000251, 12.611229399010162, 11.774543613004086, 12.656629749287784, 13.704044106115122, 14.639455179676174, 13.639611988476286, 12.642463646097378, 11.496592538432447, 10.605895159195219, 9.690897881213754, 8.7622649586539, 7.716431546111136, 7.018370335167243, 7.795988122747846, 8.707803352601427, 9.746096039196816, 10.670031802370634, 11.608678273686056, 12.5998304774134, 13.533509316130953, 13.592985077350619, 12.838357802923793, 13.711653442350595, 14.4220396684799, 13.60500351617965, 12.677631358289064, 11.698970576466873, 10.56515685650834, 9.59490383435855, 8.65920857008482, 7.814729529813671, 6.755576016359536, 5.978395350783581, 6.829051014367692, 7.758619273151807, 8.769285750492665, 9.655537192336144, 10.679112444609245, 11.647027363128048, 12.460889196522082, 13.465873609409163, 13.889385672234708, 14.538095173573062, 13.484543944724397, 12.537677904468952, 11.685982449428833, 10.755238129974968, 9.708197265388167, 8.7014845806573, 7.719460278304732, 6.837857454081173, 5.816169825292484, 4.989318374395367, 5.87613760527468, 6.8520097380272125, 7.818597560795657, 8.71775797370368, 9.680164888328253, 10.6150629219729, 11.5118893787239, 12.505646359332703, 13.425907415115223, 13.606148521236594, 12.602264012982486, 11.601839244450765, 10.741997746007264, 9.776871874899777, 8.753024984446355, 7.713390776528569, 6.724260531934501, 5.860827615388993, 4.871430294715406, 4.044489210676532, 4.919869144338342, 5.886727745204126, 6.881765995284589, 7.791374969269238, 8.800575668065193, 9.641713400052641, 10.565282834682803, 11.510364265284332, 12.432038101864373, 12.728694299280706, 11.69905366363059, 10.676820439571081, 9.753006319211162, 8.79901299120959, 7.790955533619859, 6.756752790761462, 5.773885988714451, 4.858083107293416, 3.920658302515152, 2.9812521505752194, 3.9173427545112114, 4.893426743698321, 5.907189114557897, 6.8064076010895205, 7.733104923860781, 8.702379184862462, 9.585079001202612, 10.544934731447315, 11.505948691692234, 11.769123550768473, 10.736139612537238, 9.733802908728883, 8.789695214648956, 7.780943106520987, 6.894579160842719, 5.821865735981811, 4.843841810564937, 3.8731914077702103, 2.8863266549428603, 2.0486532858275504, 3.0074249614907007, 3.9776700825463287, 4.879410317562574, 5.866384954912005, 6.754003232678534, 7.689494084717042, 8.623513707114466, 9.600744568173782, 10.62894216626898, 10.78023571263229, 9.826784830293388, 8.857489177082233, 7.900825377383114, 6.867006913639581, 5.86269306420486, 4.913509820154313, 3.899262674574529, 2.918109592016447, 1.8694264950629162, 1.001244563689017, 2.0353179260527554, 2.9828644738014445, 3.8961134631780285, 4.83817916671808, 5.820801616513885, 6.877347385291335, 7.9243716130881205, 8.900494089517807, 9.893929949604173, 10.097725366388302, 9.047472120626125, 8.09453829939424, 7.085629781682917, 6.1004480237569805, 5.10295140270555, 4.066441083267922, 3.033802579617139, 1.963248265411335, 0.934135949177936, 0.0, 0.9708840413283284, 1.938749794402288, 2.9352585697750264, 3.988079434456092, 5.042322215881886, 5.990798267630434, 6.975990429306185, 7.941754722290173, 8.881127087481698, 9.875442672748013, 9.933822200566468, 8.984452371727135, 7.994558401935988, 6.934432089205489, 5.915022543010019, 4.949377565791838, 3.9615190827746307, 2.906890274128192, 1.901883714390176, 0.9274984524052388, 1.9669091733044515, 2.911824351468703, 3.8776338237657604, 4.898866098513738, 5.9564626539248176, 6.921810436785517, 7.8969454040670986, 8.91364220395285, 9.855267704887037, 10.869162019718022, 10.832163543498483, 9.85925834175055, 8.787632438528556, 7.861104860017186, 6.833320442236876, 5.863005575873219, 4.83600896784943, 3.8881327237524155, 2.878743858337472, 1.9345469722897015, 2.9087412852561307, 3.86828987977687, 4.824681405760828, 5.785590687207004, 6.738136774210398, 7.673606904066009, 8.617874041480118, 9.641994465211667, 10.667734469815416, 11.616770194922621, 11.738686591791106, 10.796630089633656, 9.797072698873992, 8.86487502428233, 7.795986133939659, 6.734750286405588, 5.788579696789729, 4.863027270954651, 3.868204529571642, 2.872983650422754, 3.8468921801523708, 4.858216183158204, 5.781794594937232, 6.761055436541199, 7.690906449758298, 8.634899848151303, 9.60890256822261, 10.671102548467768, 11.64130464378569, 12.585872322429775, 12.691560330528493, 11.781466776691225, 10.75779235852319, 9.819999586719327, 8.749812021157263, 7.78964228750461, 6.800680989122706, 5.822817917040443, 4.8545468055439365, 3.888691681386155, 4.816282761120318, 5.789640603283799, 6.7191760724665945, 7.746536834875203, 8.634151463910372, 9.670212725131988, 10.649567558621012, 11.576768471674887, 12.634212391940299, 13.54962872660724, 13.673783058699946, 12.709521009082735, 11.727477764348157, 10.672624488309634, 9.730054564140787, 8.754064317198385, 7.744997768318973, 6.750352106250276, 5.894192480652216, 4.941958299237652, 5.842764091976519, 6.773490310139419, 7.6627350454427745, 8.607784337215719, 9.655423576743916, 10.69510912557714, 11.591518650380278, 12.6232290986505, 13.575959369846847, 14.586595162931122, 14.688354691636025, 13.668552459064498, 12.601029129767824, 11.568525103307053, 10.664060394984785, 9.64992197186385, 8.698954645303777, 7.753000672790604, 6.858236998677981, 5.87356015482813, 6.791579802013964, 7.75076403323118, 8.694528873352438, 9.584864482969516, 10.658937235955008, 11.702870198778882, 12.522872696372325, 13.454466804629213, 14.073004125028483, 14.713685963699104, 15.558691400993228, 14.502008064350017, 13.500820579808645, 12.437382099708842, 11.615694166154304, 10.646331023293575, 9.707045829080734, 8.779441007061978, 7.796745344557662, 6.812929756493666, 7.729587642620426, 8.698729505973235, 9.714512871941109, 10.60685188480712, 11.549622652874913, 12.528613613804021, 13.457921008349759, 13.956045405626552, 13.004964877337054, 13.722677920426898, 14.71025876833859, 15.413950395486303, 14.352991667401259, 13.366436678305053, 12.585646004695693, 11.694958934139889, 10.752780274231451, 9.802171138543255, 8.857363328804293, 7.811411152964653, 8.730657900279821, 9.700149150207713, 10.697974205755596, 11.533456237652675, 12.512455488778228, 13.438487215678556, 13.814398067899782, 12.88415789689795, 11.944372769036512, 12.719720021669962, 13.72941449224626, 14.699217148124829, 15.3081872648635, 14.430969815602957, 13.51333163832987, 12.664680201380383, 11.753574170355847, 10.771456563384506, 9.834850130892644, 8.760555731287322, 9.688330440968997, 10.66540924663229, 11.660379672020598, 12.605153518033278, 13.560180601211647, 13.627554639153502, 12.766995783813465, 11.886859947127256, 10.972150613973877, 11.723164584710306, 12.736781448172835, 13.648011098096177, 14.599203433247382, 15.492616678824644], [15.512963431925531, 14.5875246185225, 13.679493079991932, 12.724496530475632, 11.74180229634346, 10.85343900866902, 9.963122547602564, 10.930467327001423, 11.77509664393657, 12.727505725959075, 12.700264220517898, 11.656663556346922, 10.726683871125877, 9.716222311483877, 10.65957853213411, 11.668901527167472, 12.720687860497835, 13.649892033369206, 14.66104074534467, 15.468487905164729, 14.441277674572508, 13.64465428484419, 12.738023235177934, 11.752015341333347, 10.718676996942765, 9.87960986509897, 8.920656529075883, 9.901341982614584, 10.84664320495881, 11.694865648827182, 12.62729522986831, 12.694494987579022, 11.721040936727498, 10.71341361748165, 11.707234073075552, 12.675004899840198, 13.739397402461467, 14.705476242932155, 15.579460167591716, 14.51273117422839, 13.435495887355861, 12.639580545356552, 11.671707310409282, 10.747767823189182, 9.748888741722475, 8.881592055119937, 7.925517969637718, 8.886524311969255, 9.87075139503695, 10.677059423882339, 11.611427733333219, 12.591092972960366, 12.747959649532168, 11.698375088542079, 12.691492441811148, 13.614403488275377, 14.661817845102714, 15.610339221004503, 14.610496029804615, 13.613347687425707, 12.467476579760776, 11.576779200523548, 10.661781922542083, 9.733148999982228, 8.687315587439464, 7.8832155000210715, 6.9263243870813955, 7.838139616934976, 8.876432303530365, 9.699147761042308, 10.637794232357729, 11.628946436085073, 12.562625274802624, 12.680130766882534, 13.754317746824395, 14.669427181338188, 15.39292370980823, 14.57588755750798, 13.648515399617393, 12.669854617795203, 11.536040897836669, 10.56578787568688, 9.630092611413149, 8.785613571142, 7.726460057687865, 6.9091995002836395, 5.959387278701241, 6.888955537485357, 7.899622014826215, 8.684653151007819, 9.708228403280918, 10.67614332179972, 11.490005155193753, 12.494989568080834, 13.382460241754547, 14.364186262188733, 14.455427986052726, 13.50856194579728, 12.65686649075716, 11.726122171303295, 10.679081306716496, 9.67236862198563, 8.690344319633061, 7.808741495409501, 6.787053866620812, 5.920122523895426, 5.00647386960823, 5.982346002360762, 6.921020379879436, 7.746873932375353, 8.709280846999926, 9.644178880644573, 10.541005337395571, 11.534762318004374, 12.455023373786894, 13.380694560202071, 13.573148054310815, 12.572723285779094, 11.712881787335593, 10.747755916228105, 9.723909025774685, 8.684274817856899, 7.69514457326283, 6.831711656717321, 5.842314336043734, 4.9752933601765905, 4.050205408671892, 5.017064009537675, 5.976469263292477, 6.820490927940909, 7.8296916267368655, 8.670829358724312, 9.594398793354474, 10.539480223956003, 11.461154060536044, 12.426368603638092, 12.669937704958919, 11.64770448089941, 10.72389036053949, 9.76989703253792, 8.761839574948187, 7.727636832089791, 6.74477003004278, 5.828967148621745, 4.89154234384348, 3.9521361919035476, 3.047679018844761, 4.023763008031871, 4.970962659532197, 5.835523559761192, 6.7622208825324535, 7.731495143534133, 8.614194959874283, 9.574050690118986, 10.535064650363905, 11.586180904257866, 11.707023653865567, 10.704686950057212, 9.760579255977285, 8.751827147849315, 7.865463202171048, 6.79274977731014, 5.814725851893266, 4.844075449098539, 3.8572106962711885, 3.019537327155879, 2.0365409201623716, 3.0067860412179996, 3.9085262762342454, 4.8955009135836765, 5.783119191350206, 6.718610043388714, 7.6526296657861375, 8.629860526845453, 9.65805812494065, 10.617269952167518, 10.797668871621717, 9.828373218410562, 8.871709418711443, 7.837890954967909, 6.8335771055331875, 5.884393861482641, 4.870146715902857, 3.8889936333447754, 2.840310536391245, 1.9721286050173454, 1.0644338847244268, 2.0119804324731163, 2.9252294218497004, 3.8672951253897514, 4.8499175751855566, 5.906463343963007, 6.953487571759792, 7.9296100481894785, 8.923045908275844, 9.88130695728643, 10.018356161954452, 9.065422340722566, 8.056513823011244, 7.071332065085308, 6.073835444033877, 5.03732512459625, 4.004686620945467, 2.9341323067396634, 1.9050199905062644, 0.9708840413283284, 0.0, 0.9678657530739597, 1.964374528446698, 3.0171953931277633, 4.071438174553558, 5.019914226302106, 6.005106387977857, 6.970870680961845, 7.91024304615337, 8.904558631419686, 9.956344104014207, 9.955336413055463, 8.965442443264315, 7.905316130533817, 6.885906584338347, 5.920261607120167, 4.932403124102959, 3.87777431545652, 2.8727677557185043, 1.8983824937335672, 0.996025131976123, 1.940940310140375, 2.906749782437432, 3.9279820571854103, 4.985578612596489, 5.950926395457189, 6.92606136273877, 7.942758162624523, 8.88438366355871, 9.898277978389695, 10.830192496646003, 10.83014238307888, 9.758516479856885, 8.831988901345515, 7.804204483565203, 6.833889617201546, 5.806893009177758, 4.859016765080744, 3.8496278996658, 2.90543101361803, 1.9958869747880488, 2.9554355693087877, 3.9118270952927454, 4.872736376738922, 5.825282463742315, 6.7607525935979265, 7.705019731012034, 8.729140154743583, 9.754880159347332, 10.703915884454537, 11.661934757693267, 11.767514130961985, 10.76795674020232, 9.83575906561066, 8.766870175267986, 7.705634327733916, 6.759463738118058, 5.83391131228298, 4.839088570899971, 3.8438676917510826, 2.934037869684289, 3.9453618726901225, 4.868940284469149, 5.848201126073116, 6.7780521392902155, 7.72204553768322, 8.696048257754526, 9.758248237999684, 10.728450333317605, 11.673018011961691, 12.614808496430655, 12.752350818019554, 11.728676399851519, 10.790883628047656, 9.72069606248559, 8.760526328832938, 7.771565030451034, 6.793701958368772, 5.824116824723009, 4.858261700565228, 3.903428450652236, 4.876786292815717, 5.806321761998512, 6.83368252440712, 7.72129715344229, 8.757358414663905, 9.736713248152927, 10.663914161206803, 11.721358081472214, 12.636774416139156, 13.645133079081823, 13.680405050411064, 12.698361805676486, 11.643508529637963, 10.700938605469114, 9.724948358526712, 8.7158818096473, 7.721236147578605, 6.863762499831289, 5.911528318416725, 4.929909781508437, 5.860635999671336, 6.749880734974692, 7.694930026747636, 8.742569266275833, 9.782254815109058, 10.678664339912194, 11.710374788182415, 12.663105059378763, 13.673740852463037, 14.659704712017902, 14.639436500392828, 13.571913171096153, 12.539409144635382, 11.634944436313114, 10.62080601319218, 9.669838686632106, 8.723884714118933, 7.827807017857053, 6.843130174007202, 5.878725491545882, 6.837909722763098, 7.781674562884356, 8.672010172501434, 9.746082925486924, 10.790015888310798, 11.61001838590424, 12.541612494161129, 13.51421549733906, 14.57961301396889, 15.52482324788235, 15.472892105678346, 14.471704621136974, 13.40826614103717, 12.586578207482633, 11.615901042472647, 10.676615848259805, 9.74901102624105, 8.766315363736734, 7.782499775672738, 6.816733332152344, 7.785875195505153, 8.801658561473026, 9.693997574339038, 10.63676834240683, 11.615759303335938, 12.545066697881675, 13.096056459023252, 13.869810042190883, 14.693561961755227, 15.68114280966692, 16.384834436814632, 15.323875708729588, 14.337320719633382, 13.556530046024022, 12.66452895331896, 11.722350293410523, 10.771741157722326, 9.826933347983365, 8.780981172143724, 7.8178035898117395, 8.78729483973963, 9.785119895287513, 10.620601927184593, 11.599601178310145, 12.525632905210474, 12.944734332233331, 12.02416895029465, 12.809217933890341, 13.690604062998291, 14.700298533574589, 15.670101189453158, 16.279071306191828, 15.401853856931286, 14.484215679658199, 13.634250220559455, 12.723144189534917, 11.741026582563576, 10.804420150071714, 9.730125750466394, 8.775476130500914, 9.752554936164207, 10.747525361552515, 11.692299207565195, 12.647326290743564, 12.75789090348705, 11.897332048147014, 11.017196211460806, 11.836995778827706, 12.694048626038635, 13.707665489501164, 14.618895139424506, 15.570087474575711, 16.463500720152975], [16.48082918499949, 15.555390371596458, 14.647358833065892, 13.692362283549592, 12.70966804941742, 11.82130476174298, 10.930988300676523, 10.20428601933021, 10.965567789223511, 11.766050747851999, 11.815782923002244, 10.86123661973435, 10.083309197969747, 10.684088064557837, 11.627444285208071, 12.636767280241433, 13.688553613571795, 14.617757786443166, 15.62890649841863, 16.436353658238687, 15.409143427646466, 14.612520037918149, 13.705888988251893, 12.719881094407308, 11.686542750016725, 10.84747561817293, 9.888522282149841, 9.17516067494337, 10.037114350245751, 10.72699989575322, 11.659429476794347, 11.89906805096645, 11.077666263571368, 11.681279370555611, 12.675099826149513, 13.642870652914159, 14.707263155535427, 15.673341996006116, 16.547325920665674, 15.480596927302349, 14.40336164042982, 13.60744629843051, 12.63957306348324, 11.715633576263144, 10.716754494796435, 9.849457808193897, 8.893383722711677, 8.160343004298042, 9.055205727537198, 9.709193670808377, 10.643561980259257, 11.623227219886406, 12.10692690846439, 12.66624084161604, 13.659358194885108, 14.582269241349337, 15.629683598176674, 16.57820497407846, 15.578361782878574, 14.581213440499665, 13.435342332834734, 12.544644953597507, 11.629647675616042, 10.701014753056189, 9.655181340513424, 8.851081253095032, 7.894190140155356, 7.111958309263763, 8.00368019935152, 8.731282007968346, 9.669928479283769, 10.661080683011113, 11.594759521728664, 12.482281095310688, 13.465622357991503, 14.352954209201348, 15.283639588747953, 15.543753310581938, 14.616381152691352, 13.637720370869161, 12.503906650910627, 11.533653628760838, 10.597958364487107, 9.75347932421596, 8.694325810761825, 7.8770652533576, 6.9272530317752015, 6.1627742298141435, 6.994317503809209, 7.7167873979338575, 8.740362650206958, 9.70827756872576, 10.522139402119793, 11.527123815006874, 12.414594488680589, 13.396320509114775, 14.449465383523874, 14.476427698871241, 13.62473224383112, 12.693987924377256, 11.646947059790456, 10.640234375059588, 9.65821007270702, 8.776607248483462, 7.754919619694772, 6.887988276969386, 5.97433962268219, 5.13175094546758, 5.953154626805476, 6.7790081793013925, 7.741415093925965, 8.676313127570612, 9.573139584321611, 10.566896564930413, 11.487157620712933, 12.412828807128111, 13.416713315382221, 13.540589038853055, 12.680747540409554, 11.715621669302065, 10.691774778848645, 9.65214057093086, 8.663010326336789, 7.799577409791281, 6.8101800891176945, 5.943159113250551, 5.018071161745852, 4.133186193279654, 5.008603510218517, 5.852625174866949, 6.861825873662905, 7.702963605650352, 8.626533040280513, 9.571614470882043, 10.493288307462084, 11.458502850564132, 12.488143486214248, 12.61557023397337, 11.691756113613451, 10.73776278561188, 9.729705328022149, 8.695502585163752, 7.712635783116739, 6.796832901695704, 5.8594080969174405, 4.920001944977507, 4.015544771918721, 3.099232331561481, 4.003096906458237, 4.867657806687232, 5.794355129458493, 6.7636293904601725, 7.646329206800322, 8.606184937045025, 9.567198897289945, 10.618315151183905, 11.579947186442643, 11.672552703131172, 10.728445009051246, 9.719692900923276, 8.833328955245006, 7.7606155303841, 6.782591604967226, 5.811941202172498, 4.825076449345149, 3.9874030802298384, 3.004406673236332, 2.0485917713417354, 2.940660523160285, 3.927635160509716, 4.815253438276246, 5.750744290314754, 6.684763912712177, 7.661994773771493, 8.69019237186669, 9.649404199093558, 10.60285508143246, 10.796238971484522, 9.839575171785404, 8.80575670804187, 7.801442858607148, 6.852259614556601, 5.838012468976817, 4.856859386418735, 3.8081762894652047, 2.939994358091305, 2.0322996377983866, 1.0441146793991567, 1.9573636687757405, 2.899429372315791, 3.8820518221115963, 4.938597590889047, 5.985621818685832, 6.961744295115518, 7.955180155201885, 8.913441204212472, 9.9376235140594, 10.033288093796527, 9.024379576085204, 8.039197818159268, 7.041701197107837, 6.00519087767021, 4.972552374019427, 3.9019980598136232, 2.872885743580224, 1.938749794402288, 0.9678657530739597, 0.0, 0.9965087753727383, 2.049329640053804, 3.103572421479598, 4.0520484732281465, 5.037240634903897, 6.003004927887885, 6.942377293079411, 7.936692878345728, 8.988478350940248, 9.93784817977958, 9.933308196338277, 8.873181883607778, 7.853772337412307, 6.888127360194127, 5.900268877176919, 4.84564006853048, 3.840633508792464, 2.866248246807527, 1.9638908850500827, 0.9730745570664152, 1.9388840293634724, 2.9601163041114504, 4.01771285952253, 4.983060642383229, 5.958195609664811, 6.974892409550564, 7.9165179104847505, 8.930412225315736, 9.862326743572044, 10.835231945319977, 10.726382232930844, 9.799854654419473, 8.772070236639165, 7.801755370275506, 6.774758762251718, 5.826882518154704, 4.81749365273976, 3.8732967666919897, 2.9637527278620084, 2.042061338982024, 2.9960508898262854, 3.956960171272462, 4.909506258275856, 5.844976388131467, 6.789243525545575, 7.813363949277123, 8.839103953880873, 9.788139678988077, 10.746158552226808, 11.688215054384258, 11.735822493276283, 10.803624818684622, 9.734735928341946, 8.673500080807877, 7.727329491192018, 6.801777065356939, 5.80695432397393, 4.811733444825042, 3.9019036227582484, 3.084945763946468, 3.953164079002689, 4.932424920606657, 5.8622759338237564, 6.806269332216761, 7.780272052288068, 8.842472032533225, 9.812674127851146, 10.75724180649523, 11.699032290964194, 12.673435726786256, 12.696542152925481, 11.758749381121616, 10.68856181555955, 9.728392081906899, 8.739430783524995, 7.761567711442731, 6.7919825777969685, 5.826127453639187, 4.871294203726196, 4.024044599815648, 4.890545556532052, 5.91790631894066, 6.805520947975831, 7.841582209197446, 8.82093704268647, 9.748137955740345, 10.805581876005757, 11.720998210672695, 12.729356873615362, 13.693618923232574, 13.666227558750448, 12.611374282711923, 11.668804358543074, 10.692814111600672, 9.68374756272126, 8.689101900652563, 7.831628252905248, 6.879394071490684, 5.897775534582396, 5.007894306671267, 5.834104529508231, 6.7791538212811755, 7.826793060809372, 8.866478609642597, 9.762888134445737, 10.794598582715958, 11.747328853912306, 12.757964646996577, 13.743928506551441, 14.764025785920515, 14.539778924170111, 13.50727489770934, 12.602810189387073, 11.588671766266138, 10.637704439706065, 9.691750467192891, 8.795672770931013, 7.810995927081162, 6.846591244619842, 6.066476000173714, 6.865898357417895, 7.756233967034974, 8.830306720020465, 9.874239682844337, 10.694242180437783, 11.625836288694671, 12.598439291872603, 13.663836808502433, 14.609047042415893, 15.665730379059104, 15.439570374210932, 14.37613189411113, 13.554443960556592, 12.583766795546607, 11.644481601333766, 10.71687677931501, 9.734181116810694, 8.750365528746698, 7.784599085226303, 7.049674885266304, 7.899140164557721, 8.778221368872579, 9.720992136940371, 10.69998309786948, 11.629290492415217, 12.61492776709308, 13.666478539564032, 14.654844851774639, 15.567463085566361, 16.576351127132977, 16.291741461803547, 15.30518647270734, 14.52439579909798, 13.63239470639292, 12.690216046484483, 11.739606910796287, 10.794799101057325, 9.748846925217684, 8.785669342885699, 8.119442803537902, 8.896997807907466, 9.704825721718134, 10.683824972843686, 11.609856699744014, 12.218553024562118, 12.992034703368608, 13.777083686964302, 14.658469816072252, 15.66816428664855, 16.637966942527118, 17.246937059265786, 16.369719610005244, 15.452081432732157, 14.602115973633415, 13.69100994260888, 12.708892335637538, 11.772285903145676, 10.697991503540354, 9.743341883574875, 9.08470289996248, 9.910253098677606, 10.776523002098736, 11.731550085277105, 11.948362048773992, 11.1711507404758, 11.985061964534765, 12.804861531901667, 13.661914379112595, 14.675531242575124, 15.586760892498466, 16.53795322764967, 17.431366473226934], [17.47733796037223, 16.551899146969195, 15.6198664777699, 14.6648699282536, 13.682175694121428, 12.718285897488093, 11.827969436421636, 10.978094242351503, 9.969059013850773, 10.76954197247926, 10.841765578190426, 9.887219274922534, 10.81719896014358, 11.658309002214995, 12.601665222865229, 13.61098821789859, 14.662774551228953, 15.591978724100324, 16.603127436075788, 17.413484331484465, 16.405652203019205, 15.609028813290887, 14.682380710353037, 13.692388739111315, 12.659050394720733, 11.744456753918044, 10.785503417894954, 9.966643403676972, 9.040605574873013, 9.730491120380481, 10.662920701421609, 10.925050706154634, 11.811556025745201, 12.655500308212769, 13.64932076380667, 14.617091590571317, 15.681484093192585, 16.647562933663274, 17.524456593911456, 16.45772760054813, 15.399870415802559, 14.603955073803249, 13.63608183885598, 12.68814122096715, 11.689262139500443, 10.74643894393901, 9.79036485845679, 8.951825733031644, 8.058696952164459, 8.712684895435638, 9.647053204886518, 10.626718444513667, 11.577515005094751, 12.467527998278406, 13.460645351547475, 14.41146912689142, 15.224401908251584, 16.212002597313287, 16.555492456124355, 15.558344113745445, 14.431851108207473, 13.541153728970245, 12.626156450988779, 11.673522397760197, 10.627688985217432, 9.748062388840145, 8.791171275900469, 7.903441037997364, 7.0071714239787815, 7.734773232595608, 8.67341970391103, 9.664571907638374, 10.598250746355925, 11.485772319937949, 12.469113582618764, 13.35644543382861, 14.287130813375214, 15.278618878019826, 15.61288992806409, 14.6342291462419, 13.500415426283366, 12.530162404133577, 11.594467139859844, 10.725986968919967, 9.666833455465833, 8.774046389102713, 7.824234167520315, 6.954256958547745, 5.997808728436471, 6.7202786225611195, 7.74385387483422, 8.711768793353022, 9.525630626747054, 10.530615039634135, 11.41808571330785, 12.399811733742036, 13.452956608151135, 14.346748482668254, 14.621241019203858, 13.690496699749993, 12.643455835163191, 11.636743150432324, 10.654718848079757, 9.74911489318747, 8.727427264398779, 7.784969412714499, 6.871320758427303, 5.923233674201182, 4.956645851432738, 5.782499403928655, 6.744906318553227, 7.679804352197873, 8.576630808948872, 9.570387789557675, 10.490648845340196, 11.416320031755374, 12.420204540009482, 13.410909822650067, 13.67725631578229, 12.712130444674802, 11.68828355422138, 10.648649346303594, 9.659519101709526, 8.772085054495289, 7.782687733821701, 6.840140248995664, 5.915052297490965, 5.007132984926242, 4.012094734845779, 4.856116399494211, 5.865317098290166, 6.706454830277613, 7.6300242649077745, 8.575105695509304, 9.496779532089347, 10.461994075191395, 11.491634710841511, 12.485891017770383, 12.688264888986188, 11.734271560984617, 10.726214103394884, 9.692011360536487, 8.709144558489475, 7.793341677068441, 6.831915741621447, 5.848616511599826, 4.912525907663834, 3.981783248145563, 3.0065881310854987, 3.871149031314494, 4.797846354085754, 5.767120615087435, 6.649820431427584, 7.609676161672288, 8.570690121917208, 9.621806375811168, 10.583438411069906, 11.542873486928185, 11.724953784423983, 10.716201676296013, 9.829837730617745, 8.757124305756838, 7.779100380339963, 6.808449977545235, 5.821585224717886, 4.9290032739450975, 3.901387808981445, 2.931142687925817, 1.9441517477875472, 2.931126385136978, 3.818744662903508, 4.754235514942016, 5.688255137339439, 6.665485998398755, 7.693683596493952, 8.652895423720821, 9.606346306059724, 10.575641959270879, 10.836083947158142, 9.802265483414608, 8.797951633979885, 7.848768389929338, 6.834521244349554, 5.853368161791472, 4.804685064837942, 3.9365031334640435, 3.0288084131711246, 2.024925524174062, 0.9608548934030022, 1.9029205969430532, 2.8855430467388583, 3.9420888155163087, 4.989113043313094, 5.96523551974278, 6.958671379829147, 7.916932428839733, 8.941114738686663, 9.894048559918549, 10.020888351457943, 9.035706593532007, 8.038209972480576, 7.001699653042948, 5.969061149392165, 4.898506835186361, 3.869394518952962, 2.9352585697750264, 1.964374528446698, 0.9965087753727383, 0.0, 1.0528208646810655, 2.1070636461068597, 3.055539697855408, 4.040731859531159, 5.0064961525151475, 5.945868517706673, 6.94018410297299, 7.991969575567511, 8.941339404406843, 9.93123337419799, 9.869690658980515, 8.850281112785046, 7.884636135566865, 6.896777652549657, 5.842148843903217, 4.837142284165202, 3.862757022180265, 2.9450187738242475, 1.9306761568487132, 0.9648666845516561, 1.986098959299634, 3.0436955147107136, 4.009043297571413, 4.984178264852995, 5.978383634177826, 6.9200091351120125, 7.933903449942998, 8.865817968199305, 9.838723169947238, 10.910349073169233, 10.796363429792212, 9.768579012011902, 8.798264145648243, 7.771267537624455, 6.8233912935274414, 5.814002428112498, 4.869805542064728, 3.937973665519166, 2.978425070998427, 2.022033545014469, 2.9829428264606457, 3.9354889134640394, 4.87095904331965, 5.815226180733758, 6.839346604465307, 7.846746957092629, 8.795782682199834, 9.753801555438564, 10.695858057596014, 11.695415448355678, 11.800133594057357, 10.731244703714683, 9.670008856180614, 8.723838266564755, 7.798285840729678, 6.8034630993466685, 5.80824222019778, 4.876124560415406, 3.971540381959645, 2.9791467341908726, 3.9584075757948405, 4.88825858901194, 5.832251987404944, 6.806254707476251, 7.8684546877214085, 8.83865678303933, 9.783224461683414, 10.706675294175952, 11.681078729998012, 12.656135108004875, 12.755258156494351, 11.685070590932288, 10.724900857279636, 9.735939558897732, 8.758076486815469, 7.7662035154541265, 6.800348391296345, 5.845515141383354, 4.910639217828825, 3.9165282117202356, 4.943888974128844, 5.831503603164014, 6.8675648643856295, 7.846919697874653, 8.774120610928527, 9.831564531193939, 10.746980865860879, 11.755339528803546, 12.704921816734231, 13.625820513829842, 13.607883058084658, 12.665313133915811, 11.68932288697341, 10.680256338093997, 9.685610676025302, 8.805849190562405, 7.853615009147842, 6.871996472239554, 5.852945921522048, 4.860087184696415, 5.805136476469359, 6.852775715997556, 7.89246126483078, 8.78887078963392, 9.820581237904142, 10.773311509100488, 11.78394730218476, 12.769911161739625, 13.775328679422172, 14.597163570290872, 14.50378367308208, 13.599318964759812, 12.585180541638877, 11.634213215078804, 10.68825924256563, 9.769893708588171, 8.78521686473832, 7.820812182277, 6.864274903986168, 5.8918810126060785, 6.7822166222231575, 7.8562893752086485, 8.90022233803252, 9.720224835625967, 10.651818943882855, 11.624421947060787, 12.689819463690617, 13.635029697604077, 14.691713034247288, 15.594708736827371, 15.372640669483868, 14.531574633802371, 13.557987733203765, 12.618702538990924, 11.691097716972168, 10.708402054467852, 9.724586466403856, 8.758820022883462, 7.847473789078758, 6.925122819745905, 7.804204024060762, 8.746974792128553, 9.725965753057661, 10.6552731476034, 11.640910422281264, 12.692461194752216, 13.680827506962823, 14.593445740754545, 15.602333782321159, 16.603977182795372, 16.30169524808008, 15.50152647234376, 14.606615644050079, 13.664436984141641, 12.713827848453445, 11.769020038714483, 10.723067862874842, 9.759890280542857, 8.917241707350357, 7.922980463095649, 8.730808376906316, 9.709807628031868, 10.635839354932196, 11.647705035380413, 12.59152074004844, 13.531305867909877, 14.530891333840177, 15.540585804416475, 16.520330503451998, 17.55519654020898, 17.366228385377983, 16.429212105977935, 15.576336911290573, 14.665230880266037, 13.683113273294696, 12.746506840802834, 11.672212441197512, 10.717562821232033, 9.882501803774934, 8.93623575386579, 9.802505657286918, 10.757532740465287, 10.951853273401253, 11.882774532529014, 12.882043100279878, 13.70184266764678, 14.634422023816603, 15.648038887279132, 16.559268537202474, 17.51046087235368, 18.427875248599673], [18.480688259473204, 17.501932365729374, 16.54021248833207, 15.58521593881577, 14.602521704683598, 13.599797977531903, 12.709481516465447, 11.713691645757153, 10.704656417256423, 9.854688502598318, 10.148824396269228, 10.817171774300682, 11.747151459521728, 12.588261501593143, 13.531617722243377, 14.540940717276738, 15.5927270506071, 16.52193122347847, 17.533079935453934, 18.343436830862615, 17.425219825638163, 16.559062032051067, 15.602726720915207, 14.612734749673486, 13.579396405282903, 12.625968833961855, 11.667015497938765, 10.721504200622888, 9.776202978278663, 8.81563765049954, 9.748067231540666, 10.677272589275827, 11.69192218010683, 12.537635999457892, 13.57087516058266, 14.436014245445657, 15.280822063013325, 16.246900903484015, 17.27063536353791, 17.38768009992628, 16.419438038421518, 15.62352269642221, 14.65564946147494, 13.657419158166313, 12.609608150062613, 11.62795102398282, 10.671876938500601, 9.779983999398919, 8.795756916331225, 7.797831425554698, 8.73219973500558, 9.711864974632727, 10.66266153521381, 11.552674528397464, 12.545791881666533, 13.496615657010478, 14.309548438370642, 15.297149127432345, 16.256629747251854, 16.48829661312359, 15.451418730826434, 14.560721351589207, 13.645724073607742, 12.642800334959357, 11.596966922416593, 10.629574468883956, 9.67268335594428, 8.757168069514764, 7.778100822845619, 6.819919762714667, 7.758566234030089, 8.749718437757434, 9.683397276474983, 10.570918850057007, 11.554260112737822, 12.441591963947667, 13.372277343494272, 14.363765408138883, 15.29113756602947, 15.568671293491688, 14.519983048902327, 13.549730026752538, 12.614034762478807, 11.695264906119128, 10.636111392664994, 9.723838067191648, 8.705746247564125, 7.807983990065144, 6.85153575995387, 5.805425152680178, 6.829000404953279, 7.796915323472081, 8.610777156866112, 9.615761569753193, 10.503232243426908, 11.484958263861094, 12.538103138270193, 13.431895012787308, 14.402330100085287, 14.665859676683114, 13.666566499670619, 12.656310773051288, 11.67428647069872, 10.71839283038663, 9.69670520159794, 8.734761090803435, 7.752832838471113, 6.77696070571858, 5.810372882950136, 4.867645934047713, 5.830052848672286, 6.764950882316932, 7.66177733906793, 8.655534319676732, 9.575795375459254, 10.501466561874432, 11.50535107012854, 12.496056352769122, 13.439495061588863, 13.72672372972444, 12.711394218728808, 11.671760010811022, 10.682629766216953, 9.74136299169445, 8.751965671020862, 7.7899319270845995, 6.864843975579901, 5.897985374714118, 4.902947124633655, 3.94126292961327, 4.950463628409225, 5.7916013603966725, 6.7151707950268325, 7.660252225628362, 8.581926062208405, 9.547140605310453, 10.57678124096057, 11.571037547889437, 12.523382998519212, 12.748864846034255, 11.749324767902312, 10.715122025043915, 9.732255222996903, 8.769819926967374, 7.801193678820607, 6.817894448798986, 5.881803844862994, 4.91120289173295, 3.8974405208733742, 2.9562955614335524, 3.882992884204813, 4.852267145206493, 5.734966961546642, 6.694822691791346, 7.655836652036266, 8.706952905930226, 9.668584941188962, 10.62802001704724, 11.572127711127166, 11.730794961345651, 10.88265859529881, 9.809945170437903, 8.831921245021029, 7.861270842226302, 6.874406089398952, 5.8982812111442575, 4.870665746180605, 3.900420625124977, 2.913429684986707, 2.0162729152560366, 2.903891193022566, 3.839382045061074, 4.773401667458497, 5.750632528517813, 6.77883012661301, 7.738041953839878, 8.69149283617878, 9.660788489389933, 10.617452289089051, 10.855086348095675, 9.850772498660952, 8.901589254610405, 7.887342109030621, 6.906189026472539, 5.857505929519008, 4.989323998145109, 4.04719357906189, 2.9942034613732225, 1.9301328306021626, 0.9880671270621117, 1.970689576857917, 3.010190485224542, 4.0036744969499285, 4.939773598559596, 5.914869807526206, 6.864111564158667, 7.888293874005596, 8.841227695237482, 9.850136212948804, 10.088527458213072, 9.091030837161641, 8.054520517724013, 7.021882014073231, 5.951327699867427, 4.922215383634028, 3.9880794344560924, 3.0171953931277637, 2.049329640053804, 1.0528208646810655, 0.0, 1.0542427814257942, 2.0027188331743426, 2.9879109948500937, 3.953675287834082, 4.893047653025607, 5.887363238291924, 6.939148710886444, 7.8885185397257755, 8.878412509516922, 9.93853882224742, 9.903101977466113, 8.937457000247932, 7.949598517230723, 6.894969708584284, 5.8899631488462685, 4.915577886861331, 3.957842350230406, 2.943499733254872, 1.9776902609578146, 0.9564579862098366, 2.000192853879656, 2.9655406367403554, 3.940675604021937, 4.925562769496761, 5.8671882704309475, 6.881082585261932, 7.81299710351824, 8.785902305266173, 9.857528208488167, 10.784055786999538, 10.78317229706154, 9.812857430697882, 8.785860822674094, 7.83798457857708, 6.786317363911514, 5.842120477863744, 4.867926164897314, 3.908377570376575, 2.9519860443926174, 1.991076762946441, 2.943622849949835, 3.8790929798054457, 4.823360117219553, 5.847480540951102, 6.793926092411564, 7.742961817518768, 8.700980690757499, 9.64303719291495, 10.642594583674613, 11.574792258266275, 11.745837988764322, 10.684602141230252, 9.738431551614394, 8.770600776528694, 7.775778035145684, 6.780557155996796, 5.806077059793554, 4.901492881337793, 3.909099233569021, 2.966541512280636, 3.8963925254977356, 4.840385923890739, 5.8143886439620465, 6.876588624207203, 7.846790719525124, 8.746692587976161, 9.653854429494885, 10.628257865316947, 11.603314243323812, 12.607809025020094, 12.699663875981926, 11.739494142329274, 10.711302535830853, 9.692518634065257, 8.696156014832274, 7.730300890674493, 6.7754676407615015, 5.840591717206973, 4.846480711098383, 4.0412909762136975, 4.839637539649809, 5.875698800871424, 6.8550536343604485, 7.782254547414323, 8.839698467679733, 9.710448992153626, 10.717654341907354, 11.652100952053166, 12.572999649148779, 13.543912733958711, 13.640676110848933, 12.66468586390653, 11.655619315027119, 10.62005282327509, 9.735801689940553, 8.783567508525989, 7.801948971617702, 6.782898420900196, 5.7900396840745625, 5.112195294548162, 5.88732986132229, 6.9031085343362015, 7.797004726119716, 8.828715174389938, 9.781445445586282, 10.74741542847751, 11.732225974843434, 12.722507814741107, 13.54434270560981, 14.489126263196226, 14.5337611120096, 13.519622688888665, 12.568655362328592, 11.622701389815418, 10.699846207966317, 9.715169364116466, 8.750764681655149, 7.7942274033643155, 6.821833511984226, 6.08927544030196, 6.926565533653222, 7.957354772708702, 8.728358772111763, 9.659952880368651, 10.632555883546583, 11.697953400176413, 12.643163634089873, 13.65055259896607, 14.541887872146308, 15.465575850006864, 15.461527133180518, 14.487940232581911, 13.54865503836907, 12.621050216350314, 11.638354553845998, 10.654538965782002, 9.68877252226161, 8.777426288456907, 7.855075319124053, 7.111262842139564, 7.883262936308319, 8.862253897237428, 9.663407084089197, 10.64904435876706, 11.700595131238012, 12.688961443448619, 13.601579677240341, 14.610467718806955, 15.551156318114309, 16.394630428603076, 16.43147897172191, 15.536568143428225, 14.594389483519787, 13.64378034783159, 12.69897253809263, 11.653020362252988, 10.689842779921005, 9.847194206728505, 8.852932962473798, 8.037867194985118, 8.879758398200094, 9.805790125100422, 10.65583897186621, 11.599654676534236, 12.539439804395673, 13.539025270325974, 14.548719740902271, 15.528464439937794, 16.50635191557655, 17.447522326769782, 17.359164605356085, 16.50628941066872, 15.595183379644183, 14.613065772672842, 13.67645934018098, 12.602164940575658, 11.64751532061018, 10.812454303153082, 9.866188253243937, 9.10956447536572, 9.927483510633513, 10.808477502964568, 11.703241255952527, 12.606627415368079, 13.511661959458309, 14.515211367556006, 15.528828231018535, 16.54577338020594, 17.496965715357145, 18.50916918999147], [18.356507598641056, 17.47800240709815, 16.440141241056125, 15.485144691539826, 14.435741469863276, 13.46350250222909, 12.628984851838416, 11.638389749710212, 10.844078266883965, 9.9926941738828, 10.115008725777212, 10.852546085658346, 11.73849542902132, 12.587043488768535, 13.530399709418768, 14.494333801431251, 15.369738057154546, 16.29894223002592, 17.317410601814327, 18.275350547272435, 17.284821841288032, 17.454025058998067, 16.497689747862207, 15.507697776620486, 14.474359432229903, 13.520931860908854, 12.561978524885765, 11.616467227569888, 10.671166005225663, 9.71060067744654, 9.045649796424435, 9.814714654426247, 10.7441383634197, 11.58985218277076, 12.623091343895528, 13.488230428758525, 14.333038246326193, 15.299117086796882, 16.322851546850774, 17.25423068726056, 16.279040054071388, 16.523968759426275, 15.556095524479005, 14.557865221170378, 13.504571177009613, 12.52291405092982, 11.5668399654476, 10.674947026345919, 9.690719943278225, 8.692794452501698, 8.019016073616868, 8.849307039783147, 9.714877718526678, 10.604890711710333, 11.598008064979402, 12.548831840323347, 13.36176462168351, 14.349365310745213, 15.308845930564722, 16.305994272943632, 15.352122629857464, 15.461167414593271, 14.546170136611806, 13.543246397963422, 12.497412985420658, 11.524537495830955, 10.56764638289128, 9.652131096461764, 8.67306384979262, 7.714882789661668, 6.993547064458612, 7.887160502907854, 8.735613459787851, 9.623135033369875, 10.60647629605069, 11.493808147260536, 12.42449352680714, 13.415981591451752, 14.343353749342338, 15.322014531164529, 14.438251728569142, 14.450176089756603, 13.514480825482872, 12.595710969123193, 11.536557455669058, 10.61880109413865, 9.600709274511125, 8.702947017012145, 7.746498786900871, 6.700388179627179, 6.063981235381802, 6.934357388622502, 7.66299334017898, 8.667977753066062, 9.555448426739776, 10.537174447173962, 11.590319321583062, 12.460666073047646, 13.431101160345625, 14.36184547979949, 13.454097175454383, 13.556756836055353, 12.574732533702784, 11.618838893390695, 10.597151264602005, 9.629724117750436, 8.647795865418113, 7.671923732665581, 6.705335909897137, 5.762608960994714, 5.065033679100809, 5.902392947467352, 6.7139935223807985, 7.707750502989601, 8.628011558772123, 9.5536827451873, 10.557567253441409, 11.52482741302946, 12.4682661218492, 13.494586005002306, 12.579023181521652, 12.572206073815089, 11.58307582922102, 10.641809054698514, 9.652411734024927, 8.6848949540316, 7.759807002526902, 6.792948401661119, 5.7979101515806555, 4.836225956560271, 4.002679811722094, 4.843817543709539, 5.767386978339701, 6.7124684089412305, 7.634142245521273, 8.599356788623322, 9.628997424273438, 10.599808608149775, 11.55215405877955, 12.506147386781121, 11.594468967502952, 11.615568088047981, 10.63270128600097, 9.67026598997144, 8.701639741824673, 7.718340511803053, 6.782249907867061, 5.806165918679951, 4.792403547820375, 3.8512585883805532, 2.9352090675176816, 3.904483328519361, 4.787183144859511, 5.747038875104215, 6.708052835349134, 7.759169089243095, 8.697356001449299, 9.656791077307577, 10.600898771387504, 11.609650879515474, 10.696338704748209, 10.864187951863698, 9.886164026446824, 8.915513623652096, 7.901470315068098, 6.889139287423655, 5.861523822460002, 4.891278701404374, 3.904287761266104, 2.9112359422030374, 1.9561073763354344, 2.891598228373942, 3.8256178507713656, 4.8028487118306815, 5.8310463099258785, 6.766813014100214, 7.720263896439117, 8.689559549650271, 9.64622334934939, 10.680041813092924, 9.956035065822258, 9.955832036036199, 8.941584890456415, 7.960431807898333, 6.911748710944802, 6.043566779570903, 5.064654661966369, 4.011664544277702, 2.9475939135066413, 2.0055282099665903, 1.0229057601707852, 1.9559477037987478, 2.9494317155241343, 3.8855308171338017, 4.860627026100412, 5.809868782732872, 6.834051092579802, 7.786984913811688, 8.79589343152301, 9.781075189448947, 10.145273618587435, 9.108763299149807, 8.076124795499025, 7.005570481293221, 5.976458165059822, 5.042322215881886, 4.071438174553558, 3.103572421479598, 2.1070636461068597, 1.0542427814257942, 0.0, 0.9484760517485483, 1.9336682134242993, 2.8994325064082873, 3.838804871599813, 4.833120456866129, 5.8849059294606505, 6.834275758299982, 7.824169728091128, 8.884296040821628, 10.957344758891905, 9.991699781673724, 9.003841298656516, 7.949212490010078, 6.944205930272062, 5.969820668287125, 5.0049309918855105, 3.9905883749099766, 3.0247789026129195, 2.0035466278649414, 0.945950072453862, 1.9112978553145612, 2.8864328225961424, 3.8713199880709657, 4.812945489005152, 5.826839803836138, 6.758754322092446, 7.731659523840378, 8.803285427062372, 9.729813005573742, 11.681150047164168, 10.71083518080051, 9.683838572776722, 8.735962328679708, 7.684295114014143, 6.740098227966373, 5.765903914999943, 4.806355320479204, 3.849963794495246, 2.8890545130490692, 1.9365084260456755, 2.8473767524175404, 3.791643889831648, 4.8157643135631965, 5.739683310985768, 6.688719036092973, 7.646737909331704, 8.588794411489154, 9.588351802248818, 10.520549476840479, 12.64381573886695, 11.58257989133288, 10.636409301717022, 9.668578526631322, 8.673755785248312, 7.678534906099425, 6.704054809896183, 5.799470631440421, 4.807076983671649, 3.864519262383264, 2.9491990298666506, 3.8086696965028346, 4.782672416574141, 5.844872396819298, 6.80576091184666, 7.692449806550365, 8.599611648069091, 9.574015083891151, 10.549071461898016, 11.553566243594299, 13.597641626084554, 12.637471892431902, 11.609280285933481, 10.590496384167885, 9.594133764934902, 8.628278640777122, 7.6734453908641305, 6.738569467309601, 5.744458461201012, 4.9392687263163255, 3.8924440440187245, 4.847056881697922, 5.823337406972543, 6.7505383200264175, 7.807982240291829, 8.65620621072783, 9.66341156048156, 10.59785817062737, 11.518756867722983, 12.489669952532916, 14.53865386095156, 13.562663614009159, 12.553597065129747, 11.518030573377718, 10.633779440043181, 9.681545258628619, 8.699926721720331, 7.680876171002826, 6.688017434177192, 5.987775605219403, 4.940136365691206, 5.874466615162699, 6.7652884987318105, 7.796998947002032, 8.749729218198377, 9.693172647051714, 10.677983193417639, 11.668265033315311, 12.490099924184014, 13.43488348177043, 15.431738862112228, 14.417600438991293, 13.46663311243122, 12.520679139918046, 11.597823958068947, 10.613147114219096, 9.648742431757777, 8.692205153466945, 7.719811262086856, 6.964855750973201, 5.979372038022138, 6.9287128535352, 7.696642544723857, 8.628236652980746, 9.600839656158678, 10.666237172788508, 11.611447406701968, 12.596309817540275, 13.487645090720513, 14.411333068581069, 16.359504883283147, 15.385917982684541, 14.4466327884717, 13.519027966452944, 12.536332303948628, 11.552516715884632, 10.586750272364238, 9.675404038559536, 8.753053069226683, 7.878840208745027, 6.936069440677235, 7.915060401606343, 8.631690856701292, 9.617328131379155, 10.668878903850107, 11.657245216060714, 12.569863449852436, 13.57875149141905, 14.496913536688513, 15.34038764717728, 17.329456721824535, 16.434545893530853, 15.492367233622417, 14.54175809793422, 13.59695028819526, 12.550998112355618, 11.587820530023633, 10.745171956831134, 9.750910712576427, 8.805444561590582, 7.932564902569011, 8.85859662946934, 9.624122744478305, 10.56793844914633, 11.507723577007768, 12.507309042938068, 13.517003513514366, 14.496748212549889, 15.452109134150755, 16.39327954534399, 18.25714235545871, 17.404267160771347, 16.493161129746813, 15.511043522775472, 14.57443709028361, 13.500142690678288, 12.545493070712809, 11.710432053255712, 10.764166003346567, 9.877141841971184, 8.98029001500243, 9.861284007333484, 10.671525028564622, 11.574911187980174, 12.479945732070403, 13.4834951401681, 14.49711200363063, 15.514057152818037, 16.465249487969242, 17.45492640856568], [17.408031546892506, 16.534136097269386, 15.517654198473851, 14.56265764895755, 13.513254427281, 12.541015459646815, 11.70649780925614, 10.715902707127936, 10.029570060350522, 10.916545587528, 10.956964585263322, 9.992618953329384, 10.878568296692356, 11.727116356439568, 12.670472577089802, 13.634406669102288, 14.509810924825583, 15.439015097696954, 16.45748346948536, 17.41542341494347, 16.336345789539482, 17.281365747637427, 16.525130809341558, 15.535138838099835, 14.536379726681695, 13.514844603216863, 12.748963827782822, 11.745028051514776, 10.958023499328283, 10.659076729195089, 9.887605655910544, 8.954787522097284, 9.884211231090735, 10.729925050441794, 11.763164211566561, 12.628303296429563, 13.47311111399723, 14.439189954467919, 15.462924414521812, 16.385499398735394, 15.330564002322836, 16.276292008149788, 16.504571576227555, 15.506341272918924, 14.45304722875816, 13.471390102678368, 12.515316017196149, 11.623423078094467, 10.639195995026773, 9.641270504250246, 8.931346243299096, 7.989379907454184, 8.854950586197713, 9.744963579381366, 10.738080932650435, 11.688904707994384, 12.501837489354548, 13.48943817841625, 14.44891879823576, 15.437262984418469, 14.403646578108914, 15.372729913260025, 15.494646188360354, 14.49172244971197, 13.445889037169206, 12.473013547579503, 11.516122434639827, 10.600607148210312, 9.621539901541167, 8.663358841410215, 7.905877234140839, 7.027233370578891, 7.875686327458887, 8.76320790104091, 9.746549163721728, 10.633881014931573, 11.564566394478177, 12.55605445912279, 13.483426617013375, 14.396662211697354, 13.489775676820592, 14.460028698970381, 14.46295687723142, 13.54418702087174, 12.485033507417606, 11.567277145887198, 10.549185326259673, 9.651423068760693, 8.694974838649419, 7.648864231375727, 6.976311405064029, 6.074430256293539, 6.803066207850017, 7.808050620737097, 8.695521294410813, 9.677247314845, 10.728422746493143, 11.512190021299098, 12.482625108597077, 13.413369428050942, 12.505621123705833, 13.519461454069715, 13.523208585451332, 12.567314945139243, 11.545627316350553, 10.578200169498984, 9.59627191716666, 8.62039978441413, 7.653811961645685, 6.711085012743262, 5.977363848783036, 5.04246581513839, 5.854066390051835, 6.847823370660637, 7.768084426443159, 8.693755612858336, 9.69567067835149, 10.576351361280912, 11.519790070100653, 12.546109953253758, 11.630547129773104, 12.636833644379907, 12.531551880969568, 11.590285106447062, 10.600887785773475, 9.633371005780148, 8.70828305427545, 7.7414244534096674, 6.746386203329204, 5.784702008308819, 4.9170571744972, 3.983890411380576, 4.907459846010737, 5.852541276612267, 6.77421511319231, 7.739429656294357, 8.711794000794102, 9.651332556401227, 10.603678007031002, 11.557671335032573, 10.645992915754404, 11.6801956586128, 11.581177337749518, 10.618742041719988, 9.650115793573221, 8.6668165635516, 7.73072595961561, 6.7546419704285, 5.740879599568924, 4.799734640129102, 3.88368511926623, 3.0445561961903973, 3.927256012530547, 4.887111742775251, 5.8481257030201705, 6.838017878474055, 7.7488799497007514, 8.70831502555903, 9.652422719638956, 10.661174827766926, 9.747862652999661, 10.820576077860569, 10.83464007819537, 9.863989675400644, 8.849946366816646, 7.837615339172203, 6.80999987420855, 5.839754753152922, 4.852763813014652, 3.859711993951586, 2.904583428083983, 2.0316710960449784, 2.965690718442402, 3.9429215795017183, 4.906372217788453, 5.818336962351666, 6.771787844690569, 7.741083497901723, 8.697747297600841, 9.731565761344376, 9.007559014073708, 9.956742258124255, 9.890060942204963, 8.908907859646881, 7.86022476269335, 6.992042831319451, 6.013130713714917, 4.96014059602625, 3.8960699652551893, 2.9540042617151387, 1.9713818119193336, 1.0074716520501994, 2.000955663775586, 2.9370547653852537, 3.9121509743518637, 4.861392730984324, 5.885575040831254, 6.83850886206314, 7.847417379774463, 8.832599137700399, 9.83009575875183, 10.057239350898355, 9.024600847247573, 7.954046533041769, 6.92493421680837, 5.990798267630434, 5.019914226302106, 4.0520484732281465, 3.055539697855408, 2.0027188331743426, 0.9484760517485483, 0.0, 0.985192161675751, 1.950956454659739, 2.8903288198512644, 3.884644405117581, 4.9364298777121025, 5.885799706551434, 6.87569367634258, 7.935819989073079, 10.683550131973938, 10.940175833422272, 9.952317350405064, 8.897688541758626, 7.89268198202061, 6.918296720035673, 5.9534070436340585, 4.939064426658525, 3.9732549543614675, 2.9520226796134894, 1.8944261242024103, 0.988810812732287, 1.9639457800138684, 2.9228439363224172, 3.8644694372566035, 4.87836375208759, 5.810278270343898, 6.78318347209183, 7.854809375313824, 8.781336953825194, 11.608797492051037, 11.634686594445713, 10.607689986421924, 9.65981374232491, 8.608146527659343, 7.663949641611573, 6.689755328645144, 5.730206734124405, 4.773815208140447, 3.8129059266942704, 2.8603598396908767, 1.924889709835266, 2.869156847249374, 3.8874363465639243, 4.79120725923722, 5.740242984344425, 6.698261857583156, 7.640318359740607, 8.63987575050027, 9.572073425091931, 12.579735740926672, 12.506431304978083, 11.560260715362224, 10.592429940276524, 9.597607198893515, 8.602386319744626, 7.627906223541384, 6.723322045085623, 5.730928397316851, 4.788370676028466, 3.8730504435118522, 2.88618265392056, 3.8601853739918672, 4.916544429820027, 5.857284860098112, 6.743973754801817, 7.651135596320543, 8.625539032142605, 9.600595410149467, 10.605090191845749, 13.533561628144277, 13.561323306077105, 12.533131699578684, 11.514347797813087, 10.517985178580105, 9.552130054422323, 8.59729680450933, 7.6624208809548024, 6.668309874846214, 5.863120139961527, 4.8162954576639265, 3.924569839115647, 4.900850364390269, 5.8280512774441435, 6.868600872816143, 7.707730158979282, 8.714935508733012, 9.649382118878824, 10.570280815974433, 11.541193900784366, 14.438552993885123, 14.486515027654361, 13.47744847877495, 12.44188198702292, 11.557630853688384, 10.60539667227382, 9.62377813536553, 8.604727584648026, 7.611868847822393, 6.911627018864604, 5.863987779336408, 4.9519795725804245, 5.8428014561495365, 6.874511904419758, 7.8103478507226916, 8.744696595303164, 9.729507141669092, 10.719788981566765, 11.541623872435464, 12.486407430021881, 15.431572393179442, 15.341451852636496, 14.390484526076422, 13.444530553563249, 12.521675371714148, 11.536998527864297, 10.572593845402976, 9.616056567112144, 8.643662675732056, 7.888707164618403, 6.90322345166734, 6.006225810952925, 6.774155502141583, 7.705749610398472, 8.678352613576404, 9.743750130206234, 10.688960364119694, 11.647833765791729, 12.539169038971963, 13.462857016832519, 16.383206164348962, 16.30976939632974, 15.3704842021169, 14.442879380098145, 13.460183717593829, 12.476368129529833, 11.510601686009437, 10.599255452204735, 9.676904482871882, 8.802691622390228, 7.859920854322437, 7.025438736490343, 7.709203814119017, 8.69484108879688, 9.746391861267833, 10.73475817347844, 11.647376407270162, 12.656264448836776, 13.548437484939964, 14.39191159542873, 17.341700526939764, 17.358397307176055, 16.416218647267616, 15.465609511579421, 14.52080170184046, 13.474849526000819, 12.511671943668832, 11.669023370476333, 10.674762126221626, 9.729295975235782, 8.856416316214212, 8.044088422935898, 8.701635701896029, 9.645451406564055, 10.585236534425492, 11.584822000355793, 12.59451647093209, 13.574261169967613, 14.503633082402205, 15.44480349359544, 18.26938616057394, 17.484273994270573, 16.482111369849783, 15.505123285761448, 14.59217148041961, 13.611721638948996, 12.66786253742253, 11.877174594699623, 10.943602474386129, 10.800993255616385, 9.90414142864763, 9.046775800800042, 9.749037985982346, 10.652424145397898, 11.557458689488127, 12.561008097585825, 13.574624961048354, 14.591570110235761, 15.521383178140479, 16.50645035681713], [16.422839385216754, 15.548943935593634, 14.616014586588307, 13.661018037072006, 12.631831734917395, 11.65959276728321, 10.825075116892535, 9.834480014764333, 10.780186652403057, 11.732595734425562, 11.766036830374413, 10.801691198440475, 9.931606960001513, 10.780155019748728, 11.723511240398961, 12.687445332411446, 13.56284958813474, 14.492053761006112, 15.51052213279452, 16.45954911335943, 15.35115362786373, 16.29617358596167, 15.623491197456012, 14.63349922621429, 13.65495703431809, 12.633421910853258, 11.867541135419216, 10.863605359151173, 11.708640091380817, 11.629107482062762, 10.696677901021635, 9.763859767208375, 8.937249894399892, 9.782963713750954, 10.81620287487572, 11.68134195973872, 12.526149777306388, 13.492228617777076, 14.514735913044715, 15.400307237059645, 14.345371840647084, 15.291099846474035, 16.294746023350104, 15.66132088289658, 14.613096846912084, 13.631439720832292, 12.853851521022854, 11.878423029796501, 11.622852423130285, 10.624926932353757, 9.837692375181728, 8.798452152565275, 7.907989249506871, 8.798002242690526, 9.791119595959595, 10.741943371303542, 11.554876152663706, 12.542476841725406, 13.476067905097157, 14.45207082274272, 13.418454416433162, 14.387537751584274, 15.431843188389182, 15.475378877815478, 14.429545465272714, 13.456669975683013, 12.499778862743337, 11.584263576313822, 10.605196329644679, 9.647015269513727, 8.812223366023472, 7.836305615689981, 6.928724990768045, 7.816246564350069, 8.799587827030887, 9.68691967824073, 10.617605057787335, 11.601160885637176, 12.510575723874773, 13.411470050021604, 12.50458351514484, 13.47483653729463, 14.41053180156836, 14.527843448975249, 13.468689935521114, 12.550933573990706, 11.532841754363183, 10.635079496864202, 9.678631266752928, 8.632520659479237, 7.882657536946662, 6.883502501404629, 5.856104871159175, 6.861089284046256, 7.748559957719972, 8.730285978154157, 9.743230584817391, 10.526997859623348, 11.497432946921327, 12.428177266375192, 11.520428962030083, 12.534269292393965, 13.516293594746532, 13.550971373242751, 12.52928374445406, 11.561856597602493, 10.57992834527017, 9.604056212517639, 8.637468389749195, 7.694741440846771, 6.883709980665669, 5.948811947021023, 4.9071050533609935, 5.900862033969796, 6.821123089752318, 7.746794276167495, 8.710478516675739, 9.591159199605162, 10.534597908424903, 11.560917791578008, 10.645354968097353, 11.651641482704155, 12.62824484220411, 12.57394153455057, 11.584544213876983, 10.617027433883656, 9.691939482378958, 8.725080881513176, 7.730042631432712, 6.768358436412328, 5.823403306379833, 4.890236543263209, 3.960498509319896, 4.9055799399214255, 5.827253776501468, 6.792468319603516, 7.726601839118351, 8.666140394725478, 9.618485845355252, 10.572479173356824, 9.660800754078652, 10.695003496937048, 11.67787029898406, 11.602398469823497, 10.633772221676729, 9.650472991655109, 8.714382387719118, 7.738298398532008, 6.724536027672432, 5.783391068232611, 4.867341547369739, 3.9509023280730307, 2.9802946758397058, 3.9401504060844097, 4.901164366329329, 5.852825716798304, 6.763687788025001, 7.72312286388328, 8.667230557963206, 9.675982666091176, 8.762670491323911, 9.835383916184819, 10.813407841601693, 10.849181837076394, 9.833602794920155, 8.821271767275713, 7.793656302312059, 6.823411181256431, 5.836420241118161, 4.843368422055095, 3.888239856187492, 2.952749004148984, 2.0187293817515606, 2.995960242810877, 3.9211800561127026, 4.833144800675916, 5.786595683014818, 6.7558913362259725, 7.71255513592509, 8.746373599668624, 8.022366852397957, 8.971550096448503, 9.985797242028287, 9.89410002132263, 8.8454169243691, 7.977234992995201, 6.9983228753906666, 5.945332757701999, 4.88126212693094, 3.9391964233908894, 2.9565739735950842, 1.9926638137259505, 1.015763502099835, 1.9518626037095026, 2.9269588126761126, 3.876200569308573, 4.900382879155503, 5.8533167003873885, 6.862225218098711, 7.847406976024647, 8.844903597076078, 9.881413916513706, 10.009793008923323, 8.939238694717519, 7.91012637848412, 6.975990429306184, 6.005106387977856, 5.037240634903896, 4.040731859531158, 2.9879109948500933, 1.9336682134242993, 0.985192161675751, 0.0, 0.9657642929839881, 1.9051366581755136, 2.89945224344183, 3.951237716036351, 4.900607544875682, 5.890501514666829, 6.950627827397327, 9.698357970298186, 10.664002947516368, 10.937509512080814, 9.882880703434376, 8.87787414369636, 7.903488881711422, 6.938599205309809, 5.924256588334275, 4.9584471160372185, 3.937214841289241, 2.8796182858781614, 1.9728420991640263, 0.997707131882445, 1.9376517746466666, 2.879277275580853, 3.893171590411839, 4.825086108668147, 5.79799131041608, 6.869617213638074, 7.796144792149445, 10.623605330375288, 11.590163144274506, 11.591721272853661, 10.643845028756648, 9.592177814091082, 8.647980928043312, 7.673786615076883, 6.714238020556144, 5.757846494572187, 4.79693721312601, 3.8443911261226162, 2.9089209962670055, 1.98773415488577, 2.9022441848881737, 3.8060150975614695, 4.755050822668674, 5.713069695907405, 6.655126198064856, 7.654683588824519, 8.58688126341618, 11.594543579250923, 12.646822501617866, 12.544292001793961, 11.576461226708263, 10.581638485325254, 9.586417606176365, 8.611937509973124, 7.707353331517362, 6.7149596837485905, 5.772401962460204, 4.857081729943592, 3.8702139403522997, 2.978762681628263, 3.9313522681442756, 4.87209269842236, 5.758781593126066, 6.6659434346447926, 7.640346870466854, 8.615403248473717, 9.619898030169999, 12.548369466468527, 13.609252878147196, 13.517162986010424, 12.498379084244828, 11.502016465011845, 10.536161340854063, 9.58132809094107, 8.646452167386542, 7.6523411612779535, 6.847151426393266, 5.800326744095665, 4.908601125547387, 4.019427672026665, 4.93140213436419, 5.883408711140391, 6.722537997303531, 7.729743347057262, 8.664189957203073, 9.585088654298684, 10.556001739108616, 13.453360832209373, 14.429351079151775, 14.46147976520669, 13.425913273454661, 12.541662140120124, 11.58942795870556, 10.60780942179727, 9.588758871079767, 8.595900134254133, 7.895658305296343, 6.848019065768146, 5.9065474783659, 4.961378763785932, 5.980555727687133, 6.82515568904694, 7.759504433627414, 8.74431497999334, 9.734596819891014, 10.556431710759714, 11.50121526834613, 14.446380231503692, 15.37877671685071, 15.374515812508163, 14.42856183999499, 13.505706658145888, 12.521029814296037, 11.556625131834716, 10.600087853543885, 9.627693962163796, 8.872738451050141, 7.887254738099078, 6.862490579929243, 5.8927328097779785, 6.824326918034868, 7.7969299212128, 8.799896063413662, 9.712754271885267, 10.662641604115978, 11.553976877296213, 12.477664855156767, 15.39801400267321, 16.37160090327182, 16.354515488548643, 15.426910666529885, 14.444215004025569, 13.460399415961573, 12.494632972441178, 11.583286738636476, 10.660935769303622, 9.697817057539776, 8.755046289471984, 7.776055328542875, 6.827781121755413, 7.813418396433276, 8.86496916890423, 9.790904106685868, 10.671170315035734, 11.680058356602348, 12.563245323264212, 13.40671943375298, 16.356508365264013, 17.413775685854638, 16.527884482654972, 15.577275346966776, 14.687589180283801, 13.613904880580826, 12.678573741420866, 11.895473354433358, 11.658793412653367, 10.624421410385331, 9.720736741888759, 8.79470501498843, 7.8202130095324245, 8.76402871420045, 9.703813842061887, 10.703399307992187, 11.652014591128065, 12.631759290163588, 13.518440920726453, 14.459611331919689, 17.28419399889819, 16.537312657579733, 15.53515003315894, 14.558161949070605, 13.645210143728768, 12.664760302258156, 11.72090120073169, 10.93021325800878, 11.75267471949722, 11.696118690765934, 10.768461854322178, 9.797392392852576, 8.867615293618742, 9.771001453034293, 10.676035997124522, 11.67958540522222, 12.67298534916281, 13.68296534019224, 14.536191016464727, 15.521258195141376], [15.457075092232767, 14.583179642609647, 13.65025029360432, 12.695253744088019, 11.776899479113647, 10.917592534653371, 10.267882481344552, 10.707891097171744, 11.653597734810468, 12.606006816832974, 12.712494115429777, 11.74814848349584, 10.87806424505688, 9.918824418301899, 10.862180638952132, 11.761874625236198, 12.637278880959492, 13.566483053830863, 14.584951425619272, 15.49378482037544, 14.385389334879743, 15.330409292977686, 14.657726904472025, 13.667734933230303, 12.800024778514342, 11.89142167822342, 11.310348499871234, 11.737016441558584, 12.582051173788228, 12.575564767118127, 11.643135186077, 10.71031705226374, 9.883707179455259, 8.921633112304125, 9.954872273428892, 10.755771252563472, 11.60057907013114, 12.566657910601828, 13.548971620060726, 14.434542944075655, 13.379607547663097, 14.325335553490048, 15.328981730366117, 14.695556589912593, 13.769813033734632, 12.889439488202454, 12.305487059309398, 12.751834112203912, 12.569309708185648, 11.57138421740912, 10.784149660237095, 9.74490943762064, 8.854446534562237, 7.936671641243697, 8.929788994512766, 9.816372664128293, 10.629305445488457, 11.61690613455016, 12.510303612113168, 13.48630652975873, 12.452690123449175, 13.421773458600287, 14.466078895405195, 15.420913956173209, 14.831386188017643, 13.887816043301319, 13.304680641865719, 12.530720861369186, 11.551653614700042, 10.59347255456909, 9.758680651078839, 8.782762900745347, 7.875182275823411, 6.95491596290324, 7.8740171198556395, 8.761348971065482, 9.692034350612087, 10.635396592653187, 11.544811430890784, 12.445705757037615, 11.538819222160853, 12.509072244310643, 13.444767508584373, 14.47337852733298, 14.41514722057648, 13.497390859046073, 12.479299039418548, 11.581536781919567, 10.625088551808293, 9.5789779445346, 8.829114822002028, 7.829959786459995, 6.802562156214541, 5.999758682599427, 6.822989250544724, 7.804715270978909, 8.777466291833404, 9.561233566639359, 10.531668653937338, 11.462412973391203, 10.554664669046096, 11.568504999409978, 12.550529301762545, 13.506422942074634, 13.475741029509427, 12.508313882657859, 11.526385630325535, 10.550513497573004, 9.58392567480456, 8.641198725902136, 7.830167265721035, 6.895269232076388, 5.853562338416359, 5.039531432522967, 5.89555238257707, 6.809215116443793, 7.7447142236917506, 8.625394906621173, 9.568833615440914, 10.59515349859402, 9.679590675113365, 10.685877189720168, 11.662480549220122, 12.63720629981924, 12.53100149893235, 11.563484718939023, 10.638396767434324, 9.671538166568542, 8.676499916488078, 7.714815721467693, 6.769860591435199, 5.836693828318575, 4.9069557943752615, 4.0442493384745966, 4.9016830693262206, 5.854889159879814, 6.760837546134363, 7.7003761017414885, 8.652721552371263, 9.606714880372834, 8.695036461094665, 9.72923920395306, 10.712106006000072, 11.674541302029601, 11.580229506732096, 10.596930276710475, 9.660839672774484, 8.684755683587374, 7.6709933127277985, 6.729848353287976, 5.813798832425105, 4.897359613128396, 3.9267519608950714, 3.0145796989091624, 3.9755936591540815, 4.887061423814316, 5.797923495041013, 6.7573585708992905, 7.701466264979217, 8.710218373107187, 7.796906198339922, 8.86961962320083, 9.847643548617704, 10.818293951412432, 10.78006007997552, 9.767729052331077, 8.740113587367425, 7.769868466311797, 6.782877526173527, 5.78982570711046, 4.834697141242858, 3.8992062892043498, 2.965186666806926, 2.057642803896827, 2.9554157631287143, 3.8673805076919274, 4.82083139003083, 5.790127043241984, 6.746790842941102, 7.780609306684635, 7.056602559413968, 8.005785803464516, 9.0200329490443, 10.001186031602382, 9.81118121735309, 8.942999285979191, 7.964087168374656, 6.911097050685989, 5.847026419914928, 4.904960716374878, 3.9223382665790725, 2.9584281067099383, 1.9622207871552002, 0.9860983107255143, 1.9611945196921243, 2.9104362763245852, 3.934618586171514, 4.8875524074034, 5.896460925114723, 6.881642683040659, 7.87913930409209, 8.915649623529717, 9.948288127180499, 9.905002987701508, 8.87589067146811, 7.941754722290173, 6.970870680961845, 6.003004927887885, 5.0064961525151475, 3.9536752878340815, 2.8994325064082873, 1.950956454659739, 0.9657642929839881, 0.0, 0.9393723651915254, 1.933687950457842, 2.9854734230523627, 3.934843251891694, 4.9247372216828404, 5.984863534413339, 8.732593677314197, 9.698238654532378, 10.686097137549586, 10.848644996418365, 9.843638436680349, 8.869253174695412, 7.9043634982937965, 6.890020881318263, 5.924211409021206, 4.902979134273228, 3.845382578862149, 2.9386063921480146, 1.9634714248664331, 0.9718874816626784, 1.9135129825968646, 2.927407297427851, 3.859321815684159, 4.832227017432091, 5.903852920654085, 6.8303804991654555, 9.657841037391298, 10.624398851290517, 11.651395459314305, 11.609609321740635, 10.55794210707507, 9.6137452210273, 8.63955090806087, 7.6800023135401325, 6.723610787556175, 5.762701506109998, 4.8101554191066045, 3.8746852892509938, 2.9534984478697583, 1.9364798919041855, 2.8402508045774812, 3.789286529684686, 4.747305402923417, 5.689361905080868, 6.688919295840531, 7.621116970432192, 10.628779286266933, 11.681058208633877, 12.603966188254605, 12.54222551969225, 11.547402778309241, 10.552181899160352, 9.577701802957112, 8.673117624501351, 7.680723976732579, 6.7381662554441935, 5.82284602292758, 4.835978233336288, 3.944526974612251, 2.9655879751602874, 3.9063284054383725, 4.793017300142078, 5.700179141660804, 6.674582577482866, 7.649638955489729, 8.654133737186012, 11.582605173484538, 12.643488585163206, 13.616067480587581, 13.464143377228815, 12.467780757995833, 11.50192563383805, 10.547092383925058, 9.612216460370531, 8.618105454261942, 7.812915719377255, 6.766091037079654, 5.874365418531375, 4.892838754434076, 3.965637841380202, 4.917644418156403, 5.756773704319543, 6.763979054073274, 7.698425664219085, 8.619324361314694, 9.590237446124629, 12.487596539225384, 13.463586786167786, 14.472653335047198, 14.391677566438648, 13.507426433104111, 12.555192251689547, 11.573573714781258, 10.554523164063754, 9.56166442723812, 8.861422598280331, 7.8137833587521355, 6.779958560773312, 5.834789846193344, 5.014791434703144, 5.859391396062952, 6.7937401406434255, 7.7785506870093535, 8.768832526907026, 9.590667417775725, 10.535450975362142, 13.480615938519703, 14.413012423866721, 15.363979750426795, 15.394326132978977, 14.471470951129875, 13.486794107280025, 12.522389424818703, 11.565852146527872, 10.593458255147784, 9.838502744034129, 8.779834625160527, 7.735901662336654, 6.76614389218539, 6.069401525128554, 6.833182253440079, 7.834131770429673, 8.74698997890128, 9.69687731113199, 10.588212584312224, 11.51190056217278, 14.432249709689222, 15.405836610287828, 16.345121804500668, 15.674580738415573, 14.73487126366898, 13.751055675604984, 12.818313397633432, 12.549051031620463, 11.595180065784445, 10.571228139947188, 9.628457371879396, 8.649466410950287, 7.701192204162824, 7.134948569923865, 7.901221501131508, 8.82513981370188, 9.705406022051747, 10.714294063618361, 11.597481030280225, 12.440955140768992, 15.390744072280024, 16.44801139287065, 15.602313775479724, 14.651704639791527, 13.767739092259749, 12.752574279133999, 11.817243139974037, 12.786734389901929, 12.532249015408613, 11.497832492792742, 10.59414782429617, 9.668116097395842, 8.693624091939837, 8.206836078652467, 8.961813609432049, 9.828097712458815, 10.686250298144078, 11.6659949971796, 12.552676627742466, 13.493847038935701, 16.3184297059142, 15.611741950404486, 14.609579325983692, 13.632591241895357, 12.71963943655352, 11.803429700811328, 10.859570599284861, 11.876670543064147, 12.699132004552585, 12.569529773173345, 11.64187293672959, 10.670803475259987, 9.741026376026154, 9.21380881748631, 9.934035764494684, 10.824653149418472, 11.707221056178822, 12.717201047208253, 13.57042672348074, 14.555493902157389], [14.53946042984581, 13.66556498022269, 12.732635631217363, 11.777639081701063, 10.85928481672669, 9.999977872266415, 10.954260758874346, 11.64726346236327, 12.592970100001992, 13.545379182024497, 13.651866480621303, 12.687520848687365, 11.784904090614619, 10.77444253097262, 10.076894131407398, 10.828198627010682, 11.703602882733977, 12.632807055605348, 13.651275427393756, 14.554412455183915, 13.467774672492787, 14.41279463059073, 13.740112242085068, 12.750120270843347, 11.882410116127385, 10.973807015836464, 11.986240452078254, 12.67638880675011, 13.521423538979752, 13.514937132309653, 12.582507551268526, 11.649689417455265, 10.823079544646784, 9.777251224974846, 9.029238590465956, 9.822095254337956, 10.666903071905624, 11.632981912376312, 12.6095992548692, 13.49517057888413, 12.46199288527614, 13.407720891103091, 14.41136706797916, 13.777941927525637, 12.852198371347676, 11.971824825815498, 12.981379011516418, 13.691206477395438, 13.508682073377175, 12.510756582600647, 11.72352202542862, 10.684281802812166, 9.793818899753763, 8.792289753914417, 8.00415531154983, 8.882696665902778, 9.695629447262942, 10.683230136324642, 11.570931246921642, 12.546934164567205, 11.535075461062219, 12.50415879621333, 13.548464233018239, 14.503299293786252, 13.913771525630686, 12.970201380914363, 13.927092493854039, 13.470093226560712, 12.49102597989157, 11.532844919760617, 10.698053016270364, 9.722135265936872, 8.814554641014936, 7.81053407557396, 6.940341121630122, 7.827672972839966, 8.758358352386571, 9.696024227461661, 10.605439065699258, 11.50633339184609, 10.621204559773897, 11.591457581923686, 12.527152846197417, 13.555763864946023, 14.549902099543422, 14.010176365298024, 13.418671404610073, 12.520909147111093, 11.564460916999819, 10.518350309726127, 9.768487187193553, 8.76933215165152, 7.741934521406066, 6.855376795270146, 5.889313252319207, 6.871039272753392, 7.8380939266418785, 8.621861201447834, 9.592296288745812, 10.523040608199677, 9.637050006659138, 10.65089033702302, 11.632914639375588, 12.588808279687678, 13.610495908476368, 13.447686247849383, 12.46575799551706, 11.48988586276453, 10.523298039996085, 9.580571091093661, 8.769539630912561, 7.834641597267914, 6.792934703607885, 5.910969023299811, 4.9618763843515525, 5.869842751252268, 6.805341858500225, 7.686022541429647, 8.629461250249388, 9.655781133402494, 8.761976012726407, 9.768262527333212, 10.744865886833166, 11.719591637432284, 12.676324879989666, 12.502857084130547, 11.577769132625848, 10.610910531760066, 9.615872281679602, 8.654188086659218, 7.709232956626725, 6.7760661935101005, 5.846328159566787, 4.928241965984594, 3.968007071100703, 4.915516794688289, 5.8214651809428375, 6.761003736549963, 7.713349187179737, 8.667342515181309, 7.777421798707707, 8.811624541566104, 9.794491343613116, 10.756926639642645, 11.725552887789412, 11.536302641902, 10.600212037966008, 9.624128048778898, 8.610365677919322, 7.669220718479501, 6.753171197616629, 5.836731978319921, 4.866124326086597, 3.953952064100688, 3.0419176609285636, 3.9476890586227906, 4.858551129849487, 5.817986205707765, 6.762093899787692, 7.770846007915661, 6.857533833148397, 7.930247258009304, 8.908271183426178, 9.878921586220905, 10.916705774142963, 10.707101417522603, 9.67948595255895, 8.709240831503323, 7.722249891365052, 6.729198072301985, 5.774069506434382, 4.838578654395874, 3.9045590319984513, 2.9970151690883524, 2.016043397937189, 2.928008142500402, 3.8814590248393044, 4.850754678050459, 5.807418477749576, 6.84123694149311, 6.117230194222444, 7.06641343827299, 8.080660583852774, 9.061813666410856, 10.110496763364386, 9.882371651170716, 8.903459533566181, 7.850469415877514, 6.786398785106454, 5.844333081566403, 4.861710631770598, 3.897800471901464, 2.9015931523467255, 1.92547067591704, 1.021822154500599, 1.9710639111330597, 2.995246220979989, 3.9481800422118747, 4.957088559923197, 5.942270317849133, 6.939766938900564, 7.976277258338191, 9.008915761988973, 10.03448657262415, 9.815263036659635, 8.8811270874817, 7.91024304615337, 6.942377293079411, 5.945868517706673, 4.893047653025607, 3.838804871599813, 2.8903288198512644, 1.9051366581755136, 0.9393723651915254, 0.0, 0.9943155852663165, 2.0461010578608376, 2.9954708867001694, 3.9853648564913158, 5.0454911692218145, 7.793221312122672, 8.758866289340853, 9.74672477235806, 10.80778750280448, 10.783010801871875, 9.808625539886938, 8.843735863485323, 7.829393246509788, 6.8635837742127315, 5.842351499464754, 4.784754944053675, 3.87797875733954, 2.9028437900579585, 1.911259846854204, 0.9958983202099083, 1.9880349322363253, 2.9199494504926333, 3.892854652240566, 4.9644805554625595, 5.89100813397393, 8.718468672199773, 9.685026486098991, 10.71202309412278, 11.659899338219793, 11.497314472266595, 10.553117586218825, 9.578923273252396, 8.619374678731658, 7.6629831527477, 6.702073871301524, 5.74952778429813, 4.814057654442519, 3.8928708130612835, 2.875852257095711, 1.922636142190525, 2.8716718672977297, 3.8296907405364604, 4.771747242693911, 5.771304633453574, 6.703502308045235, 9.689406921075408, 10.741685843442351, 11.664593823063079, 12.63532585570263, 12.486775143500767, 11.491554264351878, 10.517074168148637, 9.612489989692875, 8.620096341924103, 7.677538620635719, 6.762218388119106, 5.775350598527813, 4.883899339803777, 3.904960340351813, 2.988713743051416, 3.875402637755122, 4.782564479273848, 5.756967915095909, 6.732024293102771, 7.7365190747990535, 10.643232808293012, 11.70411621997168, 12.676695115396056, 13.595116501788421, 13.407153123187356, 12.441297999029576, 11.486464749116584, 10.551588825562055, 9.557477819453467, 8.75228808456878, 7.70546340227118, 6.8137377837229, 5.832211119625602, 4.905010206571728, 4.000029755769447, 4.839159041932587, 5.8463643916863175, 6.780811001832127, 7.701709698927738, 8.67262278373767, 11.548224174033859, 12.52421442097626, 13.533280969855673, 14.522650690998255, 14.446798798295635, 13.494564616881073, 12.512946079972785, 11.49389552925528, 10.501036792429646, 9.800794963471859, 8.753155723943662, 7.7193309259648375, 6.774162211384869, 5.900873885263171, 4.9417767336759955, 5.876125478256469, 6.860936024622397, 7.851217864520067, 8.673052755388769, 9.617836312975186, 12.541243573328178, 13.473640058675196, 14.42460738523527, 15.370561357748443, 14.889815613575635, 13.905138769725784, 13.46176179001023, 12.505224511719398, 11.53283062033931, 10.777875109225656, 9.719206990352053, 8.67527402752818, 7.705516257376916, 6.888170594231054, 5.915567591053122, 6.916517108042717, 7.829375316514323, 8.779262648745032, 9.670597921925268, 10.594285899785824, 13.492877344497696, 14.466464245096303, 15.405749439309144, 14.740904740190057, 13.894681078280867, 12.965769168060248, 13.673931510304152, 13.488423396811989, 12.534552430975971, 11.510600505138713, 10.567829737070921, 9.588838776141813, 8.64056456935435, 7.953717639026365, 6.983606838744552, 7.907525151314923, 8.78779135966479, 9.796679401231405, 10.679866367893268, 11.523340478382035, 14.451371707088498, 15.508639027679124, 14.668637777254208, 13.718028641566011, 12.834063094034235, 11.967287771589262, 12.672861252644758, 13.642352502572649, 13.471621380600139, 12.437204857984268, 11.533520189487696, 10.607488462587368, 9.632996457131362, 8.98398407490653, 8.044198947045093, 8.910483050071859, 9.768635635757121, 10.748380334792644, 11.63506196535551, 12.576232376548745, 15.379057340722674, 14.67806595217897, 13.675903327758176, 12.698915243669841, 11.785963438328004, 11.018143193266592, 11.715188711955582, 12.74154916685853, 13.63850436974411, 13.50890213836487, 12.581245301921115, 11.610175840451511, 10.68039874121768, 9.968219754115951, 9.016421102107728, 9.907038487031516, 10.789606393791866, 11.799586384821296, 12.652812061093783, 13.637879239770433], [13.652866226585264, 12.778970776962147, 11.863886172236663, 10.908889622720363, 10.04897177198379, 10.985299653958618, 11.93958254056655, 12.641579047629586, 13.58728568526831, 14.539694767290815, 14.555722704164403, 13.591377072230465, 12.661765077138382, 11.651303517496382, 10.915179509369654, 9.905856514336293, 10.72651859547847, 11.655722768349841, 12.66478453448718, 13.560096869917599, 12.58118046923224, 13.526200427330183, 12.871362783104368, 11.881370811862647, 11.072097071384485, 11.959128797528667, 12.971562233770458, 13.670704392016425, 14.51573912424607, 14.418793355852753, 13.486363774811625, 12.553545640998365, 11.700887018231596, 10.654112211498608, 9.906099576989721, 8.899753141663567, 9.689818784650118, 10.655897625120806, 11.615283669602885, 12.500854993617814, 11.575398682015594, 12.521126687842544, 13.524772864718614, 12.909192468544937, 12.041885326604776, 12.9571466075077, 13.966700793208622, 14.685522062661754, 14.50245588499419, 13.504530394217662, 12.648004507136756, 11.588138026355265, 10.697675123296865, 9.66915074043818, 8.881016298073595, 7.960354553228388, 8.718545160007436, 9.706145849069138, 10.576615661655326, 11.552618579300889, 10.648481257801672, 11.617564592952784, 12.661870029757692, 13.616705090525706, 13.103458480887786, 13.955523162606566, 14.912414275546242, 14.463867038177728, 13.484799791508584, 12.526618731377631, 11.62878290595335, 10.625991489479972, 9.718410864558038, 8.687395062097725, 7.817202108153887, 6.905330860165577, 7.781274065131065, 8.701708642195344, 9.611123480432942, 10.512017806579774, 9.73461035651335, 10.70486337866314, 11.64055864293687, 12.669169661685476, 13.609979034330056, 14.664957270191588, 14.41244521622709, 13.514682958728109, 12.558234728616835, 11.512124121343142, 10.69921707687654, 9.67318837519462, 8.645790744949167, 7.732237781793911, 6.7661742388429715, 5.9486971600790035, 6.843778341375562, 7.627545616181517, 8.597980703479497, 9.528725022933362, 8.750455803398593, 9.764296133762475, 10.746320436115042, 11.702214076427131, 12.670572843263002, 13.675880293803374, 13.459531807134077, 12.483659674381546, 11.517071851613101, 10.574344902710678, 9.700269520595548, 8.765371486950901, 7.696790927150986, 6.787830009823575, 5.838737370875317, 4.875527165985951, 5.811026273233908, 6.6917069561633316, 7.635145664983073, 8.661465548136178, 7.826423195802465, 8.832709710409269, 9.794374319529425, 10.769100070128543, 11.725833312685925, 12.731051130084538, 12.571542944242863, 11.60468434337708, 10.609646093296618, 9.647961898276234, 8.681003238353318, 7.747836475236694, 6.750184383109889, 5.805102952508359, 4.844868057624468, 3.9212012094219726, 4.827149595676521, 5.766688151283647, 6.719033601913421, 7.673026929914993, 6.841868981783764, 7.876071724642161, 8.843999776309374, 9.806435072338903, 10.775061320485671, 11.758360550507291, 11.593985849583024, 10.617901860395914, 9.604139489536339, 8.662994530096517, 7.746945009233645, 6.808502260046515, 5.83789460781319, 4.878038877568486, 3.9187786474523283, 2.953373473356474, 3.8642355445831704, 4.823670620441449, 5.767778314521376, 6.776530422649345, 5.86321824788208, 6.935931672742987, 7.913955598159861, 8.884606000954587, 9.922390188876646, 10.934721216521089, 10.673259764175965, 9.703014643120337, 8.716023702982067, 7.7229718839190005, 6.767843318051398, 5.83235246601289, 4.898332843615466, 3.9211019825561504, 2.8929043844609534, 1.9336925572340853, 2.887143439572988, 3.856439092784142, 4.8131028924832595, 5.846921356226793, 5.122914608956127, 6.0720978530066745, 7.086344998586458, 8.06749808114454, 9.11618117809807, 10.101595610614456, 9.897775118832497, 8.84478500114383, 7.78071437037277, 6.83864866683272, 5.856026217036915, 4.89211605716778, 3.895908737613042, 2.919786261183356, 1.9649284227616781, 0.9767483258667431, 2.0009306357136722, 2.953864456945558, 3.9627729746568807, 4.947954732582817, 5.9454513536342475, 6.981961673071876, 8.014600176722658, 9.040170987357834, 10.05147172398305, 9.875442672748015, 8.904558631419686, 7.936692878345727, 6.940184102972989, 5.887363238291924, 4.833120456866129, 3.884644405117581, 2.89945224344183, 1.933687950457842, 0.9943155852663165, 0.0, 1.051785472594521, 2.001155301433853, 2.991049271224999, 4.051175583955498, 6.798905726856355, 7.764550704074535, 8.752409187091743, 9.813471917538163, 10.818478477276178, 10.802941125153254, 9.83805144875164, 8.823708831776106, 7.857899359479049, 6.83666708473107, 5.779070529319991, 4.872294342605857, 3.897159375324275, 2.9055754321205205, 1.990213905476225, 0.993719346970009, 1.9256338652263167, 2.8985390669742492, 3.9701649701962434, 4.896692548707613, 7.724153086933456, 8.690710900832674, 9.717707508856462, 10.665583752953475, 11.71725096761904, 11.547433171485142, 10.573238858518714, 9.613690263997976, 8.657298738014017, 7.69638945656784, 6.743843369564447, 5.8083732397088355, 4.8871863983276, 3.8701678423620276, 2.9169517274568415, 2.0613588225548285, 2.960941281555761, 3.8851530394333658, 4.884710430193029, 5.81690810478469, 8.695091335809092, 9.747370258176034, 10.670278237796762, 11.641010270436313, 12.635833011819322, 12.485869849618195, 11.511389753414955, 10.606805574959193, 9.614411927190421, 8.671854205902035, 7.756533973385422, 6.769666183794129, 5.878214925070093, 4.899275925618129, 3.9830293283177327, 3.065089593012221, 3.913815020293148, 4.870373711835364, 5.8454300898422265, 6.849924871538509, 9.648917223026697, 10.709800634705365, 11.682379530129738, 12.600800916522104, 13.597163535755087, 13.435613584295893, 12.480780334382901, 11.545904410828372, 10.551793404719785, 9.746603669835096, 8.699778987537496, 7.808053368989216, 6.826526704891918, 5.899325791838043, 4.985351537461648, 4.028845997189686, 4.977614932705618, 5.894216798571582, 6.815115495667193, 7.786028580477126, 10.553908588767543, 11.529898835709945, 12.538965384589357, 13.528335105731937, 14.488574712277934, 14.48888020214739, 13.507261665239103, 12.488211114521597, 11.495352377695964, 10.795110548738174, 9.747471309209978, 8.713646511231154, 7.768477796651185, 6.8861956669553726, 5.927098515368197, 5.065812433513568, 5.992186565641697, 6.964623661259522, 7.786458552128225, 8.731242109714639, 11.546927988061862, 12.47932447340888, 13.430291799968954, 14.376245772482127, 14.023435737964615, 14.743424147688042, 14.456077375276548, 13.499540096985715, 12.527146205605627, 11.772190694491972, 10.71352257561837, 9.669589612794496, 8.699831842643231, 7.873492375923256, 6.900889372745324, 6.106204063299816, 6.960625857533623, 7.892668445484487, 8.784003718664724, 9.707691696525277, 12.49856175923138, 13.472148659829987, 14.411433854042828, 13.763820452934551, 12.972338965606477, 13.804054546022506, 14.550792496827915, 14.482738982078306, 13.528868016242287, 12.504916090405029, 11.562145322337237, 10.583154361408129, 9.634880154620665, 8.939039420718567, 7.9689286204367535, 7.097212106572022, 7.919041900684092, 8.927929942250707, 9.793272164632725, 10.636746275121489, 13.457056121822182, 14.514323442412808, 13.691553489998702, 12.740944354310505, 11.911720981359846, 12.80557314955152, 13.54972223916852, 14.519213489096412, 14.465936965866454, 13.431520443250584, 12.527835774754012, 11.601804047853683, 10.627312042397678, 9.969305856598734, 9.029520728737296, 8.100170005328959, 8.899886176776421, 9.879630875811944, 10.748467762094966, 11.689638173288202, 14.384741755456359, 13.691575059272395, 12.69881904050267, 11.721830956414335, 10.863621325653614, 11.85642857122885, 12.592049698479345, 13.618410153382293, 14.54236059328721, 14.503217723631186, 13.57556088718743, 12.604491425717828, 11.674714326483995, 10.953541535808155, 10.001742883799931, 9.096725442288616, 9.920856934811166, 10.930836925840596, 11.76621785783324, 12.75128503650989], [12.712305021324962, 11.838409571701842, 10.93212210792339, 9.97712555840709, 10.916839735817785, 11.867923569125159, 12.82220645573309, 13.604786404152225, 14.550493041790947, 15.502902123813453, 15.578372787178989, 14.61402715524505, 13.684415160152968, 12.673953600510968, 11.842532283654037, 10.833209288620676, 9.84826640615647, 10.777470579027842, 11.677304662809036, 12.572616998239454, 11.640619263971939, 12.585639222069881, 11.939598718791096, 10.949606747549375, 11.93996503521848, 12.841752712695207, 13.854186148936998, 14.633911748539065, 15.478946480768707, 15.441443438867339, 14.509013857826211, 13.576195724012951, 12.723537101246182, 11.676762294513194, 10.839704191364152, 9.82710591594795, 8.811566595328118, 9.777645435798807, 10.62780379792474, 11.513375121939669, 10.634837476755292, 11.580565482582243, 12.584211659458312, 11.977428404231665, 12.90975329043877, 13.839770522674241, 14.849324708375162, 15.648729419184393, 15.525105968008775, 14.527180477232248, 13.670654590151342, 12.610788109369851, 11.72032520631145, 10.691800823452766, 9.82356444124272, 8.887707327512771, 7.840292970685435, 8.75208330299086, 9.589135789977181, 10.565138707622744, 9.70792005254137, 10.677003387692482, 11.72130882449739, 12.676143885265404, 13.61428541611277, 14.607458548327507, 15.564349661267183, 15.486517121192312, 14.50744987452317, 13.549268814392217, 12.651432988967935, 11.648641572494558, 10.741060947572624, 9.710045145112309, 8.759750251323013, 7.8337072553556695, 6.903021875809064, 7.714228770517199, 8.623643608754797, 9.524537934901629, 8.794049151253049, 9.764302173402838, 10.699997437676569, 11.728608456425174, 12.65342988636117, 13.708408122222702, 14.6087718036497, 14.537333041742693, 13.58088481163142, 12.534774204357728, 11.721867159891124, 10.695838458209206, 9.668440827963753, 8.754887864808495, 7.788824321857557, 6.9713472430935886, 5.965526152053561, 6.640065744503372, 7.6105008318013505, 8.541245151255216, 7.80989459813829, 8.823734928502171, 9.80575923085474, 10.76165287116683, 11.714023695294117, 12.719331145834488, 13.655858394556688, 13.50630975739613, 12.539721934627686, 11.596994985725262, 10.722919603610132, 9.788021569965485, 8.719441010165571, 7.81048009283816, 6.861387453889902, 5.898177249000536, 4.932774083911908, 5.704227084485186, 6.6476657933049275, 7.6739856764580345, 6.869874047833579, 7.876160562440382, 8.837825171560539, 9.812550922159657, 10.769284164717039, 11.774501982115652, 12.69958993362035, 12.627334426391666, 11.632296176311202, 10.670611981290818, 9.703653321367902, 8.770486558251278, 7.772834466124474, 6.827753035522944, 5.867518140639053, 4.943851292436557, 3.9488974063545204, 4.779208279605503, 5.731553730235277, 6.685547058236849, 5.885319833814878, 6.919522576673275, 7.887450628340488, 8.849885924370017, 9.818512172516785, 10.801811402538405, 11.737902006474396, 11.640551943410498, 10.626789572550923, 9.685644613111101, 8.76959509224823, 7.8311523430611, 6.860544690827775, 5.9006889605830715, 4.941428730466914, 3.976023556371059, 2.98598335526117, 3.8361907487633053, 4.7802984428432325, 5.789050550971202, 4.906669099913194, 5.979382524774101, 6.957406450190975, 7.928056852985702, 8.96584104090776, 9.978172068552203, 11.005787533515855, 10.725664726134923, 9.738673785996653, 8.745621966933586, 7.790493401065983, 6.855002549027475, 5.920982926630051, 4.943752065570735, 3.9155544674755385, 2.9563426402486703, 2.0088912502509872, 2.8689592211059987, 3.825623020805116, 4.8594414845486495, 4.0711291363616064, 5.020312380412154, 6.034559525991938, 7.01571260855002, 8.06439570550355, 9.049810138019936, 10.099372286683256, 9.89657047373835, 8.832499842967291, 7.89043413942724, 6.907811689631435, 5.943901529762302, 4.947694210207564, 3.9715717337778775, 2.9875785057762636, 1.9993984088813284, 0.9491451631191512, 1.9020789843510373, 2.91098750206236, 3.896169259988296, 4.893665881039727, 5.930176200477355, 6.962814704128138, 7.988385514763314, 8.99968625138853, 9.933822200566466, 9.956344104014208, 8.988478350940248, 7.991969575567509, 6.939148710886444, 5.8849059294606505, 4.9364298777121025, 3.9512377160363514, 2.985473423052363, 2.0461010578608376, 1.051785472594521, 0.0, 0.9493698288393315, 1.9392637986304782, 2.999390111360977, 5.811425855178212, 6.777070832396392, 7.7649293154136, 8.82599204586002, 9.830998605598035, 10.808639246292275, 10.889836921346161, 9.875494304370626, 8.90968483207357, 7.888452557325592, 6.830856001914513, 5.924079815200378, 4.9489448479187965, 3.911057983154955, 2.9694324822207685, 1.9257843191693533, 0.9938698009130456, 1.957977861713946, 3.013615822227357, 3.9401434007387275, 6.736673215255313, 7.703231029154529, 8.730227637178318, 9.678103881275332, 10.729771095940897, 11.673967981988667, 11.608903573351995, 10.649354978831257, 9.692963452847298, 8.732054171401122, 7.779508084397729, 6.8440379545421175, 5.89977081712801, 4.8756503933964614, 3.896170304201385, 2.9871960904812203, 2.0291772172424896, 2.944591834173062, 3.9441492249327252, 4.876346899524386, 7.707611464130949, 8.75989038649789, 9.682798366118618, 10.65353039875817, 11.648353140141179, 12.61240466012172, 12.547054468248236, 11.642470289792474, 10.650076642023702, 9.707518920735318, 8.792198688218704, 7.805330898627411, 6.890799343870503, 5.862483282140769, 4.8922811868228475, 3.947713508178762, 2.9820509559798767, 3.9298125065750598, 4.904868884581923, 5.909363666278205, 8.661437351348553, 9.722320763027222, 10.694899658451595, 11.61332104484396, 12.609683664076943, 13.575538788234724, 13.516445049216182, 12.581569125661654, 11.587458119553066, 10.78226838466838, 9.735443702370778, 8.785156665461104, 7.789734061414557, 6.862533148360683, 5.8679754526281895, 4.911469912356227, 4.045850868392346, 4.953655593311279, 5.8745542904068895, 6.845467375216822, 9.566428717089398, 10.5424189640318, 11.551485512911212, 12.540855234053794, 13.50109484059979, 14.530869240797895, 14.542926380072384, 13.523875829354878, 12.531017092529245, 11.764178656115213, 10.716539416587016, 9.676853867753792, 8.731685153173824, 7.768819582121914, 6.809722430534738, 5.94843634868011, 5.060422501328426, 6.024062455999219, 6.845897346867921, 7.790680904454336, 10.559448116383717, 11.491844601730735, 12.442811928290809, 13.388765900803982, 14.401079649850198, 15.385756493700049, 15.49174209010983, 14.535204811818996, 13.562810920438908, 12.74125880186901, 11.676729932141008, 10.632796969317136, 9.66303919916587, 8.756116291089798, 7.783513287911865, 6.974072027133811, 6.028861793220352, 6.9521072402241835, 7.84344251340442, 8.767130491264975, 11.511081887553235, 12.484668788151842, 13.423953982364683, 12.885568263612551, 13.868117958974098, 14.73140732030689, 15.573442579842501, 15.5078587387328, 14.492075372764926, 13.468123446927668, 12.525352678859877, 11.546361717930768, 10.598087511143305, 9.821663335885109, 8.851552535603295, 7.965080070406017, 6.98727783637082, 7.996165877937434, 8.85271095937242, 9.696185069861187, 12.469576250144037, 13.526843570734663, 12.813301300676702, 11.862692164988506, 12.807499974727467, 13.732925923835904, 14.572372322183107, 15.541863572110998, 15.429144322389094, 14.394727799773223, 13.491043131276651, 12.565011404376323, 11.590519398920318, 10.851929771765274, 9.912144643903837, 8.968037969162953, 7.96812211246315, 8.947866811498672, 9.807906556834661, 10.749076968027897, 13.397261883778214, 12.70409518759425, 11.82056685118067, 10.843578767092335, 11.780185199584198, 12.783781345513233, 13.61469978149393, 14.641060236396878, 15.565010676301796, 15.466425080153826, 14.53876824371007, 13.567698782240466, 12.637921683006635, 11.836165450974695, 10.884366798966472, 9.96459340612261, 8.989092870497894, 9.999072861527324, 10.825656652572935, 11.810723831249584], [11.76293519248563, 10.889039742862511, 10.059514217977853, 10.885226848655783, 11.824941026066476, 12.77602485937385, 13.730307745981781, 14.512887694400916, 15.458594332039638, 16.411003414062144, 16.50018385285225, 15.456583188681272, 14.526603503460226, 13.516141943818226, 12.572785723167993, 11.563462728134631, 10.578519845670424, 9.9861069200678, 10.786152469617734, 11.681464805048153, 10.691249435132606, 11.636269393230549, 11.099679870658628, 11.857708037798067, 12.84806632546717, 13.749854002943898, 14.76228743918569, 15.542013038787756, 16.3870477710174, 16.38565436208342, 15.453224781042294, 14.520406647229034, 13.577682626912699, 12.530907820179712, 11.569957630878108, 10.557359355461905, 9.541820034842072, 8.928448937967389, 9.736651604733439, 10.622222928748368, 9.68546764791596, 10.63119565374291, 11.63484183061898, 12.665332888208761, 13.720267839747244, 14.65646527458704, 15.614173414984172, 16.556830709433086, 16.469316891224857, 15.471391400448331, 14.614865513367425, 13.554999032585934, 12.590122889286214, 11.545946349119284, 10.553817880756675, 9.617960767026727, 8.57054641019939, 7.860931109799559, 8.69798359678588, 9.673986514431443, 8.758550223702038, 9.72763355885315, 10.771938995658058, 11.726774056426073, 12.664915587273438, 13.658088719488175, 14.614979832427851, 15.538154313044103, 15.451660797739253, 14.4934797376083, 13.595643912184018, 12.592852495710641, 11.610858630547387, 10.564190670778828, 9.490003690836968, 8.563960694869623, 7.633275315323019, 6.823076577325898, 7.732491415563496, 8.633385741710327, 7.844679322413717, 8.814932344563507, 9.750627608837238, 10.779238627585844, 11.704060057521838, 12.75903829338337, 13.659401974810368, 14.588970233594484, 14.525095734847502, 13.47898512757381, 12.666078083107207, 11.640049381425289, 10.612651751179836, 9.674154654070733, 8.708091111119794, 7.749330820416181, 6.695779591567516, 5.748913551312071, 6.719348638610049, 7.650092958063915, 6.860524769298959, 7.87436509966284, 8.856389402015408, 9.812283042327497, 10.764653866454784, 11.769961316995156, 12.706488565717356, 13.682360698469887, 13.483932857843769, 12.541205908941345, 11.667130526826215, 10.732232493181568, 9.663651933381654, 8.729746882100397, 7.7806542431521395, 6.817384168079715, 5.813499659825606, 4.813074891293885, 5.756513600113626, 6.782833483266733, 5.920504218994247, 6.92679073360105, 7.8884553427212065, 8.863181093320325, 9.819914335877707, 10.82513215327632, 11.750220104781018, 12.7170787056468, 12.576507099527285, 11.614822904506902, 10.647864244583987, 9.714697481467363, 8.717045389340557, 7.771963958739027, 6.811729063855136, 5.88806221565264, 4.887108837229385, 3.8880560864142013, 4.8404015370439755, 5.794394865045548, 4.935950004975546, 5.970152747833943, 6.938080799501156, 7.900516095530686, 8.869142343677453, 9.852441573699073, 10.788532177635064, 11.764616166822174, 11.571000495767006, 10.629855536327184, 9.713806015464312, 8.775363266277184, 7.8047556140438585, 6.844899883799155, 5.885639653682997, 4.920234479587142, 3.924194786136034, 2.945038555572004, 3.8891462496519305, 4.8978983577799, 3.957299271073862, 5.030012695934769, 6.008036621351643, 6.97868702414637, 8.016471212068428, 9.02880223971287, 10.056417704676523, 11.026662825732151, 10.682884709212736, 9.689832890149669, 8.734704324282065, 7.799213472243558, 6.8651938498461345, 5.887962988786819, 4.859765390691622, 3.9005535634647535, 2.9471026811258514, 1.977807027914697, 2.934470827613815, 3.9645500706456818, 3.1217593075222743, 4.070942551572822, 5.085189697152606, 6.066342779710688, 7.115025876664218, 8.100440309180604, 9.150002457843922, 10.202992575532589, 9.781869671806623, 8.839803968266573, 7.857181518470767, 6.893271358601633, 5.897064039046895, 4.920941562617209, 3.936948334615595, 2.94876823772066, 1.8985149919584827, 1.0109267911597357, 1.986722668933182, 2.971904426859118, 3.9694010479105493, 5.005911367348177, 6.03854987099896, 7.039015685923982, 8.050316422549198, 8.984452371727134, 9.955336413055463, 9.93784817977958, 8.941339404406841, 7.888518539725776, 6.834275758299982, 5.885799706551434, 4.900607544875683, 3.934843251891695, 2.9954708867001694, 2.001155301433853, 0.9493698288393315, 0.0, 0.9898939697911465, 2.050020282521645, 4.916534441275244, 5.882179418493425, 6.870037901510632, 7.931100631957052, 8.936107191695069, 9.911950824132372, 10.951361545031586, 10.824864133209958, 9.859054660912902, 8.837822386164923, 7.780225830753844, 6.8734496440397095, 5.898314676758128, 4.860427811994287, 3.9188023110601007, 2.875154148008685, 1.943239629752377, 1.0086080328746145, 2.0642459933880253, 2.9907735718993957, 5.845521022064011, 6.808339615251562, 7.83533622327535, 8.783212467372364, 9.83487968203793, 10.7790765680857, 11.753270881052128, 11.59872480767059, 10.642333281686632, 9.681424000240456, 8.728877913237062, 7.7934077833814515, 6.849140645967344, 5.8250202222357945, 4.844333105837117, 3.895297380729912, 2.937278507491181, 1.9952220053337308, 2.994779396093394, 3.9269770706850546, 6.816459270939648, 7.864998972594923, 8.78790695221565, 9.758638984855201, 10.75346172623821, 11.717513246218752, 12.691421775948369, 12.591840118631808, 11.599446470863036, 10.656888749574652, 9.741568517058036, 8.754700727466746, 7.838926570841038, 6.77058457238946, 5.800382477071539, 4.855814798427454, 3.8901522462285683, 2.9804426777357285, 3.9554990557425915, 4.959993837438874, 7.770285158157252, 8.83116856983592, 9.800008244548627, 10.718429630940992, 11.714792250173975, 12.680647374331755, 13.635480624244748, 13.530938954500987, 12.5368279483924, 11.731638213507713, 10.68481353121011, 9.693257955709797, 8.69783535166325, 7.770634438609374, 6.776076742876881, 5.8195712026049184, 4.953952158641037, 4.004285764471947, 4.925184461567558, 5.896097546377491, 8.675276523898097, 9.651266770840499, 10.66033331971991, 11.645963820150826, 12.606203426696823, 13.635977826894926, 14.66196195510095, 14.473245658194212, 13.480386921368579, 12.672279946363904, 11.624640706835708, 10.584955158002483, 9.639786443422516, 8.676920872370605, 7.7178237207834295, 6.856537638928801, 5.968523791577117, 5.074692627159887, 5.89652751802859, 6.841311075615005, 9.668295923192415, 10.600692408539434, 11.551659735099507, 12.49761370761268, 13.509927456658897, 14.494604300508747, 15.538929981945104, 15.48457464065833, 14.512180749278242, 13.649360092117702, 12.584831222389699, 11.540898259565827, 10.571140489414562, 9.66421758133849, 8.691614578160557, 7.882173317382502, 6.936963083469043, 6.002737411384852, 6.894072684565089, 7.817760662425644, 10.619929694361934, 11.59351659496054, 12.532801789173382, 13.460406611192138, 14.443102273696454, 15.42691786176045, 16.393746548344378, 16.41596002898149, 15.400176663013617, 14.37622473717636, 13.433453969108568, 12.45446300817946, 11.506188801391996, 10.7297646261338, 9.759653825851986, 8.873181360654709, 7.8953791266195115, 7.0651982342421435, 7.9033411305330885, 8.746815241021855, 11.578424056952736, 12.635691377543361, 12.090075276021702, 12.592945604502459, 13.53775341424142, 14.463179363349859, 15.414560665490365, 16.384051915418254, 16.337245612637787, 15.302829090021914, 14.399144421525342, 13.473112694625014, 12.498620689169009, 11.760031062013965, 10.820245934152528, 9.876139259411644, 8.876223402711842, 8.068906108516627, 8.858536727995329, 9.799707139188564, 12.506109690586912, 11.812942994402949, 11.029203192220628, 11.573832206606289, 12.510438639098151, 13.514034785027189, 14.45688812480119, 15.483248579704135, 16.407566709738017, 16.374526370402517, 15.446869533958761, 14.475800072489157, 13.546022973255326, 12.744266741223386, 11.792468089215163, 10.872694696371301, 9.897194160746587, 9.120112158545279, 9.876286823733603, 10.861354002410252], [10.84705381810515, 10.016905879673676, 10.894747355128546, 11.849743904644846, 12.814834995857623, 13.765918829164995, 14.720201715772927, 15.502781664192064, 16.448488301830785, 17.40089738385329, 17.490077822643396, 16.44647715847242, 15.516497473251373, 14.506035913609374, 13.56267969295914, 12.553356697925778, 11.568413815461572, 10.976000889858947, 10.044206319186122, 10.939518654616542, 9.775368060752127, 10.72038801885007, 11.676723329985931, 12.666715301227653, 13.700053645618235, 14.66458911477493, 15.619418004631193, 16.531907008578905, 17.376941740808547, 17.37554833187457, 16.44311875083344, 15.510300617020182, 14.567576596703846, 13.520801789970859, 12.559851600669255, 11.547253325253052, 10.53171400463322, 9.918342907758536, 8.994705454301826, 9.880276778316757, 8.76958627353548, 9.715314279362431, 10.7189604562385, 11.749451513828282, 12.736594771765304, 13.666571304795896, 14.624279445193029, 15.596645038287239, 16.580872121354933, 16.461285370239477, 15.604759483158572, 14.544893002377082, 13.580016859077361, 12.53584031891043, 11.543711850547822, 10.607854736817874, 9.560440379990537, 8.850825079590706, 7.956037446354268, 8.932040363999832, 7.8015669659403954, 8.770650301091507, 9.807768881568743, 10.752226018028644, 11.675021617482294, 12.668194749697031, 13.625085862636707, 14.54826034325296, 15.586553029848348, 15.483373707399448, 14.585537881975165, 13.582746465501788, 12.600752600338534, 11.554084640569975, 10.479897660628115, 9.55385466466077, 8.623169285114166, 7.812970547117045, 6.990545265131884, 7.891439591278716, 6.8701312840162885, 7.840384306166078, 8.776079570439808, 9.804690589188414, 10.714166087730694, 11.769144323592226, 12.669508005019225, 13.59907626380334, 14.6097427411442, 14.468879097364958, 13.655972052898354, 12.629943351216436, 11.602545720970983, 10.664048623861879, 9.69798508091094, 8.739224790207327, 7.685673561358663, 6.738807521103218, 5.977402488178437, 6.908146807632303, 5.885782530144912, 6.899622860508793, 7.881647162861361, 8.83754080317345, 9.77475989666364, 10.780067347204012, 11.716594595926212, 12.692466728678744, 13.659054551447188, 13.531099878732492, 12.657024496617362, 11.722126462972716, 10.653545903172802, 9.719640851891544, 8.770548212943286, 7.8072781378708624, 6.803393629616753, 5.8029688610850325, 5.014567449682014, 5.968007969108669, 4.9306102492031005, 5.936896763809903, 6.898561372930061, 7.873287123529178, 8.830020366086563, 9.835238183485176, 10.760326134989874, 11.727184735855657, 12.72222298593612, 12.604716874298049, 11.637758214375133, 10.704591451258509, 9.706939359131704, 8.761857928530175, 7.801623033646283, 6.877956185443788, 5.877002807020531, 4.877950056205348, 4.025576022885911, 4.979569350887483, 3.9460560351844, 4.9802587780427965, 5.948186829710011, 6.910622125739541, 7.879248373886308, 8.86254760390793, 9.79863820784392, 10.77472219703103, 11.788484567890606, 11.619749506118332, 10.70369998525546, 9.76525723606833, 8.794649583835005, 7.834793853590302, 6.875533623474144, 5.9101284493782895, 4.914088755927181, 3.9349325253631506, 3.018035482844614, 3.9859683354896855, 2.9674053012827155, 4.040118726143623, 5.018142651560497, 5.988793054355225, 7.026577242277282, 8.038908269921725, 9.066523734885378, 10.036768855941006, 11.023759796079275, 10.679726859940816, 9.724598294073212, 8.789107442034705, 7.855087819637282, 6.877856958577966, 5.849659360482769, 4.890447533255901, 3.9369966509169982, 2.967700997705844, 2.0593441153481704, 2.974656100854535, 2.131865337731128, 3.081048581781675, 4.095295727361458, 5.07644880991954, 6.1251319068730705, 7.1105463393894555, 8.160108488052774, 9.213098605741441, 10.277169236512501, 9.829697938057718, 8.847075488261913, 7.88316532839278, 6.886958008838042, 5.910835532408356, 4.926842304406742, 3.9386622075118067, 2.8884089617496294, 2.0008207609508823, 0.9968286991420356, 1.9820104570679715, 2.9795070781194024, 4.016017397557031, 5.048655901207813, 6.049121716132834, 7.060422452758051, 7.994558401935986, 8.965442443264315, 9.933308196338276, 9.931233374197987, 8.878412509516922, 7.824169728091128, 6.87569367634258, 5.89050151466683, 4.924737221682841, 3.9853648564913158, 2.991049271224999, 1.9392637986304782, 0.9898939697911465, 0.0, 1.0601263127304987, 3.926640471484097, 4.892285448702277, 5.880143931719485, 6.9412066621659045, 7.94621322190392, 8.922056854341225, 9.96146757524044, 10.90638275340469, 10.848948630704047, 9.827716355956069, 8.77011980054499, 7.863343613830856, 6.888208646549274, 5.850321781785434, 4.908696280851247, 3.865048117799832, 2.933133599543524, 1.9985020026657612, 1.0743520235968789, 2.0008796021082493, 4.920796698949376, 5.8184456454604145, 6.845442253484203, 7.793318497581216, 8.844985712246782, 9.789182598294552, 10.76337691126098, 11.722925505781719, 11.63222725147778, 10.671317970031604, 9.718771883028209, 8.783301753172598, 7.839034615758489, 6.814914192026941, 5.834227075628263, 4.885191350521058, 3.9271724772823275, 2.9851159751248773, 2.1226455329045573, 3.0280331941963867, 5.9729986939797355, 6.8751050028037755, 7.798012982424503, 8.768745015064054, 9.763567756447063, 10.727619276427605, 11.701527806157221, 12.712851809163055, 12.589340440654183, 11.646782719365799, 10.731462486849184, 9.744594697257892, 8.828820540632185, 7.760478542180606, 6.790276446862685, 5.8457087682186, 4.880046216019714, 3.970336647526875, 3.083365192553755, 4.075867231364123, 6.92682458119734, 7.929997003902797, 8.81011427475748, 9.728535661149845, 10.724898280382828, 11.690753404540608, 12.6455866544536, 13.61894449661708, 13.526721918183547, 12.72153218329886, 11.674707501001258, 10.683151925500944, 9.687729321454396, 8.760528408400521, 7.765970712668027, 6.809465172396065, 5.943846128432184, 4.994179734263094, 4.0530505983787215, 5.01197094030274, 7.933330373466484, 8.909320620408886, 9.754431053953745, 10.656069850359678, 11.616309456905675, 12.646083857103779, 13.672067985309802, 14.6027942034727, 14.470280891159726, 13.662173916155052, 12.614534676626855, 11.57484912779363, 10.629680413213663, 9.66681484216175, 8.707717690574576, 7.846431608719947, 6.958417761368263, 6.064586596951034, 5.024393654839753, 5.9571844695402545, 8.926349772760805, 9.858746258107821, 10.723757292213174, 11.658718416900006, 12.654844839206818, 13.577685712694256, 14.620883695347247, 15.580067926564464, 15.50207471906939, 14.639254061908849, 13.574725192180846, 12.530792229356974, 11.56103445920571, 10.654111551129635, 9.681508547951703, 8.87206728717365, 7.926857053260189, 6.992631381175999, 6.021938821376252, 6.933634056350893, 9.877983543930323, 10.85157044452893, 11.790855638741771, 12.713710511035513, 13.69640617353983, 14.517055314359792, 15.483884000943721, 16.45302586429653, 16.390070632804765, 15.366118706967507, 14.423347938899715, 13.444356977970607, 12.496082771183143, 11.719658595924946, 10.749547795643132, 9.863075330445856, 8.885273096410657, 8.05509220403329, 7.031207267344252, 7.862688634947104, 10.836477906521125, 11.89374522711175, 12.837121562090609, 13.582839574293606, 14.527647384032568, 15.453073333141006, 16.40445463528151, 17.3739458852094, 17.32713958242893, 16.29272305981306, 15.38903839131649, 14.463006664416161, 13.488514658960156, 12.74992503180511, 11.810139903943673, 10.866033229202792, 9.866117372502988, 9.021268901563474, 7.986402864806493, 8.927221772245007, 11.764163540155302, 11.070996843971336, 12.019097162011775, 12.563726176397436, 13.500332608889298, 14.503928754818336, 15.446782094592336, 16.473142549495282, 17.397460679529164, 17.364420340193664, 16.43676350374991, 15.465694042280305, 14.535916943046473, 13.734160711014532, 12.782362059006308, 11.862588666162448, 10.887088130537732, 9.955345295695972, 9.004152960544767, 9.988868635466694], [9.805487438045942, 10.621691972469172, 11.659759015419958, 12.59763011031073, 13.666363715980234, 14.596851878285769, 15.5511347648937, 16.43588756855569, 17.38159420619441, 18.334003288216916, 18.41060677605687, 17.367006111885892, 16.437026426664847, 15.426564867022847, 14.483208646372614, 13.473885651339252, 12.488942768875045, 11.89652984327242, 10.921910826139198, 9.966540224720239, 8.733801680692919, 9.678821638790863, 10.635156949926724, 11.625148921168446, 12.658487265559028, 13.62302273471572, 14.577851624571982, 15.569896328873359, 16.515197551217586, 17.475762878996708, 17.363647704246915, 16.430829570433655, 15.48810555011732, 14.441330743384333, 13.480380554082728, 12.467782278666526, 11.452242958046693, 10.83887186117201, 9.872409961254903, 8.907298348420454, 7.728019893476273, 8.673747899303224, 9.677394076179294, 10.707885133769075, 11.695028391706094, 12.625004924736686, 13.582713065133818, 14.55507865822803, 15.539305741295724, 16.48107937276012, 16.525288436572044, 15.465421955790555, 14.500545812490834, 13.456369272323904, 12.464240803961296, 11.528383690231347, 10.48096933340401, 9.77135403300418, 8.833741953307344, 7.959061934103529, 6.760000585881189, 7.7290839210323, 8.766202501509536, 9.710659637969437, 10.633455237423084, 11.626628369637821, 12.583519482577497, 13.50669396319375, 14.54498664978914, 15.503167709920092, 15.506066835388637, 14.503275418915262, 13.521281553752008, 12.474613593983449, 11.400426614041589, 10.474383618074244, 9.54369823852764, 8.733499500530518, 7.86824977208496, 6.918461161382413, 5.828564903957082, 6.798817926106871, 7.734513190380603, 8.763124209129208, 9.672599707671484, 10.727577943533017, 11.627941624960016, 12.557509883744132, 13.56817636108499, 14.497994338922869, 14.576501006311826, 13.55047230462991, 12.523074674384455, 11.584577577275356, 10.618514034324416, 9.6597537436208, 8.606202514772136, 7.659336474516691, 6.855106995131513, 5.935168377736, 4.844216150085705, 5.858056480449586, 6.840080782802154, 7.795974423114243, 8.73319351660443, 9.738500967144804, 10.675028215867004, 11.650900348619535, 12.61748817138798, 13.560215120290403, 13.577553450030834, 12.642655416386187, 11.574074856586273, 10.64016980530502, 9.691077166356761, 8.727807091284337, 7.723922583030227, 6.723497814498506, 5.89227195663509, 4.9377258200586, 3.889043869143893, 4.895330383750696, 5.8569949928708525, 6.83172074346997, 7.788453986027354, 8.793671803425967, 9.718759754930666, 10.685618355796448, 11.680656605876912, 12.673030515450936, 12.558287167788604, 11.62512040467198, 10.627468312545176, 9.682386881943646, 8.722151987059755, 7.798485138857261, 6.797531760434004, 5.798479009618822, 4.9032805298389865, 3.9492872018374148, 2.904489655125192, 3.938692397983589, 4.906620449650802, 5.869055745680332, 6.8376819938271, 7.820981223848721, 8.757071827784712, 9.733155816971822, 10.746918187831398, 11.688063147271219, 11.624228938668933, 10.685786189481801, 9.715178537248477, 8.755322807003774, 7.796062576887616, 6.830657402791762, 5.8346177093406535, 4.855461478776624, 3.9124149137536377, 2.9312173171488114, 1.9258389212235079, 2.998552346084415, 3.976576271501289, 4.947226674296017, 5.985010862218075, 6.997341889862517, 8.024957354826169, 8.995202475881797, 9.982193416020067, 10.975245235083133, 10.645127247486686, 9.709636395448179, 8.775616773050755, 7.7983859119914385, 6.7701883138962415, 5.810976486669373, 4.857525604330471, 3.8882299511193166, 2.9537235462571942, 1.9199050825136603, 1.0717390250006293, 2.0209222690511766, 3.0351694146309605, 4.0163224971890426, 5.065005594142573, 6.050420026658958, 7.0999821753222765, 8.152972293010944, 9.217042923782003, 10.159108627322054, 9.907201800992413, 8.929299442566192, 7.882275214769407, 6.9061527383397205, 5.912716878253354, 4.924536781358419, 3.8742835355962413, 2.9213497143643554, 1.9124411966530328, 0.9272594387270968, 1.9247560597785278, 2.9612663792161555, 3.9939048828669383, 4.9889954034023365, 6.000296140027553, 6.9344320892054885, 7.905316130533817, 8.873181883607776, 9.869690658980515, 9.938538822247422, 8.884296040821628, 7.935819989073079, 6.950627827397328, 5.98486353441334, 5.0454911692218145, 4.051175583955498, 2.9993901113609764, 2.050020282521645, 1.0601263127304987, 0.0, 2.8718894531432224, 3.837534430361403, 4.825392913378611, 5.88645564382503, 6.891462203563046, 7.861930541610727, 8.90134126250994, 9.84625644067419, 10.812065912971248, 10.887842668686568, 9.83024611327549, 8.895671772411692, 7.920536805130111, 6.847560087772248, 5.905934586838061, 4.862286423786646, 3.9303719055303383, 2.957466703782406, 1.8858408005604117, 0.9593132220490415, 3.8660456806085013, 4.76369462711954, 5.7906912351433295, 6.738567479240343, 7.7902346939059095, 8.73443157995368, 9.708625892920109, 10.668174487440847, 11.624566013424806, 11.649476762600301, 10.696930675596906, 9.761460545741295, 8.817193408327187, 7.7930729845956375, 6.767332979991889, 5.818297254884684, 4.860278381645953, 3.918221879488503, 2.9186644887288398, 1.9864668141371788, 4.918247675638861, 5.820353984462901, 6.743261964083629, 7.713993996723181, 8.70881673810619, 9.672868258086734, 10.64677678781635, 11.658100790822184, 12.58167920260121, 12.624941511934496, 11.709621279417881, 10.722753489826589, 9.761926444995812, 8.693584446544232, 7.723382351226311, 6.778814672582226, 5.81315212038334, 4.903058566546072, 3.8793841483780374, 3.034300851304915, 5.872073562856466, 6.875245985561923, 7.755363256416606, 8.673784642808972, 9.670147262041954, 10.636002386199735, 11.590835636112727, 12.564193478276207, 13.519060680130572, 13.699690975867558, 12.652319091086184, 11.61625782986457, 10.620835225818022, 9.693634312764146, 8.699076617031654, 7.742571076759691, 6.795374848554793, 5.831112798937582, 4.849069554203004, 3.9704045602435323, 6.918236692248804, 7.894226939191206, 8.699680035612872, 9.601318832018805, 10.561558438564802, 11.591332838762906, 12.617316966968929, 13.548043185131826, 14.462619653106751, 14.595279820518677, 13.54764058099048, 12.507955032157255, 11.562786317577288, 10.599920746525378, 9.640823594938203, 8.779537513083573, 7.809946481490873, 6.887935939960711, 5.820412610664035, 4.915618089481047, 7.953371342864501, 8.843652576890142, 9.6690062738723, 10.603967398559133, 11.600093820865945, 12.522934694353383, 13.566132677006374, 14.52531690822359, 15.494413481016414, 15.572359966272474, 14.507831096544471, 13.4638981337206, 12.494140363569334, 11.587217455493262, 10.61461445231533, 9.72359600729626, 8.7783857733828, 7.815980724185676, 6.817957777200534, 5.892067676291686, 8.90500511403402, 9.87080782359507, 10.740435645906192, 11.65895949269464, 12.641655155198956, 13.46230429601892, 14.429132982602848, 15.398274845955658, 16.414058211923532, 16.29922461133113, 15.35645384326334, 14.377462882334232, 13.429188675546769, 12.652764500288573, 11.682653700006759, 10.714604050568466, 9.736801816533267, 8.868635972069146, 7.807677243984102, 6.8211222548878965, 9.863499476624822, 10.919435734441384, 11.78670156925503, 12.681835591318686, 13.626643401057647, 14.460785692489905, 15.426628266036204, 16.396119515964095, 17.39394457151198, 17.225828964176685, 16.322144295680115, 15.396112568779786, 14.421620563323781, 13.65693254311714, 12.717147415255702, 11.717561949325402, 10.717646092625598, 9.797738878203324, 8.762872841446343, 7.8856553921858, 10.791185110258999, 11.744553407091683, 12.754649164439156, 13.48425512981091, 14.420861562302772, 15.409930270812575, 16.36731104800581, 17.361379612388674, 18.317989632942638, 18.29752624455729, 17.369869408113534, 16.39879994664393, 15.469022847410098, 14.641168222326561, 13.689369570318338, 12.714117386285059, 11.738616850660343, 10.731815272335822, 9.780622937184617, 8.947302255407488], [10.848800981883302, 11.66500551630653, 12.703072559257317, 13.640943654148089, 14.587946114397491, 15.49685604635618, 16.451138932964113, 17.468207482039347, 18.343655158265754, 18.38936482033972, 17.406688009212804, 16.363087345041826, 15.43310765982078, 14.422646100178781, 13.479289879528547, 12.507026068512094, 11.522083186047887, 10.900110265128351, 9.881641893339943, 8.923701947881836, 9.777115224530279, 10.722135182628222, 11.678470493764083, 12.668462465005804, 13.564820814996796, 14.523026902786132, 15.477855792642394, 16.46990049694377, 17.415201719287996, 17.35031396824094, 16.417884387199813, 15.485066253386552, 14.521245967290161, 13.474471160557174, 12.51352097125557, 11.500922695839368, 10.485383375219534, 9.872012278344851, 8.88297153585548, 7.917859923021033, 8.771333437313633, 9.717061443140583, 10.720707620016652, 11.671506738281096, 12.595032559776506, 13.525009092807098, 14.48271723320423, 15.45508282629844, 16.439309909366134, 16.436051006605844, 15.579525119524943, 14.519658638743453, 13.533686229663676, 12.489509689496746, 11.497381221134138, 10.561524107404189, 9.514109750576852, 8.804494450177021, 7.844303527907922, 6.969623508704107, 7.803314129718547, 8.772397464869659, 9.723636510220516, 10.656887915074142, 11.533459405493495, 12.526632537708233, 13.483523650647909, 14.40669813126416, 15.44499081785955, 15.458139343765815, 14.560303518341534, 13.55751210186816, 12.55442197092485, 11.50775401115629, 10.43356703121443, 9.507524035247085, 8.576838655700481, 7.76663991770336, 6.878811346685538, 5.929022735982992, 6.87187844779444, 7.8421314699442295, 8.691947199091581, 9.709352486233913, 10.572603875741896, 11.627582111603427, 12.527945793030426, 13.457514051814542, 14.4681805291554, 14.443644733731325, 13.630737689264723, 12.604708987582807, 11.577311357337353, 10.617717994448194, 9.651654451497254, 8.692894160793642, 7.639342931944978, 6.692476891689533, 5.865668569732092, 4.9457299523365785, 5.887529693923064, 6.898923311749505, 7.752198907311493, 8.708092547623583, 9.633197684674842, 10.638505135215214, 11.575032383937414, 12.550904516689945, 13.51749233945839, 13.505865515098861, 12.631790132983731, 11.696892099339085, 10.62831153953917, 9.673310222477859, 8.724217583529601, 7.7609475084571775, 6.757063000203068, 5.756638231671348, 4.902833531235669, 3.9482873946591788, 4.9323574129812515, 5.839732572945118, 6.7569991609412625, 7.73172491154038, 8.688458154097765, 9.693675971496377, 10.618763923001076, 11.585622523866858, 12.580660773947322, 12.579482510664418, 11.612523850741503, 10.67935708762488, 9.681704995498073, 8.736623564896544, 7.776388670012652, 6.852721821810158, 5.851768443386901, 4.831619426791663, 3.9138421044395657, 2.9598487764379935, 3.947803198962551, 4.883094587178011, 5.806624617721212, 6.769059913750742, 7.73768616189751, 8.72098539191913, 9.657075995855122, 10.633159985042232, 11.646922355901808, 11.5945151424847, 10.678465621621829, 9.7400228724347, 8.769415220201376, 7.809559489956672, 6.850299259840513, 5.884894085744659, 4.888854392293551, 3.888601895949466, 2.9444942018695395, 1.9417788917493901, 2.969152465060867, 3.912415317186985, 4.876580439571699, 5.799853055482853, 6.83763724340491, 7.849968271049352, 8.877583736013005, 9.847828857068633, 10.794432860572591, 10.654492496307185, 9.699363930439581, 8.763873078401074, 7.829853456003652, 6.852622594944336, 5.824424996849139, 4.865213169622271, 3.911762287283368, 2.942466634072214, 1.985802834373096, 0.9519843706295622, 1.900187767540677, 2.849371011591224, 3.8636181571710075, 4.84477123972909, 5.89345433668262, 6.878868769199005, 7.928430917862324, 8.897887016811463, 9.811136006188047, 10.753201709728097, 10.63256554660423, 9.788072522395852, 8.7798958344006, 7.803773357970915, 6.810337497884548, 5.822157400989613, 4.862280692059061, 3.909346870827175, 2.9298117723420614, 1.9446300144161257, 0.9560507691806284, 1.992561088618256, 2.88121996339288, 3.951774277598684, 4.980886593832083, 5.915022543010019, 6.885906584338347, 7.853772337412306, 8.850281112785044, 9.90310197746611, 10.957344758891903, 10.683550131973936, 9.698357970298185, 8.732593677314197, 7.7932213121226726, 6.798905726856356, 5.8114258551782125, 4.916534441275243, 3.926640471484097, 2.8718894531432224, 0.0, 0.9656449772181807, 1.9535034602353885, 3.0145661906818075, 4.019572750419823, 4.997213391114064, 6.054822244056453, 7.069164861031987, 8.034974333329044, 9.056206608077023, 10.113803163488102, 11.0791509463488, 10.69606510218063, 9.704481158976876, 8.777824039981285, 7.73417587692987, 6.802261358673562, 5.829356156925629, 4.757730253703635, 3.831202675192264, 0.994156227465279, 1.8918051739763182, 2.9188017820001066, 3.8666780260971207, 4.918345240762687, 5.862542126810457, 6.836736439776886, 7.796285034297625, 8.752676560281584, 9.71358584172776, 10.666131928731154, 11.601602058586765, 11.686092125183954, 10.664962437738861, 9.639222433135112, 8.690186708027907, 7.732167834789176, 6.790111332631725, 5.790553941872062, 4.858356267280401, 2.046358222495639, 2.948464531319679, 3.8713725109404065, 4.842104543579959, 5.836927284962968, 6.800978804943509, 7.774887334673126, 8.78621133767896, 9.709789749457988, 10.689050591061955, 11.618901604279054, 12.56289500267206, 12.633815898139034, 11.565473899687456, 10.595271804369535, 9.650704125725449, 8.685041573526563, 7.774948019689295, 6.75127360152126, 5.906190304448137, 3.0001841097132433, 4.003356532418701, 4.883473803273383, 5.801895189665751, 6.798257808898734, 7.7641129330565155, 8.718946182969507, 9.692304025132987, 10.64717122698735, 11.674531989395959, 12.562146618431129, 13.598207879652744, 13.492724678961245, 12.56552376590737, 11.570966070174876, 10.614460529902914, 9.667264301698017, 8.703002252080806, 7.720959007346226, 6.842294013386755, 4.0463472391055815, 5.022337486047984, 5.82779058246965, 6.729429378875583, 7.68966898542158, 8.719443385619684, 9.745427513825707, 10.676153731988606, 11.590730199963529, 12.535779491736474, 13.58341873126467, 14.623104280097895, 14.434675770720512, 13.4718101996686, 12.512713048081425, 11.651426966226797, 10.681835934634098, 9.759825393103933, 8.692302063807258, 7.787507542624269, 5.090158479030222, 5.97176312374692, 6.797116820729078, 7.732077945415911, 8.728204367722723, 9.651045241210161, 10.694243223863152, 11.653427455080369, 12.622524027873192, 13.512859637490271, 14.586932390475763, 15.630865353299637, 15.366029816712558, 14.459106908636484, 13.486503905458552, 12.595485460439484, 11.650275226526023, 10.687870177328897, 9.689847230343757, 8.744103690994942, 6.041792250199741, 6.99891837045185, 7.868546192762971, 8.787070039551418, 9.769765702055734, 10.590414842875697, 11.557243529459626, 12.526385392812436, 13.54216875878031, 14.534847039327875, 15.477617807395667, 16.456608768324777, 16.301078128689994, 15.524653953431795, 14.55454315314998, 13.58649350371169, 12.608691269676491, 11.720671986772404, 10.65971325868736, 9.673158269591154, 7.01174408874113, 8.047546281298164, 8.914812116111808, 9.809946138175464, 10.754753947914425, 11.588896239346683, 12.554738812892982, 13.524230062820873, 14.522055118368757, 15.46145139217343, 16.44045064329898, 17.366482370199307, 17.293510016467007, 16.528821996260366, 15.589036868398926, 14.589451402468626, 13.589535545768822, 12.649774892906581, 11.6149088561496, 10.737691406889057, 7.939429722375306, 8.892798019207989, 9.902893776555462, 10.829059536071634, 11.765665968563496, 12.538040817669353, 13.507686339878894, 14.48949015924545, 15.484460584633759, 16.51410667097594, 17.4881757557324, 18.369169748063452, 18.340912300553324, 17.43221146852309, 16.480412816514868, 15.540192444092666, 14.600796436226485, 13.58385128703908, 12.632658951887874, 11.799338270110745], [11.814445959101484, 11.161172664666086, 11.9647948125308, 12.796560921099328, 13.712697451391147, 14.621607383349836, 15.575890269957767, 16.592958819033, 17.468406495259416, 17.484105979766554, 16.441043031994624, 15.397442367823647, 14.467462682602601, 13.457001122960602, 12.513644902310368, 11.757785802662637, 10.858726919789317, 10.05313549484753, 9.114577712528824, 9.826020783538354, 10.74276020174846, 10.218302330987777, 10.924629159850024, 11.824079731957044, 12.689572151990452, 13.647778239779788, 14.60260712963605, 15.594651833937426, 16.539953056281654, 17.500518384060776, 17.368091932869007, 16.435273799055746, 15.429601600954497, 14.38282679422151, 13.421876604919907, 12.409278329503705, 11.393739008883871, 10.780367912009188, 9.785290371511998, 8.82017875867755, 9.736978414531814, 9.213228591500139, 9.858313235081372, 10.796258075274753, 11.719783896770162, 12.649760429800754, 13.607468570197886, 14.579834163292098, 15.564061246359792, 16.50583487782419, 16.533606774525072, 15.473740293743584, 14.442041863328011, 13.397865323161081, 12.405736854798473, 11.469879741068526, 10.422465384241189, 9.712850083841358, 8.74662236356444, 7.871942344360624, 8.768959106936729, 8.150427246667135, 8.848387847214171, 9.7816392520678, 10.658210742487151, 11.651383874701889, 12.608274987641565, 13.531449468257819, 14.569742154853207, 15.52792321498416, 15.525948495559716, 14.51159375686829, 13.462777604589185, 12.416109644820626, 11.341922664878766, 10.415879668911423, 9.485194289364818, 8.674995551367697, 7.781130182342055, 6.831341571639508, 7.837523425012622, 7.139435921830467, 7.816698536085238, 8.83410382322757, 9.697355212735552, 10.752333448597085, 11.652697130024084, 12.5822653888082, 13.592931866149058, 14.522749843986936, 14.596382666482905, 13.570353964800987, 12.542956334555534, 11.526073628112533, 10.560010085161593, 9.60124979445798, 8.547698565609315, 7.60083252535387, 6.767987405388609, 5.848048787993095, 6.853174671141245, 6.135988359727992, 6.876950244305151, 7.83284388461724, 8.757949021668498, 9.763256472208871, 10.699783720931071, 11.675655853683603, 12.642243676452047, 13.58497062535447, 13.597435110201912, 12.662537076557266, 11.593956516757352, 10.581665856142196, 9.632573217193938, 8.669303142121514, 7.6654186338674055, 6.664993865335685, 5.805152366892186, 4.850606230315695, 5.898002390199433, 5.076797620923604, 5.88175049793492, 6.856476248534038, 7.813209491091421, 8.818427308490035, 9.743515259994734, 10.710373860860516, 11.70541211094098, 12.697786020515004, 12.578168827959683, 11.645002064843059, 10.647349972716254, 9.702268542114725, 8.742033647230834, 7.7918489201656245, 6.762208284515508, 5.7399750604560005, 4.816160940096082, 3.86216761209451, 4.913448176180732, 4.120159635156497, 4.93137595471487, 5.8938112507444, 6.862437498891167, 7.845736728912788, 8.78182733284878, 9.75791132203589, 10.771673692895465, 11.712818652335287, 11.64411059884001, 10.70566784965288, 9.735060197419555, 8.775204467174852, 7.8159442370586945, 6.832278171653393, 5.799294233422158, 4.7969575296138025, 3.852849835533876, 2.8440977274059067, 3.9347974422790477, 3.1494803651654717, 4.001331776565356, 4.913884022347561, 5.951668210269618, 6.963999237914061, 7.956802527282539, 8.927047648338167, 9.82878788335441, 10.81576252070384, 10.665008907657763, 9.729518055619256, 8.795498433221832, 7.818267572162516, 6.790069974067319, 5.830858146840451, 4.8774072645015485, 3.908111611290394, 2.951447811591277, 1.9176293478477429, 2.865832744758858, 2.086436059569711, 2.988369494164665, 3.958802206593797, 4.950532162498883, 5.935946595015268, 6.984695491844594, 7.932242039593283, 8.845491028969866, 9.787556732509916, 10.770179182305721, 10.753717499614034, 9.74554081161878, 8.769418335189094, 7.775982475102729, 6.787802378207793, 5.827925669277241, 4.874991848045355, 3.8954567495602426, 2.9102749916343065, 1.9216957463988091, 1.073865189910828, 1.9155749861746996, 2.9861293003805036, 4.015241616613903, 4.949377565791838, 5.920261607120167, 6.888127360194126, 7.884636135566864, 8.93745700024793, 9.991699781673724, 10.940175833422272, 10.664002947516366, 9.698238654532378, 8.758866289340853, 7.764550704074536, 6.777070832396392, 5.882179418493425, 4.892285448702278, 3.837534430361403, 0.9656449772181807, 0.0, 0.9878584830172079, 2.048921213463627, 3.053927773201643, 4.031568413895883, 5.089177266838272, 6.103519883813806, 7.069329356110863, 8.090561630858842, 9.14815818626992, 10.11350596913062, 11.088640936412201, 10.670126136195057, 9.743469017199464, 8.699820854148049, 7.767906335891741, 6.795001134143809, 5.723375230921815, 4.796847652410444, 1.8964750631217953, 0.9261601967581375, 1.9531568047819263, 2.9010330488789404, 3.9527002635445068, 4.896897149592277, 5.871091462558707, 6.830640057079446, 7.787031583063404, 8.74794086450958, 9.700486951512975, 10.635957081368586, 11.580224218782694, 11.63060741495704, 10.604867410353291, 9.655831685246087, 8.697812812007356, 7.7557563098499065, 6.756198919090243, 5.824001244498582, 2.948677058152155, 1.9828195541014981, 2.905727533722226, 3.8764595663617785, 4.871282307744788, 5.8353338277253295, 6.809242357454947, 7.820566360460781, 8.744144772239807, 9.723405613843775, 10.653256627060875, 11.59725002545388, 12.571252745525188, 12.531118876905635, 11.560916781587714, 10.61634910294363, 9.650686550744744, 8.740592996907475, 7.716918578739441, 6.871835281666319, 3.9025029453697595, 3.03771155520052, 3.917828826055203, 4.83625021244757, 5.832612831680554, 6.798467955838335, 7.753301205751327, 8.726659047914808, 9.68152624976917, 10.70888701217778, 11.59650164121295, 12.632562902434564, 13.611917735923589, 13.53116874312555, 12.536611047393057, 11.580105507121095, 10.632909278916197, 9.668647229298985, 8.686603984564407, 7.807938990604936, 4.948666074762098, 4.0928571252529355, 4.862145605251468, 5.763784401657403, 6.7240240082034, 7.753798408401503, 8.779782536607527, 9.710508754770427, 10.62508522274535, 11.570134514518294, 12.61777375404649, 13.657459302879715, 14.553868827682855, 14.43745517688678, 13.478358025299606, 12.617071943444977, 11.647480911852277, 10.725470370322112, 9.657947041025437, 8.75315251984245, 5.992477314686738, 5.042282762951872, 5.831471843510897, 6.766432968197731, 7.762559390504544, 8.68540026399198, 9.728598246644973, 10.68778247786219, 11.656879050655013, 12.547214660272092, 13.621287413257583, 14.665220376081457, 15.485222873674902, 15.424751885854665, 14.452148882676733, 13.561130437657663, 12.615920203744203, 11.653515154547076, 10.655492207561936, 9.709748668213123, 6.944111085856257, 6.0694380096568015, 6.90290121554479, 7.821425062333237, 8.804120724837553, 9.624769865657516, 10.591598552241445, 11.560740415594253, 12.576523781562127, 13.569202062109696, 14.511972830177488, 15.490963791106596, 16.420271185652336, 16.490298930649978, 15.520188130368162, 14.55213848092987, 13.57433624689467, 12.686316963990585, 11.62535823590554, 10.638803246809335, 7.914062924397646, 7.118065920503115, 7.9491671388936265, 8.844301160957283, 9.789108970696244, 10.623251262128502, 11.5890938356748, 12.558585085602692, 13.556410141150575, 14.49580641495525, 15.474805666080803, 16.40083739298113, 17.41270307342935, 17.494466973478545, 16.554681845617107, 15.555096379686805, 14.555180522987001, 13.615419870124763, 12.580553833367782, 11.703336384107239, 8.841748558031822, 8.08778718774361, 9.0100392226947, 9.863414558853453, 10.800020991345315, 11.572395840451172, 12.542041362660713, 13.52384518202727, 14.518815607415577, 15.548461693757762, 16.52253077851422, 17.403524770845276, 17.55982354017859, 16.556962805516747, 15.605164153508523, 14.664943781086322, 13.784593609008525, 12.904196871963373, 12.173925583794993, 12.764983247328926], [12.711710873580413, 11.78627206017738, 10.97693632951359, 11.808702438082118, 12.72483896837394, 13.633748900332629, 14.58803178694056, 15.605100336015791, 16.480548012242203, 16.518376746846275, 15.475313799074344, 14.431713134903369, 13.501733449682323, 12.491271890040323, 11.54791566939009, 10.792056569742359, 9.89299768686904, 9.087406261927251, 9.889004886727646, 10.664391829123243, 11.64002511622739, 10.84340172649907, 9.936770676832815, 10.836221248939834, 11.701713668973245, 12.65991975676258, 13.614748646618843, 14.606793350920217, 15.552094573264442, 16.512659901043566, 16.40236269994873, 15.469544566135468, 14.496090515283944, 13.488463196038097, 12.595571210331531, 11.798159942415085, 10.929697497697392, 10.145064244027662, 10.773148854529206, 9.708635098186903, 10.634243329010744, 9.838327987011432, 8.870454752064163, 9.808399592257544, 10.731925413752954, 11.661901946783546, 12.619610087180678, 13.591975680274889, 14.576202763342582, 15.51797639480698, 16.45234470425786, 16.434952180778566, 15.429900346345221, 14.38572380617829, 13.393595337815682, 12.457738224085736, 11.410323867258398, 10.700708566858568, 9.734480846581647, 8.80925161138422, 9.666224021415658, 8.775526642178429, 7.860529364196963, 8.79378076905059, 9.670352259469944, 10.663525391684681, 11.620416504624357, 12.54359098524061, 13.581883671835998, 14.54006473196695, 15.488032442319637, 15.4994522398855, 14.450636087606394, 13.403968127837835, 12.329781147895975, 11.403738151928632, 10.473052772382028, 9.662854034384907, 8.768988665359263, 7.819200054656716, 8.734788339491551, 7.764535317341761, 6.8288400530680295, 7.846245340210362, 8.709496729718344, 9.764474965579875, 10.664838647006874, 11.59440690579099, 12.605073383131849, 13.534891360969727, 14.558466613242826, 14.558212447818196, 13.530814817572741, 12.513932111129742, 11.547868568178803, 10.589108277475189, 9.535557048626524, 8.588691008371079, 7.755845888405816, 6.835907271010303, 7.841033154158453, 6.87111606364051, 5.8890917612879425, 6.844985401600032, 7.77009053865129, 8.775397989191662, 9.711925237913862, 10.687797370666393, 11.654385193434837, 12.597112142337261, 13.559519056961834, 13.650395559574473, 12.58181499977456, 11.569524339159406, 10.620431700211148, 9.657161625138723, 8.653277116884613, 7.6528523483528925, 6.793010849909393, 5.838464713332903, 6.88586087321664, 5.88302225951178, 4.893892014917712, 5.868617765516829, 6.825351008074213, 7.830568825472826, 8.755656776977524, 9.722515377843306, 10.71755362792377, 11.709927537497796, 12.742161950031042, 12.632860547860266, 11.635208455733462, 10.690127025131932, 9.729892130248041, 8.779707403182833, 7.750066767532716, 6.727833543473208, 5.8040194231132896, 4.850026095111717, 5.90130665919794, 4.926384273744673, 3.9435174716976613, 4.905952767727191, 5.874579015873959, 6.85787824589558, 7.793968849831572, 8.770052839018682, 9.783815209878258, 10.724960169318079, 11.694624006635411, 11.693526332670087, 10.722918680436763, 9.76306295019206, 8.803802720075902, 7.820136654670601, 6.7871527164393655, 5.78481601263101, 4.8407083185510835, 3.8319562104231144, 4.922655925296255, 3.9914972189650224, 3.0134732935481483, 3.9260255393303525, 4.963809727252411, 5.9761407548968535, 6.968944044265331, 7.939189165320959, 8.840929400337204, 9.827904037686634, 10.715522315453164, 10.717376538636465, 9.783356916239041, 8.806126055179725, 7.777928457084527, 6.818716629857659, 5.865265747518756, 4.895970094307602, 3.9393062946084845, 2.9054878308649505, 3.8536912277760655, 2.9729258764671567, 2.0005110111474567, 2.970943723576589, 3.962673679481675, 4.94808811199806, 5.996837008827386, 6.944383556576075, 7.857632545952659, 8.79969824949271, 9.782320699288515, 10.838866468065966, 10.733399294635987, 9.757276818206302, 8.763840958119935, 7.775660861225001, 6.815784152294449, 5.862850331062563, 4.88331523257745, 3.898133474651514, 2.909554229416017, 1.9603550068082742, 0.9277165031574917, 1.9982708173632955, 3.0273831335966945, 3.9615190827746307, 4.932403124102959, 5.900268877176918, 6.896777652549656, 7.949598517230722, 9.003841298656516, 9.952317350405064, 10.937509512080815, 10.686097137549584, 9.746724772358059, 8.752409187091743, 7.7649293154136, 6.870037901510632, 5.880143931719486, 4.825392913378611, 1.9535034602353885, 0.9878584830172079, 0.0, 1.0610627304464193, 2.0660692901844353, 3.0437099308786757, 4.101318783821064, 5.115661400796598, 6.0814708730936555, 7.102703147841634, 8.160299703252713, 9.125647486113412, 10.100782453394993, 11.173759170752856, 10.731327500216672, 9.687679337165257, 8.755764818908949, 7.782859617161017, 6.711233713939023, 5.784706135427652, 2.884333546139003, 1.9140186797753453, 0.9874275718616473, 1.9353038159586613, 2.9869710306242276, 3.9311679166719977, 4.905362229638427, 5.864910824159166, 6.821302350143124, 7.7822116315893, 8.734757718592695, 9.670227848448306, 10.614494985862414, 11.638615409593964, 11.5927258933705, 10.643690168263296, 9.685671295024566, 8.743614792867115, 7.744057402107451, 6.81185972751579, 3.9365355411693628, 2.886168890417806, 1.9399983008019472, 2.9107303334414993, 3.905553074824509, 4.86960459480505, 5.843513124534667, 6.854837127540501, 7.778415539319528, 8.757676380923495, 9.687527394140595, 10.6315207925336, 11.605523512604908, 12.667723492850065, 12.548775264604924, 11.60420758596084, 10.638545033761954, 9.728451479924683, 8.704777061756648, 7.859693764683526, 4.890361428386967, 3.9410608915168286, 2.9520995931349243, 3.8705209795272912, 4.866883598760275, 5.832738722918056, 6.7875719728310475, 7.760929814994529, 8.71579701684889, 9.743157779257498, 10.63077240829267, 11.666833669514284, 12.646188503003309, 13.573389416057184, 13.524469530410267, 12.567963990138304, 11.620767761933404, 10.656505712316193, 9.674462467581614, 8.795797473622144, 5.881473168153004, 4.905482921210602, 3.89641637233119, 4.798055168737124, 5.758294775283121, 6.7880691754812235, 7.814053303687248, 8.744779521850148, 9.65935598982507, 10.604405281598014, 11.65204452112621, 12.691730069959435, 13.588139594762575, 14.619850043032796, 14.466216508316815, 13.604930426462186, 12.635339394869483, 11.71332885333932, 10.645805524042645, 9.738156586290263, 6.830848360271627, 5.816709937150693, 4.865742610590619, 5.800703735277452, 6.796830157584265, 7.719671031071702, 8.762869013724693, 9.72205324494191, 10.691149817734733, 11.581485427351812, 12.655558180337302, 13.699491143161175, 14.519493640754622, 15.45108774901151, 15.440007365693942, 14.54898892067487, 13.603778686761409, 12.641373637564284, 11.643350690579144, 10.607013582692053, 7.782482131441146, 6.843865183855623, 5.937171982624512, 6.855695829412958, 7.838391491917273, 8.659040632737238, 9.625869319321167, 10.595011182673975, 11.610794548641849, 12.603472829189416, 13.546243597257208, 14.525234558186316, 15.454541952732056, 16.440179227409917, 16.50804661338537, 15.539996963947075, 14.562194729911877, 13.583581878469515, 12.52262315038447, 11.536068161288265, 8.752433969982535, 7.892493094701937, 6.983437905973348, 7.878571928037004, 8.823379737775964, 9.657522029208224, 10.623364602754522, 11.592855852682414, 12.590680908230297, 13.53007718203497, 14.509076433160523, 15.435108160060851, 16.446973840509067, 16.52931295341539, 15.589527825553951, 14.673640735028771, 13.81770588402606, 12.967544438974816, 13.477818747846712, 12.600601298586168, 9.680119603616712, 8.862214361942431, 8.044309989774423, 8.897685325933175, 9.834291758425037, 10.606666607530894, 11.576312129740435, 12.558115949106991, 13.5530863744953, 14.582732460837484, 15.556801545593942, 16.437795537924995, 16.571965057161382, 15.56910432249954, 14.617305670491316, 13.677085298069114, 12.796735125991315, 11.916338388946164, 12.799024979306289, 13.662248161807856], [13.644805555303478, 12.719366741900446, 11.910031011236656, 10.96016944937245, 11.77969547264644, 12.688605404605129, 13.64288829121306, 14.659956840288292, 15.533383152135093, 15.564315380511836, 14.521252432739905, 13.47765176856893, 12.547672083347884, 11.537210523705884, 10.59385430305565, 9.83799520340792, 8.9389363205346, 9.86814049340597, 10.813664182182137, 11.59124555998881, 12.573119797950454, 11.776496408222137, 10.86986535855588, 9.987688260230167, 10.756570173245745, 11.71477626103508, 12.669605150891343, 13.659628490813107, 14.604929713157333, 15.565495040936456, 15.448301333614289, 14.515483199801029, 13.542029148949505, 12.534401829703658, 11.641509843997092, 10.844098576080645, 9.975636131362952, 10.925798475506381, 11.702217822415797, 10.635488829052472, 11.567338010733808, 10.771422668734498, 9.803549433787229, 8.959866603547876, 9.786781918025454, 10.716758451056046, 11.674466591453179, 12.644810820167779, 13.629037903235472, 14.554833739338855, 15.489202048789735, 15.480890814444129, 14.568947861754175, 13.519363300764086, 12.666593122913218, 11.783497164515824, 10.946909756005635, 11.733096875828585, 10.733253684628696, 9.736105342249788, 10.599318703138723, 9.708621323901495, 8.793624045920028, 7.945247780340923, 8.725208763742444, 9.718381895957181, 10.675273008896857, 11.5964261251335, 12.634718811728888, 13.576922076498825, 14.515568547814247, 15.506720751541591, 15.492732709576075, 14.446064749807515, 13.371877769865655, 12.445834773898312, 11.515149394351708, 10.69864521233206, 9.771273054441474, 8.792612272619284, 9.667883021214616, 8.697629999064826, 7.761934734791095, 6.997712351500693, 7.764353233990843, 8.819331469852374, 9.717673786899764, 10.64724204568388, 11.657908523024739, 12.562427466464335, 13.586002718737436, 14.553917637256239, 14.573200382754399, 13.556028733099422, 12.589965190148483, 11.63120489944487, 10.577653670596204, 9.630787630340759, 8.77909217530064, 7.848347855846775, 8.810923430094443, 7.804210745363576, 6.822186443011008, 5.996452412890363, 6.824947042923791, 7.830254493464161, 8.764760377806752, 9.740632510559283, 10.707220333327728, 11.624648247831871, 12.587055162456444, 13.52195319610109, 13.624200564956217, 12.611620961129086, 11.662528322180828, 10.699258247108403, 9.695373738854293, 8.694948970322573, 7.835107471879075, 6.8699816007715855, 7.855751149152631, 6.816116941234845, 5.826986696640777, 5.007447259574039, 5.880207512346713, 6.885425329745326, 7.808491916870413, 8.775350517736197, 9.770388767816659, 10.698265243397428, 11.707465942193384, 12.548603674180828, 12.692334893739982, 11.747253463138453, 10.787018568254561, 9.821804025152513, 8.792163389502397, 7.769930165442888, 6.8461160450829714, 5.892122717081399, 6.893681698326135, 5.859478955467738, 4.8766121534207265, 3.9608092719996915, 4.929435520146459, 5.86987492310729, 6.805965527043282, 7.782049516230392, 8.795811887089968, 9.71329787521771, 10.639995197988972, 11.60926945899065, 11.783981410883182, 10.82412568063848, 9.864865450522322, 8.862233276640282, 7.829249338409046, 6.826912634600691, 5.8828049405207645, 4.874052832392795, 5.983718655742676, 4.924591900688087, 3.946567975271213, 2.9759175724764857, 3.92494503071518, 4.937276058359622, 5.914315235618892, 6.88456035667452, 7.786300591690765, 8.773275229040195, 9.660893506806724, 10.596384358845231, 10.844419646685461, 9.867188785626144, 8.838991187530947, 7.879779360304078, 6.926328477965176, 5.957032824754021, 5.000369025054904, 3.96655056131137, 4.9147539582224855, 4.016235984860588, 3.0019888392808043, 2.020835756722722, 2.908044870835236, 3.893459303351621, 4.942208200180946, 5.889754747929636, 6.80300373730622, 7.745069440846271, 8.727691890642076, 9.784237659419526, 10.83126188721631, 10.818339548652721, 9.824903688566355, 8.83672359167142, 7.876846882740868, 6.923913061508983, 5.94437796302387, 4.959196205097934, 3.9706169598624363, 3.0214177372546933, 1.988779233603911, 1.0481628505094287, 1.972754324950256, 2.906890274128192, 3.87777431545652, 4.8456400685304795, 5.842148843903217, 6.8949697085842825, 7.949212490010076, 8.897688541758624, 9.882880703434376, 10.848644996418363, 10.807787502804478, 9.813471917538163, 8.82599204586002, 7.931100631957052, 6.941206662165905, 5.88645564382503, 3.014566190681808, 2.048921213463627, 1.0610627304464193, 0.0, 1.005006559738016, 1.9826472004322564, 3.040256053374645, 4.054598670350179, 5.020408142647236, 6.0416404173952145, 7.099236972806294, 8.064584755666992, 9.039719722948574, 10.112696440306436, 11.054321941240623, 10.748742067611676, 9.816827549355368, 8.843922347607435, 7.772296444385442, 6.845768865874072, 3.926430168108684, 2.9561153017450263, 1.9291186937212377, 0.9812424496242236, 1.9981513431050364, 2.9423482291528065, 3.9165425421192355, 4.876091136639975, 5.832482662623932, 6.793391944070109, 7.745938031073503, 8.681408160929113, 9.625675298343221, 10.64979572207477, 11.67553572667852, 11.704752898709716, 10.746734025470985, 9.804677523313535, 8.80512013255387, 7.8729224579622095, 4.889095859811467, 3.8278600122773967, 2.8816894226615375, 1.9566689671070614, 2.951491708490071, 3.880784907285859, 4.8546934370154755, 5.866017440021309, 6.789595851800336, 7.768856693404304, 8.698707706621404, 9.642701105014407, 10.616703825085715, 11.678903805330872, 12.649105900648793, 12.665270316407259, 11.699607764208373, 10.789514210371102, 9.765839792203067, 8.920756495129945, 5.842921747029071, 4.882752013376419, 3.8937907149945143, 2.916459613192853, 3.9128222324258366, 4.8786773565836175, 5.824084017983423, 6.797441860146904, 7.726977329329699, 8.754338091738308, 9.641952720773478, 10.678013981995093, 11.657368815484116, 12.584569728537991, 13.642013648803403, 13.629026720584724, 12.681830492379824, 11.717568442762612, 10.735525198028034, 9.77535065301591, 6.823164290012594, 5.847174043070192, 4.83810749419078, 3.8439938024026854, 4.804233408948682, 5.834007809146785, 6.850565348839623, 7.781291567002524, 8.670536302305878, 9.615585594078823, 10.66322483360702, 11.702910382440244, 12.599319907243382, 13.631030355513603, 14.583760626709951, 14.665993156908605, 13.696402125315903, 12.771278623770774, 11.7037552944741, 10.671251268013329, 7.757702091137195, 6.743563668016261, 5.7925963414561865, 4.846642368943013, 5.842768791249826, 6.765609664737262, 7.799381058877069, 8.758565290094285, 9.702330130215541, 10.59266573983262, 11.666738492818112, 12.710671455641986, 13.530673953235429, 14.462268061492317, 15.434871064670249, 15.606627799612964, 14.661417565699503, 13.604734229056293, 12.60354674451492, 11.540108264415117, 8.709335862306714, 7.768524479310115, 6.829239285097275, 5.901634463078519, 6.884330125582834, 7.704979266402798, 8.671807952986727, 9.640949816339536, 10.65673318230741, 11.614653141670225, 12.557423909738016, 13.536414870667125, 14.465722265212863, 15.451359539890726, 15.704976438126993, 14.731455138058207, 13.950017171408723, 14.516676560192579, 13.455717832107535, 12.469162843011329, 9.679287700848104, 8.817152390156428, 7.875119697390762, 6.924510561702565, 7.869318371441526, 8.703460662873784, 9.669303236420083, 10.638794486347974, 11.636619541895858, 12.54125749451578, 13.520256745641332, 14.44628847254166, 15.458154152989875, 15.584169457687889, 14.644384329826451, 13.728497239301271, 12.969172895316392, 13.900639120697882, 14.410913429569776, 13.533695980309233, 10.60697333448228, 9.786873657396923, 8.925741566570077, 7.943623959598735, 8.880230392090597, 9.652605241196454, 10.622250763405995, 11.604054582772552, 12.59902500816086, 13.612954774896382, 14.56798185807475, 15.448975850405805, 15.626821561433882, 14.62396082677204, 13.672162174763816, 12.731941802341614, 11.948202137281648, 12.84943307066923, 13.732119661029355, 14.59534284353092], [14.575691206631507, 13.650252393228476, 12.742220854697909, 11.787224305181608, 10.804530071049436, 11.713440003008126, 12.667722889616057, 13.683747275461931, 14.528376592397077, 14.575379457217105, 13.615913228111069, 12.572312563940093, 11.642332878719047, 10.631871319077048, 9.704599490271605, 9.213790398845564, 9.943942880272617, 10.873147053143988, 11.818670741920155, 12.596252119726827, 13.504005449278484, 12.707382059550167, 11.80075100988391, 10.814743116039324, 9.781404771648742, 10.739610859438077, 11.673936477536389, 12.654621931075091, 13.599923153419317, 14.56048848119844, 14.542962128985453, 13.610143995172193, 12.636689944320668, 11.629062625074821, 10.752255031213046, 10.21989377151829, 10.98064269110097, 11.930805035244399, 12.707224382153813, 11.640495388790487, 12.498223662061838, 11.702308320062528, 10.734435085115258, 9.810495597895159, 8.811616516428451, 9.741593049459043, 10.678797918098224, 11.639804260429763, 12.624031343497457, 13.549827179600841, 14.484195489051721, 14.575551609815292, 13.663608657125339, 12.61402409613525, 11.777338310129172, 11.159292359953469, 11.951916315743652, 12.7381034355666, 11.738260244366712, 10.741111901987804, 11.530204354466752, 10.639506975229525, 9.724509697248058, 8.795876774688203, 7.75004336214544, 8.743216494360178, 9.679604335541903, 10.591419565395483, 11.629712251990872, 12.57191551676081, 13.510561988076233, 14.501714191803577, 14.642447734244264, 13.595779774475705, 12.84115250004888, 12.21431605301628, 12.520155954089724, 11.703651772070076, 10.77627961417949, 9.7976188323573, 10.598768672542645, 9.628515650392856, 8.692820386119124, 7.848341345847975, 6.78918783239384, 7.8441660682553715, 8.712667227161749, 9.642235485945864, 10.652901963286723, 11.557420906726321, 12.580996158999422, 13.548911077518225, 14.362772910912255, 14.550937054779519, 13.594971749886497, 12.636211459182885, 11.58266023033422, 10.635794190078775, 9.784098735038656, 8.853354415584791, 9.74180908142247, 8.735096396691604, 7.7530720943390365, 6.871469270115477, 5.849781641326787, 6.855089091867158, 7.759753818068736, 8.735625950821268, 9.702213773589712, 10.619641688093857, 11.58204860271843, 12.516946636363077, 13.413773093114074, 13.6166275208671, 12.667534881918842, 11.704264806846417, 10.700380298592309, 9.699955530060588, 8.840114031617091, 7.874988160509601, 8.78663680048066, 7.747002592562874, 6.757872347968806, 5.894439431423296, 4.90504211074971, 5.910259928148323, 6.8034853571323985, 7.770343957998182, 8.765382208078645, 9.693258683659414, 10.70245938245537, 11.543597114442814, 12.467166549072976, 12.752260022876468, 11.792025127992577, 10.826810584890529, 9.797169949240413, 8.774936725180904, 7.851122604820987, 6.897129276819415, 7.8245673496541635, 6.790364606795767, 5.807497804748755, 4.89169492332772, 3.9542701185494558, 4.8648683633692755, 5.8009589673052675, 6.7770429564923775, 7.790805327351953, 8.708291315479697, 9.634988638250958, 10.604262899252635, 11.486962715592785, 11.829132240376493, 10.869872010260336, 9.867239836378296, 8.834255898147061, 7.831919194338707, 6.88781150025878, 5.879059392130811, 6.928190976877023, 5.855477552016116, 4.877453626599242, 3.9068032238045145, 2.919938470977164, 3.9322694986216065, 4.909308675880876, 5.879553796936504, 6.78129403195275, 7.768268669302181, 8.65588694706871, 9.591377799107217, 10.52539742150464, 10.872195345364158, 9.843997747268961, 8.884785920042093, 7.931335037703191, 6.962039384492036, 6.005375584792919, 4.971557121049385, 5.896304880239164, 4.9471216361886166, 3.932874490608833, 2.951721408050751, 1.9030383110972204, 2.8884527436136054, 3.937201640442931, 4.884748188191621, 5.797997177568205, 6.740062881108256, 7.722685330904061, 8.77923109968151, 9.826255327478297, 10.802377803907982, 10.82991024830437, 9.841730151409436, 8.881853442478883, 7.9289196212469975, 6.949384522761886, 5.9642027648359495, 4.975623519600452, 4.02642429699271, 2.993785793341927, 1.996860081445639, 0.9677477652122399, 1.901883714390176, 2.8727677557185043, 3.840633508792464, 4.8371422841652025, 5.8899631488462685, 6.944205930272062, 7.89268198202061, 8.877874143696362, 9.843638436680349, 10.783010801871875, 10.81847847727618, 9.830998605598035, 8.936107191695069, 7.946213221903921, 6.891462203563046, 4.019572750419823, 3.053927773201643, 2.0660692901844353, 1.005006559738016, 0.0, 0.9776406406942404, 2.0352494936366288, 3.0495921106121626, 4.01540158290922, 5.036633857657199, 6.094230413068278, 7.059578195928977, 8.034713163210558, 9.107689880568422, 10.049315381502609, 11.092963544554024, 10.821834109093384, 9.848928907345451, 8.777303004123457, 7.850775425612087, 4.9314367278467, 3.961121861483042, 2.9341252534592535, 1.9862490093622396, 0.9931447833670203, 1.9373416694147905, 2.9115359823812197, 3.871084576901959, 4.8274761028859166, 5.788385384332093, 6.740931471335487, 7.676401601191098, 8.620668738605206, 9.644789162336755, 10.670529166940504, 11.619564892047709, 11.751740585209001, 10.80968408305155, 9.810126692291886, 8.877929017700225, 5.894102419549482, 4.832866572015412, 3.8866959823995533, 2.9616755268450774, 2.0162493118223677, 2.875778347547843, 3.8496868772774597, 4.861010880283294, 5.7845892920623205, 6.763850133666288, 7.693701146883388, 8.637694545276393, 9.611697265347699, 10.673897245592856, 11.644099340910778, 12.588667019554862, 12.704614323946387, 11.79452077010912, 10.770846351941085, 9.85361140275363, 6.847928306767087, 5.887758573114434, 4.89879727473253, 3.9214661729308693, 3.0180301178078186, 3.891486378511244, 4.819077458245407, 5.792435300408888, 6.7219707695916835, 7.749331532000292, 8.636946161035462, 9.673007422257077, 10.6523622557461, 11.579563168799975, 12.637007089065387, 13.552423423732327, 13.686837052117841, 12.72257500250063, 11.740531757766052, 10.706236304343937, 7.8281708497506095, 6.8521806028082075, 5.843114053928796, 4.849000362140702, 4.057675792916098, 4.944752996362741, 5.845558789101608, 6.776285007264508, 7.665529742567863, 8.610579034340807, 9.658218273869004, 10.697903822702228, 11.594313347505366, 12.626023795775588, 13.578754066971936, 14.589389860056208, 14.70140868505392, 13.702164275098804, 12.63464094580213, 11.602136919341358, 8.762708650875211, 7.748570227754278, 6.797602901194203, 5.85164892868103, 5.096211175217242, 5.876354851953218, 6.794374499139053, 7.753558730356269, 8.697323570477526, 9.587659180094604, 10.661731933080095, 11.705664895903968, 12.525667393497413, 13.457261501754301, 14.429864504932233, 14.74729777973341, 15.592303217027533, 14.535619880384322, 13.53443239584295, 12.470993915743147, 9.71434242204473, 8.773531039048132, 7.834245844835292, 6.906641022816536, 6.14730794757538, 6.8157244536187545, 7.732382339745515, 8.701524203098323, 9.717307569066197, 10.609646581932209, 11.55241735, 12.531408310929109, 13.460715705474847, 14.44635298015271, 14.72981103652999, 13.756289736461204, 14.743870584372896, 15.447562211520609, 14.386603483435564, 13.400048494339359, 10.68429426058612, 9.822158949894446, 8.880126257128778, 7.929517121440582, 7.207925931822011, 7.814205850089741, 8.73345259740491, 9.7029438473328, 10.700768902880684, 11.536250934777764, 12.515250185903316, 13.441281912803644, 14.45314759325186, 14.609004056090885, 13.669218928229448, 12.753331837704268, 13.763026308280566, 14.732828964159134, 15.341799080897806, 14.464581631637262, 11.611979894220296, 10.79188021713494, 9.930748126308094, 8.948630519336753, 8.256025587528242, 8.76335042841241, 9.691125138094085, 10.668203943757378, 11.663174369145686, 12.607948215158366, 13.562975298336735, 14.443969290667788, 14.650611996607521, 13.648795425175036, 12.696996773166813, 11.756776400744611, 12.77039326420714, 13.681622914130482, 14.632815249281688, 15.52622849485895], [15.469577843002444, 14.544139029599412, 13.636107491068843, 12.681110941552543, 11.698416707420371, 10.916092296220429, 11.76028473567425, 12.727629515073112, 13.572258832008258, 13.645086307686777, 12.68562007858074, 11.642019414409765, 10.712039729188719, 9.70157816954672, 8.774306340741278, 9.78362933577464, 10.835415669105002, 11.764619841976373, 12.763972273760357, 13.570105411431161, 14.39789208564942, 13.601268695921103, 12.694637646254847, 11.708629752410259, 10.675291408019676, 9.94226315265038, 10.71781871714757, 11.698504170686272, 12.643805393030497, 13.59324814256075, 13.612668979455124, 12.679850845641864, 11.70639679479034, 10.698769475544493, 9.82196188168272, 10.789732708447366, 11.854125211068634, 12.820204051539323, 13.681077673858148, 12.614348680494823, 13.392110298432774, 12.596194956433465, 11.628321721486195, 10.704382234266095, 9.705503152799386, 8.944245342671346, 9.722680157709405, 10.683686500040944, 11.667913583108637, 12.575441917615906, 13.509810227066787, 13.645258460284964, 12.73331550759501, 11.683730946604921, 10.847045160598846, 11.729131296882544, 12.776545653709881, 13.711956727270936, 12.712113536071048, 11.714965193692139, 12.424090990837689, 11.533393611600461, 10.618396333618994, 9.68976341105914, 8.643929998516375, 7.945868787572482, 8.723486575153084, 9.635301805006664, 10.673594491602053, 11.597530254775876, 12.536176726091297, 13.52732892981864, 13.712154584713936, 12.665486624945377, 11.910859350518553, 12.784154989945355, 13.497796594783964, 12.677505063774412, 11.750132905883826, 10.771472124061635, 11.492655308913582, 10.522402286763793, 9.58670702249006, 8.74222798221891, 7.683074468764775, 6.905893803188819, 7.75654946677293, 8.686117725557045, 9.696784202897904, 10.583035644741386, 11.606610897014486, 12.574525815533288, 13.38838764892732, 13.62064390524919, 12.961887219829467, 13.613852099877125, 12.56030087102846, 11.613434830773015, 10.761739375732898, 9.830995056279033, 10.635695717793405, 9.62898303306254, 8.646958730709972, 7.765355906486412, 6.743668277697722, 5.916816826800606, 6.803636057679919, 7.779508190432451, 8.746096013200894, 9.64525642610892, 10.607663340733493, 11.54256137437814, 12.439387831129139, 13.433144811737941, 13.645175522613082, 12.681905447540657, 11.678020939286549, 10.677596170754828, 9.81775467231133, 8.852628801203842, 9.680523436851594, 8.640889228933808, 7.65175898433974, 6.788326067794231, 5.7989287471206445, 4.97198766308177, 5.847367596743581, 6.814226197609364, 7.809264447689827, 8.718873421674477, 9.728074120470431, 10.56921185245788, 11.492781287088041, 12.43786271768957, 12.769665768686817, 11.804451225584769, 10.774810589934653, 9.752577365875144, 8.828763245515226, 7.874769917513655, 8.718453986025098, 7.684251243166702, 6.70138444111969, 5.785581559698655, 4.8481567549203906, 3.908750602980458, 4.84484120691645, 5.82092519610356, 6.834687566963136, 7.733906053494759, 8.66060337626602, 9.6298776372677, 10.51257745360785, 11.472433183852553, 11.847512650954577, 10.844880477072536, 9.811896538841301, 8.809559835032946, 7.86545214095302, 6.856700032825051, 7.8220776132479575, 6.749364188387051, 5.771340262970177, 4.800689860175449, 3.813825107348099, 2.9761517382327893, 3.9349234138959392, 4.905168534951567, 5.806908769967812, 6.793883407317243, 7.681501685083773, 8.61699253712228, 9.551012159519704, 10.528243020579021, 10.821638387963203, 9.862426560736335, 8.908975678397432, 7.939680025186277, 6.98301622548716, 5.949197761743626, 6.790191516610099, 5.841008272559551, 4.8267611269797674, 3.845608044421686, 2.7969249474681552, 1.9287430160942558, 2.962816378457994, 3.910362926206684, 4.8236119155832675, 5.765677619123318, 6.748300068919123, 7.804845837696574, 8.851870065493358, 9.827992541923043, 10.82142840200941, 10.819370792103676, 9.859494083173125, 8.90656026194124, 7.9270251634561255, 6.941843405530189, 5.953264160294692, 4.99393953567316, 3.9613010320223774, 2.8907467178165738, 1.8616344015831747, 0.9274984524052388, 1.8983824937335672, 2.866248246807527, 3.8627570221802654, 4.915577886861331, 5.9698206682871255, 6.9182967200356735, 7.903488881711424, 8.869253174695412, 9.808625539886938, 10.802941125153254, 10.808639246292277, 9.911950824132374, 8.922056854341227, 7.861930541610728, 4.997213391114064, 4.031568413895884, 3.0437099308786757, 1.9826472004322564, 0.9776406406942404, 0.0, 1.0576088529423886, 2.0719514699179227, 3.03776094221498, 4.058993216962958, 5.116589772374037, 6.081937555234736, 7.057072522516318, 8.130049239874182, 9.071674740808369, 10.115322903859784, 11.047237422116092, 10.786756794155789, 9.715130890933795, 8.788603312422424, 5.90907736854094, 4.9387625021772825, 3.911765894153494, 2.9638896500564798, 1.9512454059322328, 1.0070485198844628, 1.981242832850892, 2.940791427371631, 3.8971829533555886, 4.858092234801765, 5.8106383218051585, 6.74610845166077, 7.690375589074877, 8.714496012806427, 9.740236017410176, 10.68927174251738, 11.647290615756111, 11.724128542038896, 10.724571151279232, 9.79237347668757, 6.871743060243723, 5.810507212709653, 4.864336623093794, 3.9355288185494133, 2.9407060771664035, 1.9454851980175152, 2.9193937277471322, 3.9307177307529657, 4.854296142531992, 5.83355698413596, 6.76340799735306, 7.707401395746063, 8.68140411581737, 9.743604096062528, 10.71380619138045, 11.658373870024533, 12.600164354493497, 12.708965229096464, 11.685290810928429, 10.747498039124565, 7.825568947461328, 6.865399213808675, 5.876437915426771, 4.895319464635205, 3.9270483531386975, 2.961193228980916, 3.888784308715079, 4.86214215087856, 5.791677620061355, 6.819038382469963, 7.706653011505134, 8.742714272726749, 9.722069106215772, 10.649270019269647, 11.706713939535058, 12.622130274201998, 13.630488937144666, 13.637019461487974, 12.654976216753395, 11.600122940714872, 8.805811490444851, 7.829821243502449, 6.820754694623037, 5.822853653845037, 4.966694028246977, 4.014459846832413, 4.915265639571279, 5.845991857734179, 6.735236593037534, 7.680285884810479, 8.727925124338675, 9.7676106731719, 10.664020197975038, 11.69573064624526, 12.648460917441607, 13.65909671052588, 14.645060570080744, 14.59605091146974, 13.528527582173066, 12.496023555712295, 9.736561942579547, 8.722423519458612, 7.771456192898539, 6.825502220385365, 5.930738546272741, 4.94606170242289, 5.864081349608725, 6.82326558082594, 7.767030420947198, 8.657366030564276, 9.731438783549766, 10.77537174637364, 11.595374243967084, 12.526968352223973, 13.499571355401905, 14.564968872031734, 15.510179105945195, 15.429506516755259, 14.428319032213887, 13.364880552114084, 10.688195713749066, 9.718832570888335, 8.779547376675493, 7.851942554656737, 6.869246892152422, 5.885431304088426, 6.802089190215186, 7.771231053567996, 8.787014419535868, 9.67935343240188, 10.622124200469672, 11.60111516139878, 12.530422555944519, 13.516059830622382, 13.932463329742292, 14.650176372832139, 15.637757220743831, 16.341448847891545, 15.280490119806501, 14.293935130710295, 11.658147552290455, 10.767460481734648, 9.825281821826211, 8.874672686138014, 7.929864876399053, 6.883912700559413, 7.803159447874582, 8.772650697802472, 9.770475753350356, 10.605957785247435, 11.584957036372987, 12.510988763273316, 13.522854443721531, 13.811656349303188, 12.87187122144175, 13.647218474075203, 14.6569129446515, 15.62671560053007, 16.23568571726874, 15.358468268008199, 12.585833185924631, 11.737181748975143, 10.826075717950607, 9.843958110979266, 8.907351678487403, 7.833057278882083, 8.760831988563757, 9.73791079422705, 10.732881219615358, 11.677655065628038, 12.632682148806406, 13.51367614113746, 13.694494236218702, 12.814358399532493, 11.899649066379116, 12.650663037115546, 13.664279900578075, 14.575509550501417, 15.526701885652622, 16.42011513122989], [16.508988563901653, 15.583549750498621, 14.675518211968056, 13.720521662451755, 12.737827428319584, 11.849464140645143, 10.959147679578686, 11.926492458977547, 12.771121775912693, 12.66370531764781, 11.704239088541774, 10.660638424370799, 9.730658739149753, 8.720197179507753, 9.663553400157987, 10.672876395191349, 11.72466272852171, 12.653866901393082, 13.665015613368547, 14.475372508777227, 15.43730280654863, 14.640679416820312, 13.734048367154056, 12.748040473309471, 11.714702128918889, 10.875634997075094, 9.916681661052005, 10.897367114590708, 11.842668336934933, 12.67550989420473, 12.631287989416158, 11.698469855602898, 10.725015804751374, 9.717388485505527, 10.711208941099429, 11.678979767864075, 12.743372270485343, 13.709451110956032, 14.586344771204214, 13.519615777840889, 14.431521019331983, 13.635605677332673, 12.667732442385404, 11.743792955165308, 10.744913873698598, 9.87761718709606, 8.92154310161384, 9.88254944394538, 10.866776527013073, 11.657703669259886, 12.592071978710766, 12.663877470245998, 11.751934517556045, 10.702349956565955, 11.695467309835024, 12.618378356299253, 13.66579271312659, 14.617223824617001, 13.617380633417113, 12.620232291038205, 13.463501711736898, 12.57280433249967, 11.657807054518205, 10.729174131958352, 9.683340719415588, 8.879240631997195, 7.922349519057518, 8.8341647489111, 9.872457435506488, 10.679792006419856, 11.618438477735278, 12.609590681462622, 12.730773594674972, 11.684105634906413, 12.758292614848273, 13.673402049362064, 14.503827201219176, 13.606639911119077, 12.67926775322849, 11.7006069714063, 12.53206602981279, 11.561813007663002, 10.62611774338927, 9.781638703118123, 8.722485189663988, 7.905224632259762, 6.955412410677364, 7.88498066946148, 8.895647146802338, 9.665297396385366, 10.688872648658467, 11.65678756717727, 12.4706494005713, 12.639262915210226, 13.605326458161166, 14.587052478595352, 13.566331477463672, 12.619465437208227, 11.728539674051591, 10.797795354597726, 11.67510643869262, 10.668393753961752, 9.686369451609183, 8.804766627385625, 7.7830789985969355, 6.916147655871549, 6.0024990015843525, 6.978371134336885, 7.901664625256985, 8.727518177752902, 9.689925092377475, 10.624823126022122, 11.521649582773119, 12.515406563381921, 13.435667619164441, 13.687936053975871, 12.684051545721761, 11.68362677719004, 10.82378527874654, 9.858659407639054, 10.719934157750808, 9.680299949833023, 8.691169705238952, 7.827736788693445, 6.838339468019858, 5.971318492152713, 5.046230540648015, 6.013089141513798, 6.957113508670027, 7.801135173318459, 8.810335872114415, 9.651473604101861, 10.575043038732021, 11.52012446933355, 12.441798305913592, 12.810481832019981, 11.780841196369865, 10.758607972310356, 9.834793851950437, 8.880800523948865, 9.757864706924313, 8.723661964065915, 7.740795162018903, 6.8249922805978676, 5.887567475819604, 4.9481613238796704, 4.043704150820884, 5.019788140007994, 5.951606904909746, 6.8161678051387415, 7.742865127910003, 8.712139388911682, 9.59483920525183, 10.554694935496533, 11.515708895741453, 11.85091108350775, 10.817927145276514, 9.815590441468158, 8.871482747388232, 7.8627306392602625, 8.86148833414717, 7.788774909286263, 6.810750983869389, 5.840100581074662, 4.853235828247312, 4.015562459132002, 3.0325660521384945, 4.0028111731941225, 4.889170521611795, 5.876145158961226, 6.763763436727755, 7.699254288766263, 8.633273911163686, 9.610504772223003, 10.6387023703182, 10.920035413678722, 9.96658453133982, 8.997288878128666, 8.040625078429548, 7.006806614686014, 7.829602237509311, 6.880418993458765, 5.866171847878981, 4.885018765320899, 3.836335668367368, 2.9681537369934685, 2.0604590167005497, 3.008005564449239, 3.9058736672272496, 4.847939370767301, 5.830561820563106, 6.887107589340556, 7.934131817137342, 8.890461809019312, 9.865558017985922, 10.814799774618383, 10.917102936115514, 9.964169114883628, 8.984634016398514, 7.999452258472578, 7.010873013237081, 6.033350256572374, 5.000711752921591, 3.9301574387157867, 2.9010451224823877, 1.9669091733044515, 0.996025131976123, 1.9638908850500827, 2.9450187738242475, 3.957842350230406, 5.0049309918855105, 5.9534070436340585, 6.938599205309809, 7.904363498293797, 8.843735863485323, 9.838051448751639, 10.88983692134616, 10.951361545031588, 9.961467575240441, 8.901341262509941, 6.054822244056452, 5.089177266838272, 4.101318783821064, 3.0402560533746446, 2.0352494936366288, 1.0576088529423886, 0.0, 1.014342616975534, 1.9801520892725912, 3.001384364020569, 4.058980919431648, 5.0243287022923475, 5.999463669573929, 7.072440386931793, 8.014065887865979, 9.057714050917394, 9.989628569173702, 10.962533770921635, 10.754541611833007, 9.828014033321637, 6.915107974976151, 5.944793108612494, 4.917796500588706, 3.9699202564916916, 2.918253041826125, 1.9740561557783551, 0.9998618428119258, 1.9594104373326648, 2.9158019633166226, 3.876711244762799, 4.829257331766193, 5.7647274616218045, 6.708994599035912, 7.7331150227674605, 8.75885502737121, 9.707890752478415, 10.665909625717145, 11.607966127874596, 11.763981872178446, 10.831784197586785, 7.877773666678935, 6.816537819144864, 5.8703672295290055, 4.902536454443306, 3.907713713060296, 2.912492833911408, 1.938012737708166, 2.949336740713999, 3.872915152493026, 4.852175994096994, 5.782027007314094, 6.726020405707098, 7.700023125778405, 8.762223106023562, 9.732425201341483, 10.67699287998557, 11.618783364454533, 12.593186800276593, 12.724701531827645, 11.78690876002378, 8.83159955389654, 7.871429820243886, 6.843238213745465, 5.82445431197987, 4.828091692746886, 3.862236568589105, 2.907403318676113, 3.880761160839594, 4.810296630022389, 5.837657392430997, 6.725272021466168, 7.761333282687783, 8.740688116176807, 9.667889029230682, 10.725332949496094, 11.640749284163034, 12.649107947105701, 13.613369996722913, 13.694386937652611, 12.639533661614086, 9.772611788763545, 8.796621541821143, 7.787554992941731, 6.751988501189702, 5.867737367855166, 4.915503186440602, 3.9338846495323136, 4.864610867695213, 5.753855602998568, 6.698904894771513, 7.746544134299709, 8.786229683132934, 9.682639207936074, 10.714349656206295, 11.667079927402643, 12.677715720486916, 13.66367958004178, 14.683776859410854, 14.567938303072275, 13.535434276611504, 10.665696789924212, 9.651558366803277, 8.700591040243204, 7.75463706773003, 6.831781885880931, 5.84710504203108, 4.882700359569759, 5.841884590786974, 6.785649430908232, 7.675985040525311, 8.750057793510802, 9.793990756334676, 10.61399325392812, 11.545587362185008, 12.51819036536294, 13.58358788199277, 14.52879811590623, 15.585481452549441, 15.467729753113096, 14.404291273013293, 11.593462811095131, 10.619875910496525, 9.680590716283684, 8.752985894264928, 7.770290231760612, 6.786474643696616, 5.82070820017622, 6.7898500635290295, 7.805633429496902, 8.697972442362914, 9.640743210430706, 10.619734171359815, 11.549041565905554, 12.534678840583418, 13.58622961305437, 14.574595925264976, 15.487214159056698, 16.496102200623312, 16.31990084070571, 15.333345851609504, 12.56341464963652, 11.668503821342838, 10.726325161434401, 9.775716025746204, 8.830908216007243, 7.784956040167603, 6.821778457835616, 7.791269707763507, 8.789094763311391, 9.624576795208469, 10.603576046334021, 11.52960777323435, 12.541473453682567, 13.020194082270772, 13.805243065866465, 14.686629194974415, 15.696323665550713, 16.66612632142928, 17.27509643816795, 16.397878988907408, 13.491100283270697, 12.638225088583333, 11.727119057558795, 10.745001450587454, 9.808395018095592, 8.734100618490272, 7.7794509985247915, 8.756529804188085, 9.751500229576394, 10.696274075589072, 11.65130115876744, 12.532295151098495, 12.893357180123138, 12.013221343436928, 12.83302091080383, 13.690073758014758, 14.703690621477287, 15.61492027140063, 16.566112606551833, 17.459525852129097], [17.453903742065904, 16.52846492866287, 15.620433390132307, 14.665436840616007, 13.682742606483835, 12.794379318809394, 11.904062857742938, 11.177360576396625, 11.899735170699486, 11.770879687091059, 10.842708365935827, 9.888162062667936, 9.110234640903332, 9.734539796483288, 10.677896017133522, 11.687219012166883, 12.739005345497246, 13.668209518368617, 14.67935823034408, 15.48971512575276, 16.38221798471288, 15.585594594984563, 14.678963545318307, 13.692955651473723, 12.65961730708314, 11.820550175239346, 10.861596839216256, 10.148235232009785, 10.971281731721726, 11.661167277229197, 11.858811627713296, 10.925993493900036, 10.104591706504953, 10.731731102481062, 11.725551558074963, 12.69332238483961, 13.757714887460878, 14.723793727931566, 15.600687388179747, 14.533958394816421, 15.376436197496234, 14.580520855496925, 13.612647620549655, 12.688708133329559, 11.68982905186285, 10.822532365260312, 9.866458279778092, 9.133417561364457, 9.989373109013172, 10.643361052284353, 11.577729361735233, 11.891401108543135, 11.133852351397975, 11.71669257354149, 12.709809926810559, 13.632720973274788, 14.680135330102125, 15.631566441592534, 14.631723250392646, 13.634574908013738, 14.408416889901149, 13.517719510663921, 12.602722232682456, 11.674089310122604, 10.62825589757984, 9.824155810161447, 8.86726469722177, 8.085032866330177, 8.937847580827494, 9.665449389444323, 10.604095860759744, 11.595248064487087, 12.113116610136801, 12.698448251881945, 13.772635231823806, 14.687744666337599, 15.51816981819471, 14.62098252809461, 13.693610370204023, 12.714949588381833, 13.476981207977042, 12.506728185827253, 11.571032921553522, 10.726553881282374, 9.66740036782824, 8.850139810424015, 7.900327588841616, 7.135848786880558, 7.928484885285184, 8.650954779409833, 9.674530031682933, 10.642444950201735, 11.456306783595767, 12.461291196482849, 13.348761870156562, 14.330487890590748, 14.580674094439207, 13.633808054183762, 12.742882291027126, 11.81213797157326, 12.620021616856869, 11.613308932126003, 10.631284629773434, 9.749681805549876, 8.727994176761186, 7.861062834035801, 6.947414179748605, 6.104825502533995, 6.88732200828145, 7.713175560777367, 8.67558247540194, 9.610480509046587, 10.507306965797586, 11.501063946406388, 12.421325002188908, 13.346996188604086, 13.698394162697296, 12.697969394165575, 11.838127895722074, 10.873002024614587, 11.664849335915058, 10.625215127997272, 9.636084883403203, 8.772651966857696, 7.783254646184108, 6.916233670316966, 5.991145718812267, 5.106260750346069, 5.942770891694492, 6.786792556342924, 7.79599325513888, 8.637130987126326, 9.560700421756488, 10.505781852358018, 11.427455688938059, 12.392670232040107, 12.7951838133454, 11.772950589285891, 10.849136468925971, 9.8951431409244, 10.70277988508856, 9.668577142230165, 8.685710340183153, 7.769907458762119, 6.832482653983854, 5.893076502043923, 4.988619328985136, 4.072306888627896, 4.9372642879342115, 5.801825188163207, 6.728522510934468, 7.697796771936147, 8.580496588276297, 9.540352318521, 10.50136627876592, 11.55248253265988, 11.832269762252048, 10.829933058443693, 9.885825364363766, 8.877073256235796, 9.806403512311423, 8.733690087450515, 7.7556661620336405, 6.785015759238913, 5.798151006411563, 4.960477637296254, 3.9774812303027467, 3.02166632840815, 3.87482790463626, 4.861802541985691, 5.7494208197522205, 6.684911671790728, 7.618931294188152, 8.596162155247468, 9.624359753342665, 10.583571580569533, 10.980927148315356, 10.011631495104202, 9.054967695405084, 8.02114923166155, 8.774517415673563, 7.825334171623016, 6.811087026043232, 5.82993394348515, 4.781250846531619, 3.9130689151577203, 3.005374194864802, 2.0171892364655717, 2.8915310502517153, 3.833596753791766, 4.816219203587571, 5.8727649723650215, 6.919789200161807, 7.876119192043777, 8.851215401010387, 9.80045715764285, 10.824639467489778, 10.978511731859165, 9.997454133151619, 9.012272375225683, 8.014775754174252, 6.978265434736625, 5.945626931085842, 4.875072616880038, 3.845960300646639, 2.911824351468703, 1.940940310140375, 0.9730745570664152, 1.9306761568487132, 2.943499733254872, 3.990588374909976, 4.939064426658525, 5.924256588334275, 6.8900208813182635, 7.829393246509789, 8.823708831776106, 9.875494304370626, 10.824864133209958, 10.906382753404692, 9.846256440674193, 7.069164861031987, 6.1035198838138065, 5.115661400796599, 4.054598670350179, 3.049592110612163, 2.0719514699179227, 1.014342616975534, 0.0, 0.9658094722970572, 1.9870417470450352, 3.0446383024561143, 4.009986085316814, 4.985121052598395, 6.058097769956259, 6.9997232708904455, 8.04337143394186, 8.975285952198169, 9.948191153946102, 11.019817057168096, 10.77292921148589, 7.929450591951686, 6.959135725588029, 5.9321391175642395, 4.984262873467226, 3.9325956588016595, 2.9883987727538894, 2.01420445978746, 1.068986781915609, 2.02297633275987, 2.983885614206047, 3.9364317012094405, 4.871901831065052, 5.816168968479159, 6.840289392210709, 7.866029396814458, 8.815065121921663, 9.773083995160393, 10.715140497317844, 11.714697888077508, 11.776699375751033, 8.892116283654468, 7.830880436120398, 6.884709846504539, 5.916879071418839, 4.922056330035829, 3.9268354508869416, 2.9523553546837, 2.1118712068800534, 2.9800895219362737, 3.9593503635402416, 4.889201376757342, 5.8331947751503455, 6.8071974952216525, 7.86939747546681, 8.839599570784731, 9.784167249428815, 10.72595773389778, 11.70036116971984, 12.675417547726706, 12.731823938188029, 9.845942170872073, 8.885772437219421, 7.857580830721, 6.838796928955404, 5.84243430972242, 4.876579185564639, 3.921745935651647, 3.050970042749233, 3.9174709994656367, 4.944831761874244, 5.832446390909416, 6.868507652131031, 7.8478624856200545, 8.775063398673929, 9.83250731893934, 10.74792365360628, 11.756282316548948, 12.720544366166159, 13.645102953551673, 13.584448839778336, 10.78695440573908, 9.810964158796677, 8.801897609917265, 7.766331118165236, 6.8820799848307, 5.929845803416136, 4.948227266507848, 4.034819749604853, 4.861029972441816, 5.806079264214761, 6.853718503742957, 7.893404052576182, 8.789813577379322, 9.821524025649543, 10.77425429684589, 11.784890089930162, 12.770853949485026, 13.7909512288541, 14.616446010012703, 14.480349454775755, 11.680039406899745, 10.66590098377881, 9.714933657218737, 8.768979684705563, 7.846124502856464, 6.861447659006613, 5.897042976545293, 5.093401443107299, 5.89282380035148, 6.783159409968559, 7.85723216295405, 8.901165125777922, 9.721167623371368, 10.652761731628257, 11.625364734806189, 12.690762251436018, 13.635972485349479, 14.69265582199269, 15.613991176549202, 15.349206451177544, 12.607805428070664, 11.634218527472058, 10.694933333259216, 9.76732851124046, 8.784632848736145, 7.800817260672149, 6.835050817151755, 6.0766003281998895, 6.9260656074913065, 7.805146811806163, 8.747917579873954, 9.726908540803063, 10.656215935348802, 11.641853210026666, 12.693403982497617, 13.681770294708224, 14.594388528499946, 15.60327657006656, 16.623259622517203, 16.278261029773756, 13.577757266612053, 12.682846438318371, 11.740667778409934, 10.790058642721737, 9.845250832982776, 8.799298657143135, 7.8361210748111505, 7.1463682464714875, 7.92392325084105, 8.731751164651717, 9.71075041577727, 10.636782142677598, 11.648647823125815, 12.592463527793841, 13.532248655655279, 14.531834121585579, 15.541528592161876, 16.5212732911974, 17.55613932795438, 17.34279416707166, 14.50544290024623, 13.652567705558866, 12.741461674534328, 11.759344067562987, 10.822737635071125, 9.748443235465805, 8.793793615500325, 8.111628342896065, 8.93717854161119, 9.80344844503232, 10.758475528210688, 11.639469520541741, 12.144225297542215, 12.95813652160118, 13.777936088968081, 14.63498893617901, 15.648605799641539, 16.559835449564883, 17.511027784716088, 18.40444103029335], [18.41971321436296, 17.49427440095993, 16.584733162321555, 15.629736612805257, 14.647042378673085, 13.68315258203975, 12.792836120973293, 11.94296092690316, 10.93392569840243, 10.805070214794002, 9.87689889363877, 8.922352590370878, 9.852332275591923, 10.693442317663338, 11.636798538313572, 12.646121533346934, 13.697907866677296, 14.627112039548667, 15.63826075152413, 16.44861764693281, 17.348027457009938, 16.551404067281624, 15.644773017615368, 14.657255423662972, 13.62391707927239, 12.709323438469701, 11.750370102446611, 10.93151008822863, 10.00547225942467, 10.695357804932137, 10.893002155416237, 9.960184021602977, 10.846689341193544, 11.690633623661112, 12.684454079255014, 13.65222490601966, 14.716617408640928, 15.682696249111617, 16.559589909359797, 15.492860915996472, 16.342245669793293, 15.546330327793985, 14.578457092846715, 13.653007905518809, 12.6541288240521, 11.711305628490667, 10.755231543008447, 9.9166924175833, 9.023563636716116, 9.677551579987295, 10.611919889438177, 10.925591636246077, 11.875949986086566, 12.67559509472154, 13.66871244799061, 14.591623494454838, 15.639037851282175, 16.590468962772583, 15.590625771572697, 14.593477429193788, 15.37422636219821, 14.483528982960982, 13.568531704979515, 12.638389082311853, 11.592555669769089, 10.712929073391802, 9.756037960452126, 8.868307722549021, 7.9720381085304375, 8.699639917147264, 9.638286388462687, 10.629438592190029, 11.563117430907582, 12.450639004489606, 13.43398026717042, 14.321312118380265, 15.251997497926869, 15.57988504927466, 14.652512891384074, 13.673852109561883, 14.442790680274102, 13.472537658124313, 12.53684239385058, 11.690853653471624, 10.63170014001749, 9.73891307365437, 8.789100852071972, 7.919123643099401, 6.962675412988127, 7.6851453071127755, 8.708720559385876, 9.676635477904677, 10.49049731129871, 11.495481724185792, 12.382952397859505, 13.36467841829369, 14.41782329270279, 14.592710575363812, 13.701784812207174, 12.77104049275331, 13.585831089153928, 12.57911840442306, 11.597094102070493, 10.713981577739126, 9.692293948950436, 8.749836097266156, 7.836187442978959, 6.888100358752838, 5.921512535984394, 6.747366088480311, 7.709773003104883, 8.644671036749529, 9.541497493500529, 10.535254474109331, 11.455515529891851, 12.38118671630703, 13.385071224561138, 13.656871915345626, 12.797030416902125, 11.831904545794636, 12.630658808212116, 11.59102460029433, 10.601894355700262, 9.736951739046946, 8.747554418373358, 7.80500693354732, 6.879918982042621, 5.971999669477898, 4.976961419397435, 5.820983084045867, 6.830183782841823, 7.67132151482927, 8.594890949459431, 9.539972380060961, 10.461646216641002, 11.42686075974305, 12.456501395393166, 12.731853110465941, 11.808038990106022, 10.85404566210445, 11.66858935738562, 10.634386614527223, 9.651519812480212, 8.735716931059175, 7.796782426173103, 6.813483196151482, 5.87739259221549, 4.946649932697219, 3.9714548156371547, 4.83601571586615, 5.762713038637411, 6.731987299639091, 7.61468711597924, 8.574542846223943, 9.535556806468863, 10.586673060362823, 11.548305095621561, 11.788835579623743, 10.844727885543817, 9.835975777415847, 10.77221298460848, 9.699499559747572, 8.721475634330698, 7.75082523153597, 6.76396047870862, 5.8938699584967535, 4.866254493533101, 3.896009372477473, 2.909018432339203, 3.8959930696886342, 4.783611347455164, 5.719102199493672, 6.653121821891095, 7.630352682950411, 8.658550281045608, 9.617762108272476, 10.571212990611379, 10.97744096740126, 10.02077716770214, 8.986958703958607, 9.74032688797062, 8.791143643920073, 7.776896498340289, 6.795743415782207, 5.747060318828677, 4.878878387454778, 3.971183667161859, 2.9829987087626293, 1.9257215779546584, 2.867787281494709, 3.8504097312905143, 4.906955500067965, 5.95397972786475, 6.910309719746721, 7.885405928713332, 8.834647685345793, 9.858829995192721, 10.811763816424607, 10.963263605448677, 9.978081847522741, 8.98058522647131, 7.9440749070336825, 6.9114364033829, 5.840882089177096, 4.811769772943697, 3.877633823765761, 2.906749782437432, 1.9388840293634724, 0.9648666845516561, 1.9776902609578146, 3.0247789026129195, 3.973254954361468, 4.9584471160372185, 5.924211409021207, 6.863583774212732, 7.857899359479049, 8.90968483207357, 9.859054660912902, 10.848948630704049, 10.81206591297125, 8.034974333329044, 7.069329356110863, 6.0814708730936555, 5.020408142647236, 4.01540158290922, 3.03776094221498, 1.9801520892725912, 0.9658094722970572, 0.0, 1.021232274747978, 2.0788288301590576, 3.044176613019757, 4.019311580301339, 5.092288297659202, 6.033913798593389, 7.077561961644804, 8.009476479901112, 8.982381681649045, 10.054007584871039, 10.98053516338241, 8.888353113131735, 7.918038246768077, 6.891041638744289, 5.943165394647275, 4.891498179981709, 3.947301293933939, 2.97310698096751, 2.0135583864467708, 1.057166860462813, 2.0180761419089897, 2.9706222289123834, 3.906092358767994, 4.850359496182102, 5.87447991991365, 6.900219924517399, 7.849255649624604, 8.807274522863334, 9.749331025020785, 10.74888841578045, 11.68108609037211, 9.851018804834517, 8.789782957300448, 7.843612367684589, 6.875781592598889, 5.88095885121588, 4.885737972066991, 3.91125787586375, 3.006673697407989, 2.0142800496392166, 2.9935408912431845, 3.923391904460284, 4.867385302853288, 5.841388022924595, 6.903588003169752, 7.873790098487673, 8.818357777131759, 9.760148261600722, 10.734551697422782, 11.709608075429646, 12.714102857125928, 10.804844692052122, 9.84467495839947, 8.816483351901049, 7.797699450135453, 6.8013368309024695, 5.835481706744688, 4.880648456831697, 3.9457725332771685, 2.9516615271685795, 3.9790222895771876, 4.8666369186123575, 5.902698179833973, 6.882053013322997, 7.809253926376871, 8.866697846642282, 9.782114181309224, 10.790472844251891, 11.754734893869102, 12.679293481254613, 13.650206566064545, 11.745856926919128, 10.769866679976726, 9.760800131097314, 8.725233639345285, 7.840982506010749, 6.888748324596185, 5.907129787687897, 4.888079236970393, 3.895220500144759, 4.840269791917703, 5.8879090314459, 6.927594580279124, 7.824004105082264, 8.855714553352486, 9.80844482454883, 10.819080617633105, 11.80504447718797, 12.825141756557043, 13.650636537715643, 14.59542009530206, 12.638941928079795, 11.62480350495886, 10.673836178398787, 9.727882205885614, 8.805027024036514, 7.820350180186663, 6.855945497725343, 5.899408219434512, 4.9270143280544225, 5.817349937671501, 6.891422690656992, 7.935355653480865, 8.755358151074311, 9.6869522593312, 10.659555262509132, 11.724952779138961, 12.670163013052422, 13.726846349695633, 14.648181704252142, 15.571869682112698, 13.566707949250715, 12.593121048652108, 11.653835854439267, 10.726231032420511, 9.743535369916195, 8.7597197818522, 7.7939533383318045, 6.882607104527102, 5.960256135194249, 6.839337339509106, 7.782108107576898, 8.761099068506006, 9.690406463051746, 10.676043737729609, 11.72759451020056, 12.715960822411168, 13.62857905620289, 14.637467097769504, 15.657450150220143, 16.50092426070891, 14.536659787792104, 13.641748959498422, 12.699570299589984, 11.748961163901788, 10.804153354162827, 9.758201178323185, 8.7950235959912, 7.9523750227987, 6.958113778543993, 7.7659416923546605, 8.744940943480213, 9.670972670380541, 10.682838350828758, 11.626654055496784, 12.566439183358222, 13.566024649288522, 14.57571911986482, 15.555463818900343, 16.590329855657323, 17.531500266850557, 15.46434542142628, 14.611470226738916, 13.700364195714378, 12.718246588743037, 11.781640156251175, 10.707345756645855, 9.752696136680376, 8.917635119223277, 7.971369069314132, 8.837638972735263, 9.792666055913632, 10.673660048244685, 11.604581307372445, 12.63084747095834, 13.538661338420857, 14.542210746518554, 15.555827609981083, 16.57277275916849, 17.523965094319696, 18.591735762084582], [18.532016542020045, 17.553260648276215, 16.515399482234194, 15.560402932717894, 14.510999711041343, 13.538760743407158, 12.704243093016483, 11.71364799088828, 10.83481377630521, 9.983429683304047, 9.192366410059392, 9.860713788090846, 10.790693473311892, 11.631803515383307, 12.575159736033541, 13.584482731066903, 14.636269064397265, 15.565473237268636, 16.5766219492441, 17.386978844652777, 17.461901089647277, 17.515520018260904, 16.559184707125045, 15.569192735883322, 14.53585439149274, 13.58242682017169, 12.623473484148601, 11.677962186832726, 10.7326609644885, 9.772095636709377, 10.26172533941217, 10.898545219322946, 11.785050538913513, 12.628994821381081, 13.622815276974983, 14.590586103739628, 15.654978606360897, 16.621057446831585, 17.497951107079768, 16.43122211371644, 16.456119302430633, 16.567562602541962, 15.599689367594692, 14.613877144376147, 13.566066136272449, 12.584409010192656, 11.628334924710437, 10.736441985608755, 9.752214902541061, 8.754289411764534, 9.688657721215414, 10.668322960842563, 11.619119521423647, 12.509132514607302, 13.50224986787637, 14.453073643220316, 15.26600642458048, 16.253607113642182, 16.528986969292667, 15.531838626913757, 15.529201878216709, 15.504761257708958, 14.589763979727492, 13.599258321169193, 12.553424908626429, 11.586032455093791, 10.629141342154115, 9.7136260557246, 8.734558809055455, 7.776377748924503, 8.715024220239926, 9.70617642396727, 10.63985526268482, 11.527376836266845, 12.51071809894766, 13.398049950157505, 14.32873532970411, 15.320223394348721, 15.590874089104043, 14.612213307281852, 14.615330976928387, 14.49376993287229, 13.558074668598557, 12.651722892328964, 11.59256937887483, 10.680296053401486, 9.662204233773961, 8.76444197627498, 7.807993746163706, 6.761883138890014, 7.7854583911631146, 8.753373309681917, 9.56723514307595, 10.57221955596303, 11.459690229636745, 12.441416250070931, 13.49456112448003, 14.388352998997146, 14.640146009927143, 13.709401690473278, 13.631176423813628, 13.600350679171036, 12.61832637681847, 11.674850816596466, 10.653163187807776, 9.691219077013272, 8.709290824680949, 7.733418691928416, 6.766830869159972, 5.824103920257549, 6.7865108348821215, 7.721408868526768, 8.618235325277768, 9.61199230588657, 10.53225336166909, 11.457924548084268, 12.461809056338378, 13.45251433897896, 13.735391614622094, 12.770265743514605, 12.7561024298809, 12.612256875042307, 11.623126630448239, 10.697820977904286, 9.708423657230698, 8.746389913294436, 7.821301961789737, 6.854443360923954, 5.859405110843491, 4.897720915823106, 5.906921614619062, 6.748059346606508, 7.671628781236669, 8.6167102118382, 9.53838404841824, 10.503598591520289, 11.533239227170405, 12.527495534099275, 12.74640018782599, 11.79240685982442, 11.771548215862198, 11.6556188892752, 10.672752087228188, 9.726277913177212, 8.757651665030444, 7.774352435008823, 6.838261831072831, 5.867660877942786, 4.85389850708321, 3.912753547643389, 4.83945087041465, 5.808725131416329, 6.691424947756479, 7.651280678001183, 8.612294638246102, 9.663410892140062, 10.6250429273988, 11.584478003257077, 11.783089083263786, 10.774336975135816, 10.925828587808898, 10.720731834495549, 9.742707909078675, 8.772057506283948, 7.785192753456598, 6.854739197354094, 5.827123732390442, 4.856878611334814, 3.869887671196544, 2.972730901465873, 3.8603491792324025, 4.79584003127091, 5.729859653668334, 6.70709051472765, 7.735288112822847, 8.694499940049715, 9.647950822388617, 10.61724647559977, 11.04200944245012, 10.008190978706585, 10.761559162718598, 9.812375918668051, 8.798128773088267, 7.816975690530185, 6.768292593576654, 5.9001106622027555, 4.992415941909837, 3.9506614475830593, 2.8865908168119994, 1.9445251132719483, 2.9271475630677535, 3.9594943316636892, 4.952978343389076, 5.889077444998744, 6.864173653965354, 7.813415410597814, 8.837597720444744, 9.79053154167663, 10.799440059387953, 10.999314122270718, 10.001817501219287, 8.96530718178166, 7.932668678130877, 6.862114363925073, 5.833002047691674, 4.898866098513738, 3.9279820571854103, 2.9601163041114504, 1.986098959299634, 0.9564579862098366, 2.0035466278649414, 2.95202267961349, 3.937214841289241, 4.902979134273229, 5.842351499464755, 6.836667084731071, 7.888452557325593, 8.837822386164925, 9.827716355956072, 10.88784266868657, 9.056206608077023, 8.090561630858842, 7.102703147841634, 6.0416404173952145, 5.036633857657199, 4.058993216962958, 3.001384364020569, 1.9870417470450352, 1.021232274747978, 0.0, 1.0575965554110793, 2.0229443382717784, 2.99807930555336, 4.071056022911224, 5.01268152384541, 6.0563296868968255, 6.9882442051531335, 7.961149406901066, 9.03277531012306, 9.959302888634431, 9.826714310851704, 8.856399444488046, 7.829402836464257, 6.881526592367243, 5.829859377701677, 4.885662491653907, 3.911468178687478, 2.9519195841667387, 1.995528058182781, 1.0346187767366044, 1.9871648637399981, 2.922634993595609, 3.8669021310097165, 4.891022554741266, 5.916762559345015, 6.86579828445222, 7.823817157690951, 8.7658736598484, 9.765431050608065, 10.697628725199726, 10.789380002554486, 9.728144155020416, 8.781973565404558, 7.814142790318856, 6.819320048935847, 5.824099169786959, 4.849619073583718, 3.945034895127957, 2.9526412473591845, 2.010083526070799, 2.939934539287899, 3.883927937680903, 4.85793065775221, 5.920130637997367, 6.890332733315288, 7.8349004119593735, 8.776690896428338, 9.751094332250398, 10.726150710257262, 11.730645491953544, 11.74320588977209, 10.783036156119438, 9.754844549621017, 8.736060647855421, 7.739698028622438, 6.773842904464657, 5.819009654551666, 4.884133730997137, 3.8900227248885475, 3.0848329900038607, 3.8831795534399727, 4.919240814661588, 5.898595648150612, 6.825796561204486, 7.8832404814698975, 8.79865681613684, 9.807015479079507, 10.771277528696718, 11.695836116082228, 12.666749200892161, 12.684218124639097, 11.708227877696695, 10.699161328817283, 9.663594837065254, 8.779343703730717, 7.827109522316154, 6.845490985407866, 5.82644043469036, 4.833581697864727, 4.155737308338325, 4.930871875112454, 5.946650548126366, 6.840546739909879, 7.8722571881801, 8.824987459376446, 9.83562325246072, 10.821587112015585, 11.841684391384659, 12.667179172543259, 13.611962730129676, 13.577303125799764, 12.56316470267883, 11.612197376118756, 10.666243403605582, 9.743388221756483, 8.758711377906632, 7.794306695445312, 6.83776941715448, 5.8653755257743905, 5.132817454092123, 5.970107547443386, 7.000896786498866, 7.771900785901925, 8.703494894158814, 9.676097897336746, 10.741495413966575, 11.686705647880036, 12.743388984523246, 13.664724339079758, 14.588412316940314, 14.505069146970683, 13.531482246372077, 12.592197052159236, 11.66459223014048, 10.681896567636164, 9.698080979572168, 8.732314536051774, 7.82096830224707, 6.898617332914217, 6.1548048559297275, 6.926804950098483, 7.905795911027592, 8.70694909787936, 9.692586372557223, 10.744137145028175, 11.732503457238781, 12.645121691030504, 13.654009732597117, 14.673992785047759, 15.517466895536526, 15.475020985512073, 14.58011015721839, 13.637931497309953, 12.687322361621757, 11.742514551882795, 10.696562376043154, 9.733384793711169, 8.890736220518669, 7.896474976263961, 7.081409208775282, 7.923300411990258, 8.849332138890587, 9.699380985656372, 10.643196690324398, 11.582981818185836, 12.582567284116136, 13.592261754692434, 14.572006453727957, 15.606872490484937, 16.548042901678173, 16.402706619146247, 15.549831424458885, 14.638725393434349, 13.656607786463008, 12.720001353971146, 11.645706954365824, 10.691057334400345, 9.855996316943246, 8.909730267034101, 8.153106489155885, 8.971025524423677, 9.85201951675473, 10.74678326974269, 11.650169429158241, 12.55520397324847, 13.558753381346168, 14.572370244808697, 15.589315393996102, 16.540507729147308, 17.608278396912194], [17.498647078070235, 16.532052334644284, 15.494191168602264, 14.539194619085963, 13.489791397409412, 12.517552429775227, 11.683034779384553, 10.692439677256349, 9.898128194430104, 9.046744101428938, 9.97045169042083, 10.769199451949449, 11.699179137170495, 12.540289179241908, 13.483645399892142, 14.492968394925503, 15.544754728255866, 16.473958901127236, 17.4851076131027, 18.29546450851138, 16.42696132071721, 17.371981278815156, 16.50166777946997, 15.511675808228247, 14.512916696810107, 13.491381573345276, 12.725500797911234, 11.721565021643189, 10.826581633407864, 10.085794953527717, 9.991599868878296, 10.76066472688011, 11.69008843587356, 12.535802255224622, 13.569041416349389, 14.43418050121239, 15.278988318780058, 16.24506715925075, 17.268801619304643, 17.339707777575043, 15.421179533500565, 16.366907539327517, 16.502045596932867, 15.503815293624239, 14.450521249463474, 13.468864123383682, 12.512790037901462, 11.620897098799782, 10.636670015732088, 9.63874452495556, 8.96496614607073, 9.79525711223701, 10.66082779098054, 11.550840784164194, 12.543958137433263, 13.494781912777212, 14.307714694137376, 15.295315383199078, 16.254796003018587, 16.44032429077236, 14.494262109286643, 15.463345444437754, 15.492120209065668, 14.489196470417284, 13.44336305787452, 12.470487568284817, 11.51359645534514, 10.598081168915625, 9.619013922246483, 8.66083286211553, 7.9394971369124745, 8.833110575361717, 9.681563532241713, 10.569085105823737, 11.552426368504555, 12.4397582197144, 13.370443599261005, 14.361931663905617, 15.289303821796203, 15.520698971140455, 13.580391207998321, 14.55064423014811, 14.460430897936734, 13.541661041577054, 12.48250752812292, 11.564751166592512, 10.546659346964987, 9.648897089466006, 8.692448859354732, 7.646338252081041, 7.009931307835664, 7.880307461076365, 8.608943412632842, 9.613927825519923, 10.501398499193641, 11.483124519627827, 12.536269394036927, 13.40661614550151, 14.377051232799488, 14.61788735433188, 12.596236654883562, 13.610076985247444, 13.520682606156646, 12.564788965844556, 11.543101337055866, 10.575674190204298, 9.593745937871974, 8.617873805119443, 7.651285982350998, 6.708559033448576, 6.010983751554671, 6.848343019921216, 7.659943594834661, 8.653700575443462, 9.573961631225986, 10.499632817641164, 11.503517325895274, 12.470777485483323, 13.414216194303064, 13.678751407373207, 11.721162660950831, 12.727449175557636, 12.529025901674881, 11.587759127152376, 10.598361806478788, 9.630845026485462, 8.705757074980763, 7.738898474114981, 6.743860224034518, 5.782176029014132, 4.948629884175956, 5.789767616163402, 6.713337050793563, 7.658418481395093, 8.580092317975136, 9.545306861077185, 10.574947496727301, 11.545758680603639, 12.498104131233413, 12.700892523683022, 10.73660844693213, 11.770811189790528, 11.578651358454831, 10.616216062425302, 9.647589814278534, 8.664290584256914, 7.728199980320923, 6.752115991133813, 5.738353620274237, 4.797208660834415, 3.8811591399715435, 4.850433400973223, 5.733133217313373, 6.692988947558077, 7.6540029078029965, 8.705119161696956, 9.643306073903162, 10.60274114976144, 11.546848843841367, 11.682822638994418, 9.868232032397817, 10.940945457258724, 10.800304464489756, 9.829654061695027, 8.842789308867678, 7.835089359877516, 6.807473894913864, 5.837228773858236, 4.850237833719966, 3.8571860146568993, 2.9020574487892965, 3.8375483008278044, 4.771567923225228, 5.748798784284544, 6.776996382379741, 7.712763086554077, 8.66621396889298, 9.635509622104134, 10.592173421803253, 11.065787534117664, 10.90198513827612, 10.86997247407913, 9.855725328499346, 8.874572245941264, 7.825889148987733, 6.957707217613835, 6.01060473442023, 4.957614616731563, 3.8935439859605028, 2.951478282420452, 1.968855832624647, 2.9018977762526097, 3.895381787977996, 4.831480889587664, 5.806577098554274, 6.755818855186734, 7.780001165033664, 8.73293498626555, 9.741843503976872, 10.727025261902808, 11.059414056630366, 10.022903737192738, 8.990265233541956, 7.919710919336152, 6.890598603102753, 5.9564626539248176, 4.985578612596489, 4.01771285952253, 3.0436955147107136, 2.000192853879656, 0.945950072453862, 1.8944261242024103, 2.8796182858781614, 3.8453825788621496, 4.784754944053675, 5.779070529319991, 6.830856001914512, 7.780225830753843, 8.77011980054499, 9.83024611327549, 10.113803163488102, 9.14815818626992, 8.160299703252713, 7.099236972806294, 6.094230413068278, 5.116589772374038, 4.058980919431649, 3.0446383024561148, 2.0788288301590576, 1.0575965554110793, 0.0, 0.9653477828606992, 1.9404827501422806, 3.013459467500144, 3.9550849684343303, 4.9987331314857455, 5.9306476497420535, 6.9035528514899855, 7.97517875471198, 8.90170633322335, 10.735199974710307, 9.764885108346649, 8.73788850032286, 7.790012256225847, 6.73834504156028, 5.79414815551251, 4.819953842546081, 3.8604052480253417, 2.904013722041384, 1.9431044405952074, 0.9905583535918137, 1.9014266799636783, 2.845693817377786, 3.869814241109335, 4.8818227904149465, 5.830858515522151, 6.788877388760882, 7.730933890918333, 8.730491281677997, 9.662688956269658, 11.697865666413088, 10.636629818879019, 9.69045922926316, 8.72262845417746, 7.727805712794451, 6.7325848336455625, 5.758104737442321, 4.85352055898656, 3.8611269112177875, 2.918569189929402, 2.003248957412789, 2.8627196240489723, 3.836722344120279, 4.8989223243654365, 5.869124419683358, 6.813692098327443, 7.7417511274982695, 8.71615456332033, 9.691210941327196, 10.695705723023478, 12.651691553630693, 11.69152181997804, 10.66333021347962, 9.644546311714024, 8.648183692481041, 7.68232856832326, 6.727495318410268, 5.792619394855739, 4.79850838874715, 3.9933186538624637, 2.946493971564863, 3.9011068092440593, 4.877387334518681, 5.804588247572555, 6.862032167837967, 7.777448502504908, 8.785807165447574, 9.73999765005655, 10.660896347152162, 11.631809431962095, 13.5927037884977, 12.616713541555297, 11.607646992675885, 10.572080500923857, 9.68782936758932, 8.735595186174756, 7.753976649266469, 6.7349260985489625, 5.742067361723329, 5.041825532765541, 3.9941862932373446, 4.928516542708836, 5.819338426277948, 6.8510488745481695, 7.803779145744516, 8.81441493882879, 9.800378798383655, 10.81040451274449, 11.632239403613193, 12.57702296119961, 14.485788789658367, 13.471650366537432, 12.520683039977358, 11.574729067464185, 10.651873885615084, 9.667197041765233, 8.702792359303913, 7.746255081013082, 6.773861189632993, 6.0189056785193396, 5.033421965568277, 5.982762781081337, 6.750692472269995, 7.682286580526884, 8.654889583704817, 9.720287100334646, 10.665497334248107, 11.722180670891317, 12.629784570149692, 13.553472548010248, 15.413554810829284, 14.439967910230678, 13.500682716017836, 12.57307789399908, 11.590382231494765, 10.606566643430769, 9.640800199910375, 8.729453966105673, 7.807102996772819, 6.9328901362911655, 5.9901193682233735, 6.969110329152482, 7.685740784247429, 8.671378058925292, 9.722928831396246, 10.711295143606852, 11.623913377398575, 12.632801418965188, 13.639053016117693, 14.48252712660646, 16.383506649370673, 15.488595821076991, 14.546417161168554, 13.595808025480357, 12.651000215741396, 11.605048039901755, 10.64187045756977, 9.799221884377271, 8.804960640122564, 7.85949448913672, 6.986614830115149, 7.912646557015478, 8.678172672024441, 9.621988376692467, 10.561773504553905, 11.561358970484205, 12.571053441060503, 13.550798140096026, 14.585664176853006, 15.526834588046242, 17.31119228300485, 16.458317088317486, 15.547211057292948, 14.565093450321607, 13.628487017829745, 12.554192618224425, 11.599542998258945, 10.764481980801849, 9.818215930892704, 8.931191769517323, 8.034339942548568, 8.915333934879623, 9.725574956110759, 10.62896111552631, 11.53399565961654, 12.537545067714237, 13.551161931176766, 14.568107080364172, 15.519299415515377, 16.587070083280263], [16.533299295209535, 15.566704551783584, 14.528843385741563, 13.573846836225263, 12.524443614548712, 11.552204646914527, 10.717686996523852, 9.727091894395649, 9.040759247618237, 9.927734774795715, 10.851442363787607, 10.98142976606167, 11.867379109424643, 12.715927169171858, 13.659283389822091, 14.623217481834574, 15.498621737557869, 16.42782591042924, 17.44629428221765, 18.404234227675758, 15.461613537856511, 16.406633495954452, 15.536319996609269, 14.546328025367547, 13.547568913949407, 12.526033790484576, 11.760153015050534, 10.756217238782488, 9.969212686595997, 10.92977801437512, 10.87641646864283, 9.94359833482957, 10.873022043823022, 11.718735863174084, 12.75197502429885, 13.617114109161848, 14.461921926729516, 15.428000767200205, 16.451735227254098, 17.373149336223673, 14.455831750639865, 15.401559756466815, 16.405205933342884, 15.560643678081885, 14.505708726543402, 13.52405160046361, 12.74646340065417, 11.771034909427817, 10.95112130930455, 10.604092307816261, 9.920157056031382, 8.97819072018647, 9.84376139893, 10.733774392113656, 11.726891745382725, 12.67771552072667, 13.490648302086834, 14.478248991148536, 15.437729610968045, 16.424912921906746, 13.528914326425943, 14.497997661577054, 15.542303098381963, 15.454544253277982, 14.408710840735218, 13.435835351145517, 12.478944238205841, 11.563428951776325, 10.584361705107183, 9.62618064497623, 8.894688046873126, 8.016044183311177, 8.864497140191174, 9.752018713773198, 10.735359976454014, 11.622691827663859, 12.553377207210463, 13.544865271855075, 14.472237429745661, 15.384312149185629, 12.615043425137621, 13.58529644728741, 14.520991711561141, 14.507008824437753, 13.447855310983618, 12.53009894945321, 11.512007129825687, 10.614244872326706, 9.657796642215432, 8.61168603494174, 7.965122217796315, 7.063241069025825, 7.791877020582303, 8.796861433469385, 9.6843321071431, 10.666058127577285, 11.716072683981418, 12.499839958787373, 13.470275046085352, 14.401019365539216, 11.630888872022862, 12.644729202386744, 13.626753504739312, 13.530136748705255, 12.508449119916564, 11.541021973064996, 10.559093720732674, 9.583221587980143, 8.616633765211699, 7.673906816309275, 6.966174661515322, 6.0312766278706755, 6.842877202784122, 7.836634183392924, 8.756895239175446, 9.682566425590624, 10.683320615839765, 11.564001298769186, 12.507440007588928, 13.533759890742033, 10.755814878090131, 11.762101392696936, 12.73870475219689, 12.553106910013074, 11.563709589339487, 10.59619280934616, 9.671104857841462, 8.70424625697568, 7.709208006895216, 6.7475238118748315, 5.905867987229486, 4.972701224112862, 5.896270658743024, 6.841352089344554, 7.763025925924596, 8.728240469026645, 9.699443938282378, 10.638982493889502, 11.591327944519277, 12.545321272520848, 9.77126066407143, 10.805463406929828, 11.78833020897684, 11.581563845286, 10.612937597139233, 9.629638367117613, 8.693547763181622, 7.7174637739945116, 6.703701403134936, 5.762556443695114, 4.846506922832242, 4.033367008922684, 4.916066825262834, 5.875922555507538, 6.836936515752457, 7.825667815962331, 8.736529887189027, 9.695964963047304, 10.64007265712723, 11.6488247652552, 8.902884249537118, 9.975597674398026, 10.9536215998149, 10.795001844555726, 9.808137091728376, 8.800437142738216, 7.772821677774563, 6.802576556718935, 5.815585616580665, 4.822533797517599, 3.867405231649996, 3.020481908777265, 3.9545015311746887, 4.931732392234005, 5.89402215527673, 6.805986899839942, 7.7594377821788445, 8.728733435389998, 9.685397235089116, 10.71921569883265, 9.967410797412324, 10.91659404146287, 10.821073111360045, 9.839920028801963, 8.791236931848433, 7.923055000474534, 6.975952517280929, 5.922962399592262, 4.858891768821202, 3.9168260652811515, 2.9342036154853464, 1.9962824647824864, 2.9886056012638615, 3.924704702873529, 4.899800911840139, 5.8490426684726, 6.873224978319529, 7.826158799551415, 8.835067317262737, 9.820249075188674, 10.817745696240104, 10.988251520053437, 9.955613016402655, 8.88505870219685, 7.855946385963453, 6.921810436785517, 5.950926395457189, 4.983060642383229, 4.009043297571413, 2.9655406367403554, 1.9112978553145612, 0.988810812732287, 1.9728420991640263, 2.9386063921480146, 3.87797875733954, 4.872294342605857, 5.924079815200377, 6.873449644039709, 7.863343613830855, 8.895671772411694, 11.0791509463488, 10.11350596913062, 9.125647486113412, 8.064584755666992, 7.059578195928976, 6.081937555234736, 5.0243287022923475, 4.009986085316814, 3.0441766130197565, 2.0229443382717784, 0.9653477828606992, 0.0, 0.9751349672815814, 2.048111684639445, 2.9897371855736314, 4.033385348625047, 4.965299866881355, 5.938205068629287, 7.009830971851281, 7.936358550362652, 11.616190648077083, 10.645875781713425, 9.618879173689637, 8.671002929592623, 7.619335714927057, 6.675138828879287, 5.700944515912857, 4.741395921392118, 3.7850043954081602, 2.8240951139619836, 1.87154902695859, 0.9360788971029791, 1.8803460345170868, 2.9044664582486357, 3.916475007554248, 4.865510732661453, 5.823529605900184, 6.765586108057635, 7.765143498817298, 8.697341173408958, 12.578856339779865, 11.517620492245795, 10.571449902629936, 9.603619127544237, 8.608796386161227, 7.613575507012339, 6.639095410809097, 5.734511232353336, 4.742117584584564, 3.7995598632961785, 2.8842396307795655, 1.8973718411882732, 2.8713745612595796, 3.9335745415047376, 4.903776636822658, 5.848344315466743, 6.776403344637571, 7.750806780459633, 8.725863158466495, 9.730357940162778, 13.53268222699747, 12.572512493344817, 11.544320886846398, 10.525536985080802, 9.529174365847819, 8.563319241690037, 7.608485991777044, 6.673610068222516, 5.679499062113927, 4.8743093272292395, 3.8274846449316393, 2.9357590263833604, 3.9120395516579816, 4.839240464711856, 5.896684384977267, 6.812100719644208, 7.820459382586875, 8.774649867195851, 9.695548564291462, 10.666461649101395, 14.473694461864477, 13.497704214922075, 12.488637666042663, 11.453071174290635, 10.568820040956098, 9.616585859541534, 8.634967322633244, 7.615916771915741, 6.623058035090107, 5.9228162061323175, 4.875176966604121, 3.9631687598481378, 4.853990643417249, 5.88570109168747, 6.838431362883816, 7.849067155968091, 8.835031015522954, 9.845056729883792, 10.666891620752493, 11.61167517833891, 15.366779463025145, 14.35264103990421, 13.401673713344136, 12.455719740830963, 11.532864558981862, 10.548187715132011, 9.58378303267069, 8.62724575437986, 7.654851862999771, 6.899896351886116, 5.914412638935053, 5.017414998220638, 5.785344689409295, 6.7169387976661845, 7.6895418008441165, 8.754939317473946, 9.700149551387407, 10.756832888030617, 11.664436787288992, 12.588124765149548, 16.294545484196064, 15.320958583597456, 14.381673389384614, 13.454068567365859, 12.471372904861543, 11.487557316797547, 10.521790873277151, 9.610444639472451, 8.688093670139597, 7.813880809657942, 6.87111004159015, 6.036627923758056, 6.7203930013867295, 7.706030276064593, 8.757581048535545, 9.745947360746152, 10.658565594537874, 11.667453636104488, 12.673705233256992, 13.51717934374576, 17.264497322737455, 16.36958649444377, 15.427407834535332, 14.476798698847135, 13.531990889108174, 12.486038713268533, 11.522861130936546, 10.68021255774405, 9.685951313489342, 8.740485162503496, 7.867605503481926, 7.055277610203611, 7.712824889163741, 8.656640593831767, 9.596425721693205, 10.596011187623505, 11.605705658199803, 12.585450357235326, 13.620316393992306, 14.561486805185542, 18.19218295637163, 17.339307761684264, 16.428201730659726, 15.446084123688385, 14.509477691196523, 13.435183291591203, 12.480533671625722, 11.645472654168627, 10.699206604259482, 9.8121824428841, 8.915330615915344, 8.057964988067756, 8.760227173250058, 9.66361333266561, 10.56864787675584, 11.572197284853537, 12.585814148316066, 13.602759297503471, 14.553951632654677, 15.621722300419563], [15.558164327927951, 14.676385540269823, 13.638524374227803, 12.683527824711502, 11.634124603034952, 10.661885635400767, 9.827367985010092, 8.836772882881888, 9.78247952052061, 10.734888602543116, 11.737671479786997, 11.79939833032292, 10.92931409188396, 11.777862151631174, 12.721218372281408, 13.68515246429389, 14.560556720017185, 15.489760892888556, 16.508229264676963, 17.457256245241876, 14.486478570574928, 15.43149852867287, 14.646000985095508, 13.656009013853787, 12.657249902435646, 11.635714778970815, 10.869834003536774, 9.865898227268728, 10.71093295949837, 11.671498287277494, 11.69438503290408, 10.76156689909082, 9.934957026282339, 10.7806708456334, 11.813910006758167, 12.679049091621165, 13.523856909188833, 14.489935749659521, 15.51244304492716, 16.39801436894209, 13.480696783358281, 14.426424789185232, 15.430070966061301, 14.670324666568124, 13.615389715029641, 12.633732588949849, 11.85614438914041, 10.880715897914056, 11.692841582206924, 11.57922727509784, 10.835399507064174, 9.79615928444772, 8.905696381389317, 9.795709374572972, 10.788826727842041, 11.739650503185986, 12.55258328454615, 13.540183973607853, 14.473775036979601, 15.449777954625164, 12.55377935914436, 13.52286269429547, 14.56716813110038, 15.522003191868393, 14.625282276263452, 13.632109144048714, 12.85533797169673, 11.929100592948336, 11.559496672388763, 10.60131561225781, 9.809930497905919, 8.834012747572427, 7.926432122650491, 8.813953696232515, 9.79729495891333, 10.684626810123175, 11.61531218966978, 12.59886801751962, 13.508282855757217, 14.409177181904049, 11.639908457856038, 12.610161480005827, 13.545856744279558, 14.574467763028164, 14.4229902782652, 13.50523391673479, 12.487142097107267, 11.589379839608286, 10.632931609497012, 9.58682100222332, 8.880364668829108, 7.8812096332870745, 6.853812003041621, 7.858796415928701, 8.746267089602416, 9.727993110036602, 10.740937716699838, 11.524704991505793, 12.495140078803772, 13.425884398257637, 10.65575390474128, 11.669594235105162, 12.651618537457729, 13.607512177769818, 13.483584087198146, 12.516156940346576, 11.534228688014254, 10.558356555261723, 9.591768732493279, 8.649041783590855, 7.881417112548115, 6.946519078903468, 5.904812185243439, 6.8985691658522414, 7.818830221634762, 8.744501408049938, 9.708185648558185, 10.588866331487607, 11.532305040307348, 12.558624923460453, 9.78067991080855, 10.786966425415352, 11.763569784915306, 12.738295535514425, 12.538844556621068, 11.57132777662774, 10.646239825123041, 9.67938122425726, 8.684342974176797, 7.722658779156412, 6.821110438262279, 5.887943675145655, 4.958205641202341, 5.903287071803871, 6.824960908383913, 7.79017545148596, 8.724308971000797, 9.663847526607922, 10.616192977237697, 11.570186305239268, 8.796125696789849, 9.830328439648245, 10.813195241695256, 11.775630537724785, 11.588072564420814, 10.604773334399194, 9.668682730463203, 8.692598741276093, 7.6788363704165175, 6.737691410976695, 5.821641890113824, 4.948609459955476, 3.978001807722151, 4.937857537966854, 5.898871498211774, 6.850532848680749, 7.7613949199074455, 8.720829995765724, 9.664937689845651, 10.673689797973621, 7.927749282255537, 9.000462707116444, 9.978486632533318, 10.949137035328047, 10.783272059009956, 9.775572110019796, 8.747956645056144, 7.777711524000516, 6.790720583862246, 5.797668764799179, 4.842540198931577, 3.9504561360314288, 3.0164365136340057, 3.993667374693322, 4.918887187995148, 5.83085193255836, 6.784302814897263, 7.753598468108417, 8.710262267807535, 9.744080731551069, 8.99227583013074, 9.941459074181287, 10.95570621976107, 10.815054996083543, 9.766371899130013, 8.898189967756114, 7.95108748456251, 6.898097366873843, 5.834026736102784, 4.891961032562733, 3.9093385827669276, 2.971417432064068, 2.01347063398228, 2.9495697355919477, 3.9246659445585577, 4.873907701191018, 5.898090011037947, 6.851023832269833, 7.859932349981156, 8.845114107907092, 9.842610728958523, 10.87912104839615, 10.930747983684235, 9.86019366947843, 8.831081353245033, 7.896945404067097, 6.926061362738769, 5.958195609664809, 4.984178264852994, 3.9406756040219366, 2.8864328225961424, 1.9639457800138684, 0.997707131882445, 1.9634714248664331, 2.9028437900579585, 3.897159375324275, 4.948944847918796, 5.898314676758127, 6.888208646549273, 7.920536805130111, 10.696065102180631, 11.088640936412201, 10.100782453394993, 9.039719722948574, 8.034713163210558, 7.057072522516317, 5.999463669573928, 4.985121052598394, 4.019311580301338, 2.99807930555336, 1.9404827501422806, 0.9751349672815814, 0.0, 1.0729767173578635, 2.0146022182920498, 3.0582503813434654, 3.9901648995997734, 4.963070101347705, 6.0346960045697, 6.96122358308107, 11.621312462257732, 11.621010748995007, 10.594014140971218, 9.646137896874205, 8.59447068220864, 7.650273796160868, 6.676079483194439, 5.7165308886737, 4.760139362689742, 3.7992300812435653, 2.8466839942401716, 1.9112138643845604, 0.9900270230033252, 2.0141474467348743, 2.9413400402726664, 3.890375765379871, 4.848394638618602, 5.790451140776053, 6.790008531535716, 7.722206206127377, 12.592250711133367, 12.492755459527377, 11.546584869911518, 10.578754094825818, 9.583931353442809, 8.58871047429392, 7.614230378090679, 6.709646199634918, 5.717252551866146, 4.77469483057776, 3.859374598061147, 2.8725068084698546, 1.9810555497458182, 3.0432555299909763, 4.007417641133557, 4.894106535837263, 5.801268377355989, 6.775671813178051, 7.750728191184914, 8.755222972881196, 13.546076598350972, 13.547647460626399, 12.519455854127978, 11.500671952362381, 10.504309333129399, 9.538454208971618, 8.583620959058626, 7.648745035504097, 6.654634029395509, 5.849444294510821, 4.8026196122132205, 3.9108939936649416, 3.02172054014422, 3.9489214531980945, 5.006365373463506, 5.857862940014728, 6.865068289768459, 7.79951489991427, 8.72041359700988, 9.691326681819813, 14.451067964091818, 14.472839182203655, 13.463772633324243, 12.428206141572215, 11.543955008237678, 10.591720826823115, 9.610102289914828, 8.591051739197322, 7.598193002371689, 6.897951173413898, 5.850311933885702, 4.908840346483456, 3.9636716319034875, 4.995382080173709, 5.948112351370055, 6.894829376338611, 7.879639922704539, 8.86992176260221, 9.691756653470911, 10.636540211057326, 15.444087363386137, 15.32777600718579, 14.376808680625716, 13.430854708112543, 12.507999526263443, 11.523322682413593, 10.558917999952273, 9.60238072166144, 8.629986830281352, 7.875031319167697, 6.889547606216634, 5.864783448046798, 4.895025677895534, 5.826619786152423, 6.799222789330355, 7.864620305960185, 8.809830539873644, 9.797966546827174, 10.68930182000741, 11.612989797867964, 16.395721134555657, 16.296093550879036, 15.356808356666196, 14.42920353464744, 13.446507872143124, 12.462692284079129, 11.496925840558735, 10.585579606754031, 9.663228637421177, 8.700109925657332, 7.75733915758954, 6.77834819666043, 5.830073989872968, 6.815711264550831, 7.867262037021785, 8.855628349232392, 9.768246583024112, 10.777134624590726, 11.698570265975409, 12.542044376464176, 17.35421549714646, 17.34472146172535, 16.402542801816914, 15.451933666128717, 14.507125856389756, 13.461173680550115, 12.49799609821813, 11.655347525025629, 10.661086280770922, 9.626714278502886, 8.723029610006314, 7.796997883105986, 6.82250587764998, 7.766321582318006, 8.706106710179444, 9.705692176109745, 10.715386646686042, 11.695131345721565, 12.65376586343765, 13.594936274630886, 18.281901130780636, 17.535019789462176, 16.532857165041385, 15.55586908095305, 14.642917275611213, 13.662467434140602, 12.718608332614137, 11.927920389891227, 11.674341571541062, 10.698411558883489, 9.770754722439733, 8.79968526097013, 7.869908161736298, 8.77329432115185, 9.67832886524208, 10.681878273339777, 11.695495136802306, 12.712440285989711, 13.663632621140916, 14.656583137852573], [14.485187610570087, 13.611292160946967, 12.678362811941641, 11.72336626242534, 10.805011997450968, 9.945705052990695, 9.295994999681875, 9.736003615509066, 10.681710253147788, 11.634119335170293, 12.636902212414174, 12.720035965158518, 11.849951726719558, 10.890711899964577, 11.83406812061481, 12.733762106898878, 13.609166362622172, 14.538370535493543, 15.556838907281952, 16.46567230203812, 13.413501853217063, 14.358521811315006, 13.685839422809346, 12.695847451567625, 11.828137296851663, 10.919534196560743, 10.338461018208557, 10.765128959895906, 11.610163692125548, 12.570729019904672, 12.615022667739678, 11.682204533926418, 10.855594661117937, 9.893520593966803, 10.92675975509157, 11.727658734226152, 12.57246655179382, 13.538545392264508, 14.520859101723405, 15.406430425738334, 12.407720066000417, 13.353448071827367, 14.357094248703437, 13.723669108249915, 12.797925552071954, 11.917552006539777, 11.333599577646721, 11.779946630541234, 12.592072314834102, 12.5432716990718, 11.756037141899773, 10.716796919283318, 9.826334016224916, 8.908559122906375, 9.901676476175444, 10.788260145790973, 11.601192927151137, 12.58879361621284, 13.482191093775846, 14.458194011421408, 11.480802641786495, 12.449885976937606, 13.494191413742515, 14.449026474510529, 13.859498706354964, 12.915928561638642, 12.332793160203043, 12.828331325575514, 12.523541096362722, 11.56536003623177, 10.730568132741517, 9.754650382408025, 8.84706975748609, 7.926803444565919, 8.845904601518317, 9.733236452728162, 10.663921832274767, 11.607284074315865, 12.516698912553462, 13.417593238700293, 10.566931740498173, 11.537184762647962, 12.472880026921693, 13.5014910456703, 14.495629280267698, 13.955903546022304, 13.299730268583197, 12.553424263582246, 11.596976033470972, 10.55086542619728, 9.801002303664706, 8.801847268122673, 7.774449637877219, 6.971646164262105, 7.794876732207403, 8.776602752641589, 9.74935377349608, 10.533121048302037, 11.503556135600016, 12.434300455053881, 9.582777187383416, 10.596617517747298, 11.578641820099865, 12.534535460411954, 13.556223089200644, 13.480201364320536, 12.498273111988214, 11.522400979235682, 10.555813156467238, 9.613086207564814, 8.802054747383714, 7.8671567137390666, 6.825449820079037, 6.011418914185645, 6.867439864239748, 7.781102598106472, 8.716601705354428, 9.597282388283851, 10.540721097103592, 11.567040980256698, 8.707703193450685, 9.713989708057488, 10.690593067557442, 11.66531881815656, 12.622052060713942, 12.5353722006017, 11.610284249097, 10.643425648231219, 9.648387398150755, 8.68670320313037, 7.741748073097877, 6.808581309981253, 5.87884327603794, 5.016136820137275, 5.873570550988899, 6.826776641542493, 7.732725027797041, 8.672263583404167, 9.624609034033941, 10.578602362035513, 7.7231489794319845, 8.75735172229038, 9.740218524337392, 10.70265382036692, 11.671280068513688, 11.568817758373152, 10.63272715443716, 9.65664316525005, 8.642880794390475, 7.701735834950654, 6.785686314087782, 5.869247094791074, 4.89863944255775, 3.986467180571841, 4.94748114081676, 5.8589489054769945, 6.769810976703691, 7.729246052561969, 8.673353746641896, 9.682105854769866, 6.854772564897674, 7.927485989758582, 8.905509915175456, 9.876160317970182, 10.91394450589224, 10.739616533993756, 9.712001069030103, 8.741755947974475, 7.7547650078362045, 6.761713188773138, 5.806584622905535, 4.871093770867027, 3.937074148469604, 3.029530285559505, 3.927303244791393, 4.839267989354606, 5.792718871693508, 6.762014524904663, 7.71867832460378, 8.752496788347313, 7.919299112772878, 8.868482356823424, 9.882729502403208, 10.831242133723945, 10.783068699015768, 9.91488676764187, 8.935974650037334, 7.882984532348667, 6.8189139015776075, 5.876848198037557, 4.894225748241752, 3.930315588372617, 2.9341082688178783, 1.9579857923881927, 2.933082001354803, 3.8823237579872636, 4.860203146274106, 5.813136967505992, 6.8220454852173145, 7.774819526499345, 8.772316147550777, 9.808826466988405, 10.841464970639187, 10.876890469364188, 9.847778153130788, 8.913642203952852, 7.942758162624523, 6.974892409550564, 5.978383634177826, 4.925562769496761, 3.871319988070966, 2.9228439363224177, 1.9376517746466666, 0.9718874816626784, 1.911259846854204, 2.9055754321205205, 3.9110579831549552, 4.8604278119942865, 5.850321781785433, 6.847560087772249, 9.704481158976876, 10.670126136195057, 11.173759170752856, 10.112696440306436, 9.10768988056842, 8.13004923987418, 7.072440386931793, 6.058097769956259, 5.092288297659202, 4.071056022911224, 3.0134594675001445, 2.048111684639445, 1.0729767173578635, 0.0, 0.9416255009341864, 1.985273663985602, 2.91718818224191, 3.8900933839898424, 4.961719287211837, 5.888246865723207, 10.629728519053977, 11.596286332953195, 11.61578024797382, 10.667904003876806, 9.616236789211241, 8.672039903163471, 7.697845590197042, 6.738296995676303, 5.7819054696923455, 4.820996188246169, 3.868450101242775, 2.932979971387164, 1.988712833973056, 0.964592410241507, 1.868363322914803, 2.8173990480220077, 3.7754179212607384, 4.717474423418189, 5.717031814177852, 6.649229488769513, 11.600666767929612, 12.652945690296555, 12.56835097691412, 11.600520201828422, 10.605697460445413, 9.610476581296524, 8.635996485093283, 7.731412306637521, 6.7390186588687495, 5.796460937580363, 4.881140705063751, 3.8942729154724582, 2.9797413607155487, 1.993700493497609, 2.934440923775694, 3.8211298184794, 4.728291659998126, 5.702695095820187, 6.677751473827049, 7.6822462555233315, 12.554492655147216, 13.615376066825885, 13.541221961130583, 12.522438059364987, 11.526075440132004, 10.560220315974222, 9.60538706606123, 8.670511142506701, 7.6764001363981125, 6.871210401513425, 5.824385719215824, 4.916373876817945, 3.920951272771398, 2.9937503597175237, 3.945756936493725, 4.784886222656865, 5.7920915724105955, 6.726538182556405, 7.647436879652016, 8.618349964461949, 13.459484020888063, 14.435474267830465, 14.485538740326849, 13.44997224857482, 12.565721115240283, 11.613486933825719, 10.63186839691743, 9.612817846199926, 8.619959109374292, 7.895395867472055, 6.847756627943858, 5.808071079110634, 4.862902364530665, 4.042903953040466, 4.887503914400273, 5.821852658980747, 6.806663205346675, 7.796945045244345, 8.618779936113047, 9.563563493699462, 14.452503420182381, 15.3848999055294, 15.398574787628322, 14.452620815115148, 13.529765633266047, 12.545088789416196, 11.580684106954875, 10.624146828664044, 9.651752937283955, 8.872476013225853, 7.807947143497849, 6.764014180673976, 5.794256410522712, 5.097514043465876, 5.8612947717774, 6.862244288766995, 7.775102497238601, 8.72498982946931, 9.616325102649546, 10.5400130805101, 15.4041371913519, 16.37772409195051, 16.3785744636688, 15.450969641650044, 14.468273979145728, 13.484458391081732, 12.518691947561337, 11.607345713756635, 10.623292584121767, 9.59934065828451, 8.656569890216717, 7.677578929287608, 6.729304722500146, 6.163061088261187, 6.92933401946883, 7.853252332039201, 8.733518540389069, 9.742406581955683, 10.625593548617545, 11.469067659106312, 16.362631553942702, 17.419898874533327, 16.574201257142402, 15.623592121454207, 14.739626573922429, 13.724461760796675, 12.789130621636716, 12.558186589293818, 11.560361533745935, 10.525945011130064, 9.622260342633492, 8.696228615733164, 7.721736610277158, 7.234948596989789, 7.989926127769372, 8.856210230796137, 9.7143628164814, 10.694107515516922, 11.580789146079786, 12.521959557273021, 17.29031718757688, 16.583629432067166, 15.581466807646372, 14.604478723558037, 13.6915269182162, 12.775317182474005, 11.83145808094754, 12.848558024726826, 12.573616824516074, 11.597642291510667, 10.66998545506691, 9.698915993597307, 8.769138894363476, 8.241921335823633, 8.962148282832008, 9.852765667755794, 10.735333574516144, 11.745313565545574, 12.59853924181806, 13.583606420494709], [13.5435621096359, 12.669666660012783, 11.736737311007454, 10.781740761491154, 9.863386496516782, 9.004079552056508, 9.95836243866444, 10.677629116443253, 11.623335754081975, 12.57574483610448, 13.578527713348361, 13.661661466092703, 12.780802410824526, 11.770340851182526, 11.072792451617305, 11.824096947220589, 12.699501202943884, 13.628705375815255, 14.646737145029805, 15.542049480460223, 12.471876352282877, 13.41689631038082, 12.74421392187516, 11.754221950633438, 10.886511795917476, 9.977908695626557, 10.990342131868347, 11.706754460830092, 12.551789193059735, 13.512354520838858, 13.556648168673863, 12.623830034860603, 11.797220162052124, 10.773149545184753, 10.025136910675863, 10.817993574547863, 11.662801392115531, 12.62888023258622, 13.59723628014551, 14.482807604160438, 11.46609456506623, 12.41182257089318, 13.41546874776925, 12.782043607315728, 11.856300051137767, 10.97592650560559, 11.985480691306512, 12.72157213147542, 13.533697815768289, 13.484897200005987, 12.697662642833958, 11.658422420217503, 10.767959517159102, 9.788188074124324, 9.000053631759737, 9.878594986112684, 10.691527767472849, 11.67912845653455, 12.55856827219795, 13.534571189843513, 10.539177140852308, 11.50826047600342, 12.552565912808328, 13.507400973576342, 12.917873205420777, 11.974303060704456, 12.931194173644132, 13.7699568265097, 13.465166597296909, 12.506985537165956, 11.672193633675702, 10.69627588334221, 9.788695258420276, 8.806432395783869, 7.93623944184003, 8.823571293049874, 9.754256672596478, 10.68366125273797, 11.593076090975567, 12.493970417122398, 9.625306239563987, 10.595559261713776, 11.531254525987507, 12.559865544736112, 13.554003779333511, 13.014278045088117, 13.898131282024286, 13.495049764516432, 12.538601534405158, 11.492490927131467, 10.742627804598891, 9.743472769056858, 8.716075138811405, 7.851275115480054, 6.885211572529115, 7.8669375929633, 8.833992246851786, 9.609498226724142, 10.57993331402212, 11.510677633475986, 8.641151686449229, 9.654992016813111, 10.637016319165678, 11.592909959477767, 12.614597588266458, 13.630473540897206, 13.4398986129224, 12.464026480169869, 11.497438657401425, 10.554711708499001, 9.743680248317899, 8.808782214673252, 7.767075321013223, 6.9068673435097185, 5.95777470456146, 6.8657410714621765, 7.801240178710133, 8.673659566705956, 9.617098275525697, 10.643418158678802, 7.7660776925164985, 8.772364207123301, 9.748967566623257, 10.723693317222375, 11.680426559779757, 12.68564437717837, 12.551909750031188, 11.585051149165405, 10.590012899084941, 9.628328704064558, 8.683373574032062, 7.750206810915438, 6.820468776972126, 5.924140286194502, 4.963905391310611, 5.9114151148981975, 6.817363501152745, 7.748640761826271, 8.700986212456046, 9.654979540457617, 6.781523478497798, 7.815726221356194, 8.798593023403207, 9.761028319432736, 10.729654567579503, 11.712953797601124, 11.574352655371348, 10.598268666184238, 9.584506295324662, 8.64336133588484, 7.727311815021968, 6.81087259572526, 5.840264943491936, 4.928092681506027, 4.037815981138472, 4.9435873788326985, 5.854449450059395, 6.805623230984073, 7.749730925064, 8.75848303319197, 5.913147063963487, 6.985860488824395, 7.963884414241269, 8.934534817035996, 9.972319004958054, 10.984650032602497, 10.65362656996429, 9.683381448908662, 8.696390508770392, 7.703338689707325, 6.748210123839722, 5.812719271801214, 4.87869964940379, 3.9711557864936915, 3.011941718147097, 3.92390646271031, 4.877357345049212, 5.838391703326767, 6.795055503025885, 7.825839669351723, 6.977673611838691, 7.926856855889238, 8.941104001469022, 9.889616632789759, 10.938299729743289, 10.856512268576054, 9.877600150971519, 8.824610033282852, 7.760539402511792, 6.818473698971742, 5.835851249175937, 4.871941089306803, 3.875733769752065, 2.899611293322379, 2.017720474710507, 2.966962231342968, 3.9185776453399197, 4.871511466571806, 5.880419984283129, 6.833194025565159, 7.830690646616589, 8.867200966054217, 9.899839469704999, 10.862289539003052, 10.789403654064973, 9.855267704887037, 8.884383663558708, 7.916517910484749, 6.920009135112011, 5.867188270430946, 4.812945489005152, 3.864469437256604, 2.879277275580853, 1.9135129825968646, 0.9958983202099083, 1.990213905476225, 2.9694324822207685, 3.9188023110601, 4.908696280851246, 5.905934586838062, 8.777824039981285, 9.743469017199466, 10.731327500216674, 11.054321941240623, 10.049315381502607, 9.071674740808367, 8.014065887865979, 6.999723270890444, 6.033913798593387, 5.012681523845409, 3.9550849684343303, 2.989737185573631, 2.0146022182920498, 0.9416255009341864, 0.0, 1.0436481630514154, 1.9755626813077232, 2.9484678830556557, 4.02009378627765, 4.946621364789021, 9.706105697476081, 10.669629213957604, 11.696625821981392, 11.609529504810993, 10.557862290145426, 9.613665404097656, 8.639471091131227, 7.679922496610489, 6.723530970626531, 5.762621689180355, 4.810075602176961, 3.87460547232135, 2.9303383349072423, 1.9062179111756934, 0.9267378219806165, 1.875773547087821, 2.8337924203265517, 3.775848922484002, 4.775406313243665, 5.707603987835326, 10.677043946351716, 11.726288571300964, 12.649196550921692, 12.542145702762607, 11.547322961379598, 10.552102082230709, 9.577621986027468, 8.673037807571708, 7.680644159802935, 6.73808643851455, 5.822766205997937, 4.835898416406644, 3.9213668616497355, 2.9353259944317953, 1.9928154228415078, 2.879504317545213, 3.7866661590639388, 4.761069594886, 5.736125972892863, 6.740620754589145, 11.63086983356932, 12.69175324524799, 13.661297843254669, 13.46406356029917, 12.467700941066187, 11.501845816908407, 10.547012566995415, 9.612136643440888, 8.618025637332298, 7.8128359024476115, 6.766011220150011, 5.857999377752131, 4.862576773705585, 3.93537586065171, 3.0041314355595388, 3.843260721722678, 4.850466071476408, 5.7849126816222185, 6.705811378717829, 7.676724463527762, 12.535861199310167, 13.51185144625257, 14.520917995131981, 14.391597749509003, 13.507346616174466, 12.555112434759904, 11.573493897851616, 10.55444334713411, 9.561584610308477, 8.83702136840624, 7.789382128878045, 6.74969658004482, 5.804527865464852, 4.904975565053263, 3.9458784134660876, 4.88022715804656, 5.8650377044124875, 6.855319544310158, 7.677154435178861, 8.621937992765275, 13.528880598604486, 14.461277083951504, 15.412244410511578, 15.394246316049331, 14.471391134200232, 13.486714290350381, 12.522309607889062, 11.565772329598229, 10.59337843821814, 9.814101514160038, 8.749572644432035, 7.7056396816081625, 6.735881911456898, 5.892272274021146, 4.919669270843214, 5.920618787832808, 6.833476996304413, 7.783364328535123, 8.67469960171536, 9.598387579575913, 14.480514369774005, 15.454101270372611, 16.39338646458545, 15.736803060399964, 14.890579398490773, 13.961667488270155, 13.460317448495523, 12.54897121469082, 11.564918085055954, 10.540966159218696, 9.598195391150904, 8.619204430221796, 7.670930223434333, 6.957819318816457, 5.987708518534644, 6.911626831105014, 7.791893039454882, 8.800781081021496, 9.683968047683361, 10.527442158172125, 15.439008732364806, 16.496276052955434, 15.664536097464115, 14.713926961775918, 13.829961414244142, 12.96318609179917, 13.668759572854665, 13.499812090228005, 12.501987034680122, 11.46757051206425, 10.563885843567679, 9.63785411666735, 8.663362111211345, 7.988085754696623, 7.048300626835186, 7.91458472986195, 8.772737315547213, 9.752482014582736, 10.639163645145603, 11.580334056338838, 16.36669436599898, 15.67352766981502, 14.671801647968083, 13.694813563879748, 12.78186175853791, 12.0140415134765, 12.711087032165489, 13.737447487068437, 13.515242325450261, 12.539267792444853, 11.611610956001098, 10.640541494531494, 9.710764395297662, 8.972321433906044, 8.02052278189782, 8.911140166821607, 9.793708073581957, 10.803688064611388, 11.656913740883876, 12.641980919560526], [12.659146879615257, 11.785251429992137, 10.870166825266653, 9.915170275750352, 9.05525242501378, 9.991580306988608, 10.945863193596539, 11.721277279494668, 12.66698391713339, 13.619392999155895, 14.622175876399776, 14.585096419200475, 13.655484424108392, 12.645022864466393, 11.908898856339665, 10.899575861306303, 11.72023794244848, 12.64944211531985, 13.60308898197839, 14.498401317408808, 11.587461122262233, 12.532481080360176, 11.877643436134358, 10.887651464892636, 10.078377724414475, 10.965409450558656, 11.977842886800447, 12.750402623881508, 13.59543735611115, 14.556002683890274, 14.480083121781636, 13.547264987968376, 12.694606365201606, 11.647831558468619, 10.899818923959728, 9.893472488633577, 10.683538131620127, 11.649616972090815, 12.553588117094094, 13.439159441109023, 10.581679335045587, 11.527407340872537, 12.531053517748607, 11.915473121574927, 11.048165979634765, 11.96342726053769, 12.972981446238611, 13.765220294526836, 14.577345978819704, 14.498249741187673, 13.641723854106766, 12.581857373325276, 11.691394470266873, 10.66287008740819, 9.874735645043602, 8.954073900198399, 9.712264506977444, 10.677867622160216, 11.514920109146535, 12.490923026792098, 9.654761910831665, 10.623845245982777, 11.668150682787685, 12.622985743555699, 12.109739133917776, 12.961803815636555, 13.918694928576231, 14.813604989561115, 14.478519138478594, 13.520338078347642, 12.622502252923358, 11.619710836449983, 10.712130211528047, 9.681114409067733, 8.810921455123895, 7.899050207135587, 8.774993412101074, 9.640013089686555, 10.549427927924151, 11.450322254070983, 8.740891009543343, 9.711144031693133, 10.646839295966863, 11.67545031471547, 12.616259687360047, 13.671237923221579, 14.571601604648578, 14.508402305698118, 13.551954075586844, 12.505843468313152, 11.692936423846547, 10.66690772216463, 9.639510091919176, 8.72595712876392, 7.759893585812979, 6.942416507049013, 7.837497688345571, 8.565850063672727, 9.536285150970706, 10.46702947042457, 7.756736456428585, 8.770576786792466, 9.752601089145035, 10.708494729457124, 11.676853496292994, 12.682160946833365, 13.618688195555565, 13.477379021351554, 12.51079119858311, 11.568064249680686, 10.693988867565555, 9.759090833920908, 8.690510274120994, 7.781549356793583, 6.832456717845325, 5.869246512955961, 6.804745620203917, 7.630011403654541, 8.573450112474282, 9.599769995627387, 6.832703848832456, 7.838990363439259, 8.800654972559416, 9.775380723158534, 10.732113965715916, 11.737331783114529, 12.662419734619228, 12.59840369034709, 11.603365440266627, 10.641681245246243, 9.674722585323327, 8.741555822206703, 7.7439037300798965, 6.798822299478367, 5.838587404594476, 4.914920556391982, 5.82086894264653, 6.704992598774856, 7.65733804940463, 8.611331377406202, 5.848149634813756, 6.882352377672152, 7.8502804293393655, 8.812715725368895, 9.781341973515662, 10.764641203537282, 11.700731807473273, 11.611621207365923, 10.597858836506347, 9.656713877066526, 8.740664356203654, 7.802221607016524, 6.831613954783199, 5.871758224538495, 4.912497994422337, 3.947092820326483, 4.857954891553179, 5.761975067932658, 6.706082762012585, 7.714834870140554, 4.869498900912071, 5.942212325772978, 6.920236251189852, 7.8908866539845794, 8.928670841906637, 9.94100186955108, 10.968617334514732, 10.696733990090348, 9.709743049952078, 8.71669123088901, 7.7615626650214065, 6.826071812982899, 5.892052190585475, 4.914821329526159, 3.886623731430962, 2.927411904204094, 3.8808627865429965, 4.794743540275352, 5.751407339974469, 6.7821915063003075, 5.934025448787276, 6.883208692837822, 7.897455838417606, 8.845968469738343, 9.894651566691874, 10.88006599920826, 10.891494465802506, 9.838504348113839, 8.774433717342779, 7.8323680138027285, 6.849745564006923, 5.885835404137789, 4.889628084583051, 3.9135056081533652, 2.9586477697316873, 1.970467672836752, 2.8749294822885045, 3.827863303520391, 4.8367718212317135, 5.7895458625137435, 6.787042483565174, 7.823552803002801, 8.856191306653583, 9.818641375951637, 10.829942112576854, 10.869162019718026, 9.898277978389697, 8.930412225315736, 7.9339034499429975, 6.881082585261932, 5.826839803836138, 4.87836375208759, 3.893171590411839, 2.927407297427851, 1.9880349322363253, 0.993719346970009, 1.9257843191693533, 2.8751541480086846, 3.865048117799831, 4.862286423786647, 7.73417587692987, 8.69982085414805, 9.687679337165259, 10.748742067611678, 11.092963544554024, 10.115322903859784, 9.057714050917395, 8.04337143394186, 7.077561961644804, 6.0563296868968255, 4.998733131485746, 4.033385348625047, 3.0582503813434654, 1.985273663985602, 1.0436481630514154, 0.0, 0.9319145182563079, 1.9048197200042405, 2.9764456232262346, 3.902973201737605, 8.662457534424664, 9.625981050906189, 10.652977658929977, 11.60085390302699, 11.601510453196843, 10.657313567149073, 9.683119254182644, 8.723570659661906, 7.767179133677947, 6.806269852231771, 5.853723765228377, 4.918253635372766, 3.973986497958658, 2.949866074227109, 1.9703859850320318, 1.0676394755848195, 1.9672219345857518, 2.891433692463357, 3.89099108322302, 4.823188757814681, 9.633395783300301, 10.682640408249549, 11.605548387870277, 12.576280420509828, 12.590971124431015, 11.595750245282126, 10.621270149078885, 9.716685970623123, 8.724292322854351, 7.781734601565965, 6.866414369049353, 5.87954657945806, 4.965015024701151, 3.978974157483211, 3.015937924686297, 2.071370246042212, 2.920095673323139, 3.8766543648653546, 4.851710742872218, 5.8562055245685, 10.587221670517906, 11.648105082196574, 12.617649680203254, 13.53607106659562, 13.511349104117606, 12.545493979959824, 11.590660730046832, 10.655784806492303, 9.661673800383713, 8.856484065499027, 7.809659383201426, 6.9016475408035465, 5.906224936757, 4.979024023703126, 3.9916321904916394, 3.0351266502196768, 3.983895585735608, 4.900497451601574, 5.821396148697184, 6.792309233507117, 11.492213036258752, 12.468203283201154, 13.477269832080566, 14.463605255805453, 14.550994779225885, 13.59876059781132, 12.617142060903031, 11.598091510185526, 10.605232773359893, 9.880669531457656, 8.83303029192946, 7.7933447430962355, 6.848176028516267, 5.892476319985364, 4.933379168398188, 4.072093086543559, 4.998467218671688, 5.9709043142895135, 6.792739205158216, 7.737522762744631, 12.48523243555307, 13.41762892090009, 14.368596247460163, 15.314550219973336, 15.017155084934625, 14.530362453401798, 13.565957770940477, 12.609420492649644, 11.637026601269556, 10.857749677211453, 9.79322080748345, 8.749287844659579, 7.779530074508314, 6.879773028953247, 5.907170025775315, 5.112484716329806, 5.966906510563613, 6.898949098514478, 7.790284371694715, 8.71397234955527, 13.43686620672259, 14.410453107321196, 15.349738301534037, 14.75753979990456, 13.966058312576488, 14.797773892992517, 14.503965611546938, 13.592619377742235, 12.608566248107369, 11.584614322270111, 10.64184355420232, 9.662852593273211, 8.714578386485748, 7.945320073748558, 6.975209273466745, 6.1034927596020125, 6.925322553714082, 7.934210595280696, 8.799552817662715, 9.643026928151482, 14.395360569313391, 15.452627889904017, 14.68527283696871, 13.734663701280514, 12.905440328329856, 13.799292496521531, 14.543441586138531, 14.54346025327942, 13.545635197731537, 12.511218675115666, 11.607534006619094, 10.681502279718766, 9.70701027426276, 8.975586509628723, 8.035801381767286, 7.106450658358948, 7.906166829806412, 8.885911528841934, 9.754748415124956, 10.695918826318191, 15.323046202947568, 14.629879506763604, 13.692538387472679, 12.715550303384344, 11.857340672623625, 12.85014791819886, 13.585769045449355, 14.612129500352303, 14.558890488501676, 13.582915955496269, 12.655259119052513, 11.684189657582909, 10.754412558349077, 9.959822188838144, 9.00802353682992, 8.103006095318605, 8.927137587841155, 9.937117578870586, 10.77249851086323, 11.757565689539879], [11.727232361358949, 10.85333691173583, 9.938252307010346, 8.983255757494046, 9.92296993490474, 10.874053768212113, 11.828336654820044, 12.610916603239179, 13.5566232408779, 14.509032322900406, 15.511815200144287, 15.517010937456782, 14.587398942364699, 13.576937382722699, 12.836402084567084, 11.827079089533722, 10.842136207069515, 11.771340379940886, 12.671174463722082, 13.5664867991525, 10.655546604005925, 11.600566562103868, 10.945728917878052, 9.95573694663633, 10.946095234305435, 11.847882911782161, 12.860316348023952, 13.640041947626019, 14.485076679855661, 15.445642007634785, 15.411997640037942, 14.479179506224682, 13.626520883457912, 12.579746076724925, 11.831733442216036, 10.820975716860996, 9.805436396241163, 10.771515236711851, 11.621673598837786, 12.507244922852715, 9.649764816789279, 10.59549282261623, 11.599138999492299, 10.98355860331862, 11.915883489525726, 12.845900721761195, 13.855454907462116, 14.654859618271347, 15.466985302564215, 15.430164259443979, 14.573638372363073, 13.513771891581582, 12.623308988523181, 11.594784605664497, 10.80665016329991, 9.881577128425818, 8.83416277159848, 9.745953103903906, 10.583005590890227, 11.55900850853579, 8.722847392575357, 9.691930727726469, 10.736236164531377, 11.691071225299392, 12.645200698855339, 13.638373831070076, 14.595264944009752, 15.518439424626004, 15.4104336567349, 14.452252596603948, 13.554416771179666, 12.551625354706289, 11.644044729784355, 10.613028927324041, 9.742835973380203, 8.827577056268714, 7.89689167672211, 8.708098571430245, 9.617513409667843, 10.518407735814675, 7.808976491287035, 8.779229513436825, 9.714924777710557, 10.743535796459163, 11.68434516910374, 12.73932340496527, 13.63968708639227, 14.569255345176385, 14.483868593843152, 13.437757986569459, 12.624850942102855, 11.598822240420937, 10.571424610175484, 9.657871647020228, 8.691808104069288, 7.874331025305321, 6.959395952966607, 7.633935545416418, 8.604370632714398, 9.535114952168263, 6.824821938172277, 7.838662268536158, 8.820686570888725, 9.776580211200814, 10.744938978036686, 11.750246428577057, 12.686773677299257, 13.662645810051789, 13.442705716839418, 12.499978767936994, 11.625903385821863, 10.691005352177216, 9.622424792377302, 8.713463875049891, 7.764371236101633, 6.801161031212269, 5.926643884824953, 6.698096885398233, 7.641535594217974, 8.667855477371079, 5.900789330576148, 6.907075845182951, 7.868740454303108, 8.843466204902226, 9.800199447459608, 10.805417264858221, 11.73050521636292, 12.697363817228702, 12.535279958522935, 11.573595763502551, 10.606637103579635, 9.67347034046301, 8.675818248336205, 7.730736817734675, 6.770501922850784, 5.84683507464829, 4.942767207267566, 5.773078080518548, 6.725423531148322, 7.679416859149894, 4.916235116557448, 5.950437859415844, 6.9183659110830575, 7.8808012071125875, 8.849427455259354, 9.832726685280974, 10.768817289216965, 11.744901278404075, 11.529773354762655, 10.588628395322834, 9.672578874459962, 8.734136125272832, 7.763528473039507, 6.803672742794803, 5.844412512678645, 4.879007338582791, 3.979853156174215, 4.83006054967635, 5.774168243756277, 6.782920351884246, 3.9375843826557633, 5.01029780751667, 5.988321732933544, 6.9589721357282714, 7.996756323650329, 9.009087351294772, 10.036702816258424, 11.006947937314052, 10.641657568208384, 9.648605749145318, 8.693477183277714, 7.757986331239207, 6.823966708841783, 5.846735847782467, 4.81853824968727, 3.859326422460402, 3.0027610511640326, 3.862829022019044, 4.819492821718161, 5.8502769880439995, 5.002110930530968, 5.951294174581514, 6.965541320161298, 7.914053951482035, 8.962737048435566, 9.948151480951951, 10.99771362961527, 10.770418866370147, 9.706348235599087, 8.764282532059037, 7.781660082263231, 6.817749922394097, 5.821542602839359, 4.845420126409673, 3.890562287987995, 2.90238219109306, 1.9430149640321968, 2.895948785264083, 3.9048573029754055, 4.8576313442574355, 5.855127965308866, 6.891638284746493, 7.924276788397276, 8.88672685769533, 9.898027594320546, 10.832163543498481, 10.830192496646005, 9.862326743572044, 8.865817968199305, 7.81299710351824, 6.758754322092446, 5.810278270343898, 4.825086108668147, 3.859321815684159, 2.9199494504926333, 1.9256338652263167, 0.9938698009130456, 1.943239629752377, 2.9331335995435235, 3.9303719055303388, 6.802261358673562, 7.767906335891742, 8.75576481890895, 9.81682754935537, 10.821834109093386, 11.04723742211609, 9.989628569173702, 8.975285952198167, 8.00947647990111, 6.988244205153133, 5.9306476497420535, 4.965299866881354, 3.990164899599773, 2.9171881822419095, 1.9755626813077232, 0.9319145182563079, 0.0, 0.9729052017479325, 2.0445311049699266, 2.971058683481297, 7.730543016168357, 8.69406653264988, 9.721063140673667, 10.668939384770681, 11.720606599436248, 11.589228085405379, 10.61503377243895, 9.655485177918212, 8.699093651934254, 7.738184370488078, 6.785638283484684, 5.850168153629073, 4.905901016214965, 3.8817805924834166, 2.9023005032883398, 1.993326289568175, 1.035307416329444, 1.9595191742070488, 2.959076564966712, 3.891274239558373, 8.701481265043993, 9.75072588999324, 10.673633869613967, 11.644365902253519, 12.639188643636528, 12.527664763538432, 11.553184667335191, 10.64860048887943, 9.656206841110658, 8.713649119822273, 7.79832888730566, 6.811461097714367, 5.896929542957459, 4.868613481227722, 3.8984113859098017, 2.9538437072657167, 1.9881811550668311, 2.9447398466090466, 3.9197962246159097, 4.924291006312192, 9.655307152261598, 10.716190563940266, 11.685735161946944, 12.60415654833931, 13.600519167572292, 13.47740849821613, 12.522575248303138, 11.587699324748609, 10.59358831864002, 9.788398583755335, 8.741573901457734, 7.7912868645480575, 6.795864260501511, 5.868663347447637, 4.874105651715144, 3.9176001114431815, 3.0519810674793004, 3.9685829333452656, 4.889481630440876, 5.860394715250809, 10.560298518002444, 11.536288764944846, 12.545355313824258, 13.531690737549143, 14.49193034409514, 14.530675116067627, 13.549056579159338, 12.530006028441832, 11.537147291616199, 10.770308855202167, 9.72266961567397, 8.682984066840746, 7.737815352260778, 6.774949781208869, 5.815852629621693, 4.9545665477670635, 4.0665527004153805, 5.0389897960332055, 5.860824686901908, 6.805608244488323, 11.553317917296763, 12.485714402643781, 13.436681729203855, 14.382635701717028, 15.394949450763244, 15.462276971658104, 14.497872289196783, 13.54133501090595, 12.568941119525862, 11.747389000955964, 10.682860131227962, 9.63892716840409, 8.669169398252825, 7.762246490176752, 6.78964348699882, 5.980202226220767, 5.034991992307306, 5.96703458025817, 6.858369853438407, 7.782057831298962, 12.504951688466281, 13.478538589064888, 14.41782378327773, 13.879438064525596, 14.861987759887143, 15.725277121219936, 15.435880129803245, 14.513988937819754, 13.49820557185188, 12.474253646014622, 11.53148287794683, 10.552491917017722, 9.604217710230259, 8.827793534972063, 7.85768273469025, 6.971210269492973, 5.993408035457775, 7.00229607702439, 7.867638299406407, 8.711112409895174, 13.463446051057083, 14.520713371647709, 13.807171101589747, 12.85656196590155, 13.801369775640511, 14.72679572474895, 15.475356104394837, 15.433099577023931, 14.435274521476048, 13.400857998860177, 12.497173330363605, 11.571141603463277, 10.596649598007271, 9.858059970852228, 8.91827484299079, 7.974168168249909, 6.974252311550105, 7.953997010585627, 8.822833896868648, 9.764004308061883, 14.39113168469126, 13.697964988507296, 12.814436652093715, 11.83744856800538, 12.774055000497242, 13.77765114642628, 14.517683563705662, 15.54404401860861, 15.448529812246187, 14.47255527924078, 13.544898442797024, 12.57382898132742, 11.644051882093589, 10.842295650061649, 9.890496998053425, 8.970723605209566, 7.995223069584849, 9.005203060614278, 9.840583992606922, 10.825651171283571], [10.754327159611016, 9.880431709987896, 9.050906185103237, 9.876618815781168, 10.816332993191862, 11.767416826499236, 12.721699713107167, 13.504279661526303, 14.449986299165026, 15.402395381187532, 16.405178258431413, 16.465191221555887, 15.53521153633484, 14.52474997669284, 13.581393756042607, 12.572070761009245, 11.587127878545038, 10.994714952942413, 11.794760502492348, 12.690072837922767, 9.682641402257993, 10.627661360355935, 10.091071837784012, 10.849100004923452, 11.839458292592557, 12.741245970069285, 13.753679406311075, 14.533405005913142, 15.378439738142786, 16.33900506592191, 16.384902841785877, 15.452084707972617, 14.586290659787311, 13.539515853054324, 12.578565663752721, 11.565967388336519, 10.550428067716686, 9.937056970842002, 10.745259637608052, 11.630830961622982, 8.676859615041346, 9.622587620868297, 10.626233797744366, 11.656724855334147, 12.71165980687263, 13.663845184421012, 14.621553324818144, 15.54822267655847, 16.36034836085134, 16.403069461191908, 15.546543574111007, 14.486677093329517, 13.596214190271114, 12.554554381993896, 11.562425913631287, 10.62656879990134, 9.579154443074003, 8.869539142674173, 9.706591629660494, 10.682594547306056, 7.749942190827424, 8.719025525978536, 9.763330962783444, 10.718166023551458, 11.67229549710741, 12.665468629322147, 13.622359742261823, 14.545534222878075, 15.583826909473464, 15.42515779835188, 14.527321972927599, 13.524530556454224, 12.616949931532288, 11.57279870365344, 10.49861172371158, 9.572568727744237, 8.641883348197632, 7.8316846102005115, 8.74109944843811, 9.641993774584941, 6.8360712895391025, 7.806324311688892, 8.742019575962622, 9.770630594711228, 10.71143996735581, 11.766418203217341, 12.66678188464434, 13.596350143428456, 14.607016620769315, 14.41066318831739, 13.597756143850788, 12.571727442168871, 11.544329811923417, 10.630776848768159, 9.66471330581722, 8.757938853290794, 7.70438762444213, 6.7575215841866845, 7.727956671484663, 8.658700990938529, 5.851916736424344, 6.865757066788225, 7.847781369140793, 8.803675009452881, 9.772033776288756, 10.777341226829128, 11.713868475551328, 12.68974060830386, 13.656328431072303, 13.472883969684926, 12.598808587569795, 11.663910553925149, 10.595329994125235, 9.686369076797824, 8.737276437849566, 7.774066232960202, 6.82210769270022, 5.821682924168499, 6.76512163298824, 7.791441516141347, 4.927884128828216, 5.934170643435019, 6.895835252555177, 7.870561003154294, 8.827294245711679, 9.832512063110292, 10.75760001461499, 11.724458615480772, 12.719496865561236, 12.546500965250482, 11.579542305327568, 10.646375542210944, 9.648723450084137, 8.703642019482608, 7.743407124598717, 6.819740276396223, 5.895716870103999, 4.896664119288816, 5.849009569918589, 6.8030028979201616, 3.9433299148095156, 4.977532657667912, 5.945460709335126, 6.907896005364656, 7.876522253511424, 8.859821483533045, 9.795912087469036, 10.771996076656146, 11.785758447515722, 11.561533597070765, 10.645484076207893, 9.707041327020764, 8.73643367478744, 7.776577944542736, 6.8173177144265775, 5.851912540330724, 4.932802819010648, 3.953646588446618, 4.897754282526545, 5.888684020931217, 2.9646791809078312, 4.037392605768739, 5.015416531185613, 5.98606693398034, 7.023851121902398, 8.03618214954684, 9.063797614510493, 10.034042735566121, 11.021033675704391, 10.62151095089325, 9.666382385025646, 8.730891532987139, 7.796871910589716, 6.8196410495304, 5.791443451435203, 4.832231624208335, 3.9557107140004657, 2.9864150607893114, 3.943078860488429, 4.877371786296067, 4.029205728783035, 4.9783889728335815, 5.992636118413365, 6.941148749734104, 7.989831846687634, 8.97524627920402, 10.024808427867338, 11.0385198275087, 10.67925343734702, 9.73718773380697, 8.754565284011164, 7.79065512414203, 6.794447804587292, 5.818325328157606, 4.863467489735928, 3.8752873928409928, 2.9071230248330973, 2.0195348240343503, 2.995330701807797, 3.8847261425095025, 4.882222763560933, 5.9187330829985605, 6.951371586649343, 7.913821655947398, 8.925122392572614, 9.85925834175055, 10.83014238307888, 10.835231945319977, 9.838723169947238, 8.785902305266173, 7.731659523840379, 6.783183472091831, 5.79799131041608, 4.832227017432092, 3.8928546522405663, 2.8985390669742497, 1.957977861713946, 1.0086080328746145, 1.9985020026657612, 2.957466703782406, 5.829356156925629, 6.795001134143809, 7.782859617161017, 8.843922347607435, 9.848928907345451, 10.786756794155789, 10.962533770921635, 9.9481911539461, 8.982381681649043, 7.9611494069010655, 6.903552851489986, 5.938205068629287, 4.963070101347705, 3.8900933839898424, 2.948467883055656, 1.9048197200042405, 0.9729052017479325, 0.0, 1.0716259032219941, 1.9981534817333646, 6.823512384390908, 7.721161330901946, 8.748157938925734, 9.696034183022748, 10.747701397688314, 11.691898283736084, 11.587938974186883, 10.628390379666145, 9.671998853682187, 8.71108957223601, 7.758543485232617, 6.823073355377006, 5.878806217962898, 4.854685794231349, 3.835725072962502, 2.8866893478552975, 1.9286704746165668, 0.9866139724591163, 1.9861713632187796, 2.9183690378104403, 7.8250673038142615, 8.777820688245306, 9.700728667866034, 10.671460700505586, 11.666283441888595, 12.630334961869137, 12.526089869083124, 11.621505690627362, 10.62911204285859, 9.686554321570206, 8.771234089053593, 7.7843662994623, 6.830318537966424, 5.761976539514846, 4.791774444196925, 3.8472067655528392, 2.881544213353954, 1.9718346448611141, 2.946891022867977, 3.9513858045642594, 8.778893191031866, 9.832712689344328, 10.712829960199011, 11.631251346591377, 12.62761396582436, 13.59346908998214, 13.49548045005107, 12.560604526496542, 11.566493520387954, 10.761303785503268, 9.714479103205667, 8.684649922835181, 7.689227318788634, 6.76202640573476, 5.767468710002267, 4.810963169730305, 3.9453441257664235, 2.995677731597333, 3.916576428692944, 4.887489513502876, 9.68388455677271, 10.659874803715113, 11.657146739395277, 12.55878553580121, 13.519025142347207, 14.54879954254531, 14.521961780907272, 13.502911230189767, 12.510052493364133, 11.663671913489292, 10.616032673961096, 9.576347125127871, 8.631178410547902, 7.668312839495991, 6.709215687908816, 5.847929606054187, 4.959915758702503, 4.0660845942852735, 4.887919485153975, 5.83270304274039, 10.67690395606703, 11.609300441414048, 12.560267767974121, 13.506221740487295, 14.51853548953351, 15.480401398135788, 15.470777490944718, 14.514240212653885, 13.541846321273797, 12.64075205924309, 11.576223189515087, 10.532290226691213, 9.562532456539948, 8.655609548463875, 7.683006545285942, 6.8735652845078885, 5.928355050594429, 4.994129378510238, 5.885464651690474, 6.809152629551029, 11.628537727236548, 12.602124627835154, 13.541409822047996, 14.469014644066752, 15.451710306571067, 16.419770999801326, 16.376493859459686, 15.407351996106877, 14.391568630139004, 13.367616704301746, 12.424845936233954, 11.445854975304846, 10.497580768517382, 9.721156593259186, 8.751045792977372, 7.864573327780095, 6.886771093744898, 6.05659020136753, 6.894733097658474, 7.73820720814724, 12.58703208982735, 13.644299410417975, 13.098683308896316, 13.601553637377073, 14.546361447116034, 15.471787396224471, 16.42316869836498, 16.326462635311056, 15.328637579763171, 14.2942210571473, 13.390536388650728, 12.4645046617504, 11.490012656294395, 10.751423029139351, 9.811637901277914, 8.86753122653703, 7.867615369837227, 7.060298075642012, 7.849928695120715, 8.79109910631395, 13.514717723461526, 12.821551027277563, 12.037811225095242, 12.582440239480903, 13.519046671972765, 14.5226428179018, 15.465496157675803, 16.49185661257875, 16.34189287053331, 15.365918337527903, 14.438261501084147, 13.467192039614545, 12.537414940380712, 11.735658708348772, 10.783860056340549, 9.864086663496687, 8.88858612787197, 8.111504125670663, 8.867678790858989, 9.852745969535638], [9.77270179450827, 8.942553856076795, 9.820395331531667, 10.775391881047968, 11.795992736559072, 12.802555361055862, 13.756838247663794, 14.565516589134528, 15.51122322677325, 16.463632308795756, 17.466415186039637, 17.520829182069296, 16.59084949684825, 15.580387937206252, 14.637031716556018, 13.627708721522657, 12.64276583905845, 12.050352913455825, 11.118558342783, 11.85238102528065, 8.701016037155247, 9.646035995253191, 10.602371306389053, 11.592363277630774, 12.625701622021356, 13.59023709117805, 14.545065981034313, 15.537110685335687, 16.43967666575101, 17.40024199353013, 17.45652874500787, 16.52371061119461, 15.641928620300723, 14.595153813567736, 13.634203624266133, 12.621605348849931, 11.606066028230098, 10.992694931355414, 10.069057477898705, 10.793139148980865, 7.6952342499386015, 8.640962255765553, 9.644608432641622, 10.675099490231403, 11.662242748168424, 12.592219281199016, 13.549927421596148, 14.522293014690359, 15.506520097758052, 16.44829372922245, 16.618169477332998, 15.55830299655151, 14.654368882674238, 13.610192342507307, 12.618063874144699, 11.682206760414752, 10.634792403587415, 9.925177103187584, 9.030389469951146, 9.84490273466394, 6.727214942343517, 7.696298277494629, 8.733416857971864, 9.677873994431765, 10.600669593885414, 11.593842726100151, 12.550733839039827, 13.47390831965608, 14.512201006251468, 15.47038206638242, 15.598947876149593, 14.596156459676216, 13.675104623935411, 12.628436664166852, 11.554249684224992, 10.628206688257649, 9.697521308711044, 8.887322570713923, 8.064897288728762, 8.804301961942825, 5.79577926041941, 6.766032282569199, 7.701727546842931, 8.730338565591536, 9.639814064133814, 10.694792299995346, 11.595155981422344, 12.52472424020646, 13.535390717547319, 14.465208695385197, 14.669382047072782, 13.643353345390864, 12.615955715145411, 11.702402751990155, 10.736339209039215, 9.813576813804206, 8.76002558495554, 7.813159544700096, 7.051754511775315, 7.821009178296412, 4.811430506548033, 5.825270836911915, 6.8072951392644825, 7.763188779576572, 8.70040787306676, 9.705715323607132, 10.642242572329332, 11.618114705081863, 12.584702527850308, 13.527429476752731, 13.67043449079179, 12.735536457147143, 11.66695589734723, 10.757994980019818, 9.80890234107156, 8.845692136182196, 7.877745653213632, 6.877320884681911, 6.088919473278892, 6.823566620619013, 3.8562582256062212, 4.862544740213024, 5.824209349333182, 6.798935099932299, 7.755668342489683, 8.760886159888296, 9.685974111392994, 10.652832712258776, 11.64787096233924, 12.640244871913266, 12.65116820854956, 11.718001445432936, 10.720349353306132, 9.775267922704602, 8.81503302782071, 7.891366179618217, 6.95135483061741, 5.952302079802227, 5.099928046482789, 5.835128002397827, 2.8717040115875205, 3.905906754445917, 4.873834806113131, 5.836270102142661, 6.804896350289429, 7.78819558031105, 8.724286184247042, 9.700370173434152, 10.714132544293728, 11.655277503733549, 11.717109979429889, 10.778667230242757, 9.808059578009432, 8.84820384776473, 7.888943617648572, 6.923538443552718, 5.988440779524059, 5.009284548960029, 4.092387506441492, 4.817058117709223, 1.8930532776858366, 2.965766702546744, 3.943790627963618, 4.914441030758345, 5.952225218680403, 6.964556246324845, 7.992171711288497, 8.962416832344125, 9.949407772482395, 10.942459591545461, 10.738008288247642, 9.802517436209135, 8.868497813811711, 7.891266952752394, 6.863069354657197, 5.903857527430329, 5.011348674513877, 4.042053021302722, 3.133696138945049, 3.805745883074072, 2.957579825561041, 3.906763069611588, 4.921010215191371, 5.869522846512108, 6.918205943465638, 7.903620375982023, 8.953182524645342, 9.966893924286705, 10.93270462686694, 10.808813637028964, 9.826191187233158, 8.862281027364023, 7.866073707809286, 6.8899512313796, 5.935093392957922, 4.946913296062987, 3.9627609853465082, 3.075172784547761, 2.0711807227389145, 2.8131002392875084, 3.8105968603389395, 4.847107179776567, 5.87974568342735, 6.842195752725402, 7.8534964893506185, 8.787632438528554, 9.758516479856883, 10.726382232930844, 10.910349073169233, 9.857528208488167, 8.803285427062374, 7.854809375313825, 6.869617213638074, 5.903852920654086, 4.96448055546256, 3.970164970196244, 3.013615822227357, 2.0642459933880253, 1.0743520235968789, 1.8858408005604117, 4.757730253703635, 5.723375230921815, 6.711233713939023, 7.772296444385442, 8.777303004123459, 9.715130890933793, 10.754541611833007, 11.019817057168096, 10.054007584871039, 9.03277531012306, 7.9751787547119815, 7.009830971851282, 6.0346960045697005, 4.961719287211837, 4.02009378627765, 2.9764456232262346, 2.0445311049699266, 1.0716259032219941, 0.0, 0.9265275785113704, 5.751886481168913, 6.649535427679952, 7.67653203570374, 8.624408279800754, 9.676075494466321, 10.620272380514091, 11.59446669348052, 11.696406590609271, 10.740015064625313, 9.779105783179137, 8.826559696175742, 7.891089566320132, 6.9468224289060245, 5.922702005174475, 4.896962000570727, 3.9479262754635225, 2.989907402224792, 2.0478509000673415, 1.0482935093076784, 1.9536811705995079, 6.804088476199273, 7.706194785023313, 8.62910276464404, 9.599834797283592, 10.5946575386666, 11.558709058647144, 12.53261758837676, 12.689521901570489, 11.697128253801717, 10.754570532513332, 9.839250299996717, 8.852382510405427, 7.891555465574649, 6.823213467123071, 5.85301137180515, 4.908443693161065, 3.942781140962179, 3.0326875871249106, 2.009013168956876, 3.001515207767244, 7.7579143634168775, 8.761086786122336, 9.641204056977017, 10.559625443369383, 11.555988062602365, 12.521843186760147, 13.47667643667314, 13.628620737439668, 12.634509731331079, 11.829319996446394, 10.781948111665024, 9.745886850443409, 8.750464246396861, 7.823263333342986, 6.828705637610492, 5.8722000973385295, 4.925003869133633, 3.9607418195164215, 2.9786985747818426, 3.937618916705861, 8.804077492809215, 9.780067739751617, 10.585520836173282, 11.487159632579216, 12.447399239125213, 13.477173639323315, 14.503157767529341, 14.570927441132891, 13.578068704307258, 12.724908841097516, 11.67726960156932, 10.637584052736095, 9.692415338156128, 8.729549767104215, 7.770452615517041, 6.909166533662412, 5.9395755020697125, 5.017564960539549, 3.9500416312428737, 4.882832445943375, 9.839212143424913, 10.729493377450552, 11.554847074432711, 12.489808199119544, 13.485934621426356, 14.408775494913792, 15.451973477566787, 15.58225642359701, 14.60986253221692, 13.701988986851314, 12.637460117123311, 11.593527154299439, 10.623769384148174, 9.7168464760721, 8.744243472894167, 7.853225027875098, 6.908014793961638, 5.945609744764514, 4.947586797779373, 5.859282032754014, 10.790845914594431, 11.756648624155481, 12.626276446466603, 13.54480029325505, 14.527495955759367, 15.348145096579328, 16.314973783163257, 16.468588923715103, 15.45280555774723, 14.428853631909972, 13.48608286384218, 12.507091902913071, 11.558817696125608, 10.78239352086741, 9.812282720585596, 8.844233071147304, 7.866430837112107, 7.008070567621806, 5.9568552437473725, 6.788336611350225, 11.749340277185233, 12.805276535001795, 13.67254236981544, 14.567676391879097, 15.512484201618058, 16.346626493050316, 17.312469066596613, 17.387699562919284, 16.3898745073714, 15.355457984755526, 14.451773316258954, 13.525741589358626, 12.55124958390262, 11.786561563695978, 10.84677643583454, 9.84719096990424, 8.847275113204438, 7.946916877966594, 6.912050841209614, 7.8528697486481285, 12.67702591081941, 12.145348867568215, 13.093449185608653, 13.638078199994315, 14.574684632486177, 15.578280778415213, 16.521134118189213, 17.54749457309216, 17.40312979814154, 16.42715526513613, 15.499498428692373, 14.52842896722277, 13.598651867988938, 12.770797242905399, 11.818998590897175, 10.843746406863897, 9.868245871239182, 8.880993272099094, 7.929800936947888, 8.914516611869816], [8.8461742159969, 9.66237875042013, 10.700445793370916, 11.638316888261688, 12.707050493931192, 13.637538656236728, 14.59182154284466, 15.476574346506649, 16.42228098414537, 17.374690066167876, 18.377472943411757, 18.326319333934933, 17.396339648713887, 16.385878089071888, 15.442521868421656, 14.433198873388294, 13.448255990924087, 12.855843065321462, 11.88122404818824, 10.925853446769281, 7.7744884586438765, 8.71950841674182, 9.675843727877682, 10.665835699119404, 11.699174043509986, 12.66370951266668, 13.618538402522942, 14.610583106824317, 15.555884329168542, 16.516449656947664, 17.44887923798879, 17.390142792482695, 16.447418772166362, 15.400643965433373, 14.43969377613177, 13.427095500715568, 12.411556180095735, 11.798185083221052, 10.831723183303945, 9.866611570469496, 6.768706671427231, 7.714434677254182, 8.718080854130251, 9.748571911720033, 10.735715169657054, 11.665691702687646, 12.623399843084778, 13.595765436178988, 14.579992519246682, 15.52176615071108, 16.456134460161962, 16.424735177839597, 15.459859034539875, 14.415682494372945, 13.423554026010336, 12.48769691228039, 11.440282555453052, 10.730667255053222, 9.793055175356386, 8.918375156152571, 5.800687363832147, 6.769770698983258, 7.806889279460494, 8.751346415920395, 9.674142015374043, 10.66731514758878, 11.624206260528457, 12.547380741144709, 13.585673427740097, 14.54385448787105, 15.491822198223737, 15.462588640964302, 14.480594775801048, 13.43392681603249, 12.359739836090629, 11.433696840123286, 10.503011460576682, 9.69281272257956, 8.827562994134002, 7.877774383431455, 4.86925168190804, 5.839504704057829, 6.7751999683315605, 7.8038109870801655, 8.713286485622444, 9.768264721483975, 10.668628402910974, 11.59819666169509, 12.608863139035948, 13.538681116873825, 14.562256369146926, 14.50978552667895, 13.482387896433497, 12.543890799324396, 11.577827256373457, 10.619066965669843, 9.565515736821178, 8.618649696565733, 7.8144202171805555, 6.894481599785042, 3.8849029280366634, 4.898743258400545, 5.880767560753113, 6.836661201065202, 7.77388029455539, 8.779187745095761, 9.715714993817961, 10.691587126570493, 11.658174949338937, 12.60090189824136, 13.563308812865934, 13.60196863843523, 12.533388078635316, 11.59948302735406, 10.650390388405802, 9.687120313333377, 8.683235805079267, 7.682811036547546, 6.851585178684132, 5.897039042107642, 2.9297306470948516, 3.9360171617016544, 4.897681770821811, 5.872407521420929, 6.829140763978312, 7.834358581376925, 8.759446532881624, 9.726305133747406, 10.721343383827868, 11.713717293401896, 12.745951705935141, 12.58443362672102, 11.586781534594218, 10.641700103992688, 9.681465209108797, 8.757798360906301, 7.756844982483045, 6.757792231667862, 5.862593751888029, 4.9086004238864565, 1.9451764330761505, 2.979379175934547, 3.947307227601761, 4.909742523631291, 5.878368771778058, 6.861668001799679, 7.797758605735671, 8.773842594922781, 9.787604965782357, 10.728749925222179, 11.735636423419251, 11.645099411530841, 10.674491759297517, 9.714636029052814, 8.755375798936658, 7.789970624840803, 6.793930931389695, 5.814774700825664, 4.8717281358026785, 3.8905305391978526, 0.9665256991744664, 2.0392391240353733, 3.0172630494522474, 3.987913452246975, 5.0256976401690325, 6.0380286678134745, 7.065644132777127, 8.035889253832755, 9.022880193971025, 10.015932013034092, 10.971060578901696, 10.66894961749722, 9.734929995099796, 8.757699134040479, 7.729501535945283, 6.770289708718415, 5.816838826379512, 4.847543173168358, 3.9130367683062355, 2.879218304562702, 2.031052247049671, 2.980235491100218, 3.9944826366800017, 4.942995268000738, 5.991678364954268, 6.977092797470653, 8.026654946133972, 9.040366345775334, 10.00617704835557, 10.94824275189562, 10.752718765744529, 9.788808605875396, 8.792601286320656, 7.81647880989097, 6.861620971469293, 5.873440874574357, 4.8335967576452825, 3.8806629364133967, 2.871754418702074, 1.8865726607761384, 2.8840692818275695, 3.9205796012651972, 4.95321810491598, 5.915668174214032, 6.926968910839248, 7.861104860017184, 8.831988901345513, 9.799854654419473, 10.796363429792212, 10.784055786999538, 9.729813005573744, 8.781336953825196, 7.796144792149445, 6.830380499165456, 5.891008133973931, 4.896692548707614, 3.9401434007387275, 2.9907735718993957, 2.0008796021082493, 0.9593132220490415, 3.831202675192264, 4.796847652410444, 5.784706135427652, 6.845768865874072, 7.850775425612087, 8.788603312422422, 9.828014033321637, 10.772929211485888, 10.98053516338241, 9.959302888634431, 8.901706333223352, 7.936358550362653, 6.961223583081071, 5.888246865723207, 4.946621364789021, 3.902973201737605, 2.971058683481297, 1.9981534817333646, 0.9265275785113704, 0.0, 4.825358902657543, 5.723007849168582, 6.75000445719237, 7.6978807012893835, 8.749547915954949, 9.693744802002719, 10.667939114969148, 11.627487709489886, 11.651072821997435, 10.690163540551259, 9.737617453547864, 8.802147323692253, 7.857880186278145, 6.833759762546595, 5.808019757942847, 4.858984032835642, 3.9009651595969115, 2.958908657439461, 1.959351266679798, 1.0271535920881374, 5.877560897687903, 6.7796672065119425, 7.70257518613267, 8.673307218772221, 9.66812996015523, 10.632181480135772, 11.606090009865389, 12.617414012871222, 12.608186011173839, 11.665628289885454, 10.750308057368839, 9.763440267777547, 8.80261322294677, 7.734271224495191, 6.76406912917727, 5.819501450533185, 4.853838898334299, 3.9437453444970307, 2.9200709263289957, 2.0749876292558733, 6.831386784905507, 7.8345592076109645, 8.714676478465647, 9.633097864858012, 10.629460484090995, 11.595315608248775, 12.550148858161768, 13.523506700325248, 13.545567488703202, 12.740377753818516, 11.693005869037144, 10.656944607815529, 9.661522003768981, 8.734321090715106, 7.739763394982612, 6.78325785471065, 5.836061626505753, 4.871799576888542, 3.8897563321539623, 3.0110913381944906, 7.877549914297845, 8.853540161240247, 9.658993257661912, 10.560632054067845, 11.520871660613842, 12.550646060811946, 13.576630189017969, 14.507356407180866, 14.489126461679382, 13.635966598469636, 12.58832735894144, 11.548641810108215, 10.603473095528248, 9.640607524476335, 8.68151037288916, 7.820224291034532, 6.850633259441833, 5.9286227179116695, 4.861099388614994, 3.9563048674320047, 8.912684564913544, 9.802965798939182, 10.62831949592134, 11.563280620608174, 12.559407042914986, 13.482247916402423, 14.525445899055415, 15.484630130272631, 15.520920289589045, 14.613046744223434, 13.548517874495431, 12.504584911671559, 11.534827141520294, 10.62790423344422, 9.655301230266288, 8.764282785247218, 7.8190725513337584, 6.856667502136634, 5.858644555151493, 4.932754454242644, 9.864318336083063, 10.83012104564411, 11.699748867955233, 12.61827271474368, 13.600968377247996, 14.42161751806796, 15.388446204651888, 16.3575880680047, 16.36386331511935, 15.339911389282092, 14.3971406212143, 13.418149660285192, 12.469875453497728, 11.69345127823953, 10.723340477957716, 9.755290828519424, 8.777488594484227, 7.909322750020104, 6.84836402193506, 5.861809032838854, 10.822812698673864, 11.878748956490425, 12.74601479130407, 13.641148813367726, 14.585956623106688, 15.420098914538945, 16.385941488085244, 17.355432738013135, 17.300932264743516, 16.266515742127645, 15.362831073631074, 14.436799346730746, 13.462307341274741, 12.697619321068098, 11.75783419320666, 10.75824872727636, 9.758332870576558, 8.838425656154282, 7.803559619397301, 6.926342170136758, 11.750498332308041, 12.703866629140725, 13.713962386488198, 14.443568351859952, 15.380174784351814, 16.369243492861614, 17.32662427005485, 18.320692834437715, 18.314187555513655, 17.33821302250825, 16.410556186064493, 15.43948672459489, 14.509709625361058, 13.681855000277519, 12.730056348269295, 11.754804164236017, 10.779303628611302, 9.77250205028678, 8.821309715135575, 7.987989033358446], [11.842957209348581, 12.65916174377181, 13.697228786722595, 14.635099881613368, 15.582102341862768, 16.491012273821458, 17.44529516042939, 18.462363709504622, 18.296939326876156, 17.446971412218055, 16.455627763772252, 15.412027099601275, 14.48204741438023, 13.47158585473823, 12.528229634087996, 11.518906639054634, 10.533963756590428, 9.905954037663072, 8.887485665874664, 7.929545720416558, 10.771271451995558, 11.7162914100935, 12.672626721229362, 13.662618692471083, 14.558977042462073, 15.517183130251409, 16.472012020107673, 17.464056724409048, 17.368485887898398, 16.407920560119276, 15.475490979078149, 14.542672845264889, 13.533126537832702, 12.486351731099715, 11.52540154179811, 10.512803266381908, 9.497263945762075, 8.883892848887392, 7.888815308390202, 6.923703695555754, 9.765489664778912, 10.711217670605862, 11.714863847481931, 12.665662965746375, 13.589188787241783, 14.519165320272375, 15.476873460669507, 16.44923905376372, 16.569425511630687, 15.57150002085416, 14.63713171140328, 13.577265230621789, 12.545566800206217, 11.501390260039287, 10.509261791676678, 9.57340467794673, 8.525990321119393, 7.816375020719562, 6.850147300442643, 5.975467281238828, 8.797470357183826, 9.766553692334938, 10.717792737685794, 11.651044142539421, 12.527615632958772, 13.52078876517351, 14.477679878113186, 15.400854358729438, 15.574110793714572, 14.61592973358362, 13.629762375649895, 12.615118693746496, 11.56630254146739, 10.519634581698831, 9.445447601756971, 8.519404605789626, 7.588719226243022, 6.778520488245901, 5.884655119220259, 4.934866508517713, 7.866034675259719, 8.836287697409508, 9.68610342655686, 10.703508713699192, 11.566760103207173, 12.621738339068704, 13.522102020495703, 14.451670279279819, 14.647545730822822, 13.60143512354913, 12.700196546573084, 11.674167844891166, 10.646770214645713, 9.629598564990737, 8.663535022039797, 7.704774731336184, 6.651223502487519, 5.704357462232074, 4.871512342266813, 3.9515737248712997, 6.881685921388343, 7.893079539214784, 8.746355134776772, 9.702248775088862, 10.62735391214012, 11.63266136268049, 12.56918861140269, 13.545060744155222, 13.606382853819088, 12.663655904916665, 11.701248990292092, 10.766350956647445, 9.697770396847531, 8.6851907930204, 7.736098154072143, 6.772828078999718, 5.768943570745609, 4.7685188022138885, 3.90867730377039, 2.9541311671939, 5.92651364044653, 6.833888800410397, 7.751155388406541, 8.72588113900566, 9.682614381563042, 10.687832198961654, 11.612920150466353, 12.579778751332135, 12.808708444876665, 11.783132095988556, 10.75089768345531, 9.817730920338686, 8.765904725631298, 7.820823295029768, 6.860588400145876, 5.895373857043829, 4.865733221393713, 3.8434999973342046, 2.919685876974287, 1.9656925489727146, 4.94195942642783, 5.87725081464329, 6.800780845186491, 7.763216141216021, 8.731842389362788, 9.715141619384408, 10.651232223320399, 11.627316212507509, 11.803201841116385, 10.862056881676564, 9.855170383479491, 8.878396705148507, 7.907789052915182, 6.947933322670478, 5.986919362425558, 4.935803108531598, 3.902819170300362, 2.900482466492007, 1.9563747724120806, 0.9476226642841112, 3.963308692526146, 4.906571544652264, 5.870736667036978, 6.794009282948132, 7.831793470870189, 8.844124498514631, 9.840745403727576, 10.810990524783204, 11.712730759799449, 11.579739856384286, 10.624611290516683, 9.689120438478176, 8.755100816080752, 7.777869955021435, 6.749672356926238, 5.79046052969937, 4.837009647360468, 3.8677139941493137, 2.915066139908524, 1.9461405980948412, 2.894343995005956, 3.843527239056503, 4.857774384636286, 5.8389274671943685, 6.8344750389439195, 7.819889471460304, 8.86863836828963, 9.816184916038319, 10.729433905414904, 11.671499608954955, 11.557812906681331, 10.713319882472954, 9.7051431944777, 8.729020718048014, 7.735584857961648, 6.747404761066712, 5.787528052136161, 4.834594230904275, 3.923967999807341, 2.938786241881405, 1.9502069966459072, 2.9703402530326235, 3.812050049296495, 4.882604363502299, 5.899184493058939, 6.833320442236875, 7.804204483565203, 8.772070236639163, 9.768579012011902, 10.78317229706154, 11.68115004716417, 11.608797492051036, 10.623605330375284, 9.657841037391297, 8.718468672199771, 7.724153086933455, 6.736673215255312, 5.845521022064011, 4.920796698949377, 3.8660456806085017, 0.994156227465279, 1.8964750631217953, 2.884333546139003, 3.926430168108684, 4.9314367278467, 5.90907736854094, 6.915107974976153, 7.929450591951687, 8.888353113131737, 9.826714310851704, 10.735199974710309, 11.616190648077085, 11.621312462257729, 10.629728519053975, 9.70610569747608, 8.662457534424664, 7.730543016168357, 6.823512384390908, 5.751886481168913, 4.825358902657543, 0.0, 0.9703148663636577, 1.9973114743874465, 2.9451877184844606, 3.996854933150027, 4.9410518191977975, 5.915246132164227, 6.874794726684966, 7.831186252668924, 8.7920955341151, 9.744641621118495, 10.680111750974106, 11.624378888388215, 11.594320929295481, 10.632843519456696, 9.684342935493184, 8.726324062254454, 7.784267560097004, 6.784710169337341, 5.85251249474568, 1.0522019950303598, 2.0269742237070183, 2.9498822033277463, 3.9206142359672986, 4.915436977350308, 5.87948849733085, 6.853397027060467, 7.864721030066301, 8.788299441845327, 9.767560283449296, 10.697411296666395, 11.6414046950594, 12.615407415130708, 12.559630127152731, 11.58942803183481, 10.644860353190726, 9.67919780099184, 8.769104247154573, 7.745429828986539, 6.900346531913416, 2.0060278822479645, 3.0669112939266334, 3.961983495660723, 4.8804048820530905, 5.876767501286074, 6.842622625443855, 7.797455875356847, 8.770813717520328, 9.725680919374689, 10.753041681783298, 11.64065631081847, 12.676717572040085, 13.656072405529109, 13.559679993372646, 12.565122297640153, 11.60861675736819, 10.661420529163294, 9.697158479546083, 8.715115234811504, 7.836450240852034, 3.0521910116403026, 4.0281812585827055, 4.906300274856989, 5.807939071262923, 6.76817867780892, 7.797953078007023, 8.823937206213047, 9.754663424375947, 10.669239892350868, 11.614289184123813, 12.661928423652009, 13.701613972485234, 14.598023497288375, 14.465966427133877, 13.506869275546702, 12.645583193692072, 11.675992162099373, 10.75398162056921, 9.686458291272535, 8.781663770089548, 4.0960022515649435, 4.9776068962816415, 5.875626513116417, 6.810587637803251, 7.806714060110064, 8.7295549335975, 9.772752916250493, 10.73193714746771, 11.701033720260531, 12.59136932987761, 13.665442082863102, 14.709375045686976, 15.529377543280422, 15.45326313610176, 14.480660132923829, 13.58964168790476, 12.644431453991299, 11.682026404794174, 10.684003457809034, 9.738259918460221, 5.047636022734462, 6.004762142986571, 6.944047337199412, 7.865579731938757, 8.848275394443073, 9.668924535263036, 10.635753221846965, 11.604895085199775, 12.620678451167649, 13.613356731715214, 14.556127499783006, 15.535118460712114, 16.464425855257858, 16.51881018089707, 15.548699380615258, 14.580649731176965, 13.602847497141767, 12.714828214237683, 11.653869486152638, 10.667314497056433, 6.017587861275851, 7.053390053832885, 7.990313260548248, 8.888455830562803, 9.833263640301764, 10.667405931734022, 11.63324850528032, 12.602739755208212, 13.600564810756095, 14.539961084560769, 15.518960335686321, 16.44499206258665, 17.45685774303487, 17.52297822372564, 16.583193095864203, 15.583607629933901, 14.583691773234097, 13.64393112037186, 12.60906508361488, 11.731847634354336, 6.945273494910027, 7.89864179174271, 8.908737549090183, 9.890855156061525, 10.827461588553387, 11.616550510056692, 12.586196032266233, 13.56799985163279, 14.562970277021098, 15.592616363363282, 16.56668544811974, 17.447679440450795, 18.378600699578556, 18.426367695988365, 17.474569043980143, 16.534348671557943, 15.594952663691764, 14.578007514504359, 13.626815179353153, 12.793494497576024], [12.74060615585962, 12.087332861424224, 12.890955009288936, 13.722721117857464, 14.638857648149285, 15.547767580107974, 16.502050466715907, 17.51911901579114, 17.460158833637617, 16.557945783008414, 15.514882835236483, 14.471282171065507, 13.541302485844462, 12.530840926202462, 11.587484705552228, 10.831625605904499, 9.93256672303118, 9.126975298089393, 8.188417515770686, 8.899860586780214, 11.668920398506597, 11.144462527745915, 11.85078935660816, 12.75023992871518, 13.61573234874859, 14.573938436537926, 15.528767326394188, 16.520812030695563, 17.46611325303979, 17.374361317151994, 16.441931736110867, 15.509113602297607, 14.50344140419636, 13.456666597463373, 12.495716408161769, 11.483118132745567, 10.467578812125733, 9.85420771525105, 8.85913017475386, 7.894018561919412, 10.66313861128995, 10.139388788258277, 10.784473431839508, 11.72241827203289, 12.6459440935283, 13.575920626558892, 14.533628766956024, 15.505994360050234, 16.490221443117928, 16.541814887217818, 15.607446577766938, 14.547580096985447, 13.515881666569875, 12.471705126402945, 11.479576658040337, 10.543719544310388, 9.49630518748305, 8.78668988708322, 7.820462166806301, 6.945782147602486, 9.695119303694865, 9.076587443425273, 9.77454804397231, 10.707799448825936, 11.58437093924529, 12.577544071460027, 13.534435184399703, 14.457609665015955, 15.495902351611344, 15.586244599947278, 14.600077242013553, 13.585433560110154, 12.536617407831049, 11.48994944806249, 10.41576246812063, 9.489719472153284, 8.55903409260668, 7.748835354609559, 6.854969985583917, 5.905181374881371, 8.763683621770758, 8.065596118588605, 8.742858732843375, 9.760264019985707, 10.62351540949369, 11.678493645355221, 12.57885732678222, 13.508425585566336, 14.519092062907195, 14.571749989912789, 13.670511412936742, 12.644482711254824, 11.617085081009371, 10.599913431354393, 9.633849888403454, 8.675089597699841, 7.621538368851177, 6.674672328595732, 5.841827208630471, 4.921888591234958, 7.779334867899381, 7.062148556486129, 7.803110441063288, 8.759004081375377, 9.684109218426636, 10.689416668967008, 11.625943917689208, 12.60181605044174, 13.568403873210183, 13.633970771280323, 12.67156385665575, 11.736665823011103, 10.66808526321119, 9.655505659384058, 8.7064130204358, 7.743142945363377, 6.739258437109267, 5.738833668577547, 4.8789921701340475, 3.924446033557558, 6.82416258695757, 6.002957817681741, 6.807910694693057, 7.782636445292175, 8.739369687849559, 9.744587505248171, 10.66967545675287, 11.636534057618652, 12.631572307699116, 12.75344696235221, 11.721212549818965, 10.788045786702341, 9.736219591994955, 8.791138161393425, 7.830903266509534, 6.865688723407486, 5.83604808775737, 4.813814863697862, 3.8900007433379447, 2.9360074153363724, 5.839608372938869, 5.0463198319146345, 5.857536151473007, 6.819971447502537, 7.788597695649305, 8.771896925670925, 9.707987529606916, 10.684071518794026, 11.697833889653602, 11.832371748040218, 10.825485249843146, 9.848711571512162, 8.878103919278837, 7.918248189034134, 6.957234228789215, 5.906117974895255, 4.87313403666402, 3.8707973328556653, 2.9266896387757386, 1.917937530647769, 4.860957639037185, 4.075640561923609, 4.927491973323494, 5.840044219105698, 6.8778284070277556, 7.8901594346721975, 8.87043053736392, 9.840675658419547, 10.742415893435792, 11.729390530785222, 11.5911691044159, 10.655678252377394, 9.72165862997997, 8.744427768920653, 7.716230170825456, 6.757018343598588, 5.803567461259686, 4.834271808048531, 3.877608008349414, 2.8437895446058805, 3.791992941516995, 3.012596256327848, 3.914529690922802, 4.884962403351935, 5.864160172580263, 6.849574605096648, 7.898323501925974, 8.845870049674662, 9.759119039051248, 10.701184742591298, 11.683807192387103, 11.679877696372172, 10.671701008376917, 9.695578531947232, 8.702142671860866, 7.71396257496593, 6.754085866035378, 5.801152044803493, 4.82161694631838, 3.836435188392444, 2.8478559431569463, 2.0000253866689657, 2.841735182932837, 3.912289497138641, 4.928869626695283, 5.863005575873219, 6.833889617201547, 7.801755370275506, 8.798264145648245, 9.812857430697882, 10.710835180800512, 11.634686594445714, 11.590163144274502, 10.624398851290515, 9.68502648609899, 8.690710900832674, 7.70323102915453, 6.808339615251562, 5.818445645460415, 4.763694627119541, 1.8918051739763182, 0.9261601967581375, 1.9140186797753453, 2.9561153017450263, 3.9611218614830426, 4.938762502177283, 5.944793108612495, 6.959135725588029, 7.918038246768079, 8.856399444488046, 9.76488510834665, 10.645875781713427, 11.621010748995008, 11.596286332953193, 10.669629213957602, 9.625981050906187, 8.69406653264988, 7.721161330901947, 6.649535427679953, 5.7230078491685825, 0.9703148663636577, 0.0, 1.0269966080237887, 1.9748728521208028, 3.026540066786369, 3.970736952834139, 4.944931265800569, 5.904479860321308, 6.8608713863052655, 7.821780667751442, 8.774326754754837, 9.709796884610448, 10.654064022024556, 11.678184445756106, 11.531027607111431, 10.581991882004226, 9.623973008765496, 8.681916506608045, 7.6823591158483815, 6.75016144125672, 2.0225168613940174, 1.0566593573433607, 1.9795673369640885, 2.9502993696036404, 3.94512211098665, 4.909173630967191, 5.883082160696809, 6.894406163702643, 7.8179845754816695, 8.797245417085637, 9.727096430302737, 10.671089828695742, 11.64509254876705, 12.707292529012207, 12.487076978345854, 11.54250929970177, 10.576846747502884, 9.666753193665613, 8.643078775497578, 7.797995478424457, 2.976342748611622, 2.111551358442383, 2.991668629297066, 3.9100900156894323, 4.906452634922416, 5.872307759080197, 6.8271410089931885, 7.80049885115667, 8.755366053011032, 9.78272681541964, 10.670341444454811, 11.706402705676426, 12.68575753916545, 13.612958452219326, 13.462771244151197, 12.506265703879235, 11.559069475674335, 10.594807426057123, 9.612764181322545, 8.734099187363075, 4.02250587800396, 3.1666969284947983, 3.9359854084933317, 4.837624204899265, 5.797863811445262, 6.8276382116433645, 7.853622339849389, 8.784348558012288, 9.698925025987212, 10.643974317760156, 11.691613557288353, 12.731299106121577, 13.627708630924717, 14.659419079194938, 14.404518222057746, 13.543232140203116, 12.573641108610413, 11.65163056708025, 10.584107237783575, 9.679312716600588, 5.0663171179286, 4.116122566193734, 4.905311646752761, 5.840272771439593, 6.836399193746406, 7.759240067233842, 8.802438049886835, 9.761622281104051, 10.730718853896875, 11.621054463513953, 12.695127216499444, 13.739060179323317, 14.559062676916763, 15.490656785173652, 15.378309079434873, 14.4872906344158, 13.54208040050234, 12.579675351305214, 11.581652404320074, 10.63590886497126, 6.017950889098119, 5.143277812898664, 5.976741018786654, 6.895264865575099, 7.877960528079414, 8.698609668899378, 9.665438355483307, 10.634580218836117, 11.65036358480399, 12.643041865351558, 13.58581263341935, 14.564803594348458, 15.494110988894198, 16.47974826357206, 16.4463483271263, 15.478298677688006, 14.500496443652807, 13.612477160748721, 12.551518432663677, 11.564963443567471, 6.987902727639508, 6.191905723744977, 7.02300694213549, 7.918140964199145, 8.862948773938106, 9.697091065370364, 10.662933638916662, 11.632424888844554, 12.630249944392437, 13.569646218197112, 14.548645469322665, 15.474677196222993, 16.48654287667121, 17.430358581339235, 17.480842042375244, 16.48125657644494, 15.481340719745138, 14.541580066882899, 13.506714030125918, 12.629496580865375, 7.9155883612736835, 7.161626990985472, 8.083879025936564, 8.937254362095315, 9.873860794587177, 10.646235643693034, 11.615881165902575, 12.597684985269131, 13.59265541065744, 14.622301496999624, 15.596370581756084, 16.477364574087137, 17.408285833214897, 17.483123002274883, 16.53132435026666, 15.59110397784446, 14.710753805766661, 13.83035706872151, 13.100085780553133, 13.691143444087063], [13.69913844544206, 12.773699632039028, 11.964363901375238, 12.796130009943766, 13.708814166367677, 14.617724098326367, 15.572006984934298, 16.58907553400953, 16.43316222561383, 15.530949174984627, 14.487886227212696, 13.44428556304172, 12.514305877820675, 11.503844318178675, 10.560488097528442, 9.804628997880709, 8.905570115007391, 8.099978690065605, 8.901577314865998, 9.676964257261595, 12.627452688089036, 11.830829298360719, 10.924198248694463, 11.823648820801482, 12.685688866966983, 13.643894954756318, 14.59872384461258, 15.588747184534343, 16.53404840687857, 16.347364709128207, 15.41493512808708, 14.48211699427382, 13.508662943422296, 12.501035624176449, 11.608143638469883, 10.810732370553435, 9.942269925835744, 9.157636672166015, 9.787936519688582, 8.721207526325257, 11.62167090087239, 10.82575555887308, 9.85788232392581, 10.795827164119192, 11.715900611746692, 12.645877144777284, 13.603585285174416, 14.573929513889015, 15.558156596956708, 16.483952433060093, 16.441568850894647, 15.44752460891692, 14.535581656226967, 13.485997095236877, 12.506573266064123, 11.570716152334176, 10.523301795506839, 9.813686495107008, 8.818972381901482, 7.821824039522572, 10.653651593277305, 9.762954214040077, 8.847956936058612, 9.781208340912238, 10.654327457463681, 11.647500589678419, 12.604391702618095, 13.525544818854735, 14.563837505450124, 15.506040770220064, 15.627073850037341, 14.61243016813394, 13.563614015854835, 12.516946056086276, 11.442759076144416, 10.516716080177073, 9.586030700630468, 8.775831962633347, 7.856991751714258, 6.878330969892068, 9.722215911353198, 8.751962889203408, 7.816267624929678, 8.833672912072009, 9.693471927712082, 10.748450163573613, 11.646792480621, 12.576360739405116, 13.587027216745975, 14.491546160185575, 14.69750802096053, 13.671479319278614, 12.64408168903316, 11.626910039378183, 10.660846496427244, 9.70208620572363, 8.648534976874965, 7.70166893661952, 6.849973481579404, 5.919229162125539, 8.806331475923171, 7.8585436355021585, 6.876519333149591, 7.83241297346168, 8.754065736645028, 9.7593731871854, 10.693879071527988, 11.66975120428052, 12.636339027048964, 13.553766941553109, 13.698560464679538, 12.763662431034891, 11.695081871234978, 10.682502267407846, 9.733409628459588, 8.770139553387164, 7.766255045133056, 6.765830276601335, 5.905988778157836, 4.940862907050348, 7.85115919498136, 6.870449831373428, 5.88131958677936, 6.856045337378477, 7.809326206067951, 8.814544023466564, 9.73761061059165, 10.704469211457432, 11.699507461537895, 12.627383937118665, 12.748209157842753, 11.81504239472613, 10.763216200018743, 9.818134769417213, 8.857899874533322, 7.892685331431275, 6.863044695781158, 5.840811471721651, 4.916997351361733, 3.963004023360161, 6.866604980962659, 5.913811845606321, 4.930945043559309, 5.889927965720929, 6.858554213867697, 7.798993616828528, 8.73508422076452, 9.71116820995163, 10.724930580811206, 11.642416568938948, 11.852481857866934, 10.87570817953595, 9.905100527302626, 8.945244797057923, 7.984230836813003, 6.9331145829190435, 5.900130644687808, 4.8977939408794535, 3.953686246799527, 2.9449341386715577, 5.887954247060975, 4.97892479082667, 4.000900865409796, 4.905036266197723, 5.8540637244364175, 6.8663947520808595, 7.843433929340129, 8.813679050395757, 9.715419285412002, 10.702393922761432, 11.590012200527962, 11.682674860401182, 10.748655238003758, 9.771424376944442, 8.743226778849245, 7.784014951622377, 6.830564069283475, 5.8612684160723205, 4.904604616373203, 3.870786152629669, 4.818989549540785, 3.9603534483288048, 2.9879385830091043, 3.94995445044396, 4.837163564556474, 5.822577997072859, 6.871326893902184, 7.818873441650874, 8.732122431027458, 9.674188134567508, 10.656810584363313, 11.615161638472124, 11.698697616400706, 10.72257513997102, 9.729139279884654, 8.74095918298972, 7.7810824740591675, 6.828148652827282, 5.848613554342169, 4.863431796416233, 3.8748525511807355, 2.947782578669922, 1.915144075019139, 2.9772815442306664, 3.9018730186714934, 4.83600896784943, 5.806893009177758, 6.774758762251717, 7.771267537624455, 8.785860822674094, 9.683838572776722, 10.607689986421924, 11.591721272853663, 11.651395459314305, 10.71202309412278, 9.717707508856464, 8.730227637178318, 7.835336223275351, 6.8454422534842045, 5.7906912351433295, 2.918801782000107, 1.9531568047819263, 0.9874275718616473, 1.9291186937212377, 2.9341252534592535, 3.911765894153494, 4.917796500588706, 5.9321391175642395, 6.891041638744289, 7.829402836464258, 8.73788850032286, 9.618879173689637, 10.594014140971218, 11.615780247973822, 11.696625821981392, 10.652977658929977, 9.72106314067367, 8.748157938925736, 7.676532035703741, 6.750004457192371, 1.9973114743874465, 1.0269966080237887, 0.0, 0.947876244097014, 1.9995434587625804, 2.9437403448103505, 3.9179346577767795, 4.877483252297519, 5.833874778281476, 6.794784059727653, 7.747330146731047, 8.682800276586658, 9.627067414000766, 10.651187837732316, 11.676927842336065, 11.608988490028015, 10.650969616789284, 9.708913114631834, 8.70935572387217, 7.777158049280509, 2.959977166090229, 1.898741318556159, 0.9525707289402999, 1.9233027615798517, 2.9181255029628614, 3.882177022943403, 4.85608555267302, 5.867409555678853, 6.79098796745788, 7.770248809061847, 8.700099822278947, 9.644093220671952, 10.61809594074326, 11.680295920988417, 12.650498016306338, 12.569505907725556, 11.60384335552667, 10.693749801689403, 9.670075383521368, 8.824992086448244, 3.9138030533078334, 2.9536333196551814, 1.9646720212732771, 2.883093407665643, 3.8794560268986267, 4.845311151056408, 5.800144400969399, 6.773502243132881, 7.728369444987243, 8.755730207395851, 9.643344836431021, 10.679406097652636, 11.65876093114166, 12.585961844195536, 13.643405764460947, 13.533262311903021, 12.586066083698125, 11.621804034080913, 10.639760789346335, 9.761095795386861, 4.894045596291358, 3.9180553493489554, 2.908988800469543, 3.8106275968754755, 4.7708672034214725, 5.800641603619575, 6.8266257318256, 7.7573519499885, 8.671928417963423, 9.616977709736368, 10.664616949264564, 11.704302498097789, 12.600712022900927, 13.632422471171148, 14.585152742367496, 14.570228748226903, 13.600637716634203, 12.67862717510404, 11.611103845807365, 10.706309324624375, 5.84342078840998, 4.829282365289046, 3.8783150387289718, 4.813276163415804, 5.809402585722617, 6.7322434592100535, 7.7754414418630455, 8.734625673080261, 9.703722245873086, 10.594057855490165, 11.668130608475657, 12.712063571299531, 13.532066068892973, 14.463660177149862, 15.436263180327794, 15.51428724243959, 14.56907700852613, 13.606671959329004, 12.608649012343864, 11.5944411545537, 6.795054559579499, 5.856437611993976, 4.9497444107628645, 5.86826825755131, 6.850963920055625, 7.67161306087559, 8.638441747459519, 9.607583610812327, 10.6233669767802, 11.61604525732777, 12.558816025395561, 13.53780698632467, 14.467114380870408, 15.452751655548271, 16.504302428019223, 16.505295285711796, 15.527493051676597, 14.571009450331161, 13.510050722246117, 12.523495733149911, 7.765006398120888, 6.905065522840289, 5.996010334111702, 6.891144356175356, 7.835952165914317, 8.670094457346575, 9.635937030892874, 10.605428280820766, 11.603253336368649, 12.542649610173324, 13.521648861298877, 14.447680588199205, 15.45954626864742, 16.403361973315445, 16.57350302354769, 15.657615933022509, 14.805133455887708, 13.954972010836464, 14.465246319708358, 13.588028870447815, 8.692692031755064, 7.874786790080784, 7.056882417912776, 7.910257754071526, 8.846864186563387, 9.619239035669246, 10.588884557878787, 11.570688377245343, 12.565658802633651, 13.595304888975836, 14.569373973732295, 15.45036796606335, 16.38128922519111, 16.553079520493277, 15.601280868485054, 14.661060496062852, 13.784162697852963, 12.903765960807812, 13.786452551167937, 14.649675733669502], [14.626048004927704, 13.700609191524672, 12.891273460860882, 11.941411898996673, 12.760937922270662, 13.669847854229351, 14.624130740837282, 15.641199289912514, 15.485285981516817, 14.583072930887614, 13.540009983115683, 12.496409318944707, 11.566429633723661, 10.555968074081662, 9.612611853431428, 8.856752753783695, 7.957693870910377, 8.886898043781748, 9.832421732557915, 10.610003110364588, 13.55436224757468, 12.757738857846363, 11.851107808180107, 10.968930709854389, 11.737812622869967, 12.696018710659303, 13.650847600515565, 14.64087094043733, 15.586172162781555, 15.399488465031194, 14.467058883990067, 13.534240750176807, 12.560786699325282, 11.553159380079435, 10.66026739437287, 9.862856126456421, 8.994393681738728, 9.944556025882159, 10.720975372791573, 9.654246379428248, 12.548580460358034, 11.752665118358724, 10.784791883411454, 9.941109053172099, 10.768024367649677, 11.698000900680269, 12.655709041077401, 13.626053269792001, 14.610280352859695, 15.536076188963081, 15.493692606797634, 14.499648364819906, 13.587705412129953, 12.538120851139864, 11.685350673288996, 10.8022547148916, 9.96566730638141, 10.75185442620436, 9.752011235004472, 8.754862892625564, 11.580561152762948, 10.68986377352572, 9.774866495544254, 8.926490229965145, 9.706451213366666, 10.699624345581404, 11.65651545852108, 12.577668574757721, 13.61596126135311, 14.55816452612305, 15.496810997438471, 15.4617949016952, 14.511490259951852, 13.464822300183293, 12.390635320241433, 11.46459232427409, 10.533906944727486, 9.717402762707836, 8.79003060481725, 7.81136982299506, 10.649125470838841, 9.678872448689052, 8.74317718441532, 7.9789548011249165, 8.745595683615067, 9.800573919476598, 10.698916236523987, 11.628484495308102, 12.639150972648961, 13.543669916088561, 14.56724516836166, 14.619355563375631, 13.591957933130177, 12.5747862834752, 11.60872274052426, 10.649962449820647, 9.596411220971982, 8.649545180716537, 7.797849725676418, 6.867105406222553, 9.754207720020185, 8.785453194987799, 7.803428892635232, 6.9776948625145865, 7.806189492548014, 8.811496943088384, 9.746002827430974, 10.721874960183506, 11.68846278295195, 12.605890697456095, 13.568297612080668, 13.711538675131909, 12.642958115331995, 11.630378511504864, 10.681285872556606, 9.718015797484181, 8.714131289230071, 7.71370652069835, 6.853865022254851, 5.888739151147362, 8.799035439078374, 7.797359390859069, 6.808229146265001, 5.988689709198262, 6.861449961970936, 7.866667779369549, 8.789734366494637, 9.756592967360419, 10.751631217440881, 11.679507693021652, 12.688708391817608, 12.762918638823145, 11.71109244411576, 10.76601101351423, 9.80577611863034, 8.840561575528291, 7.810920939878174, 6.788687715818666, 5.864873595458747, 4.910880267457175, 7.814481225059673, 6.840721405091962, 5.8578546030449505, 4.942051721623915, 5.910677969770682, 6.851117372731514, 7.787207976667506, 8.763291965854616, 9.777054336714192, 10.694540324841935, 11.621237647613196, 11.823584423632965, 10.852976771399641, 9.893121041154938, 8.932107080910018, 7.880990827016059, 6.848006888784823, 5.845670184976468, 4.901562490896541, 3.892810382768572, 6.835830491157989, 5.905834350312311, 4.927810424895437, 3.9571600221007093, 4.906187480339404, 5.918518507983846, 6.895557685243116, 7.865802806298744, 8.767543041314989, 9.754517678664419, 10.642135956430948, 11.577626808469455, 11.696531482100772, 10.719300621041455, 9.691103022946258, 8.73189119571939, 7.7784403133804885, 6.809144660169334, 5.852480860470217, 4.818662396726683, 5.766865793637798, 4.908229692425818, 3.935814827106118, 3.0020782063469458, 3.88928732045946, 4.874701752975845, 5.92345064980517, 6.8709971975538595, 7.784246186930443, 8.726311890470495, 9.7089343402663, 10.66728539437511, 11.659608530856485, 11.670451384068034, 10.677015523981668, 9.688835427086733, 8.728958718156182, 7.776024896924295, 6.7964897984391826, 5.8113080405132465, 4.822728795277749, 3.8956588227669355, 2.8630203191161527, 2.0294053001336523, 2.9539967745744793, 3.888132723752415, 4.859016765080743, 5.826882518154703, 6.823391293527441, 7.837984578577081, 8.735962328679708, 9.65981374232491, 10.64384502875665, 11.609609321740637, 11.659899338219793, 10.665583752953477, 9.678103881275334, 8.783212467372365, 7.793318497581218, 6.738567479240343, 3.866678026097121, 2.9010330488789404, 1.9353038159586613, 0.9812424496242236, 1.9862490093622396, 2.9638896500564798, 3.9699202564916916, 4.984262873467226, 5.943165394647275, 6.881526592367244, 7.790012256225847, 8.671002929592623, 9.646137896874205, 10.667904003876808, 11.609529504810995, 11.600853903026989, 10.668939384770681, 9.696034183022748, 8.624408279800754, 7.697880701289384, 2.9451877184844606, 1.9748728521208028, 0.947876244097014, 0.0, 1.0516672146655663, 1.9958641007133364, 2.970058413679766, 3.929607008200505, 4.885998534184463, 5.846907815630639, 6.799453902634033, 7.734924032489644, 8.679191169903753, 9.703311593635302, 10.729051598239051, 11.678087323346256, 11.598845860886298, 10.656789358728847, 9.657231967969183, 8.725034293377522, 3.9078534101872435, 2.846617562653173, 1.900446973037314, 0.9754265174828378, 1.9702492588658473, 2.9343007788463886, 3.908209308576006, 4.919533311581839, 5.843111723360867, 6.822372564964834, 7.752223578181933, 8.696216976574938, 9.670219696646246, 10.732419676891404, 11.702621772209325, 12.64718945085341, 12.551719599623684, 11.641626045786417, 10.617951627618382, 9.772868330545258, 4.861679297404848, 3.901509563752195, 2.912548265370291, 1.9352171635686295, 2.931579782801613, 3.8974349069593943, 4.852268156872386, 5.825625999035867, 6.78049320089023, 7.807853963298838, 8.695468592334008, 9.731529853555623, 10.710884687044647, 11.638085600098522, 12.695529520363934, 13.610945855030876, 13.533942327795138, 12.569680278177927, 11.587637033443348, 10.708972039483875, 5.8419218403883715, 4.8659315934459695, 3.856865044566557, 2.862751352778462, 3.822990959324459, 4.852765359522562, 5.878749487728586, 6.8094757058914865, 7.72405217386641, 8.669101465639354, 9.71674070516755, 10.756426254000775, 11.652835778803913, 12.684546227074135, 13.637276498270483, 14.647912291354757, 14.548513960731217, 13.626503419201054, 12.558980089904379, 11.652493717637554, 6.776459641512972, 5.762321218392038, 4.811353891831963, 3.86539991931879, 4.861526341625603, 5.78436721511304, 6.827565197766032, 7.7867494289832475, 8.755846001776073, 9.646181611393152, 10.720254364378643, 11.764187327202517, 12.58418982479596, 13.515783933052848, 14.48838693623078, 15.55378445286061, 15.516953252623143, 14.554548203426018, 13.556525256440878, 12.521350714039343, 7.72809341268249, 6.787282029685892, 5.847996835473052, 4.920392013454296, 5.903087675958611, 6.723736816778576, 7.690565503362505, 8.659707366715313, 9.675490732683187, 10.668169013230756, 11.610939781298548, 12.589930742227656, 13.519238136773394, 14.504875411451257, 15.556426183922209, 15.71269758768243, 14.931259621032945, 15.497919009816805, 14.43696028173176, 13.450405292635555, 8.69804525122388, 7.835909940532206, 6.893877247766538, 5.943268112078342, 6.888075921817303, 7.722218213249563, 8.68806078679586, 9.657552036723752, 10.655377092271635, 11.59477336607631, 12.573772617201863, 13.499804344102191, 14.511670024550407, 15.455485729218433, 15.625626779450673, 14.709739688925493, 13.950415344940614, 14.881881570322108, 15.392155879194002, 14.514938429933459, 9.625730884858056, 8.8056312077727, 7.944499116945853, 6.962381509974512, 7.898987942466374, 8.671362791572232, 9.641008313781773, 10.62281213314833, 11.617782558536637, 12.647428644878822, 13.621497729635282, 14.502491721966337, 15.433412981094097, 15.605203276396262, 14.653404624388038, 13.713184251965837, 12.92944458690587, 13.830675520293456, 14.71336211065358, 15.576585293155146], [15.56883598999853, 14.643397176595498, 13.735365638064929, 12.780369088548628, 11.797674854416456, 12.706584786375146, 13.660867672983077, 14.676892058828951, 14.43361876685125, 13.582234673850085, 12.622768444744048, 11.579167780573073, 10.649188095352027, 9.638726535710028, 8.711454706904586, 8.220645615478542, 9.000194623265896, 9.929398796137267, 10.874922484913434, 11.652503862720106, 14.497150232645506, 13.700526842917188, 12.793895793250933, 11.807887899406344, 10.774549555015762, 11.732755642805097, 12.667081260903409, 13.647766714442112, 14.593067936786337, 14.48224692665956, 13.549817345618433, 12.616999211805172, 11.643545160953648, 10.635917841707801, 9.759110247846028, 9.226748988151268, 10.036894434094249, 10.987056778237678, 11.763476125147092, 10.696747131783766, 13.49136844542886, 12.69545310342955, 11.72757986848228, 10.80364038126218, 9.804761299795471, 10.734737832826063, 11.671942701465245, 12.632949043796783, 13.617176126864477, 14.526687323548137, 14.576451068426, 13.582406826448272, 12.670463873758319, 11.62087931276823, 10.784193526762154, 10.166147576586447, 11.008168058736931, 11.79435517855988, 10.794511987359991, 9.797363644981083, 12.523349137833774, 11.632651758596547, 10.71765448061508, 9.789021558055225, 8.74318814551246, 9.736361277727198, 10.672749118908923, 11.584564348762504, 12.622857035357892, 13.548775660708106, 14.487422132023527, 14.544553363323566, 13.649302950877246, 12.602634991108687, 11.848007716681861, 11.221171269649258, 11.585574159393051, 10.759903515063355, 9.832531357172769, 8.853870575350578, 11.591913455909667, 10.621660433759878, 9.685965169486145, 8.841486129214996, 7.78233261576086, 8.83731085162239, 9.705812010528769, 10.635380269312884, 11.646046746653743, 12.534281050673616, 13.557856302946716, 14.525771221465519, 14.588461183317424, 13.5577922714125, 12.660389955189824, 11.701629664486212, 10.648078435637547, 9.701212395382102, 8.849516940341983, 7.918772620888118, 10.73495386478949, 9.728241180058625, 8.746216877706058, 7.864614053482497, 6.8429264246938075, 7.848233875234178, 8.752898601435756, 9.728770734188288, 10.695358556956732, 11.59650183204115, 12.558908746665724, 13.49380678031037, 13.694625329997558, 12.682045726170427, 11.73295308722217, 10.769683012149745, 9.765798503895637, 8.765373735363916, 7.905532236920418, 6.940406365812929, 9.77978158384768, 8.740147375929894, 7.751017131335826, 6.887584214790317, 5.89818689411673, 6.903404711515343, 7.796630140499418, 8.763488741365201, 9.758526991445663, 10.670118827606707, 11.679319526402663, 12.52045725839011, 12.762759658781325, 11.817678228179796, 10.857443333295905, 9.892228790193856, 8.86258815454374, 7.8403549304842315, 6.916540810124315, 5.962547482122742, 8.817712133021184, 7.783509390162787, 6.8006425881157755, 5.88483970669474, 4.947414901916476, 5.858013146736295, 6.794103750672287, 7.770187739859397, 8.783950110718973, 9.68515145942699, 10.611848782198251, 11.58112304319993, 11.904643986065206, 10.944788255820503, 9.983774295575584, 8.932658041681623, 7.899674103450389, 6.897337399642034, 5.953229705562108, 4.944477597434139, 7.887497705823556, 6.848622335383136, 5.870598409966262, 4.899948007171535, 3.9130832543441842, 4.925414281988626, 5.886168819828171, 6.856413940883799, 7.758154175900044, 8.745128813249474, 9.632747091016004, 10.56823794305451, 11.502257565451934, 11.770967835707022, 10.742770237611825, 9.783558410384957, 8.830107528046055, 7.8608118748349005, 6.904148075135783, 5.87032961139225, 6.8185330083033655, 5.940266419555637, 4.926019273975853, 3.944866191417771, 2.8961830944642406, 3.8799884220264884, 4.914061784390226, 5.861608332138916, 6.7748573215154995, 7.71692302505555, 8.699545474851355, 9.615618179709543, 10.607941316190917, 11.544040417800584, 11.728682738647235, 10.7405026417523, 9.780625932821748, 8.827692111589862, 7.84815701310475, 6.862975255178814, 5.874396009943316, 4.947326037432502, 3.914687533781719, 2.990004864812659, 1.96089254857926, 2.8787438583374714, 3.8496278996657995, 4.817493652739759, 5.814002428112497, 6.786317363911514, 7.684295114014143, 8.608146527659343, 9.592177814091082, 10.55794210707507, 11.497314472266595, 11.717250967619044, 10.7297710959409, 9.834879682037933, 8.844985712246785, 7.79023469390591, 4.9183452407626875, 3.9527002635445068, 2.9869710306242276, 1.9981513431050364, 0.9931447833670203, 1.9512454059322328, 2.918253041826125, 3.9325956588016595, 4.89149817998171, 5.829859377701677, 6.73834504156028, 7.619335714927057, 8.594470682208637, 9.616236789211241, 10.557862290145428, 11.601510453196843, 11.72060659943625, 10.747701397688317, 9.676075494466323, 8.749547915954953, 3.996854933150027, 3.026540066786369, 1.9995434587625804, 1.0516672146655663, 0.0, 0.9441968860477702, 1.9183911990141995, 2.8779397935349387, 3.8343313195188964, 4.795240600965073, 5.747786687968467, 6.683256817824078, 7.6275239552381855, 8.651644378969735, 9.677384383573484, 10.626420108680689, 11.58443898191942, 11.708456573394415, 10.70889918263475, 9.77670150804309, 4.95952062485281, 3.8982847773187395, 2.9521141877028803, 2.017927269838357, 1.0231045284553473, 1.8826335641808227, 2.8565420939104396, 3.867866096916273, 4.7914445086953, 5.770705350299268, 6.700556363516368, 7.644549761909372, 8.618552481980679, 9.680752462225836, 10.650954557543757, 11.595522236187843, 12.537312720656807, 12.693293260451984, 11.669618842283949, 10.824535545210825, 5.913346512070414, 4.953176778417761, 3.9642154800358576, 2.9777179159241483, 2.024885334440798, 2.898341595144224, 3.8259326748783864, 4.799290517041867, 5.728825986224663, 6.756186748633271, 7.643801377668442, 8.679862638890057, 9.65921747237908, 10.586418385432955, 11.643862305698367, 12.559278640365308, 13.567637303307976, 13.621347492843494, 12.639304248108916, 11.699381087710957, 6.893589055053937, 5.917598808111535, 4.908532259232123, 3.9052521051339806, 3.0645310095490776, 3.951608212995721, 4.8524140057345875, 5.783140223897487, 6.672384959200842, 7.617434250973787, 8.665073490501983, 9.704759039335208, 10.601168564138346, 11.632879012408567, 12.585609283604915, 13.59624507668919, 14.582208936244054, 14.678170633866621, 13.610647304569946, 12.59528170270838, 7.81896039386849, 6.804821970747557, 5.853854644187482, 4.907900671674309, 4.103066391850222, 4.883210068586198, 5.801229715772033, 6.760413946989249, 7.704178787110506, 8.594514396727584, 9.668587149713076, 10.71252011253695, 11.532522610130393, 12.464116718387281, 13.436719721565213, 14.502117238195043, 15.447327472108503, 15.528764663751344, 14.527577179209972, 13.464138699110169, 8.770594165038009, 7.829782782041411, 6.890497587828571, 5.962892765809815, 5.154163164208359, 5.822579670251734, 6.7392375563784945, 7.708379419731304, 8.724162785699177, 9.616501798565189, 10.55927256663298, 11.538263527562089, 12.467570922107827, 13.45320819678569, 14.504758969256642, 14.749434519828224, 15.737015367739916, 16.44070699488763, 15.379748266802586, 14.39319327770638, 9.740546003579398, 8.878410692887725, 7.9363780001220565, 6.985768864433861, 6.214781148454991, 6.821061066722721, 7.74030781403789, 8.709799063965782, 9.707624119513666, 10.543106151410743, 11.522105402536296, 12.448137129436624, 13.46000280988484, 14.403818514552865, 14.662363711596468, 13.746476621071288, 14.756171091647586, 15.725973747526155, 16.334943864264826, 15.457726415004284, 10.668231637213575, 9.84813196012822, 8.986999869301373, 8.004882262330032, 7.262880804161221, 7.770205645045391, 8.697980354727065, 9.67505916039036, 10.670029585778668, 11.614803431791346, 12.569830514969714, 13.45082450730077, 14.38174576642853, 14.641940208542056, 13.690141556533833, 12.749921184111631, 13.76353804757416, 14.674767697497503, 15.625960032648708, 16.519373278225974], [16.476626362886904, 15.551187549483872, 14.643156010953305, 13.688159461437005, 12.705465227304833, 11.923140816104892, 12.767333255558714, 13.734678034957575, 13.48942188080348, 12.638037787802315, 11.678571558696278, 10.634970894525303, 9.704991209304257, 8.694529649662257, 7.767257820856816, 8.776580815890178, 9.82836714922054, 10.757571322091911, 11.756923753875894, 12.563056891546701, 15.40494060553388, 14.608317215805563, 13.701686166139307, 12.71567827229472, 11.682339927904138, 10.949311672534844, 11.724867237032033, 12.705552690570736, 13.650853912914961, 13.53805004061179, 12.605620459570662, 11.672802325757402, 10.699348274905878, 9.691720955660031, 8.814913361798258, 9.782684188562904, 10.847076691184173, 11.81315553165486, 12.674029153973686, 11.607300160610361, 14.399158818317234, 13.603243476317925, 12.635370241370655, 11.711430754150555, 10.712551672683848, 9.95129386255581, 10.729728677593869, 11.690735019925407, 12.674962102993101, 13.582490437500367, 13.63225418237823, 12.638209940400502, 11.726266987710549, 10.67668242672046, 9.839996640714384, 10.722082776998082, 11.76949713382542, 12.704908207386474, 11.705065016186586, 10.707916673807677, 13.431139510722149, 12.540442131484921, 11.625444853503454, 10.696811930943602, 9.650978518400837, 8.952917307456945, 9.730535095037547, 10.642350324891128, 11.680643011486517, 12.604578774660336, 13.543225245975758, 13.600356477275795, 12.705106064829476, 11.658438105060917, 10.903810830634091, 11.777106470060893, 12.529771045440821, 11.67045654388995, 10.743084385999364, 9.764423604177173, 12.499703828798042, 11.529450806648253, 10.59375554237452, 9.749276502103372, 8.690122988649238, 7.912942323073282, 8.763597986657393, 9.693166245441509, 10.703832722782368, 11.590084164625846, 12.613659416898948, 13.58157433541775, 13.644264297269654, 12.61359538536473, 11.954838699945006, 12.645826550533982, 11.592275321685317, 10.645409281429872, 9.792356306822464, 8.8616119873686, 11.642744237677867, 10.636031552947, 9.654007250594432, 8.772404426370874, 7.750716797582185, 6.923865346685068, 7.810684577564381, 8.786556710316914, 9.753144533085358, 10.652304945993382, 11.614711860617955, 12.549609894262602, 13.446436351013599, 13.573822635441191, 12.67714997326994, 11.713879898197515, 10.709995389943407, 9.709570621411686, 8.849729122968187, 7.884603251860699, 10.687571956736056, 9.64793774881827, 8.658807504224201, 7.795374587678694, 6.805977267005107, 5.979036182966233, 6.854416116628044, 7.821274717493827, 8.81631296757429, 9.725921941558939, 10.735122640354895, 11.57626037234234, 12.499829806972501, 12.761875114227566, 11.801640219343675, 10.836425676241626, 9.80678504059151, 8.784551816532002, 7.860737696172083, 6.906744368170511, 9.72550250590956, 8.691299763051163, 7.708432961004152, 6.792630079583117, 5.855205274804853, 4.915799122864921, 5.851889726800913, 6.827973715988023, 7.8417360868475985, 8.740954573379222, 9.667651896150483, 10.63692615715216, 11.51962597349231, 11.888985141868273, 10.927971181623354, 9.876854927729394, 8.843870989498159, 7.841534285689804, 6.897426591609877, 5.888674483481908, 8.82912613313242, 7.756412708271513, 6.7783887828546385, 5.807738380059911, 4.820873627232562, 3.9832002581172516, 4.941971933780402, 5.91221705483603, 6.813957289852275, 7.800931927201706, 8.688550204968235, 9.624041057006743, 10.558060679404166, 11.535291540463483, 11.686967123659594, 10.727755296432726, 9.774304414093823, 8.80500876088267, 7.848344961183552, 6.814526497440019, 7.762729894351134, 6.848056792444014, 5.83380964686423, 4.852656564306148, 3.803973467352618, 2.9357915359787183, 3.9698648983424567, 4.917411446091147, 5.83066043546773, 6.772726139007781, 7.755348588803586, 8.671421293661773, 9.663744430143149, 10.599843531752816, 11.574939740719426, 11.684699527800067, 10.724822818869518, 9.771888997637632, 8.792353899152518, 7.807172141226582, 6.818592895991085, 5.891522923480272, 4.858884419829489, 3.8977952377010365, 2.8686829214676375, 1.9345469722897015, 2.90543101361803, 3.8732967666919897, 4.869805542064728, 5.842120477863744, 6.740098227966373, 7.663949641611573, 8.647980928043314, 9.613745221027301, 10.553117586218827, 11.547433171485142, 11.67396798198867, 10.779076568085701, 9.789182598294554, 8.734431579953679, 5.862542126810457, 4.896897149592276, 3.9311679166719977, 2.9423482291528065, 1.9373416694147905, 1.0070485198844628, 1.9740561557783551, 2.9883987727538894, 3.947301293933939, 4.885662491653907, 5.79414815551251, 6.675138828879287, 7.650273796160868, 8.672039903163471, 9.613665404097658, 10.657313567149073, 11.58922808540538, 11.691898283736085, 10.620272380514091, 9.69374480200272, 4.941051819197797, 3.970736952834139, 2.9437403448103505, 1.9958641007133364, 0.9441968860477702, 0.0, 0.9741943129664292, 1.9337429074871682, 2.890134433471126, 3.8510437149173025, 4.803589801920697, 5.739059931776308, 6.683327069190415, 7.707447492921965, 8.733187497525714, 9.682223222632919, 10.640242095871649, 11.5822985980291, 11.653096068682519, 10.720898394090858, 5.90371751090058, 4.8424816633665095, 3.8963110737506503, 2.92848029866495, 1.9336575572819406, 0.9384366781330524, 1.9123452078626695, 2.923669210868503, 3.8472476226475294, 4.826508464251497, 5.756359477468597, 6.7003528758616016, 7.674355595932909, 8.736555576178066, 9.706757671495987, 10.651325350140073, 11.593115834609037, 12.567519270431097, 12.613815728331716, 11.754546559009027, 6.857543398118184, 5.8973736644655315, 4.907054846516338, 3.888270944750742, 2.9199998332542347, 1.9541447090964534, 2.8817357888306163, 3.8550936309940975, 4.784629100176892, 5.8119898625855, 6.69960449162067, 7.735665752842285, 8.71502058633131, 9.642221499385185, 10.699665419650596, 11.615081754317538, 12.623440417260205, 13.587702466877417, 13.583501134156682, 12.607171460599334, 7.836428421534418, 6.860438174592016, 5.851371625712604, 4.815805133960574, 3.959645508362514, 3.00741132694795, 3.908217119686817, 4.838943337849717, 5.728188073153072, 6.673237364926017, 7.720876604454213, 8.760562153287438, 9.656971678090576, 10.688682126360797, 11.641412397557145, 12.65204819064142, 13.638012050196284, 14.658109329565358, 14.535576102057526, 13.503072075596755, 8.729513422695085, 7.71537499957415, 6.764407673014076, 5.8184537005009025, 4.923690026388278, 3.9390131825384276, 4.857032829724263, 5.8162170609414785, 6.759981901062736, 7.650317510679815, 8.724390263665306, 9.76832322648918, 10.588325724082623, 11.519919832339511, 12.492522835517443, 13.557920352147272, 14.503130586060733, 15.559813922703944, 15.435367552098347, 14.371929071998544, 9.681147193864604, 8.711784051003871, 7.772498856791031, 6.844894034772275, 5.86219837226796, 4.878382784203964, 5.7950406703307245, 6.764182533683534, 7.7799658996514065, 8.672304912517419, 9.61507568058521, 10.594066641514319, 11.523374036060057, 12.50901131073792, 13.560562083208872, 14.548928395419479, 15.4615466292112, 16.470434670777816, 16.28753863969096, 15.300983650594755, 10.651099032405993, 9.760411961850185, 8.81823330194175, 7.867624166253552, 6.922816356514591, 5.876864180674951, 6.79611092799012, 7.765602177918011, 8.763427233465896, 9.598909265362973, 10.577908516488526, 11.503940243388854, 12.51580592383707, 13.459621628505095, 13.878919741326214, 14.654266993959665, 15.663961464535962, 16.63376412041453, 17.2427342371532, 16.36551678789266, 11.57878466604017, 10.73013322909068, 9.819027198066145, 8.836909591094804, 7.9003031586029415, 6.826008758997621, 7.753783468679296, 8.73086227434259, 9.725832699730898, 10.670606545743576, 11.625633628921944, 12.506627621253, 13.43754888038076, 13.821406919416956, 12.90669758626358, 13.657711557000008, 14.671328420462537, 15.582558070385879, 16.533750405537084, 17.42716365111435], [17.450820675853333, 16.5253818624503, 15.617350323919734, 14.662353774403433, 13.679659540271262, 12.849325983457067, 11.95900952239061, 12.926354301789472, 12.515227567837051, 11.663843474835886, 10.70437724572985, 9.660776581558874, 8.730796896337829, 7.720335336695829, 8.663691557346063, 9.673014552379424, 10.724800885709787, 11.654005058581157, 12.665153770556621, 13.475510665965302, 16.37913491850031, 15.582511528771992, 14.675880479105736, 13.68987258526115, 12.656534240870567, 11.875496839887019, 10.91654350386393, 11.897228957402632, 12.842530179746857, 12.563855727645361, 11.631426146604234, 10.698608012790974, 9.72515396193945, 8.717526642693603, 9.711347098287504, 10.67911792505215, 11.743510427673419, 12.709589268144107, 13.586482928392288, 12.519753935028962, 15.373353131283663, 14.577437789284353, 13.609564554337084, 12.685625067116984, 11.686745985650276, 10.877479029907985, 9.921404944425765, 10.882411286757304, 11.866638369824997, 12.650658560954804, 12.658059869411801, 11.664015627434074, 10.75207267474412, 9.70248811375403, 10.6956054670231, 11.618516513487329, 12.665930870314666, 13.617361981805075, 12.617518790605187, 11.620370448226279, 14.405333823688578, 13.51463644445135, 12.599639166469883, 11.67100624391003, 10.625172831367266, 9.87910247480912, 8.922211361869444, 9.834026591723024, 10.872319278318413, 11.672746898114774, 12.611393369430196, 12.626162164309367, 11.730911751863047, 10.684243792094488, 11.758430772036348, 12.67354020655014, 13.50396535840725, 12.60677806830715, 11.679405910416564, 10.700745128594374, 13.47389814176447, 12.503645119614681, 11.567949855340949, 10.7234708150698, 9.664317301615666, 8.88713663603971, 7.95527425348929, 8.884842512273405, 9.895508989614264, 10.658252288080284, 11.681827540353385, 12.649742458872188, 12.670069984303225, 11.639401072398302, 12.605464615349241, 13.587190635783427, 12.566469634651746, 11.6196035943963, 10.728677831239665, 9.7979335117858, 12.616938550644296, 11.610225865913428, 10.62820156356086, 9.746598739337303, 8.724911110548613, 7.898059659651497, 7.002360844396279, 7.978232977148811, 8.894619516951904, 9.72047306944782, 10.682879984072393, 11.61777801771704, 12.479897437380743, 12.599628322474762, 13.532901483316895, 12.688074211163944, 11.684189702909835, 10.683764934378114, 9.823923435934615, 8.858797564827128, 11.661766269702484, 10.622132061784699, 9.63300181719063, 8.769568900645123, 7.780171579971536, 6.953230495932662, 6.046092383459941, 7.012950984325724, 7.950068400364945, 8.794090065013377, 9.768583726722037, 10.609721458709483, 11.533290893339645, 12.478372323941175, 12.775834532310103, 11.810619989208055, 10.780979353557939, 9.75874612949843, 8.834932009138512, 7.880938681136941, 10.699696818875989, 9.665494076017591, 8.68262727397058, 7.7668243925495455, 6.829399587771282, 5.889993435831349, 5.04356599363281, 6.01964998281992, 6.944561796604664, 7.80912269683366, 8.701112982517625, 9.670387243519304, 10.553087059859454, 11.512942790104157, 11.902165494589783, 10.851049240695822, 9.818065302464587, 8.815728598656232, 7.871620904576306, 6.862868796448337, 9.80332044609885, 8.730607021237942, 7.752583095821067, 6.78193269302634, 5.79506794019899, 4.957394571083681, 4.032427894950421, 5.002673016006049, 5.882125413306713, 6.869100050656144, 7.722011291335378, 8.657502143373886, 9.59152176577131, 10.568752626830626, 11.594966671189585, 11.701949609399158, 10.748498727060255, 9.7792030738491, 8.822539274149982, 7.788720810406448, 8.736924207317564, 7.822251105410443, 6.808003959830659, 5.826850877272577, 4.7781677803190465, 3.909985848945148, 3.0603208595124753, 4.007867407261165, 4.898828558922168, 5.840894262462219, 6.788809675170729, 7.697226980695343, 8.689550117176719, 9.625649218786386, 10.600745427752996, 11.549987184385454, 11.699017131835948, 10.746083310604062, 9.766548212118948, 8.781366454193012, 7.792787208957515, 6.865717236446702, 5.8330787327959195, 4.8719895506674655, 3.8428772344340665, 2.9087412852561307, 1.9958869747880488, 2.9637527278620084, 3.937973665519166, 4.867926164897314, 5.765903914999943, 6.689755328645144, 7.673786615076883, 8.63955090806087, 9.578923273252396, 10.573238858518712, 11.608903573351997, 11.753270881052131, 10.763376911260984, 9.708625892920109, 6.836736439776886, 5.871091462558706, 4.905362229638428, 3.9165425421192355, 2.9115359823812197, 1.981242832850892, 0.9998618428119258, 2.01420445978746, 2.97310698096751, 3.911468178687478, 4.819953842546081, 5.700944515912857, 6.676079483194439, 7.6978455901970415, 8.639471091131227, 9.683119254182643, 10.61503377243895, 11.587938974186883, 11.594466693480522, 10.667939114969151, 5.915246132164226, 4.944931265800569, 3.91793465777678, 2.970058413679766, 1.9183911990141995, 0.9741943129664292, 0.0, 0.959548594520739, 1.9159401205046969, 2.8768494019508735, 3.829395488954267, 4.764865618809878, 5.709132756223986, 6.733253179955534, 7.758993184559284, 8.708028909666488, 9.666047782905219, 10.60810428506267, 11.607661675822333, 11.695092707057288, 6.877911823867009, 5.816675976332939, 4.87050538671708, 3.9026746116313795, 2.9078518702483698, 1.9126309910994816, 0.9381508948962402, 1.9494748979020735, 2.8730533096811004, 3.8523141512850683, 4.782165164502168, 5.726158562895172, 6.700161282966479, 7.762361263211636, 8.732563358529557, 9.677131037173641, 10.618921521642605, 11.593324957464667, 12.568381335471532, 12.728740871975456, 7.831737711084614, 6.871567977431961, 5.843376370933539, 4.824592469167944, 3.82822984993496, 2.8623747257771788, 1.907541475864187, 2.880899318027668, 3.8104347872104634, 4.837795549619072, 5.725410178654242, 6.761471439875857, 7.740826273364881, 8.668027186418756, 9.725471106684168, 10.640887441351106, 11.649246104293773, 12.613508153910985, 13.538066741296499, 13.581365773565762, 8.772749945951618, 7.7967596990092165, 6.787693150129805, 5.752126658377776, 4.86787552504324, 3.9156413436286757, 2.934022806720388, 3.864749024883287, 4.753993760186643, 5.699043051959587, 6.746682291487784, 7.786367840321009, 8.682777365124148, 9.714487813394369, 10.667218084590717, 11.677853877674988, 12.663817737229852, 13.683915016598926, 14.50940979775753, 14.477266388563184, 9.665834947112286, 8.651696523991351, 7.7007291974312775, 6.754775224918104, 5.831920043069005, 4.847243199219154, 3.8828385167578334, 4.842022747975049, 5.785787588096307, 6.676123197713386, 7.750195950698877, 8.79412891352275, 9.614131411116194, 10.545725519373082, 11.518328522551014, 12.583726039180844, 13.528936273094304, 14.585619609737515, 15.506954964294028, 15.346123384964972, 10.593600968283205, 9.620014067684599, 8.680728873471757, 7.753124051453001, 6.770428388948686, 5.78661280088469, 4.820846357364295, 5.789988220717104, 6.805771586684978, 7.69811059955099, 8.640881367618782, 9.61987232854789, 10.549179723093628, 11.534816997771491, 12.586367770242443, 13.57473408245305, 14.487352316244772, 15.496240357811386, 16.51622341026203, 16.275177963561184, 11.563552806824594, 10.668641978530912, 9.726463318622475, 8.775854182934278, 7.831046373195317, 6.785094197355677, 5.8219166150236905, 6.791407864951582, 7.789232920499465, 8.624714952396545, 9.603714203522097, 10.529745930422425, 11.54161161087064, 12.485427315538667, 13.425212443400104, 14.424797909330405, 15.434492379906702, 16.414237078942225, 17.449103115699206, 17.339711100859088, 12.49123844045877, 11.638363245771407, 10.72725721474687, 9.74513960777553, 8.808533175283667, 7.734238775678347, 6.779589155712866, 7.75666796137616, 8.751638386764467, 9.696412232777147, 10.651439315955516, 11.53243330828657, 12.463354567414331, 13.013083186248853, 13.832882753615754, 14.631905869966436, 15.645522733428965, 16.556752383352308, 17.507944718503513, 18.401357964080777], [18.41036927037407, 17.48493045697104, 16.576898918440474, 15.621902368924173, 14.639208134792002, 13.808874577977807, 12.91855811691135, 12.246347358312235, 11.555678973316311, 10.704294880315146, 9.776123559159917, 8.821577255892024, 8.041247858987724, 8.679883931216567, 9.623240151866801, 10.632563146900162, 11.684349480230525, 12.613553653101896, 13.62470236507736, 14.435059260486039, 17.338683513021046, 16.542060123292732, 15.635429073626476, 14.64942117978189, 13.616082835391307, 12.835045434407759, 11.87609209838467, 11.217222013925396, 12.019030645871439, 11.72465640197851, 10.792226820937383, 9.859408687124123, 9.035604924589345, 9.677075237214341, 10.670895692808243, 11.638666519572888, 12.703059022194157, 13.669137862664845, 14.546031522913026, 13.4793025295497, 16.3329017258044, 15.536986383805093, 14.569113148857824, 13.645173661637724, 12.646294580171016, 11.837027624428725, 10.880953538946505, 10.202404343280067, 11.037122023162885, 11.691109966434064, 11.81886054374495, 10.824816301767223, 10.064865569482366, 10.66203670827477, 11.655154061543838, 12.578065108008067, 13.625479464835404, 14.576910576325814, 13.577067385125925, 12.579919042747017, 15.364882418209318, 14.47418503897209, 13.559187760990623, 12.63055483843077, 11.584721425888006, 10.83865106932986, 9.881759956390184, 9.154019648245788, 9.985596494977207, 10.713198303594034, 11.651844774909456, 11.786962838642516, 11.044129828221193, 11.643792386615225, 12.717979366557085, 13.633088801070878, 14.46351395292799, 13.566326662827889, 12.638954504937303, 11.660293723115112, 14.43344673628521, 13.463193714135421, 12.527498449861689, 11.68301940959054, 10.623865896136406, 9.846685230560452, 8.91482284801003, 8.204835568796168, 8.976233799434898, 9.698703693559544, 10.722278945832645, 11.690193864351448, 12.116749947830064, 12.598949666919038, 13.565013209869978, 14.546739230304164, 13.526018229172486, 12.57915218891704, 11.688226425760405, 10.75748210630654, 13.576487145165036, 12.569774460434168, 11.587750158081601, 10.706147333858043, 9.684459705069353, 8.857608254172238, 7.961909438917018, 7.173812284449605, 7.935070922431164, 8.76092447492708, 9.723331389551653, 10.6582294231963, 11.520348842860002, 12.514105823468805, 13.434366879251325, 13.647622805684684, 12.643738297430575, 11.643313528898855, 10.783472030455354, 9.818346159347866, 12.621314864223224, 11.581680656305439, 10.59255041171137, 9.729117495165863, 8.739720174492275, 7.912779090453402, 7.00564097798068, 6.175247532261679, 6.9905198058442055, 7.8345414704926375, 8.809035132201297, 9.650172864188743, 10.573742298818905, 11.518823729420435, 12.440497566000476, 12.770168583728795, 11.740527948078679, 10.71829472401917, 9.79448060365925, 8.84048727565768, 11.659245413396729, 10.625042670538331, 9.64217586849132, 8.726372987070285, 7.788948182292021, 6.849542030352089, 6.003114588153549, 5.141293670543505, 5.985013202083925, 6.84957410231292, 7.741564387996885, 8.710838648998564, 9.593538465338714, 10.553394195583417, 11.514408155828336, 11.810597835216562, 10.777613896985327, 9.775277193176972, 8.831169499097046, 7.822417390969076, 10.762869040619588, 9.69015561575868, 8.712131690341806, 7.74148128754708, 6.754616534719729, 5.916943165604421, 4.99197648947116, 4.0906531103237596, 4.9225768187859735, 5.909551456135405, 6.762462696814638, 7.697953548853146, 8.63197317125057, 9.609204032309886, 10.635418076668847, 11.547382821232059, 11.708047321580995, 10.73875166836984, 9.782087868670722, 8.748269404927187, 9.696472801838302, 8.781799699931183, 7.767552554351399, 6.786399471793317, 5.737716374839786, 4.869534443465887, 4.0198694540332145, 3.086176018381181, 3.939279964401429, 4.8813456679414795, 5.829261080649989, 6.737678386174604, 7.7300015226559795, 8.666100624265647, 9.641196833232257, 10.590438589864718, 11.598500141950412, 11.705631905124802, 10.726096806639687, 9.74091504871375, 8.752335803478253, 7.8252658309674406, 6.792627327316658, 5.831538145188205, 4.802425828954806, 3.86828987977687, 2.9554355693087877, 2.042061338982024, 2.978425070998427, 3.908377570376575, 4.806355320479204, 5.730206734124405, 6.714238020556144, 7.6800023135401325, 8.619374678731658, 9.613690263997974, 10.64935497883126, 11.598724807670592, 11.722925505781722, 10.668174487440847, 7.796285034297625, 6.830640057079445, 5.864910824159166, 4.876091136639975, 3.8710845769019584, 2.940791427371631, 1.9594104373326648, 1.068986781915609, 2.0135583864467708, 2.9519195841667387, 3.8604052480253417, 4.741395921392118, 5.7165308886737, 6.738296995676303, 7.67992249661049, 8.723570659661906, 9.655485177918214, 10.628390379666147, 11.696406590609273, 11.62748770948989, 6.874794726684965, 5.904479860321308, 4.877483252297519, 3.9296070082005046, 2.8779397935349382, 1.9337429074871682, 0.959548594520739, 0.0, 0.9563915259839578, 1.9173008074301343, 2.869846894433528, 3.805317024289139, 4.749584161703247, 5.773704585434796, 6.799444590038545, 7.74848031514575, 8.70649918838448, 9.648555690541931, 10.648113081301595, 11.580310755893256, 7.837460418387748, 6.776224570853677, 5.8300539812378185, 4.862223206152119, 3.867400464769109, 2.872179585620221, 1.8976994894169792, 1.0428844249644442, 1.9135047151603615, 2.892765556764329, 3.822616569981429, 4.766609968374433, 5.74061268844574, 6.802812668690898, 7.773014764008819, 8.717582442652905, 9.659372927121868, 10.633776362943928, 11.608832740950792, 12.613327522647074, 8.791286305605352, 7.831116571952699, 6.802924965454279, 5.784141063688683, 4.787778444455699, 3.821923320297918, 2.867090070384926, 1.981983260833624, 2.8508861926897247, 3.8782469550983327, 4.7658615841335035, 5.801922845355119, 6.781277678844142, 7.708478591898016, 8.765922512163428, 9.68133884683037, 10.689697509773037, 11.653959559390248, 12.578518146775759, 13.549431231585691, 9.732298540472359, 8.756308293529957, 7.747241744650545, 6.711675252898515, 5.827424119563979, 4.875189938149415, 3.8935714012411267, 2.965832967689243, 3.794445165665904, 4.739494457438848, 5.787133696967045, 6.826819245800269, 7.723228770603409, 8.75493921887363, 9.707669490069977, 10.718305283154251, 11.704269142709116, 12.72436642207819, 13.549861203236789, 14.494644760823206, 10.625383541633024, 9.61124511851209, 8.660277791952016, 7.714323819438843, 6.791468637589743, 5.806791793739892, 4.842387111278573, 4.02441466119169, 4.826238993575568, 5.7165746031926465, 6.7906473561781375, 7.8345803190020105, 8.654582816595456, 9.586176924852344, 10.558779928030276, 11.624177444660106, 12.569387678573566, 13.626071015216777, 14.547406369773288, 15.471094347633844, 11.553149562803943, 10.579562662205337, 9.640277467992496, 8.71267264597374, 7.729976983469424, 6.746161395405428, 5.780394951885034, 5.00761354628428, 5.859480800715394, 6.738562005030251, 7.681332773098043, 8.660323734027152, 9.58963112857289, 10.575268403250753, 11.626819175721705, 12.615185487932312, 13.527803721724034, 14.536691763290648, 15.556674815741289, 16.400148926230056, 12.523101401345333, 11.62819057305165, 10.686011913143213, 9.735402777455016, 8.790594967716055, 7.744642791876415, 6.78146520954443, 6.077381464555878, 6.857338444065138, 7.665166357875806, 8.644165609001357, 9.570197335901685, 10.582063016349903, 11.525878721017929, 12.465663848879366, 13.465249314809666, 14.474943785385964, 15.454688484421487, 16.48955452117847, 17.430724932371703, 13.45078703497951, 12.597911840292145, 11.686805809267607, 10.704688202296266, 9.768081769804404, 8.693787370199084, 7.739137750233605, 7.0426415609804565, 7.870593734835278, 8.736863638256409, 9.691890721434776, 10.57288471376583, 11.503805972893591, 12.530072136479486, 13.437886003942001, 14.441435412039699, 15.455052275502227, 16.471997424689633, 17.423189759840838, 18.490960427605724], [18.45830704672962, 17.47955115298579, 16.441689986943768, 15.486693437427467, 14.437290215750917, 13.465051248116731, 12.531347717130453, 11.514279168055221, 10.599287447332351, 9.747903354331187, 8.819732033175958, 7.865185729908065, 8.79516541512911, 9.636275457200524, 10.579631677850758, 11.58895467288412, 12.640741006214482, 13.569945179085853, 14.581093891061318, 15.39145078647, 17.38819159435685, 17.49845164927669, 16.591820599610433, 15.605812705765848, 14.572474361375265, 13.766490298932514, 12.807536962909424, 11.988676948691442, 11.062639119887482, 10.768264875994552, 9.835835294953425, 8.903017161140165, 9.789522480730732, 10.633466763198298, 11.6272872187922, 12.595058045556845, 13.659450548178114, 14.625529388648802, 15.502423048896985, 14.43569405553366, 16.382409807140206, 16.49337790978905, 15.52550467484178, 14.601565187621684, 13.602686106154975, 12.76847248895348, 11.81239840347126, 10.973859278046113, 10.080730497178928, 10.734718440450107, 10.862469017760993, 9.868424775783264, 10.818783125623753, 11.618428234258726, 12.611545587527795, 13.534456633992024, 14.581870990819361, 15.533302102309772, 14.533458911109884, 13.536310568730975, 15.455492382926282, 15.430576564956047, 14.51557928697458, 13.586946364414729, 12.541112951871964, 11.770095933854615, 10.813204820914939, 9.925474583011834, 9.02920496899325, 9.756806777610077, 10.6954532489255, 10.830571312658558, 11.79804738436258, 12.600183912599181, 13.674370892541042, 14.589480327054835, 15.419905478911947, 14.522718188811847, 13.595346030921261, 12.61668524909907, 14.54162148163796, 14.419585240119378, 13.483889975845646, 12.6394109355745, 11.580257422120365, 10.796079934117182, 9.846267712534784, 8.976290503562215, 8.01984227345094, 8.742312167575587, 9.765887419848688, 10.733802338367491, 11.512957134674227, 12.517941547561309, 13.405412221235022, 14.387138241669208, 14.482409755156443, 13.535543714900998, 12.644617951744362, 11.713873632290497, 13.557466928523201, 13.526165986418125, 12.544141684065558, 11.662538859842002, 10.640851231053311, 9.807002957728969, 8.893354303441772, 7.94526721921565, 6.978679396447206, 7.804532948943123, 8.766939863567696, 9.701837897212343, 10.563957316876046, 11.557714297484848, 12.477975353267368, 13.403646539682546, 13.600129823414532, 12.599705054882811, 11.73986355643931, 10.774737685331823, 12.682392934590471, 12.538072182289396, 11.548941937695327, 10.685509021149821, 9.696111700476234, 8.862173794010133, 7.937085842505434, 7.029166529940711, 6.034128279860248, 6.87814994450868, 7.85264360621734, 8.693781338204786, 9.617350772834948, 10.562432203436478, 11.484106040016519, 12.449320583118567, 12.696919474062636, 11.674686250003127, 10.750872129643207, 9.796878801641636, 11.69783872057177, 11.581434196522288, 10.598567394475277, 9.682764513054241, 8.74533970827598, 7.805933556336046, 6.934559452678303, 6.0038167931600315, 5.028621676099967, 5.893182576328963, 6.785172862012928, 7.754447123014607, 8.637146939354757, 9.59700266959946, 10.55801662984438, 11.60913288373834, 11.734005422969284, 10.731668719160929, 9.787561025081002, 8.778808916953032, 11.719260566603545, 10.646547141742637, 9.668523216325763, 8.697872813531037, 7.711008060703687, 6.8733346915883775, 5.923421353995914, 4.953176232940286, 3.966185292802016, 4.953159930151447, 5.8060711708306805, 6.741562022869188, 7.675581645266612, 8.652812506325928, 9.679026550684888, 10.590991295248102, 11.544442177587005, 11.695143194353797, 10.738479394654679, 9.704660930911144, 10.65286432782226, 9.73819122591514, 8.723944080335356, 7.7427909977772735, 6.694107900823743, 5.825925969449845, 4.976260980017172, 4.040165569225442, 2.982888438417471, 3.924954141957522, 4.872869554666031, 5.781286860190647, 6.773609996672022, 7.709709098281689, 8.684805307248299, 9.634047063880761, 10.642108615966452, 11.595042437198337, 11.682488332623644, 10.697306574697707, 9.70872732946221, 8.781657356951397, 7.7490188533006155, 6.787929671172162, 5.758817354938763, 4.824681405760828, 3.9118270952927454, 2.9960508898262854, 2.022033545014469, 2.9519860443926174, 3.849963794495246, 4.773815208140448, 5.757846494572187, 6.723610787556175, 7.6629831527477, 8.657298738014017, 9.6929634528473, 10.642333281686632, 11.63222725147778, 11.624566013424804, 8.752676560281582, 7.787031583063402, 6.821302350143124, 5.832482662623932, 4.8274761028859166, 3.897182953355589, 2.9158019633166226, 2.02297633275987, 1.057166860462813, 1.995528058182781, 2.904013722041384, 3.7850043954081607, 4.760139362689742, 5.781905469692345, 6.723530970626531, 7.7671791336779465, 8.699093651934254, 9.671998853682187, 10.740015064625315, 11.651072821997435, 7.831186252668922, 6.860871386305265, 5.833874778281476, 4.885998534184463, 3.8343313195188964, 2.8901344334711263, 1.9159401205046969, 0.9563915259839578, 0.0, 0.9609092814461765, 1.9134553684495703, 2.8489254983051815, 3.793192635719289, 4.8173130594508375, 5.843053064054587, 6.792088789161792, 7.750107662400523, 8.692164164557973, 9.691721555317637, 10.623919229909298, 8.793851944371704, 7.732616096837635, 6.786445507221776, 5.818614732136076, 4.823791990753067, 3.8285711116041785, 2.854091015400937, 1.9495068369451758, 0.9571131891764036, 1.9363740307803714, 2.8662250439974715, 3.8102184423904757, 4.784221162461782, 5.846421142706939, 6.81662323802486, 7.761190916668945, 8.70298140113791, 9.67738483695997, 10.652441214966835, 11.656935996663117, 9.747677831589309, 8.787508097936657, 7.759316491438236, 6.7405325896726405, 5.744169970439657, 4.778314846281876, 3.8234815963688837, 2.8886056728143554, 1.8944946667057665, 2.9218554291143746, 3.8094700581495453, 4.845531319371161, 5.824886152860184, 6.752087065914059, 7.80953098617947, 8.724947320846411, 9.733305983789078, 10.69756803340629, 11.622126620791802, 12.593039705601734, 10.688690066456315, 9.712699819513913, 8.703633270634501, 7.668066778882473, 6.783815645547937, 5.8315814641333725, 4.849962927225084, 3.83091237650758, 2.838053639681946, 3.78310293145489, 4.830742170983086, 5.870427719816311, 6.766837244619452, 7.798547692889673, 8.751277964086018, 9.761913757170294, 10.747877616725159, 11.76797489609423, 12.593469677252832, 13.53825323483925, 11.581775067616983, 10.567636644496048, 9.616669317935974, 8.670715345422801, 7.747860163573701, 6.763183319723851, 5.798778637262529, 4.842241358971699, 3.86984746759161, 4.760183077208688, 5.834255830194179, 6.878188793018052, 7.698191290611498, 8.629785398868387, 9.60238840204632, 10.667785918676149, 11.61299615258961, 12.66967948923282, 13.591014843789331, 14.514702821649887, 12.509541088787902, 11.535954188189296, 10.596668993976454, 9.669064171957698, 8.686368509453382, 7.702552921389387, 6.736786477868991, 5.825440244064289, 4.903089274731436, 5.782170479046292, 6.724941247114084, 7.703932208043193, 8.633239602588933, 9.618876877266796, 10.670427649737748, 11.658793961948355, 12.571412195740077, 13.580300237306691, 14.600283289757332, 15.443757400246099, 13.479492927329291, 12.58458209903561, 11.642403439127172, 10.691794303438975, 9.746986493700014, 8.701034317860373, 7.7378567355283865, 6.895208162335887, 5.90094691808118, 6.708774831891847, 7.687774083017398, 8.613805809917727, 9.625671490365946, 10.569487195033972, 11.50927232289541, 12.50885778882571, 13.518552259402007, 14.49829695843753, 15.53316299519451, 16.474333406387746, 14.407178560963468, 13.554303366276104, 12.643197335251568, 11.661079728280226, 10.724473295788364, 9.650178896183043, 8.695529276217561, 7.8604682587604655, 6.91420220885132, 7.78047211227245, 8.735499195450817, 9.61649318778187, 10.547414446909631, 11.573680610495526, 12.481494477958044, 13.485043886055742, 14.49866074951827, 15.515605898705676, 16.46679823385688, 17.534568901621768], [17.49739776528344, 16.51864187153961, 15.48078070549759, 14.52578415598129, 13.47638093430474, 12.504141966670554, 11.66962431627988, 10.679029214151676, 9.800194999568607, 8.948810906567443, 8.157747633322789, 8.826095011354242, 9.756074696575288, 10.597184738646702, 11.540540959296935, 12.549863954330297, 13.601650287660659, 14.53085446053203, 15.542003172507494, 16.352360067916173, 16.427282312910673, 17.372302271008618, 16.488257316365296, 15.498265345123574, 14.499506233705434, 13.477971110240603, 12.708457306656069, 11.673949660890592, 10.728648438546367, 9.98786175866622, 9.227106562675566, 9.863926442586342, 10.750431762176909, 11.594376044644475, 12.588196500238377, 13.555967327003023, 14.620359829624292, 15.58643867009498, 16.46333233034316, 15.396603336979835, 15.421500525694027, 16.36722853152098, 16.486413956287958, 15.562474469067862, 14.563595387601152, 13.61902778692926, 12.66295370144704, 11.771060762345359, 10.786833679277665, 9.788908188501138, 10.253740285483133, 10.829334057229442, 11.77969240706993, 12.579337515704903, 13.572454868973972, 14.495365915438201, 15.542780272265539, 16.494211383755946, 15.49436819255606, 14.497219850177151, 14.494583101480105, 15.463666436631216, 15.476488568420757, 14.547855645860906, 13.502022233318142, 12.620651231830395, 11.66376011889072, 10.748244832461204, 9.76917758579206, 8.810996525661107, 9.74964299697653, 10.740795200703873, 11.62466797283692, 12.512189546418945, 13.495530809099762, 14.382862660309607, 15.313548039856212, 15.483627470258025, 14.556255312367439, 13.577594530545248, 13.580712200191783, 14.550965222341572, 14.444799257291823, 13.600320217020677, 12.541166703566542, 11.71491483013809, 10.696823010510565, 9.799060753011585, 8.84261252290031, 7.796501915626619, 8.820077167899719, 9.787992086418521, 10.55204785322805, 11.557032266115131, 12.444502939788848, 13.426228960223034, 14.479373834632133, 14.496452996347177, 13.60552723319054, 12.674782913736674, 12.596557647077024, 13.610397977440906, 13.505050965511735, 12.62344814128818, 11.601760512499489, 10.725837853749876, 9.743909601417553, 8.768037468665021, 7.801449645896577, 6.858722696994154, 7.821129611618726, 8.756027645263373, 9.603048035429868, 10.59680501603867, 11.517066071821192, 12.44273725823637, 13.44662176649048, 13.56061433632899, 12.70077283788549, 11.735646966778, 11.721483653144295, 12.727770167751098, 12.509851219141504, 11.646418302595999, 10.657020981922411, 9.78100869003104, 8.855920738526342, 7.889062137660559, 6.894023887580096, 5.932339692559711, 6.891734324771162, 7.732872056758609, 8.65644149138877, 9.6015229219903, 10.523196758570343, 11.488411301672391, 12.518051937322507, 12.635595531449306, 11.711781411089387, 10.757788083087815, 10.736929439125594, 11.77113218198399, 11.559476675921454, 10.643673794500419, 9.706248989722157, 8.766842837782225, 7.872880607809435, 6.902279654679392, 5.888517283819816, 4.947372324379994, 5.82426358056675, 6.793537841568431, 7.6762376579085805, 8.636093388153284, 9.597107348398204, 10.648223602292164, 11.56062500115101, 11.692578000607108, 10.748470306527182, 9.739718198399212, 11.656689239725726, 11.607456423188815, 10.62943249777194, 9.658782094977214, 8.671917342149865, 7.834243973034555, 6.861742509127046, 5.891497388071418, 4.904506447933148, 4.007349678202478, 4.845161889384504, 5.780652741423012, 6.714672363820435, 7.691903224879751, 8.718117269238713, 9.630082013801925, 10.583532896140827, 11.552828549351982, 11.699388676100858, 10.665570212357323, 11.613773609268438, 10.699100507361317, 9.684853361781533, 8.703700279223451, 7.65501718226992, 6.786835250896021, 5.937170261463349, 4.985280224319663, 3.9212095935486033, 2.9791438900085527, 3.9119602732198544, 4.820377578744471, 5.812700715225845, 6.748799816835513, 7.723896025802123, 8.673137782434583, 9.681199334520276, 10.634133155752162, 11.643041673463484, 11.658215856143887, 10.66963661090839, 9.742566638397573, 8.709928134746791, 7.748838952618339, 6.71972663638494, 5.785590687207004, 4.8727363767389225, 3.956960171272462, 2.9829428264606457, 1.991076762946441, 2.8890545130490692, 3.8129059266942713, 4.79693721312601, 5.762701506109998, 6.702073871301524, 7.69638945656784, 8.732054171401124, 9.681424000240456, 10.671317970031604, 11.649476762600301, 9.713585841727761, 8.74794086450958, 7.7822116315893, 6.793391944070109, 5.788385384332093, 4.858092234801766, 3.876711244762799, 2.983885614206047, 2.0180761419089897, 1.0346187767366044, 1.9431044405952074, 2.824095113961984, 3.7992300812435653, 4.820996188246168, 5.762621689180355, 6.80626985223177, 7.738184370488078, 8.71108957223601, 9.779105783179139, 10.690163540551259, 8.7920955341151, 7.821780667751442, 6.794784059727653, 5.846907815630639, 4.795240600965073, 3.851043714917303, 2.8768494019508735, 1.9173008074301343, 0.9609092814461765, 0.0, 0.9525460870033938, 1.888016216859005, 2.8322833542731125, 3.8564037780046614, 4.88214378260841, 5.831179507715615, 6.789198380954346, 7.731254883111797, 8.73081227387146, 9.663009948463122, 9.754761225817882, 8.693525378283812, 7.747354788667953, 6.779524013582252, 5.784701272199243, 4.789480393050355, 3.8150002968471135, 2.9104161183913524, 1.9180224706225801, 0.9754647493341948, 1.9053157625512946, 2.849309160944299, 3.8233118810156057, 4.885511861260763, 5.855713956578684, 6.8002816352227695, 7.742072119691733, 8.716475555513794, 9.691531933520658, 10.69602671521694, 10.708587113035486, 9.748417379382834, 8.720225772884413, 7.701441871118817, 6.7050792518858335, 5.739224127728052, 4.784390877815061, 3.849514954260532, 2.855403948151943, 2.0502142132672563, 2.8485607767033683, 3.8846220379249834, 4.863976871414008, 5.791177784467882, 6.848621704733294, 7.764038039400234, 8.7723967023429, 9.736658751960112, 10.661217339345624, 11.632130424155557, 11.649599347902493, 10.67360910096009, 9.664542552080679, 8.62897606032865, 7.744724926994113, 6.792490745579549, 5.810872208671261, 4.791821657953756, 3.7989629211281226, 3.1211185316017205, 3.8962530983758494, 4.912031771389761, 5.805927963173275, 6.837638411443496, 7.790368682639842, 8.801004475724117, 9.786968335278981, 10.807065614648053, 11.632560395806655, 12.577343953393072, 12.54268434906316, 11.528545925942225, 10.577578599382152, 9.631624626868978, 8.708769445019877, 7.724092601170026, 6.759687918708707, 5.803150640417876, 4.8307567490377865, 4.098198677355518, 4.935488770706781, 5.966278009762261, 6.737282009165321, 7.668876117422211, 8.641479120600144, 9.706876637229973, 10.652086871143434, 11.708770207786644, 12.630105562343154, 13.55379354020371, 13.470450370234078, 12.496863469635471, 11.55757827542263, 10.629973453403874, 9.647277790899558, 8.663462202835563, 7.6976957593151685, 6.786349525510466, 5.863998556177613, 5.120186079193123, 5.892186173361878, 6.871177134290987, 7.672330321142756, 8.657967595820619, 9.709518368291572, 10.69788468050218, 11.610502914293901, 12.619390955860515, 13.639374008311155, 14.482848118799922, 14.440402208775467, 13.545491380481785, 12.603312720573348, 11.65270358488515, 10.70789577514619, 9.661943599306548, 8.698766016974563, 7.856117443782064, 6.861856199527357, 6.046790432038677, 6.888681635253654, 7.814713362153983, 8.664762208919768, 9.608577913587794, 10.548363041449232, 11.547948507379532, 12.55764297795583, 13.537387676991353, 14.572253713748333, 15.513424124941569, 15.368087842409643, 14.51521264772228, 13.604106616697742, 12.6219890097264, 11.685382577234538, 10.611088177629219, 9.656438557663739, 8.821377540206642, 7.875111490297497, 7.11848771241928, 7.936406747687073, 8.817400740018126, 9.712164493006085, 10.615550652421637, 11.520585196511867, 12.524134604609564, 13.537751468072093, 14.554696617259498, 15.505888952410704, 16.57365962017559], [16.544851678280047, 15.566095784536216, 14.528234618494196, 13.573238068977895, 12.523834847301345, 11.55159587966716, 10.717078229276485, 9.726483127148281, 8.90756984083829, 8.056185747837125, 8.979893336829017, 9.778641098357635, 10.70862078357868, 11.549730825650096, 12.49308704630033, 13.502410041333691, 14.554196374664054, 15.483400547535425, 16.494549259510887, 17.304906154919568, 15.474736225907279, 16.41975618400522, 15.535711229361901, 14.54571925812018, 13.54696014670204, 12.525425023237208, 11.759544247803166, 10.75560847153512, 9.83602327981605, 9.095236599935902, 10.027666180977029, 10.816472529589735, 11.702977849180302, 12.54692213164787, 13.540742587241771, 14.508513414006417, 15.572905916627686, 16.538984757098376, 17.41587841734656, 16.34914942398323, 14.468954438690632, 15.414682444517583, 16.418328621393652, 15.560034910834517, 14.505099959296034, 13.523442833216242, 12.745854633406802, 11.77042614218045, 10.817931902524604, 10.113042824880743, 9.955524499662545, 10.785815465828824, 11.651386144572355, 12.54139913775601, 13.534516491025078, 14.485340266369024, 15.298273047729188, 16.28587373679089, 16.446914279559454, 15.449765937180546, 13.54203701447671, 14.511120349627822, 15.55542578643273, 15.479754824009097, 14.433921411466333, 13.46104592187663, 12.504154808936955, 11.588639522507439, 10.609572275838294, 9.651391215707342, 8.930055490504289, 9.82366892895353, 10.672121885833528, 11.559643459415552, 12.542984722096367, 13.430316573306213, 14.361001952852817, 15.352490017497429, 15.508801399370832, 14.530140617548641, 12.628166113188389, 13.598419135338178, 14.534114399611909, 14.532219395168868, 13.473065881714733, 12.555309520184325, 11.5372177005568, 10.63945544305782, 9.683007212946546, 8.636896605672854, 8.000489661427478, 8.870865814668178, 9.599501766224657, 10.604486179111738, 11.491956852785453, 12.473682873219639, 13.526827747628738, 14.371388985745963, 14.558073320193932, 13.627329000740067, 11.64401156007363, 12.657851890437511, 13.63987619279008, 13.55534731943637, 12.53365969064768, 11.566232543796112, 10.584304291463788, 9.608432158711256, 8.641844335942812, 7.699117387040389, 7.001542105146485, 7.838901373513029, 8.650501948426475, 9.644258929035278, 10.564519984817798, 11.490191171232976, 12.494075679487086, 13.435550325727776, 13.653318924888882, 12.688193053781394, 10.7689375661409, 11.775224080747703, 12.751827440247657, 12.57831748074419, 11.588920160070602, 10.621403380077275, 9.696315428572577, 8.729456827706795, 7.7344185776263314, 6.772734382605946, 5.93918823776777, 6.780325969755216, 7.703895404385377, 8.648976834986907, 9.570650671566948, 10.535865214668997, 11.565505850319113, 12.510531520848092, 12.66432749809278, 11.710334170091208, 9.7843833521222, 10.818586094980596, 11.801452897027607, 11.596219881503812, 10.638148167870348, 9.654848937848728, 8.718758333912737, 7.742674344725627, 6.728911973866051, 5.787767014426229, 4.871717493563358, 5.840991754565037, 6.723691570905187, 7.683547301149891, 8.64456126139481, 9.69567751528877, 10.608078914147617, 11.567513990005894, 11.701016393530574, 10.692264285402604, 10.704143152722331, 11.776856577583239, 11.581978584775335, 10.611328181980607, 9.624463429153257, 8.786790060037948, 7.798032248505677, 6.8277871274500495, 5.8407961873117795, 4.847744368248713, 3.89261580238111, 4.828106654419618, 5.762126276817042, 6.7393571378763575, 7.76557118223532, 8.677535926798532, 9.630986809137434, 10.600282462348588, 11.556946262047706, 11.618116299360716, 11.768669700597536, 11.65164659436471, 10.637399448784926, 9.656246366226844, 8.607563269273314, 7.739381337899415, 6.889716348466743, 5.937826311323057, 4.873755680551997, 3.9316899770119464, 2.9594141862164607, 3.867831491741076, 4.8601546282224515, 5.796253729832118, 6.771349938798729, 7.72059169543119, 8.728653247516881, 9.681587068748767, 10.69049558646009, 11.624190114324003, 11.622182697911782, 10.695112725400968, 9.662474221750186, 8.701385039621734, 7.672272723388334, 6.738136774210398, 5.825282463742316, 4.909506258275856, 3.9354889134640394, 2.9436228499498345, 1.9365084260456755, 2.8603598396908767, 3.8443911261226167, 4.8101554191066045, 5.74952778429813, 6.743843369564447, 7.77950808439773, 8.728877913237062, 9.718771883028209, 10.696930675596906, 10.666131928731154, 9.700486951512973, 8.734757718592695, 7.745938031073503, 6.740931471335487, 5.810638321805159, 4.829257331766193, 3.9364317012094405, 2.9706222289123834, 1.9871648637399981, 0.9905583535918137, 1.87154902695859, 2.8466839942401716, 3.8684501012427748, 4.810075602176961, 5.853723765228376, 6.785638283484684, 7.758543485232616, 8.826559696175744, 9.737617453547864, 9.744641621118493, 8.774326754754835, 7.747330146731047, 6.799453902634033, 5.747786687968467, 4.803589801920697, 3.829395488954267, 2.869846894433528, 1.9134553684495703, 0.9525460870033938, 0.0, 0.935470129855611, 1.8797372672697188, 2.9038576910012677, 3.9295976956050165, 4.878633420712221, 5.836652293950952, 6.778708796108403, 7.778266186868066, 8.710463861459727, 10.707307312821275, 9.646071465287205, 8.699900875671347, 7.732070100585647, 6.737247359202637, 5.742026480053749, 4.767546383850507, 3.862962205394746, 2.870568557625974, 1.9280108363375885, 1.0126906038209753, 1.896763073940905, 2.870765794012212, 3.9329657742573696, 4.903167869575291, 5.847735548219376, 6.7895260326883395, 7.763929468510401, 8.738985846517263, 9.743480628213545, 11.66113320003888, 10.700963466386227, 9.672771859887806, 8.65398795812221, 7.657625338889227, 6.691770214731446, 5.7369369648184545, 4.802061041263926, 3.807950035155337, 3.00276030027065, 1.9559356179730492, 2.935150259135992, 3.911430784410614, 4.838631697464488, 5.8960756177299, 6.811491952396841, 7.819850615339507, 8.784112664956718, 9.70867125234223, 10.679584337152162, 12.602145434905886, 11.626155187963484, 10.617088639084072, 9.581522147332043, 8.697271013997506, 7.745036832582943, 6.763418295674655, 5.74436774495715, 4.751509008131516, 4.051267179173727, 3.0036279396455305, 3.9625599926007693, 4.853381876169881, 5.8850923244401026, 6.837822595636449, 7.848458388720723, 8.834422248275587, 9.854519527644658, 10.68001430880326, 11.624797866389677, 13.495230436066553, 12.481092012945618, 11.530124686385545, 10.584170713872371, 9.661315532023272, 8.676638688173421, 7.712234005712101, 6.755696727421269, 5.78330283604118, 5.028347324927525, 4.042863611976463, 5.01680623097327, 5.784735922161928, 6.716330030418817, 7.688933033596749, 8.754330550226578, 9.699540784140039, 10.75622412078325, 11.67755947533976, 12.601247453200315, 14.422996457237472, 13.449409556638866, 12.510124362426025, 11.582519540407269, 10.599823877902953, 9.616008289838957, 8.650241846318563, 7.7388956125138595, 6.816544643181007, 5.942331782699352, 4.99956101463156, 5.978551975560668, 6.719784234139362, 7.705421508817225, 8.756972281288178, 9.745338593498785, 10.657956827290507, 11.66684486885712, 12.68682792130776, 13.530302031796527, 15.392948295778861, 14.49803746748518, 13.555858807576742, 12.605249671888545, 11.660441862149584, 10.614489686309943, 9.651312103977958, 8.808663530785457, 7.8144022865307505, 6.868936135544907, 5.996056476523336, 6.922088203423664, 7.712216121916374, 8.6560318265844, 9.595816954445837, 10.595402420376137, 11.605096890952435, 12.584841589987958, 13.619707626744939, 14.560878037938174, 16.320633929413038, 15.467758734725674, 14.556652703701136, 13.574535096729795, 12.637928664237933, 11.563634264632613, 10.608984644667133, 9.773923627210035, 8.82765757730089, 7.940633415925509, 7.0437815889567545, 7.9247755812878085, 8.75961840600269, 9.663004565418243, 10.568039109508472, 11.57158851760617, 12.585205381068699, 13.602150530256104, 14.55334286540731, 15.621113533172196], [15.609381548424436, 14.630625654680607, 13.592764488638585, 12.637767939122284, 11.588364717445733, 10.616125749811548, 9.781608099420874, 8.791012997292672, 8.104680350515258, 8.991655877692734, 9.915363466684628, 10.714111228213246, 11.644090913434292, 12.485200955505706, 13.42855717615594, 14.4378801711893, 15.489666504519663, 16.418870677391034, 17.430019389366496, 18.240376284775177, 14.539266096051666, 15.484286054149608, 14.60024109950629, 13.610249128264568, 12.611490016846428, 11.589954893381597, 10.824074117947555, 9.820138341679511, 9.033133789493018, 9.993699117272142, 10.926128698313269, 10.879677231932549, 11.809100940926001, 12.65481476027706, 13.688053921401828, 14.553193006264829, 15.398000823832497, 16.364079664303187, 17.38781412435708, 17.28461955383884, 13.53348430883502, 14.47921231466197, 15.482858491538039, 14.624564780978906, 13.569629829440423, 12.58797270336063, 11.810384503551193, 10.83495601232484, 10.015042412201572, 11.011505342216985, 10.85623595313436, 9.914269617289449, 10.77984029603298, 11.669853289216633, 12.662970642485702, 13.61379441782965, 14.426727199189814, 15.414327888251517, 16.373808508071026, 16.385236067036153, 12.606566884621097, 13.575650219772209, 14.619955656577117, 15.574790717345131, 14.579522390674233, 13.586349258459496, 12.809578086107514, 11.88334070735912, 11.06656794038725, 10.562259542079207, 9.830766943976105, 8.952123080414156, 9.800576037294153, 10.688097610876177, 11.671438873556994, 12.55877072476684, 13.489456104313444, 14.480944168958056, 15.408316326848642, 15.465610747404252, 11.692695983332776, 12.662949005482565, 13.598644269756296, 14.627255288504902, 14.383934208086597, 13.466177846556187, 12.448086026928666, 11.550323769429685, 10.593875539318411, 9.547764932044718, 8.901201114899294, 7.9993199661288035, 8.727955917685282, 9.732940330572363, 10.62041100424608, 11.602137024680266, 12.652151581084398, 13.435918855890353, 14.406353943188332, 14.562799130595678, 10.708541430218018, 11.7223817605819, 12.704406062934467, 13.660299703246556, 13.444528017019543, 12.477100870167973, 11.495172617835653, 10.519300485083122, 9.552712662314677, 8.609985713412254, 7.902253558618301, 6.967355524973654, 7.7789560998871, 8.772713080495903, 9.692974136278425, 10.618645322693602, 11.619399512942746, 12.500080195872167, 13.443518904691908, 13.623663183637005, 9.83346743628529, 10.839753950892094, 11.816357310392048, 12.791083060991166, 12.499788486442466, 11.532271706449137, 10.607183754944439, 9.640325154078656, 8.645286903998194, 7.68360270897781, 6.841946884332465, 5.908780121215841, 6.832349555846003, 7.777430986447532, 8.699104823027575, 9.664319366129623, 10.635522835385357, 11.575061390992483, 12.527406841622257, 12.64580429994682, 8.848913222266589, 9.883115965124986, 10.865982767171998, 11.828418063201527, 11.549016494242212, 10.565717264220591, 9.6296266602846, 8.65354267109749, 7.6397803002379145, 6.698635340798093, 5.782585819935221, 4.969445906025663, 5.852145722365813, 6.812001452610517, 7.773015412855436, 8.761746713065309, 9.672608784292006, 10.632043860150285, 11.576151554230211, 11.627734415258216, 9.76867302286672, 10.841386447727627, 11.796026945321511, 11.546798311836218, 10.559933559008869, 9.722260189893559, 8.708900574877543, 7.738655453821914, 6.751664513683644, 5.758612694620577, 4.803484128752975, 3.956560805880244, 4.8905804282776675, 5.867811289336983, 6.8301010523797085, 7.742065796942921, 8.695516679281823, 9.664812332492978, 10.621476132192097, 11.655294595935631, 10.833199570741925, 11.782382814792472, 11.572869578640537, 10.591716496082455, 9.543033399128925, 8.674851467755026, 7.825186478322355, 6.85904129669524, 5.794970665924181, 4.85290496238413, 3.8702825125883256, 2.9323613618854654, 3.9246844983668403, 4.860783599976508, 5.835879808943118, 6.7851215655755786, 7.79318311766127, 8.746116938893156, 9.755025456604479, 10.688719984468392, 11.686216605519823, 11.630582855256579, 10.597944351605797, 9.636855169477343, 8.607742853243945, 7.673606904066009, 6.760752593597927, 5.844976388131467, 4.870959043319651, 3.8790929798054457, 2.8473767524175404, 1.924889709835266, 2.9089209962670055, 3.8746852892509938, 4.814057654442519, 5.8083732397088355, 6.844037954542118, 7.79340778338145, 8.783301753172596, 9.761460545741295, 11.601602058586765, 10.635957081368584, 9.670227848448306, 8.681408160929115, 7.676401601191098, 6.7461084516607706, 5.7647274616218045, 4.871901831065052, 3.9060923587679945, 2.9226349935956093, 1.9014266799636783, 0.9360788971029791, 1.9112138643845604, 2.9329799713871636, 3.87460547232135, 4.918253635372765, 5.850168153629073, 6.823073355377005, 7.891089566320133, 8.802147323692253, 10.680111750974104, 9.709796884610446, 8.682800276586658, 7.734924032489644, 6.683256817824078, 5.739059931776308, 4.764865618809878, 3.805317024289139, 2.8489254983051815, 1.888016216859005, 0.935470129855611, 0.0, 0.9442671374141078, 1.9683875611456567, 2.9941275657494053, 3.94316329085661, 4.901182164095341, 5.843238666252792, 6.842796057012455, 7.774993731604116, 11.642777442676886, 10.581541595142816, 9.635371005526958, 8.667540230441258, 7.672717489058249, 6.67749660990936, 5.703016513706118, 4.798432335250357, 3.806038687481585, 2.8634809661931997, 1.9481607336765863, 0.9612929440852941, 1.9352956641566008, 2.9974956444017584, 3.967697739719679, 4.912265418363765, 5.854055902832728, 6.82845933865479, 7.803515716661653, 8.808010498357934, 12.59660332989449, 11.636433596241838, 10.608241989743417, 9.589458087977821, 8.593095468744838, 7.627240344587057, 6.672407094674066, 5.737531171119537, 4.7434201650109475, 3.938230430126261, 2.89140574782866, 1.9996801292803812, 2.975960654555003, 3.903161567608877, 4.960605487874289, 5.8760218225412295, 6.884380485483896, 7.848642535101107, 8.773201122486618, 9.744114207296551, 13.537615564761497, 12.561625317819095, 11.552558768939683, 10.516992277187654, 9.632741143853117, 8.680506962438553, 7.698888425530266, 6.67983787481276, 5.686979137987127, 4.986737309029338, 3.9390980695011413, 3.0270898627451586, 3.91791174631427, 4.949622194584491, 5.9023524657808375, 6.912988258865112, 7.898952118419976, 8.919049397789047, 9.744544178947649, 10.689327736534064, 14.430700565922164, 13.41656214280123, 12.465594816241156, 11.519640843727982, 10.596785661878881, 9.61210881802903, 8.647704135567711, 7.69116685727688, 6.7187729658967905, 5.963817454783136, 4.978333741832073, 4.081336101117659, 4.8492657923063165, 5.780859900563206, 6.753462903741138, 7.818860420370967, 8.764070654284428, 9.820753990927638, 10.742089345484148, 11.665777323344702, 15.358466587093082, 14.384879686494475, 13.445594492281634, 12.517989670262878, 11.535294007758562, 10.551478419694567, 9.585711976174172, 8.67436574236947, 7.752014773036617, 6.877801912554962, 5.93503114448717, 5.100549026655077, 5.784314104283751, 6.769951378961614, 7.8215021514325676, 8.809868463643173, 9.722486697434896, 10.73137473900151, 11.751357791452147, 12.594831901940914, 16.32841842563447, 15.433507597340789, 14.491328937432352, 13.540719801744155, 12.595911992005194, 11.549959816165552, 10.586782233833567, 9.744133660641069, 8.749872416386362, 7.804406265400517, 6.931526606378945, 6.119198713100633, 6.7767459920607624, 7.7205616967287884, 8.660346824590226, 9.659932290520526, 10.669626761096824, 11.649371460132347, 12.684237496889327, 13.625407908082563, 17.256104059268647, 16.403228864581283, 15.492122833556746, 14.510005226585404, 13.573398794093542, 12.499104394488223, 11.544454774522743, 10.709393757065646, 9.763127707156501, 8.87610354578112, 7.979251718812364, 7.121886090964777, 7.82414827614708, 8.727534435562632, 9.632568979652861, 10.636118387750559, 11.649735251213087, 12.666680400400494, 13.6178727355517, 14.685643403316586], [14.665114411010327, 13.686358517266498, 12.648497351224478, 11.693500801708177, 10.644097580031627, 9.671858612397441, 8.837340962006767, 7.846745859878564, 8.792452497517287, 9.744861579539792, 10.747644456783672, 11.635342589942317, 11.919341114887285, 12.7678891746345, 13.711245395284733, 14.675179487297216, 15.55058374302051, 16.479787915891883, 17.49825628768029, 18.447283268245204, 13.594998958637557, 14.5400189167355, 13.655973962092183, 12.665981990850462, 11.667222879432321, 10.64568775596749, 9.879806980533449, 8.875871204265405, 9.720905936495047, 10.68147126427417, 11.613900845315298, 11.751593922094145, 10.924984049285664, 11.770697868636725, 12.803937029761492, 13.66907611462449, 14.513883932192158, 15.479962772662846, 16.502470067930485, 17.388041391945418, 12.589217171420911, 13.534945177247861, 14.53859135412393, 13.6802976435648, 12.625362692026316, 11.643705565946524, 10.866117366137086, 9.890688874910733, 10.7028145592036, 11.699277489219014, 11.80050309054847, 10.786186307451045, 9.895723404392642, 10.785736397576297, 11.778853750845366, 12.729677526189311, 13.542610307549475, 14.530210996611178, 15.463802059982926, 16.43980497762849, 11.662299747206989, 12.6313830823581, 13.675688519163009, 14.630523579931022, 13.635255253260127, 12.642082121045389, 11.865310948693407, 10.939073569945013, 11.754340087389279, 11.506526679493316, 10.775034081390213, 9.824039770575752, 8.916459145653816, 9.80398071923584, 10.787321981916655, 11.6746538331265, 12.605339212673105, 13.588895040522946, 14.498309878760542, 15.399204204907374, 10.748428845918667, 11.718681868068456, 12.654377132342187, 13.682988151090793, 14.596110783011726, 13.68205710542905, 12.817825908178747, 11.888257649394632, 11.53814267673252, 10.492032069458826, 9.845468252313403, 8.8712366562904, 7.843839026044945, 8.848823438932026, 9.73629411260574, 10.718020133039927, 11.730964739703163, 12.514732014509118, 13.485167101807097, 14.415911421260962, 9.76427429280391, 10.778114623167792, 11.760138925520359, 12.716032565832448, 13.737720194621138, 13.421368007582082, 12.439439755249762, 11.46356762249723, 10.496979799728786, 9.554252850826362, 8.84652069603241, 7.911622662387763, 6.894839208246763, 7.888596188855566, 8.808857244638087, 9.734528431053265, 10.69821267156151, 11.578893354490932, 12.522332063310673, 13.548651946463778, 8.889200298871181, 9.895486813477985, 10.87209017297794, 11.846815923577058, 12.80354916613444, 12.476538843863246, 11.551450892358547, 10.584592291492765, 9.589554041412303, 8.627869846391919, 7.786214021746574, 6.85304725862995, 5.9482326642056655, 6.893314094807195, 7.814987931387238, 8.780202474489286, 9.714335994004122, 10.653874549611247, 11.606220000241022, 12.560213328242593, 7.90464608485248, 8.938848827710878, 9.92171562975789, 10.884150925787418, 11.852777173934186, 11.5099844016347, 10.573893797698709, 9.597809808511599, 8.584047437652023, 7.642902478212202, 6.72685295734933, 5.913713043439771, 4.968028830725475, 5.927884560970179, 6.888898521215099, 7.840559871684074, 8.75142194291077, 9.71085701876905, 10.654964712848976, 11.663716820976946, 8.824405885452611, 9.897119310313519, 10.851759807907403, 11.822410210702131, 11.504200696422977, 10.666527327307668, 9.65316771229165, 8.682922591236022, 7.6959316510977525, 6.702879832034686, 5.747751266167083, 4.9008279432943525, 4.00646353663733, 4.983694397696646, 5.908914210998473, 6.820878955561685, 7.774329837900588, 8.743625491111743, 9.700289290810861, 10.734107754554396, 9.888932433327817, 10.838115677378363, 11.852362822958147, 11.535983633496564, 10.487300536543033, 9.619118605169135, 8.769453615736461, 7.803308434109349, 6.739237803338289, 5.797172099798239, 4.814549650002434, 3.8766284992995734, 3.003497656985605, 3.9395967585952727, 4.914692967561883, 5.863934724194343, 6.8489159802471615, 7.801849801479047, 8.81075831919037, 9.744452847054283, 10.741949468105714, 11.778459787543342, 11.542211489019905, 10.581122306891452, 9.552009990658053, 8.617874041480118, 7.705019731012035, 6.789243525545574, 5.815226180733759, 4.823360117219553, 3.791643889831648, 2.869156847249374, 1.98773415488577, 2.9534984478697583, 3.892870813061284, 4.8871863983276, 5.899770817128011, 6.849140645967342, 7.8390346157584885, 8.817193408327187, 11.686092125183958, 11.580224218782693, 10.614494985862414, 9.625675298343221, 8.620668738605206, 7.690375589074878, 6.708994599035912, 5.816168968479159, 4.850359496182103, 3.866902131009717, 2.845693817377786, 1.8803460345170868, 0.9900270230033252, 1.988712833973056, 2.9303383349072423, 3.9739864979586574, 4.905901016214965, 5.878806217962898, 6.9468224289060245, 7.857880186278145, 11.624378888388213, 10.654064022024555, 9.627067414000766, 8.679191169903753, 7.6275239552381855, 6.683327069190415, 5.709132756223986, 4.749584161703247, 3.793192635719289, 2.8322833542731125, 1.8797372672697188, 0.9442671374141078, 0.0, 1.0241204237315489, 2.0498604283352977, 2.9988961534425025, 3.956915026681233, 4.8989715288386835, 5.898528919598347, 6.830726594190008, 12.587044580090994, 11.525808732556925, 10.579638142941066, 9.611807367855365, 8.616984626472355, 7.621763747323468, 6.647283651120226, 5.742699472664465, 4.750305824895693, 3.8077481036073073, 2.8924278710906943, 1.9055600814994018, 0.991028526742493, 2.053228506987651, 3.0234306023055715, 3.9679982809496566, 4.90978876541862, 5.8841922012406815, 6.859248579247544, 7.863743360943826, 13.540870467308599, 12.580700733655947, 11.552509127157526, 10.53372522539193, 9.537362606158947, 8.571507482001165, 7.616674232088173, 6.6817983085336445, 5.687687302425056, 4.882497567540369, 3.835672885242768, 2.943947266694489, 2.0316935171408947, 2.958894430194769, 4.01633835046018, 4.931754685127122, 5.940113348069788, 6.904375397687, 7.828933985072511, 8.799847069882443, 14.481882702175605, 13.505892455233203, 12.496825906353791, 11.461259414601763, 10.577008281267226, 9.624774099852662, 8.643155562944374, 7.6241050122268685, 6.631246275401235, 5.931004446443446, 4.88336520691525, 3.91881332348013, 2.9736446089001616, 4.005355057170383, 4.958085328366729, 5.968721121451004, 6.954684981005868, 7.97478226037494, 8.800277041533542, 9.745060599119956, 15.374967703336273, 14.360829280215338, 13.409861953655264, 12.463907981142091, 11.54105279929299, 10.556375955443139, 9.59197127298182, 8.635433994690988, 7.663040103310899, 6.908084592197245, 5.918689387867346, 4.874756425043473, 3.9049986548922084, 4.836592763149097, 5.809195766327029, 6.874593282956859, 7.819803516870319, 8.87648685351353, 9.797822208070041, 10.721510185930594, 16.302733724507192, 15.329146823908584, 14.389861629695742, 13.462256807676987, 12.47956114517267, 11.495745557108675, 10.529979113588281, 9.61863287978358, 8.696281910450725, 7.7100829026540065, 6.767312134586215, 5.788321173657105, 4.840046966869643, 5.825684241547506, 6.877235014018459, 7.865601326229065, 8.778219560020787, 9.787107601587401, 10.807090654038042, 11.650564764526806, 17.272685563048583, 16.377774734754897, 15.43559607484646, 14.484986939158263, 13.540179129419302, 12.49422695357966, 11.531049371247676, 10.668928833663315, 9.671103778115432, 8.636687255499561, 7.733002587002989, 6.806970860102661, 5.832478854646655, 6.776294559314681, 7.716079687176118, 8.71566515310642, 9.725359623682717, 10.70510432271824, 11.73997035947522, 12.681140770668456, 18.20037119668276, 17.347496001995392, 16.436389970970854, 15.454272363999513, 14.51766593150765, 13.443371531902331, 12.488721911936851, 11.634188930087893, 10.684359068885572, 9.708384535880164, 8.780727699436408, 7.809658237966805, 6.879881138732973, 7.783267298148525, 8.688301842238754, 9.691851250336452, 10.70546811379898, 11.722413262986386, 12.673605598137591, 13.741376265902478], [13.642564292259035, 12.768668842635915, 11.802264163869285, 10.847267614352985, 9.927760036189676, 9.010574307789023, 8.331402589440367, 8.77141120526756, 9.717117842906282, 10.669526924928787, 11.672309802172666, 12.560007935331312, 12.814544136961066, 11.855304310206085, 12.798660530856319, 13.698354517140386, 14.57375877286368, 15.502962945735051, 16.521431317523458, 17.43026471227963, 12.570878534906011, 13.515898493003954, 12.80974077473699, 11.81974880349527, 10.950885335590371, 9.984403451359071, 9.373868607967049, 9.8005365496544, 10.645571281884042, 11.606136609663166, 12.538566190704293, 12.646796944167924, 11.820187071359445, 10.858113004208311, 11.891352165333078, 12.69225114446766, 13.537058962035328, 14.503137802506016, 15.485451511964913, 16.371022835979844, 11.565096747689365, 12.510824753516316, 13.514470930392385, 12.84757046017756, 11.920673590810662, 10.982421261338105, 10.369007167405213, 10.815354220299728, 11.627479904592596, 12.623942834608009, 12.720629552141279, 11.681389329524825, 10.790926426466424, 9.873151533147883, 10.866268886416952, 11.752852556032481, 12.565785337392645, 13.553386026454348, 14.446783504017354, 15.422786421662916, 10.638179323475443, 11.607262658626555, 12.651568095431463, 13.606403156199477, 12.973970948651708, 11.98079781643697, 11.368200749961535, 11.863738915334007, 12.679005432778274, 12.529952446473278, 11.695160542983023, 10.719242792649531, 9.811662167727597, 8.891395854807428, 9.810497011759825, 10.69782886296967, 11.628514242516275, 12.571876484557373, 13.48129132279497, 14.382185648941801, 9.724308422187121, 10.69456144433691, 11.630256708610641, 12.658867727359247, 13.653005961956646, 13.020772800820632, 12.335137858341689, 12.812922994783627, 12.56156844371248, 11.515457836438788, 10.765594713906212, 9.76643967836418, 8.739042048118726, 7.936238574503613, 8.75946914244891, 9.741195162883097, 10.713946183737589, 11.497713458543545, 12.468148545841524, 13.39889286529539, 8.740153869072362, 9.753994199436244, 10.736018501788813, 11.691912142100902, 12.713599770889592, 13.729475723520338, 13.288051267434701, 12.48699338947719, 11.520405566708746, 10.577678617806322, 9.76664715762522, 8.831749123980574, 7.7900422303205445, 6.976011324427153, 7.832032274481256, 8.74569500834798, 9.681194115595936, 10.56187479852536, 11.5053135073451, 12.531633390498206, 7.865079875139632, 8.871366389746434, 9.847969749246388, 10.822695499845507, 11.779428742402889, 12.784646559801502, 12.574876659338509, 11.608018058472727, 10.612979808392263, 9.651295613371879, 8.706340483339384, 7.7731737202227595, 6.843435686279447, 5.980729230378783, 6.838162961230407, 7.791369051784001, 8.69731743803855, 9.636855993645675, 10.58920144427545, 11.54319477227702, 6.880525661120931, 7.9147284039793275, 8.897595206026338, 9.860030502055867, 10.828656750202635, 11.811955980224255, 11.597319564678669, 10.621235575491559, 9.607473204631983, 8.666328245192162, 7.75027872432929, 6.833839505032581, 5.863231852799257, 4.951059590813348, 5.912073551058268, 6.823541315718502, 7.734403386945198, 8.693838462803477, 9.637946156883404, 10.646698265011374, 7.800285461721064, 8.872998886581971, 9.827639384175852, 10.798289786970578, 11.836073974892637, 11.690647751039215, 10.676593479271611, 9.706348358215983, 8.719357418077713, 7.726305599014646, 6.771177033147043, 5.835686181108535, 4.901666558711112, 3.9941226958010123, 4.891895655032901, 5.803860399596113, 6.757311281935015, 7.72660693514617, 8.683270734845287, 9.7129780671093, 8.864812009596267, 9.813995253646814, 10.828242399226598, 11.753371602724341, 11.511420960274581, 10.643239028900682, 9.79357403946801, 8.827428857840898, 7.763358227069839, 6.821292523529788, 5.838670073733983, 4.894907998614125, 3.8987006790593854, 2.9225782026297, 3.8976744115963102, 4.846916168228771, 5.824795556515614, 6.7777293777475, 7.7866378954588225, 8.720332423322736, 9.717829044374167, 10.754339363811795, 11.786977867462577, 11.605242730623, 10.5761304143896, 9.641994465211665, 8.729140154743584, 7.813363949277122, 6.839346604465306, 5.847480540951103, 4.815764313563197, 3.887436346563925, 2.9022441848881737, 1.9364798919041855, 2.875852257095711, 3.8701678423620276, 4.875650393396462, 5.825020222235794, 6.81491419202694, 7.793072984595638, 10.664962437738861, 11.630607414957042, 11.638615409593964, 10.64979572207477, 9.644789162336755, 8.714496012806427, 7.7331150227674605, 6.840289392210707, 5.87447991991365, 4.891022554741266, 3.869814241109335, 2.9044664582486357, 2.0141474467348743, 0.964592410241507, 1.9062179111756934, 2.949866074227109, 3.881780592483417, 4.854685794231349, 5.922702005174477, 6.833759762546597, 11.594320929295485, 11.678184445756104, 10.651187837732316, 9.703311593635302, 8.651644378969735, 7.707447492921964, 6.733253179955534, 5.773704585434795, 4.8173130594508375, 3.8564037780046614, 2.9038576910012677, 1.9683875611456567, 1.0241204237315489, 0.0, 1.0257400046037488, 1.9747757297109534, 2.9327946029496843, 3.8748511051071346, 4.874408495866798, 5.806606170458459, 12.56525917817112, 12.549929156288474, 11.603758566672616, 10.635927791586914, 9.641105050203905, 8.645884171055016, 7.6714040748517744, 6.766819896396013, 5.7744262486272415, 4.831868527338856, 3.9165482948222428, 2.9296805052309507, 2.0151489504740416, 1.029108083256102, 1.9993101785740226, 2.9438778572181077, 3.8856683416870714, 4.860071777509132, 5.835128155515996, 6.839622937212278, 13.519085065388724, 13.604821157387496, 12.576629550889075, 11.557845649123479, 10.561483029890496, 9.595627905732714, 8.640794655819722, 7.705918732265193, 6.7118077261566045, 5.906617991271918, 4.859793308974316, 3.9517814665764375, 2.956358862529891, 2.0291579494760166, 3.0106261912920536, 3.9076342613955726, 4.915992924338239, 5.88025497395545, 6.804813561340962, 7.775726646150895, 14.42407643112957, 14.530012878964753, 13.52094633008534, 12.485379838333312, 11.601128704998775, 10.648894523584211, 9.667275986675921, 8.648225435958418, 7.6553666991327844, 6.930803457230548, 5.883164217702351, 4.8434786688691265, 3.898309954289158, 3.078311542798959, 3.9523731691986024, 4.944600697719455, 5.930564557274319, 6.95066183664339, 7.776156617801994, 8.72094017538841, 15.41709583042389, 15.384949703946887, 14.433982377386814, 13.48802840487364, 12.565173223024539, 11.580496379174688, 10.616091696713367, 9.659554418422536, 8.687160527042447, 7.907883602984346, 6.843354733256342, 5.799421770432469, 4.829664000281205, 4.132921633224369, 4.926164026575729, 5.984992327505703, 6.899003849166244, 7.878706620868355, 8.773701784338492, 9.697389762199048, 16.368729601593408, 16.353267247640133, 15.413982053427292, 14.486377231408536, 13.50368156890422, 12.519865980840224, 11.554099537319829, 10.642753303515127, 9.65870017388026, 8.634748248043001, 7.691977479975209, 6.712986519046101, 5.764712312258639, 5.19846867801968, 5.994203274267159, 6.976000370777909, 7.857419892316713, 8.866307933883327, 9.782970230306493, 10.62644434079526, 17.327223964184213, 17.401895158486447, 16.459716498578008, 15.509107362889813, 14.564299553150851, 13.51834737731121, 12.555169794979223, 11.59359417905231, 10.595769123504427, 9.561352600888556, 8.657667932391984, 7.7316362054916565, 6.7571442000356505, 6.270356186748282, 7.054795382567701, 7.978958269534845, 8.838264168409044, 9.818008867444567, 10.738165827768734, 11.67933623896197, 18.25490959781839, 17.54822184230867, 16.54605921788788, 15.569071133799545, 14.656119328457708, 13.739909592715513, 12.796050491189048, 12.558854275476888, 11.609024414274566, 10.633049881269159, 9.705393044825403, 8.7343235833558, 7.8045464841219685, 7.277328925582125, 8.027017537630336, 8.975513706494501, 9.859234926443788, 10.869214917473219, 11.755915923507008, 12.740983102183657], [12.616824287655286, 11.742928838032167, 10.809999489026836, 9.855002939510536, 8.936648674536166, 8.077341730075892, 9.031624616683823, 9.778582818190268, 10.724289455828991, 11.676698537851497, 12.679481415095376, 13.567179548254021, 13.707540232805142, 12.697078673163142, 11.999530273597921, 12.750834769201207, 13.626239024924502, 14.555443197795872, 15.573474967010423, 16.46878730244084, 11.545138530302262, 12.490158488400205, 11.817476099894542, 10.82748412865282, 9.95977397393686, 9.05117087364594, 10.063604309887731, 10.807708162577107, 11.652742894806751, 12.613308222585875, 13.545737803627002, 13.55056785684122, 12.72395798403274, 11.699887367165369, 10.95187473265648, 11.744731396528481, 12.589539214096149, 13.555618054566837, 14.523974102126127, 15.409545426141056, 10.539356743085616, 11.485084748912566, 12.488730925788635, 11.85530578533511, 10.92956222915715, 10.049188683624974, 11.058742869325895, 11.822525833222436, 12.634651517515305, 13.631114447530717, 13.624400464814574, 12.58516024219812, 11.694697339139719, 10.71492589610494, 9.926791453740353, 10.805332808093302, 11.618265589453467, 12.605866278515169, 13.485306094178569, 14.461309011824131, 9.612439318871694, 10.581522654022805, 11.625828090827714, 12.58066315159573, 11.991135383440161, 11.04756523872384, 12.004456351663515, 12.870910528256715, 13.686177045700983, 13.433723359146573, 12.598931455656318, 11.623013705322826, 10.715433080400892, 9.733170217764485, 8.862977263820646, 9.750309115030491, 10.680994494577096, 11.610399074718588, 12.519813912956185, 13.420708239103016, 8.698568417583372, 9.668821439733161, 10.604516704006894, 11.6331277227555, 12.627265957352895, 12.087540223107501, 12.97139346004367, 13.820094607706334, 13.465339356385774, 12.419228749112083, 11.669365626579507, 10.670210591037474, 9.642812960792021, 8.778012937460671, 7.811949394509732, 8.793675414943918, 9.760730068832403, 10.53623604870476, 11.506671136002739, 12.437415455456604, 7.7144138644686135, 8.728254194832495, 9.710278497185062, 10.666172137497151, 11.687859766285841, 12.70373571891659, 13.64026296763879, 13.390764302150485, 12.42417647938204, 11.481449530479617, 10.670418070298515, 9.735520036653869, 8.69381314299384, 7.833605165490336, 6.8845125265420775, 7.792478893442793, 8.72797800069075, 9.600397388686574, 10.543836097506315, 11.57015598065942, 6.839339870535882, 7.845626385142685, 8.82222974464264, 9.796955495241757, 10.753688737799141, 11.758906555197754, 12.683994506702453, 12.511788971146022, 11.516750721065558, 10.555066526045174, 9.610111396012678, 8.676944632896054, 7.747206598952742, 6.850878108175119, 5.890643213291228, 6.838152936878814, 7.744101323133362, 8.67537858380689, 9.627724034436664, 10.581717362438235, 5.854785656517182, 6.888988399375578, 7.87185520142259, 8.83429049745212, 9.802916745598887, 10.786215975620507, 11.722306579556498, 11.525006488164854, 10.511244117305278, 9.570099157865457, 8.654049637002585, 7.737610417705876, 6.767002765472552, 5.854830503486644, 4.964553803119089, 5.8703252008133155, 6.781187272040012, 7.732361052964691, 8.676468747044618, 9.685220855172588, 6.7745454571173145, 7.847258881978222, 8.801899379572102, 9.77254978236683, 10.81033397028889, 11.718814840368177, 11.580364391944906, 10.610119270889278, 9.623128330751008, 8.63007651168794, 7.674947945820338, 6.73945709378183, 5.805437471384407, 4.897893608474308, 3.938679540127714, 4.850644284690927, 5.804095167029829, 6.765129525307384, 7.721793325006502, 8.68723806250555, 7.839072004992518, 8.788255249043065, 9.802502394622849, 10.727631598120594, 11.776314695074124, 11.668979033504431, 10.804337972952135, 9.751347855263468, 8.687277224492409, 7.745211520952358, 6.762589071156553, 5.7986789112874195, 4.802471591732681, 3.8263491153029956, 2.944458296691124, 3.8937000533235846, 4.845315467320537, 5.798249288552423, 6.807157806263746, 7.694592418718986, 8.692089039770417, 9.728599359208046, 10.761237862858827, 11.700304504333888, 11.60187041899335, 10.667734469815414, 9.754880159347334, 8.839103953880871, 7.846746957092627, 6.793926092411562, 5.739683310985768, 4.79120725923722, 3.8060150975614695, 2.8402508045774812, 1.922636142190525, 2.9169517274568415, 3.8961703042013855, 4.844333105837117, 5.834227075628263, 6.767332979991889, 9.639222433135112, 10.604867410353293, 11.5927258933705, 11.675535726678518, 10.670529166940502, 9.740236017410176, 8.75885502737121, 7.866029396814456, 6.900219924517399, 5.916762559345015, 4.881822790414947, 3.916475007554248, 2.9413400402726664, 1.868363322914803, 0.9267378219806165, 1.9703859850320318, 2.9023005032883398, 3.835725072962502, 4.896962000570728, 5.808019757942848, 10.6328435194567, 11.531027607111431, 11.676927842336063, 10.72905159823905, 9.677384383573482, 8.733187497525712, 7.758993184559284, 6.7994445900385445, 5.843053064054587, 4.88214378260841, 3.9295976956050165, 2.9941275657494053, 2.0498604283352977, 1.0257400046037488, 0.0, 0.9490357251072046, 1.9070545983459355, 2.849111100503386, 3.848668491263049, 4.78086616585471, 11.603781768332334, 12.587686964454791, 12.629498571276363, 11.661667796190663, 10.666845054807654, 9.671624175658765, 8.697144079455525, 7.792559900999763, 6.800166253230991, 5.857608531942605, 4.942288299425992, 3.9554205098346995, 3.040888955077791, 2.036279696178812, 1.0660776008608912, 1.952766495564597, 2.8599283370833226, 3.8343317729053834, 4.8093881509122465, 5.813882932608529, 12.557607655549939, 13.618491067228607, 13.602369555492823, 12.583585653727226, 11.587223034494244, 10.621367910336463, 9.666534660423471, 8.731658736868942, 7.737547730760354, 6.932357995875666, 5.885533313578065, 4.958953079499148, 3.963530475452601, 3.0363295623987265, 2.077393613578922, 2.916522899742062, 3.9237282494957917, 4.858174859641602, 5.779073556737213, 6.749986641547146, 13.462599021290785, 14.438589268233187, 14.546686334689088, 13.51111984293706, 12.626868709602523, 11.67463452818796, 10.693015991279673, 9.673965440562167, 8.681106703736534, 7.937975070153257, 6.890335830625061, 5.850650281791836, 4.905481567211868, 3.9782377430726465, 3.019140591485471, 3.953489336065944, 4.938299882431871, 5.928581722329542, 6.750416613198245, 7.69520017078466, 14.455618420585104, 15.388014905932122, 15.459722381990561, 14.513768409477388, 13.590913227628288, 12.606236383778437, 11.641831701317118, 10.685294423026285, 9.712900531646197, 8.915055215907055, 7.850526346179051, 6.806593383355178, 5.836835613203914, 4.96553445204053, 3.992931448862598, 4.993880965852192, 5.906739174323797, 6.856626506554507, 7.7479617797347435, 8.671649757595299, 15.407252191754623, 16.38083909235323, 16.43972205803104, 15.512117236012285, 14.52942157350797, 13.545605985443974, 12.57983954192358, 11.668493308118876, 10.665871786802969, 9.64191986096571, 8.699149092897919, 7.720158131968811, 6.771883925181348, 6.031081496835841, 5.060970696554028, 5.984889009124398, 6.865155217474266, 7.87404325904088, 8.757230225702743, 9.60070433619151, 16.365746554345424, 17.42301387493605, 16.59127391944473, 15.640664783756536, 14.756699236224758, 13.889923913779786, 13.570257041902911, 12.60076579197502, 11.602940736427136, 10.568524213811266, 9.664839545314694, 8.738807818414365, 7.76431581295836, 7.061347932716007, 6.12156280485457, 6.987846907881334, 7.8459994935665955, 8.825744192602118, 9.712425823164985, 10.65359623435822, 17.2934321879796, 16.600265491795636, 15.598539469948701, 14.621551385860366, 13.708599580518529, 12.940779335457115, 13.637824854146105, 13.566025888399597, 12.616196027197276, 11.640221494191868, 10.712564657748112, 9.74149519627851, 8.811718097044677, 8.045583611925428, 7.093784959917205, 7.984402344840991, 8.86697025160134, 9.87695024263077, 10.730175918903258, 11.715243097579908], [11.66778856254808, 10.793893112924962, 9.860963763919633, 8.905967214403333, 7.987612949428961, 8.923940831403788, 9.87822371801172, 10.660803666430855, 11.606510304069577, 12.558919386092082, 13.561702263335963, 14.449400396494609, 14.656575957912347, 13.646114398270347, 12.948565998705126, 11.96721533689112, 12.787877418033299, 13.71708159090467, 14.664500753290257, 15.559813088720675, 10.596102805195057, 11.541122763293, 10.868440374787339, 9.878448403545617, 9.010738248829655, 9.897769974973837, 10.910203411215628, 11.689929010817695, 12.534963743047337, 13.49552907082646, 14.427958651867588, 14.499603581948424, 13.672993709139945, 12.648923092272573, 11.900910457763684, 10.961111964218395, 11.751177607204946, 12.717256447675634, 13.614999888405961, 14.50057121242089, 9.590321017978411, 10.536049023805361, 11.53969520068143, 10.906270060227907, 9.980526504049946, 10.895787784952871, 11.905341970653792, 12.704746681463023, 13.51687236575589, 14.513335295771302, 14.57343618992178, 13.534195967305324, 12.643733064246923, 11.663961621212145, 10.875827178847558, 10.021713375783216, 10.779903982562264, 11.739279393472083, 12.576331880458403, 13.552334798103965, 8.663403593764489, 9.6324869289156, 10.676792365720509, 11.631627426488524, 11.042099658332956, 11.894164340051736, 12.851055452991412, 13.753131376497302, 14.568397893941569, 14.382759084253777, 13.547967180763525, 12.572049430430031, 11.664468805508097, 10.68220594287169, 9.812012988927851, 8.966689682720405, 9.842632887685893, 10.701424860998422, 11.610839699236019, 12.51173402538285, 7.749532692476167, 8.719785714625957, 9.65548097889969, 10.684091997648295, 11.67823023224569, 12.734444369129108, 13.644140651624598, 14.573708910408714, 14.41437508149298, 13.368264474219288, 12.618401351686714, 11.619246316144679, 10.591848685899226, 9.727048662567876, 8.760985119616937, 8.010055982633832, 8.90513716393039, 9.627261834984594, 10.597696922282573, 11.528441241736438, 6.765378139361409, 7.77921846972529, 8.761242772077857, 9.717136412389946, 10.738824041178637, 11.754699993809385, 12.691227242531586, 13.667099375284117, 13.373212204489246, 12.430485255586822, 11.619453795405722, 10.684555761761075, 9.642848868101044, 8.78264089059754, 7.833548251649281, 6.93688598854078, 7.8723850957887365, 8.691423174966408, 9.634861883786149, 10.661181766939254, 5.8903041454286775, 6.89659066003548, 7.873194019535435, 8.847919770134553, 9.804653012691936, 10.80987083009055, 11.734958781595248, 12.70181738246103, 12.465786446172762, 11.504102251152378, 10.559147121119885, 9.625980358003261, 8.696242324059947, 7.799913833282323, 6.839678938398432, 5.982560031976801, 6.888508418231349, 7.766404370086724, 8.718749820716498, 9.67274314871807, 4.905749931409977, 5.9399526742683735, 6.922819476315385, 7.885254772344915, 8.853881020491682, 9.837180250513303, 10.773270854449294, 11.749354843636404, 11.460279842412483, 10.519134882972661, 9.60308536210979, 8.686646142813082, 7.7160384905797565, 6.803866228593848, 5.913589528226293, 5.014732295911302, 5.9255943671379985, 6.823386839244526, 7.767494533324452, 8.749514572033496, 5.82550973201011, 6.898223156871017, 7.852863654464898, 8.823514057259626, 9.861298245181684, 10.769779115260972, 11.784408953131683, 11.559154995996483, 10.572164055858213, 9.579112236795146, 8.623983670927542, 7.688492818889035, 6.754473196491611, 5.846929333581512, 4.8877152652349185, 3.995051379788914, 4.948502262127816, 5.856155311587219, 6.812819111286337, 7.738202337398345, 6.890036279885313, 7.83921952393586, 8.853466669515644, 9.778595873013389, 10.827278969966919, 11.812693402483305, 11.75337369805934, 10.700383580370673, 9.636312949599613, 8.694247246059563, 7.711624796263758, 6.747714636394623, 5.751507316839886, 4.7753848404102, 3.893494021798328, 3.0381071484215716, 3.936341253600372, 4.889275074832258, 5.882020049663094, 6.745556693611781, 7.743053314663212, 8.779563634100839, 9.81220213775162, 10.751268779226683, 11.762569515851899, 11.61677019492262, 10.703915884454538, 9.788139678988076, 8.795782682199832, 7.742961817518767, 6.688719036092972, 5.740242984344424, 4.755050822668673, 3.7892865296846856, 2.8716718672977293, 2.0613588225548285, 2.9871960904812207, 3.895297380729912, 4.885191350521058, 5.818297254884684, 8.690186708027907, 9.655831685246088, 10.643690168263296, 11.704752898709716, 11.619564892047707, 10.68927174251738, 9.707890752478415, 8.815065121921661, 7.849255649624604, 6.86579828445222, 5.830858515522151, 4.865510732661452, 3.8903757653798707, 2.8173990480220072, 1.875773547087821, 1.0676394755848195, 1.993326289568175, 2.8866893478552975, 3.947926275463523, 4.858984032835643, 9.684342935493186, 10.581991882004226, 11.608988490028015, 11.678087323346254, 10.626420108680687, 9.682223222632917, 8.708028909666488, 7.748480315145749, 6.792088789161792, 5.831179507715615, 4.878633420712221, 3.94316329085661, 2.9988961534425025, 1.9747757297109534, 0.9490357251072046, 0.0, 0.9580188732387308, 1.9000753753961812, 2.8996327661558445, 3.8318304407475052, 10.694807554612169, 11.638651239347586, 12.561559218968315, 12.610703521297868, 11.615880779914859, 10.62065990076597, 9.64617980456273, 8.741595626106967, 7.749201978338196, 6.806644257049809, 5.891324024533197, 4.904456234941904, 3.986842542870977, 2.9185005444193983, 1.9482984491014774, 1.0037307704573923, 1.9108926119761178, 2.885296047798179, 3.860352425805042, 4.864847207501324, 11.648633441829773, 12.693543240446608, 13.573660511301291, 13.532621378834431, 12.536258759601449, 11.570403635443668, 10.615570385530676, 9.680694461976147, 8.68658345586756, 7.881393720982871, 6.83456903868527, 5.841173927739734, 4.845751323693188, 3.918550410639313, 2.92399271490682, 1.9674871746348574, 2.974692524388587, 3.909139134534398, 4.830037831630008, 5.800950916439941, 12.55362480757062, 13.529615054513021, 14.517977290497557, 14.460155568044264, 13.575904434709727, 12.623670253295165, 11.642051716386877, 10.623001165669372, 9.630142428843739, 8.820195918393845, 7.772556678865648, 6.732871130032423, 5.787702415452455, 4.8248368444005445, 3.865739692813369, 3.00445361095874, 3.9892641573246665, 4.979545997222338, 5.80138088809104, 6.746164445677455, 13.546644206864938, 14.479040692211957, 15.43000801877203, 15.462804134584593, 14.539948952735493, 13.555272108885642, 12.590867426424323, 11.63433014813349, 10.661936256753402, 9.797276064147642, 8.732747194419638, 7.6888142315957655, 6.719056461444501, 5.812133553368428, 4.839530550190496, 4.044845240744988, 4.957703449216592, 5.907590781447303, 6.798926054627539, 7.722614032488094, 14.498277978034457, 15.471864878633063, 16.411150072845903, 15.82517927548938, 15.033697788161303, 14.494641710551178, 13.528875267030784, 12.56387600101143, 11.548092635043556, 10.524140709206298, 9.581369941138506, 8.602378980209398, 7.654104773421936, 6.877680598163739, 5.9075697978819255, 5.035853284017194, 5.916119492367061, 6.925007533933675, 7.808194500595539, 8.651668611084306, 15.456772340625259, 16.514039661215886, 15.75291231255353, 14.802303176865333, 13.973079803914672, 14.83895963888699, 14.452477890143498, 13.482986640215607, 12.485161584667724, 11.450745062051853, 10.547060393555281, 9.621028666654952, 8.646536661198947, 7.907947034043905, 6.968161906182467, 6.03881118277413, 6.896963768459391, 7.876708467494913, 8.76339009805778, 9.704560509251015, 16.384457974259433, 15.691291278075472, 14.760177863057498, 13.783189778969163, 12.924980148208443, 13.88981506056432, 14.58686057925331, 14.448246736640185, 13.498416875437863, 12.522442342432456, 11.5947855059887, 10.623716044519096, 9.693938945285264, 8.892182713253325, 7.940384061245102, 7.035366619733787, 7.917934526494135, 8.927914517523565, 9.781140193796054, 10.766207372472703], [10.70976968930935, 9.83587423968623, 8.902944890680901, 7.947948341164602, 8.887662518575295, 9.83874635188267, 10.7930292384906, 11.575609186909736, 12.52131582454846, 13.473724906570965, 14.476507783814844, 15.36420591697349, 15.614594831151075, 14.604133271509076, 13.871709500896529, 12.862386505863167, 11.87744362339896, 12.806647796270331, 13.706481880051527, 14.601794215481945, 9.638083931956327, 10.58310389005427, 9.910421501548607, 8.920429530306885, 9.91078781797599, 10.812575495452718, 11.825008931694509, 12.604734531296575, 13.44976926352622, 14.410334591305343, 15.34276417234647, 15.457622455187156, 14.631012582378677, 13.606941965511302, 12.858929331002413, 11.856283133190441, 10.840743812570608, 11.806822653041296, 12.656981015167231, 13.54255233918216, 8.63230214473968, 9.578030150566631, 10.5816763274427, 9.948251186989175, 10.88057607319628, 11.810593305431752, 12.820147491132673, 13.619552201941904, 14.431677886234773, 15.428140816250185, 15.53145506316051, 14.492214840544056, 13.601751937485655, 12.621980494450874, 11.833846052086287, 10.916884544755263, 9.869470187927925, 10.781260520233353, 11.618313007219673, 12.594315924865235, 7.705384720525759, 8.67446805567687, 9.718773492481779, 10.673608553249792, 11.68106688875856, 12.674240020973297, 13.631131133912973, 14.564874116619603, 15.483203414420451, 15.34077795749251, 14.505986054002255, 13.530068303668763, 12.622487678746829, 11.640224816110418, 10.77003186216658, 9.862884472598159, 8.932199093051555, 9.743405987759692, 10.652820825997289, 11.55371515214412, 6.791513819237437, 7.761766841387226, 8.697462105660957, 9.726073124409563, 10.72021135900696, 11.776425495890377, 12.686121778385868, 13.615690037169983, 14.626356514510842, 14.32628334745802, 13.576420224925444, 12.57726518938341, 11.549867559137958, 10.685067535806605, 9.719003992855665, 8.909638441634764, 7.994703369296051, 8.669242961745864, 9.639678049043843, 10.570422368497708, 5.8073592661226785, 6.82119959648656, 7.803223898839128, 8.759117539151216, 9.780805167939906, 10.796681120570655, 11.733208369292855, 12.709080502045387, 13.67566832481383, 13.388504128825554, 12.577472668644452, 11.642574634999805, 10.600867741339776, 9.74065976383627, 8.791567124888012, 7.836468447541712, 6.961951301154397, 7.733404301727678, 8.676843010547419, 9.703162893700524, 4.932285272189947, 5.93857178679675, 6.915175146296705, 7.889900896895822, 8.846634139453206, 9.851851956851819, 10.776939908356518, 11.7437985092223, 12.738836759302764, 12.46212112439111, 11.517165994358615, 10.583999231241991, 9.654261197298679, 8.757932706521053, 7.797697811637162, 6.882142490977733, 5.97807462359701, 6.808385496847993, 7.760730947477767, 8.71472427547934, 3.9477310581712466, 4.981933801029643, 5.964800603076655, 6.927235899106185, 7.895862147252952, 8.879161377274572, 9.815251981210563, 10.791335970397673, 11.80509834125725, 11.477153756211393, 10.561104235348521, 9.644665016051812, 8.674057363818488, 7.76188510183258, 6.871608401465023, 5.914314754912235, 5.015160572503659, 5.865367966005795, 6.809475660085722, 7.791495698794764, 4.8674908587713785, 5.940204283632285, 6.894844781226168, 7.8654951840208955, 8.903279371942954, 9.811760242022242, 10.826390079892953, 11.79663520094858, 11.530182929096945, 10.537131110033878, 9.582002544166274, 8.646511692127767, 7.712492069730343, 6.804948206820244, 5.845734138473649, 4.894633838789846, 4.038068467493477, 4.898136438348488, 5.854800238047606, 6.780183464159613, 5.932017406646582, 6.88120065069713, 7.895447796276914, 8.820576999774659, 9.869260096728189, 10.854674529244575, 11.798497115330898, 11.658402453609403, 10.594331822838344, 9.652266119298293, 8.669643669502488, 7.705733509633355, 6.709526190078617, 5.733403713648931, 4.851512895037059, 3.937689607422504, 2.9783223803616408, 3.931256201593527, 4.924001176424364, 5.78753782037305, 6.7850344414244805, 7.821544760862109, 8.85418326451289, 9.793249905987953, 10.804550642613169, 11.738686591791105, 11.661934757693269, 10.746158552226808, 9.753801555438562, 8.700980690757497, 7.646737909331703, 6.698261857583155, 5.7130696959074045, 4.747305402923416, 3.8296907405364604, 2.960941281555761, 2.0291772172424896, 2.9372785074911816, 3.927172477282328, 4.860278381645953, 7.732167834789175, 8.697812812007356, 9.685671295024564, 10.746734025470984, 11.751740585209, 11.64729061575611, 10.665909625717145, 9.773083995160393, 8.807274522863336, 7.82381715769095, 6.788877388760883, 5.823529605900184, 4.848394638618602, 3.7754179212607384, 2.833792420326552, 1.9672219345857518, 1.035307416329444, 1.9286704746165668, 2.989907402224792, 3.900965159596912, 8.726324062254454, 9.623973008765494, 10.650969616789283, 11.598845860886296, 11.584438981919417, 10.640242095871647, 9.666047782905219, 8.70649918838448, 7.750107662400523, 6.789198380954346, 5.836652293950952, 4.901182164095341, 3.956915026681233, 2.9327946029496843, 1.9070545983459355, 0.9580188732387308, 0.0, 0.9420565021574504, 1.9416138929171136, 2.8738115675087745, 9.736788681373438, 10.680632366108854, 11.603540345729582, 12.574272378369134, 12.573899653153589, 11.5786787740047, 10.60419867780146, 9.699614499345698, 8.707220851576926, 7.764663130288541, 6.849342897771928, 5.862475108180635, 4.901648063349857, 3.833306064898278, 2.8631039695803575, 1.9185362909362724, 0.9528737387373871, 1.9272771745594481, 2.9023335525663114, 3.9068283342625936, 10.690614568591043, 11.735524367207876, 12.61564163806256, 13.534063024454925, 13.49427763284018, 12.528422508682398, 11.573589258769406, 10.638713335214877, 9.644602329106288, 8.839412594221603, 7.792040709440229, 6.755979448218614, 5.760556844172068, 4.833355931118193, 3.8387982353857, 2.8822926951137373, 2.0166736511498566, 2.9511202612956673, 3.872018958391278, 4.842932043201211, 11.59560593433189, 12.571596181274291, 13.559958417258825, 14.461597213664758, 14.53392330794846, 13.581689126533895, 12.600070589625606, 11.5810200389081, 10.588161302082467, 9.735001438872724, 8.687362199344527, 7.647676650511303, 6.702507935931335, 5.739642364879424, 4.780545213292249, 3.9192591314376197, 3.0312452840859363, 4.021527123983607, 4.8433620148523095, 5.788145572438725, 12.588625333626208, 13.521021818973226, 14.4719891455333, 15.417943118046473, 15.497967825974223, 14.513290982124373, 13.548886299663051, 12.592349021372218, 11.61995512999213, 10.712081584626521, 9.64755271489852, 8.603619752074646, 7.633861981923381, 6.726939073847308, 5.754336070669376, 4.944894809891322, 3.999684575977862, 4.949571908208572, 5.8409071813888085, 6.764595159249364, 13.540259104795727, 14.513846005394333, 15.453131199607174, 14.914745480855041, 15.897295176216588, 15.414652071427048, 14.447823384843119, 13.47868152149031, 12.462898155522437, 11.438946229685179, 10.496175461617387, 9.517184500688279, 8.568910293900815, 7.792486118642619, 6.822375318360805, 5.935902853163528, 4.958100619128331, 5.966988660694945, 6.850175627356808, 7.693649737845575, 14.498753467386528, 15.556020787977154, 14.842478517919192, 13.891869382230995, 14.836677191969956, 15.762103141078395, 15.36728341062238, 14.397792160694488, 13.399967105146604, 12.365550582530734, 11.461865914034162, 10.535834187133833, 9.561342181677828, 8.822752554522785, 7.882967426661347, 6.938860751920464, 5.9389448952206605, 6.918689594256183, 7.80537122481905, 8.746541636012285, 15.426439101020705, 14.733272404836741, 13.84974406842316, 12.872755984334825, 13.809362416826687, 14.812958562755725, 15.544879452492038, 15.363052257119065, 14.413222395916744, 13.437247862911336, 12.50959102646758, 11.538521564997978, 10.608744465764145, 9.806988233732206, 8.855189581723982, 7.9354161888801205, 6.959915653255405, 7.9698956442848345, 8.823121320557323, 9.808188499233973], [9.7677131871519, 8.893817737528781, 8.064292212644121, 8.890004843322052, 9.829719020732746, 10.78080285404012, 11.735085740648051, 12.517665689067186, 13.463372326705908, 14.415781408728414, 15.418564285972295, 16.306262419130938, 16.521825508793956, 15.511363949151958, 14.568007728501724, 13.558684733468363, 12.573741851004156, 11.981328925401531, 12.781374474951466, 13.676686810381884, 8.696027429798876, 9.641047387896819, 9.104457865324896, 9.862486032464336, 10.85284432013344, 11.754631997610169, 12.76706543385196, 13.546791033454026, 14.391825765683668, 15.352391093462792, 16.28482067450392, 16.39967895734461, 15.572904632246429, 14.526129825513442, 13.56517963621184, 12.552581360795637, 11.537042040175804, 10.92367094330112, 11.73187361006717, 12.6174449340821, 7.69024564258223, 8.63597364840918, 9.63961982528525, 10.670110882875031, 11.725045834413514, 12.706702960493306, 13.688268214311844, 14.561608704099354, 15.373734388392222, 16.370197318407634, 16.473511565317963, 15.434271342701509, 14.543808439643108, 13.541168354453013, 12.549039886090405, 11.613182772360458, 10.565768415533121, 9.85615311513329, 10.693205602119612, 11.669208519765174, 6.763328218368308, 7.7324115535194196, 8.776716990324328, 9.731552051092342, 10.739010386601109, 11.732183518815846, 12.689074631755522, 13.622817614462152, 14.66111030105754, 15.619291361188493, 15.448042556159708, 14.472124805826216, 13.564544180904281, 12.559412676112558, 11.485225696170698, 10.559182700203355, 9.62849732065675, 8.81829858265963, 9.727713420897228, 10.62860774704406, 5.849457317079986, 6.8197103392297755, 7.755405603503507, 8.784016622252112, 9.77815485684951, 10.834368993732927, 11.744065276228417, 12.673633535012533, 13.684300012353392, 14.614117990191268, 14.518476727082897, 13.519321691540863, 12.49192406129541, 11.617390821227277, 10.651327278276337, 9.744552825749912, 8.691001596901247, 7.744135556645802, 8.714570643943782, 9.645314963397647, 4.865302763965228, 5.879143094329109, 6.861167396681677, 7.817061036993766, 8.838748665782456, 9.854624618413204, 10.791151867135405, 11.767023999887936, 12.73361182265638, 13.676338771558804, 13.519529170801905, 12.584631137157258, 11.542924243497229, 10.67298304925694, 9.723890410308682, 8.760680205419318, 7.808721665159338, 6.808296896627617, 7.751735605447358, 8.778055488600463, 3.9902287700324965, 4.996515284639299, 5.973118644139254, 6.947844394738372, 7.9045776372957555, 8.909795454694368, 9.834883406199067, 10.801742007064849, 11.796780257145311, 12.789154166719339, 12.459222496516068, 11.526055733399444, 10.596317699456131, 9.690255991941724, 8.730021097057833, 7.806354248855339, 6.882330842563115, 5.883278091747933, 6.835623542377706, 7.7896168703792785, 3.005674556013796, 4.0398772988721925, 5.022744100919204, 5.985179396948734, 6.9538056450955015, 7.9371048751171225, 8.873195479053114, 9.849279468240224, 10.8630418390998, 11.804186798539622, 11.503160737505972, 10.586721518209265, 9.61611386597594, 8.70394160399003, 7.803931686885694, 6.83852651278984, 5.919416791469764, 4.940260560905735, 5.884368254985661, 6.849439196637313, 3.925434356613928, 4.9981477814748345, 5.952788279068717, 6.923438681863445, 7.9612228697855025, 8.869703739864791, 9.884333577735504, 10.854578698791132, 11.841569638929402, 11.479187612191328, 10.524059046323725, 9.588568194285218, 8.654548571887794, 7.747004708977695, 6.778057423894319, 5.818845596667451, 4.942324686459582, 3.9730290332484275, 4.929692832947545, 5.838126962002162, 4.9899609044891315, 5.939144148539679, 6.953391294119463, 7.878520497617208, 8.927203594570738, 9.912618027087124, 10.856440613173449, 11.859055790733711, 11.536388324995794, 10.594322621455744, 9.611700171659939, 8.647790011790805, 7.651582692236068, 6.675460215806382, 5.79356939719451, 4.861901365300109, 3.8937369972922133, 3.0061487964934663, 3.981944674266913, 4.845481318215599, 5.84297793926703, 6.879488258704658, 7.912126762355441, 8.851193403830502, 9.862494140455718, 10.796630089633654, 11.767514130961983, 11.688215054384257, 10.695858057596013, 9.643037192914948, 8.588794411489154, 7.640318359740606, 6.655126198064855, 5.689361905080867, 4.771747242693911, 3.8851530394333658, 2.944591834173062, 1.9952220053337308, 2.9851159751248773, 3.9182218794885024, 6.790111332631724, 7.755756309849905, 8.743614792867113, 9.804677523313533, 10.809684083051549, 11.724128542038892, 11.607966127874596, 10.715140497317842, 9.749331025020785, 8.7658736598484, 7.730933890918333, 6.765586108057634, 5.790451140776052, 4.717474423418189, 3.7758489224840024, 2.8914336924633566, 1.9595191742070488, 0.9866139724591163, 2.0478509000673415, 2.958908657439461, 7.784267560097003, 8.681916506608042, 9.70891311463183, 10.656789358728844, 11.708456573394411, 11.582298598029098, 10.60810428506267, 9.648555690541931, 8.692164164557973, 7.731254883111796, 6.778708796108402, 5.843238666252791, 4.8989715288386835, 3.8748511051071346, 2.849111100503386, 1.9000753753961812, 0.9420565021574504, 0.0, 0.9995573907596632, 1.931755065351324, 8.811681276273378, 9.738575863951402, 10.66148384357213, 11.632215876211681, 12.62703861759469, 12.520735276162151, 11.54625517995891, 10.641671001503148, 9.649277353734377, 8.70671963244599, 7.791399399929378, 6.804531610338085, 5.843704565507307, 4.775362567055729, 3.805160471737808, 2.8605927930937227, 1.8949302408948374, 0.9852206724019977, 1.9602770504088607, 2.964771832105143, 9.765507163490982, 10.793467865050424, 11.673585135905107, 12.592006522297472, 13.588369141530455, 13.470479010839849, 12.515645760926857, 11.580769837372328, 10.58665883126374, 9.781469096379052, 8.73409721159768, 7.698035950376065, 6.702613346329518, 5.775412433275644, 4.78085473754315, 3.8243491972711876, 2.9587301533073065, 2.0090637591382166, 2.9299624562338273, 3.90087554104376, 10.670498529231828, 11.64648877617423, 12.617901915101372, 13.519540711507306, 14.479780318053303, 14.523745628691346, 13.542127091783058, 12.523076541065553, 11.53021780423992, 10.677057941030174, 9.629418701501978, 8.589733152668753, 7.644564438088786, 6.681698867036874, 5.722601715449699, 4.86131563359507, 3.973301786243386, 3.0794706218261565, 3.901305512694859, 4.846089070281274, 11.663517928526147, 12.595914413873166, 13.54688174043324, 14.492835712946412, 15.505149461992628, 15.455347484281823, 14.490942801820504, 13.53440552352967, 12.562011632149582, 11.654138086783972, 10.589609217055969, 9.545676254232097, 8.575918484080832, 7.6689955760047575, 6.696392572826825, 5.886951312048772, 4.941741078135312, 4.007515406051121, 4.898850679231358, 5.822538657091913, 12.615151699695666, 13.588738600294272, 14.528023794507114, 15.45562861652587, 16.438324279030184, 16.3567085735845, 15.389879887000571, 14.420738023647761, 13.404954657679887, 12.38100273184263, 11.438231963774838, 10.45924100284573, 9.510966796058266, 8.734542620800068, 7.764431820518255, 6.877959355320979, 5.900157121285781, 5.069976228908413, 5.908119125199358, 6.751593235688124, 13.573646062286468, 14.630913382877093, 14.085297281355434, 14.58816760983619, 15.532975419575152, 16.45840136868359, 16.30933991277983, 15.339848662851939, 14.342023607304055, 13.307607084688184, 12.403922416191612, 11.477890689291284, 10.503398683835279, 9.764809056680235, 8.825023928818798, 7.880917254077914, 6.88100139737811, 6.073684103182895, 6.863314722661599, 7.8044851338548344, 14.501331695920644, 13.80816499973668, 13.02442519755436, 13.56905421194002, 14.505660644431883, 15.509256790360919, 16.45211013013492, 16.305108759276518, 15.355278898074195, 14.379304365068787, 13.451647528625031, 12.480578067155427, 11.550800967921596, 10.749044735889656, 9.797246083881433, 8.877472691037571, 7.901972155412855, 7.124890153211547, 7.8810648183998735, 8.866131997076522], [8.768155796392236, 7.894260346769118, 8.77210182222399, 9.72709837174029, 10.747699227251394, 11.754261851748184, 12.708544738356116, 13.517223079826849, 14.46292971746557, 15.415338799488076, 16.418121676731957, 17.305819809890604, 17.521382899553622, 16.510921339911622, 15.567565119261388, 14.558242124228027, 13.57329924176382, 12.980886316161195, 12.16685185209068, 12.885204713449077, 7.6964700390392125, 8.641489997137157, 9.597825308273018, 10.58781727951474, 11.621155623905322, 12.693993863734216, 13.683849382990344, 14.546348424213688, 15.39138315644333, 16.351948484222454, 17.28437806526358, 17.399236348104267, 16.572462023006096, 15.525687216273107, 14.564737026971503, 13.552138751555301, 12.536599430935468, 11.923228334060784, 11.117350987206384, 11.825962837149293, 6.690688251822567, 7.636416257649518, 8.640062434525587, 9.670553492115369, 10.725488443653852, 11.707145569733644, 12.68871082355218, 13.664139314778533, 14.648366397846226, 15.597645633268861, 16.532013942719743, 16.43382873346117, 15.543365830402767, 14.54072574521268, 13.54859727685007, 12.612740163120122, 11.565325806292785, 10.855710505892954, 10.078682979258826, 10.877726422832367, 5.763770827608645, 6.7328541627597565, 7.777159599564664, 8.731994660332678, 9.739452995841445, 10.732626128056182, 11.689517240995858, 12.62326022370249, 13.661552910297878, 14.61973397042883, 15.567701680781518, 15.471682196585874, 14.56410157166394, 13.558970066872224, 12.484783086930364, 11.558740090963019, 10.628054711416414, 9.817855973419293, 9.113190798036442, 9.837125650111252, 4.849899926320323, 5.820152948470112, 6.755848212743844, 7.784459231492449, 8.778597466089845, 9.834811602973263, 10.744507885468755, 11.67407614425287, 12.68474262159373, 13.614560599431606, 14.638135851704707, 14.518879082300522, 13.49148145205507, 12.616948211986939, 11.650884669036, 10.744110216509576, 9.69055898766091, 8.743692947405465, 8.100048021082996, 8.85383286646484, 3.8657453732055647, 4.879585703569446, 5.861610005922014, 6.817503646234103, 7.839191275022793, 8.85506722765354, 9.791594476375742, 10.767466609128274, 11.734054431896718, 12.676781380799142, 13.639188295423715, 13.584188527916917, 12.542481634256887, 11.672540440016604, 10.723447801068346, 9.76023759617898, 8.808279055919, 7.807854287387279, 7.137212982586572, 7.85639030878744, 2.9906713792728334, 3.996957893879636, 4.973561253379591, 5.948287003978709, 6.905020246536092, 7.910238063934705, 8.835326015439405, 9.802184616305187, 10.797222866385649, 11.789596775959675, 12.82183118849292, 12.525613124159102, 11.59587509021579, 10.689813382701388, 9.729578487817497, 8.805911639615001, 7.881888233322778, 6.882835482507595, 6.148221555790468, 6.8679516905662545, 2.0061171652541328, 3.0403199081125294, 4.023186710159541, 4.985622006189071, 5.954248254335838, 6.937547484357459, 7.873638088293451, 8.84972207748056, 9.863484448340136, 10.804629407779958, 11.81151590597703, 11.586278908968923, 10.615671256735599, 9.703498994749692, 8.803489077645358, 7.838083903549503, 6.9189741822294275, 5.939817951665397, 5.140681015749171, 5.849881805877651, 2.9258769658542647, 3.998590390715172, 4.953230888309054, 5.923881291103782, 6.961665479025839, 7.870146349105128, 8.884776186975841, 9.85502130803147, 10.84201224816974, 11.744652053957473, 11.523616437083385, 10.588125585044878, 9.654105962647455, 8.746562099737357, 7.777614814653982, 6.818402987427114, 5.941882077219245, 4.972586424008091, 4.181989648252728, 4.8385695712425, 3.9904035137294684, 4.939586757780015, 5.953833903359799, 6.878963106857546, 7.927646203811076, 8.913060636327462, 9.856883222413787, 10.859498399974049, 11.825309102554284, 11.593880012215408, 10.611257562419603, 9.64734740255047, 8.65114008299573, 7.675017606566044, 6.793126787954172, 5.861458756059772, 4.893294388051876, 4.005706187253129, 3.119474232046593, 3.845923927455936, 4.843420548507367, 5.879930867944994, 6.912569371595777, 7.85163601307084, 8.862936749696056, 9.797072698873992, 10.76795674020232, 11.735822493276281, 11.695415448355677, 10.642594583674612, 9.588351802248818, 8.63987575050027, 7.654683588824518, 6.68891929584053, 5.771304633453573, 4.884710430193029, 3.9441492249327252, 2.994779396093394, 2.1226455329045573, 2.9186644887288393, 5.790553941872062, 6.7561989190902425, 7.74405740210745, 8.805120132553869, 9.810126692291885, 10.72457115127923, 11.763981872178444, 11.714697888077504, 10.748888415780447, 9.765431050608063, 8.730491281677995, 7.765143498817297, 6.790008531535715, 5.717031814177852, 4.775406313243665, 3.89099108322302, 2.959076564966712, 1.9861713632187796, 1.0482935093076784, 1.959351266679798, 6.784710169337341, 7.68235911584838, 8.709355723872168, 9.657231967969182, 10.708899182634749, 11.653096068682519, 11.607661675822332, 10.648113081301593, 9.691721555317635, 8.730812273871459, 7.778266186868065, 6.842796057012454, 5.898528919598347, 4.874408495866797, 3.848668491263049, 2.8996327661558445, 1.9416138929171136, 0.9995573907596632, 0.0, 0.9321976745916608, 7.836912164367701, 8.73901847319174, 9.661926452812468, 10.63265848545202, 11.627481226835028, 12.591532746815572, 12.545812570718573, 11.64122839226281, 10.648834744494039, 9.706277023205654, 8.790956790689041, 7.804089001097748, 6.8432619562669705, 5.774919957815392, 4.804717862497471, 3.8601501838533863, 2.894487631654501, 1.9843940778172324, 0.9607196596491976, 1.9652144413454797, 8.790738051585306, 9.793910474290762, 10.674027745145445, 11.59244913153781, 12.588811750770793, 13.554666874928575, 13.515203151686519, 12.58032722813199, 11.586216222023403, 10.781026487138716, 9.733654602357342, 8.697593341135727, 7.7021707370891805, 6.774969824035306, 5.780412128302814, 4.823906588030852, 3.876710359825954, 2.912448310208743, 1.9304050654741642, 2.901318150284097, 9.836901180977645, 10.812891427920047, 11.61834452434171, 12.519983320747643, 13.48022292729364, 14.509997327491742, 14.54168448254272, 13.522633931825215, 12.529775194999582, 11.676615331789836, 10.62897609226164, 9.589290543428415, 8.644121828848448, 7.681256257796538, 6.722159106209363, 5.860873024354734, 4.891281992762034, 3.9692714512318714, 2.9017481219351957, 3.846531679521611, 10.87203583159334, 11.762317065618982, 12.587670762601139, 13.522631887287972, 14.518758309594784, 15.44159918308222, 15.490500192580166, 14.533962914289333, 13.561569022909245, 12.653695477543634, 11.589166607815631, 10.54523364499176, 9.575475874840494, 8.668552966764421, 7.695949963586489, 6.80493151856742, 5.8597212846539595, 4.897316235456836, 3.8992932884716947, 4.82298126633225, 11.823669602762859, 12.78947231232391, 13.65910013463503, 14.577623981423478, 15.560319643927794, 16.380968784747758, 16.389437277760234, 15.420295414407423, 14.40451204843955, 13.380560122602292, 12.4377893545345, 11.458798393605392, 10.510524186817928, 9.734100011559732, 8.763989211277918, 7.795939561839626, 6.818137327804428, 5.959777058314128, 4.908561734439695, 5.752035844928461, 12.78216396535366, 13.838100223170224, 14.705366057983868, 15.587725000595855, 16.532532810334814, 17.379450181218743, 17.308897303539492, 16.3394060536116, 15.341580998063717, 14.307164475447847, 13.403479806951275, 12.477448080050946, 11.502956074594941, 10.7382680543883, 9.798482926526862, 8.798897460596562, 7.798981603896758, 6.8986233686589165, 5.863757331901936, 6.804927743095171, 13.709849598987837, 13.193642376875895, 14.023982588314023, 14.568611602699685, 15.505218035191547, 16.508814181120584, 17.451667520894585, 17.30466615003618, 16.35483628883386, 15.37886175582845, 14.451204919384693, 13.48013545791509, 12.550358358681258, 11.722503733597721, 10.770705081589497, 9.795452897556219, 8.819952361931502, 7.832699762791416, 6.88150742764021, 7.866574606316859], [7.850775392214492, 8.666979926637723, 9.684750517631217, 10.639747067147518, 11.679896901843055, 12.686459526339846, 13.640742412947777, 14.44942075441851, 15.395127392057233, 16.34753647407974, 17.35031935132362, 18.238017484482263, 18.423493240802028, 17.413031681160028, 16.469675460509794, 15.460352465476433, 14.475409583012226, 13.8829966574096, 12.908377640276377, 11.953007038857416, 6.779089634861469, 7.7241095929594135, 8.680444904095275, 9.670436875336996, 10.703775219727579, 11.776613459556472, 12.76222021048906, 13.754264914790435, 14.69956613713466, 15.660131464913784, 16.59256104595491, 17.52537917976817, 17.474572364254502, 16.427797557521515, 15.46684736821991, 14.454249092803707, 13.438709772183874, 12.82533867530919, 11.858876775392082, 10.893765162557631, 5.773307847644824, 6.719035853471775, 7.722682030347844, 8.753173087937625, 9.808108039476108, 10.7897651655559, 11.767081651050896, 12.739447244145106, 13.7236743272128, 14.665447958677198, 15.59981626812808, 16.588802746792492, 16.47556350499443, 15.442836086461085, 14.450707618098477, 13.514850504368528, 12.467436147541191, 11.75782084714136, 10.820208767444523, 9.945528748240706, 4.8463904234309005, 5.815473758582012, 6.85977919538692, 7.814614256154935, 8.817823823340161, 9.810996955554899, 10.767888068494575, 11.691062549110827, 12.729355235706215, 13.687536295837168, 14.635504006189855, 15.626656209917199, 15.496299246255603, 14.46108040812063, 13.38689342817877, 12.460850432211425, 11.53016505266482, 10.7199663146677, 9.854716586222139, 8.904927975519591, 3.93251952214258, 4.902772544292369, 5.838467808566101, 6.867078827314706, 7.856968293588562, 8.911946529450093, 9.812310210877092, 10.741878469661208, 11.752544947002066, 12.682362924839943, 13.705938177113044, 14.673853095631847, 14.423679126646732, 13.549145886578598, 12.583082343627659, 11.646220557757982, 10.592669328909317, 9.645803288653871, 8.841573809268693, 7.921635191873179, 2.948364969027821, 3.9622052993917025, 4.94422960174427, 5.90012324205636, 6.917562102521509, 7.922869553061879, 8.85939680178408, 9.83526893453661, 10.801856757305055, 11.744583706207479, 12.706990620832052, 13.641888654476698, 13.47467930884855, 12.604738114608264, 11.655645475660005, 10.69243527077064, 9.710389397167406, 8.709964628635685, 7.878738770772269, 6.924192634195779, 2.058473704681173, 3.064760219287976, 4.04136357878793, 5.016089329387047, 5.972822571944431, 6.978040389343044, 7.903128340847743, 8.869986941713526, 9.86502519179399, 10.857399101368014, 11.88963351390126, 12.795426124906532, 12.528072764807453, 11.622011057293047, 10.661776162409156, 9.73810931420666, 8.783998574571184, 7.784945823756001, 6.889747343976166, 5.935754015974593, 1.073919490662472, 2.1081222335208687, 3.09098903556788, 4.05342433159741, 5.022050579744177, 6.005349809765798, 6.94144041370179, 7.9175244028889, 8.931286773748475, 9.872431733188296, 10.87931823138537, 11.856091909716353, 11.547868931327262, 10.635696669341353, 9.735686752237017, 8.770281578141162, 7.821084523477833, 6.841928292913803, 5.898881727890816, 4.9176841312859905, 1.9936792912626038, 3.066392716123511, 4.021033213717393, 4.991683616512121, 6.029467804434178, 6.937948674513467, 7.9525785123841795, 8.922823633439808, 9.909814573578078, 10.812454379365812, 11.767582945233416, 11.52032325963654, 10.586303637239116, 9.678759774329018, 8.709812489245643, 7.750600662018774, 6.84399241846765, 5.874696765256496, 4.940190360394373, 3.9063718966508394, 3.058205839137808, 4.007389083188356, 5.0216362287681395, 5.9467654322658845, 6.995448529219415, 7.9808629617358, 8.924685547822124, 9.927300725382388, 10.893111427962623, 11.835177131502673, 11.543455237011264, 10.57954507714213, 9.58333775758739, 8.607215281157705, 7.725324462545833, 6.793656430651432, 5.825492062643537, 4.9078165285015345, 3.898908010790212, 2.913726252864276, 3.911222873915707, 4.947733193353335, 5.980371697004117, 6.919438338479178, 7.930739075104395, 8.86487502428233, 9.83575906561066, 10.80362481868462, 11.800133594057359, 11.574792258266273, 10.520549476840479, 9.572073425091931, 8.58688126341618, 7.621116970432191, 6.703502308045234, 5.816908104784689, 4.876346899524386, 3.926977070685055, 3.0280331941963867, 1.9864668141371788, 4.858356267280402, 5.824001244498582, 6.81185972751579, 7.8729224579622095, 8.877929017700225, 9.792373476687569, 10.831784197586783, 11.776699375751035, 11.681086090372109, 10.697628725199724, 9.662688956269657, 8.697341173408958, 7.722206206127376, 6.649229488769513, 5.707603987835326, 4.82318875781468, 3.891274239558373, 2.9183690378104403, 1.9536811705995079, 1.0271535920881374, 5.852512494745681, 6.7501614412567195, 7.777158049280509, 8.725034293377522, 9.77670150804309, 10.72089839409086, 11.695092707057288, 11.580310755893255, 10.623919229909296, 9.66300994846312, 8.710463861459726, 7.774993731604115, 6.830726594190008, 5.806606170458458, 4.78086616585471, 3.8318304407475052, 2.8738115675087745, 1.931755065351324, 0.9321976745916608, 0.0, 6.90471448977604, 7.80682079860008, 8.729728778220808, 9.70046081086036, 10.69528355224337, 11.659335072223913, 12.633243601953529, 12.573426066854472, 11.5810324190857, 10.638474697797315, 9.7231544652807, 8.73628667568941, 7.775459630858632, 6.707117632407053, 5.736915537089132, 4.792347858445047, 3.8266853062461617, 2.916591752408893, 1.8929173342408583, 1.0478340371677362, 7.858540376993645, 8.861712799699102, 9.741830070553785, 10.66025145694615, 11.656614076179133, 12.622469200336916, 13.577302450249908, 13.512524902723651, 12.518413896615062, 11.713224161730377, 10.665852276949003, 9.629791015727388, 8.634368411680843, 7.707167498626967, 6.712609802894474, 5.756104262622512, 4.808908034417615, 3.8446459848004038, 2.862602740065825, 1.9839377461063534, 8.904703506385983, 9.880693753328385, 10.68614684975005, 11.587785646155984, 12.548025252701981, 13.577799652900083, 14.60378378110611, 14.454831606416874, 13.461972869591241, 12.6088130063815, 11.561173766853303, 10.521488218020078, 9.576319503440109, 8.613453932388198, 7.654356780801023, 6.793070698946394, 5.823479667353695, 4.901469125823532, 3.833945796526856, 2.9291512753438678, 9.93983815700168, 10.83011939102732, 11.65547308800948, 12.590434212696312, 13.586560635003124, 14.50940150849056, 15.552599491143555, 15.466160588880992, 14.493766697500904, 13.585893152135297, 12.521364282407294, 11.47743131958342, 10.507673549432155, 9.600750641356083, 8.62814763817815, 7.737129193159081, 6.791918959245621, 5.8295139100484965, 4.831490963063355, 3.905600862154506, 10.891471928171198, 11.85727463773225, 12.726902460043371, 13.64542630683182, 14.628121969336135, 15.448771110156096, 16.415599796740025, 16.352493088999083, 15.33670972303121, 14.312757797193953, 13.369987029126161, 12.390996068197053, 11.44272186140959, 10.666297686151394, 9.69618688586958, 8.728137236431287, 7.750335002396089, 6.882169157931967, 5.821210429846923, 4.834655440750717, 11.849966290762, 12.905902548578563, 13.773168383392209, 14.668302405455865, 15.613110215194826, 16.447252506627084, 17.41309508017338, 17.271603728203264, 16.27377867265538, 15.239362150039508, 14.335677481542936, 13.409645754642607, 12.435153749186602, 11.670465728979961, 10.730680601118523, 9.731095135188223, 8.731179278488419, 7.811272064066145, 6.776406027309164, 5.899188578048621, 12.777651924396176, 13.73102022122886, 14.741115978576333, 15.47072194394809, 16.407328376439953, 17.396397084949754, 18.35377786214299, 18.236863824627843, 17.287033963425518, 16.311059430420112, 15.383402593976355, 14.412333132506753, 13.48255603327292, 12.654701408189382, 11.702902756181158, 10.72765057214788, 9.752150036523163, 8.745348458198643, 7.794156123047439, 6.960835441270309], [12.895159204378942, 13.71136373880217, 14.749430781752956, 15.687301876643728, 16.63430433689313, 17.54321426885182, 18.49749715545975, 18.390877742568133, 17.3818425140674, 16.531874599409296, 15.540530950963491, 14.496930286792516, 13.56695060157147, 12.55648904192947, 11.613132821279237, 10.603809826245875, 9.61886694378167, 8.853752042632712, 7.835283670844303, 6.877343725386197, 11.823473447025918, 12.768493405123861, 13.724828716259722, 14.714820687501444, 15.611179037492434, 16.56938512528177, 17.524214015138032, 17.398690297433866, 16.45338907508964, 15.492823747310517, 14.56039416626939, 13.62757603245613, 12.618029725023943, 11.571254918290956, 10.610304728989352, 9.59770645357315, 8.582167132953318, 7.950110044268667, 6.926375584214774, 5.921586994449859, 10.817691659809272, 11.763419665636222, 12.767065842512292, 13.717864960776737, 14.641390782272143, 15.571367315302735, 16.529075455699868, 16.63855578188962, 15.654328698821928, 14.6564032080454, 13.72203489859452, 12.66216841781303, 11.630469987397458, 10.586293447230528, 9.59416497886792, 8.65830786513797, 7.610893508310634, 6.887442085409076, 5.887707576267214, 5.002221855005047, 9.849672352214187, 10.818755687365298, 11.769994732716155, 12.703246137569781, 13.579817627989133, 14.57299076020387, 15.529881873143546, 15.638081227574958, 14.659013980905813, 13.700832920774861, 12.714665562841137, 11.700021880937737, 10.651205728658631, 9.604537768890072, 8.530350788948212, 7.604307792980869, 6.673622413434264, 5.849587552935415, 4.92221539504483, 3.9616210822839313, 8.91823667029008, 9.888489692439869, 10.73830542158722, 11.755710708729552, 12.618962098237533, 13.673940334099065, 14.574304015526064, 14.688897148125339, 13.732448918014065, 12.686338310740371, 11.785099733764326, 10.75907103208241, 9.731673401836956, 8.714501752181977, 7.748438209231038, 6.789677918527426, 5.736126689678761, 4.789260649423316, 3.909072618091384, 2.9783282986375186, 7.933887916418703, 8.945281534245144, 9.798557129807133, 10.754450770119222, 11.67955590717048, 12.684863357710851, 13.621390606433051, 13.657873863778775, 12.691286041010331, 11.748559092107907, 10.786152177483334, 9.851254143838688, 8.782673584038774, 7.770093980211642, 6.821001341263384, 5.857731266190959, 4.85384675793685, 3.85342198940513, 2.965049160691775, 1.9808857409601188, 6.978715635476891, 7.886090795440756, 8.803357383436902, 9.77808313403602, 10.734816376593402, 11.740034193992015, 12.665122145496714, 12.965377571753564, 11.970339321673102, 10.903464857558799, 9.871230445025553, 8.938063681908929, 7.872149611504631, 6.927068180903102, 5.96683328601921, 5.001618742917163, 3.9719781072670464, 2.928403184525446, 1.9760577338956717, 1.0220644058940995, 5.99416142145819, 6.929452809673649, 7.852982840216852, 8.81541813624638, 9.784044384393148, 10.758970782918759, 11.69506138685475, 12.67114537604186, 12.709205174882175, 11.768060215442354, 10.761173717245281, 9.784400038914297, 8.813792386680973, 7.853936656436269, 6.8929226961913495, 5.906741357407234, 4.873757419175998, 3.8714207153676434, 2.9835982739369693, 1.999824659314471, 5.015510687556506, 5.958773539682624, 6.922938662067338, 7.846211277978492, 8.814040890526647, 9.82637191817109, 10.80341109543036, 11.773656216485987, 12.675396451502234, 12.550678105259923, 11.59554953939232, 10.660058687353812, 9.726039064956389, 8.748808203897072, 7.720610605801875, 6.761398778575007, 5.807947896236104, 4.83865224302495, 3.9422896414334128, 2.998342593125201, 3.946545990036316, 4.895729234086863, 5.909976379666647, 6.891129462224729, 7.797140730646703, 8.782555163163089, 9.831304059992414, 10.778850607741104, 11.69209959711769, 12.63416530065774, 12.528751155556968, 11.68425813134859, 10.676081443353336, 9.699958966923651, 8.706523106837285, 7.718343009942349, 6.758466301011797, 5.805532479779911, 4.976169994837701, 3.9909882369117646, 3.0024089916762673, 4.022542248062983, 4.864252044326855, 5.934806358532659, 6.861850184761723, 7.795986133939659, 8.766870175267988, 9.734735928341948, 10.731244703714687, 11.745837988764322, 12.643815738866952, 12.579735740926672, 11.59454357925092, 10.628779286266933, 9.689406921075408, 8.695091335809092, 7.707611464130949, 6.816459270939647, 5.972998693979736, 4.918247675638861, 2.046358222495639, 2.948677058152155, 3.9365355411693628, 4.889095859811467, 5.894102419549482, 6.871743060243723, 7.877773666678935, 8.892116283654468, 9.851018804834519, 10.789380002554486, 11.69786566641309, 12.578856339779867, 12.592250711133365, 11.600666767929612, 10.677043946351718, 9.633395783300303, 8.701481265043995, 7.8250673038142615, 6.804088476199273, 5.877560897687903, 1.0522019950303598, 2.0225168613940174, 2.959977166090229, 3.907853410187243, 4.959520624852809, 5.903717510900579, 6.8779118238670085, 7.837460418387748, 8.793851944371706, 9.754761225817882, 10.707307312821277, 11.642777442676888, 12.587044580090996, 12.565259178171118, 11.603781768332334, 10.694807554612169, 9.736788681373438, 8.811681276273378, 7.8369121643677015, 6.90471448977604, 0.0, 1.0612358475340702, 2.007406437149929, 3.004969261812106, 3.999792003195116, 4.995012882344004, 5.984835879313847, 6.996159882319681, 7.988553530088453, 9.022088386387779, 9.951939399604878, 10.978902114543619, 12.03069396378668, 13.099035962238258, 12.599892650953795, 11.65532497230971, 10.689662420110825, 9.796901948675375, 8.7976318240169, 7.952548526943777, 0.9538258872176045, 2.014709298896274, 3.019507729482906, 3.964759907897898, 4.961122527130882, 5.926977651288663, 6.881810901201654, 7.855168743365136, 8.894718121946312, 9.92207888435492, 10.895184413756953, 11.931245674978568, 12.926668279025115, 13.85386919207899, 13.575586916759137, 12.619081376487175, 11.713622524193656, 10.749360474576445, 9.767317229841867, 8.888652235882393, 1.9999890166099425, 2.975979263552345, 3.963824508679172, 4.89229409710773, 5.8525337036537275, 6.88230810385183, 7.908292232057855, 8.839018450220754, 9.831877187046388, 10.776926478819332, 11.824565718347529, 12.864251267180753, 13.809419981760723, 14.841130430030944, 14.517333894665686, 13.656047812811057, 12.728194157129735, 11.806183615599572, 10.738660286302897, 9.833865765119906, 3.043800256534583, 3.925404901251281, 4.8763722278113555, 5.822326200324529, 6.834639949370745, 7.813909959442308, 8.8571079420953, 9.816292173312517, 10.788686064692605, 11.75400662457313, 12.82807937755862, 13.872012340382494, 14.740774027752769, 15.672368136009657, 15.491124752042813, 14.641843682935122, 13.696633449021661, 12.734228399824536, 11.736205452839396, 10.790461913490581, 3.9954340277041016, 4.952560147956211, 5.891845342169051, 6.819450164187807, 7.802145826692122, 8.753279561107844, 9.720108247691773, 10.689250111044583, 11.705033477012456, 12.728985402849714, 13.671756170917506, 14.650747131846614, 15.599021338634078, 16.58465861331194, 16.559163999734242, 15.632851726207328, 14.655049492172129, 13.767030209268043, 12.706071481182999, 11.719516492086793, 4.965385866245491, 6.001188058802525, 6.938111265517888, 7.842326262811853, 8.787134072550813, 9.75176095757883, 10.717603531125128, 11.68709478105302, 12.684919836600903, 13.655589755695269, 14.634589006820821, 15.56062073372115, 16.580403406877092, 17.52421911154512, 17.619756108034785, 16.635809624964264, 15.63589376826446, 14.69613311540222, 13.66126707864524, 12.784049629384697, 5.8930714998796665, 6.84643979671235, 7.856535554059822, 8.838653161031164, 9.775259593523026, 10.7009055359015, 11.670551058111041, 12.652354877477597, 13.647325302865905, 14.67697138920809, 15.68231411925424, 16.563308111585293, 17.494229370713054, 18.52049553429895, 18.526771039010505, 17.586550666588305, 16.647154658722126, 15.630209509534719, 14.679017174383514, 13.845696492606384], [13.797265513202982, 13.143992218767584, 13.863105219931397, 14.694871328499925, 15.607555484923836, 16.516465416882525, 17.470748303490456, 17.399858244324573, 16.484866523601703, 15.551379827682812, 14.50831687991088, 13.464716215739905, 12.53473653051886, 11.52427497087686, 10.580918750226626, 9.80730983378658, 8.90825095091326, 8.093578550741164, 7.131758158427326, 7.907145100822921, 12.725579755849958, 12.201121885089275, 12.822939567250621, 13.72239013935764, 14.584430185523141, 15.542636273312477, 16.49746516316874, 17.487488503090503, 17.328360689605514, 16.367795361826392, 15.435365780785265, 14.502547646972005, 13.52909359612048, 12.521466276874634, 11.628574291168068, 10.658942301107219, 9.643402980487386, 9.011345891802737, 7.987611431748843, 6.951388369886583, 11.719797968633312, 11.196048145601637, 11.75662364248197, 12.69456848267535, 13.61464193030285, 14.544618463333443, 15.502326603730575, 16.472670832445175, 16.715564546355996, 15.717639055579468, 14.783270746128588, 13.723404265347098, 12.691705834931525, 11.647529294764595, 10.655400826401987, 9.71954371267204, 8.672129355844703, 7.948677932943146, 6.948943423801284, 6.0520048830838995, 10.751778661038227, 10.133246800768633, 10.74669825461477, 11.679949659468397, 12.55306877601984, 13.546241908234578, 14.503133021174254, 15.424286137410895, 15.720249828439881, 14.762068768308929, 13.775901410375205, 12.761257728471804, 11.712441576192699, 10.66577361642414, 9.59158663648228, 8.665543640514937, 7.734858260968332, 6.910823400469485, 5.9834512425789, 5.022856929818002, 9.82034297911412, 9.122255475931965, 9.715008943485836, 10.732414230628168, 11.59221324626824, 12.647191482129772, 13.54553379917716, 14.475102057961276, 14.793684765548132, 13.747574158274439, 12.846335581298394, 11.820306879616478, 10.792909249371023, 9.775737599716047, 8.809674056765108, 7.8509137660614945, 6.7973625372128295, 5.850496496957384, 4.970308465625454, 4.039564146171589, 8.835994225242743, 8.118807913829489, 8.775260651705748, 9.731154292017838, 10.652807055201187, 11.658114505741558, 12.592620390084148, 13.56849252283668, 13.752521888544399, 12.809794939641975, 11.847388025017402, 10.912489991372755, 9.843909431572841, 8.83132982774571, 7.882237188797453, 6.918967113725029, 5.91508260547092, 4.914657836939199, 4.026285008225845, 3.0421215884941892, 7.880821944300932, 7.059617175025102, 7.780060905335517, 8.754786655934636, 9.70806752462411, 10.713285342022722, 11.63635192914781, 12.603210530013593, 13.03157516920717, 11.964700705092866, 10.93246629255962, 9.999299529442997, 8.9333854590387, 7.988304028437171, 7.02806913355328, 6.0628545904512325, 5.033213954801116, 3.9896390320595154, 3.0372935814297417, 2.0833002534281695, 6.896267730282231, 6.102979189257995, 6.829686362115467, 7.788669284277089, 8.757295532423855, 9.69773493538469, 10.63382553932068, 11.60990952850779, 12.623671899367366, 12.829296062976422, 11.822409564779349, 10.845635886448365, 9.87502823421504, 8.915172503970338, 7.954158543725419, 6.962777332238615, 5.92979339400738, 4.927456690199025, 3.9833489961190987, 2.9745968879911295, 5.917616996380547, 5.13229991926697, 5.899642183965954, 6.803777584753883, 7.752805042992577, 8.76513607063702, 9.74217524789629, 10.712420368951918, 11.614160603968163, 12.601135241317593, 12.647828461759262, 11.712337609720755, 10.778317987323332, 9.801087126264015, 8.772889528168818, 7.813677700941949, 6.860226818603047, 5.890931165391892, 4.934267365692775, 3.900448901949241, 4.848652298860356, 4.069255613671209, 4.886679901565262, 5.84869576900012, 6.735904883112633, 7.721319315629018, 8.770068212458344, 9.717614760207033, 10.630863749583618, 11.572929453123669, 12.555551902919474, 12.736537053715534, 11.728360365720278, 10.752237889290592, 9.758802029204226, 8.770621932309291, 7.810745223378739, 6.8578114021468535, 5.878276303661741, 4.893094545735805, 3.9045153005003073, 3.056684744012326, 3.8138853935752977, 4.876022862786826, 5.800614337227653, 6.734750286405589, 7.705634327733917, 8.673500080807877, 9.670008856180615, 10.684602141230252, 11.582579891332882, 12.506431304978085, 12.646822501617862, 11.681058208633875, 10.74168584344235, 9.747370258176034, 8.75989038649789, 7.864998972594923, 6.875105002803776, 5.820353984462901, 2.948464531319679, 1.9828195541014981, 2.886168890417806, 3.8278600122773967, 4.832866572015413, 5.810507212709654, 6.816537819144865, 7.830880436120399, 8.78978295730045, 9.728144155020416, 10.63662981887902, 11.517620492245797, 12.492755459527379, 12.652945690296553, 11.726288571300962, 10.682640408249547, 9.75072588999324, 8.777820688245306, 7.706194785023313, 6.7796672065119425, 2.0269742237070183, 1.0566593573433607, 1.898741318556159, 2.846617562653173, 3.8982847773187395, 4.8424816633665095, 5.816675976332939, 6.776224570853678, 7.732616096837636, 8.693525378283812, 9.646071465287207, 10.581541595142818, 11.525808732556927, 12.549929156288476, 12.587686964454791, 11.638651239347586, 10.680632366108856, 9.738575863951406, 8.739018473191742, 7.80682079860008, 1.0612358475340702, 0.0, 0.9461705896158591, 1.9437334142780363, 2.938556155661046, 3.933777034809934, 4.9236000317797775, 5.934924034785611, 6.927317682554383, 7.960852538853708, 8.890703552070809, 9.91766626700955, 10.96945811625261, 12.03780011470419, 13.008002210022111, 12.59916865704513, 11.633506104846244, 10.723412551008973, 9.699738132840938, 8.854654835767816, 2.015061734751675, 1.0548920010990221, 1.958271881948836, 2.9035240603638277, 3.8998866795968112, 4.8657418037545925, 5.820575053667584, 6.793932895831065, 7.833482274412242, 8.86084303682085, 9.833948566222883, 10.870009827444498, 11.865432431491044, 12.79263334454492, 13.85007726481033, 13.562925061222595, 12.615728833017695, 11.651466783400483, 10.669423538665905, 9.790758544706433, 3.061224864144013, 2.1100375711514374, 2.902588661145102, 3.83105824957366, 4.791297856119657, 5.82107225631776, 6.847056384523785, 7.777782602686685, 8.770641339512318, 9.715690631285263, 10.76332987081346, 11.803015419646684, 12.748184134226651, 13.779894582496873, 14.738991734084047, 14.599891497546476, 13.630300465953773, 12.70828992442361, 11.640766595126935, 10.735972073943948, 4.073601631971307, 3.0594632088503735, 3.8719148994045307, 4.817868871917704, 5.829833238420801, 6.752674111908238, 7.79587209456123, 8.755056325778446, 9.727450217158534, 10.69277077703906, 11.766843530024552, 12.810776492848426, 13.679538180218698, 14.611132288475586, 15.583735291653518, 15.54394999175916, 14.5987397578457, 13.636334708648574, 12.638311761663434, 11.692568222314621, 5.025235403140826, 4.086618455555303, 4.9433442714384235, 5.870949093457179, 6.853644755961494, 7.692043713573774, 8.658872400157703, 9.628014263510511, 10.643797629478385, 11.667749555315643, 12.610520323383435, 13.589511284312543, 14.537785491100006, 15.52342276577787, 16.578278231115277, 16.534958035031366, 15.557155800996167, 14.669136518092083, 13.608177790007039, 12.621622800910833, 5.995187241682215, 5.135246366401617, 5.989610194787261, 6.893825192081225, 7.838633001820186, 8.69052511004476, 9.656367683591059, 10.62585893351895, 11.623683989066834, 12.594353908161198, 13.57335315928675, 14.499384886187078, 15.519167559343021, 16.462983264011047, 17.402768391872485, 17.5379159337883, 16.538000077088498, 15.59823942422626, 14.56337338746928, 13.686155938208737, 6.922872875316391, 6.104967633642112, 7.050482278588335, 7.912938589977395, 8.849545022469258, 9.63966968836743, 10.609315210576971, 11.591119029943528, 12.586089455331836, 13.61573554167402, 14.621078271720169, 15.502072264051222, 16.432993523178983, 17.459259686764877, 17.50002218704121, 16.55980181461901, 15.682904016409122, 14.80250727936397, 14.156745137896493, 14.747802801430424], [14.651709174382361, 13.72627036097933, 12.91693463031554, 13.748700738884068, 14.661384895307977, 15.570294827266666, 16.5245777138746, 16.453687654708716, 15.538695933985846, 14.605209238066951, 13.56214629029502, 12.518545626124045, 11.588565940902999, 10.578104381261, 9.634748160610766, 8.86113924417072, 7.962080361297401, 7.147407961125305, 7.949006585925698, 8.724393528321293, 13.580023417029338, 12.78340002730102, 11.876768977634764, 12.776219549741784, 13.638259595907282, 14.596465683696618, 15.55129457355288, 16.541317913474643, 16.382190099989653, 15.421624772210532, 14.489195191169404, 13.556377057356144, 12.58292300650462, 11.575295687258773, 10.682403701552207, 9.867242616843447, 8.998780172125754, 8.205065943225716, 8.835365790748282, 7.768636797384956, 12.574241629812692, 11.778326287813382, 10.810453052866112, 11.748397893059494, 12.668471340686992, 13.598447873717584, 14.556156014114716, 15.526500242829314, 16.510727325897008, 16.439430997155373, 15.515828913976971, 14.521784671999244, 13.60984171930929, 12.560257158319201, 11.601571416017848, 10.6657143022879, 9.618299945460564, 8.86624484416107, 7.866401652961182, 6.869253310582272, 11.606222322217606, 10.715524942980378, 9.800527664998912, 10.73377906985254, 11.606898186403981, 12.600071318618719, 13.556962431558395, 14.478115547795035, 15.516408234390424, 15.70823935792479, 14.722071999991066, 13.707428318087665, 12.65861216580856, 11.61194420604, 10.53775722609814, 9.611714230130797, 8.681028850584193, 7.831793180664543, 6.904421022773958, 5.925760240951768, 10.6747866402935, 9.70453361814371, 8.768838353869977, 9.78624364101231, 10.646042656652382, 11.701020892513913, 12.5993632095613, 13.528931468345416, 14.539597945686275, 14.6937447478903, 13.792506170914255, 12.766477469232338, 11.739079838986884, 10.721908189331907, 9.755844646380968, 8.797084355677354, 7.74353312682869, 6.796667086573245, 5.897402752639104, 4.9666584331852395, 9.758902204863471, 8.811114364442458, 7.8290900620898904, 8.78498370240198, 9.706636465585328, 10.7119439161257, 11.646449800468288, 12.62232193322082, 13.588909755989263, 13.755965529257836, 12.793558614633262, 11.858660580988616, 10.790080021188702, 9.777500417361571, 8.828407778413313, 7.865137703340889, 6.86125319508678, 5.860828426555059, 4.972455597841704, 3.988292178110048, 8.80372992392166, 7.8230205603137275, 6.8338903157196595, 7.808616066318777, 8.76189693500825, 9.767114752406863, 10.69018133953195, 11.657039940397732, 12.652078190478196, 12.910871294708725, 11.87863688217548, 10.945470119058855, 9.879556048654559, 8.934474618053029, 7.974239723169139, 7.009025180067091, 5.979384544416975, 4.935809621675375, 3.983464171045601, 3.0294708430440287, 7.819175709902959, 6.866382574546621, 5.883515772499609, 6.842498694661228, 7.811124942807996, 8.751564345768829, 9.68765494970482, 10.66373893889193, 11.677501309751506, 12.594987297879248, 12.76858015439521, 11.791806476064226, 10.821198823830901, 9.861343093586198, 8.900329133341279, 7.885685311859343, 6.852701373628108, 5.850364669819753, 4.906256975739827, 3.8975048676118575, 6.840524976001275, 5.93149551976697, 4.953471594350096, 5.857606995138022, 6.8066344533767165, 7.818965481021159, 8.79600465828043, 9.766249779336057, 10.667990014352302, 11.654964651701732, 12.542582929468262, 12.635245589341482, 11.701225966944058, 10.723995105884741, 9.695797507789544, 8.736585680562676, 7.783134798223775, 6.81383914501262, 5.857175345313503, 4.8233568815699694, 5.771560278481084, 4.912924177269105, 3.940509311949404, 4.902525179384259, 5.789734293496773, 6.775148726013158, 7.823897622842484, 8.771444170591172, 9.684693159967757, 10.626758863507808, 11.609381313303613, 12.567732367412423, 12.651268345341004, 11.675145868911319, 10.681710008824952, 9.693529911930018, 8.733653202999468, 7.7807193817675815, 6.801184283282469, 5.816002525356533, 4.827423280121035, 3.9003533076102217, 2.867714803959439, 3.929852273170966, 4.854443747611793, 5.7885796967897285, 6.759463738118057, 7.727329491192016, 8.723838266564755, 9.738431551614394, 10.636409301717022, 11.560260715362224, 12.544292001793963, 12.603966188254603, 11.664593823063077, 10.670278237796762, 9.68279836611862, 8.787906952215652, 7.798012982424504, 6.743261964083629, 3.871372510940407, 2.905727533722226, 1.9399983008019472, 2.8816894226615375, 3.8866959823995533, 4.864336623093793, 5.8703672295290055, 6.884709846504539, 7.843612367684589, 8.781973565404558, 9.69045922926316, 10.571449902629936, 11.546584869911518, 12.568350976914122, 12.64919655092169, 11.605548387870275, 10.673633869613967, 9.700728667866034, 8.62910276464404, 7.702575186132671, 2.9498822033277463, 1.9795673369640885, 0.9525707289402999, 1.900446973037314, 2.9521141877028803, 3.8963110737506503, 4.870505386717079, 5.8300539812378185, 6.786445507221776, 7.747354788667953, 8.699900875671347, 9.635371005526958, 10.579638142941066, 11.603758566672616, 12.629498571276365, 12.561559218968315, 11.603540345729584, 10.661483843572134, 9.66192645281247, 8.729728778220808, 2.007406437149929, 0.9461705896158591, 0.0, 0.997562824662177, 1.9923855660451868, 2.987606445194075, 3.977429442163918, 4.988753445169751, 5.981147092938523, 7.014681949237848, 7.9445329624549474, 8.971495677393687, 10.023287526636748, 11.091629525088326, 12.061831620406247, 13.006399299050333, 12.556414084466972, 11.646320530629701, 10.622646112461666, 9.777562815388544, 2.9612323243675336, 2.001062590714881, 1.012101292332977, 1.9573534707479687, 2.953716089980952, 3.9195712141387333, 4.874404464051725, 5.847762306215206, 6.887311684796384, 7.914672447204992, 8.88777797660702, 9.923839237828636, 10.919261841875183, 11.846462754929059, 12.90390667519447, 13.860412215466432, 13.538636812638423, 12.574374763021211, 11.592331518286633, 10.713666524327161, 3.9414748673510576, 2.965484620408655, 1.956418071529243, 2.8848876599578013, 3.8451272665037983, 4.874901666701901, 5.900885794907926, 6.831612013070826, 7.824470749896459, 8.769520041669404, 9.8171592811976, 10.856844830030825, 11.802013544610794, 12.833723992881016, 13.79282114446819, 14.83254370323177, 14.553208445574501, 13.631197904044338, 12.563674574747663, 11.658880053564676, 4.89085005946968, 3.8767116363487464, 2.925744309788672, 3.871698282301845, 4.883662648804942, 5.806503522292379, 6.849701504945371, 7.808885736162587, 8.781279627542675, 9.746600187423201, 10.820672940408691, 11.864605903232565, 12.73336759060284, 13.664961698859729, 14.637564702037661, 15.70296221866749, 15.521647737466427, 14.559242688269302, 13.561219741284162, 12.547011883494001, 5.842483830639199, 4.903866883053676, 3.9971736818225647, 4.9247785038413205, 5.907474166345636, 6.7458731239579155, 7.712701810541844, 8.681843673894655, 9.697627039862528, 10.721578965699786, 11.664349733767578, 12.643340694696686, 13.59161490148415, 14.577252176162013, 15.63210764149942, 16.66615846816944, 16.480063780616895, 15.523580179271462, 14.462621451186418, 13.476066462090213, 6.812435669180588, 5.952494793899989, 5.043439605171402, 5.9476546024653665, 6.892462412204328, 7.744354520428902, 8.7101970939752, 9.679688343903091, 10.677513399450975, 11.64818331854534, 12.627182569670893, 13.553214296571221, 14.572996969727164, 15.51681267439519, 16.456597802256628, 16.610186661962807, 15.75770418482801, 14.907542739776765, 15.41781704864866, 14.540599599388116, 7.740121302814764, 6.922216061140484, 6.1043116889724764, 6.966768000361537, 7.903374432853399, 8.693499098751571, 9.663144620961113, 10.644948440327669, 11.639918865715977, 12.669564952058161, 13.674907682104312, 14.555901674435365, 15.486822933563126, 16.51308909714902, 16.553851597425354, 15.613631225003152, 14.736733426793265, 13.856336689748113, 14.739023280108238, 15.602246462609804], [15.601474522410541, 14.67603570900751, 13.86669997834372, 12.916838416479514, 13.736364439753501, 14.64527437171219, 15.599557258320122, 15.456124830046537, 14.541133109323667, 13.607646413404776, 12.564583465632845, 11.52098280146187, 10.591003116240824, 9.580541556598824, 8.63718533594859, 7.8813262363008585, 6.982267353427539, 7.91147152629891, 8.856995215075077, 9.634576592881746, 14.529788765057518, 13.7331653753292, 12.826534325662944, 11.94435722733723, 12.713239140352806, 13.671445228142142, 14.626274117998404, 15.616297457920167, 15.38462727532748, 14.424061947548356, 13.491632366507229, 12.558814232693969, 11.585360181842445, 10.577732862596598, 9.684840876890032, 8.887429608973585, 8.01896716425589, 8.96912950839932, 9.745548855308735, 8.67881986194541, 13.524006977840871, 12.728091635841562, 11.760218400894292, 10.91653557065494, 11.743450885132516, 12.673427418163108, 13.63113555856024, 14.601479787274839, 15.585706870342532, 15.441868172493198, 14.518266089314796, 13.524221847337069, 12.612278894647115, 11.562694333657026, 10.709924155806158, 9.826828197408764, 8.990240788898573, 9.776427908721523, 8.776584717521635, 7.779436375142725, 12.555987670245786, 11.665290291008558, 10.750293013027092, 9.901916747447984, 10.681877730849505, 11.675050863064243, 12.631941976003919, 13.553095092240559, 14.591387778835948, 15.533059073325283, 15.535526706488685, 14.486368384212362, 13.591117971766042, 12.544450011997483, 11.535320050760319, 10.609277054792974, 9.67859167524637, 8.741976245224997, 7.814604087334411, 6.835943305512221, 11.624551988321679, 10.65429896617189, 9.718603701898157, 8.954381318607755, 9.721022201097906, 10.776000436959437, 11.674342754006824, 12.60391101279094, 13.614577490131799, 14.518564463290794, 14.790068995576434, 13.764040293894517, 12.736642663649063, 11.719471013994086, 10.753407471043147, 9.794647180339531, 8.741095951490866, 7.794229911235422, 6.863876008157515, 5.93313168870365, 10.729634237503022, 9.760879712470636, 8.77885541011807, 7.953121379997425, 8.781616010030852, 9.786923460571224, 10.721429344913812, 11.697301477666343, 12.663889300434787, 13.58078524465833, 13.791121439295441, 12.856223405650795, 11.78764284585088, 10.77506324202375, 9.825970603075492, 8.862700528003067, 7.858816019748957, 6.8583912512172365, 5.970018422503882, 4.985855002772225, 9.774461956561211, 8.772785908341907, 7.7836556637478385, 6.9641162266811, 7.836876479453775, 8.842094296852387, 9.765160883977474, 10.732019484843256, 11.727057734923719, 12.654402240223886, 12.876199706837658, 11.943032943721034, 10.877118873316737, 9.932037442715208, 8.971802547831317, 8.006588004729268, 6.976947369079152, 5.933372446337552, 4.981026995707778, 4.027033667706206, 8.78990774254251, 7.8161479225748, 6.833281120527788, 5.917478239106753, 6.886104487253521, 7.826543890214352, 8.762634494150344, 9.738718483337454, 10.75248085419703, 11.66943487204417, 12.59613219481543, 12.789369300726403, 11.818761648493078, 10.858905918248375, 9.897891958003456, 8.856417344498894, 7.823433406267659, 6.821096702459305, 5.876989008379378, 4.868236900251409, 7.811257008640826, 6.881260867795149, 5.903236942378275, 4.932586539583547, 5.8816139978222415, 6.893945025466683, 7.870452232445352, 8.84069735350098, 9.742437588517223, 10.729412225866653, 11.617030503633183, 12.55252135567169, 12.671957999583611, 11.694727138524295, 10.666529540429098, 9.70731771320223, 8.753866830863327, 7.784571177652172, 6.827907377953054, 5.794088914209521, 6.742292311120636, 5.883656209908656, 4.911241344588955, 3.977504723829784, 4.864713837942298, 5.850128270458683, 6.898345197007407, 7.845891744756096, 8.759140734132679, 9.70120643767273, 10.683828887468534, 11.599901592326724, 12.592224728808098, 12.645877901550872, 11.652442041464505, 10.66426194456957, 9.70438523563902, 8.751451414407134, 7.77191631592202, 6.786734557996084, 5.798155312760587, 4.871085340249773, 3.8384468365989903, 3.0048318176164903, 3.9294232920573173, 4.863027270954651, 5.8339113122829795, 6.801777065356939, 7.798285840729677, 8.770600776528694, 9.668578526631322, 10.592429940276524, 11.576461226708263, 12.54222551969225, 12.63532585570263, 11.641010270436315, 10.653530398758171, 9.758638984855203, 8.768745015064056, 7.713993996723181, 4.842104543579959, 3.876459566361778, 2.910730333441499, 1.9566689671070614, 2.9616755268450774, 3.935528818549413, 4.902536454443306, 5.9168790714188395, 6.875781592598889, 7.814142790318858, 8.72262845417746, 9.603619127544237, 10.578754094825818, 11.600520201828422, 12.542145702762609, 12.576280420509828, 11.64436590225352, 10.671460700505587, 9.599834797283593, 8.673307218772223, 3.920614235967298, 2.9502993696036404, 1.9233027615798517, 0.9754265174828378, 2.017927269838357, 2.92848029866495, 3.9026746116313795, 4.862223206152119, 5.818614732136076, 6.779524013582253, 7.732070100585647, 8.667540230441258, 9.611807367855366, 10.635927791586916, 11.661667796190665, 12.61070352129787, 12.574272378369136, 11.632215876211685, 10.632658485452021, 9.70046081086036, 3.004969261812106, 1.9437334142780363, 0.997562824662177, 0.0, 0.9948227413830096, 1.9900436205318979, 2.9798666175017408, 3.9911906205075742, 4.9835842682763465, 6.017119124575672, 6.946970137792771, 7.973932852731512, 9.025724701974573, 10.09406670042615, 11.064268795744072, 12.008836474388158, 12.974499026587043, 12.617052563269255, 11.59337814510122, 10.748294848028095, 3.9587951490297106, 2.9986254153770586, 1.9785745478513876, 0.9597906460857917, 1.956153265318775, 2.9220083894765563, 3.876841639389548, 4.850199481553029, 5.8897488601342065, 6.917109622542815, 7.890215151944846, 8.92627641316646, 9.921699017213008, 10.848899930266883, 11.906343850532295, 12.862849390804257, 13.871208053746924, 13.545106795660764, 12.563063550926186, 11.684398556966713, 4.907948122869469, 3.931957875927066, 2.9228913270476538, 1.8873248352956242, 2.8475644418416213, 3.877338842039724, 4.903322970245749, 5.834049188408649, 6.826907925234282, 7.771957217007227, 8.819596456535423, 9.859282005368648, 10.804450719948616, 11.836161168218837, 12.795258319806011, 13.834980878569592, 14.869267750985081, 14.601929936683891, 13.534406607387217, 12.627920235120392, 5.801033124030133, 4.786894700909199, 3.8359273743491253, 2.8899734018359524, 3.8860998241427653, 4.808940697630202, 5.852138680283194, 6.81132291150041, 7.783716802880499, 8.749037362761024, 9.823110115746516, 10.86704307857039, 11.735804765940662, 12.66739887419755, 13.640001877375482, 14.705399394005312, 15.650609627918772, 15.529974720908855, 14.531951773923716, 13.49677723152218, 6.752666895199652, 5.811855512203055, 4.872570317990214, 3.9449654959714584, 4.9276611584757735, 5.7483102992957384, 6.715138985879667, 7.684280849232477, 8.70006421520035, 9.724016141037607, 10.666786909105399, 11.645777870034507, 12.59405207682197, 13.579689351499834, 14.634544816837241, 15.66859564350726, 15.906686138515786, 16.473345527299642, 15.412386799214598, 14.425831810118392, 7.722618733741041, 6.860483423049368, 5.9184507302837, 4.967841594595504, 5.9126494043344655, 6.746791695766725, 7.712634269313023, 8.682125519240914, 9.679950574788798, 10.650620493883162, 11.629619745008714, 12.555651471909043, 13.575434145064985, 14.519249849733011, 15.459034977594449, 15.685166206408333, 14.925841862423455, 15.857308087804945, 16.367582396676838, 15.490364947416296, 8.650304367375217, 7.830204690289864, 6.969072599463016, 5.9869549924916745, 6.923561424983537, 7.695936274089395, 8.665581796298937, 9.647385615665492, 10.6423560410538, 11.672002127395984, 12.677344857442133, 13.558338849773186, 14.489260108900947, 15.515526272486841, 15.628831141870878, 14.688610769448676, 13.904871104388711, 14.806102037776293, 15.688788628136418, 16.552011810637985], [16.591940518453875, 15.666501705050843, 14.758470166520276, 13.803473617003975, 12.820779382871804, 13.729689314830493, 14.683972201438424, 14.545927505772159, 13.630935785049289, 12.751210119359781, 11.70814717158785, 10.664546507416874, 9.734566822195829, 8.72410526255383, 7.780749041903595, 7.197541087023196, 7.977090094810548, 8.90629426768192, 9.851817956458087, 10.629399334264757, 15.520254761100851, 14.723631371372534, 13.817000321706278, 12.830992427861691, 11.797654083471109, 12.755860171260444, 13.658524794313973, 14.639210247852676, 14.528190981282485, 13.567625653503361, 12.635196072462234, 11.702377938648974, 10.72892388779745, 9.721296568551603, 8.828404582845037, 8.203644459695923, 9.0137899056389, 9.96395224978233, 10.740371596691745, 9.67364260332842, 14.514472973884205, 13.718557631884895, 12.750684396937626, 11.826744909717526, 10.827865828250818, 11.75784236128141, 12.663386234875809, 13.624392577207347, 14.60861966027504, 14.585431878448205, 13.661829795269803, 12.667785553292074, 11.75584260060212, 10.706258039612031, 9.853487861761163, 9.143043048131101, 9.985063530281582, 10.771250650104532, 9.771407458904644, 8.774259116525736, 13.54645366628912, 12.655756287051892, 11.740759009070425, 10.812126086510572, 9.766292673967808, 10.759465806182545, 11.664192652319487, 12.576007882173068, 13.614300568768456, 14.538236331942276, 14.67909041244369, 13.629932090167367, 12.734681677721046, 11.688013717952487, 10.91730205168087, 10.198066741193912, 10.673414416629381, 9.736798986608008, 8.809426828717422, 7.830766046895231, 12.615017984365013, 11.644764962215223, 10.70906969794149, 9.864590657670343, 8.805437144216208, 9.846599880355223, 10.697255543939333, 11.626823802723449, 12.637490280064307, 13.523741721907786, 14.547316974180887, 14.58273520445272, 13.673839910161224, 12.6431709982563, 11.748230212426154, 10.789469921722542, 9.735918692873877, 8.789052652618432, 7.858698749540524, 6.927954430086659, 11.724456978886032, 10.75134570851397, 9.769321406161403, 8.887718581937845, 7.8660309531491555, 8.85752290396701, 9.74434213484632, 10.720214267598852, 11.686802090367296, 12.585962503275322, 13.548369417899895, 13.851046147033802, 12.782465587233888, 11.769885983406757, 10.8207933444585, 9.857523269386075, 8.853638761131966, 7.853213992600246, 6.9648411638868915, 5.980677744155235, 10.76928469794422, 9.76325190438524, 8.774121659791172, 7.9106887432456645, 6.921291422572078, 7.912693740248173, 8.788073673909983, 9.754932274775765, 10.749970524856227, 11.659579498840879, 12.668780197636835, 12.937855685104044, 11.871941614699747, 10.926860184098217, 9.966625289214326, 9.001410746112278, 7.971770110462161, 6.928195187720561, 5.975849737090788, 5.0218564090892155, 9.78473048392552, 8.806613918618133, 7.8237471165711225, 6.9079442351500875, 5.970519430371824, 6.849456680146861, 7.785547284082853, 8.761631273269963, 9.775393644129538, 10.674612130661162, 11.601309453432423, 12.5705837144341, 12.813584389876087, 11.853728659631384, 10.892714699386465, 9.851240085881905, 8.81825614765067, 7.815919443842315, 6.871811749762388, 5.863059641634419, 8.806079750023835, 7.871726863838483, 6.893702938421609, 5.923052535626882, 4.936187782799532, 5.916857815399192, 6.875629491062343, 7.845874612117971, 8.747614847134216, 9.734589484483646, 10.622207762250175, 11.557698614288682, 12.491718236686106, 12.689549879907302, 11.661352281812105, 10.702140454585237, 9.748689572246334, 8.779393919035181, 7.822730119336064, 6.78891165559253, 7.737115052503645, 6.878478951291666, 5.906064085971966, 4.967970719873119, 3.919287622919588, 4.869449093260659, 5.9035224556243975, 6.8510690033730866, 7.76431799274967, 8.706383696289722, 9.689006146085527, 10.605078850943714, 11.597401987425089, 12.533501089034756, 12.647264782847513, 11.659084685952578, 10.699207977022029, 9.746274155790143, 8.76673905730503, 7.781557299379093, 6.792978054143596, 5.865908081632783, 4.8332695779820005, 3.9996545589994996, 2.9839970770346076, 3.868204529571642, 4.83908857089997, 5.80695432397393, 6.803463099346668, 7.775778035145685, 8.673755785248312, 9.597607198893515, 10.581638485325254, 11.547402778309241, 12.486775143500767, 12.635833011819322, 11.64835314014118, 10.753461726238212, 9.763567756447065, 8.70881673810619, 5.836927284962968, 4.871282307744788, 3.9055530748245086, 2.951491708490071, 2.0162493118223677, 2.9407060771664035, 3.9077137130602955, 4.922056330035829, 5.88095885121588, 6.8193200489358485, 7.727805712794451, 8.608796386161227, 9.583931353442809, 10.605697460445413, 11.5473229613796, 12.590971124431015, 12.63918864363653, 11.666283441888597, 10.594657538666603, 9.668129960155232, 4.915436977350308, 3.94512211098665, 2.9181255029628614, 1.9702492588658473, 1.0231045284553473, 1.9336575572819406, 2.9078518702483698, 3.867400464769109, 4.823791990753067, 5.784701272199244, 6.737247359202637, 7.672717489058249, 8.616984626472357, 9.641105050203906, 10.666845054807656, 11.61588077991486, 12.57389965315359, 12.627038617594694, 11.62748122683503, 10.69528355224337, 3.9997920031951164, 2.938556155661046, 1.9923855660451868, 0.9948227413830096, 0.0, 0.9952208791488881, 1.985043876118731, 2.9963678791245645, 3.9887615268933367, 5.022296383192662, 5.952147396409762, 6.979110111348502, 8.030901960591564, 9.099243959043143, 10.069446054361064, 11.01401373300515, 11.979676285204036, 12.994928644326695, 12.588200886484227, 11.743117589411105, 4.953617890412721, 3.993448156760068, 2.973397289234397, 1.9546133874688012, 1.001780805985451, 1.9676359301432322, 2.9224691800562237, 3.895827022219705, 4.9261430044227, 5.953503766831308, 6.895392410561836, 7.931453671783451, 8.926876275829997, 9.854077188883872, 10.911521109149284, 11.868026649421246, 12.876385312363913, 13.840647361981125, 13.557886292309194, 12.679221298349722, 5.902770864252478, 4.926780617310076, 3.917714068430663, 2.8821475766786335, 2.0414264810937306, 3.020902547994729, 3.9489505109124243, 4.8796767290753245, 5.869701977398879, 6.814751269171824, 7.86239050870002, 8.902076057533245, 9.847244772113214, 10.878955220383435, 11.83805237197061, 12.87777493073419, 13.890956945299994, 14.911054224669066, 14.529229348770224, 13.618386231163726, 6.795855865413143, 5.7817174422922095, 4.830750115732135, 3.8847961432189617, 3.0799618633948747, 3.952504403585207, 4.89776622094987, 5.856950452167085, 6.829344343547175, 7.791831414925622, 8.865904167911113, 9.909837130734985, 10.77859881810526, 11.710192926362149, 12.682795929540081, 13.74819344616991, 14.693403680083371, 15.750087016726582, 15.526774515306723, 14.487243227565514, 7.747489636582662, 6.806678253586064, 5.8673930593732235, 4.939788237354468, 4.131058635753012, 4.8918740052507435, 5.835774061556331, 6.804915924909141, 7.820699290877014, 8.813818816763227, 9.75658958483102, 10.735580545760127, 11.68385475254759, 12.669492027225454, 13.724347492562861, 14.739201489442117, 15.651819723233839, 16.660707764800453, 16.40285279525793, 15.416297806161726, 8.717441475124051, 7.855306164432378, 6.9132734716667095, 5.962664335978514, 5.191676619999644, 5.89035540172173, 6.836844319215727, 7.806335569143618, 8.804160624691502, 9.740423169608782, 10.719422420734334, 11.645454147634663, 12.665236820790605, 13.609052525458631, 14.548837653320069, 14.769581149526635, 15.779275620102933, 16.7490782759815, 17.35804839272017, 16.48083094345963, 9.645127108758228, 8.825027431672872, 7.963895340846025, 6.981777733874684, 6.239776275705874, 6.8394999800444, 7.794516859904903, 8.771595665568196, 9.766566090956504, 10.796212177298688, 11.767147533167753, 12.648141525498808, 13.579062784626569, 14.605328948212463, 14.71324608498918, 13.773025712566978, 14.786642576029507, 15.69787222595285, 16.649064561104055, 17.54247780668132], [17.415063041019955, 16.489624227616922, 15.581592689086358, 14.626596139570058, 13.643901905437886, 12.861577494237943, 13.705769933691768, 13.550706626623267, 12.635714905900397, 11.784330812899233, 10.756049347803453, 9.712448683632477, 8.782468998411431, 7.772007438769432, 6.828821142723763, 7.838144137757124, 8.889930471087487, 9.819134643958858, 10.81848707574284, 11.624620213413646, 16.343377283666932, 15.546753893938615, 14.640122844272359, 13.654114950427774, 12.620776606037191, 11.887748350667895, 12.663303915165086, 13.643989368703789, 13.564168344878157, 12.615527829718964, 11.683098248677837, 10.750280114864577, 9.776826064013052, 8.769198744767206, 7.876476683665205, 8.84424751042985, 9.90864001305112, 10.874718853521808, 11.735592475840633, 10.668863482477308, 15.337595496450286, 14.541680154450976, 13.573806919503706, 12.64986743228361, 11.6509883508169, 10.889730540688861, 11.668165355726922, 12.62917169805846, 13.613398781126154, 13.633334054663806, 12.709731971485404, 11.715687729507676, 10.803744776817723, 9.754160215827634, 8.90155996258133, 9.78364609886503, 10.831060455692366, 11.76647152925342, 10.766628338053533, 9.769479995674624, 14.3695761888552, 13.478878809617973, 12.563881531636508, 11.635248609076655, 10.58941519653389, 9.891353985589996, 10.6689717731706, 11.58078700302418, 12.61907968961957, 13.543015452793387, 13.726992588659293, 12.67783426638297, 11.78258385393665, 10.735915894168091, 9.965374152501038, 10.83866979192784, 11.66863529577827, 10.732019865756897, 9.80464770786631, 8.82598692604412, 13.438140506931093, 12.467887484781304, 11.532192220507573, 10.687713180236425, 9.62855966678229, 8.851379001206334, 9.702034664790446, 10.631602923574562, 11.64226940091542, 12.528520842758898, 13.552096095031999, 13.630637380668322, 12.721742086376828, 11.691073174471905, 11.016402021811952, 11.78469080087143, 10.731139572022766, 9.78427353176732, 8.853919628689413, 7.923175309235548, 12.58118091581092, 11.574468231080054, 10.592443928727485, 9.710841104503928, 8.689153475715237, 7.862302024818121, 8.749121255697434, 9.724993388449965, 10.69158121121841, 11.590741624126434, 12.553148538751007, 13.488046572395653, 13.663880028375496, 12.651300424548365, 11.816014223607388, 10.852744148534963, 9.848859640280855, 8.848434871749134, 7.96006204303578, 6.975898623304123, 11.626008634869109, 10.586374426951323, 9.597244182357255, 8.733811265811747, 7.7444139451381595, 6.917472861099285, 7.792852794761096, 8.759711395626878, 9.754749645707342, 10.66435861969199, 11.673559318487946, 12.514697050475391, 12.867162493848635, 11.922081063247106, 10.961846168363214, 9.996631625261166, 8.96699098961105, 7.92341606686945, 6.971070616239676, 6.017077288238104, 10.663939184042611, 9.629736441184216, 8.646869639137204, 7.73106675771617, 6.7936419529379055, 5.854235800997973, 6.790326404933965, 7.766410394121075, 8.78017276498065, 9.679391251512273, 10.606088574283534, 11.575362835285212, 12.458062651625362, 12.827421820001328, 11.866407859756409, 10.815291605862448, 9.782307667631212, 8.779970963822857, 7.83586326974293, 6.827111161614961, 9.767562811265474, 8.694849386404567, 7.716825460987692, 6.746175058192964, 5.759310305365614, 4.921636936250304, 5.880408611913454, 6.850653732969082, 7.752393967985327, 8.739368605334757, 9.626986883101287, 10.562477735139794, 11.496497357537217, 12.473728218596534, 12.625403801792649, 11.66619197456578, 10.712741092226878, 9.743445439015725, 8.786781639316606, 7.752963175573072, 8.701166572484187, 7.786493470577067, 6.772246324997283, 5.791093242439201, 4.74241014548567, 3.874228214111771, 4.908301576475509, 5.855848124224199, 6.7690971136007825, 7.711162817140833, 8.693785266936638, 9.609857971794826, 10.6021811082762, 11.538280209885867, 12.513376418852477, 12.623136205933122, 11.663259497002572, 10.710325675770687, 9.730790577285571, 8.745608819359635, 7.757029574124138, 6.829959601613325, 5.797321097962542, 4.836231915834089, 3.80711959960069, 2.872983650422754, 3.8438676917510826, 4.811733444825042, 5.80824222019778, 6.780557155996797, 7.678534906099425, 8.602386319744626, 9.586417606176365, 10.552181899160352, 11.491554264351878, 12.485869849618194, 12.612404660121724, 11.717513246218754, 10.727619276427607, 9.672868258086732, 6.80097880494351, 5.8353338277253295, 4.86960459480505, 3.880784907285859, 2.875778347547843, 1.9454851980175152, 2.9124928339114073, 3.9268354508869416, 4.885737972066991, 5.82409916978696, 6.7325848336455625, 7.613575507012339, 8.58871047429392, 9.610476581296522, 10.552102082230709, 11.595750245282124, 12.527664763538432, 12.630334961869139, 11.558709058647144, 10.632181480135774, 5.87948849733085, 4.909173630967192, 3.882177022943403, 2.934300778846389, 1.8826335641808227, 0.9384366781330524, 1.9126309910994816, 2.872179585620221, 3.8285711116041785, 4.789480393050355, 5.742026480053749, 6.67749660990936, 7.621763747323468, 8.645884171055016, 9.671624175658765, 10.62065990076597, 11.5786787740047, 12.520735276162151, 12.591532746815572, 11.65933507222391, 4.995012882344004, 3.933777034809934, 2.987606445194075, 1.9900436205318979, 0.9952208791488881, 0.0, 0.989822996969843, 2.0011469999756764, 2.9935406477444486, 4.027075504043774, 4.956926517260873, 5.983889232199614, 7.035681081442675, 8.104023079894255, 9.074225175212176, 10.018792853856262, 10.984455406055147, 11.999707765177806, 13.023382183345841, 12.69298323714208, 5.9488387695616085, 4.9886690359089565, 3.9686181683832857, 2.9498342666176898, 1.9815631551211823, 1.015708030963401, 1.95921357793779, 2.932571420101271, 3.9309221252738116, 4.95828288768242, 5.900171531412948, 6.936232792634563, 7.931655396681109, 8.858856309734984, 9.916300230000395, 10.872805770272358, 11.881164433215025, 12.845426482832236, 13.827469727566815, 13.545608138732387, 6.8979917434013664, 5.9220014964589645, 4.912934947579552, 3.877368455827522, 3.0212088302294617, 2.0689746488148977, 2.985694908793991, 3.91642112695689, 4.874481098249991, 5.819530390022935, 6.867169629551132, 7.906855178384356, 8.852023892964326, 9.883734341234547, 10.842831492821722, 11.882554051585302, 12.895736066151105, 13.915833345520177, 14.798812784027845, 14.441508753729806, 7.791076744562032, 6.776938321441098, 5.825970994881024, 4.88001702236785, 3.9852533482552257, 3.0005765044053754, 3.9345106188314363, 4.893694850048652, 5.866088741428741, 6.7966105357767335, 7.8706832887622244, 8.914616251586096, 9.783377938956372, 10.71497204721326, 11.687575050391192, 12.752972567021022, 13.698182800934482, 14.754866137577693, 15.756053622119065, 15.310365750131595, 8.74271051573155, 7.773347372870819, 6.8340621786579785, 5.906457356639223, 4.923761694134908, 3.9399461060709116, 4.872518459437898, 5.841660322790707, 6.857443688758581, 7.818597937614338, 8.761368705682129, 9.740359666611237, 10.6886338733987, 11.674271148076564, 12.729126613413971, 13.743980610293228, 14.65659884408495, 15.665486885651564, 16.726445613736608, 16.239420328727807, 9.71266235427294, 8.821975283717132, 7.879796623808696, 6.9291874881205, 5.984379678381539, 4.938427502541898, 5.873588717097293, 6.843079967025185, 7.840905022573068, 8.745202290459892, 9.724201541585444, 10.650233268485772, 11.670015941641715, 12.613831646309741, 13.553616774171179, 14.553202240101479, 15.562896710677776, 16.542641409713298, 17.57750744647028, 17.30395346602571, 10.640347987907116, 9.791696550957626, 8.880590519933092, 7.898472912961751, 6.961866480469888, 5.887572080864568, 6.831261257786469, 7.808340063449763, 8.80331048883807, 9.816899570840494, 10.771926654018863, 11.652920646349916, 12.583841905477676, 13.610108069063571, 13.84513426439663, 14.596148235133061, 15.60976509859559, 16.520994748518934, 17.47218708367014, 18.3656003292474], [18.388971570749572, 17.46353275734654, 16.555501218815973, 15.600504669299674, 14.617810435167502, 13.787476878353308, 12.897160417286852, 12.560883629653425, 11.645891908930555, 10.794507815929391, 9.76622635083361, 8.722625686662635, 7.792646001441589, 6.782184441799589, 7.725540662449823, 8.734863657483183, 9.786649990813546, 10.715854163684917, 11.72700287566038, 12.53735977106906, 17.31728581339655, 16.520662423668234, 15.614031374001978, 14.62802348015739, 13.594685135766808, 12.81364773478326, 11.85469439876017, 12.835379852298873, 12.574345347908315, 11.625704832749122, 10.693275251707995, 9.760457117894735, 8.787003067043209, 7.779375747797362, 8.773196203391263, 9.74096703015591, 10.805359532777178, 11.771438373247866, 12.648332033496047, 11.581603040132721, 16.311504026179904, 15.515588684180596, 14.547715449233326, 13.623775962013227, 12.624896880546517, 11.815629924804226, 10.859555839322006, 11.820562181653544, 12.804789264721238, 12.643511057693964, 11.719908974515562, 10.725864732537834, 9.81392177984788, 8.76433721885779, 9.757454572126859, 10.680365618591088, 11.727779975418425, 12.679211086908834, 11.679367895708946, 10.682219553330038, 15.34348471858482, 14.452787339347593, 13.537790061366126, 12.609157138806271, 11.563323726263507, 10.81725336970536, 9.860362256765685, 10.772177486619265, 11.810470173214654, 12.610897793011016, 12.737169591689451, 11.688011269413128, 10.792760856966805, 9.746092897198245, 10.820279877140106, 11.735389311653899, 12.658458292748112, 11.668627173410911, 10.741255015520325, 9.762594233698135, 14.412049036660713, 13.441796014510924, 12.506100750237191, 11.661621709966042, 10.602468196511907, 9.825287530935952, 8.89342514838553, 9.822993407169646, 10.833659884510505, 11.596403182976527, 12.619978435249626, 12.64081438369848, 11.731919089406983, 10.70125017750206, 11.667313720452999, 12.649039740887185, 11.720962568992608, 10.774096528737163, 9.790526936343426, 8.85978261688956, 13.555089445540538, 12.54837676080967, 11.566352458457104, 10.684749634233544, 9.663062005444853, 8.836210554547739, 7.940511739292519, 8.916383872045051, 9.832770411848145, 10.658623964344061, 11.621030878968634, 12.55592891261328, 12.67405703140565, 11.66147742757852, 12.594750588420652, 11.842567145504805, 10.838682637250697, 9.838257868718976, 8.949885040005622, 7.965721620273966, 12.599917164598727, 11.560282956680942, 10.571152712086873, 9.707719795541363, 8.718322474867776, 7.8913813908289026, 6.984243278356181, 7.951101879221964, 8.888219295261186, 9.732240959909618, 10.706734621618276, 11.547872353605722, 12.471441788235884, 12.65675952162689, 11.951669165333056, 10.986454622231008, 9.956813986580892, 8.913239063839292, 7.960893613209518, 7.006900285207946, 11.637847713772231, 10.603644970913834, 9.620778168866822, 8.704975287445786, 7.767550482667522, 6.82814433072759, 5.98171688852905, 6.95780087771616, 7.882712691500905, 8.7472735917299, 9.639263877413864, 10.608538138415543, 11.491237954755693, 12.451093685000396, 12.840316389486025, 11.789200135592065, 10.756216197360828, 9.753879493552473, 8.809771799472546, 7.801019691344577, 10.74147134099509, 9.668757916134183, 8.690733990717309, 7.720083587922581, 6.73321883509523, 5.895545465979922, 4.970578789846661, 5.940823910902289, 6.820276308202954, 7.807250945552385, 8.660162186231616, 9.595653038270124, 10.529672660667547, 11.506903521726864, 12.533117566085826, 12.640100504295397, 11.686649621956494, 10.717353968745341, 9.760690169046223, 8.726871705302688, 9.675075102213803, 8.760402000306684, 7.7461548547269, 6.765001772168818, 5.716318675215287, 4.848136743841388, 3.998471754408716, 4.946018302157405, 5.836979453818409, 6.77904515735846, 7.726960570066968, 8.635377875591583, 9.62770101207296, 10.563800113682627, 11.538896322649236, 12.488138079281697, 12.637168026732189, 11.684234205500303, 10.704699107015188, 9.719517349089251, 8.730938103853754, 7.803868131342941, 6.771229627692159, 5.810140445563706, 4.7810281293303065, 3.8468921801523708, 2.934037869684289, 3.901903622758249, 4.876124560415406, 5.806077059793554, 6.704054809896183, 7.627906223541384, 8.611937509973124, 9.577701802957112, 10.517074168148637, 11.511389753414953, 12.547054468248238, 12.69142177594837, 11.701527806157223, 10.646776787816348, 7.774887334673126, 6.809242357454946, 5.843513124534667, 4.8546934370154755, 3.8496868772774597, 2.9193937277471322, 1.938012737708166, 2.9523553546837, 3.91125787586375, 4.8496190735837175, 5.758104737442321, 6.639095410809097, 7.614230378090679, 8.635996485093282, 9.577621986027468, 10.621270149078883, 11.553184667335191, 12.526089869083124, 12.53261758837676, 11.60609000986539, 6.853397027060466, 5.883082160696809, 4.85608555267302, 3.908209308576006, 2.8565420939104396, 1.9123452078626695, 0.9381508948962402, 1.8976994894169792, 2.854091015400937, 3.8150002968471135, 4.767546383850507, 5.703016513706118, 6.647283651120226, 7.671404074851775, 8.697144079455525, 9.64617980456273, 10.60419867780146, 11.54625517995891, 12.545812570718574, 12.633243601953527, 5.984835879313847, 4.923600031779777, 3.977429442163918, 2.9798666175017408, 1.985043876118731, 0.989822996969843, 0.0, 1.0113240030058335, 2.0037176507746057, 3.037252507073931, 3.9671035202910305, 4.994066235229771, 6.045858084472832, 7.114200082924411, 8.084402178242332, 9.028969856886416, 9.994632409085302, 11.00988476820796, 12.033559186375996, 13.038053968072278, 6.938661766531451, 5.9466047194585885, 4.9052254760373, 3.8864415742717036, 2.89007895503872, 1.9242238308809387, 0.969390580967947, 1.942748423131428, 2.9410991283039687, 3.9684598907125768, 4.910348534443104, 5.946409795664719, 6.941832399711266, 7.86903331276514, 8.926477233030552, 9.882982773302514, 10.891341436245181, 11.855603485862392, 12.83764673059697, 13.896358270606317, 7.834599051055379, 6.858608804112977, 5.849542255233565, 4.813975763481536, 3.9297246301469997, 2.9774904487324356, 1.9958719118241475, 2.926598129987047, 3.884658101280148, 4.829707393053092, 5.877346632581289, 6.9170321814145135, 7.862200895994482, 8.893911344264703, 9.853008495851878, 10.892731054615458, 11.90591306918126, 12.926010348550333, 13.808989787058001, 14.841493813518772, 8.727684052216047, 7.713545629095112, 6.7625783025350374, 5.816624330021864, 4.893769148172764, 3.9090923043229133, 2.944687621861593, 3.903871853078809, 4.876265744458898, 5.806787538806891, 6.880860291792382, 7.9247932546162545, 8.793554941986528, 9.725149050243417, 10.697752053421349, 11.763149570051178, 12.708359803964639, 13.76504314060785, 14.766230625149221, 15.81794340032941, 9.655450073386964, 8.681863172788358, 7.742577978575516, 6.814973156556761, 5.8322774940524456, 4.84846190598845, 3.882695462468055, 4.851837325820864, 5.867620691788737, 6.828774940644495, 7.771545708712287, 8.750536669641395, 9.698810876428858, 10.684448151106722, 11.73930361644413, 12.754157613323384, 13.666775847115106, 14.67566388868172, 15.736622616766764, 16.72317760586297, 10.625401911928353, 9.730491083634671, 8.788312423726234, 7.837703288038038, 6.892895478299077, 5.846943302459437, 4.8837657201274505, 5.853256970055342, 6.851082025603225, 7.75537929349005, 8.734378544615602, 9.66041027151593, 10.680192944671873, 11.624008649339899, 12.563793777201337, 13.563379243131637, 14.573073713707934, 15.552818412743457, 16.587684449500436, 17.52885486069367, 11.55308754556253, 10.700212350875166, 9.78910631985063, 8.806988712879289, 7.870382280387427, 6.796087880782107, 5.841438260816626, 6.81851706647992, 7.813487491868227, 8.827076573870652, 9.78210365704902, 10.663097649380074, 11.594018908507834, 12.62028507209373, 13.536015932263972, 14.53956534036167, 15.553182203824198, 16.570127353011603, 17.52131968816281, 18.589090355927695], [18.50150449802971, 17.52274860428588, 16.48488743824386, 15.529890888727559, 14.480487667051008, 13.508248699416823, 12.56662817572282, 11.54955962664759, 10.634567905924719, 9.783183812923555, 8.855012491768326, 7.900466188500435, 6.998363434023281, 7.7252505388643025, 8.668606759514535, 9.677929754547897, 10.72971608787826, 11.65892026074963, 12.670068972725094, 13.480425868133775, 17.504462621216266, 17.531986426674067, 16.62535537700781, 15.639347483163224, 14.606009138772642, 13.824971737789095, 12.866018401766006, 12.260106438889839, 11.563021344902479, 10.803545334586921, 9.871115753545794, 8.938297619732534, 7.992720499624902, 8.722441844862075, 9.716262300455977, 10.684033127220623, 11.748425629841892, 12.71450447031258, 13.59139813056076, 12.524669137197435, 16.650506009751243, 16.526912687186428, 15.559039452239158, 14.635099965019059, 13.636220883552351, 12.826953927810061, 11.870879842327842, 11.24528876824451, 12.030237334124104, 11.821351559531763, 10.897749476353361, 9.903705234375634, 9.021981144517923, 9.707403315922503, 10.700520669191572, 11.623431715655801, 12.670846072483139, 13.622277183973548, 12.62243399277366, 11.625285650394751, 15.747408958599973, 15.464111342353425, 14.549114064371958, 13.620481141812105, 12.57464772926934, 11.828577372711196, 10.87168625977152, 10.19690407321023, 10.978711805938426, 11.706313614555253, 11.91501009352725, 10.865851771250927, 10.00124540325675, 10.68915899426296, 11.763345974204821, 12.678455408718612, 13.603181335120237, 12.611693270475625, 11.684321112585039, 10.705660330762848, 14.833538057311653, 14.453120017516756, 13.517424753243024, 12.672945712971876, 11.613792199517741, 10.836611533941785, 9.904749151391366, 9.247719993760612, 9.969349110396116, 10.691819004520763, 11.715394256793864, 11.81865488553628, 11.07386552286562, 11.644316274566775, 12.610379817517714, 13.5921058379519, 12.716507272857838, 11.769641232602392, 10.73359303340814, 9.802848713954274, 13.849461490521952, 13.559700763815503, 12.577676461462936, 11.696073637239378, 10.674386008450687, 9.84753455755357, 8.951835742298353, 8.216696709414048, 8.928186233392383, 9.754039785888299, 10.716446700512872, 11.651344734157519, 12.022865340663802, 12.604543524643235, 13.537816685485367, 12.853891148510641, 11.850006640256531, 10.84958187172481, 9.961209043011454, 8.9770456232798, 13.093704567339417, 12.571606959686774, 11.582476715092705, 10.719043798547197, 9.72964647787361, 8.902705393834735, 7.995567281362015, 7.218131957226122, 7.983635116805424, 8.827656781453856, 9.802150443162516, 10.643288175149962, 11.566857609780124, 12.511939040381653, 12.96299316833889, 11.997778625236842, 10.968137989586726, 9.924563066845126, 8.972217616215351, 8.01822428821378, 12.649171716778064, 11.614968973919666, 10.632102171872654, 9.716299290451618, 8.778874485673356, 7.839468333733422, 6.993040891534884, 6.184178095507949, 6.978128513045143, 7.8426894132741385, 8.734679698958104, 9.703953959959783, 10.586653776299933, 11.546509506544636, 12.507523466789555, 12.800524138597897, 11.767540200366662, 10.765203496558307, 9.82109580247838, 8.81234369435041, 11.752795344000923, 10.680081919140015, 9.702057993723141, 8.731407590928413, 7.744542838101063, 6.906869468985754, 5.981902792852495, 5.133537535288204, 5.915692129747192, 6.902666767096623, 7.755578007775857, 8.691068859814365, 9.625088482211789, 10.602319343271105, 11.628533387630064, 12.540498132193274, 12.697973624962327, 11.728677971751173, 10.772014172052055, 9.73819570830852, 10.686399105219635, 9.771726003312516, 8.757478857732732, 7.77632577517465, 6.72764267822112, 5.859460746847221, 5.009795757414549, 4.129060443345625, 4.932395275362647, 5.874460978902698, 6.822376391611208, 7.730793697135822, 8.723116833617198, 9.659215935226865, 10.634312144193474, 11.583553900825933, 12.591615452911627, 12.695558208506135, 11.71602311002102, 10.730841352095084, 9.742262106859586, 8.815192134348774, 7.782553630697992, 6.821464448569539, 5.7923521323361395, 4.858216183158204, 3.945361872690122, 3.0849457639464686, 3.971540381959645, 4.901492881337793, 5.799470631440422, 6.723322045085623, 7.707353331517362, 8.67311762450135, 9.612489989692875, 10.606805574959191, 11.642470289792476, 12.591840118631808, 12.712851809163055, 11.65810079082218, 8.786211337678958, 7.820566360460778, 6.8548371275405, 5.8660174400213085, 4.861010880283293, 3.9307177307529653, 2.949336740713999, 2.1118712068800534, 3.006673697407989, 3.945034895127957, 4.85352055898656, 5.734511232353336, 6.709646199634918, 7.73141230663752, 8.673037807571706, 9.716685970623121, 10.64860048887943, 11.621505690627362, 12.68952190157049, 12.617414012871222, 7.864721030066298, 6.894406163702641, 5.867409555678853, 4.919533311581839, 3.8678660969162726, 2.9236692108685025, 1.9494748979020735, 1.0428844249644442, 1.9495068369451758, 2.9104161183913524, 3.862962205394746, 4.798432335250357, 5.742699472664465, 6.766819896396013, 7.792559900999763, 8.741595626106967, 9.699614499345698, 10.641671001503148, 11.641228392262812, 12.573426066854474, 6.99615988231968, 5.93492403478561, 4.988753445169751, 3.9911906205075742, 2.9963678791245645, 2.0011469999756764, 1.0113240030058335, 0.0, 0.9923936477687721, 2.0259285040680974, 2.9557795172851975, 3.982742232223938, 5.034534081466999, 6.102876079918578, 7.073078175236499, 8.017645853880584, 8.98330840607947, 9.998560765202129, 11.022235183370164, 12.026729965066446, 7.949985769537284, 6.889670816523302, 5.8482915731020135, 4.829507671336417, 3.8331450521034336, 2.8672899279456523, 1.9124566780326608, 0.9390988358691797, 1.9297751252981352, 2.9571358877067433, 3.8990245314372713, 4.935085792658887, 5.9305083967054335, 6.857709309759308, 7.915153230024719, 8.871658770296682, 9.880017433239349, 10.84427948285656, 11.826322727591139, 12.885034267600485, 8.777665148120093, 7.801674901177691, 6.792608352298279, 5.7570418605462494, 4.872790727211713, 3.920556545797149, 2.9389380088888615, 1.922948542724799, 2.8733340982743147, 3.818383390047259, 4.866022629575455, 5.90570817840868, 6.850876892988648, 7.882587341258869, 8.841684492846044, 9.881407051609624, 10.894589066175428, 11.914686345544501, 12.79766578405217, 13.83016981051294, 9.67075014928076, 8.656611726159825, 7.705644399599751, 6.759690427086578, 5.836835245237477, 4.852158401387626, 3.887753718926307, 2.981530236227246, 3.9051279261839786, 4.795463535801057, 5.869536288786548, 6.913469251610421, 7.782230938980694, 8.713825047237583, 9.686428050415515, 10.751825567045344, 11.697035800958805, 12.753719137602015, 13.754906622143388, 14.806619397323578, 10.598516170451678, 9.624929269853071, 8.68564407564023, 7.758039253621473, 6.775343591117158, 5.791528003053163, 4.8257615595327685, 3.9647291213198366, 4.938369733323805, 5.817450937638661, 6.760221705706453, 7.739212666635561, 8.687486873423024, 9.673124148100888, 10.727979613438295, 11.74283361031755, 12.655451844109272, 13.664339885675886, 14.72529861376093, 15.711853602857136, 11.568468008993067, 10.673557180699385, 9.731378520790948, 8.78076938510275, 7.83596157536379, 6.790009399524149, 5.826831817192164, 5.034497039591435, 5.936227376673549, 6.744055290484216, 7.723054541609767, 8.649086268510095, 9.668868941666037, 10.612684646334063, 11.552469774195501, 12.552055240125801, 13.561749710702099, 14.541494409737622, 15.576360446494602, 16.517530857687838, 12.496153642627243, 11.64327844793988, 10.732172416915343, 9.750054809944002, 8.81344837745214, 7.7391539778468195, 6.78450435788134, 5.999757136016013, 6.949482667443689, 7.815752570864818, 8.770779654043185, 9.651773646374238, 10.582694905501999, 11.608961069087893, 12.524691929258136, 13.528241337355833, 14.541858200818362, 15.558803350005768, 16.509995685156973, 17.57776635292186], [17.50911085026094, 16.530354956517108, 15.492493790475088, 14.537497240958787, 13.488094019282237, 12.515855051648051, 11.57423452795405, 10.55716597887882, 9.642174258155949, 8.790790165154785, 7.862618843999555, 6.908072540731661, 7.8380522259527075, 8.681809220950505, 9.625165441600739, 10.6344884366341, 11.686274769964463, 12.615478942835834, 13.627689897874832, 14.438046793283512, 16.512068973447494, 17.456305712478652, 16.499970401342793, 15.509978430101071, 14.511219318682931, 13.4896841952181, 12.550436565243409, 11.515928919477934, 10.570627697133709, 9.811151686818148, 8.87872210577702, 7.9459039719637605, 8.832409291554328, 9.679000526948279, 10.67282098254218, 11.640591809306827, 12.704984311928095, 13.671063152398784, 14.549019055710499, 13.482290062347174, 15.658112361982472, 16.603840367809422, 16.482617864018184, 15.558678376798088, 14.559799295331379, 13.725585678129884, 12.769511592647664, 11.930972467222517, 11.037843686355332, 10.828957911762991, 9.90535582858459, 8.91131158660686, 9.861669936447349, 10.663961998008707, 11.657079351277776, 12.579990397742005, 13.627404754569342, 14.579898109123286, 13.580054917923398, 12.58290657554449, 14.7550153108312, 15.72409864598231, 15.472692476150984, 14.544059553591133, 13.498226141048368, 12.727209123031018, 11.770318010091342, 10.882587772188238, 9.986318158169654, 10.71391996678648, 10.922616445758477, 9.873458123482154, 10.840934195186176, 11.645717676349165, 12.719904656291025, 13.635014090804816, 14.564675849445713, 13.604086918244397, 12.67671476035381, 11.69805397853162, 13.841144409542878, 14.811397431692667, 14.44100316502205, 13.596524124750903, 12.537370611296769, 11.753193123293586, 10.803380901711188, 9.933403692738619, 8.976955462627345, 9.699425356751991, 10.723000609025092, 10.826261237767506, 11.85365886801296, 12.600874956652978, 13.566938499603918, 14.548664520038104, 13.70890092062661, 12.762034880371164, 11.725986681176911, 10.795242361723046, 12.857067842753178, 13.87090817311706, 13.501254873241962, 12.619652049018406, 11.597964420229715, 10.764116146905373, 9.850467492618176, 8.902380408392055, 7.93579258562361, 8.761646138119527, 9.7240530527441, 10.658951086388747, 11.52107050605245, 12.514827486661252, 13.435088542443772, 13.846284796279413, 12.842400288025303, 11.841975519493582, 10.953602690780226, 9.969439271048572, 12.101310919570645, 13.14094512748843, 12.50605512687173, 11.642622210326225, 10.653224889652638, 9.819286983186537, 8.894199031681838, 7.986279719117115, 6.991241469036652, 7.835263133685084, 8.809756795393742, 9.65089452738119, 10.574463962011352, 11.519545392612882, 12.441219229192923, 12.990172273005614, 11.960531637355498, 10.916956714613898, 9.964611263984123, 9.010617935982552, 12.654951909748174, 12.538547385698692, 11.55568058365168, 10.639877702230645, 9.702452897452384, 8.763046745512451, 7.891672641854707, 6.9609299823364355, 5.985734865276371, 6.850295765505367, 7.74228605118933, 8.711560312191011, 9.594260128531161, 10.554115858775864, 11.515129819020784, 12.566246072914744, 12.69111861214569, 11.688781908337335, 10.744674214257408, 9.735922106129438, 12.676373755779949, 11.603660330919041, 10.625636405502167, 9.65498600270744, 8.668121249880091, 7.8304478807647815, 6.880534543172318, 5.91028942211669, 4.92329848197842, 5.910273119327851, 6.763184360007084, 7.6986752120455915, 8.632694834443015, 9.609925695502332, 10.636139739861292, 11.548104484424503, 12.501555366763405, 12.652256383530203, 11.695592583831084, 10.66177412008755, 11.609977516998665, 10.695304415091544, 9.68105726951176, 8.699904186953678, 7.6512210900001465, 6.783039158626248, 5.933374169193575, 4.997278758401846, 3.9400016275938747, 4.882067331133926, 5.829982743842434, 6.7384000493670495, 7.730723185848425, 8.666822287458093, 9.641918496424703, 10.591160253057161, 11.599221805142857, 12.552155626374743, 12.63960152180005, 11.654419763874113, 10.665840518638616, 9.7387705461278, 8.706132042477018, 7.7450428603485655, 6.715930544115166, 5.781794594937231, 4.868940284469149, 3.953164079002689, 2.9791467341908726, 3.9090992335690213, 4.807076983671649, 5.73092839731685, 6.71495968374859, 7.680723976732578, 8.620096341924103, 9.61441192719042, 10.650076642023706, 11.599446470863038, 12.589340440654185, 12.58167920260121, 9.709789749457988, 8.744144772239807, 7.778415539319527, 6.789595851800335, 5.78458929206232, 4.854296142531992, 3.872915152493026, 2.9800895219362737, 2.0142800496392166, 2.9526412473591845, 3.8611269112177875, 4.742117584584563, 5.717252551866145, 6.739018658868749, 7.680644159802935, 8.724292322854351, 9.65620684111066, 10.629112042858592, 11.697128253801719, 12.608186011173839, 8.788299441845327, 7.817984575481669, 6.7909879674578795, 5.843111723360866, 4.7914445086952995, 3.8472476226475294, 2.8730533096811004, 1.9135047151603615, 0.9571131891764036, 1.9180224706225801, 2.870568557625974, 3.8060386874815846, 4.750305824895692, 5.7744262486272415, 6.800166253230991, 7.749201978338196, 8.707220851576926, 9.649277353734377, 10.64883474449404, 11.581032419085702, 7.988553530088453, 6.927317682554382, 5.9811470929385235, 4.9835842682763465, 3.9887615268933367, 2.9935406477444486, 2.0037176507746057, 0.9923936477687721, 0.0, 1.0335348562993252, 1.963385869516425, 2.990348584455165, 4.0421404336982265, 5.110482432149805, 6.080684527467726, 7.025252206111811, 7.990914758310697, 9.006167117433357, 10.029841535601392, 11.034336317297674, 8.942379417306057, 7.882064464292074, 6.840685220870785, 5.82190131910519, 4.825538699872206, 3.859683575714425, 2.904850325801433, 1.931492483637952, 0.937381477529363, 1.964742239937971, 2.906630883668499, 3.942692144890114, 4.938114748936661, 5.865315661990535, 6.922759582255947, 7.879265122527909, 8.887623785470575, 9.851885835087787, 10.833929079822365, 11.892640619831711, 9.770058795888865, 8.794068548946463, 7.785002000067051, 6.749435508315022, 5.865184374980486, 4.912950193565922, 3.9205782241889713, 2.8737991873311763, 1.8809404505055425, 2.8259897422784865, 3.873628981806683, 4.913314530639908, 5.858483245219876, 6.890193693490097, 7.849290845077273, 8.889013403840854, 9.902195418406656, 10.922292697775728, 11.805272136283396, 12.837776162744166, 10.663143797049532, 9.649005373928597, 8.698038047368524, 7.75208407485535, 6.829228893006251, 5.8445520491564, 4.844312401012511, 3.8851281697952946, 2.912734278415206, 3.803069888032285, 4.877142641017776, 5.921075603841649, 6.7898372912119225, 7.721431399468812, 8.694034402646745, 9.759431919276574, 10.704642153190035, 11.761325489833245, 12.762512974374618, 13.814225749554804, 11.556137095601416, 10.58255019500281, 9.643265000789969, 8.715660178771213, 7.732964516266897, 6.749148928202901, 5.782320241618972, 4.868327054887885, 3.9459760855550323, 4.825057289869889, 5.767828057937681, 6.746819018866789, 7.695093225654252, 8.680730500332114, 9.735585965669522, 10.75043996254878, 11.663058196340502, 12.671946237907116, 13.73290496599216, 14.719459955088366, 12.526088934142805, 11.631178105849123, 10.688999445940686, 9.73839031025249, 8.793582500513528, 7.747630324673888, 6.783390499278368, 5.938094973159483, 4.943833728904776, 5.751661642715444, 6.730660893840995, 7.656692620741324, 8.676475293897266, 9.620290998565292, 10.560076126426729, 11.55966159235703, 12.569356062933327, 13.54910076196885, 14.58396679872583, 15.525137209919066, 13.453774567776982, 12.600899373089618, 11.68979334206508, 10.707675735093739, 9.771069302601877, 8.696774902996557, 7.7410630399675435, 6.9033550695840615, 5.957089019674916, 6.8233589230960465, 7.778386006274414, 8.659379998605468, 9.590301257733229, 10.616567421319123, 11.532298281489364, 12.535847689587062, 13.54946455304959, 14.566409702236996, 15.517602037388201, 16.585372705153087], [16.538000786506768, 15.559244892762937, 14.521383726720916, 13.566387177204616, 12.516983955528065, 11.54474498789388, 10.710227337503206, 9.719632235375004, 8.824730250234413, 7.973346157233248, 7.182282883988594, 7.941607397030987, 8.871587082252033, 9.715344077249831, 10.658700297900065, 11.668023292933427, 12.719809626263789, 13.64901379913516, 14.661224754174158, 15.471581649582838, 15.540958909693323, 16.48519564872448, 15.528860337588622, 14.5388683663469, 13.54010925492876, 12.518574131463929, 11.732992557321875, 10.698484911556399, 9.753183689212173, 9.012397009332027, 8.251641813341372, 8.979438828263087, 9.865944147853654, 10.712535383247605, 11.706355838841507, 12.674126665606153, 13.738519168227421, 14.70459800869811, 15.582553912009825, 14.5158249186465, 14.646160101159198, 15.591888106986149, 16.58367507665102, 15.553184019061238, 14.498249067522755, 13.516591941442963, 12.68873107342808, 11.713302582201727, 10.735092311920727, 10.030203234276868, 9.27827553614894, 9.944846442906186, 10.895204792746675, 11.697496854308033, 12.690614207577102, 13.613525254041331, 14.660939610868668, 15.613432965422612, 14.613589774222724, 13.616441431843816, 13.721480454531873, 14.690563789682985, 15.734869226487893, 15.5233203951951, 14.477486982652335, 13.59611598116459, 12.639224868224915, 11.723709581795399, 10.744642335126256, 9.786461274995304, 10.303744545307195, 10.90699297978148, 11.874469051485502, 12.67925253264849, 13.75343951259035, 14.668548947104142, 15.59821070574504, 14.637621774543721, 13.710249616653135, 12.731588834830944, 12.807609553243552, 13.77786257539334, 14.713557839667072, 14.57578496635487, 13.516631452900736, 12.690379579472285, 11.67228775984476, 10.77452550234578, 9.818077272234506, 8.771966664960814, 9.795541917233914, 10.763456835752717, 11.527512602562247, 12.532497015449328, 13.419967689123041, 14.401693709557227, 14.742435776925936, 13.79556973667049, 12.759521537476237, 11.828777218022372, 11.823532986453852, 12.837373316817734, 13.819397619170303, 13.598912890622373, 12.577225261833682, 11.701302603084072, 10.719374350751748, 9.743502217999216, 8.776914395230772, 7.834187446328349, 8.796594360952922, 9.731492394597568, 10.578512784764065, 11.572269765372868, 12.492530821155388, 13.418202007570565, 13.875935144324627, 12.875510375792906, 11.98713754707955, 11.002974127347896, 11.06777606327132, 12.107410271189105, 13.107175261966221, 12.621883051930192, 11.632485731256605, 10.756473439365235, 9.831385487860537, 8.864526886994755, 7.869488636914292, 6.907804441893906, 7.867199074105358, 8.708336806092804, 9.631906240722968, 10.576987671324497, 11.498661507904538, 12.463876051006586, 12.994066493654822, 11.950491570913222, 10.998146120283447, 10.044152792281876, 11.712394188459788, 12.746596931318184, 12.534941425255647, 11.619138543834612, 10.68171373905635, 9.742307587116418, 8.84834535714363, 7.877744404013587, 6.863982033154011, 5.922837073714189, 6.799728329900946, 7.769002590902626, 8.651702407242777, 9.61155813748748, 10.5725720977324, 11.62368835162636, 12.536089750485203, 12.668042749941302, 11.723935055861375, 10.715182947733405, 12.632153989059919, 12.582921172523008, 11.604897247106134, 10.634246844311408, 9.647382091484058, 8.809708722368748, 7.837207258461241, 6.866962137405613, 5.879971197267343, 4.982814427536673, 5.820626638718699, 6.756117490757207, 7.6901371131546306, 8.667367974213947, 9.693582018572906, 10.605546763136118, 11.55899764547502, 12.528293298686176, 12.674853425435051, 11.641034961691517, 12.589238358602632, 11.67456525669551, 10.660318111115727, 9.679165028557644, 8.630481931604114, 7.762300000230216, 6.912635010797544, 5.960744973653858, 4.896674342882799, 3.954608639342748, 4.88742502255405, 5.795842328078665, 6.7881654645600396, 7.7242645661697065, 8.699360775136316, 9.648602531768777, 10.65666408385447, 11.609597905086355, 12.618506422797678, 12.63368060547808, 11.645101360242583, 10.718031387731768, 9.685392884080986, 8.724303701952532, 7.695191385719134, 6.761055436541199, 5.848201126073117, 4.932424920606657, 3.9584075757948405, 2.966541512280636, 3.864519262383264, 4.788370676028466, 5.772401962460204, 6.738166255444193, 7.677538620635718, 8.671854205902035, 9.707518920735318, 10.65688874957465, 11.646782719365797, 12.624941511934495, 10.689050591061955, 9.723405613843774, 8.757676380923495, 7.768856693404303, 6.7638501336662875, 5.83355698413596, 4.852175994096994, 3.9593503635402416, 2.9935408912431845, 2.010083526070799, 2.918569189929402, 3.7995598632961785, 4.77469483057776, 5.796460937580362, 6.738086438514549, 7.781734601565964, 8.713649119822271, 9.686554321570204, 10.754570532513332, 11.665628289885452, 9.767560283449294, 8.797245417085636, 7.770248809061847, 6.822372564964834, 5.770705350299267, 4.826508464251497, 3.8523141512850683, 2.892765556764329, 1.9363740307803714, 0.9754647493341948, 1.9280108363375885, 2.8634809661931993, 3.807748103607307, 4.831868527338855, 5.857608531942605, 6.806644257049809, 7.7646631302885405, 8.70671963244599, 9.706277023205654, 10.638474697797315, 9.022088386387777, 7.9608525388537075, 7.014681949237849, 6.017119124575672, 5.022296383192662, 4.027075504043774, 3.037252507073931, 2.0259285040680974, 1.0335348562993252, 0.0, 0.9298510132170998, 1.95681372815584, 3.0086055773989013, 4.07694757585048, 5.047149671168401, 5.991717349812486, 6.957379902011372, 7.972632261134032, 8.996306679302066, 10.000801460998348, 9.975914273605381, 8.9155993205914, 7.874220077170111, 6.855436175404515, 5.8590735561715315, 4.89321843201375, 3.9383851821007583, 2.965027339937277, 1.9709163338286881, 1.0747494639330615, 1.8730960273691737, 2.909157288590789, 3.9045798926373356, 4.83178080569121, 5.8892247259566215, 6.845730266228584, 7.85408892917125, 8.81835097878846, 9.800394223523039, 10.859105763532385, 10.80359365218819, 9.827603405245789, 8.818536856366377, 7.782970364614347, 6.898719231279811, 5.946485049865247, 4.9541130804882965, 3.9073340436305015, 2.9144753068048677, 2.1456537822675257, 2.920788349041655, 3.9365670220555664, 4.846530984396603, 5.878241432666824, 6.83097170386317, 7.870694262626751, 8.86866056210733, 9.888757841476401, 10.77173727998407, 11.80424130644484, 11.696678653348856, 10.682540230227922, 9.731572903667848, 8.785618931154675, 7.862763749305575, 6.878086905455724, 5.877847257311836, 4.91866302609462, 3.946269134714531, 3.122733928021324, 3.960024021372587, 4.990813260428067, 5.777885030388649, 6.709479138645539, 7.682082141823471, 8.747479658453301, 9.692689892366761, 10.749373229009972, 11.750560713551344, 12.780690893255478, 12.589671951900742, 11.616085051302136, 10.676799857089295, 9.749195035070539, 8.766499372566223, 7.782683784502226, 6.8158550979182975, 5.90186191118721, 4.9795109418543575, 4.144721329858928, 4.916721424027684, 5.895712384956793, 6.7129333423660835, 7.698570617043947, 8.7501213895149, 9.738487701725507, 10.65110593551723, 11.659993977083843, 12.720952705168887, 13.707507694265093, 13.559623790442132, 12.66471296214845, 11.722534302240012, 10.771925166551815, 9.827117356812854, 8.781165180973213, 7.816925355577693, 6.971629829458808, 5.977368585204101, 5.071325682704483, 5.913216885919459, 6.839248612819787, 7.705365230143095, 8.64918093481112, 9.588966062672558, 10.588551528602858, 11.598245999179156, 12.577990698214679, 13.61285673497166, 14.554027146164895, 14.487309424076308, 13.634434229388944, 12.723328198364406, 11.741210591393065, 10.804604158901203, 9.730309759295883, 8.774597896266869, 7.936889925883387, 6.990623875974242, 6.143022963085086, 6.960941998352878, 7.841935990683932, 8.752767514229413, 9.656153673644964, 10.561188217735193, 11.56473762583289, 12.57835448929542, 13.595299638482825, 14.54649197363403, 15.614262641398916], [15.60814977328967, 14.629393879545841, 13.591532713503819, 12.636536163987518, 11.587132942310967, 10.614893974676782, 9.780376324286108, 8.789781222157904, 7.894879237017313, 7.043495144016148, 7.967202733008042, 8.854900866166687, 9.784880551387733, 10.645195090466931, 11.588551311117165, 12.597874306150526, 13.649660639480889, 14.57886481235226, 15.591075767391256, 16.401432662799937, 14.611107896476225, 15.555344635507385, 14.599009324371524, 13.609017353129802, 12.610258241711662, 11.58872311824683, 10.803141544104772, 9.768633898339298, 8.823332675995072, 8.082545996114927, 9.014975577156054, 9.892732297398787, 10.779237616989354, 11.642386396464705, 12.636206852058606, 13.603977678823252, 14.668370181444521, 15.63444902191521, 16.512404925226924, 15.445675931863597, 13.716309087942097, 14.662037093769047, 15.653824063433921, 14.62333300584414, 13.568398054305657, 12.586740928225865, 11.758880060210979, 10.783451568984626, 9.805241298703626, 9.100352221059769, 10.03472053051065, 10.858139912041887, 11.808498261882376, 12.627347867525133, 13.620465220794202, 14.54337626725843, 15.590790624085768, 16.54328397863971, 15.543440787439822, 14.546292445060914, 12.791629441314775, 13.760712776465887, 14.805018213270795, 15.631658929795101, 14.578290615539467, 13.58511748332473, 12.7580736427673, 11.831836264018905, 10.856766826889304, 10.0782638838998, 9.942746094325264, 10.836359532774505, 11.684812489654503, 12.572334063236527, 13.555675325917342, 14.443007177127187, 15.373692556673792, 15.56747278776082, 14.640100629870235, 13.661439848048044, 11.877758540026456, 12.848011562176245, 13.783706826449976, 14.812317845198582, 14.446482466117835, 13.5680001240053, 12.549908304377777, 11.652146046878796, 10.695697816767522, 9.64958720949383, 9.013180265248453, 9.883556418489153, 10.612192370045632, 11.617176782932713, 12.504647456606428, 13.486373477040614, 14.539518351449713, 14.725420749887588, 13.689372550693335, 12.75862823123947, 10.893681973236754, 11.907522303600636, 12.889546605953203, 13.845440246265293, 13.507076275050782, 12.578923147617086, 11.596994895284764, 10.621122762532233, 9.654534939763789, 8.711807990861365, 8.01423270896746, 8.851591977334005, 9.66319255224745, 10.656949532856252, 11.577210588638774, 12.502881775053952, 13.50676628330806, 13.805361389010006, 12.91698856029665, 11.932825140564995, 10.13792505005422, 11.177559257972005, 12.177324248749121, 13.15204999934824, 12.562336744473704, 11.63409398389825, 10.709006032393551, 9.74214743152777, 8.747109181447305, 7.785424986426921, 6.951878841588744, 7.793016573576191, 8.716586008206352, 9.661667438807882, 10.583341275387925, 11.548555818489973, 12.57819645414009, 12.880342584130322, 11.927997133500547, 10.974003805498976, 10.797073955943176, 11.831276698801574, 12.814143500848585, 12.548989557051712, 11.61156475227345, 10.667539541669703, 9.731448937733711, 8.755364948546601, 7.741602577687026, 6.800457618247204, 5.884408097384332, 6.8536823583860125, 7.736382174726162, 8.696237904970866, 9.657251865215786, 10.708368119109746, 11.620769517968593, 12.580204593826872, 12.653786069078475, 11.645033960950505, 11.716833756543307, 12.789547181404215, 12.534748260323234, 11.564097857528507, 10.577233104701158, 9.739559735585848, 8.76705827167834, 7.796813150622713, 6.809822210484443, 5.860434972069688, 4.905306406202086, 5.840797258240594, 6.774816880638017, 7.752047741697333, 8.778261786056294, 9.690226530619508, 10.64367741295841, 11.612973066169566, 12.569636865868684, 12.570885974908617, 12.781360304418513, 12.60441626991261, 11.590169124332826, 10.609016041774744, 9.560332944821214, 8.692151013447315, 7.842486024014644, 6.890595986870958, 5.826525356099898, 4.884459652559848, 3.972104790037436, 4.880522095562052, 5.872845232043427, 6.808944333653095, 7.784040542619705, 8.733282299252165, 9.741343851337858, 10.694277672569743, 11.703186190281066, 12.63688071814498, 12.574952373459682, 11.647882400948868, 10.615243897298086, 9.654154715169632, 8.625042398936234, 7.690906449758298, 6.778052139290216, 5.8622759338237564, 4.88825858901194, 3.8963925254977356, 2.949199029866651, 3.8730504435118522, 4.857081729943592, 5.82284602292758, 6.762218388119106, 7.756533973385422, 8.792198688218706, 9.741568517058038, 10.731462486849185, 11.709621279417883, 11.618901604279054, 10.653256627060873, 9.687527394140595, 8.698707706621404, 7.693701146883387, 6.76340799735306, 5.782027007314094, 4.889201376757342, 3.923391904460284, 2.939934539287899, 2.003248957412789, 2.8842396307795655, 3.859374598061147, 4.88114070506375, 5.822766205997937, 6.866414369049352, 7.79832888730566, 8.771234089053593, 9.83925029999672, 10.75030805736884, 10.697411296666393, 9.727096430302735, 8.700099822278947, 7.752223578181933, 6.700556363516367, 5.756359477468597, 4.782165164502167, 3.8226165699814287, 2.866225043997471, 1.9053157625512946, 1.0126906038209753, 1.9481607336765863, 2.8924278710906943, 3.916548294822243, 4.942288299425992, 5.891324024533197, 6.849342897771928, 7.791399399929379, 8.790956790689043, 9.723154465280704, 9.951939399604877, 8.890703552070807, 7.944532962454948, 6.946970137792771, 5.952147396409762, 4.956926517260873, 3.9671035202910305, 2.955779517285197, 1.963385869516425, 0.9298510132170998, 0.0, 1.0269627149387401, 2.0787545641818017, 3.1470965626333802, 4.117298657951301, 5.061866336595386, 6.027528888794272, 7.042781247916932, 8.066455666084966, 9.070950447781248, 10.905765286822481, 9.845450333808499, 8.80407109038721, 7.785287188621614, 6.78892456938863, 5.823069445230849, 4.8682361953178575, 3.8948783531543767, 2.9007673470457878, 2.004600477150161, 0.9432450141520738, 1.9793062753736892, 2.974728879420236, 3.9019297924741103, 4.959373712739522, 5.915879253011484, 6.9242379159541505, 7.888499965571362, 8.870543210305941, 9.929254750315287, 11.733444665405289, 10.757454418462887, 9.748387869583475, 8.712821377831446, 7.82857024449691, 6.876336063082346, 5.883964093705396, 4.837185056847601, 3.8443263200219673, 3.0385765753527516, 1.9909373358245552, 3.006716008838467, 3.9166799711795033, 4.948390419449725, 5.901120690646071, 6.940843249409651, 7.93880954889023, 8.958906828259302, 9.841886266766972, 10.874390293227743, 12.626529666565956, 11.612391243445021, 10.661423916884948, 9.715469944371774, 8.792614762522675, 7.807937918672824, 6.8076982705289355, 5.84851403931172, 4.876120147931631, 4.0156567211065495, 3.0301730081554874, 4.060962247210967, 4.84803401717155, 5.779628125428439, 6.752231128606371, 7.8176286452362005, 8.76283887914966, 9.81952221579287, 10.820709700334243, 11.85083988003838, 13.51952296511784, 12.545936064519234, 11.606650870306392, 10.679046048287637, 9.69635038578332, 8.712534797719325, 7.745706111135397, 6.83171292440431, 5.909361955071457, 4.929641178878376, 3.9868704108105844, 4.9658613717396936, 5.783082329148984, 6.768719603826847, 7.820270376297801, 8.808636688508408, 9.721254922300128, 10.730142963866742, 11.791101691951786, 12.777656681047992, 14.48947480365923, 13.594563975365547, 12.65238531545711, 11.701776179768913, 10.756968370029952, 9.71101619419031, 8.746776368794793, 7.888487109887686, 6.890662054339803, 5.856245531723931, 4.983365872702359, 5.909397599602688, 6.775514216925996, 7.719329921594022, 8.65911504945546, 9.65870051538576, 10.668394985962058, 11.648139684997581, 12.683005721754562, 13.624176132947797, 15.417160437293406, 14.564285242606042, 13.653179211581506, 12.671061604610165, 11.734455172118302, 10.660160772512981, 9.704448909483968, 8.853747206312264, 7.903917345109942, 6.927942812104534, 6.031090985135778, 6.912084977466832, 7.822916501012314, 8.726302660427866, 9.631337204518095, 10.634886612615793, 11.648503476078321, 12.665448625265729, 13.616640960416934, 14.68441162818182], [14.667230683111066, 13.688474789367238, 12.650613623325217, 11.695617073808917, 10.646213852132366, 9.67397488449818, 8.839457234107506, 7.8488621319793035, 7.143387406429963, 8.070457858954889, 8.99416544794678, 9.881863581105426, 10.811843266326472, 11.672157805405671, 12.615514026055905, 13.624837021089267, 14.676623354419629, 15.605827527291, 16.618038482329997, 17.428395377738678, 13.670188806297624, 14.614425545328784, 13.658090234192922, 12.668098262951201, 11.66933915153306, 10.64780402806823, 9.881923252634188, 8.877987476366144, 8.071840845407724, 9.032406173186848, 9.964835754227975, 10.897653888041235, 11.806200331928093, 12.669349111403445, 13.663169566997347, 14.630940393761993, 15.695332896383261, 16.66141173685395, 17.53936764016567, 16.47263864680234, 12.769461543319595, 13.715189549146546, 14.71290497325532, 13.682413915665538, 12.627478964127056, 11.645821838047263, 10.868233638237825, 9.892805147011472, 9.053749468116278, 10.050212398131691, 10.984580707582573, 10.875562561374744, 11.741133240118275, 12.63114623330193, 13.624263586570999, 14.575087361914944, 15.388020143275108, 16.37562083233681, 16.570403502378564, 15.573255159999656, 11.842544119105673, 12.811627454256785, 13.855932891061693, 14.6907398396165, 13.637371525360866, 12.644198393146128, 11.867427220794147, 10.941189842045752, 10.105274996301956, 11.028124060971722, 10.792059888061399, 9.913416024499451, 10.761868981379449, 11.649390554961473, 12.632731817642288, 13.520063668852133, 14.450749048398738, 15.44223711304335, 15.667063344808977, 14.688402562986786, 10.928673217817352, 11.89892623996714, 12.834621504240872, 13.863232522989478, 14.598227055112465, 13.68417337752979, 12.819942180279487, 11.890373921495371, 11.114637691844266, 10.509057876130012, 9.862494058984588, 8.960612910214099, 9.689248861770578, 10.694233274657659, 11.581703948331374, 12.56342996876556, 13.613444525169692, 14.397211799975647, 14.716335265632077, 13.785590946178212, 9.944518664702594, 10.958358995066476, 11.940383297419043, 12.896276937731132, 13.917964566519823, 13.438393814253267, 12.456465561920947, 11.480593429168415, 10.514005606399971, 9.571278657497547, 8.863546502703596, 7.92864846905895, 8.740249043972396, 9.734006024581198, 10.654267080363718, 11.579938266778896, 12.58069245702804, 13.46137313995746, 13.94395127523539, 12.959787855503736, 9.110962335115481, 10.150596543033267, 11.150361533810383, 12.125087284409501, 13.114484605083089, 12.49356465053443, 11.568476699029732, 10.60161809816395, 9.606579848083488, 8.644895653063104, 7.803239828417761, 6.870073065301137, 7.793642499931297, 8.738723930532828, 9.660397767112869, 10.625612310214917, 11.596815779470651, 12.536354335077776, 12.954959848439287, 12.000966520437716, 9.810206166351882, 10.84440890921028, 11.827275711257291, 12.78971100728682, 12.510309438327505, 11.527010208305885, 10.590919604369894, 9.614835615182784, 8.601073244323208, 7.659928284883387, 6.743878764020515, 5.9307388501109575, 6.813438666451107, 7.773294396695811, 8.73430835694073, 9.723039657150602, 10.6339017283773, 11.593336804235578, 12.537444498315505, 12.58902735934351, 10.729965966952014, 11.802679391812921, 12.757319889406805, 12.508091255921512, 11.521226503094162, 10.683553133978853, 9.670193518962835, 8.699948397907207, 7.712957457768938, 6.719905638705871, 5.764777072838268, 4.917853749965539, 5.851873372362962, 6.829104233422278, 7.791393996465002, 8.703358741028214, 9.656809623367117, 10.626105276578272, 11.58276907627739, 12.616587540020925, 11.794492514827219, 12.743675758877766, 12.53416252272583, 11.553009440167749, 10.504326343214219, 9.63614441184032, 8.786479422407648, 7.820334240780534, 6.756263610009475, 5.814197906469424, 4.831575456673619, 3.8936543059707596, 4.885977442452135, 5.822076544061803, 6.797172753028413, 7.746414509660873, 8.754476061746564, 9.70740988297845, 10.716318400689772, 11.650012928553686, 12.647509549605116, 12.591875799341873, 11.55923729569109, 10.598148113562637, 9.569035797329239, 8.634899848151303, 7.722045537683221, 6.806269332216759, 5.832251987404944, 4.840385923890739, 3.808669696502834, 2.88618265392056, 3.8702139403522997, 4.835978233336288, 5.7753505985278135, 6.76966618379413, 7.805330898627413, 8.754700727466744, 9.744594697257892, 10.722753489826589, 12.56289500267206, 11.597250025453878, 10.6315207925336, 9.642701105014408, 8.637694545276393, 7.707401395746064, 6.726020405707098, 5.833194775150345, 4.867385302853288, 3.883927937680903, 2.8627196240489723, 1.8973718411882732, 2.8725068084698546, 3.894272915472458, 4.8358984164066445, 5.87954657945806, 6.811461097714368, 7.784366299462301, 8.852382510405427, 9.763440267777547, 11.641404695059398, 10.67108982869574, 9.644093220671952, 8.696216976574938, 7.644549761909372, 6.7003528758616016, 5.726158562895172, 4.766609968374433, 3.8102184423904752, 2.8493091609442986, 1.896763073940905, 0.9612929440852941, 1.9055600814994018, 2.9296805052309507, 3.9554205098346995, 4.904456234941904, 5.862475108180635, 6.804531610338086, 7.804089001097749, 8.73628667568941, 10.978902114543617, 9.917666267009547, 8.971495677393689, 7.973932852731512, 6.979110111348502, 5.983889232199614, 4.994066235229771, 3.9827422322239374, 2.990348584455165, 1.95681372815584, 1.0269627149387401, 0.0, 1.0517918492430613, 2.12013384769464, 3.0903359430125605, 4.034903621656646, 5.000566173855532, 6.015818532978192, 7.039492951146227, 8.04398773284251, 11.932728001761221, 10.87241304874724, 9.831033805325951, 8.812249903560355, 7.8158872843273715, 6.85003216016959, 5.895198910256599, 4.9218410680931175, 3.927730061984528, 3.0315631920889015, 1.970207729090814, 1.038387185195087, 2.0338097892416336, 2.961010702295508, 4.0184546225609195, 4.974960162832882, 5.983318825775548, 6.9475808753927595, 7.929624120127338, 8.980091441781127, 12.76040738034403, 11.784417133401629, 10.775350584522217, 9.739784092770188, 8.855532959435651, 7.903298778021087, 6.9109268086441356, 5.864147771786341, 4.871289034960707, 4.0655392902914915, 3.0179000507632954, 2.0657969186598644, 2.975760881000901, 4.007471329271122, 4.960201600467468, 5.99992415923105, 6.997890458711628, 8.0179877380807, 8.900967176588368, 9.92530497101864, 13.653492381504698, 12.639353958383763, 11.68838663182369, 10.742432659310516, 9.819577477461415, 8.834900633611564, 7.834660985467676, 6.87547675425046, 5.903082862870371, 5.04261943604529, 4.057135723094227, 3.120043157032365, 3.9071149269929477, 4.8387090352498365, 5.811312038427769, 6.876709555057598, 7.8219197889710586, 8.87860312561427, 9.879790610155641, 10.901754557829278, 14.546485680056582, 13.572898779457976, 12.633613585245135, 11.706008763226379, 10.723313100722063, 9.739497512658067, 8.772668826074138, 7.85867563934305, 6.9363246700101975, 5.956603893817116, 5.013833125749324, 4.139256082569783, 4.842163238970382, 5.827800513648246, 6.879351286119198, 7.867717598329804, 8.780335832121526, 9.78922387368814, 10.850182601773184, 11.83080913642549, 15.516437518597971, 14.62152669030429, 13.679348030395852, 12.728738894707655, 11.783931084968694, 10.737978909129053, 9.773739083733533, 8.915449824826425, 7.917624769278541, 6.8832082466626705, 6.0103285876411, 5.157905769015338, 5.834595126747394, 6.77841083141542, 7.718195959276858, 8.717781425207159, 9.727475895783456, 10.70722059481898, 11.74208663157596, 12.683257042769196, 16.444123152232148, 15.591247957544784, 14.680141926520246, 13.698024319548905, 12.761417887057043, 11.687123487451723, 10.731411624422709, 9.880709921251002, 8.93088006004868, 7.954905527043273, 7.0580537000745185, 6.160593146879482, 6.881997410833712, 7.785383570249264, 8.690418114339494, 9.693967522437191, 10.70758438589972, 11.724529535087125, 12.67572187023833, 13.743492538003217], [13.674085884267834, 12.695329990524005, 11.657468824481985, 10.702472274965684, 9.653069053289133, 8.680830085654948, 7.846312435264274, 6.855717333136072, 7.801423970774794, 8.7538330527973, 9.756615930041178, 10.644314063199824, 11.57429374842087, 12.545810278520852, 13.489166499171086, 14.498489494204447, 15.55027582753481, 16.47948000040618, 17.49794837219459, 18.383658082733994, 12.677044007454393, 13.621280746485551, 12.66494543534969, 11.674953464107968, 10.676194352689828, 9.654659229224997, 8.888778453790955, 7.8848426775229115, 8.729877409752554, 9.690442737531678, 10.622872318572805, 11.555690452386065, 11.916012576028157, 12.761726395379219, 13.794965556503985, 14.660104641366983, 15.504912458934651, 16.47099129940534, 17.493498594672978, 17.427901351797658, 11.717669694076532, 12.663397699903483, 13.667043876779552, 12.689269116822306, 11.634334165283823, 10.65267703920403, 9.875088839394593, 8.89966034816824, 9.711786032461108, 10.708248962476521, 11.642617271927403, 11.777214834193538, 10.886751931135136, 11.77676492431879, 12.76988227758786, 13.720706052931805, 14.533638834291969, 15.521239523353671, 16.454830586725418, 16.528517864994974, 10.79075226986261, 11.759835605013722, 12.80414104181863, 13.697595040773267, 12.644226726517633, 11.651053594302896, 10.874282421950914, 9.94804504320252, 10.763311560646786, 11.686160625316552, 11.766062608132707, 10.815068297318245, 9.907487672396309, 10.795009245978333, 11.778350508659148, 12.665682359868994, 13.596367739415598, 14.579923567265439, 15.489338405503036, 15.740194412229846, 9.876881368574288, 10.847134390724078, 11.782829654997808, 12.811440673746414, 13.605082256269233, 12.691028578686558, 11.826797381436254, 10.897229122652138, 11.772674256189095, 11.48306059620132, 10.836496779055896, 9.862265183032893, 8.834867552787438, 9.83985196567452, 10.727322639348234, 11.70904865978242, 12.721993266445656, 13.505760541251611, 14.47619562854959, 14.837382795421272, 8.89272681545953, 9.906567145823413, 10.88859144817598, 11.844485088488069, 12.86617271727676, 13.680105555074771, 12.779710790529267, 11.928252406998702, 11.48800832647128, 10.545281377568855, 9.837549222774904, 8.902651189130257, 7.885867734989256, 8.879624715598059, 9.79988577138058, 10.725556957795758, 11.689241198304003, 12.569921881233425, 13.513360590053166, 14.011579704746795, 8.059170485872418, 9.098804693790203, 10.09856968456732, 11.073295435166438, 12.062692755840025, 13.067910573238638, 12.54247941910104, 11.575620818235258, 10.580582568154796, 9.618898373134412, 8.777242548489067, 7.844075785372443, 6.939261190948159, 7.884342621549688, 8.806016458129731, 9.77123100123178, 10.705364520746615, 11.64490307635374, 12.597248526983515, 13.052758369680776, 8.849379121521103, 9.8835818643795, 10.866448666426512, 11.828883962456041, 12.797510210602809, 12.501012928377193, 11.564922324441202, 10.588838335254092, 9.575075964394516, 8.633931004954695, 7.717881484091823, 6.9047415701822645, 5.959057357467969, 6.9189130877126725, 7.879927047957592, 8.831588398426566, 9.742450469653264, 10.701885545511542, 11.64599323959147, 12.65474534771944, 9.769138922121236, 10.841852346982144, 11.796492844576026, 12.767143247370754, 12.49522922316547, 11.65755585405016, 10.644196239034143, 9.673951117978515, 8.686960177840245, 7.693908358777179, 6.738779792909576, 5.891856470036846, 4.997492063379823, 5.974722924439139, 6.899942737740966, 7.8119074823041785, 8.765358364643081, 9.734654017854236, 10.691317817553355, 11.681831527509472, 10.833665469996442, 11.782848714046988, 12.797095859626772, 12.527012160239057, 11.478329063285527, 10.610147131911628, 9.760482142478955, 8.794336960851842, 7.730266330080783, 6.788200626540732, 5.805578176744927, 4.867657026042067, 3.994526183728098, 4.930625285337766, 5.905721494304376, 6.854963250936836, 7.839944506989655, 8.79287832822154, 9.801786845932863, 10.689185883722908, 11.686682504774339, 12.723192824211967, 12.533240015762399, 11.572150833633945, 10.543038517400547, 9.60890256822261, 8.696048257754528, 7.780272052288067, 6.806254707476252, 5.8143886439620465, 4.782672416574141, 3.8601853739918672, 2.9787626816282633, 3.9445269746122515, 4.883899339803777, 5.878214925070093, 6.890799343870504, 7.838926570841038, 8.828820540632185, 9.761926444995812, 12.633815898139034, 12.571252745525186, 11.605523512604908, 10.616703825085715, 9.611697265347699, 8.681404115817372, 7.700023125778405, 6.8071974952216525, 5.841388022924596, 4.85793065775221, 3.8367223441202793, 2.87137456125958, 1.9810555497458182, 2.9797413607155487, 3.921366861649735, 4.965015024701151, 5.896929542957459, 6.8303185379664235, 7.891555465574649, 8.80261322294677, 12.615407415130706, 11.645092548767048, 10.61809594074326, 9.670219696646246, 8.618552481980679, 7.674355595932909, 6.700161282966479, 5.74061268844574, 4.784221162461782, 3.8233118810156057, 2.870765794012212, 1.9352956641566008, 0.991028526742493, 2.0151489504740416, 3.0408889550777904, 3.986842542870977, 4.901648063349857, 5.843704565507307, 6.8432619562669705, 7.775459630858632, 12.030693963786677, 10.969458116252607, 10.023287526636748, 9.025724701974571, 8.030901960591562, 7.035681081442674, 6.045858084472831, 5.034534081466998, 4.0421404336982265, 3.0086055773989013, 2.0787545641818017, 1.0517918492430613, 0.0, 1.0683419984515785, 2.038544093769499, 2.9831117724135843, 3.9487743246124696, 4.9640266837351295, 5.9877011019031645, 6.992195883599447, 12.984519851004281, 11.9242048979903, 10.882825654569011, 9.864041752803415, 8.867679133570432, 7.901824009412651, 6.946990759499659, 5.973632917336178, 4.9795219112275895, 4.083355041331963, 3.0219995783338756, 2.0360875944449486, 1.0406649903984018, 1.9678659034522763, 3.025309823717688, 3.946868176591049, 4.955226839533716, 5.919488889150927, 6.901532133885507, 7.928299592538064, 13.81219922958709, 12.836208982644688, 11.827142433765276, 10.791575942013248, 9.90732480867871, 8.955090627264147, 7.962718657887197, 6.915939621029402, 5.9230808842037685, 5.015109585099058, 3.9674703455708613, 2.927784796737637, 1.9826160821576688, 3.0143265304278906, 3.9670568016242367, 4.983834612914931, 5.969798472469796, 6.989895751838867, 7.872875190346538, 8.873513121775577, 14.705284230747758, 13.691145807626823, 12.74017848106675, 11.794224508553576, 10.871369326704475, 9.886692482854624, 8.886452834710738, 7.927268603493522, 6.9548747121134324, 5.992189730852856, 4.927660861124853, 3.8837278983009798, 2.9139701281497157, 3.845564236406605, 4.818167239584537, 5.8835647562143665, 6.828774990127826, 7.885458326771037, 8.870420356883038, 9.849962708586215, 15.501748385051899, 14.528161484453292, 13.588876290240451, 12.661271468221695, 11.67857580571738, 10.694760217653384, 9.727931531069455, 8.758789667716645, 7.743006301748771, 6.719054375911513, 5.776283607843721, 4.797292646914613, 3.8490184401271503, 4.834655714805013, 5.886206487275967, 6.874572799486573, 7.787191033278295, 8.79607907484491, 9.857037802929954, 10.779017287182427, 16.471700223593288, 15.543872656818545, 14.582335375525144, 13.631726239836947, 12.686918430097986, 11.613234130395012, 10.647391556848714, 9.677900306920822, 8.680075251372939, 7.645658728757068, 6.741974060260497, 5.8159423333601685, 4.8414503279041625, 5.7852660325721885, 6.725051160433626, 7.724636626363927, 8.734331096940226, 9.714075795975749, 10.74894183273273, 11.690112243925965, 17.399385857227465, 16.51359392405904, 15.555397147786206, 14.573279540814864, 13.636673108323002, 12.562378708717683, 11.60506409753789, 10.6431604033454, 9.693330542143078, 8.71735600913767, 7.789699172693916, 6.818629711224313, 5.8888526119904805, 6.792238771406032, 7.697273315496261, 8.700822723593959, 9.714439587056487, 10.731384736243893, 11.682577071395098, 12.750347739159984], [12.726795240194624, 11.797045416728881, 10.773156080613182, 9.818159531096882, 8.898651952933575, 7.98146622453292, 7.302294506184266, 7.742303122011458, 8.68800975965018, 9.640418841672686, 10.643201718916565, 11.53089985207521, 12.460879537296256, 12.884412393462187, 13.82776861411242, 14.727462600396487, 15.602866856119782, 16.532071028991155, 17.539787944949804, 18.435100280380226, 11.6551094828416, 12.600129440939543, 11.780632691480887, 10.790640720239166, 9.92177725233427, 8.95529536810297, 8.344760524710948, 8.771428466398298, 9.61646319862794, 10.577028526407064, 11.509458107448191, 12.442276241261451, 12.849295154615547, 11.887221087464413, 12.92046024858918, 13.721359227723761, 14.56616704529143, 15.532245885762118, 16.49028708006551, 17.37585840408044, 10.649327695624955, 11.595055701451905, 12.598701878327974, 11.818462376921456, 10.89156550755456, 9.953313178082004, 9.339899084149112, 9.786246137043626, 10.598371821336494, 11.594834751351907, 12.52920306080279, 12.710497412780926, 11.820034509722525, 10.902259616403985, 11.895376969673054, 12.781960639288583, 13.594893420648747, 14.58249410971045, 15.45161907211795, 16.427621989763512, 9.722410271411032, 10.691493606562144, 11.735799043367052, 12.690634104135068, 11.944862865395606, 10.951689733180869, 10.339092666705433, 10.834630832077906, 11.649897349522172, 12.572746414191938, 12.724268626239125, 11.748350875905633, 10.840770250983699, 9.92050393806353, 10.839605095015926, 11.726936946225772, 12.657622325772376, 13.57671205265797, 14.486126890895566, 15.387021217042397, 8.808539370122713, 9.778792392272502, 10.714487656546233, 11.743098675294839, 12.737236909892237, 11.99166471756453, 11.306029775085587, 11.783814911527525, 12.659260045064482, 12.54456591969489, 11.794702797162314, 10.79554776162028, 9.768150131374828, 8.965346657759715, 9.788577225705012, 10.770303246139198, 11.74305426699369, 12.502549026644141, 13.47298411394212, 14.403728433395985, 7.824384817007953, 8.838225147371835, 9.820249449724404, 10.776143090036493, 11.797830718825184, 12.822717751925001, 12.2589431841786, 12.814838195874088, 12.549513649964847, 11.606786701062424, 10.795755240881322, 9.860857207236675, 8.819150313576646, 8.005119407683255, 8.861140357737357, 9.774803091604081, 10.710302198852037, 11.566710366625955, 12.510149075445696, 13.536468958598801, 6.99082848742084, 8.030462695338626, 9.030227686115742, 10.00495343671486, 10.994350757388448, 11.99956857478706, 12.92465652629176, 12.637126141728828, 11.642087891648364, 10.68040369662798, 9.735448566595485, 8.802281803478861, 7.8725437695355485, 7.009837313634884, 7.867271044486508, 8.820477135040102, 9.72642552129465, 10.64169156174627, 11.594037012376045, 12.548030340377617, 7.781037123069526, 8.815239865927921, 9.798106667974933, 10.760541964004462, 11.72916821215123, 12.71246744217285, 12.62642764793477, 11.65034365874766, 10.636581287888085, 9.695436328448263, 8.779386807585391, 7.862947588288683, 6.892339936055358, 5.98016767406945, 6.941181634314369, 7.852649398974603, 8.7635114702013, 9.698674030904073, 10.642781724984, 11.624801763693043, 8.700796923669657, 9.773510348530564, 10.728150846124446, 11.698801248919175, 12.736585436841233, 12.719755834295318, 11.705701562527713, 10.735456441472085, 9.748465501333815, 8.755413682270747, 7.800285116403145, 6.864794264364637, 5.930774641967213, 5.023230779057114, 5.921003738289002, 6.832968482852214, 7.786419365191117, 8.731442503246766, 9.688106302945885, 10.613489529057892, 9.765323471544862, 10.714506715595409, 11.728753861175193, 12.653883064672938, 12.540529043530684, 11.672347112156785, 10.822682122724112, 9.856536941097, 8.79246631032594, 7.85040060678589, 6.867778156990084, 5.924016081870226, 4.927808762315488, 3.9516862858858017, 4.926782494852412, 5.876024251484872, 6.8116284452599185, 7.764562266491804, 8.757307241322643, 9.620843885271329, 10.61834050632276, 11.654850825760388, 12.68748932941117, 12.634350813879102, 11.605238497645704, 10.671102548467768, 9.758248237999686, 8.842472032533225, 7.868454687721409, 6.876588624207204, 5.844872396819299, 4.916544429820027, 3.9313522681442756, 2.9655879751602874, 3.904960340351813, 4.899275925618129, 5.862483282140768, 6.77058457238946, 7.760478542180606, 8.693584446544232, 11.565473899687454, 12.531118876905635, 12.667723492850065, 11.678903805330872, 10.673897245592856, 9.74360409606253, 8.762223106023562, 7.86939747546681, 6.903588003169753, 5.920130637997367, 4.8989223243654365, 3.9335745415047376, 3.043255529990976, 1.993700493497609, 2.9353259944317953, 3.9789741574832105, 4.868613481227722, 5.761976539514845, 6.82321346712307, 7.73427122449519, 12.559630127152733, 12.707292529012205, 11.680295920988417, 10.732419676891404, 9.680752462225836, 8.736555576178066, 7.762361263211637, 6.802812668690898, 5.84642114270694, 4.885511861260763, 3.9329657742573696, 2.9974956444017584, 2.053228506987651, 1.029108083256102, 2.036279696178812, 2.9185005444193983, 3.833306064898278, 4.775362567055729, 5.774919957815392, 6.707117632407053, 13.099035962238258, 12.037800114704188, 11.09162952508833, 10.094066700426152, 9.099243959043143, 8.104023079894255, 7.114200082924411, 6.102876079918577, 5.110482432149805, 4.07694757585048, 3.1470965626333802, 2.12013384769464, 1.0683419984515785, 0.0, 0.9702020953179208, 1.9147697739620058, 2.880432326160891, 3.895684685283551, 4.919359103451586, 5.923853885147868, 14.052861849455862, 12.992546896441878, 11.951167653020589, 10.932383751254992, 9.93602113202201, 8.97016600786423, 8.015332757951237, 7.0419749157877565, 6.047863909679168, 5.022915729651152, 3.958734644541951, 2.9226733833203355, 1.927250779273789, 1.0000498662199147, 1.9815181080359516, 2.8785261781394706, 3.8868848410821375, 4.851146890699349, 5.833190135433927, 6.859957594086485, 14.880541228038668, 13.904550981096266, 12.895484432216854, 11.859917940464825, 10.969121538627384, 9.93934713842928, 8.886382439430818, 7.839603402573023, 6.84674466574739, 5.901695373974445, 4.854056134446249, 3.814370585613024, 2.869201871033056, 2.0492034595428565, 2.9232650859425005, 3.915492614463353, 4.901456474018217, 5.921553753387289, 6.804533191894959, 7.8051711233239995, 15.743147074895601, 14.729008651774667, 13.778041325214593, 12.83208735270142, 11.819773603655204, 10.835096759805353, 9.790771078368996, 8.83158684715178, 7.859192955771691, 6.878775519728244, 5.81424665000024, 4.770313687176367, 3.8005559170251026, 3.103813549968266, 3.8970559433196277, 4.955884244249601, 5.869895765910143, 6.849598537612254, 7.802078358431458, 8.781620710134638, 16.388334173927287, 15.414747273328679, 14.475462079115838, 13.547857257097082, 12.565161594592766, 11.58134600652877, 10.614517319944841, 9.645375456592031, 8.629592090624158, 7.6056401647869, 6.662869396719108, 5.68387843579, 4.735604229002537, 4.169360594763577, 4.9650951910110575, 5.946892287521807, 6.828311809060612, 7.837199850627226, 8.811346804399458, 9.71067528873085, 17.358286012468675, 16.43045844569393, 15.46892116440053, 14.518312028712334, 13.573504218973373, 12.499819919270399, 11.5339773457241, 10.564486095796209, 9.566661040248325, 8.532244517632455, 7.6285598491358835, 6.702528122235555, 5.728036116779549, 5.24124810349218, 6.025687299311599, 6.949850186278743, 7.809156085152941, 8.788900784188463, 9.766542401861699, 10.707712813054934, 18.28597164610285, 17.400179712934424, 16.441982936661592, 15.45986532969025, 14.523258897198389, 13.448964497593069, 12.491649886413276, 11.529746192220786, 10.579916331018465, 9.603941798013057, 8.676284961569301, 7.705215500099699, 6.775438400865867, 6.248220842326024, 6.997909454374234, 7.9464056232384, 8.830126843187685, 9.840106834217115, 10.784292497599973, 11.769359676276622], [11.756593144876703, 10.826843321410959, 9.802953985295263, 8.847957435778962, 7.928449857615653, 7.011264129214999, 7.965547015822931, 8.712505217329378, 9.658211854968101, 10.610620936990607, 11.613403814234486, 12.501101947393131, 13.431081632614177, 13.763156274024032, 13.065607874458811, 13.816912370062097, 14.692316625785391, 15.621520798656762, 16.56958584963188, 17.464898185062303, 10.68490738752368, 11.629927345621622, 10.810430596162968, 9.820438624921247, 8.951575157016348, 7.985093272785048, 8.997526709026838, 9.741630561716217, 10.586665293945861, 11.547230621724985, 12.479660202766112, 13.412478336579372, 13.790035584893632, 12.765964968026259, 12.01795233351737, 12.81080899738937, 13.655616814957039, 14.621695655427727, 15.520084984747587, 16.405656308762516, 9.679125600307033, 10.624853606133984, 11.628499783010053, 10.848260281603537, 9.921363412236639, 8.983111082764083, 9.992665268465002, 10.756448232361546, 11.568573916654415, 12.565036846669827, 13.499405156120709, 13.651237843059013, 12.76077494000061, 11.78100349696583, 10.992869054601243, 11.871410408954192, 12.684343190314356, 13.644364489813709, 14.481416976800029, 15.457419894445591, 8.752208176093111, 9.721291511244223, 10.765596948049131, 11.720432008817149, 10.974660770077685, 9.981487637862948, 10.938378750802624, 11.804832927395825, 12.620099444840093, 13.542948509509857, 13.665009056517212, 12.68909130618372, 11.781510681261784, 10.799247818625375, 9.929054864681536, 10.816386715891381, 11.747072095437986, 12.606509957340048, 13.515924795577645, 14.416819121724476, 7.838337274804791, 8.80859029695458, 9.744285561228313, 10.77289657997692, 11.767034814574314, 11.02146262224661, 11.905315859182778, 12.754017006845444, 13.629462140382403, 13.485306349972973, 12.7354432274404, 11.736288191898367, 10.708890561652913, 9.844090538321561, 8.878026995370622, 9.859753015804808, 10.826807669693293, 11.53234693132622, 12.502782018624199, 13.433526338078064, 6.854182721690032, 7.868023052053913, 8.850047354406481, 9.80594099471857, 10.82762862350726, 11.852515656607078, 12.85822926827579, 13.785040291192008, 13.490254080242932, 12.547527131340509, 11.736495671159409, 10.801597637514762, 9.759890743854731, 8.899682766351226, 7.950590127402968, 8.858556494303684, 9.79405560155164, 10.596508271308034, 11.539946980127775, 12.56626686328088, 6.020626392102919, 7.0602606000207055, 8.06002559079782, 9.03475134139694, 10.024148662070527, 11.02936647946914, 11.954454430973838, 12.92131303183962, 12.58282832192645, 11.621144126906065, 10.676188996873572, 9.743022233756948, 8.813284199813634, 7.91695570903601, 6.956720814152119, 7.904230537739705, 8.810178923994254, 9.67148946642835, 10.623834917058124, 11.577828245059695, 6.8108350277516045, 7.845037770610001, 8.827904572657012, 9.79033986868654, 10.758966116833308, 11.742265346854929, 12.67835595079092, 12.591084089025745, 11.57732171816617, 10.636176758726348, 9.720127237863476, 8.803688018566769, 7.833080366333443, 6.920908104347535, 6.03063140397998, 6.936402801674207, 7.847264872900904, 8.728471935586152, 9.672579629666078, 10.654599668375122, 7.730594828351736, 8.803308253212643, 9.757948750806525, 10.728599153601252, 11.76638334152331, 12.674864211602598, 12.646441992805796, 11.676196871750168, 10.689205931611898, 9.696154112548832, 8.741025546681229, 7.805534694642722, 6.871515072245298, 5.963971209335199, 5.004757140988605, 5.916721885551818, 6.870172767890721, 7.761240407928844, 8.717904207627962, 9.643287433739971, 8.79512137622694, 9.744304620277486, 10.75855176585727, 11.683680969355015, 12.732364066308545, 12.642549207474705, 11.792884218042033, 10.81742545612436, 9.7533548253533, 8.81128912181325, 7.8286666720174445, 6.86475651214831, 5.868549192593573, 4.892426716163887, 4.010535897552015, 4.959777654184476, 5.841426349941997, 6.794360171173883, 7.787105146004721, 8.650641789953408, 9.648138411004838, 10.684648730442467, 11.717287234093249, 12.656353875568309, 12.575440592963623, 11.641304643785688, 10.728450333317607, 9.812674127851146, 8.838656783039331, 7.846790719525125, 6.805760911846659, 5.857284860098111, 4.87209269842236, 3.9063284054383725, 2.988713743051416, 3.9830293283177327, 4.892281186822847, 5.800382477071539, 6.790276446862685, 7.72338235122631, 10.595271804369533, 11.560916781587714, 12.548775264604922, 12.649105900648792, 11.644099340910776, 10.71380619138045, 9.732425201341483, 8.839599570784731, 7.8737900984876745, 6.890332733315288, 5.869124419683358, 4.903776636822658, 4.007417641133557, 2.934440923775694, 1.9928154228415078, 3.015937924686297, 3.8984113859098013, 4.791774444196924, 5.853011371805149, 6.764069129177269, 11.589428031834812, 12.487076978345852, 12.650498016306337, 11.702621772209323, 10.650954557543756, 9.706757671495986, 8.732563358529557, 7.773014764008819, 6.816623238024861, 5.855713956578684, 4.903167869575291, 3.9676977397196795, 3.0234306023055715, 1.9993101785740226, 1.0660776008608912, 1.9482984491014774, 2.8631039695803575, 3.805160471737808, 4.804717862497471, 5.736915537089132, 12.599892650953795, 13.008002210022108, 12.061831620406249, 11.064268795744072, 10.069446054361062, 9.074225175212174, 8.08440217824233, 7.073078175236497, 6.080684527467725, 5.0471496711684, 4.1172986579513005, 3.0903359430125605, 2.038544093769499, 0.9702020953179208, 0.0, 0.9445676786440851, 1.9102302308429704, 2.92548258996563, 3.949157008133665, 4.953651789829947, 13.553718538171399, 13.9627489917598, 12.921369748338511, 11.902585846572915, 10.906223227339932, 9.94036810318215, 8.985534853269158, 8.012177011105678, 7.018066004997088, 5.993117824969072, 4.928936739859871, 3.8928754786382562, 2.8974528745917096, 1.9702519615378353, 1.011316012718031, 1.90832408282155, 2.9166827457642164, 3.880944795381428, 4.862988040116006, 5.889755498768564, 14.458709903912245, 14.874753076414189, 13.865686527534777, 12.830120035782748, 11.939323633945307, 10.909549233747203, 9.856584534748741, 8.809805497890945, 7.816946761065311, 6.8718974692923664, 5.82425822976417, 4.784572680930945, 3.839403966350977, 2.9121601422117553, 1.9530629906245798, 2.9452905191454324, 3.931254378700296, 4.951351658069368, 5.834331096577038, 6.834969028006078, 15.451729303206564, 15.699210747092588, 14.748243420532514, 13.80228944801934, 12.789975698973125, 11.805298855123274, 10.760973173686917, 9.8017889424697, 8.829395051089612, 7.848977615046165, 6.78444874531816, 5.740515782494287, 4.770758012343023, 3.8994568511796395, 2.926853848001707, 3.98568214893168, 4.899693670592222, 5.879396442294333, 6.831876263113537, 7.811418614816717, 16.403363074376085, 16.3849493686466, 15.445664174433757, 14.518059352415001, 13.535363689910685, 12.55154810184669, 11.58471941526276, 10.615577551909952, 9.599794185942079, 8.575842260104821, 7.633071492037029, 6.65408053110792, 5.7058063243204575, 4.9650038959749505, 3.9948930956931363, 4.976690192203886, 5.8581097137426905, 6.8669977553093045, 7.8411447090815365, 8.740473193412928, 17.361857436966886, 17.400660541011852, 16.439123259718453, 15.488514124030257, 14.543706314291295, 13.47002201458832, 12.504179441042021, 11.53468819111413, 10.536863135566247, 9.502446612950376, 8.598761944453804, 7.672730217553475, 6.698238212097469, 5.9952703318551155, 5.055485203993678, 5.979648090960822, 6.83895398983502, 7.818698688870542, 8.796340306543778, 9.737510717737013, 18.289543070601063, 17.596376374417094, 16.66461707080959, 15.687628986721256, 14.774677181379419, 14.006856936318005, 13.461851981731197, 12.499948287538707, 11.550118426336386, 10.574143893330978, 9.646487056887223, 8.67541759541762, 7.745640496183787, 6.979506011064537, 6.027707359056313, 6.976203527920479, 7.859924747869765, 8.869904738899194, 9.814090402282051, 10.7991575809587], [10.812025466232619, 9.882275642766874, 8.858386306651177, 7.903389757134876, 6.983882178971568, 7.920210060946396, 8.874492947554328, 9.657072895973462, 10.602779533612186, 11.555188615634691, 12.55797149287857, 13.445669626037215, 14.375649311258261, 14.649845168727738, 13.952296769162517, 12.970946107348514, 13.791608188490692, 14.720812361362063, 15.625018170987799, 16.52033050641822, 9.740339708879596, 10.685359666977538, 9.865862917518882, 8.87587094627716, 8.007007478372262, 8.894039204516446, 9.906472640758237, 10.686198240360302, 11.531232972589946, 12.49179830036907, 13.424227881410197, 14.357046015223457, 14.67672447959734, 13.652653862729965, 12.904641228221076, 11.964842734675788, 12.754908377662339, 13.720987218133027, 14.575517306103503, 15.461088630118432, 8.73455792166295, 9.6802859274899, 10.683932104365969, 9.90369260295945, 8.976795733592553, 9.89205701449548, 10.9016112001964, 11.70101591100563, 12.5131415952985, 13.509604525313911, 14.443972834764793, 14.537926737762719, 13.647463834704318, 12.667692391669537, 11.87955794930495, 11.02544414624061, 11.783634753019657, 12.699796811169625, 13.536849298155945, 14.512852215801507, 7.807640497449027, 8.776723832600139, 9.821029269405047, 10.77586433017306, 10.038368887875563, 10.890433569594345, 11.84732468253402, 12.74940060603991, 13.564667123484178, 14.487516188153942, 14.551697951220918, 13.575780200887426, 12.668199575965492, 11.685936713329081, 10.815743759385242, 9.970420453177798, 10.846363658143286, 11.661942278695964, 12.57135711693356, 13.472251443080392, 6.8937695961607055, 7.864022618310495, 8.799717882584225, 9.828328901332831, 10.822467135930228, 11.878681272813646, 12.814261790914175, 13.698584685489529, 14.574029819026487, 14.371995244676679, 13.622132122144107, 12.622977086602074, 11.59557945635662, 10.730779433025267, 9.764715890074328, 9.013786753091225, 9.908867934387782, 10.587779252682136, 11.558214339980115, 12.48895865943398, 5.909615043045947, 6.923455373409828, 7.905479675762396, 8.861373316074484, 9.883060944863175, 10.907947977962992, 11.955480712802036, 12.931352845554567, 13.897940668323011, 13.434216026044215, 12.623184565863115, 11.688286532218468, 10.646579638558439, 9.786371661054933, 8.837279022106674, 7.940616758998173, 8.87611586624613, 9.65194059266395, 10.59537930148369, 11.621699184636796, 5.076058713458834, 6.1156929213766205, 7.115457912153736, 8.090183662752853, 9.07958098342644, 10.084798800825054, 11.009886752329752, 11.976745353195534, 12.971783603275998, 12.507833021609772, 11.562877891577278, 10.629711128460654, 9.699973094517341, 8.803644603739716, 7.843409708855825, 6.986290802434194, 7.892239188688742, 8.726921787784265, 9.67926723841404, 10.633260566415611, 5.866267349107519, 6.900470091965915, 7.883336894012927, 8.845772190042457, 9.814398438189224, 10.797697668210844, 11.733788272146835, 12.709872261333945, 12.464010612869876, 11.522865653430054, 10.606816132567182, 9.690376913270475, 8.71976926103715, 7.807596999051241, 6.917320298683686, 6.018463066368695, 6.9293251375953915, 7.783904256942067, 8.728011951021994, 9.710031989731037, 6.786027149707651, 7.858740574568559, 8.81338107216244, 9.784031474957168, 10.821815662879226, 11.730296532958514, 12.744926370829225, 12.562885766453874, 11.575894826315604, 10.582843007252539, 9.627714441384935, 8.692223589346428, 7.758203966949004, 6.850660104038905, 5.8914460356923115, 4.998782150246306, 5.952233032585209, 6.81667272928476, 7.773336528983878, 8.698719755095887, 7.850553697582855, 8.799736941633402, 9.813984087213186, 10.73911329071093, 11.78779638766446, 12.773210820180847, 12.73745189668612, 11.704114350828066, 10.640043720057006, 9.697978016516956, 8.71535556672115, 7.751445406852016, 6.755238087297278, 5.779115610867592, 4.897224792255721, 4.041837918878964, 4.896858671297913, 5.849792492529799, 6.842537467360636, 7.706074111309323, 8.703570732360754, 9.740081051798382, 10.772719555449164, 11.711786196924225, 12.72308693354944, 12.585872322429772, 11.673018011961693, 10.75724180649523, 9.783224461683416, 8.74669258797616, 7.692449806550365, 6.743973754801817, 5.758781593126066, 4.793017300142078, 3.875402637755122, 3.065089593012221, 3.9477135081787615, 4.855814798427454, 5.8457087682186, 6.778814672582226, 9.650704125725449, 10.61634910294363, 11.604207585960838, 12.665270316407257, 12.588667019554862, 11.658373870024533, 10.67699287998557, 9.784167249428815, 8.818357777131759, 7.834900411959374, 6.813692098327443, 5.848344315466743, 4.894106535837263, 3.8211298184794, 2.8795043175452135, 2.071370246042212, 2.953843707265716, 3.847206765552839, 4.908443693161065, 5.819501450533185, 10.644860353190728, 11.542509299701768, 12.569505907725556, 12.647189450853407, 11.595522236187842, 10.651325350140072, 9.677131037173643, 8.717582442652905, 7.761190916668946, 6.8002816352227695, 5.847735548219376, 4.912265418363765, 3.9679982809496566, 2.9438778572181077, 1.952766495564597, 1.0037307704573923, 1.9185362909362724, 2.8605927930937227, 3.860150183853386, 4.792347858445047, 11.65532497230971, 12.599168657045128, 13.006399299050337, 12.00883647438816, 11.01401373300515, 10.018792853856262, 9.028969856886418, 8.017645853880584, 7.025252206111811, 5.991717349812486, 5.061866336595386, 4.034903621656646, 2.9831117724135843, 1.9147697739620058, 0.9445676786440851, 0.0, 0.9656625521988854, 1.9809149113215452, 3.00458932948958, 4.009084111185862, 12.609150859527315, 13.65406065814415, 13.865937426982596, 12.847153525217, 11.850790905984017, 10.884935781826236, 9.930102531913244, 8.956744689749764, 7.962633683641174, 6.9376855036131575, 5.873504418503956, 4.837443157282341, 3.8420205532357947, 2.9148196401819204, 1.9202619444494275, 0.963756404177465, 1.9721150671201317, 2.9363771167373427, 3.9184203614719215, 4.945187820124479, 13.514142225268161, 14.490132472210563, 14.810254206178861, 13.774687714426832, 12.883891312589391, 11.854116912391287, 10.801152213392825, 9.75437317653503, 8.761514439709396, 7.8164651479364515, 6.768825908408255, 5.72914035957503, 4.783971644995062, 3.821106073943152, 2.8620089223559764, 2.0007228405013473, 2.9866867000562114, 4.006783979425283, 4.8897634179329525, 5.890401349361993, 14.50716162456248, 15.439558109909498, 15.692811099176598, 14.746857126663425, 13.734543377617209, 12.749866533767358, 11.705540852331001, 10.746356621113785, 9.773962729733697, 8.793545293690249, 7.729016423962245, 6.6850834611383725, 5.715325690987108, 4.808402782911036, 3.8357997797331036, 3.041114470287595, 3.955125991948137, 4.9348287636502475, 5.8873085844694515, 6.866850936172632, 15.458795395731999, 16.432382296330605, 16.390231853077843, 15.462627031059085, 14.47993136855477, 13.496115780490774, 12.529287093906845, 11.560145230554037, 10.544361864586163, 9.520409938748905, 8.577639170681113, 7.598648209752005, 6.650374002964543, 5.873949827706347, 4.903839027424533, 4.032122513559801, 4.913542035098605, 5.92243007666522, 6.896577030437451, 7.795905514768843, 16.417289758322802, 17.474557078913428, 16.75664308301092, 15.806033947322726, 14.976810574372067, 14.414589693232404, 13.448747119686105, 12.479255869758214, 11.48143081421033, 10.44701429159446, 9.543329623097888, 8.61729789619756, 7.642805890741554, 6.9042162635865125, 5.964431135725075, 5.035080412316737, 5.894386311190935, 6.874131010226457, 7.851772627899693, 8.792943039092927, 17.34497539195698, 16.651808695773013, 15.763908633514891, 14.786920549426556, 13.928710918665836, 14.893545831021711, 14.406419660375281, 13.444515966182792, 12.49468610498047, 11.518711571975063, 10.591054735531307, 9.619985274061705, 8.690208174827871, 7.888451942795934, 6.93665329078771, 6.031635849276394, 6.91535706922568, 7.925337060255108, 8.869522723637967, 9.854589902314615], [9.846362914033733, 8.972467464410615, 7.950071151943514, 6.995074602427215, 7.934788779837908, 8.885872613145281, 9.840155499753212, 10.622735448172348, 11.568442085811071, 12.520851167833577, 13.523634045077456, 14.411332178236101, 15.341311863457147, 15.557007010246464, 14.824583239633915, 13.815260244600553, 12.830317362136347, 13.759521535007718, 14.659355618788913, 15.554667954219331, 8.77467715668071, 9.719697114778654, 8.95754776281122, 7.967555791569499, 8.957914079238604, 9.85970175671533, 10.87213519295712, 11.651860792559187, 12.496895524788831, 13.457460852567955, 14.389890433609082, 15.322708567422342, 15.583886321116065, 14.55981570424869, 13.8118030697398, 12.809156871927827, 11.793617551307994, 12.759696391778682, 13.609854753904617, 14.495426077919547, 7.768895369464064, 8.714623375291016, 9.718269552167085, 8.995377448251789, 9.927702334458894, 10.857719566694364, 11.867273752395285, 12.666678463204516, 13.478804147497385, 14.475267077512797, 15.409635386963679, 15.445088579281444, 14.554625676223043, 13.574854233188262, 12.786719790823675, 11.869758283492649, 10.822343926665312, 11.73413425897074, 12.571186745957059, 13.547189663602621, 6.841977945250142, 7.811061280401254, 8.855366717206161, 9.810201777974177, 10.817660113482942, 11.81083324569768, 12.767724358637356, 13.715063158238795, 14.530329675683063, 15.453178740352827, 15.458859792739643, 14.482942042406151, 13.575361417484217, 12.593098554847806, 11.722905600903967, 10.815758211335545, 9.885072831788941, 10.696279726497078, 11.605694564734675, 12.506588890881506, 5.928107043961821, 6.89836006611161, 7.8340553303853415, 8.862666349133947, 9.856804583731343, 10.91301872061476, 11.942731569696162, 12.872299828480278, 13.882966305821137, 14.812784283659013, 14.529293963662832, 13.530138928120799, 12.502741297875346, 11.637941274543993, 10.671877731593053, 9.862512180372152, 8.947577108033437, 9.62211670048325, 10.592551787781229, 11.523296107235094, 4.943952490847061, 5.957792821210942, 6.93981712356351, 7.8957107638755994, 8.917398392664289, 9.942285425764107, 10.98981816060315, 11.965690293355681, 12.932278116124126, 13.87500506502655, 13.53034640738184, 12.595448373737193, 11.553741480077164, 10.693533502573658, 9.7444408636254, 8.7893421862791, 7.9148250398917845, 8.686278040465064, 9.629716749284805, 10.65603663243791, 4.110396161259948, 5.150030369177735, 6.14979535995485, 7.124521110553967, 8.113918431227555, 9.119136248626168, 10.044224200130866, 11.011082800996649, 12.006121051077113, 13.072995515191415, 12.470039733096003, 11.53687296997938, 10.607134936036067, 9.710806445258441, 8.75057155037455, 7.835016229715121, 6.930948362334397, 7.76125923558538, 8.713604686215154, 9.667598014216725, 4.900604796908633, 5.9348075397670295, 6.917674341814041, 7.880109637843571, 8.848735885990338, 9.832035116011959, 10.76812571994795, 11.74420970913506, 12.757972079994635, 12.43002749494878, 11.513977974085908, 10.5975387547892, 9.626931102555876, 8.714758840569965, 7.824482140202411, 6.867188493649622, 5.9680343112410466, 6.818241704743182, 7.762349398823108, 8.744369437532152, 5.820364597508766, 6.893078022369673, 7.847718519963554, 8.818368922758282, 9.85615311068034, 10.764633980759628, 11.779263818630339, 12.749508939685967, 12.48305666783433, 11.490004848771264, 10.53487628290366, 9.599385430865153, 8.66536580846773, 7.75782194555763, 6.798607877211037, 5.847507577527233, 4.990942206230864, 5.851010177085875, 6.807673976784993, 7.733057202897001, 6.884891145383969, 7.834074389434516, 8.8483215350143, 9.773450738512045, 10.822133835465575, 11.80754826798196, 12.751370854068284, 12.611276192346791, 11.547205561575732, 10.605139858035681, 9.622517408239876, 8.658607248370743, 7.662399928816003, 6.686277452386317, 5.804386633774446, 4.890563346159891, 3.931196119099028, 4.884129940330914, 5.876874915161751, 6.740411559110437, 7.737908180161868, 8.774418499599495, 9.807057003250277, 10.746123644725339, 11.757424381350555, 12.69156033052849, 12.614808496430655, 11.699032290964192, 10.70667529417595, 9.653854429494885, 8.599611648069091, 7.651135596320542, 6.665943434644792, 5.700179141660803, 4.782564479273847, 3.913815020293148, 2.9820509559798767, 3.8901522462285687, 4.880046216019715, 5.81315212038334, 8.685041573526563, 9.650686550744744, 10.638545033761952, 11.699607764208372, 12.704614323946387, 12.600164354493497, 11.618783364454531, 10.725957733897777, 9.76014826160072, 8.776690896428336, 7.7417511274982695, 6.77640334463757, 5.8012683773559885, 4.728291659998125, 3.7866661590639388, 2.920095673323139, 1.9881811550668311, 2.881544213353954, 3.942781140962179, 4.853838898334299, 9.679197800991842, 10.576846747502882, 11.60384335552667, 12.551719599623684, 12.537312720656804, 11.593115834609033, 10.618921521642605, 9.659372927121867, 8.702981401137908, 7.742072119691732, 6.789526032688339, 5.8540559028327275, 4.90978876541862, 3.885668341687071, 2.859928337083322, 1.9108926119761178, 0.9528737387373871, 1.8949302408948374, 2.8944876316545005, 3.826685306246161, 10.689662420110825, 11.633506104846242, 12.55641408446697, 12.974499026587043, 11.979676285204034, 10.984455406055146, 9.994632409085302, 8.983308406079468, 7.990914758310696, 6.957379902011371, 6.027528888794271, 5.000566173855531, 3.9487743246124696, 2.880432326160891, 1.9102302308429704, 0.9656625521988854, 0.0, 1.0152523591226597, 2.0389267772906945, 3.0434215589869766, 11.643488307328429, 12.688398105945264, 13.568515376799947, 13.812816077415885, 12.816453458182902, 11.85059833402512, 10.895765084112128, 9.922407241948648, 8.928296235840058, 7.903348055812043, 6.839166970702842, 5.803105709481227, 4.8076831054346805, 3.8804821923808057, 2.885924496648313, 1.9294189563763504, 1.0637999124124693, 2.0280619620296805, 3.008612183115661, 3.979525267925594, 12.548479673069275, 13.524469920011677, 14.512832155996213, 14.740350266625718, 13.849553864788277, 12.819779464590173, 11.766814765591711, 10.720035728733915, 9.727176991908282, 8.782127700135337, 7.734488460607141, 6.694802911773916, 5.749634197193948, 4.786768626142037, 3.8276714745548617, 2.966385392700233, 2.078371545348549, 3.098468824717621, 3.979955239576692, 4.9247387971631085, 13.541499072363594, 14.473895557710613, 15.424862884270686, 15.71251967886231, 14.700205929816095, 13.715529085966244, 12.671203404529887, 11.71201917331267, 10.739625281932582, 9.759207845889135, 8.694678976161132, 7.650746013337258, 6.680988243185994, 5.7740653351099205, 4.8014623319319885, 3.992021071153935, 3.046810837240475, 4.026513608942586, 4.977500406113191, 5.901188383973747, 14.493132843533113, 15.46671974413172, 16.40600493834456, 15.867619219592427, 15.445593920753655, 14.46177833268966, 13.49494964610573, 12.525807782752922, 11.510024416785049, 10.486072490947791, 9.543301722879999, 8.56431076195089, 7.616036555163428, 6.8396123799052315, 5.869501579623418, 4.983029114426142, 4.005226880390944, 5.0141149219575585, 5.986768852081191, 6.830242962569958, 15.451627206123915, 16.508894526714542, 15.795352256656578, 14.844743120968381, 15.789550930707343, 15.38025224543129, 14.414409671884991, 13.4449184219571, 12.447093366409216, 11.412676843793346, 10.508992175296774, 9.582960448396445, 8.60846844294044, 7.869878815785397, 6.93009368792396, 5.9859870131830775, 4.986071156483273, 5.9658158555187955, 6.941964449543432, 7.883134860736668, 16.37931283975809, 15.686146143574128, 14.802617807160546, 13.825629723072211, 14.762236155564073, 15.76583230149311, 15.372082212574167, 14.410178518381677, 13.460348657179356, 12.484374124173948, 11.556717287730192, 10.58564782626059, 9.655870727026757, 8.854114494994818, 7.902315842986595, 6.982542450142734, 6.007041914518018, 7.0170219055474465, 7.959714545281707, 8.944781723958355], [8.831110554911074, 7.957215105287955, 7.079071540242125, 7.919379826368175, 8.85909400377887, 9.865656628275662, 10.819939514883593, 11.637987807295008, 12.58369444493373, 13.536103526956236, 14.538886404200117, 15.426584537358762, 16.35656422257981, 16.496584621553957, 15.553228400903723, 14.543905405870362, 13.558962523406155, 12.96654959780353, 13.766595147353463, 14.661907482783882, 7.759424797558051, 8.704444755655993, 8.1192371929229, 8.89186101551046, 9.882219303179564, 10.83948577184571, 11.851919208087502, 12.667113151681848, 13.51214788391149, 14.472713211690614, 15.405142792731741, 16.337960926545, 16.55812530464843, 15.511350497915442, 14.550400308613838, 13.537802033197636, 12.522262712577803, 11.90889161570312, 12.717094282469168, 13.602665606484097, 6.7536430103414045, 7.699371016168356, 8.703017193044426, 9.733508250634207, 10.78844320217269, 11.770100328252482, 12.751665582071018, 13.681930822327177, 14.494056506620044, 15.490519436635456, 16.424887746086338, 16.419492015103504, 15.529029112045102, 14.526389026855014, 13.534260558492406, 12.598403444762457, 11.55098908793512, 10.84137378753529, 11.678426274521609, 12.654429192167171, 5.826725586127482, 6.795808921278594, 7.840114358083501, 8.794949418851516, 9.802407754360283, 10.79558088657502, 11.752471999514697, 12.781506375153468, 13.819799061748856, 14.777980121879809, 15.750673005886267, 15.45734547822821, 14.549764853306275, 13.544633348514559, 12.470446368572699, 11.544403372605354, 10.61371799305875, 9.803519255061628, 10.712934093299225, 11.613828419446056, 4.912854684839161, 5.88310770698895, 6.818802971262682, 7.847413990011287, 8.841552224608684, 9.897766361492101, 10.927479210573503, 11.857047469357619, 12.867713946698478, 13.797531924536354, 14.821107176809456, 14.504542363942857, 13.477144733697404, 12.602611493629274, 11.636547950678334, 10.72977349815191, 9.676222269303246, 8.7293562290478, 9.69979131634578, 10.630535635799644, 3.928700131724402, 4.942540462088283, 5.924564764440851, 6.8804584047529405, 7.90214603354163, 8.927033066641448, 9.974565801480491, 10.950437934233022, 11.917025757001467, 12.85975270590389, 13.822159620528463, 13.569851809559252, 12.528144915899222, 11.65820372165894, 10.709111082710681, 9.745900877821315, 8.793942337561335, 7.793517569029614, 8.736956277849355, 9.76327616100246, 3.0951438021372892, 4.134778010055076, 5.134543000832191, 6.109268751431308, 7.098666072104895, 8.103883889503509, 9.028971841008207, 9.99583044187399, 10.990868691954454, 12.057743156068756, 13.089977568602002, 12.511276405801437, 11.581538371858125, 10.675476664343723, 9.715241769459832, 8.791574921257336, 7.867551514965113, 6.86849876414993, 7.8208442147797035, 8.774837542781276, 3.9905112430713654, 5.024713985929762, 6.0075807879767735, 6.9700160840063035, 7.938642332153071, 8.921941562174691, 9.858032166110682, 10.834116155297792, 11.847878526157368, 12.78902348559719, 12.488381409907968, 11.571942190611258, 10.601334538377934, 9.689162276392027, 8.789152359287693, 7.823747185191838, 6.9046374638717625, 5.925481233307732, 6.8695889273876585, 7.8342758836948825, 4.910271043671497, 5.982984468532404, 6.937624966126287, 7.908275368921014, 8.946059556843073, 9.85454042692236, 10.869170264793071, 11.8394153858487, 12.82640632598697, 12.464408284593324, 11.50927971872572, 10.573788866687213, 9.63976924428979, 8.732225381379692, 7.763278096296317, 6.804066269069449, 5.92754535886158, 4.9582497056504256, 5.914913505349543, 6.822963649059732, 5.974797591546701, 6.9239808355972485, 7.938227981177032, 8.863357184674777, 9.912040281628308, 10.897454714144693, 11.841277300231017, 12.843892477791279, 12.521608997397793, 11.579543293857743, 10.596920844061938, 9.633010684192804, 8.636803364638064, 7.660680888208379, 6.778790069596507, 5.847122037702107, 4.878957669694211, 3.9913694688954644, 4.967165346668911, 5.830318005273169, 6.827814626324599, 7.8643249457622275, 8.89696344941301, 9.836030090888071, 10.847330827513288, 11.781466776691223, 12.752350818019552, 12.673435726786254, 11.681078729998012, 10.628257865316947, 9.574015083891153, 8.625539032142605, 7.640346870466853, 6.674582577482865, 5.756967915095908, 4.870373711835364, 3.92981250657506, 2.980442677735729, 3.9703366475268753, 4.903058566546072, 7.774948019689294, 8.740592996907475, 9.728451479924683, 10.789514210371102, 11.794520770109118, 12.708965229096462, 12.593186800276593, 11.700361169719839, 10.734551697422782, 9.751094332250398, 8.71615456332033, 7.750806780459632, 6.77567181317805, 5.702695095820187, 4.761069594886, 3.8766543648653546, 2.9447398466090466, 1.9718346448611141, 3.0326875871249106, 3.9437453444970307, 8.769104247154573, 9.666753193665613, 10.693749801689401, 11.641626045786415, 12.69329326045198, 12.567519270431095, 11.593324957464667, 10.633776362943928, 9.67738483695997, 8.716475555513794, 7.7639294685104, 6.828459338654789, 5.8841922012406815, 4.860071777509132, 3.834331772905384, 2.885296047798179, 1.9272771745594481, 0.9852206724019977, 1.9843940778172324, 2.9165917524088933, 9.796901948675375, 10.723412551008973, 11.646320530629701, 12.617052563269253, 12.994928644326695, 11.999707765177806, 11.009884768207963, 9.998560765202129, 9.006167117433357, 7.972632261134031, 7.042781247916931, 6.015818532978191, 4.9640266837351295, 3.895684685283551, 2.9254825899656303, 1.9809149113215452, 1.0152523591226597, 0.0, 1.0236744181680348, 2.028169199864317, 10.75072783589298, 11.778304552107995, 12.658421822962678, 13.576843209355044, 13.831705817305561, 12.865850693147781, 11.911017443234789, 10.937659601071308, 9.94354859496272, 8.918600414934703, 7.854419329825502, 6.818358068603887, 5.82293546455734, 4.895734551503466, 3.9011768557709727, 2.94467131549901, 1.9881051363534301, 1.023843086736219, 1.9933598239930013, 2.9642729088029345, 11.655719201633826, 12.631709448576228, 13.602738602158944, 14.504377398564877, 14.864806223910936, 13.835031823712832, 12.78206712471437, 11.735288087856574, 10.74242935103094, 9.797380059257996, 8.7497408197298, 7.710055270896576, 6.764886556316608, 5.802020985264697, 4.8429238336775216, 3.9816377518228925, 3.0026767692895096, 2.0942499494241593, 2.9647028804540323, 3.9094864380404486, 12.648738600928144, 13.581135086275163, 14.532102412835236, 15.47805638534841, 15.715458288938754, 14.730781445088903, 13.686455763652546, 12.72727153243533, 11.754877641055241, 10.774460205011794, 9.709931335283791, 8.665998372459919, 7.696240602308654, 6.78931769423258, 5.816714691054648, 4.916326295094896, 3.9711160611814353, 3.022294733649124, 3.9622480469905312, 4.8859360248510875, 13.600372372097663, 14.57395927269627, 15.51324446690911, 16.44084928892787, 16.460846279876318, 15.477030691812322, 14.510202005228393, 13.541060141875583, 12.52527677590771, 11.501324850070452, 10.55855408200266, 9.579563121073551, 8.631288914286088, 7.854864739027891, 6.884753938746078, 5.907334338367102, 4.929532104331904, 4.0847555565064155, 4.971516492958531, 5.814990603447298, 14.558866734688465, 15.61613405527909, 15.070517953757433, 15.57338828223819, 16.51819609197715, 16.39550460455395, 15.429662031007652, 14.46017078107976, 13.462345725531877, 12.427929202916006, 11.524244534419434, 10.598212807519106, 9.6237208020631, 8.849662830915777, 7.909877703054339, 6.910292237124038, 5.910376380424234, 5.088463430780898, 5.926712090420772, 6.867882501614008, 15.486552368322641, 14.793385672138678, 14.009645869956358, 14.55427488434202, 15.490881316833882, 16.49447746276292, 16.387334571696826, 15.425430877504338, 14.475601016302017, 13.499626483296609, 12.571969646852853, 11.60090018538325, 10.671123086149418, 9.833898510125199, 8.882099858116975, 7.906847674083695, 6.931347138458978, 6.13966948080955, 6.944462186159047, 7.9295293648356955], [7.807436136743038, 6.93354068711992, 7.811382162574792, 8.766378712091091, 9.786979567602195, 10.793542192098986, 11.747825078706917, 12.642337055096236, 13.58804369273496, 14.540452774757465, 15.543235652001345, 16.43093378515999, 17.360913470381035, 17.47164099956082, 16.528284778910585, 15.518961783877225, 14.534018901413019, 13.941605975810393, 13.127571511739877, 13.845924373098274, 6.735750379390016, 7.680770337487959, 8.63710564862382, 9.627097619865541, 10.660435964256123, 11.733274204085017, 12.723129723341147, 13.671462399483076, 14.51649713171272, 15.477062459491844, 16.40949204053297, 17.34231017434623, 17.533181682655293, 16.486406875922306, 15.525456686620702, 14.5128584112045, 13.497319090584666, 12.883947993709983, 12.078070646855581, 12.78668249679849, 5.729968592173369, 6.675696598000321, 7.679342774876391, 8.709833832466172, 9.764768784004655, 10.746425910084447, 11.727991163902983, 12.703419655129336, 13.68764673819703, 14.685572228973557, 15.619940538424437, 16.679807019205928, 16.504085490051967, 15.501445404861876, 14.509316936499268, 13.57345982276932, 12.526045465941984, 11.816430165542153, 11.039402638908022, 11.838446082481564, 4.803051167959446, 5.772134503110558, 6.816439939915465, 7.771275000683481, 8.778733336192248, 9.771906468406986, 10.728797581346662, 11.757831956985433, 12.796124643580821, 13.754305703711774, 14.726998587718231, 15.718150791445575, 15.52482123131314, 14.51968972652142, 13.44550274657956, 12.519459750612217, 11.588774371065613, 10.778575633068492, 10.073910457685638, 10.797845309760449, 3.8891802666711257, 4.859433288820915, 5.795128553094647, 6.823739571843252, 7.817877806440648, 8.874091943324066, 9.903804792405468, 10.833373051189584, 11.844039528530443, 12.77385750636832, 13.79743275864142, 14.765347677160223, 14.45220111170427, 13.577667871636136, 12.611604328685196, 11.704829876158774, 10.651278647310109, 9.704412607054664, 9.060767680732193, 9.814552526114037, 2.905025713556367, 3.9188660439202483, 4.900890346272816, 5.856783986584905, 6.878471615373595, 7.903358648473413, 8.950891383312456, 9.926763516064987, 10.893351338833432, 11.836078287735855, 12.798485202360428, 13.733383236005075, 13.503201293906088, 12.6332600996658, 11.684167460717543, 10.720957255828177, 9.768998715568198, 8.768573947036478, 8.097932642235769, 8.817109968436636, 2.071469383969254, 3.1111035918870407, 4.110868582664156, 5.085594333263273, 6.07499165393686, 7.080209471335473, 8.005297422840172, 8.972156023705955, 9.967194273786419, 11.034068737900721, 12.066303150433967, 12.999469913550591, 12.55659474986499, 11.650533042350585, 10.690298147466693, 9.766631299264198, 8.842607892971976, 7.843555142156793, 7.108941215439666, 7.828671350215451, 2.9668368249033303, 4.001039567761727, 4.9839063698087385, 5.946341665838268, 6.914967913985036, 7.898267144006657, 8.834357747942649, 9.810441737129759, 10.824204107989335, 11.765349067429156, 12.772235565626229, 12.546998568618124, 11.5763909163848, 10.66421865439889, 9.764208737294554, 8.7988035631987, 7.879693841878625, 6.900537611314595, 6.101400675398368, 6.810601465526847, 3.8865966255034623, 4.959310050364369, 5.913950547958252, 6.884600950752979, 7.922385138675037, 8.830866008754326, 9.845495846625038, 10.815740967680666, 11.802731907818936, 12.705371713606672, 12.484336096732584, 11.548845244694077, 10.614825622296653, 9.707281759386555, 8.73833447430318, 7.779122647076311, 6.9026017368684425, 5.933306083657288, 5.142709307901925, 5.799289230891697, 4.951123173378666, 5.9003064174292135, 6.914553563008997, 7.839682766506742, 8.888365863460272, 9.873780295976658, 10.817602882062983, 11.820218059623246, 12.78602876220348, 12.554599671864604, 11.5719772220688, 10.608067062199666, 9.611859742644928, 8.635737266215243, 7.753846447603371, 6.822178415708969, 5.8540140477010745, 4.966425846902327, 4.0801938916957905, 4.806643587105134, 5.804140208156564, 6.8406505275941925, 7.873289031244975, 8.812355672720036, 9.823656409345253, 10.757792358523188, 11.728676399851517, 12.696542152925478, 12.656135108004873, 11.603314243323808, 10.549071461898015, 9.600595410149467, 8.615403248473715, 7.649638955489728, 6.732024293102771, 5.845430089842226, 4.904868884581923, 3.9554990557425915, 3.083365192553755, 3.879384148378037, 6.751273601521259, 7.716918578739439, 8.704777061756648, 9.765839792203067, 10.770846351941083, 11.685290810928427, 12.724701531827641, 12.675417547726703, 11.709608075429646, 10.726150710257262, 9.691210941327192, 8.725863158466494, 7.750728191184913, 6.677751473827049, 5.736125972892863, 4.851710742872217, 3.9197962246159093, 2.9468910228679768, 2.009013168956876, 2.9200709263289957, 7.745429828986538, 8.643078775497576, 9.670075383521365, 10.617951627618378, 11.669618842283946, 12.613815728331716, 12.56838133547153, 11.608832740950792, 10.652441214966833, 9.691531933520658, 8.738985846517263, 7.803515716661653, 6.859248579247545, 5.835128155515996, 4.8093881509122465, 3.8603524258050417, 2.902333552566311, 1.9602770504088607, 0.9607196596491976, 1.8929173342408583, 8.797631824016898, 9.699738132840936, 10.622646112461664, 11.593378145101216, 12.588200886484225, 13.023382183345841, 12.033559186375998, 11.022235183370164, 10.029841535601392, 8.996306679302066, 8.066455666084966, 7.039492951146226, 5.9877011019031645, 4.919359103451586, 3.949157008133665, 3.00458932948958, 2.0389267772906945, 1.0236744181680348, 0.0, 1.0044947816962821, 9.751457711234503, 10.754630133939958, 11.634747404794641, 12.553168791187007, 13.54953141041999, 13.889525111315816, 12.934691861402824, 11.961334019239343, 10.967223013130756, 9.942274833102738, 8.878093747993537, 7.842032486771922, 6.846609882725375, 5.919408969671501, 4.880854903391385, 3.924349363119423, 2.9159907001767564, 1.9517286505595455, 0.9696854058249665, 1.9405984906348994, 10.797620840626841, 11.773611087569243, 12.579064183990907, 13.48070298039684, 14.440942586942837, 14.858706241880867, 13.805741542882405, 12.75896250602461, 11.766103769198976, 10.821054477426031, 9.773415237897835, 8.73372968906461, 7.788560974484643, 6.7816990328851094, 5.822601881297934, 4.961315799443305, 3.930562333112836, 3.008551791582673, 1.9410284622859977, 2.8858120198724135, 11.832755491242537, 12.723036725268178, 13.548390422250336, 14.483351546937168, 15.47947796924398, 15.74467457614762, 14.700348894711263, 13.741164663494047, 12.768770772113959, 11.78835333607051, 10.71428058308502, 9.670347620261147, 8.700589850109882, 7.768995741852993, 6.796392738675061, 5.8442118589182215, 4.899001625004762, 3.9365965758076378, 2.9385736288224966, 3.862261606683052, 12.784389262412056, 13.750191971973107, 14.619819794284227, 15.538343641072675, 16.52103930357699, 16.481379939613547, 15.51455125302962, 14.545409389676811, 13.529626023708937, 12.50567409787168, 11.562903329803888, 10.58391236887478, 9.635638162087316, 8.834542786648303, 7.86443198636649, 6.835219902190428, 5.857417668155231, 4.999057398664929, 3.9478420747904965, 4.791316185279263, 13.742883625002857, 14.798819882819421, 15.666085717633065, 16.548444660245053, 17.493252469984014, 17.39985385235518, 16.43401127880888, 15.464520028880989, 14.466694973333105, 13.432278450717234, 12.528593782220662, 11.602562055320334, 10.628070049864329, 9.777548394739101, 8.837763266877664, 7.8381778009473635, 6.83826194424756, 5.937903709009718, 4.903037672252737, 5.844208083445973, 14.670569258637034, 14.154362036525091, 14.984702247963222, 15.529331262348883, 16.465937694840743, 17.46953384076978, 17.391683819498056, 16.429780125305566, 15.479950264103245, 14.503975731097837, 13.576318894654081, 12.605249433184479, 11.675472333950646, 10.761784073948522, 9.809985421940299, 8.83473323790702, 7.859232702282305, 6.871980103142217, 5.920787767991012, 6.90585494666766], [6.802941355046756, 7.619145889469986, 8.63691648046348, 9.59191302997978, 10.661493835248299, 11.702608565958785, 12.656891452566716, 13.646831836792519, 14.587497205400368, 15.539906287422873, 16.547730433697627, 17.435428566856274, 18.36540825207732, 18.460865718327764, 17.51750949767753, 16.50818650264417, 15.523243620179962, 14.930830694577336, 13.956211677444113, 13.000841076025152, 5.731255597693734, 6.676275555791677, 7.632610866927538, 8.62260283816926, 9.655941182559843, 10.728779422388737, 11.718634941644865, 12.713742544078382, 13.659043766422608, 14.619609094201731, 15.552038675242859, 16.48485680905612, 17.537595487894123, 17.47563159468925, 16.514681405387645, 15.502083129971442, 14.486543809351609, 13.873172712476926, 12.906710812559817, 11.941599199725367, 4.725473810477087, 5.6712018163040385, 6.674847993180109, 7.70533905076989, 8.760274002308373, 9.741931128388165, 10.7234963822067, 11.698924873433054, 12.683151956500748, 13.681077447277275, 14.615445756728157, 15.675312237509647, 16.71243554195657, 16.49067012362882, 15.498541655266212, 14.562684541536264, 13.515270184708926, 12.805654884309096, 11.868042804612259, 10.993362785408442, 3.7985563862631646, 4.767639721414276, 5.811945158219183, 6.766780218987199, 7.774238554495965, 8.767411686710703, 9.72430279965038, 10.75333717528915, 11.79162986188454, 12.749810922015492, 13.72250380602195, 14.713656009749293, 15.762472162028399, 15.508914445288365, 14.434727465346505, 13.50868446937916, 12.577999089832556, 11.767800351835435, 10.902550623389875, 9.952762012687327, 2.8846854849748436, 3.8549385071246327, 4.790633771398364, 5.8192447901469695, 6.813383024744366, 7.869597161627783, 8.899310010709186, 9.828878269493302, 10.83954474683416, 11.769362724672039, 12.792937976945138, 13.760852895463941, 14.746468831906888, 14.58216265333242, 13.61609911038148, 12.694054594925717, 11.640503366077052, 10.693637325821607, 9.889407846436429, 8.969469229040914, 1.900530931860085, 2.914371262223966, 3.896395564576534, 4.852289204888623, 5.873976833677313, 6.8988638667771305, 7.946396601616174, 8.922268734368705, 9.88885655713715, 10.831583506039573, 11.793990420664146, 12.728888454308793, 13.797469014108707, 13.637754881362083, 12.688662242413825, 11.725452037524459, 10.758223434335141, 9.75779866580342, 8.926572807940005, 7.972026671363515, 1.0669746022729718, 2.106608810190758, 3.106373800967874, 4.081099551566991, 5.070496872240578, 6.075714689639191, 7.000802641143889, 7.967661242009672, 8.962699492090135, 10.029573956204437, 11.061808368737683, 11.994975131854307, 13.060889202258604, 12.655027824046867, 11.694792929162976, 10.77112608096048, 9.83183261173892, 8.832779860923736, 7.937581381143901, 6.983588053142329, 2.0515288162916727, 3.0632467959578653, 4.046113598004877, 5.008548894034407, 5.977175142181174, 6.960474372202795, 7.896564976138787, 8.872648965325897, 9.886411336185473, 10.827556295625294, 11.834442793822367, 12.811216472153351, 12.58088569808108, 11.668713436095173, 10.768703518990836, 9.803298344894982, 8.868918560645568, 7.889762330081538, 6.946715765058551, 5.965518168453725, 3.030179550193357, 4.033926065948891, 4.97615777615439, 5.946808178949118, 6.984592366871175, 7.893073236950464, 8.907703074821177, 9.877948195876805, 10.864939136015074, 11.76757894180281, 12.722707507670414, 12.553340026390359, 11.619320403992935, 10.711776541082838, 9.742829255999462, 8.783617428772594, 7.891826455635385, 6.922530802424231, 5.988024397562108, 4.954205933818574, 4.0991442477135465, 5.048327491764093, 5.989120058555082, 6.901889994702881, 7.950573091656411, 8.935987524172797, 9.879810110259122, 10.882425287819384, 11.848235990399619, 12.79030169393967, 12.576472003765081, 11.612561843895948, 10.61635452434121, 9.640232047911525, 8.758341229299653, 7.826673197405252, 6.858508829397357, 5.95565056566927, 4.946742047957947, 3.9615602900320113, 4.959056911083442, 5.99556723052107, 7.028205734171853, 7.874562900916175, 8.88586363754139, 9.819999586719327, 10.790883628047656, 11.758749381121616, 12.755258156494355, 12.60780902502009, 11.553566243594297, 10.605090191845749, 9.619898030169997, 8.65413373718601, 7.7365190747990535, 6.849924871538509, 5.909363666278205, 4.959993837438874, 4.075867231364123, 3.0343008513049146, 5.9061903044481365, 6.871835281666317, 7.8596937646835245, 8.920756495129943, 9.85361140275363, 10.747498039124565, 11.78690876002378, 12.73182393818803, 12.71410285712593, 11.730645491953545, 10.695705723023476, 9.730357940162778, 8.755222972881196, 7.6822462555233315, 6.740620754589145, 5.8562055245685, 4.924291006312192, 3.951385804564259, 3.001515207767244, 2.0749876292558733, 6.900346531913415, 7.797995478424454, 8.824992086448242, 9.772868330545256, 10.824535545210821, 11.754546559009029, 12.728740871975457, 12.613327522647076, 11.656935996663117, 10.696026715216941, 9.743480628213547, 8.808010498357936, 7.863743360943827, 6.839622937212278, 5.813882932608529, 4.864847207501324, 3.906828334262593, 2.964771832105143, 1.9652144413454797, 1.0478340371677362, 7.952548526943775, 8.854654835767814, 9.777562815388542, 10.748294848028094, 11.743117589411103, 12.692983237142082, 13.038053968072282, 12.026729965066448, 11.034336317297676, 10.00080146099835, 9.07095044778125, 8.04398773284251, 6.9921958835994475, 5.923853885147869, 4.953651789829948, 4.009084111185863, 3.043421558986977, 2.028169199864317, 1.0044947816962821, 0.0, 8.90637441416138, 9.909546836866836, 10.789664107721519, 11.708085494113885, 12.704448113346867, 13.670303237504648, 13.939186643099108, 12.965828800935627, 11.97171779482704, 10.94676961479902, 9.88258852968982, 8.846527268468204, 7.8511046644216576, 6.923903751367783, 5.885349685087667, 4.928844144815705, 3.9204854818730386, 2.9562234322558276, 1.9741801875212488, 0.9361037089386173, 9.952537543553719, 10.92852779049612, 11.733980886917784, 12.635619683323718, 13.595859289869715, 14.625633690067819, 14.810236324578689, 13.763457287720893, 12.77059855089526, 11.825549259122315, 10.777910019594119, 9.738224470760894, 8.793055756180925, 7.786193814581392, 6.827096662994216, 5.965810581139587, 4.935057114809118, 3.981344593933578, 2.913821264636902, 1.8813172381761314, 10.987672194169415, 11.877953428195056, 12.703307125177213, 13.638268249864046, 14.634394672170858, 15.557235545658296, 15.704843676407544, 14.745659445190327, 13.773265553810239, 12.792848117766791, 11.718775364781301, 10.674842401957429, 9.705084631806164, 8.773490523549276, 7.800887520371343, 6.848706640614504, 5.903496406701044, 4.909389378158543, 3.911366431173401, 2.85776682498677, 11.939305965338933, 12.905108674899985, 13.774736497211105, 14.693260343999553, 15.675956006503869, 16.496605147323834, 16.519046034725903, 15.549904171373093, 14.53412080540522, 13.510168879567962, 12.56739811150017, 11.588407150571062, 10.640132943783598, 9.839037568344587, 8.868926768062773, 7.83971468388671, 6.843223162330844, 5.83433512076423, 4.773376392679186, 3.786821403582981, 12.897800327929735, 13.953736585746299, 14.821002420559942, 15.716136442623599, 16.660944252362558, 17.49508654379482, 17.438506060505162, 16.46901481057727, 15.471189755029387, 14.436773232413517, 13.533088563916944, 12.607056837016616, 11.632564831560611, 10.692247790301966, 9.752462662440529, 8.752877196510228, 7.74318272593393, 6.763438026898408, 5.728571990141427, 4.851354540880884, 13.825485961563912, 14.778854258396596, 15.788950015744069, 16.518555981115828, 17.455162413607688, 18.44423112211749, 18.396178601194336, 17.43427490700185, 16.48444504579953, 15.50847051279412, 14.580813676350363, 13.60974421488076, 12.679967115646928, 11.676483469511387, 10.724684817503164, 9.728076433680842, 8.714459570218313, 7.697514421030906, 6.746322085879702, 5.913001404102571], [13.848985091596546, 14.665189626019774, 15.70325666897056, 16.64112776386133, 17.588130224110735, 18.497040156069424, 18.52974358749456, 17.512675038419328, 16.5657423128089, 15.664196621777563, 14.621133674005632, 13.577533009834656, 12.647553324613611, 11.637091764971611, 10.693735544321378, 9.779198517622742, 8.802766742523168, 7.899926155415107, 6.881457783626699, 5.923517838168593, 12.777299334243523, 13.722319292341465, 14.678654603477327, 15.668646574719048, 16.56500492471004, 17.523211012499374, 17.617097741940842, 16.582590096175366, 15.63728887383114, 14.676723546052017, 13.74429396501089, 12.81147583119763, 11.801929523765443, 10.755154717032456, 9.794204527730852, 8.78160625231465, 7.766066931694817, 6.996284157051063, 5.972549696997169, 4.9677611072322545, 11.771517547026876, 12.717245552853827, 13.720891729729896, 14.671690847994341, 15.595216669489748, 16.525193202520338, 16.736689895302295, 15.822455580631122, 14.838228497563428, 13.8403030067869, 12.90593469733602, 11.84606821655453, 10.814369786138958, 9.770193245972028, 8.778064777609421, 7.842207663879471, 6.794793307052134, 5.933616198191472, 4.93388168904961, 4.048395967787442, 10.803498239431791, 11.772581574582903, 12.72382061993376, 13.657072024787386, 14.533643515206737, 15.526816647421475, 15.737496312745973, 14.821981026316458, 13.842913779647313, 12.88473271951636, 11.898565361582637, 10.883921679679236, 9.835105527400131, 8.788437567631572, 7.714250587689713, 6.788207591722369, 5.8575222121757635, 4.895761665717811, 3.9683895078272258, 3.007795195066327, 9.872062557507684, 10.842315579657473, 11.692131308804825, 12.709536595947156, 13.572787985455138, 14.62776622131667, 14.770559204365819, 13.872796946866838, 12.916348716755564, 11.870238109481871, 10.968999532505826, 9.94297083082391, 8.915573200578455, 7.898401550923478, 6.932338007972539, 5.973577717268926, 4.920026488420261, 3.9731604481648155, 2.9552467308737795, 2.024502411419914, 8.887713803636307, 9.899107421462748, 10.752383017024737, 11.708276657336826, 12.633381794388084, 13.638689244928456, 13.817645795272806, 12.841773662520275, 11.87518583975183, 10.932458890849407, 9.970051976224834, 9.035153942580187, 7.966573382780274, 6.9539937789531425, 6.004901140004884, 5.04163106493246, 4.037746556678351, 3.03732178814663, 2.093883079326889, 1.0270598537425144, 7.932541522694496, 8.83991668265836, 9.757183270654506, 10.731909021253625, 11.688642263811007, 12.69386008120962, 13.618948032714318, 13.814775206419252, 12.81973695633879, 11.857290744776403, 10.825056332243157, 9.891889569126533, 8.825975498722237, 7.880894068120706, 6.920659173236815, 5.955444630134767, 4.925803994484651, 3.8822290717430503, 2.929883621113276, 1.975890293111704, 6.9479873086757955, 7.883278696891254, 8.806808727434456, 9.769244023463985, 10.737870271610753, 11.712796670136363, 12.648887274072354, 13.624971263259464, 13.663031062099778, 12.721886102659957, 11.714999604462884, 10.7382259261319, 9.767618273898576, 8.807762543653872, 7.846748583408954, 6.860567244624838, 5.827583306393603, 4.825246602585247, 3.9374241611545737, 2.9536505465320757, 5.969336574774111, 6.912599426900228, 7.8767645492849425, 8.800037165196096, 9.767866777744251, 10.780197805388694, 11.757236982647964, 12.727482103703592, 13.629222338719838, 13.504503992477526, 12.549375426609922, 11.613884574571415, 10.679864952173991, 9.702634091114675, 8.674436493019478, 7.7152246657926105, 6.761773783453708, 5.792478130242554, 4.896115528651017, 3.9521684803428054, 4.900371877253921, 5.849555121304467, 6.863802266884251, 7.844955349442333, 8.750966617864307, 9.736381050380693, 10.785129947210018, 11.732676494958708, 12.645925484335294, 13.587991187875344, 13.48257704277457, 12.638084018566193, 11.629907330570939, 10.653784854141254, 9.660348994054887, 8.672168897159953, 7.712292188229401, 6.759358366997515, 5.929995882055305, 4.944814124129369, 3.9562348788938717, 4.9763681352805875, 5.81807793154446, 6.888632245750264, 7.815676071979327, 8.749812021157263, 9.720696062485592, 10.688561815559552, 11.685070590932291, 12.699663875981926, 13.597641626084556, 13.533561628144277, 12.548369466468525, 11.582605173484538, 10.643232808293012, 9.648917223026697, 8.661437351348551, 7.77028515815725, 6.926824581197341, 5.872073562856466, 3.0001841097132433, 3.90250294536976, 4.890361428386968, 5.842921747029072, 6.847928306767088, 7.825568947461328, 8.83159955389654, 9.845942170872075, 10.804844692052123, 11.74320588977209, 12.651691553630695, 13.532682226997471, 13.54607659835097, 12.554492655147216, 11.63086983356932, 10.587221670517906, 9.655307152261598, 8.778893191031864, 7.7579143634168775, 6.831386784905507, 2.0060278822479645, 2.9763427486116223, 3.913803053307834, 4.861679297404848, 5.913346512070414, 6.857543398118184, 7.831737711084614, 8.791286305605352, 9.74767783158931, 10.708587113035486, 11.661133200038881, 12.596603329894492, 13.5408704673086, 13.519085065388722, 12.557607655549937, 11.648633441829771, 10.690614568591041, 9.76550716349098, 8.790738051585306, 7.858540376993645, 0.9538258872176045, 2.015061734751675, 2.961232324367534, 3.958795149029711, 4.953617890412721, 5.948838769561609, 6.938661766531452, 7.949985769537285, 8.942379417306057, 9.975914273605383, 10.905765286822483, 11.932728001761223, 12.984519851004285, 14.052861849455862, 13.553718538171399, 12.609150859527315, 11.643488307328429, 10.750727835892977, 9.751457711234504, 8.90637441416138, 0.0, 1.0608834116786692, 2.102262655099958, 3.121046556865554, 4.117409176098537, 5.083264300256318, 6.03809755016931, 7.011455392332791, 8.051004770913968, 9.078365533322575, 10.142546618431776, 11.178607879653391, 12.174030483699937, 13.101231396753812, 14.158675317019224, 13.57290726370478, 12.66744841141126, 11.70318636179405, 10.721143117059471, 9.842478123099998, 1.0461631293923381, 2.0221533763347406, 3.031219925214153, 4.048580746075387, 5.008820352621384, 6.0385947528194865, 7.06457888102551, 7.9953050991884105, 8.988163836014044, 9.933213127786988, 10.980852367315185, 12.02053791614841, 12.965706630728377, 13.997417078998598, 14.956514230585773, 14.609873700028661, 13.68202004434734, 12.760009502817176, 11.692486173520502, 10.78769165233751, 2.0899743693169786, 2.9715790140336766, 3.922546340593751, 4.868500313106924, 5.88081406215314, 6.865490906002991, 7.909816587439348, 8.869000818656565, 9.841394710036653, 10.8218121460801, 11.895884899065592, 12.939817861889466, 13.897060676720423, 14.828654784977312, 15.801257788155244, 15.595669570152726, 14.650459336239265, 13.68805428704214, 12.690031340057, 11.744287800708186, 3.041608140486497, 3.9987342607386065, 4.938019454951447, 5.865624276970203, 6.848319939474518, 7.804860507668527, 8.771689194252456, 9.740831057605266, 10.75661442357314, 11.780566349410398, 12.72333711747819, 13.702328078407298, 14.650602285194761, 15.636239559872624, 16.691095025210032, 16.586677613424932, 15.608875379389733, 14.720856096485647, 13.659897368400603, 12.673342379304398, 4.011559979027886, 5.04736217158492, 5.984285378300283, 6.888500375594249, 7.83330818533321, 8.803341904139513, 9.769184477685812, 10.738675727613703, 11.736500783161587, 12.707170702255953, 13.686169953381505, 14.612201680281833, 15.631984353437776, 16.575800058105802, 17.51558518596724, 17.589635512181868, 16.589719655482064, 15.649959002619825, 14.615092965862845, 13.737875516602301, 4.939245612662062, 5.892613909494745, 6.902709666842218, 7.884827273813559, 8.82143370630542, 9.752486482462183, 10.722132004671725, 11.70393582403828, 12.698906249426589, 13.728552335768773, 14.733895065814924, 15.614889058145977, 16.545810317273737, 17.572076480859632, 18.487807341029875, 18.54037655380591, 17.60098054593973, 16.584035396752324, 15.632843061601118, 14.799522379823989], [14.852157514302004, 14.198884219866608, 14.91799722103042, 15.749763329598949, 16.662447486022856, 17.57135741798155, 17.562219507777794, 16.54515095870256, 15.63015923797969, 14.696672542060796, 13.653609594288865, 12.610008930117889, 11.680029244896843, 10.669567685254844, 9.72621146460461, 8.834977211017277, 7.935918328143957, 7.095334529116711, 6.076866157328302, 6.8522530997238995, 13.78047175694898, 13.256013886188299, 13.877831568349645, 14.777282140456665, 15.639322186622161, 16.5975282744115, 17.55235716426776, 17.418954626327725, 16.473653403983498, 15.513088076204376, 14.580658495163249, 13.647840361349989, 12.674386310498464, 11.666758991252618, 10.773867005546052, 9.83155770562695, 8.81601838500712, 7.98695982220478, 6.963225362150887, 5.896496368787561, 12.774689969732334, 12.25094014670066, 12.811515643580993, 13.749460483774374, 14.66953393140187, 15.599510464432463, 16.557218604829597, 16.872407033943425, 15.888179950875731, 14.890254460099204, 13.955886150648324, 12.896019669866833, 11.864321239451261, 10.82014469928433, 9.828016230921722, 8.892159117191772, 7.844744760364436, 6.965433169600557, 5.965698660458695, 4.997112881984878, 11.806670662137249, 11.188138801867657, 11.801590255713792, 12.734841660567419, 13.60796077711886, 14.601133909333598, 15.558025022273274, 15.882864437995126, 14.903797191325983, 13.945616131195031, 12.959448773261306, 11.93387313299154, 10.885056980712434, 9.838389020943875, 8.764202041002015, 7.83815904503467, 6.907473665488065, 5.927578637126896, 5.000206479236311, 4.039612166475412, 10.875234980213142, 10.177147477030989, 10.769900944584858, 11.78730623172719, 12.64710524736726, 13.702083483228792, 14.60042580027618, 14.933680358545507, 13.977232128434233, 12.931121521160541, 12.029882944184495, 11.003854242502577, 9.976456612257124, 8.959284962602148, 7.993221419651208, 7.023529170581227, 5.969977941732562, 5.023111901477117, 3.9870637022828643, 3.056319382828999, 9.890886226341765, 9.173699914928513, 9.83015265280477, 10.78604629311686, 11.707699056300207, 12.713006506840578, 13.647512391183168, 13.902657074198943, 12.9360692514305, 11.993342302528076, 11.030935387903503, 10.096037354258856, 9.027456794458942, 8.014877190631811, 7.065784551683554, 6.1025144766111294, 5.09862996835702, 4.0982051998252995, 3.1547664910055584, 2.087943265421184, 8.935713945399954, 8.114509176124125, 8.83495290643454, 9.809678657033658, 10.76295952572313, 11.768177343121742, 12.69124393024683, 13.658102531112613, 13.880620368017459, 12.91817415645507, 11.885939743921824, 10.9527729808052, 9.886858910400903, 8.941777479799374, 7.981542584915483, 7.016328041813436, 5.98668740616332, 4.94311248342172, 3.9907670327919456, 3.0367737047903733, 7.951159731381253, 7.157871190357017, 7.884578363214489, 8.843561285376108, 9.812187533522875, 10.75262693648371, 11.6887175404197, 12.66480152960681, 13.678563900466386, 13.782769514338627, 12.775883016141554, 11.79910933781057, 10.828501685577246, 9.868645955332543, 8.907631995087623, 7.9214506563035085, 6.888466718072273, 5.886130014263918, 4.998307572833243, 4.014533958210745, 6.972508997479569, 6.187191920365992, 6.954534185064976, 7.858669585852903, 8.807697044091597, 9.82002807173604, 10.79706724899531, 11.767312370050938, 12.669052605067185, 13.656027242416615, 13.610258838288592, 12.674767986250085, 11.740748363852662, 10.763517502793345, 9.735319904698148, 8.77610807747128, 7.822657195132378, 6.853361541921224, 5.956998940329686, 4.955340903048263, 5.903544299959378, 5.124147614770231, 5.941571902664284, 6.90358777009914, 7.7907968842116535, 8.77621131672804, 9.824960213557365, 10.772506761306055, 11.68575575068264, 12.62782145422269, 13.610443904018496, 13.698967430244863, 12.69079074224961, 11.714668265819924, 10.721232405733558, 9.733052308838623, 8.773175599908072, 7.820241778676185, 6.933168304760763, 5.9479865468348265, 4.959407301599329, 4.111576745111348, 4.86877739467432, 5.930914863885847, 6.855506338326673, 7.789642287504609, 8.760526328832938, 9.728392081906899, 10.724900857279637, 11.739494142329274, 12.637471892431904, 13.561323306077107, 13.609252878147196, 12.643488585163208, 11.704116219971683, 10.709800634705367, 9.722320763027223, 8.83116856983592, 7.929997003902798, 6.875245985561923, 4.003356532418701, 3.0377115552005205, 3.941060891516828, 4.882752013376418, 5.887758573114434, 6.865399213808674, 7.871429820243887, 8.885772437219421, 9.844674958399471, 10.783036156119438, 11.691521819978043, 12.572512493344819, 13.5476474606264, 13.615376066825887, 12.691753245247993, 11.648105082196578, 10.71619056394027, 9.832712689344328, 8.761086786122334, 7.8345592076109645, 3.0669112939266334, 2.111551358442383, 2.953633319655181, 3.901509563752195, 4.953176778417761, 5.8973736644655315, 6.871567977431961, 7.8311165719527, 8.787508097936659, 9.748417379382834, 10.700963466386229, 11.63643359624184, 12.580700733655949, 13.604821157387498, 13.618491067228609, 12.693543240446608, 11.735524367207878, 10.793467865050427, 9.793910474290763, 8.861712799699102, 2.014709298896274, 1.0548920010990221, 2.001062590714881, 2.998625415377058, 3.993448156760068, 4.988669035908956, 5.9466047194585885, 6.889670816523302, 7.882064464292074, 8.915599320591399, 9.845450333808499, 10.872413048747239, 11.9242048979903, 12.99254689644188, 13.9627489917598, 13.65406065814415, 12.688398105945264, 11.778304552107997, 10.754630133939962, 9.909546836866838, 1.0608834116786692, 0.0, 1.0413792434212887, 2.060163145186885, 3.0565257644198685, 4.02238088857765, 4.977214138490641, 5.950571980654122, 6.9901213592352995, 8.017482121643908, 9.08166320675311, 10.117724467974725, 11.11314707202127, 12.040347985075146, 13.097791905340557, 14.05429744561252, 13.670620834116718, 12.706358784499507, 11.724315539764929, 10.845650545805455, 2.0311358169948175, 1.0551455700524153, 1.9856960226175546, 2.9876973343967173, 3.9479369409427143, 4.977711341140817, 6.003695469346842, 6.934421687509742, 7.927280424335375, 8.87232971610832, 9.919968955636516, 10.959654504469741, 11.90482321904971, 12.936533667319932, 13.895630818907106, 14.935353377670687, 14.685192467052797, 13.763181925522634, 12.69565859622596, 11.790864075042968, 3.0187096308722854, 2.004571207751351, 2.9550222608769836, 3.9009762333901565, 4.913289982436373, 5.897966826286224, 6.9422925077225806, 7.901476738939796, 8.873870630319885, 9.849409861862117, 10.923482614847607, 11.967415577671481, 12.836177265041757, 13.767771373298645, 14.740374376476577, 15.805771893106407, 15.653631758944723, 14.691226709747598, 13.693203762762458, 12.747460223413643, 3.970343402041804, 3.0317264544562805, 3.971011648669121, 4.898616470687877, 5.881312133192192, 6.83733642795176, 7.804165114535689, 8.773306977888499, 9.789090343856373, 10.81304226969363, 11.755813037761422, 12.73480399869053, 13.683078205477994, 14.668715480155857, 15.723570945493265, 16.757621772163283, 16.61204780209519, 15.724028519191105, 14.66306979110606, 13.676514802009855, 4.940295240583193, 4.080354365302593, 5.017277572017958, 5.921492569311923, 6.866300379050884, 7.8358178244227465, 8.801660397969044, 9.771151647896936, 10.76897670344482, 11.739646622539185, 12.718645873664737, 13.644677600565066, 14.664460273721009, 15.608275978389035, 16.548061106250472, 17.547646572180774, 17.59289207818752, 16.653131425325284, 15.618265388568302, 14.741047939307759, 5.867980874217369, 5.050075632543089, 6.060171389890561, 6.940605967208093, 7.877212399699955, 8.784962402745416, 9.754607924954957, 10.736411744321513, 11.731382169709821, 12.761028256052006, 13.766370986098156, 14.64736497842921, 15.57828623755697, 16.604552401142865, 17.520283261313107, 17.61469381571803, 16.737796017508145, 15.857399280462994, 15.211637138995517, 15.802694802529446], [15.663810466715336, 14.738371653312305, 13.929035922648515, 14.760802031217043, 15.673486187640954, 16.582396119599643, 16.520840264356504, 15.503771715281271, 14.5887799945584, 13.655293298639508, 12.612230350867577, 11.568629686696601, 10.638650001475556, 9.628188441833556, 8.684832221183322, 7.849037951837743, 6.949979068964423, 6.135306668792326, 6.936905293592721, 7.712292235988317, 14.592124709362313, 13.795501319633996, 12.88887026996774, 13.788320842074759, 14.65036088824026, 15.608566976029595, 16.56339586588586, 16.37757538290644, 15.432274160562212, 14.471708832783088, 13.539279251741961, 12.606461117928701, 11.633007067077177, 10.62537974783133, 9.732487762124764, 8.85514132451047, 7.986678879792776, 7.192964650892737, 7.823264498415304, 6.756535505051978, 13.586342922145667, 12.790427580146357, 11.822554345199087, 12.760499185392469, 13.680572633019969, 14.61054916605056, 15.568257306447693, 16.538601535162293, 16.414182783270764, 15.489515057727932, 14.56591297454953, 13.5718687325718, 12.659925779881847, 11.610341218891758, 10.726253988944986, 9.790396875215036, 8.742982518387699, 7.854143551828092, 6.854300360628204, 5.857152018249295, 12.618323614550581, 11.727626235313354, 10.812628957331889, 11.745880362185515, 12.618999478736958, 13.612172610951696, 14.569063723891372, 15.490216840128014, 15.883207851883794, 14.925026791752842, 13.881269213291127, 12.832110891014803, 11.783294738735698, 10.736626778967139, 9.662439799025279, 8.736396803057934, 7.805711423511329, 6.819691888331565, 5.89231973044098, 4.9136589486187905, 11.686887932626474, 10.716634910476685, 9.780939646202954, 10.798344933345286, 11.658143948985359, 12.71312218484689, 13.611464501894279, 14.541032760678394, 15.018611371855522, 13.97250076458183, 12.984780578445866, 11.927623034139994, 10.90022540389454, 9.869556491989616, 8.903492949038677, 7.921766928604491, 6.868215699755826, 5.921349659500381, 4.8853014603061276, 3.9545571408522626, 10.771003497196448, 9.823215656775435, 8.841191354422866, 9.797084994734956, 10.718737757918305, 11.724045208458676, 12.658551092801266, 13.634423225553798, 13.977448494851789, 13.034721545949365, 12.072314631324792, 11.137416597680145, 10.068836037880232, 9.0562564340531, 8.107163795104842, 7.143893720032418, 6.140009211778309, 5.139584443246588, 4.196145734426847, 3.1293225088424723, 9.815831216254637, 8.835121852646704, 7.8459916080526355, 8.820717358651754, 9.773998227341227, 10.77921604473984, 11.702282631864929, 12.669141232730711, 13.664179482811175, 13.922972587041704, 12.890738174508458, 11.957571411391834, 10.891657340987537, 9.946575910386008, 8.986341015502116, 8.021126472400068, 6.991485836749952, 5.947910914008352, 4.995565463378578, 4.041572135377006, 8.831277002235936, 7.878483866879597, 6.895617064832585, 7.854599986994207, 8.823226235140973, 9.763665638101807, 10.699756242037799, 11.675840231224909, 12.689602602084484, 13.607088590212227, 13.780681446728186, 12.803907768397202, 11.833300116163878, 10.873444385919175, 9.912430425674255, 8.89778660419232, 7.864802665961085, 6.86246596215273, 5.9183582680728035, 4.909606159944834, 7.852626268334252, 6.943596812099946, 5.965572886683072, 6.869708287471001, 7.818735745709695, 8.831066773354138, 9.808105950613408, 10.778351071669036, 11.68009130668528, 12.66706594403471, 13.55468422180124, 13.64734688167446, 12.713327259277037, 11.73609639821772, 10.707898800122523, 9.748686972895655, 8.795236090556752, 7.825940437345597, 6.86927663764648, 5.835458173902946, 6.783661570814061, 5.925025469602081, 4.9526106042823805, 5.914626471717238, 6.8018355858297515, 7.787250018346136, 8.835998915175463, 9.78354546292415, 10.696794452300736, 11.638860155840787, 12.621482605636592, 13.540603351628885, 13.663369637673982, 12.687247161244297, 11.69381130115793, 10.705631204262996, 9.745754495332445, 8.79282067410056, 7.813285575615446, 6.8281038176895095, 5.839524572454012, 4.9124545999431986, 3.8798160962924158, 4.941953565503944, 5.866545039944771, 6.800680989122707, 7.771565030451035, 8.739430783524995, 9.735939558897734, 10.711302535830853, 11.609280285933483, 12.533131699578686, 13.517162986010424, 13.616067480587581, 12.676695115396056, 11.68237953012974, 10.694899658451597, 9.800008244548629, 8.810114274757481, 7.755363256416606, 4.883473803273384, 3.9178288260552034, 2.9520995931349243, 3.893790714994515, 4.898797274732531, 5.876437915426772, 6.843238213745466, 7.857580830721, 8.81648335190105, 9.754844549621017, 10.663330213479622, 11.544320886846398, 12.51945585412798, 13.541221961130583, 13.661297843254669, 12.617649680203254, 11.685735161946946, 10.712829960199013, 9.641204056977019, 8.714676478465648, 3.9619834956607236, 2.991668629297066, 1.9646720212732771, 2.912548265370291, 3.9642154800358576, 4.9070548465163375, 5.84337637093354, 6.802924965454279, 7.759316491438237, 8.720225772884413, 9.672771859887808, 10.60824198974342, 11.552509127157528, 12.576629550889077, 13.602369555492826, 13.573660511301291, 12.615641638062561, 11.67358513590511, 10.674027745145446, 9.741830070553785, 3.019507729482906, 1.958271881948836, 1.012101292332977, 1.9785745478513876, 2.973397289234397, 3.9686181683832853, 4.9052254760373, 5.8482915731020135, 6.840685220870785, 7.8742200771701105, 8.804071090387211, 9.831033805325951, 10.882825654569013, 11.95116765302059, 12.921369748338511, 13.865937426982597, 13.568515376799947, 12.65842182296268, 11.634747404794645, 10.78966410772152, 2.102262655099958, 1.0413792434212887, 0.0, 1.018783901765596, 2.0151465209985795, 2.981001645156361, 3.9358348950693527, 4.909192737232834, 5.94874211581401, 6.976102878222618, 8.040283963331818, 9.076345224553434, 10.071767828599981, 10.998968741653856, 12.056412661919268, 13.01291820219123, 14.021276865133897, 13.58647605535419, 12.604432810619612, 11.725767816660138, 2.9293735750180807, 1.9533833280756783, 0.9443167791962659, 1.9463180909754283, 2.906557697521425, 3.9363320977195277, 4.962316225925553, 5.8930424440884535, 6.885901180914087, 7.830950472687031, 8.878589712215227, 9.918275261048452, 10.863443975628421, 11.895154423898642, 12.854251575485817, 13.893974134249397, 14.928261006664886, 14.643299196377317, 13.575775867080642, 12.670981345897651, 3.8787487671367025, 2.8646103440157686, 1.9136430174556947, 2.8595969899688676, 3.8719107390150835, 4.856587582864934, 5.900913264301291, 6.860097495518507, 7.832491386898596, 8.80803061844083, 9.882103371426322, 10.926036334250195, 11.794798021620467, 12.726392129877356, 13.698995133055288, 14.764392649685117, 15.709602883598578, 15.57134398060228, 14.573321033617141, 13.559113175826976, 4.830382538306221, 3.8917655907206985, 2.985072389489587, 3.9126772115083432, 4.895372874012659, 5.7959571845304705, 6.762785871114399, 7.731927734467209, 8.747711100435081, 9.77166302627234, 10.714433794340131, 11.69342475526924, 12.641698962056703, 13.627336236734566, 14.682191702071973, 15.716242528741992, 16.668018926749046, 16.535681471604438, 15.474722743519393, 14.488167754423188, 5.80033437684761, 4.940393501567012, 4.0313383128384235, 4.935553310132389, 5.88036111987135, 6.794438581001457, 7.760281154547755, 8.729772404475646, 9.72759746002353, 10.698267379117894, 11.677266630243446, 12.603298357143775, 13.623081030299717, 14.566896734967743, 15.506681862829181, 16.50626732875948, 16.769805477160983, 15.91964403210974, 16.429918340981633, 15.552700891721091, 6.728020010481786, 5.9101147688075075, 5.092210396639498, 5.954666708028559, 6.891273140520421, 7.743583159324127, 8.71322868153367, 9.695032500900224, 10.690002926288532, 11.719649012630716, 12.724991742676865, 13.60598573500792, 14.53690699413568, 15.563173157721575, 16.478904017891818, 16.62573251733613, 15.74883471912624, 14.868437982081089, 15.751124572441213, 16.61434775494278], [16.56126516849633, 15.635826355093299, 14.826490624429509, 13.876629062565303, 14.696155085839294, 15.605065017797983, 15.51340273303598, 14.496334183960748, 13.581342463237878, 12.647855767318983, 11.604792819547052, 10.561192155376077, 9.631212470155031, 8.620750910513031, 7.6773946898627985, 6.921535590215067, 6.022476707341747, 6.951680880213118, 7.897204568989286, 8.674785946795955, 15.489579411143307, 14.69295602141499, 13.786324971748734, 12.90414787342302, 13.6730297864386, 14.631235874227935, 15.586064764084197, 15.370137851585913, 14.424836629241687, 13.464271301462563, 12.531841720421436, 11.599023586608176, 10.625569535756652, 9.617942216510805, 8.72505023080424, 7.927638962887793, 7.0591765181701, 8.009338862313529, 8.785758209222942, 7.719029215859617, 14.48379762392666, 13.687882281927351, 12.720009046980081, 11.876326216740729, 12.703241531218309, 13.6332180642489, 14.590926204646033, 15.561270433360631, 15.406745251950241, 14.482077526407405, 13.558475443229003, 12.564431201251276, 11.652488248561323, 10.602903687571233, 9.750133509720365, 8.867037551322971, 8.030450142812782, 8.81663726263573, 7.816794071435843, 6.8196457290569334, 13.515778316331575, 12.625080937094348, 11.710083659112883, 10.861707393533775, 11.641668376935298, 12.634841509150036, 13.591732622089712, 14.512885738326352, 15.55117842492174, 15.459989189247436, 14.575736060402892, 13.52657773812657, 12.63132732568025, 11.58465936591169, 10.630402039297763, 9.70435904333042, 8.773673663783816, 7.782185599139204, 6.854813441248619, 5.876152659426429, 12.584342634407468, 11.614089612257679, 10.678394347983948, 9.914171964693546, 10.680812847183699, 11.73579108304523, 12.634133400092617, 13.563701658876733, 14.574368136217592, 14.991284666347426, 14.00356448021146, 12.946406935905589, 11.919009305660136, 10.888340393755213, 9.922276850804273, 8.940550830370087, 7.886999601521422, 6.940133561265977, 5.904085362071724, 4.973341042617858, 11.689424883588813, 10.72067035855643, 9.73864605620386, 8.912912026083216, 9.741406656116645, 10.746714106657016, 11.681219990999605, 12.657092123752136, 13.62367994652058, 14.053505447714961, 13.091098533090388, 12.156200499445742, 11.087619939645828, 10.075040335818697, 9.125947696870439, 8.162677621798014, 7.158793113543905, 6.158368345012184, 5.214929636192443, 4.148106410608069, 10.734252602647002, 9.7325765544277, 8.74344630983363, 7.923906872766892, 8.796667125539567, 9.80188494293818, 10.724951530063267, 11.69181013092905, 12.686848381009511, 13.614192886309679, 13.83599035292345, 12.902823589806825, 11.836909519402528, 10.891828088800999, 9.931593193917108, 8.96637865081506, 7.936738015164943, 6.893163092423343, 5.940817641793569, 4.986824313791997, 9.749698388628302, 8.775938568660592, 7.79307176661358, 6.877268885192545, 7.8458951333393125, 8.786334536300146, 9.722425140236137, 10.698509129423247, 11.712271500282823, 12.629225518129962, 13.525705451685567, 13.749159946812194, 12.77855229457887, 11.818696564334166, 10.857682604089247, 9.816207990584687, 8.783224052353452, 7.780887348545097, 6.83677965446517, 5.828027546337201, 8.771047654726617, 7.841051513880941, 6.863027588464067, 5.892377185669339, 6.841404643908033, 7.853735671552476, 8.830242878531143, 9.800487999586771, 10.702228234603016, 11.689202871952446, 12.54660376050332, 13.482094612541827, 13.6317486456694, 12.654517784610084, 11.626320186514887, 10.667108359288019, 9.713657476949116, 8.744361823737963, 7.787698024038845, 6.753879560295312, 7.702082957206427, 6.843446855994448, 5.871031990674748, 4.937295369915575, 5.82450448402809, 6.809918916544475, 7.858135843093198, 8.805682390841888, 9.718931380218471, 10.660997083758522, 11.613402144338671, 12.521819449863289, 13.514142586344663, 13.605668547636661, 12.612232687550295, 11.62405259065536, 10.66417588172481, 9.711242060492925, 8.731706962007811, 7.746525204081875, 6.757945958846378, 5.830875986335565, 4.798237482684782, 3.9646224637022818, 4.88921393814311, 5.822817917040443, 6.793701958368771, 7.761567711442731, 8.758076486815469, 9.692518634065257, 10.590496384167887, 11.51434779781309, 12.498379084244828, 13.464143377228815, 13.59511650178842, 12.600800916522104, 11.613321044843962, 10.718429630940994, 9.728535661149847, 8.673784642808972, 5.80189518966575, 4.8362502124475695, 3.870520979527291, 2.916459613192853, 3.9214661729308693, 4.895319464635205, 5.82445431197987, 6.838796928955404, 7.797699450135454, 8.736060647855421, 9.644546311714025, 10.525536985080802, 11.500671952362383, 12.522438059364987, 13.464063560299174, 13.53607106659562, 12.604156548339311, 11.631251346591378, 10.559625443369384, 9.633097864858014, 4.88040488205309, 3.9100900156894323, 2.8830934076656436, 1.9352171635686295, 2.9777179159241483, 3.888270944750742, 4.824592469167944, 5.784141063688683, 6.7405325896726405, 7.701441871118817, 8.653987958122212, 9.589458087977823, 10.533725225391931, 11.55784564912348, 12.58358565372723, 13.532621378834435, 13.534063024454927, 12.592006522297476, 11.592449131537812, 10.66025145694615, 3.964759907897898, 2.9035240603638277, 1.9573534707479687, 0.9597906460857917, 1.9546133874688012, 2.9498342666176893, 3.886441574271703, 4.829507671336417, 5.821901319105189, 6.855436175404514, 7.785287188621614, 8.812249903560353, 9.864041752803415, 10.932383751254992, 11.902585846572913, 12.847153525217, 13.812816077415885, 13.576843209355044, 12.553168791187009, 11.708085494113886, 3.1210465568655543, 2.060163145186885, 1.018783901765596, 0.0, 0.9963626192329834, 1.9622177433907648, 2.9170509933037563, 3.8904088354672375, 4.929958214048414, 5.957318976457022, 7.021500061566223, 8.057561322787839, 9.052983926834386, 9.980184839888262, 11.037628760153673, 11.994134300425635, 13.002492963368303, 13.966755012985514, 13.522854197011975, 12.644189203052504, 3.9481574767836767, 2.9721672298412742, 1.9631006809618619, 0.9275341892098324, 1.8877737957558294, 2.917548195953932, 3.943532324159957, 4.874258542322857, 5.8671172791484905, 6.812166570921435, 7.859805810449632, 8.899491359282855, 9.844660073862823, 10.876370522133044, 11.835467673720219, 12.8751902324838, 13.909477104899288, 14.936769832236466, 14.494197253473006, 13.587710881206181, 4.841242477944341, 3.8271040548234074, 2.8761367282633334, 1.9301827557501605, 2.9263091780569734, 3.84915005154441, 4.892348034197402, 5.851532265414618, 6.823926156794707, 7.789246716675233, 8.863319469660723, 9.907252432484597, 10.77601411985487, 11.707608228111757, 12.68021123128969, 13.745608747919519, 14.69081898183298, 15.74750231847619, 15.491742420009505, 14.45656787760797, 5.79287624911386, 4.852064866117264, 3.9127796719044228, 2.9851748498856665, 3.9678705123899816, 4.7885196532099465, 5.755348339793875, 6.724490203146685, 7.740273569114558, 8.764225494951816, 9.706996263019608, 10.685987223948716, 11.63426143073618, 12.619898705414043, 13.67475417075145, 14.708804997421469, 15.649235024983447, 16.65812306655006, 16.372177445300387, 15.385622456204182, 6.762828087655249, 5.900692776963577, 4.958660084197909, 4.008050948509712, 4.952858758248674, 5.787001049680933, 6.752843623227232, 7.722334873155123, 8.720159928703007, 9.690829847797371, 10.669829098922923, 11.595860825823252, 12.615643498979194, 13.55945920364722, 14.499244331508658, 15.498829797438958, 15.885632508509245, 16.817098733890735, 17.327373042762627, 16.450155593502085, 7.690513721289425, 6.870414044204073, 6.009281953377224, 5.027164346405883, 5.963770778897745, 6.736145628003603, 7.705791150213145, 8.6875949695797, 9.682565394968009, 10.712211481310193, 11.717554211356342, 12.598548203687397, 13.529469462815157, 14.555735626401052, 15.471466486571293, 15.648401415534469, 14.8646617504745, 15.765892683862083, 16.648579274222207, 17.511802456723775], [17.557627787729313, 16.63218897432628, 15.760250972505727, 14.805254422989426, 13.822560188857254, 14.731470120815944, 14.564048737364017, 13.546980188288785, 12.631988467565915, 11.749429313374328, 10.706366365602397, 9.662765701431422, 8.732786016210376, 7.722324456568377, 6.778968235918144, 6.195760281037745, 7.018839326574731, 7.948043499446102, 8.893567188222269, 9.67114856602894, 16.48594203037629, 15.689318640647972, 14.782687590981716, 13.832773233847142, 12.79943488945656, 13.757640977245895, 14.644867070286267, 14.471711397641258, 13.526410175297032, 12.565844847517909, 11.633415266476781, 10.700597132663521, 9.727143081811997, 8.71951576256615, 7.826623776859584, 7.201863653710471, 8.055539137403082, 9.005701481546513, 9.782120828455927, 8.715391835092602, 15.480160243159643, 14.684244901160334, 13.716371666213064, 12.828525715702977, 11.82964663423627, 12.759623167266861, 13.649728510848103, 14.610734853179641, 14.508318798005586, 13.58365107246275, 12.660048989284348, 11.666004747306621, 10.754061794616668, 9.704477233626578, 8.85170705577571, 8.14126224214565, 9.026812762045765, 9.812999881868715, 8.813156690668826, 7.816008348289917, 14.512140935564558, 13.62144355632733, 12.706446278345865, 11.813906892496023, 10.768073479953259, 11.761246612167996, 12.650534928291782, 13.562350158145362, 14.60064284474075, 14.56156273530278, 13.677309606458238, 12.628151284181914, 11.732900871735595, 10.686232911967036, 9.915521245695418, 9.196285935208461, 9.7700362830168, 8.778548218372189, 7.8511760604816025, 6.872515278659413, 13.580705253640451, 12.610452231490662, 11.674756967216931, 10.866371463655794, 9.80721795020166, 10.832942156327517, 11.683597819911627, 12.613166078695743, 13.623832556036602, 14.486482138015244, 14.606875435535049, 13.580954398467266, 12.672059104175773, 11.64139019227085, 10.918639470037256, 9.93691344960307, 8.883362220754405, 7.93649618049896, 6.900447981304707, 5.969703661850842, 12.685787502821798, 11.717032977789412, 10.735008675436843, 9.889499387923296, 8.867811759134606, 9.843865179939304, 10.730684410818615, 11.706556543571146, 12.67314436633959, 13.548702919382778, 14.087461152323371, 13.152563118678724, 12.08398255887881, 11.07140295505168, 10.122310316103421, 9.159040241030997, 8.155155732776889, 7.154730964245168, 6.211292255425427, 5.144469029841052, 11.730615221879987, 10.728939173660681, 9.739808929066612, 8.912469549231115, 7.923072228557528, 8.899036016220467, 9.774415949882277, 10.74127455074806, 11.736312800828522, 12.622319914948335, 13.596813576656995, 13.89918620903981, 12.833272138635513, 11.888190708033983, 10.927955813150092, 9.962741270048044, 8.933100634397928, 7.8895257116563275, 6.937180261026554, 5.983186933024982, 10.746061007861286, 9.772301187893573, 8.789434385846562, 7.873631504425528, 6.972300236357274, 7.835798956119155, 8.771889560055147, 9.747973549242257, 10.761735920101833, 11.637352546768618, 12.529342832452583, 13.49861709345426, 13.774914913811854, 12.81505918356715, 11.854045223322231, 10.81257060981767, 9.779586671586435, 8.77724996777808, 7.8331422736981535, 6.824390165570184, 9.767410273959602, 8.837414133113924, 7.859390207697049, 6.888739804902322, 5.937968588784982, 6.903200091371486, 7.860657744885382, 8.83090286594101, 9.710355263241672, 10.697329900591102, 11.550241141270336, 12.485731993308843, 13.419751615706266, 13.65088040384307, 12.622682805747873, 11.663470978521005, 10.710020096182102, 9.740724442970947, 8.784060643271829, 7.750242179528295, 8.698445576439411, 7.839809475227432, 6.867394609907732, 5.933657989148559, 4.921068428905039, 5.8557913692329535, 6.888550709447436, 7.836097257196125, 8.727058408857127, 9.669124112397178, 10.617039525105687, 11.525456830630304, 12.517779967111679, 13.453879068721346, 13.60859530678328, 12.620415209888346, 11.660538500957795, 10.70760467972591, 9.728069581240796, 8.74288782331486, 7.754308578079362, 6.8272386055685494, 5.794600101917767, 4.960985082935265, 3.985777883020058, 4.8545468055439365, 5.824116824723009, 6.7919825777969685, 7.766203515454126, 8.696156014832274, 9.594133764934902, 10.517985178580105, 11.502016465011843, 12.46778075799583, 13.407153123187356, 13.59716353575509, 12.609683664076947, 11.714792250173979, 10.724898280382831, 9.670147262041956, 6.798257808898733, 5.832612831680553, 4.866883598760275, 3.9128222324258366, 3.018030117807818, 3.9270483531386975, 4.828091692746886, 5.84243430972242, 6.8013368309024695, 7.739698028622438, 8.648183692481041, 9.529174365847817, 10.504309333129399, 11.526075440132002, 12.46770094106619, 13.511349104117604, 13.600519167572296, 12.627613965824363, 11.555988062602369, 10.629460484090998, 5.876767501286073, 4.906452634922416, 3.879456026898627, 2.931579782801613, 2.024885334440798, 2.9199998332542347, 3.82822984993496, 4.787778444455699, 5.744169970439657, 6.7050792518858335, 7.657625338889227, 8.593095468744838, 9.537362606158947, 10.561483029890496, 11.587223034494246, 12.53625875960145, 13.49427763284018, 13.58836914153046, 12.588811750770796, 11.656614076179135, 4.961122527130882, 3.8998866795968112, 2.953716089980952, 1.956153265318775, 1.001780805985451, 1.9815631551211823, 2.89007895503872, 3.8331450521034336, 4.825538699872205, 5.859073556171531, 6.78892456938863, 7.815887284327371, 8.867679133570432, 9.93602113202201, 10.90622322733993, 11.850790905984017, 12.816453458182902, 13.831705817305561, 13.549531410419995, 12.70444811334687, 4.117409176098538, 3.0565257644198685, 2.0151465209985795, 0.9963626192329834, 0.0, 0.9658551241577813, 1.920688374070773, 2.894046216234254, 3.9335955948154306, 4.960956357224038, 6.025137442333239, 7.0611987035548545, 8.0566213076014, 8.983822220655275, 10.041266140920687, 10.99777168119265, 12.006130344135316, 12.970392393752528, 13.952435638487106, 13.640551822285488, 4.94452009601666, 3.9685298490742578, 2.9594633001948454, 1.9238968084428159, 1.0396456751082794, 2.019121742009278, 2.9471697049269734, 3.877895923089873, 4.870754659915507, 5.815803951688451, 6.863443191216648, 7.903128740049873, 8.84829745462984, 9.880007902900061, 10.839105054487236, 11.878827613250817, 12.913114485666306, 13.940407213003484, 14.923778694948137, 14.584073500439164, 5.837605097177325, 4.823466674056391, 3.872499347496317, 2.926545374983144, 2.0781810574094233, 2.950723597599756, 3.895985414964419, 4.8551696461816345, 5.827563537561724, 6.79288409744225, 7.866956850427741, 8.910889813251615, 9.779651500621886, 10.711245608878775, 11.683848612056707, 12.749246128686536, 13.694456362599997, 14.751139699243208, 15.75232718378458, 15.452930496840953, 6.789238868346843, 5.848427485350246, 4.909142291137406, 3.98153746911865, 3.129277829767561, 3.890093199265292, 4.83399325557088, 5.80313511892369, 6.818918484891563, 7.814871499279854, 8.757642267347645, 9.736633228276753, 10.684907435064217, 11.67054470974208, 12.725400175079487, 13.740254171958743, 14.652872405750465, 15.661760447317079, 16.722719175402123, 16.381985075437164, 7.759190706888233, 6.89705539619656, 5.955022703430892, 5.004413567742696, 4.189895814014193, 4.888574595736278, 5.835063513230276, 6.804554763158167, 7.802379818706051, 8.741475852125408, 9.72047510325096, 10.646506830151289, 11.666289503307231, 12.610105207975257, 13.549890335836695, 14.549475801766995, 15.559170272343293, 16.538914971378816, 17.573781008135796, 17.446518212735068, 8.686876340522408, 7.866776663437055, 7.0056445726102075, 6.023526965638866, 5.237995469720423, 5.8377191740589485, 6.792736053919452, 7.769814859582746, 8.764785284971053, 9.794431371313237, 10.768200215684379, 11.649194208015434, 12.580115467143195, 13.60638163072909, 14.52211249089933, 14.77480651855243, 15.788423382014958, 16.6996530319383, 17.644941893455186, 18.508165075956757], [18.430771071983354, 17.505332258580324, 16.59730072004976, 15.642304170533459, 14.659609936401287, 13.877285525201346, 13.598193613206236, 12.581125064131005, 11.666133343408134, 10.783574189216548, 9.740511241444617, 8.696910577273641, 7.766930892052596, 6.756469332410596, 5.813113111760362, 6.822436106793723, 7.874222440124086, 8.803426612995457, 9.80277904477944, 10.613135940188123, 17.35908531463033, 16.562461924902017, 15.655830875235761, 14.669822981391174, 13.636484637000592, 12.903456381631297, 13.679011946128487, 13.505856273483477, 12.560555051139252, 11.599989723360128, 10.667560142319001, 9.73474200850574, 8.761287957654217, 7.753660638408369, 6.860768652701804, 7.828539479466449, 8.892931982087719, 9.859010822558407, 10.724108202615108, 9.657379209251783, 16.353303527413686, 15.557388185414379, 14.589514950467109, 13.66557546324701, 12.666696381780302, 11.905438571652263, 12.683873386690323, 13.644879729021861, 13.542463673847806, 12.61779594830497, 11.694193865126568, 10.70014962314884, 9.788206670458887, 8.738622109468798, 7.88585193161793, 8.767938067901628, 9.815352424728966, 10.754987256027896, 9.755144064828007, 8.757995722449099, 15.385284219818603, 14.494586840581375, 13.579589562599908, 12.650956640040055, 11.605123227497291, 10.907062016553398, 11.684679804134001, 12.596495033987582, 13.63478772058297, 13.595707611145, 12.711454482300457, 11.662296160024134, 10.767045747577814, 9.720377787809255, 8.949666121537637, 9.82296176096444, 10.735891407174583, 9.74440334252997, 8.817031184639385, 7.838370402817195, 14.453848537894496, 13.483595515744707, 12.547900251470974, 11.703421211199826, 10.644267697745692, 9.867087032169737, 10.717742695753847, 11.647310954537963, 12.657977431878821, 13.520627013857464, 13.641020311377268, 12.615099274309486, 11.706203980017992, 10.675535068113069, 10.000693990848552, 10.779595461051013, 9.849217344912185, 8.90235130465674, 7.866303105462487, 6.935558786008622, 13.596888946774321, 12.590176262043453, 11.608151959690886, 10.726549135467328, 9.704861506678638, 8.878010055781523, 9.764829286660834, 10.740701419413366, 11.70728924218181, 12.582847795225, 13.545254709849573, 13.647063715464634, 12.64834192201666, 11.63576231818953, 10.928130858816207, 10.124895365188777, 9.121010856934669, 8.120586088402948, 7.177147379583208, 6.1103241539988336, 12.64171666583251, 11.602082457914724, 10.612952213320655, 9.749519296775148, 8.76012197610156, 7.933180892062687, 8.808560825724497, 9.775419426590279, 10.770457676670741, 11.656464790790556, 12.630958452499215, 13.47209618448666, 13.57612584283943, 12.6310444122379, 11.893810937307872, 10.928596394205824, 9.898955758555708, 8.855380835814108, 7.903035385184334, 6.949042057182762, 11.679647215006014, 10.645444472147616, 9.662577670100605, 8.74677478867957, 7.809349983901306, 6.869943831961375, 7.806034435897367, 8.782118425084477, 9.795880795944052, 10.67149742261084, 11.563487708294803, 12.53276196929648, 13.41546178563663, 13.660714051803334, 12.819900347480012, 11.778425733975453, 10.745441795744217, 9.743105091935861, 8.798997397855935, 7.790245289727966, 10.733265398117382, 9.710557417367966, 8.732533491951092, 7.761883089156365, 6.775018336329015, 5.937344967213706, 6.894802620727599, 7.865047741783227, 8.744500139083893, 9.731474776433323, 10.584386017112555, 11.519876869151062, 12.453896491548486, 13.431127352607803, 13.588537929905653, 12.629326102678785, 11.675875220339883, 10.70657956712873, 9.749915767429611, 8.716097303686077, 9.664300700597192, 8.802201501540468, 7.787954355960684, 6.806801273402602, 5.758118176449071, 4.889936245075172, 5.922695585289654, 6.870242133038344, 7.761203284699348, 8.7032689882394, 9.651184400947907, 10.559601706472524, 11.551924842953898, 12.488023944563565, 13.463120153530175, 13.586270334046127, 12.626393625115577, 11.673459803883691, 10.693924705398576, 9.70874294747264, 8.720163702237143, 7.79309372972633, 6.760455226075547, 5.85193994679749, 4.822827630564091, 3.888691681386155, 4.858261700565228, 5.826127453639187, 6.800348391296345, 7.730300890674493, 8.628278640777122, 9.552130054422324, 10.536161340854063, 11.50192563383805, 12.441297999029576, 13.435613584295892, 13.575538788234729, 12.680647374331759, 11.690753404540612, 10.636002386199737, 7.764112933056515, 6.798467955838334, 5.832738722918055, 4.8786773565836175, 3.8914863785112437, 2.961193228980916, 3.8622365685891045, 4.876579185564639, 5.835481706744689, 6.773842904464656, 7.68232856832326, 8.563319241690037, 9.538454208971618, 10.56022031597422, 11.501845816908407, 12.545493979959822, 13.47740849821613, 13.593469089982143, 12.52184318676015, 11.595315608248779, 6.8426226254438545, 5.872307759080197, 4.845311151056408, 3.8974349069593943, 2.8983415951442235, 1.9541447090964534, 2.8623747257771788, 3.821923320297918, 4.778314846281876, 5.739224127728052, 6.691770214731446, 7.627240344587057, 8.571507482001165, 9.595627905732714, 10.621367910336463, 11.570403635443668, 12.528422508682398, 13.470479010839849, 13.554666874928577, 12.622469200336916, 5.926977651288663, 4.8657418037545925, 3.9195712141387338, 2.9220083894765567, 1.9676359301432322, 1.015708030963401, 1.9242238308809387, 2.8672899279456523, 3.8596835757144246, 4.89321843201375, 5.82306944523085, 6.85003216016959, 7.9018240094126515, 8.97016600786423, 9.94036810318215, 10.884935781826236, 11.850598334025122, 12.865850693147781, 13.889525111315816, 13.670303237504651, 5.083264300256319, 4.02238088857765, 2.981001645156361, 1.9622177433907648, 0.9658551241577813, 0.0, 0.9548332499129917, 1.9281910920764727, 2.9677404706576493, 3.9951012330662574, 5.059282318175458, 6.095343579397073, 7.09076618344362, 8.017967096497495, 9.075411016762907, 10.031916557034869, 11.040275219977536, 12.004537269594747, 12.986580514329326, 14.045292054338672, 5.910375220174441, 4.934384973232039, 3.9253184243526267, 2.889751932600597, 2.005500799266061, 1.0532666178514967, 1.9813145807691923, 2.912040798932092, 3.9048995357577256, 4.84994882753067, 5.897588067058867, 6.937273615892091, 7.88244233047206, 8.914152778742281, 9.873249930329456, 10.912972489093036, 11.947259361508525, 12.974552088845703, 13.957923570790356, 14.990427597251127, 6.803460221335107, 5.789321798214173, 4.838354471654099, 3.8924004991409253, 2.969545317291825, 1.9848684734419744, 2.9301302908066376, 3.8893145220238536, 4.861708413403942, 5.8270289732844684, 6.901101726269959, 7.945034689093832, 8.813796376464106, 9.745390484720994, 10.717993487898926, 11.783391004528756, 12.728601238442216, 13.785284575085427, 14.7864720596268, 15.849910539726602, 7.731226242506025, 6.757639341907418, 5.818354147694578, 4.890749325675822, 3.908053663171507, 2.9242380751075108, 3.8681381314130996, 4.837279994765909, 5.853063360733783, 6.849016375122073, 7.791787143189865, 8.770778104118973, 9.719052310906436, 10.7046895855843, 11.759545050921707, 12.774399047800962, 13.687017281592684, 14.695905323159298, 15.756864051244342, 16.743419040340548, 8.701178081047415, 7.806267252753731, 6.864088592845295, 5.913479457157099, 4.968671647418138, 3.922719471578497, 4.869208389072495, 5.838699639000386, 6.836524694548269, 7.7756207279676275, 8.75461997909318, 9.680651705993508, 10.700434379149451, 11.644250083817477, 12.584035211678914, 13.583620677609215, 14.593315148185512, 15.573059847221035, 16.607925883978016, 17.54909629517125, 9.628863714681591, 8.775988519994225, 7.864882488969691, 6.88276488199835, 5.946158449506488, 4.871864049901167, 5.82688092976167, 6.803959735424964, 7.7989301608132715, 8.828576247155455, 9.802345091526599, 10.683339083857653, 11.614260342985414, 12.640526506571309, 13.55625736674155, 14.559806774839247, 15.573423638301776, 16.590368787489183, 17.54156112264039, 18.609331790405275], [18.57823668560013, 17.5994807918563, 16.561619625814277, 15.606623076297979, 14.557219854621428, 13.584980886987243, 12.643360363293242, 11.62629181421801, 10.71130009349514, 9.839898717637595, 8.796835769865664, 7.753235105694688, 6.823255420473641, 5.812793860831642, 6.756150081481875, 7.765473076515236, 8.8172594098456, 9.74646358271697, 10.757612294692432, 11.567969190101113, 17.581194808786684, 17.49005300463618, 16.583421954969925, 15.597414061125338, 14.564075716734756, 13.783038315751208, 12.824084979728118, 12.562180801904523, 11.616879579560297, 10.656314251781174, 9.723884670740047, 8.791066536926786, 7.817612486075262, 6.8099851668294145, 7.803805622423317, 8.771576449187963, 9.835968951809232, 10.80204779227992, 11.678941452528099, 10.612212459164773, 16.72723819732166, 16.484979265148542, 15.517106030201273, 14.593166542981173, 13.594287461514465, 12.785020505772174, 11.828946420289954, 12.789952762621493, 12.598788202268851, 11.674120476726017, 10.750518393547615, 9.756474151569886, 8.844531198879933, 7.7949466378898435, 8.788063991158912, 9.710975037623141, 10.758389394450479, 11.709820505940886, 10.709977314740998, 9.71282897236209, 15.835866851090005, 15.422177920315539, 14.507180642334072, 13.57854771977422, 12.532714307231455, 11.786643950673309, 10.829752837733633, 11.741568067587213, 12.779860754182602, 12.652032139566048, 11.767779010721503, 10.71862068844518, 9.823370275998858, 8.776702316230299, 9.85088929617216, 10.765998730685952, 11.690724657087575, 10.699236592442963, 9.771864434552377, 8.793203652730186, 15.038962594136848, 14.41118659547887, 13.475491331205138, 12.63101229093399, 11.571858777479855, 10.794678111903899, 9.862815729353478, 10.792383988137594, 11.803050465478453, 12.565793763944473, 12.697344839798314, 11.671423802730532, 10.762528508439036, 9.731859596534113, 10.697923139485052, 11.679649159919238, 10.804050594825178, 9.857184554569733, 8.82113635537548, 7.890392035921614, 14.054886027347147, 13.517767341777617, 12.53574303942505, 11.654140215201492, 10.632452586412802, 9.805601135515685, 8.909902320260466, 9.885774453012997, 10.802160992816091, 11.628014545312007, 12.59042145993658, 12.70338824388568, 11.704666450437704, 10.692086846610573, 11.625360007452706, 11.079728615101772, 10.075844106847661, 9.07541933831594, 8.1319806294962, 7.065157403911825, 13.569307745566674, 12.529673537648888, 11.540543293054819, 10.677110376509312, 9.687713055835724, 8.860771971796849, 7.953633859324128, 8.92049246018991, 9.857609876229132, 10.701631540877564, 11.676125202586222, 12.517262934573669, 12.632450371260473, 11.687368940658944, 12.619229320703555, 11.883429644118817, 10.8537890084687, 9.8102140857271, 8.857868635097326, 7.903875307095754, 12.607238294740178, 11.57303555188178, 10.590168749834769, 9.674365868413732, 8.73694106363547, 7.797534911695537, 6.951107469496997, 7.927191458684107, 8.852103272468852, 9.716664172697847, 10.60865445838181, 11.57792871938349, 12.46062853572364, 12.717038580224377, 13.545318730875694, 12.733258983888444, 11.700275045657209, 10.697938341848854, 9.753830647768927, 8.745078539640957, 11.688098648030373, 10.63814849710213, 9.660124571685255, 8.689474168890527, 7.7026094160631775, 6.864936046947868, 5.939969370814608, 6.910214491870236, 7.7896668891709, 8.776641526520331, 9.629552767199563, 10.56504361923807, 11.499063241635493, 12.47629410269481, 13.50250814705377, 13.584159352591776, 12.630708470252873, 11.66141281704172, 10.704749017342602, 9.670930553599067, 10.619133950510182, 9.72979258127463, 8.715545435694846, 7.734392353136764, 6.685709256183234, 5.817527324809335, 4.967862335376663, 5.915408883125353, 6.806370034786355, 7.748435738326406, 8.696351151034914, 9.60476845655953, 10.597091593040904, 11.533190694650571, 12.508286903617181, 13.45752866024964, 13.581226875028568, 12.628293053796682, 11.648757955311567, 10.66357619738563, 9.674996952150133, 8.74792697963932, 7.7152884759885385, 6.779531026531653, 5.750418710298254, 4.816282761120318, 3.903428450652236, 4.871294203726196, 5.845515141383353, 6.775467640761501, 7.67344539086413, 8.59729680450933, 9.581328090941069, 10.547092383925056, 11.486464749116582, 12.480780334382898, 13.516445049216184, 13.63548062424475, 12.645586654453602, 11.590835636112727, 8.718946182969505, 7.753301205751325, 6.787571972831047, 5.824084017983423, 4.819077458245407, 3.888784308715079, 2.907403318676113, 3.9217459356516473, 4.880648456831697, 5.819009654551664, 6.727495318410267, 7.6084859917770435, 8.583620959058624, 9.605387066061228, 10.547012566995415, 11.59066073004683, 12.522575248303138, 13.49548045005107, 13.47667643667314, 12.55014885816177, 7.797455875356845, 6.827141008993188, 5.800144400969399, 4.852268156872386, 3.8259326748783864, 2.8817357888306163, 1.907541475864187, 2.867090070384926, 3.8234815963688837, 4.78439087781506, 5.736936964818454, 6.672407094674065, 7.616674232088172, 8.640794655819722, 9.666534660423471, 10.615570385530676, 11.573589258769406, 12.515645760926857, 13.51520315168652, 13.577302450249906, 6.881810901201654, 5.820575053667584, 4.874404464051725, 3.876841639389548, 2.9224691800562237, 1.95921357793779, 0.969390580967947, 1.9124566780326608, 2.904850325801433, 3.9383851821007583, 4.868236195317858, 5.895198910256599, 6.94699075949966, 8.015332757951239, 8.98553485326916, 9.930102531913246, 10.895765084112131, 11.91101744323479, 12.934691861402825, 13.939186643099108, 6.038097550169311, 4.977214138490641, 3.9358348950693522, 2.9170509933037563, 1.920688374070773, 0.9548332499129917, 0.0, 0.9733578421634811, 2.012907220744658, 3.040267983153266, 4.104449068262467, 5.140510329484082, 6.135932933530628, 7.063133846584503, 8.120577766849914, 9.077083307121876, 10.085441970064544, 11.049704019681755, 12.031747264416333, 13.09045880442568, 6.865208470087433, 5.889218223145031, 4.880151674265618, 3.8445851825135886, 2.9603340491790524, 2.0080998677644883, 1.0264813308562006, 1.9572075490191003, 2.950066285844734, 3.8951155776176782, 4.942754817145874, 5.982440365979099, 6.927609080559067, 7.959319528829289, 8.918416680416463, 9.958139239180044, 10.992426111595533, 12.019718838932711, 13.003090320877364, 14.035594347338135, 7.758293471248098, 6.744155048127165, 5.79318772156709, 4.847233749053917, 3.9243785672048164, 2.939701723354966, 1.975297040893646, 2.934481272110862, 3.906875163490951, 4.872195723371476, 5.946268476356967, 6.99020143918084, 7.858963126551114, 8.790557234808002, 9.763160237985934, 10.828557754615764, 11.773767988529224, 12.830451325172435, 13.831638809713807, 14.89507728981361, 8.686059492419016, 7.71247259182041, 6.773187397607569, 5.845582575588813, 4.862886913084498, 3.8790713250205022, 2.913304881500108, 3.8824467448529174, 4.898230110820791, 5.89418312520908, 6.836953893276872, 7.815944854205981, 8.764219060993444, 9.749856335671307, 10.804711801008715, 11.81956579788797, 12.732184031679692, 13.741072073246306, 14.80203080133135, 15.788585790427556, 9.656011330960405, 8.761100502666723, 7.818921842758288, 6.868312707070091, 5.92350489733113, 4.877552721491488, 3.914375139159503, 4.883866389087395, 5.881691444635278, 6.820787478054635, 7.799786729180187, 8.725818456080514, 9.745601129236457, 10.689416833904483, 11.62920196176592, 12.62878742769622, 13.638481898272518, 14.618226597308041, 15.653092634065022, 16.594263045258256, 10.583696964594582, 9.730821769907218, 8.819715738882682, 7.837598131911341, 6.900991699419479, 5.826697299814159, 4.872047679848679, 5.849126485511973, 6.84409691090028, 7.873742997242464, 8.847511841613604, 9.72850583394466, 10.65942709307242, 11.685693256658315, 12.601424116828555, 13.604973524926253, 14.618590388388782, 15.635535537576189, 16.586727872727394, 17.65449854049228], [17.60487884343665, 16.62612294969282, 15.5882617836508, 14.6332652341345, 13.58386201245795, 12.611623044823764, 11.670002521129762, 10.65293397205453, 9.73794225133166, 8.886558158330494, 7.958386837175266, 6.989244283375147, 6.0592645981541, 6.786151702995123, 7.7295079236453565, 8.738830918678717, 9.79061725200908, 10.71982142488045, 11.730970136855914, 12.541327032264594, 16.607836966623207, 17.552073705654365, 16.595738394518506, 15.605746423276784, 14.606987311858644, 13.585452188393813, 12.646204558419122, 11.611696912653645, 10.66639569030942, 9.892323429461634, 8.959893848420506, 8.027075714607246, 7.053621663755721, 7.783343008992896, 8.777163464586797, 9.744934291351443, 10.809326793972712, 11.7754056344434, 12.65229929469158, 11.585570301328255, 15.75388035515818, 16.69960836098513, 16.490463872364753, 15.566524385144653, 14.567645303677946, 13.758378347935654, 12.802304262453434, 12.18438760411369, 11.648304313017974, 10.910129654406475, 9.986527571228073, 8.992483329250346, 8.082882308648744, 8.768304480053324, 9.761421833322393, 10.684332879786622, 11.731747236613959, 12.683178348104368, 11.68333515690448, 10.686186814525572, 14.862509008926525, 15.831592344077636, 15.480538484497552, 14.5519055619377, 13.506072149394935, 12.760001792836789, 11.803110679897113, 11.13600290907941, 11.917810641807606, 11.888041317246506, 11.003788188401963, 9.95462986612564, 9.06214656738757, 9.75006015839378, 10.82424713833564, 11.739356572849433, 12.664082499251057, 11.672594434606445, 10.74522227671586, 9.766561494893669, 14.065604751973368, 15.035857774123157, 14.448849173368618, 13.60437013309747, 12.545216619643336, 11.768035954067381, 10.836173571516959, 10.186818829629791, 10.908447946265296, 11.630917840389944, 11.933354017478774, 10.907432980410992, 10.134766686996441, 10.705217438697593, 11.671280981648533, 12.653007002082719, 11.777408436988658, 10.830542396733213, 9.79449419753896, 8.863749878085095, 13.081528185183666, 14.095368515547548, 13.50910088158853, 12.627498057364972, 11.605810428576282, 10.778958977679167, 9.883260162423946, 9.155795545283228, 9.867285069261563, 10.69313862175748, 11.655545536382053, 11.93939742156614, 11.083766504794623, 11.665444688774054, 12.598717849616186, 12.053086457265252, 11.049201949011142, 10.048777180479421, 9.10533847165968, 8.038515246075306, 14.032803403208595, 13.503031379812368, 12.5139011352183, 11.650468218672792, 10.661070897999204, 9.834129813960331, 8.926991701487609, 8.157230793095302, 8.922733952674603, 9.766755617323037, 10.741249279031695, 11.58238701101914, 12.03037304883572, 12.660726782822424, 13.592587162867035, 12.856787486282297, 11.82714685063218, 10.78357192789058, 9.831226477260806, 8.877233149259235, 13.580596136903658, 12.54639339404526, 11.563526591998249, 10.647723710577212, 9.71029890579895, 8.770892753859018, 7.924465311660478, 7.123276931377129, 7.917227348914324, 8.78178824914332, 9.673778534827283, 10.643052795828961, 11.52575261216911, 12.485608342413814, 13.446622302658733, 13.706616826051928, 12.673632887820691, 11.671296184012336, 10.72718848993241, 9.71843638180444, 12.661456490193856, 11.61150633926561, 10.633482413848736, 9.662832011054007, 8.675967258226658, 7.838293889111348, 6.913327212978089, 6.072636371157383, 6.854790965616372, 7.841765602965803, 8.694676843645036, 9.630167695683543, 10.564187318080966, 11.541418179140283, 12.567632223499244, 13.479596968062456, 13.604066312416357, 12.634770659205204, 11.678106859506086, 10.644288395762551, 11.592491792673666, 10.70315042343811, 9.688903277858326, 8.707750195300244, 7.659067098346714, 6.790885166972815, 5.941220177540144, 5.068159279214805, 5.8714941112318275, 6.813559814771878, 7.761475227480387, 8.669892533005001, 9.662215669486377, 10.598314771096044, 11.573410980062654, 12.522652736695115, 13.530714288780807, 13.601650895960166, 12.62211579747505, 11.636934039549114, 10.648354794313617, 9.7212848218028, 8.688646318152019, 7.752888868695133, 6.723776552461734, 5.789640603283798, 4.876786292815717, 4.024044599815648, 4.910639217828825, 5.840591717206974, 6.738569467309602, 7.6624208809548024, 8.646452167386542, 9.61221646037053, 10.551588825562055, 11.54590441082837, 12.581569125661655, 13.530938954500987, 13.618944496617086, 12.564193478276211, 9.692304025132989, 8.726659047914808, 7.760929814994528, 6.797441860146903, 5.792435300408887, 4.86214215087856, 3.8807611608395938, 3.050970042749233, 3.9457725332771685, 4.884133730997137, 5.792619394855739, 6.673610068222516, 7.648745035504097, 8.6705111425067, 9.612136643440886, 10.655784806492301, 11.587699324748609, 12.560604526496542, 13.62862073743967, 13.523506700325253, 8.770813717520328, 7.80049885115667, 6.773502243132881, 5.825625999035867, 4.799290517041867, 3.855093630994097, 2.880899318027668, 1.981983260833624, 2.8886056728143554, 3.849514954260532, 4.802061041263926, 5.737531171119537, 6.6817983085336445, 7.705918732265193, 8.731658736868942, 9.680694461976147, 10.638713335214877, 11.580769837372328, 12.580327228131992, 13.512524902723653, 7.855168743365136, 6.793932895831065, 5.847762306215206, 4.850199481553029, 3.895827022219705, 2.932571420101271, 1.942748423131428, 0.9390988358691797, 1.931492483637952, 2.965027339937277, 3.894878353154377, 4.9218410680931175, 5.973632917336179, 7.041974915787757, 8.012177011105678, 8.956744689749762, 9.922407241948648, 10.937659601071307, 11.961334019239342, 12.965828800935624, 7.011455392332792, 5.950571980654122, 4.909192737232834, 3.8904088354672375, 2.894046216234254, 1.9281910920764727, 0.9733578421634811, 0.0, 1.0395493785811767, 2.0669101409897848, 3.1310912260989854, 4.1671524873206005, 5.162575091367147, 6.089776004421021, 7.147219924686433, 8.103725464958396, 9.112084127901063, 10.076346177518275, 11.058389422252853, 12.1171009622622, 7.838566312250913, 6.862576065308511, 5.853509516429099, 4.81794302467707, 3.9336918913425336, 2.9814577099279695, 1.9998391730196818, 0.9838497068556192, 1.976708443681253, 2.921757735454197, 3.969396974982393, 5.009082523815618, 5.954251238395586, 6.985961686665807, 7.945058838252983, 8.984781397016564, 10.019068269432053, 11.04636099676923, 12.029732478713884, 13.062236505174655, 8.73165131341158, 7.717512890290646, 6.766545563730571, 5.820591591217398, 4.897736409368298, 3.9130595655184472, 2.9486548830571273, 2.042431400358066, 3.008502271590917, 3.8988378812079953, 4.972910634193486, 6.016843597017359, 6.8856052843876325, 7.817199392644522, 8.789802395822454, 9.855199912452283, 10.800410146365744, 11.857093483008954, 12.858280967550327, 13.92171944765013, 9.659417334582498, 8.685830433983892, 7.74654523977105, 6.8189404177522945, 5.8362447552479795, 4.852429167183984, 3.8866627236635893, 3.0256302854506565, 4.04141365141853, 4.9208252830456, 5.863596051113392, 6.8425870120425, 7.790861218829963, 8.776498493507825, 9.831353958845233, 10.84620795572449, 11.758826189516212, 12.767714231082826, 13.82867295916787, 14.815227948264075, 10.629369173123887, 9.734458344830205, 8.792279684921768, 7.841670549233572, 6.896862739494611, 5.8509105636549705, 4.887732981322984, 4.0953982037222545, 5.039271294768274, 5.847429635891155, 6.826428887016706, 7.752460613917035, 8.772243287072978, 9.716058991741004, 10.655844119602442, 11.655429585532742, 12.66512405610904, 13.644868755144563, 14.679734791901543, 15.620905203094779, 11.557054806758064, 10.7041796120707, 9.793073581046164, 8.810955974074822, 7.874349541582961, 6.800055141977641, 5.84540552201216, 5.060658300146833, 6.0525265855384145, 6.9191269162717575, 7.874153999450125, 8.755147991781179, 9.68606925090894, 10.712335414494834, 11.628066274665077, 12.631615682762774, 13.645232546225303, 14.662177695412709, 15.613370030563914, 16.6811406983288], [16.57172937273158, 15.592973478987748, 14.555112312945726, 13.600115763429425, 12.550712541752874, 11.57847357411869, 10.636853050424689, 9.619784501349457, 8.704792780626587, 7.853408687625421, 6.925237366470192, 5.970691063202299, 6.900670748423345, 7.744427743421144, 8.687783964071379, 9.69710695910474, 10.748893292435103, 11.678097465306474, 12.69030842034547, 13.500665315754151, 15.574687495918132, 16.518924234949292, 15.562588923813431, 14.57259695257171, 13.57383784115357, 12.552302717688738, 11.613055087714049, 10.578547441948572, 9.633246219604347, 8.873770209288786, 7.9413406282476595, 7.0085224944343985, 7.895027814024966, 8.741619049418917, 9.73543950501282, 10.703210331777466, 11.767602834398735, 12.733681674869423, 13.611637578181137, 12.544908584817811, 14.720730884453108, 15.666458890280058, 16.617403662875827, 15.586912605286047, 14.531977653747564, 13.550320527667772, 12.568793603820254, 11.5933651125939, 10.6151548423129, 9.891576434233627, 8.967974351055227, 7.973930109077497, 8.924288458917989, 9.726580520479345, 10.719697873748414, 11.642608920212645, 12.690023277039982, 13.642516631593924, 12.642673440394036, 11.645525098015128, 13.829359538221452, 14.798442873372563, 15.842748310177472, 15.481441031120495, 14.43560761857773, 13.66459060056038, 12.707699487620705, 11.8199692497176, 10.923699635699016, 10.869488097073658, 9.985234968229115, 8.936076645952792, 9.903552717656815, 10.7083361988198, 11.78252317876166, 12.697632613275456, 13.627294371916353, 12.712143813187621, 11.784771655297035, 10.806110873474845, 13.02605537339219, 13.996308395541979, 14.93200365981571, 14.533905602280266, 13.474752088826131, 12.690574600822949, 11.74076237924055, 10.87078517026798, 9.914336940156707, 10.636806834281355, 10.914800797305926, 9.888879760238144, 10.916277390483597, 11.663493479123614, 12.629557022074554, 13.61128304250874, 12.816957815569834, 11.870091775314389, 10.834043576120136, 9.903299256666271, 12.041978806602488, 13.05581913696637, 14.037843439318937, 13.557033526547768, 12.535345897759077, 11.701497624434735, 10.787848970147538, 9.839761885921417, 8.873174063152973, 9.699027615648891, 10.661434530273464, 10.920844201393292, 11.865277208281778, 12.623720729200075, 13.556993890042207, 13.092635835846426, 12.088751327592318, 11.088326559060597, 10.144887850240856, 9.078064624656482, 12.9971510875443, 14.036785295462085, 13.443436604401095, 12.580003687855587, 11.590606367182, 10.756668460715899, 9.8315805092112, 8.923661196646478, 7.928622946566015, 8.772644611214448, 9.747138272923106, 10.588276004910554, 11.511845439540716, 12.456926870142246, 13.378600706722287, 13.896336864863473, 12.866696229213357, 11.823121306471757, 10.870775855841982, 9.916782527840411, 13.592333387277536, 13.475928863228056, 12.493062061181044, 11.577259179760008, 10.639834374981746, 9.700428223041813, 8.82905411938407, 7.898311459865798, 6.923116342805734, 7.78767724303473, 8.679667528718694, 9.648941789720375, 10.531641606060525, 11.491497336305228, 12.452511296550147, 13.503627550444108, 13.628500089675052, 12.626163385866697, 11.68205569178677, 10.6733035836588, 13.613755233309313, 12.541041808448405, 11.56301788303153, 10.592367480236803, 9.605502727409453, 8.767829358294144, 7.817916020701681, 6.847670899646053, 5.860679959507783, 6.847654596857214, 7.700565837536447, 8.636056689574955, 9.570076311972379, 10.547307173031696, 11.573521217390654, 12.485485961953867, 13.438936844292769, 13.589637861059565, 12.632974061360446, 11.599155597616912, 12.547358994528027, 11.632685892620906, 10.618438747041122, 9.63728566448304, 8.58860256752951, 7.720420636155611, 6.870755646722939, 5.934660235931209, 4.877383105123238, 5.819448808663289, 6.767364221371798, 7.6757815268964125, 8.668104663377788, 9.604203764987455, 10.579299973954065, 11.528541730586525, 12.536603282672218, 13.489537103904103, 13.576982999329411, 12.591801241403475, 11.603221996167978, 10.676152023657163, 9.643513520006382, 8.68242433787793, 7.653312021644529, 6.719176072466594, 5.806321761998512, 4.890545556532052, 3.9165282117202356, 4.846480711098384, 5.744458461201012, 6.668309874846213, 7.652341161277953, 8.61810545426194, 9.557477819453466, 10.551793404719781, 11.587458119553066, 12.536827948392398, 13.526721918183545, 13.519060680130572, 10.64717122698735, 9.681526249769169, 8.71579701684889, 7.726977329329698, 6.721970769591683, 5.791677620061355, 4.810296630022389, 3.9174709994656367, 2.9516615271685795, 3.8900227248885475, 4.79850838874715, 5.679499062113926, 6.654634029395508, 7.676400136398111, 8.618025637332297, 9.661673800383712, 10.59358831864002, 11.566493520387953, 12.63450973133108, 13.5455674887032, 9.725680919374689, 8.75536605301103, 7.728369444987242, 6.780493200890229, 5.728825986224662, 4.784629100176892, 3.8104347872104634, 2.850886192689724, 1.8944946667057665, 2.855403948151943, 3.807950035155337, 4.7434201650109475, 5.687687302425055, 6.711807726156604, 7.737547730760353, 8.686583455867558, 9.644602329106288, 10.586658831263739, 11.586216222023403, 12.518413896615064, 8.894718121946312, 7.833482274412242, 6.887311684796384, 5.8897488601342065, 4.9261430044227, 3.9309221252738116, 2.9410991283039687, 1.9297751252981352, 0.937381477529363, 1.9709163338286881, 2.9007673470457878, 3.927730061984528, 4.9795219112275895, 6.047863909679168, 7.018066004997089, 7.962633683641174, 8.92829623584006, 9.943548594962719, 10.967223013130754, 11.971717794827036, 8.051004770913968, 6.990121359235299, 5.94874211581401, 4.929958214048415, 3.933595594815431, 2.96774047065765, 2.012907220744658, 1.0395493785811767, 0.0, 1.027360762408608, 2.091541847517809, 3.1276031087394243, 4.123025712785971, 5.050226625839845, 6.107670546105257, 7.064176086377219, 8.072534749319885, 9.036796798937097, 10.018840043671675, 11.077551583681021, 8.87811569083209, 7.9021254438896875, 6.893058895010276, 5.857492403258247, 4.973241269923711, 4.021007088509147, 2.9831967466596083, 1.9364177098018134, 0.9435589729761795, 1.8886082647491236, 2.93624750427732, 3.975933053110545, 4.921101767690513, 5.952812215960734, 6.91190936754791, 7.9516319263114905, 8.98591879872698, 10.013211526064158, 10.990183100132706, 12.022687126593476, 9.771200691992757, 8.757062268871822, 7.8060949423117485, 6.860140969798575, 5.935933448769356, 4.9512566049195055, 3.906930923483148, 2.947746692265932, 1.9753528008858432, 2.865688410502922, 3.939761163488413, 4.983694126312286, 5.8524558136825595, 6.784049921939449, 7.756652925117381, 8.82205044174721, 9.76726067566067, 10.823944012303881, 11.825131496845254, 12.888569976945057, 10.618755618072054, 9.645168717473448, 8.705883523260606, 7.77827870124185, 6.795583038737535, 5.811767450673539, 4.84493876408961, 3.9309455773585227, 3.0085946080256694, 3.887675812340526, 4.830446580408318, 5.809437541337427, 6.75771174812489, 7.743349022802753, 8.798204488140161, 9.813058485019416, 10.725676718811139, 11.734564760377753, 12.795523488462797, 13.782078477559002, 11.588707456613443, 10.693796628319761, 9.751617968411324, 8.801008832723127, 7.856201022984166, 6.810248847144526, 5.846009021749006, 5.000713495630121, 4.006452251375413, 4.814280165186081, 5.793279416311632, 6.719311143211961, 7.7390938163679035, 8.68290952103593, 9.622694648897367, 10.622280114827667, 11.631974585403965, 12.611719284439488, 13.646585321196468, 14.587755732389704, 12.51639309024762, 11.663517895560256, 10.75241186453572, 9.770294257564379, 8.833687825072516, 7.759393425467196, 6.8036815624381815, 5.9659735920546995, 5.019707542145554, 5.885977445566684, 6.841004528745051, 7.721998521076105, 8.652919780203867, 9.679185943789761, 10.594916803960002, 11.5984662120577, 12.612083075520228, 13.629028224707636, 14.58022055985884, 15.647991227623727], [15.729085844246795, 14.750329950502966, 13.712468784460945, 12.757472234944645, 11.708069013268094, 10.735830045633909, 9.819149104010028, 8.802080554934797, 7.8870888342119265, 7.035704741210762, 6.107533420055533, 6.995231553214177, 7.925211238435224, 8.77178850582975, 9.715144726479984, 10.724467721513346, 11.776254054843708, 12.705458227715079, 13.717669182754078, 14.528026078162757, 14.732043967433352, 15.676280706464512, 14.71994539532865, 13.72995342408693, 12.731194312668789, 11.709659189203958, 10.795351141299388, 9.760843495533912, 8.815542273189687, 8.07475559330954, 7.176892349408311, 8.033062984446277, 8.919568304036844, 9.768979811827524, 10.762800267421426, 11.730571094186072, 12.79496359680734, 13.761042437278029, 14.638998340589744, 13.572269347226419, 13.837245158899224, 14.782973164726174, 15.774760134391048, 14.744269076801267, 13.689334125262784, 12.707676999182992, 11.751089657405593, 10.77566116617924, 9.79745089589824, 9.092561818254381, 8.20352607221588, 8.998470599089377, 9.948828948929865, 10.753941282887952, 11.747058636157021, 12.66996968262125, 13.717384039448588, 14.669877394002532, 13.670034202802643, 12.672885860423735, 12.9125655122719, 13.881648847423012, 14.92595428422792, 15.752595000752228, 14.699226686496594, 13.706053554281857, 12.750283239961915, 11.82404586121352, 10.848976424083919, 10.070473481094412, 9.228995081374135, 9.96061713596467, 10.928093207668692, 11.73569696122841, 12.80988394117027, 13.724993375684061, 14.654655134324958, 13.739504575596229, 12.812132417705643, 11.833471635883452, 11.99869461098358, 12.96894763313337, 13.9046428974071, 14.933253916155707, 14.50211285123474, 13.717935363231557, 12.747037223777822, 11.849274966278841, 10.892826736167567, 9.846716128893874, 10.158560910450946, 10.913420250250022, 11.940817880495477, 12.690854241532223, 13.656917784483163, 14.638643804917349, 13.844318577978443, 12.897452537722998, 11.861404338528745, 10.93066001907488, 11.01461804419388, 12.028458374557761, 13.010482676910328, 13.966376317222418, 13.562706660167686, 12.728858386843344, 11.79412381468481, 10.818251681932278, 9.851663859163834, 8.90893691026141, 9.871343824885983, 10.80624185853063, 11.653262248697125, 12.647019229305927, 13.567280285088447, 14.119996598255035, 13.116112090000927, 12.115687321469206, 11.172248612649465, 10.105425387065091, 11.96979032513569, 13.009424533053476, 14.00568242328056, 13.607364450264196, 12.617967129590609, 11.784029223124508, 10.858941271619809, 9.939276350927816, 8.944238100847352, 7.9825539058269674, 8.94194853803842, 9.783086270025866, 10.706655704656027, 11.651737135257557, 12.573410971837598, 13.538625514939646, 13.894056991621966, 12.850482068880366, 11.898136618250591, 10.94414329024902, 12.78714365239285, 13.821346395251247, 13.520422823589653, 12.604619942168616, 11.667195137390355, 10.72778898545042, 9.856414881792679, 8.925672222274407, 7.938731497087073, 6.99758653764725, 7.874477793834007, 8.843752054835686, 9.726451871175836, 10.68630760142054, 11.647321561665459, 12.69843781555942, 13.610839214418263, 13.653524148275306, 12.70941645419538, 11.70066434606741, 13.70690345299298, 13.568402570857014, 12.59037864544014, 11.619728242645412, 10.632863489818062, 9.79519012070275, 8.84527678311029, 7.875031662054661, 6.888040721916391, 6.0575638914697345, 6.895376102651761, 7.8308669546902685, 8.764886577087692, 9.742117438147009, 10.768331482505968, 11.680296227069178, 12.63374710940808, 13.603042762619236, 13.660334823769055, 12.626516360025521, 13.574719756936636, 12.660046655029515, 11.64579950944973, 10.664646426891649, 9.615963329938118, 8.747781398564218, 7.898116409131546, 6.962020998339816, 5.904743867531846, 5.0293581032758095, 5.962174486487111, 6.870591792011726, 7.862914928493101, 8.799014030102768, 9.774110239069378, 10.723351995701837, 11.731413547787533, 12.684347369019418, 13.693255886730741, 13.619162003812084, 12.630582758576587, 11.703512786065772, 10.67087428241499, 9.709785100286538, 8.680672784053138, 7.746536834875202, 6.83368252440712, 5.917906318940659, 4.943888974128844, 4.0412909762136975, 4.9392687263163255, 5.863120139961526, 6.847151426393266, 7.812915719377254, 8.752288084568779, 9.746603669835094, 10.782268384668381, 11.731638213507713, 12.72153218329886, 13.699690975867556, 11.674531989395959, 10.708887012177778, 9.7431577792575, 8.754338091738306, 7.749331532000291, 6.819038382469963, 5.837657392430997, 4.944831761874244, 3.9790222895771876, 3.0848329900038607, 3.9933186538624637, 4.8743093272292395, 5.849444294510821, 6.871210401513424, 7.812835902447611, 8.856484065499027, 9.788398583755335, 10.761303785503268, 11.829319996446394, 12.740377753818514, 10.753041681783298, 9.78272681541964, 8.755730207395851, 7.807853963298837, 6.7561867486332705, 5.8119898625855, 4.837795549619071, 3.8782469550983323, 2.9218554291143746, 2.0502142132672563, 3.00276030027065, 3.9382304301262607, 4.882497567540368, 5.906617991271917, 6.932357995875666, 7.881393720982871, 8.839412594221601, 9.781469096379052, 10.781026487138716, 11.713224161730377, 9.92207888435492, 8.860843036820851, 7.914672447204992, 6.917109622542815, 5.953503766831307, 4.95828288768242, 3.9684598907125768, 2.9571358877067433, 1.964742239937971, 1.0747494639330615, 2.004600477150161, 3.0315631920889015, 4.083355041331963, 5.022915729651151, 5.993117824969072, 6.9376855036131575, 7.903348055812043, 8.918600414934703, 9.942274833102738, 10.94676961479902, 9.078365533322577, 8.017482121643908, 6.976102878222619, 5.957318976457023, 4.960956357224039, 3.995101233066258, 3.040267983153266, 2.0669101409897848, 1.027360762408608, 0.0, 1.0641810851092008, 2.100242346330816, 3.095664950377363, 4.022865863431237, 5.080309783696649, 6.036815323968611, 7.045173986911277, 8.009436036528488, 8.991479281263066, 10.050190821272412, 9.905476453240698, 8.929486206298296, 7.9204196574188845, 6.884853165666855, 6.000602032332319, 5.048367850917755, 4.010557509068216, 2.9637784722104215, 1.9709197353847876, 1.0709043183344642, 2.1118734067816822, 3.1276520797955936, 4.03761604213663, 5.069326490406851, 6.0220567616031975, 7.061779320366778, 8.059745619847357, 9.079842899216429, 9.962822337724097, 10.995326364184868, 10.798561454401364, 9.78442303128043, 8.833455704720356, 7.887501732207183, 6.963294211177963, 5.978617367328113, 4.934291685891756, 3.9751074546745397, 3.002713563294451, 2.0479844640882625, 3.1220572170737535, 4.165990179897626, 4.9689700881286765, 5.900564196385566, 6.873167199563498, 7.938564716193327, 8.883774950106787, 9.940458286749998, 10.94164577129137, 11.971775950995506, 11.646116380480661, 10.672529479882055, 9.733244285669214, 8.805639463650458, 7.822943801146142, 6.839128213082146, 5.872299526498217, 4.95830633976713, 4.035955370434277, 3.069971865925867, 4.012742633993659, 4.991733594922767, 5.904018400106111, 6.889655674783974, 7.9412064472549275, 8.929572759465534, 9.842190993257255, 10.851079034823869, 11.912037762908913, 12.898592752005118, 12.61606821902205, 11.721157390728369, 10.778978730819931, 9.828369595131734, 8.883561785392773, 7.837609609553133, 6.873369784157613, 6.028074258038728, 5.030992741387292, 3.9965762187714216, 4.975575469896973, 5.901607196797301, 6.896450287883122, 7.840265992551148, 8.780051120412587, 9.779636586342887, 10.789331056919185, 11.769075755954708, 12.803941792711688, 13.745112203904924, 13.543753852656227, 12.690878657968863, 11.779772626944325, 10.797655019972984, 9.861048587481122, 8.786754187875802, 7.831042324846789, 6.993334354463307, 6.044248032157432, 5.068273499152024, 6.023300582330392, 6.904294574661446, 7.835215833789206, 8.847238731384993, 9.752273275475222, 10.75582268357292, 11.769439547035448, 12.786384696222854, 13.737577031374059, 14.805347699138945], [14.664904759137594, 13.686148865393765, 12.648287699351744, 11.693291149835444, 10.643887928158893, 9.671648960524708, 8.837131310134033, 7.846536208005832, 6.951634222865239, 6.100250129864074, 7.023957718855968, 7.911655852014613, 8.841635537235659, 9.813152067335642, 10.756508287985875, 11.765831283019237, 12.8176176163496, 13.74682178922097, 14.765290161009379, 15.57814165786623, 13.667862882324151, 14.612099621355311, 13.65576431021945, 12.665772338977728, 11.667013227559588, 10.645478104094757, 9.8598965299527, 8.825388884187225, 7.880087661842999, 7.139300981962852, 8.071730563003978, 8.949487283246713, 9.83599260283728, 10.810343373333415, 11.804163828927317, 12.771934655691963, 13.836327158313232, 14.80240599878392, 15.689113920293217, 14.622384926929891, 12.773064073790023, 13.718792079616973, 14.710579049281847, 13.680087991692066, 12.625153040153583, 11.64349591407379, 10.815635046058906, 9.840206554832553, 8.861996284551552, 8.157107206907694, 9.091475516358575, 9.914894897889813, 10.865253247730301, 11.795304844393844, 12.788422197662912, 13.711333244127141, 14.758747600954479, 15.719992973706004, 14.720149782506116, 13.723001440127208, 11.848384427162701, 12.817467762313813, 13.861773199118721, 14.688413915643027, 13.635045601387393, 12.641872469172656, 11.814828628615228, 10.888591249866833, 9.91352181273723, 9.135018869747725, 10.11694452551683, 10.877041434765106, 11.844517506469128, 12.777060522734299, 13.85124750267616, 14.766356937189952, 15.69601869583085, 14.80368566070543, 13.876313502814844, 12.897652720992653, 10.93451352587438, 11.904766548024169, 12.8404618122979, 13.869072831046505, 14.595901131138993, 13.681847453556317, 12.767343588100568, 11.837775329316452, 10.92288450827954, 10.149513479782215, 9.956425279400527, 10.826801432641227, 11.555437384197706, 12.560421797084787, 13.4478924707585, 14.429618491192686, 14.908499663087643, 13.961633622832197, 12.925585423637944, 11.99484110418408, 9.95043695908468, 10.964277289448562, 11.94630159180113, 12.90219523211322, 13.92388286090191, 13.522168161769159, 12.540239909436838, 11.564367776684307, 10.597779953915863, 9.655053005013439, 8.957477723119535, 9.79483699148608, 10.606437566399524, 11.600194547008327, 12.520455602790847, 13.446126789206025, 14.180293175110126, 13.179868406578406, 12.236429697758664, 11.16960647217429, 10.905609240026491, 11.945243447944277, 12.941501338171362, 13.891200385429544, 13.505581758625778, 12.577338998050323, 11.652251046545624, 10.685392445679842, 9.69035419559938, 8.728670000578996, 7.8951238557408185, 8.736261587728265, 9.659831022358427, 10.604912452959956, 11.526586289539997, 12.491800832642046, 13.521441468292162, 13.823587598282396, 12.871242147652621, 11.91724881965105, 11.739771767611478, 12.773974510469873, 13.756841312516885, 13.492234571203786, 12.554809766425524, 11.610784555821777, 10.674693951885786, 9.698609962698676, 8.6848475918391, 7.743702632399278, 6.8276531115364065, 7.796927372538086, 8.679627188878236, 9.639482919122939, 10.600496879367858, 11.651613133261819, 12.564014532120666, 13.523449607978945, 13.597031083230549, 12.588278975102579, 12.659531568211609, 13.732244993072516, 13.47799327447531, 12.507342871680581, 11.520478118853232, 10.682804749737922, 9.710303285830415, 8.740058164774787, 7.753067224636516, 6.803679986221762, 5.848551420354159, 6.784042272392667, 7.7180618947900905, 8.695292755849406, 9.721506800208367, 10.63347154477158, 11.586922427110483, 12.556218080321639, 13.512881880020757, 13.51413098906069, 13.724058116086814, 13.547661284064684, 12.5334141384849, 11.552261055926818, 10.503577958973288, 9.63539602759939, 8.785731038166718, 7.833841001023032, 6.769770370251972, 5.827704666711921, 4.91534980418951, 5.823767109714126, 6.8160902461955, 7.752189347805167, 8.727285556771777, 9.67652731340424, 10.68458886548993, 11.637522686721816, 12.646431204433139, 13.579578529813281, 13.518197387611757, 12.591127415100942, 11.55848891145016, 10.597399729321708, 9.568287413088308, 8.634151463910372, 7.721297153442291, 6.805520947975829, 5.8315036031640135, 4.839637539649809, 3.8924440440187245, 4.8162954576639265, 5.800326744095665, 6.766091037079653, 7.705463402271179, 8.699778987537496, 9.735443702370778, 10.68481353121011, 11.674707501001258, 12.652319091086184, 12.562146618431129, 11.596501641212948, 10.63077240829267, 9.641952720773478, 8.636946161035462, 7.706653011505134, 6.725272021466168, 5.832446390909414, 4.8666369186123575, 3.8831795534399727, 2.9464939715648626, 3.8274846449316393, 4.8026196122132205, 5.824385719215823, 6.76601122015001, 7.809659383201425, 8.741573901457732, 9.714479103205665, 10.781948111665022, 11.693005869037142, 11.640656310818468, 10.67034144445481, 9.643344836431021, 8.695468592334008, 7.643801377668441, 6.699604491620671, 5.725410178654242, 4.765861584133503, 3.809470058149545, 2.8485607767033683, 1.9559356179730492, 2.89140574782866, 3.8356728852427677, 4.859793308974316, 5.885533313578065, 6.83456903868527, 7.792040709440229, 8.73409721159768, 9.733654602357344, 10.665852276949005, 10.895184413756951, 9.833948566222881, 8.887777976607023, 7.890215151944846, 6.895392410561836, 5.900171531412948, 4.910348534443105, 3.8990245314372713, 2.906630883668499, 1.8730960273691737, 0.9432450141520738, 1.970207729090814, 3.021999578333875, 3.9587346445419507, 4.928936739859871, 5.873504418503956, 6.839166970702842, 7.854419329825502, 8.878093747993537, 9.88258852968982, 10.142546618431776, 9.081663206753108, 8.040283963331818, 7.021500061566223, 6.025137442333239, 5.059282318175458, 4.104449068262467, 3.131091226098986, 2.091541847517809, 1.0641810851092008, 0.0, 1.0360612612216153, 2.0314838652681617, 2.958684778322036, 4.016128698587448, 4.97263423885941, 5.980992901802076, 6.945254951419288, 7.927298196153867, 8.986009736163213, 10.969657538349898, 9.993667291407496, 8.984600742528084, 7.949034250776055, 7.064783117441519, 6.112548936026955, 5.0747385941774175, 4.0279595573196225, 3.0351008204939887, 2.0953315612006778, 1.0476923216724814, 2.0634709946863925, 2.973434957027429, 4.00514540529765, 4.957875676493996, 5.997598235257577, 6.995564534738156, 8.015661814107228, 8.898641252614897, 9.931145279075668, 11.862742539510565, 10.84860411638963, 9.897636789829557, 8.951682817316383, 8.013409790881436, 7.028732947031585, 5.9844072655952285, 5.025223034378013, 4.052829142997924, 3.072411706954476, 2.086927994003413, 3.117717233058893, 3.904789003019476, 4.836383111276365, 5.808986114454297, 6.874383631084126, 7.819593864997586, 8.876277201640796, 9.877464686182169, 10.907594865886306, 12.696231960184134, 11.722645059585528, 10.783359865372686, 9.85575504335393, 8.873059380849615, 7.889243792785619, 6.92241510620169, 6.008421919470603, 5.01034809056356, 3.986396164726302, 3.04362539665851, 4.022616357587619, 4.8398373149969105, 5.825474589674774, 6.8770253621457265, 7.865391674356332, 8.778009908148054, 9.786897949714668, 10.847856677799712, 11.834411666895917, 13.666183798725523, 12.771272970431841, 11.829094310523404, 10.878485174835207, 9.933677365096246, 8.880575919209802, 7.914733345663503, 6.945242095735612, 5.947417040187728, 4.913000517571857, 4.040120858550285, 4.966152585450613, 5.832269202773922, 6.776084907441948, 7.715870035303386, 8.715455501233686, 9.725149971809984, 10.704894670845507, 11.739760707602487, 12.680931118795723, 14.5938694323597, 13.740994237672336, 12.822738936600995, 11.840621329629654, 10.904014897137792, 9.829720497532472, 8.872405886352679, 7.91050219216019, 6.960672330957868, 5.984697797952459, 5.087845970983704, 5.968839963314758, 6.87967148686024, 7.783057646275791, 8.68809219036602, 9.691641598463718, 10.705258461926247, 11.722203611113652, 12.673395946264858, 13.741166614029744], [13.628843497915978, 12.65008760417215, 11.61222643813013, 10.657229888613829, 9.607826666937278, 8.635587699303093, 7.801070048912418, 6.8104749467842165, 6.105000221234876, 7.057409303257383, 8.043360679481488, 8.931058812640133, 9.861038497861179, 10.832555027961162, 11.775911248611395, 12.785234243644757, 13.83702057697512, 14.76622474984649, 15.784693121634898, 16.59754461849175, 12.631801621102538, 13.576038360133696, 12.619703048997835, 11.629711077756113, 10.630951966337973, 9.609416842873141, 8.8435360674391, 7.839600291171056, 7.033453660212636, 7.99401898799176, 8.926448569032887, 9.859266702846147, 10.8553955634628, 11.829746333958935, 12.823566789552837, 13.791337616317483, 14.855730118938752, 15.82180895940944, 16.708516880918737, 15.641787887555411, 11.73700281256841, 12.68273081839536, 13.674517788060232, 12.64402673047045, 11.589091778931968, 10.607434652852175, 9.829846453042737, 8.854417961816385, 8.01536228292119, 9.011825212936603, 9.946193522387485, 10.824674317489247, 11.86179762193617, 12.814707805019363, 13.807825158288432, 14.730736204752661, 15.778150561579999, 16.739395934331522, 15.739552743131636, 14.742404400752728, 10.812323165941088, 11.7814065010922, 12.825711937897108, 13.652352654421412, 12.598984340165778, 11.60581120795104, 10.829040035599059, 9.902802656850664, 9.066887811106868, 9.989736875776634, 10.971662531545741, 10.951803209694537, 11.800256166574535, 12.687777740156559, 13.671119002837376, 14.558450854047221, 15.489136233593825, 15.839746921927047, 14.91237476403646, 13.93371398221427, 9.898452264652768, 10.868705286802557, 11.804400551076288, 12.833011569824894, 13.559839869917377, 12.645786192334702, 11.781554995084399, 10.851986736300283, 10.076250506649178, 11.004231485811122, 10.900881244179676, 9.999000095409185, 10.727636046965664, 11.732620459852745, 12.620091133526461, 13.601817153960647, 14.65183171036478, 14.997694884053814, 13.961646684859561, 13.030902365405696, 8.914375697863065, 9.928216028226947, 10.910240330579516, 11.866133970891605, 12.887821599680295, 13.634863168722916, 12.734468404177411, 11.883010020646847, 11.117413383652911, 10.609665842692635, 9.901933687898683, 8.967035654254037, 9.778636229167482, 10.772393209776284, 11.692654265558806, 12.618325451973984, 13.619079642223127, 14.215929667800022, 13.272490958980281, 12.205667733395908, 9.869547978804876, 10.909182186722662, 11.905440076949747, 12.855139124207929, 13.832561130257373, 13.531951835729519, 12.60686388422482, 11.640005283359038, 10.644967033278576, 9.683282838258192, 8.841627013612847, 7.908460250496223, 8.832029685126384, 9.777111115727914, 10.698784952307957, 11.663999495410005, 12.635202964665739, 13.564364945066608, 13.907303408874235, 12.953310080872663, 10.703710506389863, 11.737913249248258, 12.72078005129527, 13.683215347324799, 13.548696623522593, 12.565397393500973, 11.629306789564982, 10.653222800377872, 9.639460429518296, 8.698315470078475, 7.782265949215603, 6.9691260353060445, 7.851825851646194, 8.811681581890898, 9.772695542135818, 10.76142684234569, 11.672288913572388, 12.62134741422441, 13.565455108304336, 13.624340236324196, 11.623470306989994, 12.696183731850901, 13.650824229444783, 13.543404132902197, 12.556539380074847, 11.718866010959538, 10.708580704157923, 9.738335583102295, 8.751344642964025, 7.758292823900959, 6.803164258033356, 5.956240935160626, 6.890260557558049, 7.867491418617365, 8.82978118166009, 9.741745926223302, 10.695196808562205, 11.654115886567103, 12.610779686266222, 13.536162912378229, 12.6879968548652, 13.637180098915746, 13.569475399706516, 12.588322317148434, 11.539639220194903, 10.671457288821005, 9.821792299388333, 8.858721425975622, 7.7946507952045625, 6.852585091664512, 5.869962641868707, 4.932041491165847, 5.924364627647222, 6.860463729256889, 7.8355599382235, 8.784801694855961, 9.734301828580255, 10.687235649812141, 11.679980624642978, 12.543517268591666, 13.541013889643096, 13.62718867632256, 12.594550172671777, 11.633460990543323, 10.604348674309923, 9.670212725131988, 8.757358414663907, 7.841582209197444, 6.867564864385629, 5.875698800871425, 4.847056881697922, 3.924569839115647, 4.908601125547387, 5.874365418531375, 6.8137377837229005, 7.808053368989217, 8.785156665461104, 9.693257955709795, 10.683151925500942, 11.61625782986457, 13.598207879652746, 12.632562902434564, 11.666833669514286, 10.678013981995093, 9.673007422257077, 8.742714272726749, 7.761333282687783, 6.868507652131029, 5.902698179833973, 4.919240814661588, 3.9011068092440597, 2.9357590263833604, 3.910893993664942, 4.916373876817945, 5.857999377752131, 6.9016475408035465, 7.791286864548058, 8.684649922835181, 9.745886850443407, 10.656944607815527, 12.676717572040085, 11.706402705676426, 10.679406097652638, 9.731529853555624, 8.679862638890057, 7.735665752842286, 6.761471439875857, 5.801922845355118, 4.84553131937116, 3.884622037924984, 2.935150259135992, 1.9996801292803812, 2.9439472666944893, 3.9517814665764375, 4.958953079499148, 5.841173927739733, 6.755979448218614, 7.698035950376065, 8.697593341135729, 9.62979101572739, 11.931245674978564, 10.870009827444495, 9.923839237828636, 8.926276413166459, 7.93145367178345, 6.936232792634562, 5.946409795664719, 4.935085792658886, 3.942692144890114, 2.909157288590789, 1.9793062753736892, 1.038387185195087, 2.0360875944449486, 2.9226733833203355, 3.8928754786382562, 4.837443157282341, 5.803105709481227, 6.818358068603887, 7.842032486771922, 8.846527268468204, 11.178607879653393, 10.117724467974725, 9.076345224553435, 8.057561322787839, 7.061198703554855, 6.095343579397074, 5.140510329484083, 4.167152487320601, 3.1276031087394243, 2.100242346330816, 1.0360612612216153, 0.0, 0.9954226040465466, 1.922623517100421, 2.9800674373658325, 3.9365729776377947, 4.944931640580461, 5.9091936901976725, 6.891236934932252, 7.949948474941598, 12.005718799571515, 11.029728552629113, 10.0206620037497, 8.985095511997672, 8.100844378663135, 7.148610197248571, 6.0994215872825714, 5.0526425504247765, 4.059783813599143, 3.1147345218261986, 2.067095282298002, 1.0274097334647774, 1.9373736958058136, 2.969084144076035, 3.9218144152723813, 4.961536974035962, 5.959503273516541, 6.979600552885612, 7.862579991393283, 8.895084017854055, 12.898803800732182, 11.884665377611247, 10.933698051051174, 9.987744078538, 9.032812751506956, 8.048135907657105, 7.003810226220749, 6.044625995003534, 5.072232103623445, 4.091814667579997, 3.106330954628934, 2.081655971837278, 2.8687277417978603, 3.8003218500547495, 4.772924853232682, 5.838322369862511, 6.783532603775971, 7.840215940419181, 8.841403424960554, 9.871533604664693, 13.715634920809654, 12.742048020211048, 11.802762825998206, 10.87515800397945, 9.892462341475134, 8.908646753411139, 7.941818066827211, 7.027824880096124, 6.029751051189081, 5.005799125351823, 4.063028357284031, 3.1008688973746956, 3.803776053775295, 4.789413328453158, 5.840964100924111, 6.829330413134717, 7.741948646926439, 8.750836688493054, 9.811795416578098, 10.798350405674304, 14.685586759351043, 13.790675931057361, 12.848497271148924, 11.897888135460727, 10.953080325721766, 9.899978879835322, 8.934136306289023, 7.964645056361132, 6.966820000813248, 5.932403478197378, 5.0455503107205795, 4.119518583820251, 4.796207941552307, 5.740023646220333, 6.679808774081771, 7.679394240012072, 8.68908871058837, 9.668833409623893, 10.703699446380874, 11.64486985757411, 15.61327239298522, 14.760397198297856, 13.842141897226515, 12.860024290255174, 11.923417857763312, 10.849123458157992, 9.891808846978199, 8.92990515278571, 7.980075291583388, 7.00410075857798, 6.093275423153998, 5.122205961684395, 5.843610225638625, 6.746996385054176, 7.652030929144406, 8.655580337242103, 9.669197200704632, 10.686142349892037, 11.637334685043243, 12.705105352808129], [12.633420893869433, 11.654665000125604, 10.616803834083582, 9.661807284567281, 8.61240406289073, 7.640165095256545, 6.805647444865873, 5.81505234273767, 6.760758980376392, 7.713168062398898, 8.715950939642777, 9.603649072801423, 10.533628758022468, 11.505145288122451, 12.448501508772685, 13.457824503806046, 14.509610837136409, 15.43881501000778, 16.457283381796188, 17.342993092335593, 11.63637901705599, 12.580615756087148, 11.624280444951287, 10.634288473709566, 9.635529362291425, 8.613994238826594, 7.848113463392553, 6.8441776871245095, 7.689212419354152, 8.649777747133275, 9.582207328174402, 10.515025461987662, 11.527985823624089, 12.502336594120225, 13.496157049714126, 14.463927876478772, 15.528320379100041, 16.49439921957073, 17.453965354762584, 16.387236361399257, 10.741580208521864, 11.687308214348814, 12.679095184013685, 11.648604126423903, 10.59366917488542, 9.612012048805628, 8.834423848996192, 7.858995357769838, 8.671121042062705, 9.667583972078116, 10.601952281528998, 11.480433076630762, 11.927416921533538, 12.817429914717192, 13.81054726798626, 14.70921141856237, 15.522144199922534, 16.509744888984237, 16.48500121697548, 15.487852874596571, 9.81690056189454, 10.785983897045652, 11.83028933385056, 12.656930050374864, 11.60356173611923, 10.610388603904493, 9.833617431552513, 8.907380052804118, 9.722646570248383, 10.645495634918147, 11.627421290687254, 11.855733287716646, 10.948152662794712, 11.835674236376736, 12.766855874289714, 13.65418772549956, 14.584873105046164, 15.503962831931759, 15.82946725892609, 14.8508064771039, 8.903029660606219, 9.873282682756008, 10.808977947029739, 11.837588965778345, 12.56441726587083, 11.650363588288155, 10.786132391037853, 9.856564132253737, 10.732009265790692, 11.659990244952635, 11.877161769454299, 10.902930173431294, 9.875532543185841, 10.880516956072922, 11.7158280049788, 12.697554025412986, 13.670305046267481, 14.42979980591793, 14.957069288906105, 14.02632496945224, 7.918953093816518, 8.9327934241804, 9.914817726532966, 10.870711366845056, 11.892398995633746, 12.639440564676368, 11.739045800130866, 10.8875874166003, 11.773172142794426, 11.585946367967257, 10.878214213173306, 9.94331617952866, 8.92653272538766, 9.920289705996462, 10.788391137011146, 11.702053870877869, 12.637552978125829, 13.493961145899744, 14.267913563026825, 13.201090337442452, 8.87412537475833, 9.913759582676116, 10.910017472903197, 11.85971652016138, 12.837138526210824, 13.584269728395205, 12.695314261067203, 11.886152168788227, 11.621247558553197, 10.659563363532813, 9.81790753888747, 8.884740775770846, 7.979926181346562, 8.925007611948091, 9.794521823760297, 10.74772791431389, 11.65367630056844, 12.56894234102006, 13.521287791649835, 13.94873268491921, 9.708287902343315, 10.742490645201713, 11.725357447248724, 12.687792743278253, 13.65641899142502, 13.541677918775594, 12.605587314839603, 11.629503325652493, 10.615740954792917, 9.674595995353096, 8.758546474490224, 7.9454065605806665, 6.9997223478663715, 7.907418453343239, 8.868432413588158, 9.779900178248392, 10.690762249475089, 11.625924810177862, 12.570032504257789, 13.552052542966832, 10.628047702943446, 11.700761127804354, 12.655401625398238, 13.626052028192966, 13.535894213563871, 12.698220844448562, 11.684861229432544, 10.714616108376916, 9.727625168238646, 8.73457334917558, 7.779444783307977, 6.932521460435248, 6.038157053778226, 6.950481558330903, 7.848254517562792, 8.760219262126004, 9.713670144464906, 10.658693282520556, 11.615357082219674, 12.540740308331682, 11.692574250818652, 12.641757494869198, 13.656004640448982, 13.567677150637458, 12.518994053683928, 11.650812122310029, 10.801147132877357, 9.835001951250243, 8.770931320479184, 7.828865616939133, 6.846243167143328, 5.908322016440469, 5.0351911741265, 5.87893706515959, 6.854033274126201, 7.803275030758662, 8.738879224533708, 9.691813045765594, 10.684558020596432, 11.548094664545118, 12.545591285596549, 13.582101605034177, 13.5739050061608, 12.612815824032346, 11.583703507798948, 10.649567558621012, 9.736713248152931, 8.820937042686468, 7.846919697874653, 6.855053634360449, 5.823337406972543, 4.900850364390269, 4.019427672026665, 4.892838754434076, 5.832211119625602, 6.8265267048919185, 7.789734061414557, 8.69783535166325, 9.687729321454396, 10.620835225818022, 13.492724678961244, 13.611917735923587, 12.646188503003309, 11.657368815484116, 10.6523622557461, 9.722069106215773, 8.740688116176807, 7.847862485620054, 6.882053013322997, 5.8985956481506125, 4.877387334518681, 3.912039551657982, 3.02172054014422, 3.920951272771398, 4.862576773705585, 5.906224936757, 6.795864260501512, 7.689227318788634, 8.75046424639686, 9.66152200376898, 13.656072405529107, 12.685757539165449, 11.65876093114166, 10.710884687044647, 9.65921747237908, 8.71502058633131, 7.740826273364881, 6.781277678844142, 5.824886152860184, 4.863976871414008, 3.911430784410614, 2.975960654555003, 2.0316935171408947, 2.956358862529891, 3.963530475452601, 4.845751323693187, 5.760556844172068, 6.702613346329518, 7.702170737089181, 8.634368411680843, 12.926668279025112, 11.865432431491042, 10.919261841875183, 9.921699017213006, 8.926876275829997, 7.931655396681109, 6.9418323997112665, 5.930508396705433, 4.938114748936661, 3.9045798926373356, 2.9747288794202356, 2.0338097892416336, 1.0406649903984018, 1.927250779273789, 2.8974528745917096, 3.8420205532357947, 4.8076831054346805, 5.82293546455734, 6.846609882725375, 7.8511046644216576, 12.174030483699937, 11.113147072021269, 10.07176782859998, 9.052983926834383, 8.0566213076014, 7.09076618344362, 6.135932933530628, 5.162575091367147, 4.123025712785971, 3.095664950377363, 2.0314838652681617, 0.9954226040465466, 0.0, 0.9272009130538744, 1.9846448333192859, 2.941150373591248, 3.9495090365339145, 4.913771086151126, 5.895814330885704, 6.954525870895051, 13.001141403618059, 12.025151156675657, 11.016084607796245, 9.980518116044216, 9.041870759353593, 8.01209635915549, 6.959131660157029, 5.912352623299234, 4.9194938864736, 3.974444594700656, 2.9268053551724598, 1.8871198063392354, 0.9419510917592671, 1.9736615400294886, 2.9263918112258347, 3.9661143699894157, 4.964080669469994, 5.984177948839066, 6.867157387346736, 7.8996614138075065, 13.815896295621812, 12.801757872500877, 11.850790545940804, 10.90483657342763, 9.892522824381414, 8.907845980531564, 7.863520299095207, 6.904336067877991, 5.931942176497902, 4.951524740454454, 3.8869958707264507, 2.8430629079025778, 1.8733051377513137, 2.804899246008203, 3.777502249186135, 4.8428997658159645, 5.788109999729425, 6.844793336372636, 7.845980820914008, 8.876111000618145, 14.461083394653498, 13.487496494054891, 12.54821129984205, 11.620606477823294, 10.637910815318978, 9.654095227254983, 8.687266540671054, 7.718124677318244, 6.70234131135037, 5.678389385513112, 4.73561861744532, 3.756627656516211, 2.8083534497287483, 3.793990724406611, 4.845541496877565, 5.833907809088171, 6.746526042879894, 7.7554140844465085, 8.816372812531553, 9.802927801627758, 15.431035233194887, 14.503207666420144, 13.541670385126743, 12.591061249438546, 11.646253439699585, 10.572569139996611, 9.606726566450313, 8.637235316522421, 7.639410260974538, 6.604993738358667, 5.701309069862095, 4.7752773429617665, 3.8007853375057605, 4.7446010421737865, 5.684386170035224, 6.683971635965525, 7.693666106541823, 8.673410805577346, 9.708276842334326, 10.649447253527562, 16.358720866829064, 15.472928933660638, 14.514732157387805, 13.532614550416463, 12.596008117924601, 11.521713718319281, 10.564399107139488, 9.602495412946999, 8.652665551744677, 7.67669101873927, 6.749034182295514, 5.777964720825911, 4.8481876215920785, 5.751573781007631, 6.656608325097859, 7.660157733195557, 8.673774596658085, 9.690719745845492, 10.641912080996697, 11.709682748761583], [11.880157839014851, 10.917745828679461, 9.886849820795417, 8.931853271279117, 7.981146980862889, 7.05739203676238, 6.302244639964352, 6.742253255791544, 7.687959893430266, 8.640368975452771, 9.64315185269665, 10.530849985855296, 11.460829671076342, 12.432346201176324, 13.375702421826558, 14.38502541685992, 15.436811750190282, 16.366015923061653, 17.38448429485006, 18.270194005389467, 10.822398860271235, 11.767418818369178, 10.894326431663123, 9.904334460421401, 9.004272280263585, 8.031221180332428, 7.344710658491032, 7.771378600178384, 8.616413332408026, 9.57697866018715, 10.509408241228277, 11.442226375041537, 12.455186736677963, 12.88727095368433, 13.920510114809098, 14.721409093943679, 15.566216911511347, 16.532295751982037, 17.490336946285424, 17.31443727445313, 9.816617073054589, 10.76234507888154, 11.765991255757609, 10.932156117103691, 9.974060535483876, 9.029238990311462, 8.339849217929197, 8.786196270823712, 9.59832195511658, 10.594784885131993, 11.529153194582875, 12.407633989684637, 12.820084375942441, 11.902309482623902, 12.895426835892971, 13.7820105055085, 14.594943286868665, 15.582543975930367, 16.451668938337864, 16.415053787650443, 8.889699648840667, 9.858782983991778, 10.903088420796687, 11.8579234815647, 11.020788677625065, 10.027615545410328, 9.339042800485519, 9.834580965857992, 10.649847483302258, 11.572696547972024, 12.55462220374113, 12.74840074212555, 11.840820117203615, 10.920553804283445, 11.839654961235844, 12.72698681244569, 13.657672191992294, 14.576761918877885, 15.486176757115482, 15.778007390157775, 7.975828747552345, 8.946081769702134, 9.881777033975865, 10.910388052724471, 11.904604273646926, 11.06759052979399, 10.305979908865673, 10.78376504530761, 11.659210178844567, 12.587191158006512, 12.794752663382232, 11.795597627840198, 10.768199997594744, 9.965396523979631, 10.78862709192493, 11.770353112359116, 12.743104133213604, 13.502598892864057, 14.473033980162036, 14.953525882506117, 6.991752180762645, 8.005592511126526, 8.987616813479093, 9.943510453791182, 10.965198082579873, 11.99008511567969, 11.258893317958686, 11.814788329654174, 12.700373055848301, 12.513147281021132, 11.79580510710124, 10.860907073456593, 9.819200179796562, 9.00516927390317, 9.861190223957275, 10.774852957823995, 11.710352065071952, 12.566760232845871, 13.510198941665612, 14.128291250496329, 7.946924461704457, 8.986558669622243, 9.982816559849324, 10.932515607107506, 11.90993761315695, 12.915155430555563, 12.215161778895023, 12.8133530818421, 12.548448471607072, 11.586764276586688, 10.735498432815403, 9.802331669698779, 8.872593635755464, 8.0098871798548, 8.867320910706425, 9.820527001260016, 10.726475387514565, 11.641741427966187, 12.594086878595961, 13.548080206597533, 8.78108698928944, 9.815289732147836, 10.798156534194847, 11.760591830224376, 12.729218078371144, 13.712517308392764, 13.217688168722153, 12.556704238706368, 11.542941867846793, 10.601796908406971, 9.6857473875441, 8.8629974545086, 7.892389802275274, 6.980217540289366, 7.941231500534285, 8.852699265194518, 9.763561336421214, 10.698723897123989, 11.642831591203915, 12.624851629912959, 9.700846789889573, 10.77356021475048, 11.72820071234436, 12.698851115139089, 13.736635303061147, 13.625421757502435, 12.61206214248642, 11.641817021430793, 10.654826081292523, 9.661774262229455, 8.706645696361852, 7.859722373489121, 6.930824508187129, 6.02328064527703, 6.921053604508916, 7.8330183490721295, 8.786469231411031, 9.731492369466682, 10.6881561691658, 11.613539395277808, 10.765373337764778, 11.714556581815325, 12.728803727395109, 13.653932930892852, 13.446194966737801, 12.578013035363902, 11.72834804593123, 10.762202864304118, 9.698132233533059, 8.756066529993008, 7.773444080197203, 6.835522929494342, 5.927858628535403, 4.951736152105717, 5.926832361072327, 6.876074117704787, 7.8116783114798345, 8.76461213271172, 9.757357107542557, 10.620893751491245, 11.618390372542676, 12.654900691980304, 13.687539195631086, 13.54001673708622, 12.510904420852821, 11.576768471674885, 10.663914161206804, 9.748137955740344, 8.774120610928529, 7.782254547414323, 6.7505383200264175, 5.828051277444143, 4.93140213436419, 3.965637841380202, 4.905010206571728, 5.899325791838044, 6.862533148360683, 7.770634438609375, 8.760528408400521, 9.693634312764148, 12.56552376590737, 13.531168743125551, 13.573389416057182, 12.58456972853799, 11.579563168799973, 10.649270019269647, 9.66788902923068, 8.775063398673929, 7.809253926376872, 6.825796561204486, 5.804588247572555, 4.839240464711856, 3.9489214531980945, 2.9937503597175237, 3.93537586065171, 4.979024023703126, 5.8686633474476375, 6.76202640573476, 7.823263333342986, 8.734321090715106, 13.559679993372649, 13.612958452219322, 12.585961844195534, 11.63808560009852, 10.586418385432953, 9.642221499385183, 8.668027186418755, 7.708478591898016, 6.752087065914059, 5.791177784467882, 4.838631697464488, 3.903161567608877, 2.9588944301947695, 2.0291579494760166, 3.0363295623987265, 3.9185504106393125, 4.833355931118193, 5.775412433275644, 6.774969824035307, 7.707167498626968, 13.853869192078987, 12.792633344544917, 11.846462754929059, 10.848899930266882, 9.854077188883872, 8.858856309734984, 7.86903331276514, 6.857709309759307, 5.865315661990535, 4.83178080569121, 3.90192979247411, 2.961010702295508, 1.9678659034522763, 1.0000498662199147, 1.9702519615378353, 2.9148196401819204, 3.8804821923808057, 4.895734551503465, 5.9194089696715, 6.923903751367782, 13.101231396753814, 12.040347985075146, 10.998968741653856, 9.98018483988826, 8.983822220655277, 8.017967096497495, 7.0631338465845035, 6.089776004421022, 5.050226625839845, 4.022865863431237, 2.958684778322036, 1.922623517100421, 0.9272009130538744, 0.0, 1.0574439202654113, 2.013949460537374, 3.02230812348004, 3.9865701730972516, 4.968613417831831, 6.027324957841177, 13.928342316671936, 12.952352069729534, 11.943285520850122, 10.907719029098093, 9.96907167240747, 8.939297272209366, 7.886332573210904, 6.839553536353109, 5.846694799527476, 4.901645507754531, 3.8540062682263345, 2.81432071939311, 1.8691520048131416, 1.0491535933229421, 1.99919089817196, 3.038913456935541, 4.03687975641612, 5.0569770357851915, 5.939956474292862, 6.972460500753633, 14.743097208675687, 13.728958785554752, 12.777991458994679, 11.832037486481505, 10.81972373743529, 9.835046893585439, 8.790721212149082, 7.831536980931866, 6.859143089551777, 5.878725653508329, 4.814196783780326, 3.770263820956453, 2.8005060508051884, 2.103763683748352, 2.972981755549087, 4.038379272178917, 4.983589506092377, 5.985021820010156, 6.937501640829361, 7.948910087564272, 15.388284307707371, 14.414697407108765, 13.475412212895924, 12.547807390877168, 11.565111728372852, 10.581296140308856, 9.614467453724927, 8.645325590372117, 7.6295422244042435, 6.605590298566986, 5.662819530499194, 4.683828569570085, 3.735554362782623, 3.169310728543663, 4.041021003240517, 5.029387315451123, 5.942005549242846, 6.950893590809461, 7.946770086797361, 8.877964666160484, 16.35823614624876, 15.430408579474017, 14.468871298180616, 13.51826216249242, 12.573454352753458, 11.499770053050485, 10.533927479504186, 9.564436229576295, 8.566611174028411, 7.53219465141254, 6.628509982915969, 5.702478256015641, 4.727986250559635, 4.241198237272266, 5.101613111541059, 6.032345214208059, 6.922849825335176, 7.902594524370698, 8.901965684259602, 9.843136095452838, 17.285921779882937, 16.400129846714513, 15.441933070441678, 14.459815463470337, 13.523209030978474, 12.448914631373155, 11.491600020193362, 10.529696326000872, 9.57986646479855, 8.603891931793143, 7.676235095349388, 6.705165633879785, 5.775388534645953, 5.24817097610611, 6.073835266603694, 7.0289006511677155, 7.94382058336992, 8.953800574399349, 9.904992909550554, 10.904782958674526], [10.822713918749438, 9.860301908414051, 8.829405900530004, 7.874409351013704, 6.923703060597478, 5.999948116496968, 6.9542310031049, 7.761482151704853, 8.707188789343576, 9.659597871366081, 10.66238074860996, 11.550078881768606, 12.480058566989651, 13.451575097089634, 14.076923887176841, 14.828228382780127, 15.703632638503422, 16.632836811374794, 17.545280115437226, 18.440592450867648, 9.764954940005822, 10.709974898103765, 9.83688251139771, 8.846890540155988, 7.9468283599981735, 6.973777260067017, 7.986210696308807, 8.790607496091694, 9.635642228321336, 10.59620755610046, 11.528637137141587, 12.461455270954847, 13.474415632591272, 13.777280980744289, 13.0292683462354, 13.822125010107401, 14.666932827675069, 15.633011668145757, 16.495779250552932, 17.38135057456786, 8.759173152789176, 9.704901158616126, 10.708547335492195, 9.874712196838278, 8.916616615218464, 7.971795070046052, 8.981349255746972, 9.805425166737022, 10.61755085102989, 11.614013781045301, 12.548382090496183, 13.426862885597947, 13.772090952718642, 12.79231950968386, 12.004185067319273, 12.882726421672222, 13.695659203032386, 14.620058755619052, 15.457111242605372, 16.433114160250934, 7.832255728575254, 8.801339063726365, 9.845644500531273, 10.800479561299289, 9.963344757359653, 8.970171625144916, 9.927062738084592, 10.853809861771301, 11.669076379215568, 12.591925443885332, 13.573851099654439, 13.70040731890175, 12.792826693979816, 11.810563831343405, 10.940370877399566, 11.827702728609411, 12.758388108156016, 13.582204223145391, 14.491619061382988, 15.392513387529819, 6.918384827286933, 7.888637849436722, 8.824333113710454, 9.85294413245906, 10.847160353381515, 10.010146609528578, 10.893999846464746, 11.80299394122092, 12.678439074757877, 13.60642005391982, 13.74675924015843, 12.747604204616398, 11.720206574370945, 10.855406551039591, 9.889343008088652, 10.871069028522838, 11.82912987883721, 12.508041197131563, 13.478476284429542, 14.409220603883407, 5.934308260497232, 6.948148590861114, 7.9301728932136815, 8.88606653352577, 9.907754162314461, 10.932641195414279, 11.846913255557759, 12.82278538831029, 13.71960195176161, 13.55884314405854, 12.747811683877439, 11.812913650232792, 10.771206756572763, 9.910998779069256, 8.961906140120998, 9.8608787034476, 10.796377810695557, 11.572202537113377, 12.515641245933118, 13.541961129086223, 6.889480541439044, 7.92911474935683, 8.925372639583912, 9.875071686842094, 10.852493692891539, 11.857711510290152, 12.78279946179485, 13.749658062660632, 13.594144334644481, 12.632460139624097, 11.687505009591602, 10.754338246474978, 9.824600212531665, 8.92827172175404, 7.968036826870149, 8.906552746883621, 9.81250113313817, 10.647183732233692, 11.599529182863467, 12.553522510865038, 7.7865292935569475, 8.820732036415343, 9.803598838462355, 10.766034134491884, 11.734660382638651, 12.717959612660271, 13.654050216596263, 13.602400101743777, 12.588637730884201, 11.64749277144438, 10.731443250581508, 9.815004031284799, 8.844396379051474, 7.932224117065567, 7.04194741669801, 7.938725010818122, 8.849587082044819, 9.704166201391494, 10.648273895471421, 11.630293934180465, 8.706289094157079, 9.779002519017986, 10.733643016611868, 11.704293419406596, 12.742077607328655, 13.650558477407941, 13.65775800552383, 12.687512884468202, 11.700521944329932, 10.707470125266864, 9.75234155939926, 8.816850707360754, 7.88283108496333, 6.975287222053231, 6.016073153706635, 6.9190440946957334, 7.872494977034636, 8.736934673734188, 9.693598473433306, 10.618981699545314, 9.770815642032284, 10.71999888608283, 11.734246031662614, 12.65937523516036, 13.70805833211389, 13.635456955629312, 12.785791966196642, 11.81964678456953, 10.75557615379847, 9.81351045025842, 8.830888000462615, 7.876072524866341, 6.879865205311604, 5.903742728881918, 5.021851910270046, 5.962099863328391, 6.81712061574734, 7.770054436979226, 8.762799411810064, 9.62633605575875, 10.623832676810181, 11.66034299624781, 12.692981499898591, 13.632048141373653, 13.56834834111823, 12.634212391940295, 11.721358081472216, 10.805581876005755, 9.83156453119394, 8.839698467679733, 7.807982240291829, 6.868600872816142, 5.883408711140391, 4.917644418156403, 4.000029755769447, 4.985351537461648, 5.8679754526281895, 6.7760767428768816, 7.765970712668028, 8.699076617031654, 11.570966070174876, 12.536611047393057, 13.524469530410265, 13.6420136488034, 12.637007089065385, 11.706713939535057, 10.725332949496092, 9.83250731893934, 8.866697846642284, 7.8832404814698975, 6.862032167837967, 5.896684384977267, 5.006365373463506, 3.945756936493725, 3.0041314355595388, 3.9916321904916394, 4.874105651715144, 5.767468710002267, 6.828705637610492, 7.739763394982612, 12.565122297640155, 13.462771244151195, 13.643405764460944, 12.69552952036393, 11.643862305698365, 10.699665419650595, 9.725471106684166, 8.765922512163428, 7.80953098617947, 6.848621704733294, 5.8960756177299, 4.960605487874289, 4.016338350460181, 3.0106261912920536, 2.077393613578922, 2.92399271490682, 3.8387982353857, 4.780854737543151, 5.780412128302814, 6.712609802894475, 13.575586916759137, 13.850077264810329, 12.90390667519447, 11.906343850532293, 10.911521109149284, 9.916300230000395, 8.926477233030552, 7.9151532300247185, 6.922759582255947, 5.8892247259566215, 4.959373712739522, 4.0184546225609195, 3.025309823717688, 1.9815181080359516, 1.011316012718031, 1.9202619444494275, 2.885924496648313, 3.9011768557709727, 4.880854903391385, 5.885349685087667, 14.158675317019224, 13.097791905340555, 12.056412661919266, 11.03762876015367, 10.041266140920687, 9.075411016762907, 8.120577766849914, 7.147219924686434, 6.107670546105257, 5.080309783696649, 4.016128698587448, 2.9800674373658325, 1.9846448333192859, 1.0574439202654113, 0.0, 0.9565055402719624, 1.964864203214629, 2.92912625283184, 3.911169497566419, 4.969881037575765, 14.985786236937345, 14.009795989994943, 13.000729441115531, 11.965162949363503, 11.02651559267288, 9.996741192474778, 8.943776493476316, 7.896997456618521, 6.904138719792887, 5.959089428019943, 4.911450188491746, 3.8717646396585215, 2.926595925078553, 1.9008441294937242, 0.9417469779065487, 1.9814695366701298, 2.9794358361507087, 3.99953311551978, 4.88251255402745, 5.915016580488221, 15.771869987846484, 14.75773156472555, 13.806764238165476, 12.860810265652303, 11.848496516606087, 10.863819672756236, 9.819493991319879, 8.860309760102663, 7.887915868722573, 6.907498432679126, 5.833425679693635, 4.789492716869762, 3.8197349467184973, 2.888140838461608, 1.9155378352836758, 2.980935351913505, 3.926145585826965, 4.927577899744745, 5.880057720563949, 6.8914661672988595, 16.40751320362068, 15.433926303022073, 14.494641108809232, 13.567036286790476, 12.58434062428616, 11.600525036222164, 10.633696349638235, 9.664554486285427, 8.648771120317553, 7.624819194480295, 6.6820484264125035, 5.703057465483394, 4.754783258695932, 3.953687883256919, 2.9835770829751054, 3.9719433951857113, 4.884561628977433, 5.893449670544047, 6.889326166531949, 7.82052074589507, 17.377465042162072, 16.449637475387327, 15.488100194093928, 14.537491058405731, 13.59268324866677, 12.518998948963795, 11.553156375417496, 10.583665125489604, 9.585840069941721, 8.55142354732585, 7.647738878829278, 6.72170715192895, 5.747215146472944, 4.9839543191370845, 4.044169191275647, 4.974901293942647, 5.865405905069763, 6.845150604105285, 7.84452176399419, 8.785692175187425, 18.30515067579625, 17.41935874262782, 16.46116196635499, 15.479044359383648, 14.542437926891786, 13.468143527286465, 12.510828916106671, 11.548925221914182, 10.59909536071186, 9.623120827706453, 8.695463991262697, 7.724394529793094, 6.794617430559262, 5.968189998346505, 5.016391346338282, 5.971456730902304, 6.886376663104508, 7.896356654133937, 8.847548989285142, 9.847339038409112], [9.866208378477477, 8.918519238589411, 7.894629902473711, 6.9396333529574115, 6.020125774794103, 6.956453656768931, 7.910736543376863, 8.717987691976814, 9.663694329615538, 10.616103411638043, 11.618886288881923, 12.506584422040568, 13.436564107261614, 14.408080637361596, 14.916053173339984, 13.934702511525979, 14.755364592668156, 15.684568765539527, 16.588774575165264, 17.484086910595686, 8.80844939973386, 9.753469357831804, 8.902106513341417, 7.912114542099696, 7.0432510741947985, 7.930282800338979, 8.94271623658077, 9.747113036363654, 10.592147768593298, 11.552713096372422, 12.485142677413549, 13.41796081122681, 14.430921172863235, 14.616410266907431, 13.868397632398542, 12.928599138853253, 13.718664781839804, 14.684743622310492, 15.539273710280968, 16.4248450342959, 7.802667612517214, 8.748395618344166, 9.752041795220235, 8.939936198781986, 8.01303932941509, 8.928300610318013, 9.937854796018934, 10.761930707008982, 11.574056391301852, 12.570519321317263, 13.504887630768145, 14.383368425869909, 14.611220238881781, 13.631448795847003, 12.843314353482416, 11.989200550418074, 12.747391157197121, 13.66355321534709, 14.50060570233341, 15.476608619978972, 6.875750188303292, 7.844833523454404, 8.889138960259311, 9.843974021027327, 9.0746124836981, 9.926677165416878, 10.883568278356554, 11.810315402043262, 12.62558191948753, 13.548430984157294, 14.530356639926401, 14.539536605064889, 13.631955980142955, 12.649693117506548, 11.779500163562709, 10.934176857355263, 11.81012006232075, 12.625698682873429, 13.535113521111025, 14.436007847257857, 5.961879287014971, 6.93213230916476, 7.8678275734384915, 8.896438592187097, 9.890654813109553, 10.94686894999297, 11.850505386736709, 12.759499481492881, 13.63494461502984, 14.562925594191782, 14.58588852632157, 13.586733490779537, 12.559335860534084, 11.694535837202734, 10.728472294251794, 9.97754315726869, 10.872624338565247, 11.5515356568596, 12.52197074415758, 13.452715063611445, 4.97780272022527, 5.991643050589151, 6.973667352941719, 7.9295609932538085, 8.951248622042499, 9.976135655142317, 11.02366838998136, 11.999540522733891, 12.966128345502336, 13.90885529440476, 13.586940970040578, 12.652042936395931, 11.610336042735902, 10.750128065232397, 9.80103542628414, 8.904373163175638, 9.839872270423594, 10.615696996841415, 11.559135705661156, 12.585455588814261, 5.932975001167081, 6.972609209084868, 7.96886709931195, 8.918566146570132, 9.895988152619577, 10.90120597001819, 11.826293921522888, 12.79315252238867, 13.788190772469132, 13.471589425787236, 12.526634295754741, 11.593467532638117, 10.663729498694805, 9.767401007917181, 8.80716611303329, 7.950047206611659, 8.855995592866208, 9.69067819196173, 10.643023642591505, 11.597016970593076, 6.830023753284985, 7.864226496143382, 8.847093298190394, 9.809528594219923, 10.77815484236669, 11.761454072388311, 12.697544676324302, 13.673628665511412, 13.42776701704734, 12.48662205760752, 11.570572536744647, 10.654133317447938, 9.683525665214614, 8.771353403228705, 7.881076702861151, 6.98221947054616, 7.893081541772856, 8.747660661119532, 9.691768355199459, 10.673788393908502, 7.749783553885116, 8.822496978746024, 9.777137476339908, 10.747787879134634, 11.785572067056693, 12.69405293713598, 13.708682775006691, 13.526642170631341, 12.539651230493071, 11.546599411430003, 10.5914708455624, 9.655979993523893, 8.72196037112647, 7.81441650821637, 6.855202439869776, 5.962538554423771, 6.915989436762674, 7.780429133462225, 8.737092933161343, 9.662476159273352, 8.81431010176032, 9.763493345810867, 10.77774049139065, 11.702869694888397, 12.751552791841927, 13.736967224358313, 13.701208300863582, 12.66787075500553, 11.603800124234471, 10.66173442069442, 9.679111970898616, 8.71520181102948, 7.718994491474743, 6.742872015045057, 5.860981196433186, 5.005594323056429, 5.860615075475378, 6.813548896707264, 7.806293871538101, 8.669830515486789, 9.66732713653822, 10.703837455975847, 11.73647595962663, 12.675542601101691, 13.686843337726907, 13.549628726607235, 12.636774416139156, 11.720998210672693, 10.746980865860879, 9.710448992153625, 8.65620621072783, 7.707730158979282, 6.722537997303531, 5.756773704319543, 4.839159041932587, 4.028845997189686, 4.911469912356227, 5.819571202604919, 6.809465172396066, 7.742571076759691, 10.614460529902914, 11.580105507121095, 12.567963990138303, 13.629026720584722, 13.552423423732325, 12.622130274201997, 11.640749284163032, 10.747923653606279, 9.782114181309222, 8.798656816136837, 7.777448502504907, 6.812100719644207, 5.857862940014728, 4.784886222656865, 3.8432607217226784, 3.035126650219677, 3.917600111443182, 4.810963169730305, 5.8722000973385295, 6.78325785471065, 11.608616757368193, 12.506265703879233, 13.533262311903021, 13.61094585503087, 12.559278640365305, 11.615081754317535, 10.640887441351106, 9.681338846830368, 8.72494732084641, 7.7640380394002335, 6.81149195239684, 5.876021822541229, 4.931754685127121, 3.9076342613955726, 2.916522899742062, 1.9674871746348574, 2.8822926951137378, 3.824349197271188, 4.823906588030852, 5.756104262622513, 12.619081376487175, 13.562925061222593, 13.860412215466434, 12.862849390804257, 11.868026649421248, 10.87280577027236, 9.882982773302516, 8.871658770296682, 7.879265122527909, 6.845730266228584, 5.915879253011484, 4.974960162832882, 3.946868176591049, 2.8785261781394706, 1.90832408282155, 0.963756404177465, 1.9294189563763504, 2.94467131549901, 3.9243493631194233, 4.928844144815706, 13.57290726370478, 14.054297445612518, 13.012918202191228, 11.994134300425632, 10.99777168119265, 10.031916557034869, 9.077083307121876, 8.103725464958396, 7.064176086377219, 6.036815323968611, 4.97263423885941, 3.9365729776377947, 2.941150373591248, 2.013949460537374, 0.9565055402719624, 0.0, 1.0083586629426666, 1.9726207125598778, 2.9546639572944566, 4.0133754973038025, 14.477898629445626, 14.966301530266906, 13.957234981387494, 12.921668489635465, 11.983021132944845, 10.953246732746742, 9.90028203374828, 8.853502996890484, 7.860644260064849, 6.915594968291905, 5.867955728763708, 4.828270179930484, 3.8831014653505154, 2.8573496697656866, 1.898252518178511, 1.0369664363238824, 2.022930295878746, 3.0430275752478178, 3.9260070137554877, 4.958511040216258, 15.470918028739945, 15.71423710499751, 14.763269778437436, 13.817315805924263, 12.805002056878047, 11.820325213028196, 10.77599953159184, 9.816815300374623, 8.844421408994535, 7.864003972951088, 6.789931219965597, 5.745998257141724, 4.77624048699046, 3.8446463787335707, 2.8720433755556383, 2.07735806611013, 2.991369587770672, 3.9710723594727826, 4.923552180291987, 5.934960627026897, 16.422551799909463, 16.390431843294035, 15.451146649081194, 14.523541827062438, 13.540846164558122, 12.557030576494126, 11.590201889910198, 10.62106002655739, 9.605276660589515, 8.581324734752258, 7.638553966684466, 6.6595630057553565, 5.711288798967894, 4.910193423528882, 3.9400826232470676, 3.0683661093823362, 3.94978563092114, 4.9586736724877545, 5.9328206262599865, 6.864015205623108, 17.38104616250027, 17.40614301565929, 16.44460573436589, 15.493996598677693, 14.549188788938732, 13.475504489235757, 12.509661915689458, 11.540170665761567, 10.542345610213683, 9.507929087597812, 8.60424441910124, 7.678212692200912, 6.703720686744906, 5.940459859409047, 5.000674731547609, 4.071324008139272, 4.93062990701347, 5.910374606048992, 6.888016223722228, 7.829186634915463, 18.308731796134445, 17.615565099950476, 16.727665037692354, 15.750676953604021, 14.8924673228433, 14.424649067558427, 13.467334456378634, 12.505430762186144, 11.555600900983823, 10.579626367978415, 9.65196953153466, 8.680900070065057, 7.751122970831224, 6.924695538618467, 5.972896886610244, 5.067879445098929, 5.951600665048215, 6.961580656077643, 7.905766319460502, 8.890833498137152], [8.85784971553481, 7.910160575646744, 6.886271239531044, 5.931274690014744, 6.870988867425439, 7.8775514919222305, 8.831834378530163, 9.72634635491948, 10.672052992558203, 11.624462074580709, 12.627244951824588, 13.514943084983233, 14.444922770204279, 15.416439300304262, 15.888383152046385, 14.879060157013024, 13.894117274548817, 14.823321447420188, 15.723155531201384, 16.618467866631804, 7.800090736791194, 8.745110694889137, 7.893747850398751, 6.903755879157028, 7.894114166826134, 8.85138063549228, 9.86381407173407, 10.75547169930632, 11.600506431535964, 12.561071759315087, 13.493501340356215, 14.426319474169475, 15.4392798358059, 15.62361561666116, 14.875602982152271, 13.872956784340298, 12.857417463720465, 13.823496304191153, 14.673654666317088, 15.559225990332017, 6.794308949574548, 7.740036955401499, 8.74368313227757, 7.931577535839319, 8.863902422046426, 9.845559548126218, 10.858952631172235, 11.770289369951648, 12.582415054244517, 13.578877984259929, 14.51324629371081, 15.391727088812575, 15.61842558863551, 14.638654145600732, 13.850519703236145, 12.93355819590512, 11.886143839077782, 12.79793417138321, 13.63498665836953, 14.610989576015092, 5.867391525360626, 6.836474860511737, 7.880780297316645, 8.83561535808466, 9.843151679918485, 10.836324812133222, 11.793215925072898, 12.818674064985927, 13.633940582430196, 14.55678964709996, 15.538715302869067, 15.546741954818618, 14.639161329896684, 13.656898467260277, 12.786705513316438, 11.879558123748016, 10.948872744201411, 11.760079638909549, 12.669494477147145, 13.570388803293977, 4.953520624072304, 5.923773646222093, 6.859468910495825, 7.88807992924443, 8.882296150166885, 9.938510287050303, 10.968223136131705, 11.89779139491582, 12.90845787225668, 13.838275850094558, 14.861851102367657, 14.593938840533266, 13.566541210287813, 12.701741186956463, 11.735677644005523, 10.92631209278462, 10.011377020445908, 10.68591661289572, 11.6563517001937, 12.587096019647564, 3.9694440572826037, 4.983284387646485, 5.965308689999053, 6.921202330311142, 7.942889959099832, 8.96777699219965, 10.015309727038693, 10.991181859791224, 11.957769682559668, 12.900496631462092, 13.862903546086665, 13.65924828614966, 12.617541392489631, 11.757333414986126, 10.808240776037868, 9.853142098691569, 8.978624952304255, 9.750077952877534, 10.693516661697275, 11.71983654485038, 4.924616338224416, 5.964250546142202, 6.960508436369284, 7.910207483627467, 8.88762948967691, 9.892847307075522, 10.81793525858022, 11.784793859446003, 12.779832109526467, 13.826879635896535, 13.53383964550847, 12.600672882391846, 11.670934848448534, 10.77460635767091, 9.814371462787019, 8.89881614212759, 7.994748274746867, 8.82505914799785, 9.777404598627625, 10.731397926629196, 5.882827525080087, 6.917030267938483, 7.899897069985495, 8.862332366015025, 9.830958614161792, 10.814257844183413, 11.750348448119404, 12.726432437306514, 13.74019480816609, 13.493827407361248, 12.577777886498376, 11.661338667201667, 10.690731014968343, 9.778558752982436, 8.88828205261488, 7.930988406062092, 7.031834223653516, 7.882041617155652, 8.826149311235579, 9.726592165703606, 6.80258732568022, 7.875300750541127, 8.829941248135007, 9.800591650929736, 10.838375838851794, 11.746856708931082, 12.761486546801793, 13.73173166785742, 13.5468565802468, 12.553804761183732, 11.598676195316129, 10.663185343277622, 9.729165720880198, 8.8216218579701, 7.862407789623505, 6.911307489939703, 6.0547421186433334, 6.914810089498345, 7.871473889197462, 8.715279931068455, 7.867113873555423, 8.81629711760597, 9.830544263185754, 10.755673466683499, 11.804356563637029, 12.789770996153415, 13.733593582239738, 13.67507610475926, 12.6110054739882, 11.66893977044815, 10.686317320652345, 9.722407160783211, 8.726199841228473, 7.750077364798788, 6.868186546186916, 5.954363258572361, 4.994996031511498, 5.947929852743384, 6.94067482757422, 7.722634287281891, 8.720130908333322, 9.75664122777095, 10.789279731421733, 11.728346372896793, 12.739647109522009, 13.673783058699945, 13.645133079081823, 12.72935687361536, 11.755339528803546, 10.717654341907354, 9.66341156048156, 8.714935508733012, 7.729743347057261, 6.763979054073273, 5.846364391686317, 4.977614932705618, 4.045850868392346, 4.953952158641038, 5.943846128432185, 6.795374848554794, 9.667264301698017, 10.632909278916198, 11.620767761933406, 12.681830492379826, 13.686837052117841, 13.630488937144666, 12.6491079471057, 11.756282316548946, 10.79047284425189, 9.807015479079505, 8.785807165447574, 7.820459382586875, 6.865068289768458, 5.792091572410595, 4.850466071476408, 3.983895585735609, 3.051981067479301, 3.9453441257664235, 4.925003869133633, 5.836061626505753, 10.661420529163296, 11.559069475674336, 12.586066083698125, 13.533942327795138, 13.567637303307972, 12.623440417260202, 11.649246104293773, 10.689697509773035, 9.733305983789077, 8.7723967023429, 7.819850615339507, 6.884380485483896, 5.940113348069788, 4.915992924338239, 3.9237282494957917, 2.9746925243885873, 2.0166736511498566, 2.958730153307307, 3.876710359825954, 4.808908034417615, 11.713622524193656, 12.615728833017696, 13.538636812638424, 13.871208053746921, 12.876385312363912, 11.881164433215023, 10.89134143624518, 9.880017433239345, 8.887623785470574, 7.854088929171249, 6.92423791595415, 5.983318825775548, 4.955226839533716, 3.8868848410821375, 2.916682745764217, 1.9721150671201317, 1.0637999124124693, 1.9881051363534301, 2.9159907001767564, 3.9204854818730386, 12.66744841141126, 13.670620834116718, 14.021276865133894, 13.002492963368297, 12.006130344135315, 11.040275219977534, 10.085441970064542, 9.112084127901062, 8.072534749319885, 7.045173986911277, 5.980992901802076, 4.944931640580461, 3.9495090365339145, 3.02230812348004, 1.964864203214629, 1.0083586629426666, 0.0, 0.9642620496172112, 1.94630529435179, 3.005016834361136, 13.612279585481746, 14.588269832424148, 14.96559364433016, 13.93002715257813, 12.99137979588751, 11.961605395689407, 10.908640696690945, 9.86186165983315, 8.869002923007516, 7.923953631234571, 6.876314391706375, 5.83662884287315, 4.891460128293182, 3.8657083327083535, 2.906611181121178, 2.045325099266549, 1.0145716329360797, 2.0346689123051513, 2.9176483508128213, 3.950152377273592, 14.605298984776065, 15.537695470123083, 15.771628441380104, 14.82567446886693, 13.813360719820714, 12.828683875970864, 11.784358194534507, 10.82517396331729, 9.852780071937202, 8.872362635893754, 7.798289882908263, 6.7543569200843905, 5.784599149933126, 4.853005041676237, 3.880402038498305, 2.9282211587414655, 1.9830109248280055, 2.962713696530116, 3.91519351734932, 4.926601964084231, 15.556932755945583, 16.53051965654419, 16.45950531202386, 15.531900490005103, 14.549204827500787, 13.565389239436792, 12.598560552852863, 11.629418689500055, 10.613635323532181, 9.589683397694923, 8.646912629627131, 7.667921668698023, 6.719647461910561, 5.918552086471548, 4.948441286189735, 3.919229202013672, 2.9414269679784737, 3.950315009545088, 4.92446196331732, 5.855656542680442, 16.515427118536387, 17.572694439127012, 16.85915216906905, 15.908543033380852, 15.557547451881398, 14.483863152178422, 13.518020578632123, 12.548529328704232, 11.550704273156349, 10.516287750540478, 9.612603082043906, 8.686571355143577, 7.712079349687572, 6.861557694562347, 5.921772566700909, 4.922187100770608, 3.9222712440708034, 4.902015943106326, 5.879657560779561, 6.820827971972797, 17.443112752170563, 16.749946055986598, 15.866417719573016, 14.889429635484682, 15.826036067976544, 15.433007730501092, 14.4756931193213, 13.51378942512881, 12.563959563926488, 11.58798503092108, 10.660328194477325, 9.689258733007723, 8.75948163377389, 7.845793373771768, 6.893994721763544, 5.918742537730265, 4.943242002105547, 5.953221993134978, 6.897407656517836, 7.882474835194484], [7.893587665917598, 6.9458985260295325, 6.055228453505905, 6.8955367396319565, 7.83525091704265, 8.841813541539443, 9.796096428147374, 10.690608404536691, 11.636315042175415, 12.58872412419792, 13.5915070014418, 14.479205134600445, 15.40918481982149, 16.380701349921473, 16.57707148763994, 15.567748492606581, 14.582805610142374, 13.99039268453975, 14.790438234089683, 15.685750569520101, 6.835828687173983, 7.780848645271926, 7.095394106186681, 7.868017928774241, 8.858376216443345, 9.815642685109491, 10.828076121351282, 11.719733748923531, 12.564768481153175, 13.525333808932299, 14.457763389973426, 15.390581523786686, 16.40354188542311, 16.535193584651662, 15.574243395350058, 14.561645119933855, 13.546105799314022, 12.932734702439339, 13.740937369205387, 14.626508693220316, 5.8300468999573365, 6.775774905784288, 7.779421082660358, 8.80991214025014, 9.828164471663635, 10.809821597743428, 11.823214680789446, 12.73455141956886, 13.546677103861729, 14.54314003387714, 15.477508343328022, 16.355989138429784, 16.552872198781323, 15.550232113591232, 14.558103645228623, 13.622246531498677, 12.57483217467134, 11.865216874271509, 12.702269361257828, 13.67827227890339, 4.903129475743414, 5.872212810894526, 6.916518247699433, 7.871353308467449, 8.878889630301273, 9.872062762516011, 10.828953875455687, 11.857988251094458, 12.896280937689847, 13.854461997820799, 14.827154881827257, 15.8183070855546, 15.573607940042496, 14.568476435250776, 13.494289455308916, 12.568246459341573, 11.637561079794969, 10.827362341797848, 11.736777180035444, 12.637671506182276, 3.9892585744550932, 4.959511596604883, 5.895206860878615, 6.92381787962722, 7.918034100549673, 8.974248237433091, 10.003961086514494, 10.93352934529861, 11.944195822639468, 12.874013800477346, 13.897589052750446, 14.865503971269248, 14.500987820433625, 13.626454580365492, 12.660391037414552, 11.75361658488813, 10.700065356039465, 9.75319931578402, 10.723634403081999, 11.654378722535863, 3.0051820076653923, 4.0190223380292736, 5.001046640381841, 5.956940280693931, 6.97862790948262, 8.003514942582438, 9.051047677421481, 10.026919810174013, 10.993507632942457, 11.93623458184488, 12.898641496469454, 13.8335395301141, 13.551988002635444, 12.682046808395157, 11.732954169446899, 10.769743964557533, 9.817785424297554, 8.817360655765833, 9.760799364585575, 10.768838618996183, 3.960354288607204, 4.99998849652499, 5.996246386752072, 6.945945434010255, 7.923367440059698, 8.92858525745831, 9.85367320896301, 10.820531809828791, 11.815570059909255, 12.862617586279324, 13.89485199881257, 13.535119492537659, 12.605381458594346, 11.69931975107994, 10.73908485619605, 9.815418007993554, 8.891394601701332, 7.892341850886149, 8.844687301515924, 9.780400000774998, 4.918565475462875, 5.952768218321272, 6.9356350203682835, 7.898070316397813, 8.866696564544581, 9.849995794566201, 10.786086398502192, 11.762170387689302, 12.775932758548878, 13.7170777179887, 13.512224496644187, 12.59578527734748, 11.625177625114155, 10.713005363128246, 9.81299544602391, 8.847590271928055, 7.928480550607981, 6.949324320043951, 7.893432014123878, 8.762330116086394, 5.838325276063008, 6.911038700923916, 7.865679198517797, 8.836329601312524, 9.874113789234583, 10.78259465931387, 11.797224497184581, 12.76746961824021, 13.75446055837848, 13.488251371329543, 12.53312280546194, 11.597631953423432, 10.663612331026009, 9.756068468115911, 8.787121183032536, 7.827909355805667, 6.951388445597798, 5.982092792386644, 6.9387565920857615, 7.751017881451244, 6.902851823938212, 7.8520350679887585, 8.866282213568542, 9.791411417066287, 10.840094514019817, 11.825508946536203, 12.769331532622527, 13.771946710182789, 13.545452084134011, 12.60338638059396, 11.620763930798155, 10.656853770929022, 9.660646451374284, 8.684523974944598, 7.8026331563327265, 6.8709651244383245, 5.90280075643043, 5.015212555631683, 5.9910084334051295, 6.7583722376646795, 7.75586885871611, 8.792379178153737, 9.82501768180452, 10.764084323279581, 11.775385059904798, 12.709521009082733, 13.680405050411062, 13.693618923232572, 12.70492181673423, 11.652100952053164, 10.59785817062737, 9.649382118878822, 8.664189957203071, 7.698425664219084, 6.780811001832127, 5.894216798571581, 4.953655593311279, 4.004285764471947, 4.994179734263094, 5.831112798937583, 8.703002252080806, 9.668647229298987, 10.656505712316195, 11.717568442762614, 12.72257500250063, 13.637019461487972, 13.613369996722911, 12.720544366166157, 11.7547348938691, 10.771277528696716, 9.739997650056548, 8.77464986719585, 7.799514899914269, 6.726538182556405, 5.7849126816222185, 4.900497451601573, 3.968582933345265, 2.9956777315973326, 3.9607418195164215, 4.871799576888542, 9.697158479546085, 10.594807426057125, 11.621804034080913, 12.569680278177927, 13.621347492843494, 13.587702466877413, 12.613508153910985, 11.653959559390247, 10.697568033406288, 9.736658751960112, 8.784112664956718, 7.848642535101107, 6.904375397687, 5.88025497395545, 4.858174859641602, 3.9091391345343975, 2.951120261295667, 2.0090637591382166, 2.912448310208743, 3.8446459848004038, 10.749360474576445, 11.651466783400485, 12.574374763021213, 13.545106795660764, 13.840647361981123, 12.845426482832234, 11.85560348586239, 10.844279482856557, 9.851885835087785, 8.81835097878846, 7.888499965571361, 6.9475808753927595, 5.919488889150927, 4.851146890699349, 3.880944795381428, 2.9363771167373427, 2.0280619620296805, 1.023843086736219, 1.9517286505595455, 2.9562234322558276, 11.70318636179405, 12.706358784499507, 13.58647605535419, 13.966755012985509, 12.970392393752526, 12.004537269594746, 11.049704019681753, 10.076346177518273, 9.036796798937097, 8.009436036528488, 6.945254951419288, 5.9091936901976725, 4.913771086151126, 3.9865701730972516, 2.92912625283184, 1.9726207125598778, 0.9642620496172112, 0.0, 0.9820432447345788, 2.0407547847439247, 12.679562288370045, 13.655552535312447, 14.530792834550455, 14.894289202195342, 13.955641845504722, 12.925867445306618, 11.872902746308156, 10.82612370945036, 9.833264972624727, 8.888215680851783, 7.840576441323586, 6.8008908924903615, 5.855722177910393, 4.829970382325564, 3.870873230738389, 3.00958714888376, 1.9788336825532908, 1.0704068626879402, 1.95338630119561, 2.985890327656381, 13.672581687664364, 14.604978173011382, 15.500119072809884, 15.789936518484142, 14.777622769437926, 13.792945925588075, 12.748620244151718, 11.789436012934502, 10.817042121554413, 9.836624685510966, 8.762551932525474, 7.718618969701601, 6.748861199550337, 5.817267091293448, 4.844664088115516, 3.892483208358677, 2.947272974445217, 1.9984516469129048, 2.950931467732109, 3.9623399144670195, 14.624215458833882, 15.597802359432489, 16.53708755364533, 16.496162539622315, 15.513466877117999, 14.529651289054003, 13.562822602470074, 12.593680739117266, 11.577897373149392, 10.553945447312135, 9.611174679244343, 8.632183718315234, 7.683909511527771, 6.882814136088759, 5.912703335806945, 4.8834912516308835, 3.905689017595685, 3.060912469770196, 3.9601999137001087, 4.89139449306323, 15.582709821424684, 16.63997714201531, 16.094361040493652, 16.59723136897441, 16.52180950149861, 15.448125201795634, 14.482282628249335, 13.512791378321444, 12.51496632277356, 11.48054980015769, 10.576865131661117, 9.650833404760789, 8.676341399304784, 7.825819744179558, 6.8860346163181205, 5.886449150387819, 4.886533293688015, 4.064620344044679, 4.91539551116235, 5.8565659223555855, 16.51039545505886, 15.817228758874897, 15.033488956692578, 15.578117971078239, 16.5147244035701, 16.397269780118304, 15.43995516893851, 14.478051474746021, 13.5282216135437, 12.552247080538292, 11.624590244094536, 10.653520782624934, 9.7237436833911, 8.81005542338898, 7.858256771380756, 6.883004587347476, 5.90750405172276, 5.115826394073331, 5.9331456069006245, 6.918212785577273], [6.911544421183018, 5.963855281294953, 6.841696756749825, 7.796693306266125, 8.817294161777228, 9.823856786274021, 10.778139672881952, 11.672651649271272, 12.618358286909995, 13.5707673689325, 14.57355024617638, 15.461248379335025, 16.39122806455607, 17.362744594656053, 17.497970184735554, 16.488647189702192, 15.503704307237985, 14.91129138163536, 14.097256917564843, 14.81560977892324, 5.8537854424394045, 6.798805400537348, 7.755140711673209, 8.745132682914932, 9.778471027305514, 10.79768592984407, 11.81011936608586, 12.701776993658111, 13.546811725887755, 14.507377053666879, 15.439806634708006, 16.372624768521266, 17.38558513015769, 17.456092281747274, 16.49514209244567, 15.482543817029466, 14.467004496409633, 13.85363339953495, 13.047756052680548, 13.756367902623456, 4.848003655222758, 5.793731661049709, 6.797377837925779, 7.827868895515561, 8.882803847054044, 9.864460973133836, 10.84610421327743, 11.821532704503783, 12.805759787571477, 13.803685278348004, 14.738053587798884, 15.797920068580375, 16.835043373027297, 16.471130810686844, 15.479002342324236, 14.543145228594287, 13.49573087176695, 12.78611557136712, 12.009088044732989, 12.80813148830653, 3.9210862310088355, 4.890169566159947, 5.934475002964854, 6.88931006373287, 7.896846385566694, 8.890019517781433, 9.846910630721109, 10.87594500635988, 11.914237692955268, 12.87241875308622, 13.845111637092678, 14.836263840820022, 15.885079993099128, 15.489375132346389, 14.415188152404529, 13.489145156437184, 12.55845977689058, 11.748261038893459, 11.043595863510605, 11.767530715585416, 3.0072153297205144, 3.9774683518703036, 4.913163616144035, 5.94177463489264, 6.935990855815095, 7.992204992698512, 9.021917841779915, 9.951486100564031, 10.96215257790489, 11.891970555742766, 12.915545808015867, 13.88346072653467, 14.869076662977617, 14.547353277461104, 13.581289734510165, 12.67451528198374, 11.620964053135076, 10.67409801287963, 10.03045308655716, 10.784237931939003, 2.0231387629308135, 3.036979093294695, 4.019003395647263, 4.974897035959352, 5.996584664748042, 7.0214716978478595, 8.069004432686903, 9.044876565439434, 10.011464388207878, 10.954191337110302, 11.916598251734875, 12.851496285379522, 13.920076845179436, 13.602945505490768, 12.65385286654251, 11.690642661653143, 10.738684121393165, 9.738259352861444, 9.067618048060735, 9.786795374261603, 2.9783110438726252, 4.017945251790412, 5.014203142017494, 5.963902189275677, 6.9413241953251195, 7.946542012723732, 8.87162996422843, 9.838488565094213, 10.833526815174675, 11.880574341544746, 12.912808754077991, 13.845975517194615, 13.526280155689955, 12.620218448175551, 11.65998355329166, 10.736316705089164, 9.812293298796943, 8.81324054798176, 8.078626621264632, 8.798356756040418, 3.936522230728297, 4.970724973586694, 5.953591775633705, 6.916027071663235, 7.884653319810003, 8.867952549831623, 9.804043153767614, 10.780127142954724, 11.7938895138143, 12.735034473254121, 13.741920971451194, 13.516683974443088, 12.546076322209764, 11.633904060223857, 10.733894143119521, 9.768488969023666, 8.849379247703592, 7.870223017139562, 7.071086081223335, 7.780286871351814, 4.856282031328429, 5.928995456189336, 6.883635953783219, 7.854286356577946, 8.892070544500005, 9.800551414579292, 10.815181252450003, 11.785426373505631, 12.772417313643901, 13.675057119431637, 13.45402150255755, 12.518530650519043, 11.58451102812162, 10.676967165211522, 9.708019880128147, 8.748808052901278, 7.872287142693409, 6.902991489482255, 6.112394713726892, 6.768974636716663, 5.920808579203633, 6.86999182325418, 7.884238968833964, 8.809368172331709, 9.85805126928524, 10.843465701801625, 11.787288287887948, 12.78990346544821, 13.755714168028446, 13.524285077689571, 12.541662627893766, 11.577752468024633, 10.581545148469894, 9.60542267204021, 8.723531853428337, 7.791863821533936, 6.823699453526041, 5.936111252727294, 5.049879297520757, 5.7763289929301, 6.773825613981531, 7.810335933419159, 8.842974437069941, 9.782041078545003, 10.79334181517022, 11.727477764348155, 12.698361805676484, 13.666227558750444, 13.62582051382984, 12.572999649148775, 11.518756867722981, 10.570280815974433, 9.585088654298682, 8.619324361314694, 7.701709698927738, 6.815115495667193, 5.8745542904068895, 4.925184461567558, 4.0530505983787215, 4.849069554203004, 7.7209590073462255, 8.686603984564407, 9.674462467581614, 10.735525198028034, 11.74053175776605, 12.654976216753393, 13.694386937652608, 13.645102953551671, 12.679293481254614, 11.69583611608223, 10.66089634715216, 9.695548564291462, 8.72041359700988, 7.647436879652016, 6.705811378717829, 5.821396148697184, 4.889481630440876, 3.9165764286929434, 2.9786985747818426, 3.8897563321539623, 8.715115234811504, 9.612764181322545, 10.639760789346333, 11.587637033443347, 12.639304248108914, 13.583501134156684, 13.538066741296499, 12.57851814677576, 11.622126620791802, 10.661217339345626, 9.708671252342231, 8.77320112248662, 7.828933985072512, 6.804813561340962, 5.779073556737213, 4.830037831630008, 3.8720189583912776, 2.9299624562338273, 1.9304050654741642, 2.862602740065825, 9.767317229841865, 10.669423538665905, 11.592331518286633, 12.563063550926184, 13.557886292309194, 13.827469727566815, 12.83764673059697, 11.826322727591137, 10.833929079822365, 9.80039422352304, 8.870543210305941, 7.929624120127339, 6.901532133885506, 5.833190135433927, 4.862988040116006, 3.9184203614719215, 3.0086121831156607, 1.9933598239930013, 0.9696854058249665, 1.9741801875212488, 10.72114311705947, 11.724315539764927, 12.60443281061961, 13.522854197011975, 13.952435638487106, 12.986580514329326, 12.031747264416333, 11.058389422252853, 10.018840043671677, 8.991479281263068, 7.927298196153867, 6.891236934932252, 5.895814330885705, 4.968613417831831, 3.9111694975664193, 2.9546639572944566, 1.94630529435179, 0.9820432447345788, 0.0, 1.058711540009346, 11.767306246451808, 12.74329649339421, 13.548749589815875, 14.450388386221809, 14.937685090239299, 13.907910690041195, 12.854945991042733, 11.808166954184939, 10.815308217359306, 9.870258925586361, 8.822619686058164, 7.782934137224941, 6.8377654226449724, 5.812013627060144, 4.852916475472968, 3.991630393618339, 2.9608769272878694, 2.0388663857577067, 0.9713430564610313, 2.0038470829218022, 12.802440897067504, 13.692722131093145, 14.518075828075304, 15.453036952762137, 15.759666014172502, 14.774989170322652, 13.730663488886295, 12.771479257669078, 11.79908536628899, 10.818667930245542, 9.744595177260052, 8.70066221443618, 7.730904444284916, 6.799310336028027, 5.826707332850095, 4.874526453093255, 3.9293162191797952, 2.9669111699826716, 1.9688882229975302, 2.9802966697324407, 13.754074668237022, 14.719877377798074, 15.589505200109196, 16.508029046897644, 16.49551012185258, 15.511694533788583, 14.544865847204655, 13.575723983851846, 12.559940617883973, 11.535988692046715, 10.593217923978923, 9.614226963049815, 8.665952756262351, 7.864857380823338, 6.894746580541525, 5.865534496365461, 4.887732262330264, 4.0293719928399625, 2.9781566689655303, 3.909351248328652, 14.712569030827824, 15.768505288644388, 16.63577112345803, 17.51813006607002, 17.50385274623319, 16.430168446530214, 15.464325872983915, 14.494834623056024, 13.49700956750814, 12.46259304489227, 11.558908376395697, 10.632876649495369, 9.658384644039364, 8.807862988914136, 7.868077861052698, 6.868492395122397, 5.868576538422594, 4.968218303184752, 3.933352266427771, 4.874522677621006, 15.640254664462, 15.124047442350058, 15.954387653788189, 16.49901666817385, 17.435623100665712, 17.379313024852884, 16.42199841367309, 15.460094719480601, 14.51026485827828, 13.534290325272872, 12.606633488829116, 11.635564027359514, 10.705786928125681, 9.792098668123558, 8.840300016115334, 7.865047832082054, 6.889547296457338, 5.9022946973172505, 4.951102362166045, 5.936169540842694], [5.866837646108139, 6.683042180531369, 7.7008127715248635, 8.655809321041163, 9.725390126309682, 10.766504857020168, 11.7207877436281, 12.714226791263282, 13.65139349646175, 14.603802578484256, 15.632261786185724, 16.51995991934437, 17.449939604565415, 18.421456134665398, 18.453613206616147, 17.444290211582786, 16.45934732911858, 15.866934403515954, 14.892315386382728, 13.936944784963769, 4.795151888755116, 5.74017184685306, 6.696507157988921, 7.6864991292306435, 8.719837473621226, 9.79267571345012, 10.782531232706248, 11.777638835139765, 12.72294005748399, 13.683505385263114, 14.615934966304241, 15.548753100117501, 16.601491778955506, 17.648266585688493, 17.450785114326262, 16.43818683891006, 15.422647518290226, 14.809276421415543, 13.842814521498433, 12.877702908663984, 3.78937010153847, 4.735098107365421, 5.738744284241491, 6.769235341831273, 7.824170293369756, 8.805827419449548, 9.787392673268084, 10.762821164494436, 11.74704824756213, 12.744973738338658, 13.67934204778954, 14.73920852857103, 15.776331833017952, 16.771085117717952, 16.43464536420483, 15.498788250474881, 14.451373893647544, 13.741758593247713, 12.804146513550874, 11.929466494347059, 2.8624526773245473, 3.8315360124756586, 4.875841449280566, 5.830676510048582, 6.838134845557348, 7.831307977772085, 8.788199090711762, 9.817233466350533, 10.855526152945922, 11.813707213076874, 12.786400097083332, 13.777552300810676, 14.826368453089781, 15.789329439377495, 15.370831174285122, 14.444788178317777, 13.514102798771173, 12.703904060774052, 11.83865433232849, 10.888865721625944, 1.9485817760362263, 2.9188347981860154, 3.854530062459747, 4.883141081208352, 5.877279315805748, 6.933493452689166, 7.963206301770568, 8.892774560554683, 9.903441037895542, 10.833259015733422, 11.856834268006521, 12.824749186525324, 13.810365122968271, 14.834172159073681, 14.552202819320097, 13.630158303864334, 12.57660707501567, 11.629741034760224, 10.825511555375044, 9.905572937979532, 0.9644272229214675, 1.9782675532853489, 2.9602918556379167, 3.916185495950006, 4.9378731247386956, 5.962760157838513, 7.0102928926775565, 7.986165025430089, 8.952752848198532, 9.895479797100956, 10.857886711725529, 11.792784745370176, 12.86136530517009, 13.87394490899722, 13.624765951352442, 12.661555746463076, 11.694327143273759, 10.693902374742038, 9.86267651687862, 8.908130380302131, 1.9195995038632794, 2.9592337117810654, 3.9554916020081476, 4.905190649266331, 5.882612655315773, 6.887830472714386, 7.812918424219085, 8.779777025084867, 9.77481527516533, 10.8218628015354, 11.854097214068645, 12.787263977185269, 13.807971849211187, 13.591131532985484, 12.630896638101593, 11.707229789899097, 10.767936320677537, 9.768883569862354, 8.873685090082517, 7.919691762080946, 2.9041537178819805, 3.915871697548172, 4.898738499595184, 5.861173795624714, 6.829800043771481, 7.813099273793102, 8.749189877729094, 9.725273866916204, 10.73903623777578, 11.680181197215601, 12.687067695412674, 13.663841373743658, 13.516989407019697, 12.60481714503379, 11.704807227929454, 10.739402053833599, 9.805022269584185, 8.825866039020156, 7.882819473997168, 6.901621877392342, 3.882804451783665, 4.886550967539198, 5.828782677744697, 6.7994330805394245, 7.837217268461482, 8.74569813854077, 9.760327976411483, 10.730573097467111, 11.717564037605381, 12.620203843393117, 13.57533240926072, 13.489443735328976, 12.555424112931552, 11.647880250021455, 10.67893296493808, 9.719721137711211, 8.827930164574003, 7.858634511362848, 6.924128106500725, 5.890309642757192, 4.951769149303855, 5.900952393354402, 6.841744960145389, 7.754514896293188, 8.803197993246718, 9.788612425763104, 10.732435011849429, 11.73505018940969, 12.700860891989926, 13.642926595529977, 13.512575712703699, 12.548665552834565, 11.552458233279827, 10.576335756850142, 9.69444493823827, 8.76277690634387, 7.794612538335974, 6.891754274607887, 5.882845756896565, 4.8976639989706285, 5.895160620022059, 6.913523263013285, 7.914539468135354, 8.727187802506482, 9.738488539131698, 10.672624488309634, 11.643508529637963, 12.611374282711923, 13.607883058084662, 13.543912733958708, 12.489669952532914, 11.541193900784366, 10.556001739108615, 9.590237446124627, 8.67262278373767, 7.786028580477126, 6.845467375216822, 5.896097546377491, 5.01197094030274, 3.970404560243532, 6.842294013386754, 7.807938990604934, 8.795797473622143, 9.77535065301591, 10.706236304343937, 11.600122940714872, 12.639533661614086, 13.584448839778338, 13.650206566064547, 12.666749200892163, 11.631809431962093, 10.666461649101395, 9.691326681819813, 8.618349964461949, 7.676724463527763, 6.792309233507117, 5.860394715250809, 4.887489513502876, 3.937618916705861, 3.0110913381944906, 7.836450240852033, 8.734099187363071, 9.76109579538686, 10.708972039483873, 11.699381087710957, 12.607171460599336, 13.581365773565764, 13.549431231585693, 12.593039705601734, 11.632130424155559, 10.679584337152164, 9.744114207296553, 8.799847069882444, 7.775726646150895, 6.749986641547147, 5.800950916439942, 4.842932043201211, 3.90087554104376, 2.901318150284097, 1.9839377461063534, 8.888652235882393, 9.790758544706431, 10.71366652432716, 11.68439855696671, 12.67922129834972, 13.545608138732389, 13.896358270606319, 12.885034267600485, 11.892640619831713, 10.859105763532387, 9.929254750315287, 8.980091441781127, 7.928299592538065, 6.859957594086486, 5.889755498768565, 4.94518782012448, 3.9795252679255944, 2.9642729088029345, 1.9405984906348994, 0.9361037089386173, 9.842478123099998, 10.845650545805453, 11.725767816660136, 12.644189203052502, 13.640551822285484, 14.04529205433867, 13.090458804425678, 12.117100962262198, 11.077551583681021, 10.050190821272414, 8.986009736163213, 7.949948474941597, 6.954525870895051, 6.027324957841176, 4.969881037575765, 4.0133754973038025, 3.005016834361136, 2.0407547847439247, 1.058711540009346, 0.0, 10.888641252492336, 11.864631499434738, 12.670084595856402, 13.571723392262335, 14.531962998808332, 14.966622230050543, 13.913657531052081, 12.866878494194285, 11.874019757368652, 10.928970465595707, 9.88133122606751, 8.841645677234286, 7.896476962654318, 6.870725167069489, 5.9116280154823135, 5.050341933627685, 4.019588467297216, 3.0452408849949606, 1.9777175556982851, 0.9452135292375141, 11.923775903108032, 12.814057137133673, 13.63941083411583, 14.574371958802663, 15.570498381109475, 15.833700710332, 14.789375028895643, 13.830190797678426, 12.857796906298338, 11.87737947025489, 10.8033067172694, 9.759373754445527, 8.789615984294262, 7.858021876037372, 6.88541887285944, 5.933237993102601, 4.9880277591891415, 3.9732856692199254, 2.975262722234784, 1.9216631160481525, 12.87540967427755, 13.841212383838602, 14.710840206149722, 15.62936405293817, 16.612059715442484, 16.570406073797926, 15.603577387214, 14.63443552386119, 13.618652157893317, 12.59470023205606, 11.651929463988267, 10.672938503059159, 9.724664296271696, 8.923568920832682, 7.95345812055087, 6.924246036374807, 5.907119453392227, 4.898231411825613, 3.837272683740569, 2.8507176946443638, 13.833904036868352, 14.889840294684916, 15.75710612949856, 16.652240151562214, 17.597047961301175, 17.48887998653956, 16.52303741299326, 15.553546163065368, 14.555721107517485, 13.521304584901614, 12.617619916405042, 11.691588189504714, 10.699959786031375, 9.756144081363349, 8.816358953501911, 7.81677348757161, 6.807079016995313, 5.8273343179597905, 4.79246828120281, 3.915250831942267, 14.761589670502529, 15.714957967335213, 16.725053724682684, 17.454659690054445, 18.391266122546305, 18.43802456486223, 17.480709953682435, 16.518806259489946, 15.568976398287624, 14.593001865282217, 13.66534502883846, 12.678283329245453, 11.747362070117692, 10.74037976057277, 9.788581108564546, 8.791972724742223, 7.778355861279695, 6.761410712092289, 5.8102183769410845, 4.976897695163955], [14.895148220988885, 15.711352755412113, 16.749419798362897, 17.68729089325367, 18.602859762659033, 18.42520098179622, 17.48358045810222, 16.466511909026988, 15.551520188304117, 14.618033492385226, 13.574970544613295, 12.53136988044232, 11.601390195221274, 10.590928635579274, 9.64757241492904, 8.733035388230405, 7.78296719889414, 6.853763026022769, 5.835294654234361, 4.877354708776255, 13.823462463635861, 14.768482421733804, 15.724817732869665, 16.71480970411139, 17.579734463258337, 17.648346814500115, 16.635913378258326, 15.60140573249285, 14.656104510148625, 13.695539182369501, 12.763109601328374, 11.830291467515114, 10.820745160082927, 9.77397035334994, 8.813020164048336, 7.800421888632134, 6.784882568012301, 5.99696531146533, 4.9732308514114365, 3.921597977839917, 12.817680676419215, 13.763408682246165, 14.75192792021717, 15.689872760410552, 16.609946208038046, 16.840151366772425, 15.816699708174959, 14.841271216948606, 13.857044133880912, 12.859118643104384, 11.924750333653504, 10.864883852872014, 9.833185422456442, 8.789008882289512, 7.796880413926904, 6.861023300196955, 5.813608943369618, 4.934297352605739, 3.934562843463877, 3.022214491037233, 11.84966136882413, 12.818744703975241, 13.74200253234997, 14.675253937203596, 15.548373053755038, 15.978052452039547, 15.021161339099871, 13.9921269634611, 12.953834276865711, 11.995653216734759, 10.951895638273044, 9.90273731599672, 8.853921163717615, 7.807253203949056, 6.733066224007197, 5.807023228039853, 4.876337848493248, 3.896442820132078, 2.969070662241493, 2.0084763494805946, 10.918225686900023, 11.888478709049812, 12.710313221221035, 13.727718508363367, 14.587517524003438, 15.152096922788106, 14.08116920919384, 13.151600950409724, 12.140934473068866, 11.087985087515724, 10.055407003427783, 8.998249459121912, 7.970851828876457, 6.940182916971534, 5.974119374020595, 4.99239335358641, 3.9388421247377448, 2.9919760844822996, 1.955927885288047, 1.0251835658341817, 9.933876933028646, 10.945270550855088, 11.770564929440948, 12.726458569753037, 13.648111332936384, 14.653418783476756, 14.642525639730389, 13.666653506977857, 12.700065684209413, 11.75733873530699, 10.794931820682416, 9.86003378703777, 8.791453227237856, 7.778873623410724, 6.829780984462466, 5.866510909390041, 4.862626401135932, 3.8622016326042115, 2.9187629237844703, 2.0226261235115817, 8.978704652086835, 9.886079812050701, 10.775365183070717, 11.750090933669835, 12.703371802359307, 13.70858961975792, 14.631656206883008, 14.639655050876836, 13.644616800796372, 12.683721739741433, 11.69044856806241, 10.757281804945785, 9.691367734541489, 8.746286303939959, 7.786051409056068, 6.82083686595402, 5.830795360225496, 4.787220437483896, 3.9077543505805736, 3.011064741732767, 7.994150438068134, 8.929441826283593, 9.824990639850666, 10.783973562012285, 11.752599810159053, 12.693039213119887, 13.629129817055878, 14.605213806242988, 14.528423297919032, 13.58727833847921, 12.580391840282138, 11.603618161951154, 10.63301050971783, 9.673154779473126, 8.712140819228207, 7.765558610365685, 6.732574672134449, 5.730237968326094, 4.915294890621871, 3.999813675924414, 7.01549970416645, 7.958762556292567, 8.894946461701153, 9.79908186248908, 10.748109320727774, 11.760440348372217, 12.737479525631487, 13.707724646687115, 14.609464881703362, 14.409495358218372, 13.454366792350768, 12.518875940312261, 11.584856317914838, 10.607625456855521, 9.579427858760324, 8.620216031533456, 7.666765149194554, 6.6974694959834, 5.873986258118314, 4.998331609735144, 5.9465350066462594, 6.895718250696806, 7.881984179300462, 8.844000046735317, 9.73120916084783, 10.716623593364217, 11.765372490193542, 12.712919037942232, 13.626168027318817, 14.568233730858868, 14.387568408515417, 13.54307538430704, 12.534898696311783, 11.558776219882098, 10.565340359795732, 9.577160262900797, 8.617283553970248, 7.664349732738361, 6.9365016743244485, 5.990977253521708, 5.00239800828621, 6.022531264672925, 6.809189671310497, 7.871327140522024, 8.79591861496285, 9.730054564140787, 10.700938605469116, 11.668804358543076, 12.665313133915815, 13.640676110848933, 14.538653860951563, 14.438552993885121, 13.45336083220937, 12.487596539225382, 11.548224174033857, 10.553908588767541, 9.5664287170894, 8.675276523898097, 7.933330373466484, 6.918236692248804, 4.0463472391055815, 4.948666074762097, 5.881473168153005, 6.8231642900125955, 7.828170849750611, 8.805811490444851, 9.772611788763546, 10.786954405739081, 11.74585692691913, 12.684218124639097, 13.592703788497701, 14.473694461864477, 14.451067964091814, 13.45948402088806, 12.535861199310169, 11.492213036258754, 10.560298518002446, 9.68388455677271, 8.804077492809215, 7.877549914297846, 3.0521910116403026, 4.02250587800396, 4.894045596291358, 5.8419218403883715, 6.893589055053938, 7.836428421534419, 8.77274994595162, 9.732298540472359, 10.688690066456317, 11.649599347902493, 12.602145434905887, 13.537615564761499, 14.481882702175607, 14.424076431129567, 13.462599021290785, 12.55362480757062, 11.59560593433189, 10.670498529231827, 9.836901180977645, 8.904703506385983, 1.9999890166099425, 3.0612248641440125, 3.941474867351058, 4.907948122869469, 5.902770864252478, 6.8979917434013664, 7.83459905105538, 8.777665148120095, 9.770058795888866, 10.80359365218819, 11.73344466540529, 12.76040738034403, 13.812199229587092, 14.88054122803867, 14.458709903912247, 13.514142225268163, 12.548479673069277, 11.655719201633824, 10.797620840626841, 9.952537543553719, 1.0461631293923381, 2.0311358169948175, 2.9293735750180807, 3.9481574767836767, 4.94452009601666, 5.9103752201744415, 6.865208470087433, 7.838566312250914, 8.878115690832091, 9.905476453240698, 10.9696575383499, 12.005718799571515, 13.00114140361806, 13.928342316671936, 14.985786236937347, 14.477898629445628, 13.612279585481746, 12.679562288370043, 11.767306246451808, 10.888641252492336, 0.0, 0.9759902469424024, 1.9850567958218148, 3.0368956987498796, 3.9971353052958767, 5.0269097054939795, 6.0798744044924415, 7.1266534413502365, 8.11951217817587, 9.064561469948815, 10.112200709477012, 11.151886258310236, 12.097054972890206, 13.128765421160427, 14.087862572747602, 15.127585131511182, 14.626851218417826, 13.749969151057984, 12.738649302912838, 11.833854781729851, 1.0438112399246404, 1.9254158846413383, 2.8763832112014125, 3.8223371837145854, 4.834650932760802, 5.819327776610653, 6.863653458047009, 7.822837689264225, 8.795231580644314, 9.775649016687762, 10.849721769673252, 11.893654732497126, 12.86341250264839, 13.79500661090528, 14.767609614083211, 15.83300713071304, 15.595290510309752, 14.678013935282948, 13.736194469449337, 12.790450930100524, 1.9954450110941593, 2.952571131346268, 3.8918563255591083, 4.819461147577864, 5.802156810082179, 6.758697378276189, 7.725526064860118, 8.694667928212926, 9.7104512941808, 10.734403220018057, 11.67717398808585, 12.656164949014958, 13.604439155802421, 14.590076430480284, 15.644931895817692, 16.67898272248771, 16.55370655346022, 15.74047475814024, 14.706060497792942, 13.719505508696736, 2.9653968496355487, 4.001199042192582, 4.938122248907945, 5.84233724620191, 6.787145055940871, 7.757178774747175, 8.723021348293473, 9.692512598221365, 10.690337653769248, 11.661007572863612, 12.640006823989165, 13.566038550889493, 14.585821224045436, 15.529636928713462, 16.4694220565749, 17.4690075225052, 17.53455082955255, 16.696122132012164, 15.661256095255183, 14.78403864599464, 3.8930824832697244, 4.8464507801024075, 5.85654653744988, 6.838664144421221, 7.775270576913083, 8.706323353069845, 9.675968875279386, 10.657772694645942, 11.65274312003425, 12.682389206376435, 13.687731936422583, 14.568725928753636, 15.499647187881397, 16.525913351467292, 17.441644211637534, 18.44519361973523, 18.555521587587293, 17.630198526144664, 16.67900619099346, 15.845685509216327], [15.871138467931287, 15.254029789919024, 15.882419250724196, 16.714185359292724, 17.62686951571663, 17.449210734853818, 16.50759021115982, 15.490521662084586, 14.575529941361715, 13.642043245442823, 12.598980297670892, 11.555379633499916, 10.62539994827887, 9.61493838863687, 8.671582167986637, 7.779831640964862, 6.880772758091543, 6.040188959064297, 5.0217205872758885, 5.797107529671484, 14.799452710578263, 14.311159456240715, 14.84225359804342, 15.74170417015044, 16.603744216315935, 17.56195030410527, 17.39883297547523, 16.364325329709754, 15.419024107365527, 14.458458779586403, 13.526029198545276, 12.593211064732015, 11.619757013880491, 10.612129694634644, 9.719237708928079, 8.776412135574537, 7.760872814954704, 6.931814252152365, 5.908079792098471, 4.841350798735146, 13.793670923361617, 13.306085716753076, 13.775937673274768, 14.71388251346815, 15.633955961095644, 16.563932494126234, 16.792689955117364, 15.817261463891011, 14.833034380823317, 13.83510889004679, 12.900740580595908, 11.840874099814418, 10.809175669398845, 9.764999129231917, 8.772870660869307, 7.8370135471393585, 6.789599190312021, 5.910287599548142, 4.91055309040628, 3.941967311932462, 12.825651615766532, 12.243284371920073, 12.766012285407568, 13.699263690261194, 14.572382806812634, 15.565555939027371, 15.997151586042273, 14.968117210403502, 13.929824523808113, 12.971643463677161, 11.927885885215447, 10.878727562939124, 9.829911410660019, 8.78324345089146, 7.7090564709496, 6.783013474982256, 5.8523280954356505, 4.872433067074481, 3.945060909183896, 2.984466596422997, 11.894215933842425, 11.232293047083404, 11.734322974278633, 12.751728261420965, 13.611527277061034, 14.666505512922566, 15.057159456136242, 14.127591197352126, 13.116924720011268, 12.063975334458126, 11.031397250370185, 9.974239706064314, 8.94684207581886, 7.916173163913937, 6.950109620962998, 5.968383600528813, 4.914832371680148, 3.9679663314247025, 2.9319181322304497, 2.0011738127765843, 10.909867179971048, 10.228845484980928, 10.794574682498546, 11.750468322810635, 12.67212108599398, 13.677428536534352, 14.611934420876942, 14.64264375392026, 13.676055931151815, 12.733328982249391, 11.770922067624818, 10.836024033980172, 9.767443474180258, 8.754863870353127, 7.805771231404869, 6.842501156332444, 5.838616648078335, 4.838191879546614, 3.894753170726873, 2.998616370453984, 9.954694899029237, 9.16965474617654, 9.799374936128315, 10.774100686727433, 11.727381555416903, 12.732599372815516, 13.655665959940604, 14.622524560806387, 14.620607047738774, 13.659711986683835, 12.666438815004813, 11.73327205188819, 10.667357981483892, 9.722276550882363, 8.762041655998472, 7.796827112896423, 6.806785607167898, 5.763210684426298, 4.883744597522977, 3.98705498867517, 8.970140685010536, 8.213016760409433, 8.849000392908264, 9.807983315069881, 10.776609563216649, 11.717048966177483, 12.653139570113474, 13.629223559300584, 14.64298593016016, 14.563268585421614, 13.556382087224542, 12.579608408893558, 11.609000756660233, 10.64914502641553, 9.68813106617061, 8.741548857308086, 7.708564919076851, 6.706228215268496, 5.8912851375642745, 4.975803922866816, 7.991489951108852, 7.242337490418407, 7.918956214758751, 8.823091615546677, 9.77211907378537, 10.784450101429814, 11.761489278689083, 12.731734399744711, 13.633474634760958, 14.620449272110388, 14.43035703929317, 13.494866187254663, 12.56084656485724, 11.583615703797923, 10.555418105702726, 9.596206278475858, 8.642755396136955, 7.673459742925802, 6.8499765050607175, 5.974321856677546, 6.922525253588661, 6.1792931848226464, 6.90599393235806, 7.8680097997929135, 8.755218913905427, 9.740633346421813, 10.789382243251138, 11.736928790999828, 12.650177780376413, 13.592243483916464, 14.57486593371227, 14.519065631249441, 13.510888943254185, 12.5347664668245, 11.541330606738134, 10.5531505098432, 9.59327380091265, 8.640339979680764, 7.912491921266852, 6.96696750046411, 5.978388255228612, 5.166722315163764, 5.833199424368094, 6.89533689357962, 7.819928368020447, 8.754064317198383, 9.724948358526712, 10.692814111600672, 11.689322886973411, 12.66468586390653, 13.56266361400916, 14.486515027654363, 14.429351079151772, 13.463586786167784, 12.524214420976259, 11.529898835709943, 10.542418964031802, 9.6512667708405, 8.909320620408888, 7.894226939191206, 5.0223374860479835, 4.0928571252529355, 4.905482921210602, 5.847174043070192, 6.8521806028082075, 7.8298212435024475, 8.796621541821143, 9.810964158796677, 10.769866679976728, 11.708227877696695, 12.6167135415553, 13.497704214922075, 14.472839182203657, 14.435474267830463, 13.511851446252571, 12.468203283201156, 11.536288764944848, 10.659874803715114, 9.780067739751619, 8.853540161240248, 4.028181258582705, 3.1666969284947983, 3.918055349348955, 4.865931593445969, 5.917598808111535, 6.860438174592015, 7.796759699009217, 8.756308293529957, 9.712699819513915, 10.67360910096009, 11.626155187963485, 12.561625317819097, 13.505892455233205, 14.530012878964754, 14.438589268233187, 13.529615054513021, 12.571596181274291, 11.64648877617423, 10.812891427920047, 9.880693753328385, 2.975979263552345, 2.1100375711514374, 2.965484620408655, 3.9319578759270657, 4.926780617310075, 5.922001496458963, 6.858608804112977, 7.801674901177691, 8.794068548946463, 9.827603405245789, 10.757454418462888, 11.784417133401629, 12.83620898264469, 13.904550981096268, 14.874753076414189, 14.490132472210565, 13.52446992001168, 12.631709448576228, 11.773611087569243, 10.92852779049612, 2.0221533763347406, 1.0551455700524153, 1.9533833280756783, 2.9721672298412742, 3.9685298490742578, 4.934384973232039, 5.88921822314503, 6.862576065308511, 7.9021254438896875, 8.929486206298296, 9.993667291407498, 11.029728552629113, 12.025151156675658, 12.952352069729534, 14.009795989994945, 14.966301530266907, 14.588269832424148, 13.655552535312447, 12.74329649339421, 11.864631499434738, 0.9759902469424024, 0.0, 1.0090665488794124, 2.060905451807477, 3.021145058353474, 4.050919458551577, 5.103884157550039, 6.150663194407834, 7.143521931233467, 8.088571223006412, 9.136210462534608, 10.175896011367833, 11.1210647259478, 12.152775174218021, 13.111872325805196, 14.151594884568777, 15.185881756984266, 14.725959398000388, 13.71463954985524, 12.809845028672253, 1.96356406081987, 0.9494256376989358, 1.90039296425901, 2.846346936772183, 3.858660685818399, 4.843337529668249, 5.887663211104606, 6.846847442321821, 7.81924133370191, 8.799658769745358, 9.87373152273085, 10.917664485554724, 11.887422255705989, 12.819016363962877, 13.79161936714081, 14.857016883770639, 15.8022271176841, 15.654004182225352, 14.71218471639174, 13.766441177042926, 2.9151978319893885, 1.9765808844038655, 2.9158660786167063, 3.8434709006354626, 4.826166563139778, 5.782707131333785, 6.749535817917714, 7.718677681270523, 8.734461047238396, 9.758412973075654, 10.701183741143446, 11.680174702072554, 12.628448908860017, 13.61408618353788, 14.668941648875288, 15.702992475545306, 16.74309534576453, 16.716465005082643, 15.682050744735344, 14.695495755639138, 3.8851496705307778, 3.0252087952501787, 3.9621320019655433, 4.866346999259508, 5.811154808998469, 6.781188527804772, 7.7470311013510695, 8.716522351278961, 9.714347406826844, 10.685017325921208, 11.66401657704676, 12.59004830394709, 13.609830977103032, 14.553646681771058, 15.493431809632495, 16.493017275562796, 17.502711746139095, 17.672112378954566, 16.637246342197585, 15.760028892937042, 4.812835304164953, 3.994930062490674, 5.0050258198381465, 5.885460397155678, 6.82206682964754, 7.730333106127442, 8.699978628336984, 9.681782447703538, 10.676752873091846, 11.706398959434031, 12.71174168948018, 13.592735681811234, 14.523656940938995, 15.54992310452489, 16.465653964695132, 17.46920337279283, 17.70221804720192, 16.82182131015677, 16.26678270904793, 16.82167575615873], [16.608127245911604, 15.682688432508572, 14.873352701844782, 15.70511881041331, 16.61780296683722, 16.518144008854236, 15.576523485160235, 14.559454936085004, 13.644463215362133, 12.710976519443243, 11.667913571671312, 10.624312907500336, 9.69433322227929, 8.68387166263729, 7.740515441987057, 6.9047211726414774, 6.005662289768158, 5.190989889596061, 5.992588514396456, 6.767975456792051, 15.53644148855858, 14.739818098830263, 13.833187049164007, 14.732637621271026, 15.594677667436525, 16.55288375522586, 16.46776624947565, 15.433258603710172, 14.487957381365947, 13.527392053586823, 12.594962472545696, 11.662144338732436, 10.688690287880911, 9.681062968635064, 8.788170982928499, 7.910824545314203, 7.0423621005965105, 6.2486478716964715, 6.878947719219038, 5.812218725855713, 14.530659701341934, 13.734744359342624, 12.766871124395355, 13.704815964588736, 14.624889412216234, 15.554865945246826, 16.51257408564396, 16.4480762743555, 15.4698660040745, 14.545198278531664, 13.621596195353263, 12.627551953375535, 11.715609000685582, 10.666024439695493, 9.781937209748719, 8.84608009601877, 7.798665739191433, 6.909826772631827, 5.909983581431939, 4.912835239053029, 13.562640393746848, 12.67194301450962, 11.756945736528156, 12.690197141381782, 13.563316257933224, 14.556489390147961, 15.513380503087637, 15.977183759282916, 14.938891072687527, 13.980710012556575, 12.93695243409486, 11.887794111818536, 10.83897795953943, 9.792309999770872, 8.718123019829012, 7.792080023861668, 6.861394644315062, 5.8753751091353, 4.948002951244715, 3.969342169422525, 12.631204711822742, 11.660951689672952, 10.725256425399222, 11.742661712541553, 12.602460728181624, 13.657438964043155, 14.555781281090544, 15.13665774623154, 14.125991268890681, 13.07304188333754, 12.040463799249599, 10.983306254943727, 9.955908624698273, 8.92523971279335, 7.95917616984241, 6.977450149408225, 5.92389892055956, 4.977032880304114, 3.9409846811098617, 3.0102403616559963, 11.715320276392713, 10.767532435971702, 9.785508133619134, 10.741401773931223, 11.66305453711457, 12.668361987654942, 13.602867871997532, 14.578740004750063, 14.685122480031227, 13.742395531128803, 12.77998861650423, 11.845090582859584, 10.77651002305967, 9.763930419232539, 8.81483778028428, 7.851567705211856, 6.847683196957747, 5.847258428426026, 4.903819719606285, 4.007682919333396, 10.760147995450902, 9.779438631842972, 8.790308387248903, 9.765034137848021, 10.718315006537493, 11.723532823936106, 12.646599411061194, 13.613458011926976, 14.608496262007439, 14.668778535563247, 13.675505363884225, 12.742338600767601, 11.676424530363304, 10.731343099761775, 9.771108204877883, 8.805893661775835, 7.81585215604731, 6.77227723330571, 5.892811146402389, 4.985888914573271, 9.775593781432201, 8.822800646075864, 7.839933844028852, 8.798916766190471, 9.767543014337239, 10.707982417298073, 11.644073021234064, 12.620157010421174, 13.63391938128075, 14.551405369408494, 14.565448636103953, 13.58867495777297, 12.618067305539645, 11.658211575294942, 10.697197615050023, 9.7506154061875, 8.717631467956263, 7.715294764147908, 6.86267504726907, 5.853922939141101, 8.796943047530517, 7.887913591296213, 6.909889665879339, 7.814025066667266, 8.76305252490596, 9.775383552550403, 10.752422729809673, 11.722667850865301, 12.624408085881548, 13.611382723230978, 14.499001000997508, 14.503932736134077, 13.569913113736654, 12.592682252677337, 11.56448465458214, 10.605272827355272, 9.65182194501637, 8.682526291805214, 7.813593416842745, 6.779774953099212, 7.727978350010327, 6.869342248798348, 5.896927383478648, 6.858943250913503, 7.746152365026017, 8.731566797542403, 9.780315694371728, 10.727862242120418, 11.641111231497003, 12.583176935037054, 13.565799384832859, 14.48492013082515, 14.5199554921336, 13.543833015703914, 12.550397155617548, 11.562217058722613, 10.602340349792062, 9.649406528560176, 8.757602354811711, 7.772420596885775, 6.783841351650278, 5.856771379139465, 4.824132875488682, 5.886270344700209, 6.810861819141037, 7.744997768318973, 8.715881809647302, 9.683747562721262, 10.680256338094, 11.655619315027119, 12.553597065129749, 13.477448478774951, 14.46147976520669, 14.472653335047198, 13.533280969855673, 12.538965384589357, 11.551485512911214, 10.660333319719912, 9.754431053953747, 8.699680035612872, 5.82779058246965, 4.862145605251469, 3.89641637233119, 4.838107494190781, 5.8431140539287965, 6.820754694623037, 7.787554992941732, 8.801897609917265, 9.760800131097316, 10.699161328817283, 11.607646992675887, 12.488637666042663, 13.463772633324245, 14.485538740326849, 14.520917995131983, 13.477269832080568, 12.54535531382426, 11.657146739395278, 10.585520836173284, 9.658993257661914, 4.9063002748569895, 3.9359854084933317, 2.908988800469543, 3.856865044566557, 4.908532259232123, 5.851371625712604, 6.7876931501298055, 7.747241744650545, 8.703633270634503, 9.664542552080679, 10.617088639084074, 11.552558768939685, 12.496825906353793, 13.520946330085343, 14.546686334689092, 14.517977290497557, 13.559958417258827, 12.617901915101376, 11.618344524341712, 10.68614684975005, 3.9638245086791724, 2.902588661145102, 1.956418071529243, 2.9228913270476538, 3.9177140684306635, 4.912934947579552, 5.849542255233565, 6.792608352298279, 7.785002000067051, 8.818536856366375, 9.748387869583475, 10.775350584522215, 11.827142433765276, 12.895484432216854, 13.865686527534775, 14.810254206178861, 14.512832155996215, 13.602738602158944, 12.579064183990909, 11.733980886917786, 3.031219925214153, 1.9856960226175546, 0.9443167791962659, 1.9631006809618619, 2.9594633001948454, 3.9253184243526267, 4.880151674265618, 5.853509516429099, 6.893058895010276, 7.920419657418884, 8.984600742528084, 10.020662003749699, 11.016084607796245, 11.94328552085012, 13.000729441115531, 13.957234981387494, 14.965593644330161, 14.530792834550454, 13.548749589815875, 12.670084595856403, 1.9850567958218148, 1.0090665488794124, 0.0, 1.0518389029280648, 2.012078509474062, 3.0418529096721647, 4.094817608670627, 5.141596645528422, 6.134455382354055, 7.079504674127, 8.127143913655196, 9.16682946248842, 10.11199817706839, 11.143708625338611, 12.102805776925786, 13.142528335689367, 14.176815208104856, 15.204107935442034, 14.520092646276906, 13.615298125093918, 2.934431987940437, 1.9202935648195032, 0.9693262382594289, 1.915280210772602, 2.927593959818818, 3.9122708036686684, 4.956596485105026, 5.915780716322241, 6.8881746077023305, 7.868592043745778, 8.942664796731268, 9.986597759555142, 10.956355529706407, 11.887949637963295, 12.860552641141227, 13.925950157771057, 14.871160391684517, 15.927843728327728, 15.517637812813405, 14.503429955023243, 3.8860657591099557, 2.947448811524433, 2.0407556102933215, 2.968360432312078, 3.9510560948163933, 4.851640405334205, 5.818469091918134, 6.787610955270943, 7.803394321238816, 8.827346247076074, 9.770117015143866, 10.749107976072974, 11.697382182860437, 12.6830194575383, 13.737874922875708, 14.771925749545726, 15.812028619764952, 16.820916661331566, 16.41903952271566, 15.432484533619455, 4.856017597651345, 3.9960767223707463, 3.0870215336421585, 3.9912365309361233, 4.9360443406750845, 5.850121801805192, 6.81596437535149, 7.785455625279381, 8.783280680827264, 9.753950599921628, 10.73294985104718, 11.65898157794751, 12.678764251103452, 13.622579955771478, 14.562365083632915, 15.561950549563216, 16.571645020139513, 16.863960811306008, 17.3742351201779, 16.49701767091736, 5.7837032312855206, 4.965797989611241, 4.147893617443232, 5.0103499288322935, 5.946956361324156, 6.799266380127862, 7.768911902337403, 8.750715721703958, 9.745686147092266, 10.775332233434451, 11.7806749634806, 12.661668955811653, 13.592590214939413, 14.618856378525308, 15.53458723869555, 16.538136646793248, 16.693151498322507, 15.812754761277356, 16.69544135163748, 17.558664534139048], [17.488799357706164, 16.56336054430313, 15.754024813639342, 14.804163251775137, 15.623689275049124, 15.527489067520147, 14.585868543826146, 13.568799994750915, 12.653808274028044, 11.72032157810915, 10.677258630337219, 9.633657966166243, 8.703678280945198, 7.693216721303199, 6.749860500652965, 5.994001401005234, 5.094942518131915, 6.024146691003286, 6.969670379779453, 7.747251757586123, 16.41711360035314, 15.620490210624823, 14.713859160958567, 13.831682062632852, 14.600563975648429, 15.558770063437764, 15.477111308141556, 14.44260366237608, 13.497302440031854, 12.53673711225273, 11.604307531211603, 10.671489397398343, 9.698035346546819, 8.690408027300972, 7.797516041594406, 7.00010477367796, 6.131642328960267, 7.081804673103696, 7.858224020013111, 6.791495026649785, 15.411331813136494, 14.615416471137184, 13.647543236189914, 12.803860405950562, 13.630775720428138, 14.56075225345873, 15.518460393855863, 15.457421333021408, 14.479211062740408, 13.554543337197572, 12.63094125401917, 11.636897012041443, 10.72495405935149, 9.6753694983614, 8.822599320510532, 7.93950336211314, 7.10291595360295, 7.889103073425899, 6.8892598822260105, 5.892111539847101, 14.443312505541408, 13.55261512630418, 12.637617848322714, 11.789241582743607, 12.569202566145128, 13.562375698359865, 14.519266811299541, 15.440419927536183, 15.490636060168555, 14.532455000037602, 13.64820187119306, 12.599043548916736, 11.703793136470416, 10.657125176701857, 9.702867850087934, 8.776824854120589, 7.8461394745739845, 6.854651409929372, 5.927279252038787, 4.948618470216597, 13.511876823617301, 12.541623801467512, 11.60592853719378, 10.841706153903377, 11.608347036393528, 12.66332527225506, 13.561667589302449, 14.491235848086564, 15.177830171818746, 14.124880786265605, 13.092302702177664, 12.035145157871792, 11.00774752762634, 9.977078615721416, 9.011015072770476, 8.02928905233629, 6.975737823487625, 6.02887178323218, 4.992823584037927, 4.062079264584061, 12.616959072798647, 11.648204547766259, 10.666180245413692, 9.840446215293047, 10.668940845326475, 11.674248295866846, 12.608754180209436, 13.584626312961968, 14.551214135730412, 14.794234434056868, 13.831827519432295, 12.896929485787648, 11.828348925987735, 10.815769322160603, 9.866676683212345, 8.903406608139921, 7.899522099885812, 6.899097331354091, 5.95565862253435, 5.059521822261461, 11.661786791856835, 10.66011074363753, 9.670980499043461, 8.851441061976724, 9.724201314749397, 10.72941913214801, 11.652485719273098, 12.61934432013888, 13.614382570219345, 14.541727075519512, 14.72734426681229, 13.794177503695666, 12.728263433291369, 11.78318200268984, 10.822947107805948, 9.8577325647039, 8.864272204374776, 7.820697281633176, 6.868351831003403, 5.91435850300183, 10.677232577838135, 9.703472757870422, 8.72060595582341, 7.804803074402376, 8.773429322549143, 9.713868725509977, 10.649959329445968, 11.626043318633078, 12.639805689492654, 13.556759707339795, 14.453239640895399, 14.640513860701034, 13.66990620846771, 12.710050478223007, 11.749036517978087, 10.74374217979452, 9.710758241563285, 8.70842153775493, 7.764313843675002, 6.755561735547033, 9.69858184393645, 8.768585703090773, 7.790561777673898, 6.819911374879171, 7.768938833117865, 8.781269860762308, 9.757777067740976, 10.728022188796604, 11.62976242381285, 12.61673706116228, 13.474137949713151, 14.409628801751659, 14.559282834879234, 13.582051973819917, 12.55385437572472, 11.594642548497852, 10.64119166615895, 9.671896012947796, 8.715232213248678, 7.681413749505144, 8.62961714641626, 7.770981045204281, 6.798566179884581, 5.864829559125408, 6.752038673237921, 7.737453105754306, 8.785670032303031, 9.73321658005172, 10.646465569428305, 11.588531272968355, 12.540936333548503, 13.44935363907312, 14.441676775554495, 14.533202736846494, 13.539766876760128, 12.551586779865193, 11.591710070934644, 10.638776249702758, 9.659241151217644, 8.674059393291708, 7.685480148056211, 6.758410175545398, 5.7257716718946154, 4.892156652912114, 5.816748127352941, 6.750352106250276, 7.721236147578604, 8.689101900652563, 9.685610676025302, 10.620052823275088, 11.518030573377718, 12.44188198702292, 13.42591327345466, 14.391677566438647, 14.522650690998253, 13.528335105731937, 12.540855234053796, 11.645963820150827, 10.65606985035968, 9.601318832018805, 6.729429378875582, 5.763784401657402, 4.798055168737124, 3.8439938024026854, 4.849000362140702, 5.822853653845037, 6.751988501189702, 7.766331118165236, 8.725233639345285, 9.663594837065252, 10.572080500923857, 11.453071174290633, 12.428206141572215, 13.449972248574818, 14.391597749509005, 14.463605255805453, 13.531690737549145, 12.558785535801212, 11.487159632579218, 10.560632054067847, 5.807939071262922, 4.837624204899265, 3.810627596875476, 2.862751352778462, 3.9052521051339815, 4.815805133960574, 5.752126658377776, 6.711675252898515, 7.668066778882473, 8.628976060328649, 9.581522147332043, 10.516992277187654, 11.461259414601763, 12.485379838333312, 13.511119842937061, 14.460155568044266, 14.46159721366476, 13.51954071150731, 12.519983320747645, 11.587785646155984, 4.89229409710773, 3.8310582495736605, 2.8848876599578013, 1.8873248352956242, 2.882147576678634, 3.877368455827522, 4.813975763481536, 5.7570418605462494, 6.749435508315021, 7.782970364614346, 8.712821377831446, 9.739784092770186, 10.791575942013248, 11.859917940464825, 12.830120035782747, 13.774687714426832, 14.740350266625718, 14.504377398564877, 13.480702980396842, 12.63561968332372, 4.048580746075387, 2.9876973343967173, 1.9463180909754283, 0.9275341892098324, 1.9238968084428159, 2.889751932600597, 3.8445851825135886, 4.81794302467707, 5.857492403258247, 6.884853165666855, 7.949034250776056, 8.985095511997672, 9.98051811604422, 10.907719029098095, 11.965162949363506, 12.921668489635469, 13.930027152578136, 14.894289202195347, 14.450388386221809, 13.571723392262337, 3.0368956987498796, 2.060905451807477, 1.0518389029280648, 0.0, 0.9602396065459968, 1.9900140067440997, 3.042978705742562, 4.089757742600357, 5.08261647942599, 6.027665771198935, 7.075305010727131, 8.114990559560356, 9.060159274140325, 10.091869722410546, 11.050966873997721, 12.090689432761302, 13.12497630517679, 14.152269032513969, 15.219792361810644, 14.515245070416015, 3.913708288734509, 2.899569865613575, 1.9486025390535011, 1.002648566540328, 1.9987749888471407, 2.921615862334577, 3.965941543770934, 4.92512577498815, 5.897519666368239, 6.877937102411686, 7.952009855397177, 8.99594281822105, 9.965700588372314, 10.897294696629203, 11.869897699807135, 12.935295216436964, 13.880505450350425, 14.937188786993636, 15.938376271535008, 15.384102066817803, 4.865342059904028, 3.9245306769074313, 2.9852454826945904, 2.057640660675834, 3.0403363231801492, 3.8609854640001133, 4.827814150584042, 5.7969560139368514, 6.812739379904725, 7.836691305741983, 8.779462073809775, 9.758453034738883, 10.706727241526346, 11.69236451620421, 12.747219981541617, 13.781270808211636, 14.82137367843086, 15.830261719997473, 16.891220448082517, 16.313156645414015, 5.835293898445417, 4.973158587753744, 4.031125894988076, 3.08051675929988, 4.025324569038841, 4.8594668604711, 5.825309434017399, 6.79480068394529, 7.7926257394931735, 8.763295658587538, 9.74229490971309, 10.668326636613418, 11.688109309769361, 12.631925014437387, 13.571710142298825, 14.571295608229125, 15.580990078805423, 16.560734777840945, 17.595600814597926, 17.37768978271192, 6.7629795320795925, 5.942879854994239, 5.081747764167392, 4.09963015719605, 5.036236589687912, 5.80861143879377, 6.778256961003311, 7.7600607803698685, 8.755031205758176, 9.78467729210036, 10.790020022146509, 11.671014014477564, 12.601935273605324, 13.628201437191219, 14.54393229736146, 15.547481705459157, 15.792195939684333, 16.693426873071918, 17.576113463432037, 18.439336645933608], [18.449038964252157, 17.523600150849127, 16.71426442018534, 15.76440285832113, 14.862205863965535, 14.56724946097415, 13.62562893728015, 12.608560388204918, 11.693568667482047, 10.760081971563155, 9.717019023791224, 8.673418359620248, 7.743438674399202, 6.732977114757202, 5.789620894106968, 5.156114605929465, 6.055182124677912, 6.984386297549283, 7.92990998632545, 8.707491364132121, 17.377353206899134, 16.58072981717082, 15.674098767504564, 14.791921669178846, 13.83908056456484, 14.797286652354176, 14.516871701595559, 13.482364055830084, 12.537062833485859, 11.576497505706735, 10.644067924665608, 9.711249790852348, 8.737795740000822, 7.730168420754975, 6.837276435048409, 6.162217978602191, 7.091881935506264, 8.042044279649694, 8.818463626559108, 7.751734633195782, 16.37157141968249, 15.575656077683181, 14.607782842735912, 13.764100012496556, 12.86929230934455, 13.799268842375142, 14.689374185956382, 14.497181726475413, 13.518971456194413, 12.594303730651578, 11.670701647473177, 10.676657405495448, 9.764714452805492, 8.715129891815403, 7.862359713964535, 7.101616567037371, 8.063155560148948, 8.849342679971896, 7.8494994887720075, 6.852351146393098, 15.403552112087405, 14.512854732850178, 13.597857454868711, 12.749481189289602, 11.80771915506154, 12.800892287276277, 13.69018060340006, 14.60199583325364, 14.530396453622561, 13.572215393491609, 12.687962264647064, 11.63880394237074, 10.74355352992442, 9.69688557015586, 8.926173903884242, 8.156640260100183, 8.806379081119982, 7.814891016475369, 6.887518858584784, 5.908858076762594, 14.472116430163299, 13.50186340801351, 12.566168143739777, 11.801945760449373, 10.84686362530994, 11.872587831435796, 12.723243495019906, 13.652811753804022, 14.66347823114488, 14.586710003526097, 13.617528093723875, 12.591607056656093, 11.682711762364598, 10.652042850459674, 9.971254679316473, 8.989528658882287, 7.935977430033622, 6.989111389778177, 5.953063190583924, 5.022318871130058, 13.577198679344642, 12.608444154312256, 11.626419851959689, 10.800685821839043, 9.907457434242886, 10.883510855047582, 11.770330085926894, 12.746202218679425, 13.71279004144787, 14.58834859449106, 14.558469531455888, 13.623571497811241, 12.624849704363266, 11.612270100536135, 10.826916289758342, 9.863646214685918, 8.859761706431808, 7.859336937900088, 6.915898229080347, 6.019761428807458, 12.62202639840283, 11.620350350183527, 10.631220105589458, 9.811680668522719, 8.962717903665808, 9.938681691328746, 10.814061624990556, 11.780920225856338, 12.7759584759368, 13.661965590056617, 14.636459251765276, 14.618547695590332, 13.552633625186035, 12.607552194584505, 11.783186714351945, 10.817972171249897, 9.824511810920773, 8.780936888179173, 7.8285914375494, 6.8745981095478275, 11.63747218438413, 10.66371236441642, 9.680845562369408, 8.765042680948373, 8.011945911465554, 8.875444631227435, 9.811535235163426, 10.787619224350536, 11.801381595210112, 12.6769982218769, 13.568988507560864, 14.538262768562543, 14.532837458666226, 13.637221834149939, 12.709276124524084, 11.703981786340517, 10.67099784810928, 9.668661144300925, 8.724553450220998, 7.715801342093029, 10.658821450482446, 9.728825309636768, 8.750801384219894, 7.780150981425168, 6.977614263893262, 7.942845766479765, 8.90030341999366, 9.870548541049288, 10.750000938349954, 11.736975575699384, 12.589886816378616, 13.525377668417123, 14.459397290814547, 14.542291580365914, 13.514093982270717, 12.554882155043849, 11.601431272704946, 10.632135619493793, 9.675471819794675, 8.64165335605114, 9.589856752962255, 8.731220651750277, 7.758805786430576, 6.825069165671405, 5.960714104013318, 6.895437044341232, 7.928196384555715, 8.875742932304405, 9.76670408396541, 10.70876978750546, 11.656685200213968, 12.565102505738585, 13.55742564221996, 14.493524743829626, 14.500006483306125, 13.51182638641119, 12.551949677480641, 11.599015856248755, 10.61948075776364, 9.634298999837704, 8.645719754602206, 7.718649782091394, 6.686011278440612, 5.852396259458112, 5.025423558128338, 5.894192480652215, 6.863762499831289, 7.831628252905248, 8.805849190562407, 9.735801689940553, 10.633779440043183, 11.557630853688385, 12.541662140120124, 13.507426433104111, 14.446798798295637, 14.488574712277934, 13.501094840599793, 12.606203426696823, 11.616309456905675, 10.5615584385648, 7.689668985421578, 6.724024008203398, 5.75829477528312, 4.804233408948683, 4.057675792916098, 4.966694028246977, 5.867737367855166, 6.8820799848307, 7.84098250601075, 8.779343703730717, 9.687829367589321, 10.568820040956098, 11.54395500823768, 12.565721115240283, 13.50734661617447, 14.550994779225885, 14.49193034409514, 13.519025142347207, 12.447399239125213, 11.520871660613842, 6.768178677808918, 5.797863811445261, 4.7708672034214725, 3.822990959324459, 3.0645310095490776, 3.959645508362514, 4.86787552504324, 5.827424119563979, 6.783815645547937, 7.744724926994113, 8.697271013997508, 9.632741143853119, 10.577008281267227, 11.601128704998777, 12.626868709602526, 13.57590443470973, 14.533923307948461, 14.479780318053304, 13.48022292729364, 12.54802525270198, 5.8525337036537275, 4.791297856119657, 3.8451272665037983, 2.8475644418416213, 2.0414264810937306, 3.0212088302294617, 3.9297246301469992, 4.872790727211713, 5.865184374980485, 6.89871923127981, 7.82857024449691, 8.85553295943565, 9.90732480867871, 10.969121538627384, 11.939323633945305, 12.883891312589391, 13.849553864788277, 14.864806223910936, 14.440942586942839, 13.595859289869715, 5.008820352621384, 3.9479369409427143, 2.9065576975214253, 1.8877737957558294, 1.0396456751082794, 2.005500799266061, 2.9603340491790524, 3.9336918913425336, 4.97324126992371, 6.000602032332318, 7.064783117441519, 8.100844378663135, 9.041870759353595, 9.96907167240747, 11.026515592672881, 11.983021132944844, 12.99137979588751, 13.955641845504722, 14.9376850902393, 14.531962998808332, 3.9971353052958767, 3.0211450583534742, 2.012078509474062, 0.9602396065459968, 0.0, 1.0297744001981028, 2.082739099196565, 3.12951813605436, 4.122376872879993, 5.067426164652938, 6.115065404181134, 7.154750953014359, 8.099919667594328, 9.13163011586455, 10.090727267451724, 11.130449826215305, 12.164736698630794, 13.192029425967972, 14.259552755264647, 15.292056781725417, 4.873947895280506, 3.859809472159572, 2.9088421455994977, 1.9628881730863248, 1.0385353823011438, 1.9613762557885805, 3.0057019372249374, 3.9648861684421535, 4.937280059822243, 5.91769749586569, 6.991770248851181, 8.035703211675054, 9.00546098182632, 9.937055090083208, 10.90965809326114, 11.975055609890969, 12.92026584380443, 13.97694918044764, 14.978136664989012, 16.041575145088817, 5.825581666450025, 4.884770283453428, 3.9454850892405875, 3.0178802672218312, 2.0896321546592818, 2.9007458574541167, 3.867574544038045, 4.836716407390854, 5.852499773358728, 6.876451699195986, 7.819222467263778, 8.798213428192886, 9.74648763498035, 10.732124909658213, 11.78698037499562, 12.821031201665638, 13.861134071884862, 14.870022113451476, 15.93098084153652, 16.917535830632726, 6.795533504991414, 5.933398194299741, 4.991365501534073, 4.040756365845877, 3.150250138905913, 3.899227253925103, 4.865069827471402, 5.834561077399293, 6.8323861329471764, 7.803056052041541, 8.782055303167093, 9.708087030067421, 10.727869703223364, 11.67168540789139, 12.611470535752828, 13.611056001683128, 14.620750472259425, 15.600495171294948, 16.63536120805193, 17.576531619245163, 7.7232191386255895, 6.9031194615402365, 6.041987370713389, 5.059869763742047, 4.1983497946121435, 4.848371832247773, 5.818017354457314, 6.799821173823871, 7.794791599212179, 8.824437685554363, 9.829780415600512, 10.710774407931567, 11.641695667059327, 12.667961830645222, 13.583692690815463, 14.58724209891316, 15.600858962375689, 16.617804111563096, 17.5689964467143, 18.636767114479188], [18.53073085938893, 17.5519749656451, 16.51411379960308, 15.55911725008678, 14.50971402841023, 13.537475060776044, 12.595854537082042, 11.57878598800681, 10.66379426728394, 9.730307571365053, 8.687244623593122, 7.643643959422145, 6.713664274201099, 5.703202714559099, 4.759846493908865, 5.769169488942226, 6.820955822272589, 7.75015999514396, 8.749512426927943, 9.559869322336624, 17.533688982575487, 17.610504217368923, 16.703873167702668, 15.723089599242671, 14.689751254852089, 13.956722999482793, 13.487097301397455, 12.45258965563198, 11.507288433287755, 10.546723105508631, 9.614293524467504, 8.681475390654244, 7.70802133980272, 6.700394020556872, 5.807502034850307, 6.775272861614952, 7.839665364236221, 8.80574420470691, 9.670841584763611, 8.604112591400286, 16.82641383732873, 16.605430477881285, 15.637557242934015, 14.718842081098508, 13.719962999631798, 12.958705189503759, 13.737140004541818, 13.467407326277309, 12.489197055996309, 11.564529330453475, 10.640927247275073, 9.646883005297344, 8.73494005260739, 7.685355491617301, 6.832585313766433, 7.714671450050131, 8.762085806877469, 9.701720638176399, 8.70187744697651, 7.704729104597602, 15.952590306167107, 15.542629133048282, 14.627631855066815, 13.704223257891552, 12.658389845348788, 11.960328634404894, 12.737946421985496, 13.649761651839077, 13.500622053424458, 12.542440993293505, 11.65818786444896, 10.609029542172637, 9.713779129726316, 8.667111169957757, 7.8963995036861405, 8.769695143112942, 9.69935690175384, 8.780595291875589, 7.8532231339850025, 6.874562352162813, 15.265650628326025, 14.531637808211613, 13.59594254393788, 12.756687829051323, 11.697534315597188, 10.920353650021232, 11.771009313605342, 12.700577572389458, 13.711244049730317, 13.556935603327993, 12.587753693525771, 11.56183265645799, 10.652937362166494, 9.62226845026157, 8.947427372997055, 9.726328843199516, 8.965751830231724, 8.018885789976279, 6.982837590782026, 6.052093271328161, 14.606973079542746, 13.63821855451036, 12.656194252157793, 11.779815753318825, 10.758128124530135, 9.931276673633018, 10.81809590451233, 11.793968037264861, 12.760555860033305, 13.636114413076493, 13.528695131257784, 12.593797097613137, 11.595075304165162, 10.58249570033803, 9.874864240964708, 10.799498837292568, 9.88953610662991, 8.88911133809819, 7.945672629278449, 7.049535829005561, 13.651800798600934, 12.65012475038163, 11.660994505787562, 10.802785914626645, 9.813388593953057, 8.986447509914182, 9.861827443575992, 10.828686044441774, 11.823724294522236, 12.70973140864205, 13.68422507035071, 13.588773295392228, 12.522859224987931, 11.577777794386401, 10.868733554215558, 11.753824793856547, 10.854286211118875, 9.810711288377275, 8.8583658377475, 7.904372509745929, 12.667246584582234, 11.693486764614523, 10.710619962567511, 9.794817081146475, 8.862616601752803, 7.92321044981287, 8.859301053748862, 9.835385042935972, 10.849147413795547, 11.724764040462333, 12.616754326146298, 13.586028587147975, 13.503063058468122, 12.607447433951835, 11.794822964387697, 12.721652529922045, 11.700772248307386, 10.69843554449903, 9.754327850419104, 8.745575742291134, 11.68859585068055, 10.758599709834872, 9.780575784417998, 8.80992538162327, 7.828284954180511, 6.990611585065201, 7.948069238579096, 8.918314359634724, 9.797766756935387, 10.784741394284817, 11.63765263496405, 12.573143487002557, 13.50716310939998, 13.56438432896417, 12.820697227379071, 13.584656555241953, 12.63120567290305, 11.661910019691897, 10.705246219992778, 9.671427756249244, 10.619631153160359, 9.76099505194838, 8.78858018662868, 7.854843565869507, 6.811384794300567, 5.943202862926668, 6.975962203141151, 7.92350875088984, 8.814469902550842, 9.756535606090893, 10.704451018799402, 11.612868324324019, 12.605191460805393, 13.54129056241506, 13.81491847081566, 14.541600786609294, 13.581724077678745, 12.628790256446859, 11.649255157961743, 10.664073400035807, 9.67549415480031, 8.748424182289497, 7.7157856786387145, 6.8821706596562136, 5.876094248415587, 4.941958299237651, 5.911528318416724, 6.879394071490683, 7.85361500914784, 8.783567508525989, 9.681545258628617, 10.60539667227382, 11.589427958705558, 12.555192251689546, 13.494564616881071, 14.488880202147387, 14.530869240797896, 13.635977826894926, 12.646083857103779, 11.591332838762904, 8.719443385619682, 7.753798408401502, 6.788069175481223, 5.834007809146785, 4.94475299636274, 4.014459846832413, 4.915503186440601, 5.929845803416135, 6.888748324596184, 7.827109522316153, 8.735595186174756, 9.616585859541532, 10.591720826823114, 11.613486933825717, 12.555112434759904, 13.598760597811319, 14.530675116067627, 14.54879954254531, 13.477173639323317, 12.550646060811946, 7.797953078007022, 6.8276382116433645, 5.800641603619575, 4.852765359522562, 3.95160821299572, 3.00741132694795, 3.915641343628675, 4.875189938149414, 5.831581464133372, 6.792490745579548, 7.745036832582942, 8.680506962438553, 9.624774099852662, 10.648894523584211, 11.67463452818796, 12.623670253295165, 13.581689126533895, 14.523745628691346, 14.509997327491744, 13.577799652900083, 6.88230810385183, 5.82107225631776, 4.874901666701901, 3.877338842039724, 3.020902547994729, 2.0689746488148977, 2.977490448732435, 3.920556545797149, 4.912950193565921, 5.946485049865246, 6.876336063082346, 7.903298778021086, 8.955090627264148, 9.93934713842928, 10.909549233747201, 11.854116912391287, 12.819779464590173, 13.835031823712832, 14.858706241880867, 14.625633690067819, 6.0385947528194865, 4.977711341140817, 3.936332097719528, 2.917548195953932, 2.019121742009278, 1.0532666178514967, 2.0080998677644883, 2.9814577099279695, 4.021007088509146, 5.048367850917754, 6.112548936026955, 7.14861019724857, 8.01209635915549, 8.939297272209366, 9.996741192474778, 10.95324673274674, 11.961605395689407, 12.925867445306618, 13.907910690041197, 14.966622230050543, 5.0269097054939795, 4.0509194585515775, 3.0418529096721647, 1.9900140067440997, 1.0297744001981028, 0.0, 1.0529646989984622, 2.099743735856257, 3.092602472681891, 4.037651764454835, 5.0852910039830315, 6.124976552816256, 7.070145267396224, 8.101855715666446, 9.06095286725362, 10.100675426017201, 11.13496229843269, 12.162255025769868, 13.229778355066543, 14.262282381527314, 5.839652170680725, 4.825513747559791, 3.874546420999717, 2.928592448486544, 1.916278699440328, 0.9316018555904777, 1.9759275370268345, 2.9351117682440506, 3.9075056596241393, 4.8879230956675865, 5.9619958486530775, 7.0059288114769505, 7.9756865816282145, 8.907280689885104, 9.879883693063036, 10.945281209692865, 11.890491443606326, 12.947174780249536, 13.948362264790909, 15.011800744890712, 6.6779596246545285, 5.704372724055921, 4.765087529843081, 3.837482707824325, 2.85478704532001, 1.8709714572560139, 2.8378001438399423, 3.8069420071927516, 4.822725373160624, 5.846677298997882, 6.789448067065674, 7.768439027994782, 8.716713234782246, 9.702350509460109, 10.757205974797516, 11.791256801467535, 12.831359671686759, 13.840247713253373, 14.901206441338417, 15.887761430434622, 7.647911463195918, 6.753000634902234, 5.810821974993798, 4.8602128393056026, 3.9154050295666414, 2.869452853727, 3.8352954272732984, 4.804786677201189, 5.802611732749073, 6.773281651843437, 7.752280902968988, 8.678312629869316, 9.698095303025259, 10.641911007693285, 11.581696135554722, 12.581281601485022, 13.59097607206132, 14.570720771096843, 15.605586807853824, 16.54675721904706, 8.575597096830094, 7.722721902142729, 6.811615871118194, 5.829498264146853, 4.892891831654991, 3.8185974320496703, 4.7882429542592115, 5.770046773625768, 6.765017199014075, 7.7946632853562585, 8.800006015402406, 9.68100000773346, 10.61192126686122, 11.638187430447115, 12.553918290617357, 13.557467698715055, 14.571084562177584, 15.588029711364989, 16.539222046516194, 17.60699271428108], [17.566852230906854, 16.588096337163023, 15.550235171121003, 14.595238621604702, 13.545835399928151, 12.573596432293966, 11.631975908599964, 10.614907359524732, 9.699915638801862, 8.813417386781394, 7.770354439009464, 6.726753774838487, 5.796774089617441, 4.786312529975441, 5.729668750625675, 6.738991745659035, 7.790778078989399, 8.71998225186077, 9.732193206899765, 10.542550102308446, 16.56981035409341, 17.514047093124567, 16.557711781988708, 15.567719810746986, 14.568960699328846, 13.547425575864015, 12.570207116813798, 11.535699471048323, 10.590398248704098, 9.629832920924974, 8.697403339883847, 7.764585206070587, 6.791131155219062, 5.783503835973214, 6.7773242915671155, 7.745095118331761, 8.80948762095303, 9.775566461423718, 10.653522364735432, 9.586793371372107, 15.816809685160358, 16.76253769098731, 16.543587361057472, 15.619647873837373, 14.620768792370665, 13.811501836628373, 12.855427751146154, 12.550517141693652, 11.572306871412652, 10.647639145869817, 9.724037062691416, 8.729992820713687, 7.818049868023732, 6.768465307033643, 7.761582660302711, 8.68449370676694, 9.731908063594277, 10.68440141814822, 9.684558226948331, 8.687409884569423, 14.925438338928702, 15.894521674079813, 15.533661973190272, 14.605029050630419, 13.559195638087655, 12.813125281529508, 11.856234168589832, 12.768049398443413, 12.5837318688408, 11.625550808709848, 10.741297679865303, 9.69213935758898, 8.796888945142658, 7.750220985374099, 8.82440796531596, 9.73951739982975, 10.669179158470648, 9.833559990874052, 8.906187832983466, 7.927527051161276, 14.212685929327563, 15.182938951477352, 14.501972662061338, 13.65749362179019, 12.598340108336055, 11.8211594427601, 10.889297060209678, 11.818865318993794, 12.829531796334653, 12.640045418744336, 11.670863508942114, 10.644942471874332, 9.736047177582837, 8.705378265677913, 9.671441808628852, 10.653167829063038, 10.018716529230186, 9.071850488974741, 8.035802289780488, 7.105057970326623, 14.878084753973548, 14.544248672633817, 13.56222437028125, 12.680621546057692, 11.658933917269001, 10.832082466371887, 9.936383651116666, 10.912255783869197, 11.828642323672293, 12.654495876168209, 12.611804946674127, 11.67690691302948, 10.678185119581505, 9.665605515754374, 10.598878676596506, 11.56214875166893, 10.942500805628374, 9.942076037096653, 8.998637328276912, 8.091638734768026, 14.595789076422873, 13.556154868505088, 12.567024623911019, 11.703591707365511, 10.714194386691924, 9.88725330265305, 8.980115190180328, 9.94697379104611, 10.884091207085334, 11.728112871733765, 12.702606533442424, 12.67188311080857, 11.605969040404274, 10.660887609802744, 11.592747989847355, 12.51647470823291, 11.8802703393249, 10.8366954165833, 9.884349965953525, 8.930356637951954, 13.633719625596378, 12.59951688273798, 11.616650080690968, 10.700847199269932, 9.76342239449167, 8.824016242551737, 7.977588800353198, 8.953672789540308, 9.878584603325054, 10.743145503554048, 11.635135789238012, 12.60441005023969, 12.586172873884465, 11.690557249368178, 12.518837400019494, 13.484302444298407, 12.72675637651341, 11.724419672705055, 10.780311978625129, 9.771559870497159, 12.714579978886576, 11.66462982795833, 10.686605902541455, 9.715955499746727, 8.729090746919377, 7.891417377804068, 6.966450701670809, 7.936695822726437, 8.816148220027102, 9.803122857376533, 10.656034098055764, 11.591524950094271, 12.525544572491695, 12.647494144380513, 13.544711663010869, 14.503923490237737, 13.657189801109077, 12.687894147897923, 11.731230348198805, 10.69741188445527, 11.645615281366386, 10.75627391213083, 9.742026766551046, 8.760873683992964, 7.712190587039434, 6.844008655665535, 5.994343666232863, 6.941890213981552, 7.832851365642557, 8.774917069182608, 9.722832481891116, 10.631249787415733, 11.623572923897108, 12.559672025506774, 13.534768234473384, 14.484009991105843, 14.607708205884771, 13.654774384652885, 12.67523928616777, 11.690057528241834, 10.701478283006336, 9.77440831049552, 8.741769806844738, 7.806012357387853, 6.7769000411544535, 5.842764091976518, 4.929909781508436, 5.8977755345823955, 6.871996472239554, 7.801948971617702, 8.699926721720331, 9.623778135365534, 10.607809421797272, 11.57357371478126, 12.512946079972785, 13.5072616652391, 14.542926380072386, 14.661961955100953, 13.672067985309805, 12.61731696696893, 9.745427513825708, 8.779782536607527, 7.814053303687247, 6.8505653488396225, 5.845558789101607, 4.915265639571279, 3.933884649532313, 4.948227266507847, 5.907129787687898, 6.845490985407865, 7.753976649266469, 8.634967322633246, 9.610102289914828, 10.63186839691743, 11.573493897851616, 12.617142060903031, 13.54905657915934, 14.521961780907272, 14.503157767529343, 13.576630189017973, 8.823937206213047, 7.853622339849389, 6.8266257318256, 5.878749487728586, 4.852414005734587, 3.9082171196868165, 2.9340228067203875, 3.8935714012411267, 4.849962927225085, 5.810872208671261, 6.763418295674655, 7.698888425530266, 8.643155562944374, 9.667275986675923, 10.693015991279673, 11.642051716386877, 12.600070589625608, 13.542127091783058, 14.541684482542722, 14.60378378110611, 7.908292232057855, 6.847056384523785, 5.900885794907926, 4.903322970245749, 3.9489505109124243, 2.9856949087939904, 1.9958719118241475, 2.9389380088888615, 3.9205782241889713, 4.9541130804882965, 5.883964093705396, 6.910926808644136, 7.962718657887198, 8.886382439430818, 9.85658453474874, 10.801152213392825, 11.766814765591711, 12.78206712471437, 13.805741542882405, 14.810236324578687, 7.064578881025511, 6.003695469346842, 4.962316225925553, 3.943532324159957, 2.9471697049269734, 1.9813145807691923, 1.0264813308562006, 1.9998391730196818, 2.9831967466596083, 4.010557509068216, 5.0747385941774175, 6.0994215872825714, 6.95913166015703, 7.886332573210904, 8.943776493476316, 9.900282033748278, 10.908640696690945, 11.872902746308156, 12.854945991042735, 13.913657531052081, 6.0798744044924415, 5.1038841575500395, 4.094817608670627, 3.042978705742562, 2.082739099196565, 1.0529646989984622, 0.0, 1.046779036857795, 2.039637773683429, 2.984687065456373, 4.0323263049845695, 5.072011853817794, 6.017180568397762, 7.048891016667984, 8.007988168255158, 9.047710727018739, 10.081997599434228, 11.109290326771406, 12.17681365606808, 13.209317682528852, 6.892616869679188, 5.878478446558254, 4.927511119998179, 3.981557147485006, 2.96924339843879, 1.98456655458894, 0.9488157100374455, 1.9079999412546615, 2.8803938326347502, 3.860811268678198, 4.934884021663689, 5.978816984487562, 6.948534614389809, 7.880128722646698, 8.852731725824631, 9.91812924245446, 10.863339476367921, 11.920022813011132, 12.921210297552504, 13.984648777652307, 7.660640404626349, 6.687053504027743, 5.747768309814902, 4.820163487796147, 3.8374678252918315, 2.853652237227836, 1.8868235506439075, 2.8559654139967168, 3.87174877996459, 4.882798670515802, 5.825569438583594, 6.804560399512702, 7.752834606300165, 8.738471880978027, 9.793327346315435, 10.827378172985453, 11.821755519518389, 12.830643561085003, 13.891602289170047, 14.878157278266253, 8.630592243167738, 7.7356814148740565, 6.793502754965621, 5.842893619277424, 4.898085809538463, 3.852133633698822, 2.8878938083033026, 3.857385058231194, 4.855210113779077, 5.809403023361357, 6.788402274486908, 7.714434001387237, 8.73421667454318, 9.678032379211206, 10.617817507072644, 11.617402973002944, 12.627097443579242, 13.606842142614765, 14.641708179371745, 15.582878590564981, 9.558277876801915, 8.705402682114551, 7.794296651090016, 6.8121790441186745, 5.875572611626812, 4.801278212021492, 3.8455663489924783, 4.822645154655772, 5.817615580044079, 6.847261666386263, 7.836127386920327, 8.717121379251381, 9.648042638379142, 10.674308801965037, 11.590039662135279, 12.593589070232976, 13.607205933695505, 14.62415108288291, 15.575343418034116, 16.643114085799002], [16.621029136581033, 15.642273242837202, 14.60441207679518, 13.64941552727888, 12.600012305602329, 11.627773337968144, 10.686152814274143, 9.669084265198912, 8.754092544476041, 7.902708451474876, 6.974537130319646, 6.005394576519528, 5.075414891298482, 5.833091566833236, 6.77644778748347, 7.78577078251683, 8.837557115847194, 9.766761288718564, 10.77897224375756, 11.589329139166242, 15.623987259767587, 16.568223998798747, 15.611888687662885, 14.621896716421164, 13.623137605003024, 12.601602481538192, 11.662354851563503, 10.627847205798027, 9.682545983453801, 8.908473722606015, 7.976044141564889, 7.0432260077516275, 6.0697719569001025, 6.830282872831009, 7.824103328424911, 8.791874155189557, 9.856266657810826, 10.822345498281514, 11.700301401593228, 10.633572408229902, 14.770030648302562, 15.715758654129512, 16.66670342672528, 15.636212369135501, 14.581277417597018, 13.599620291517226, 12.618093367669708, 11.642664876443355, 10.664454606162355, 9.926279947550857, 9.002677864372457, 8.008633622394727, 7.099032601793124, 7.815244343891438, 8.808361697160507, 9.731272743624736, 10.778687100452073, 11.731180455006015, 10.731337263806127, 9.734188921427219, 13.878659302070906, 14.847742637222018, 15.892048074026926, 15.53575526879332, 14.489921856250556, 13.743851499692408, 12.786960386752732, 12.119852615935029, 11.715980134348033, 10.904191610390887, 10.019938481546344, 8.97078015927002, 8.07829686053195, 8.797000022231895, 9.871187002173755, 10.786296436687547, 11.715958195328444, 10.880339027731848, 9.952966869841262, 8.974306088019071, 13.16590689246977, 14.13615991461956, 15.07185517889329, 14.58821983995309, 13.529066326498956, 12.751885660923, 11.820023278372577, 11.17066853648541, 11.85075464995852, 11.918686220425375, 10.949504310623155, 9.923583273555373, 9.15091698014082, 9.752157302535709, 10.718220845486648, 11.699946865920834, 11.06549556608798, 10.118629525832535, 9.082581326638282, 8.151837007184417, 13.831305717115754, 14.845146047479636, 14.492950588444149, 13.611347764220593, 12.589660135431902, 11.762808684534786, 10.867109869279565, 10.139645252138846, 10.809591772954786, 11.635445325450704, 11.890445748355168, 10.955547714710521, 10.099916797939002, 10.71238455261217, 11.645657713454302, 12.608927788526726, 11.989279842486168, 10.988855073954447, 10.045416365134706, 9.022364952930925, 14.786477998057565, 14.486881086667987, 13.497750842073918, 12.634317925528412, 11.644920604854825, 10.81797952081595, 9.910841408343227, 9.14108049995092, 9.865040656367826, 10.70906232101626, 11.683555982724918, 12.014123118468335, 11.0465233419801, 11.70766664666054, 12.639527026705151, 13.563253745090705, 12.8109965574878, 11.7674216347462, 10.815076184116425, 9.861082856114853, 14.564445843759277, 13.53024310090088, 12.547376298853868, 11.631573417432833, 10.69414861265457, 9.754742460714638, 8.908315018516097, 8.107126638232748, 8.859534052607547, 9.724094952836543, 10.616085238520506, 11.585359499522184, 12.026727175460291, 12.737336286225974, 13.56561643687729, 14.531081481156203, 13.65748259467631, 12.655145890867955, 11.711038196788028, 10.702286088660058, 13.645306197049475, 12.595356046121228, 11.617332120704354, 10.646681717909628, 9.659816965082278, 8.822143595966969, 7.897176919833708, 7.056486078013002, 7.797097669309596, 8.784072306659027, 9.636983547338259, 10.572474399376766, 11.50649402177419, 12.483724882833506, 13.509938927192467, 14.421903671755679, 14.587916019271976, 13.618620366060822, 12.661956566361704, 11.62813810261817, 12.576341499529285, 11.68700013029373, 10.672752984713947, 9.691599902155865, 8.642916805202335, 7.774734873828435, 6.9250698843957625, 6.052008986070423, 6.8138008149250515, 7.755866518465102, 8.70378193117361, 9.612199236698226, 10.6045223731796, 11.540621474789267, 12.515717683755877, 13.464959440388338, 14.473020992474032, 14.585500602815785, 13.605965504330669, 12.620783746404733, 11.632204501169236, 10.705134528658421, 9.67249602500764, 8.736738575550753, 7.707626259317354, 6.773490310139418, 5.860635999671336, 5.0078943066712664, 5.852945921522049, 6.782898420900197, 7.680876171002826, 8.604727584648026, 9.588758871079765, 10.554523164063752, 11.493895529255278, 12.488211114521594, 13.52387582935488, 14.473245658194212, 14.602794203472705, 13.54804318513183, 10.676153731988608, 9.710508754770427, 8.744779521850148, 7.781291567002523, 6.776285007264507, 5.845991857734179, 4.864610867695213, 4.034819749604852, 4.888079236970393, 5.82644043469036, 6.734926098548963, 7.61591677191574, 8.59105173919732, 9.612817846199924, 10.55444334713411, 11.598091510185526, 12.530006028441834, 13.502911230189767, 14.570927441132895, 14.507356407180872, 9.754663424375947, 8.784348558012288, 7.7573519499885, 6.8094757058914865, 5.783140223897487, 4.838943337849717, 3.864749024883287, 2.965832967689243, 3.83091237650758, 4.791821657953756, 5.74436774495715, 6.679837874812761, 7.6241050122268685, 8.648225435958418, 9.673965440562167, 10.623001165669372, 11.581020038908102, 12.523076541065553, 13.522633931825217, 14.454831606416878, 8.839018450220754, 7.777782602686685, 6.831612013070826, 5.834049188408649, 4.8796767290753245, 3.91642112695689, 2.926598129987047, 1.922948542724799, 2.8737991873311763, 3.9073340436305015, 4.837185056847601, 5.8641477717863415, 6.915939621029403, 7.839603402573024, 8.809805497890945, 9.75437317653503, 10.720035728733915, 11.735288087856574, 12.75896250602461, 13.763457287720891, 7.9953050991884105, 6.934421687509741, 5.893042444088453, 4.874258542322857, 3.8778959230898735, 2.9120407989320922, 1.9572075490191003, 0.9838497068556192, 1.9364177098018134, 2.9637784722104215, 4.0279595573196225, 5.0526425504247765, 5.912352623299235, 6.839553536353109, 7.896997456618521, 8.853502996890484, 9.861861659833151, 10.826123709450362, 11.80816695418494, 12.866878494194287, 7.126653441350236, 6.150663194407834, 5.141596645528422, 4.089757742600357, 3.12951813605436, 2.099743735856257, 1.046779036857795, 0.0, 0.9928587368256337, 1.937908028598578, 2.9855472681267745, 4.025232816959999, 4.970401531539967, 6.002111979810189, 6.961209131397364, 8.000931690160945, 9.035218562576434, 10.062511289913612, 11.130034619210287, 12.162538645671058, 7.939395906536983, 6.925257483416049, 5.974290156855974, 5.028336184342801, 4.016022435296585, 3.0313455914467347, 1.9955947468952404, 1.0585816935024468, 2.0246525647352973, 2.9149881743523762, 3.989060927337867, 5.03299389016174, 5.901755577532014, 6.833349685788903, 7.805952688966835, 8.871350205596665, 9.816560439510125, 10.873243776153336, 11.874431260694708, 12.937869740794511, 8.707419441484145, 7.733832540885538, 6.794547346672697, 5.8669425246539415, 4.8842468621496264, 3.900431274085631, 2.9336025875017024, 2.0417805785950374, 3.0575639445629106, 3.9369755761899805, 4.879746344257772, 5.858737305186882, 6.807011511974344, 7.792648786652207, 8.847504251989616, 9.86235824886887, 10.774976482660593, 11.783864524227207, 12.844823252312251, 13.831378241408457, 9.677371280025534, 8.78246045173185, 7.840281791823415, 6.889672656135219, 5.944864846396258, 4.8989126705566175, 3.9346728451610975, 3.111548496866636, 4.0554215879126545, 4.863579929035535, 5.842579180161087, 6.768610907061415, 7.788393580217358, 8.732209284885384, 9.671994412746821, 10.671579878677122, 11.68127434925342, 12.661019048288942, 13.695885085045923, 14.637055496239158, 10.60505691365971, 9.752181718972345, 8.84107568794781, 7.85895808097647, 6.922351648484608, 5.848057248879288, 4.892345385850273, 4.076808593291214, 5.068676878682794, 5.935277209416138, 6.8903042925945055, 7.771298284925559, 8.702219544053321, 9.728485707639216, 10.644216567809456, 11.647765975907154, 12.661382839369683, 13.67832798855709, 14.629520323708295, 15.697290991473182], [15.628170399755396, 14.649414506011567, 13.611553339969547, 12.656556790453246, 11.607153568776695, 10.63491460114251, 9.69329407744851, 8.676225528373278, 7.761233807650407, 6.909849714649242, 5.981678393494013, 5.027132090226119, 5.957111775447165, 6.800868770444964, 7.744224991095198, 8.75354798612856, 9.805334319458922, 10.734538492330293, 11.74674944736929, 12.55710634277797, 14.631128522941953, 15.575365261973113, 14.619029950837252, 13.62903797959553, 12.63027886817739, 11.608743744712559, 10.669496114737868, 9.634988468972393, 8.689687246628168, 7.930211236312606, 6.997781655271479, 6.064963521458218, 6.951468841048786, 7.798060076442737, 8.79188053203664, 9.759651358801285, 10.824043861422554, 11.790122701893242, 12.668078605204956, 11.60134961184163, 13.777171911476927, 14.722899917303877, 15.67384468989965, 14.643353632309868, 13.588418680771385, 12.606761554691593, 11.625234630844075, 10.649806139617722, 9.671595869336722, 8.948017461257448, 8.024415378079047, 7.030371136101317, 7.980729485941808, 8.783021547503166, 9.776138900772235, 10.699049947236464, 11.746464304063801, 12.698957658617744, 11.699114467417855, 10.701966125038947, 12.88580056524527, 13.854883900396382, 14.89918933720129, 15.627860772810443, 14.57449245855481, 13.581319326340072, 12.624428213400396, 11.698190834652001, 10.7231213975224, 9.925929124097479, 9.041675995252934, 7.992517672976611, 8.959993744680634, 9.764777225843623, 10.838964205785484, 11.754073640299275, 12.683735398940172, 11.856691068228438, 10.929318910337852, 9.950658128515661, 12.173048155644135, 13.143301177793925, 14.078996442067655, 15.107607460816261, 14.418311061802312, 13.63413357379913, 12.684321352216731, 11.814344143244162, 10.857895913132888, 10.940423734131969, 9.971241824329745, 8.945320787261963, 9.972718417507416, 10.719934506147437, 11.685998049098377, 12.667724069532563, 12.058354302913616, 11.11148826265817, 10.075440063463917, 9.144695744010052, 12.838446980290119, 13.852287310654, 14.83431161300657, 14.500592499523949, 13.478904870735258, 12.645056597410916, 11.731407943123719, 10.783320858897598, 9.816733036129154, 10.64258658862507, 10.912183262061758, 9.977285228417111, 10.921718235305597, 11.680161756223898, 12.61343491706603, 13.576704992138454, 12.982138579311803, 11.981713810780082, 11.038275101960341, 10.015223689756558, 13.79361926123193, 14.833253469149716, 14.386995577377276, 13.523562660831768, 12.53416534015818, 11.70022743369208, 10.775139482187381, 9.867220169622659, 8.872181919542195, 9.716203584190627, 10.690697245899285, 11.035860632174925, 11.868324779346695, 12.675443850272268, 13.60730423031688, 14.531030948702433, 13.803855294313433, 12.760280371571833, 11.807934920942058, 10.853941592940487, 14.535892360253717, 14.419487836204237, 13.436621034157225, 12.520818152736188, 11.583393347957927, 10.643987196017992, 9.77261309236025, 8.84187043284198, 7.866675315781914, 8.73123621601091, 9.623226501694873, 10.592500762696552, 11.475200579036702, 12.435056309281405, 13.396070269526325, 14.447186523420285, 14.572059062651233, 13.569722358842878, 12.625614664762951, 11.616862556634981, 14.557314206285493, 13.484600781424586, 12.506576856007712, 11.535926453212983, 10.549061700385634, 9.711388331270323, 8.761474993677862, 7.791229872622233, 6.804238932483963, 7.791213569833394, 8.644124810512626, 9.579615662551133, 10.513635284948556, 11.490866146007873, 12.517080190366835, 13.429044934930047, 14.38249581726895, 14.533196834035746, 13.576533034336627, 12.542714570593093, 13.490917967504208, 12.576244865597086, 11.561997720017303, 10.58084463745922, 9.53216154050569, 8.66397960913179, 7.814314619699118, 6.878219208907388, 5.820942078099418, 6.763007781639469, 7.710923194347977, 8.619340499872592, 9.611663636353969, 10.547762737963636, 11.522858946930246, 12.472100703562706, 13.480162255648398, 14.433096076880284, 14.520541972305592, 13.535360214379656, 12.546780969144159, 11.619710996633344, 10.587072492982562, 9.62598331085411, 8.59687099462071, 7.662735045442774, 6.749880734974692, 5.834104529508231, 4.8600871846964155, 5.790039684074563, 6.688017434177192, 7.611868847822393, 8.595900134254133, 9.56166442723812, 10.501036792429646, 11.495352377695962, 12.531017092529247, 13.480386921368579, 14.470280891159726, 14.462619653106753, 11.59073019996353, 10.62508522274535, 9.659355989825071, 8.670536302305878, 7.665529742567863, 6.735236593037535, 5.753855602998569, 4.861029972441816, 3.895220500144759, 4.833581697864727, 5.74206736172333, 6.623058035090106, 7.598193002371688, 8.61995910937429, 9.561584610308477, 10.605232773359893, 11.5371472916162, 12.510052493364133, 13.578068704307261, 14.489126461679382, 10.66923989235087, 9.698925025987212, 8.671928417963423, 7.724052173866409, 6.672384959200842, 5.728188073153072, 4.753993760186643, 3.7944451656659037, 2.838053639681946, 3.7989629211281226, 4.751509008131516, 5.6869791379871275, 6.631246275401235, 7.6553666991327844, 8.681106703736534, 9.630142428843739, 10.588161302082469, 11.53021780423992, 12.529775194999583, 13.461972869591245, 9.831877187046388, 8.770641339512318, 7.824470749896459, 6.826907925234282, 5.869701977398879, 4.8744810982499915, 3.884658101280148, 2.8733340982743147, 1.8809404505055425, 2.9144753068048677, 3.8443263200219677, 4.871289034960708, 5.923080884203769, 6.846744665747389, 7.81694676106531, 8.761514439709394, 9.72717699190828, 10.742429351030939, 11.766103769198974, 12.770598550895256, 8.988163836014044, 7.9272804243353745, 6.885901180914086, 5.8671172791484905, 4.870754659915507, 3.9048995357577256, 2.950066285844734, 1.976708443681253, 0.9435589729761795, 1.9709197353847876, 3.035100820493988, 4.059783813599142, 4.9194938864736, 5.846694799527475, 6.904138719792886, 7.8606442600648485, 8.869002923007516, 9.833264972624727, 10.815308217359306, 11.874019757368652, 8.11951217817587, 7.143521931233469, 6.134455382354056, 5.082616479425991, 4.122376872879994, 3.0926024726818913, 2.039637773683429, 0.9928587368256337, 0.0, 0.9450492917729442, 1.9926885313011407, 3.032374080134365, 3.977542794714333, 5.009253242984554, 5.96835039457173, 7.008072953335311, 8.0423598257508, 9.069652553087979, 10.137175882384653, 11.169679908845424, 8.915747947033573, 7.901609523912639, 6.950642197352565, 6.004688224839391, 4.992374475793175, 4.0076976319433255, 2.9633719505069687, 2.0041877192897526, 1.0317938279096637, 1.9221294375267424, 2.9962021905122334, 4.040135153336106, 4.9088968407063795, 5.840490948963269, 6.813093952141201, 7.87849146877103, 8.82370170268449, 9.8803850393277, 10.881572523869073, 11.945011003968876, 9.675196645095873, 8.701609744497267, 7.762324550284426, 6.83471972826567, 5.852024065761355, 4.868208477697359, 3.9013797911134307, 2.987386604382343, 2.06503563504949, 2.9441168393643466, 3.8868876074321386, 4.865878568361247, 5.81415277514871, 6.799790049826573, 7.8546455151639805, 8.869499512043237, 9.782117745834958, 10.791005787401572, 11.851964515486616, 12.838519504582822, 10.645148483637263, 9.75023765534358, 8.808058995435143, 7.857449859746947, 6.912642050007986, 5.866689874168346, 4.902450048772826, 4.057154522653941, 3.0628932783992338, 3.8707211922099014, 4.849720443335453, 5.775752170235782, 6.795534843391724, 7.73935054805975, 8.679135675921188, 9.678721141851488, 10.688415612427786, 11.668160311463309, 12.70302634822029, 13.644196759413525, 11.572834117271439, 10.719958922584075, 9.808852891559539, 8.826735284588198, 7.890128852096336, 6.815834452491016, 5.8601225894620015, 5.0224146190785195, 4.076148569169374, 4.9424184725905045, 5.897445555768872, 6.778439548099926, 7.709360807227687, 8.735626970813582, 9.651357830983823, 10.65490723908152, 11.66852410254405, 12.685469251731455, 13.63666158688266, 14.704432254647546], [14.683121107982453, 13.704365214238624, 12.666504048196602, 11.711507498680302, 10.66210427700375, 9.689865309369566, 8.748244785675565, 7.731176236600334, 6.816184515877462, 5.964800422876298, 5.0366291017210685, 5.924327234879714, 6.85430692010076, 7.726572524332546, 8.66992874498278, 9.679251740016142, 10.731038073346504, 11.660242246217875, 12.672453201256872, 13.482810096665553, 13.686079231169009, 14.630315970200169, 13.673980659064307, 12.683988687822586, 11.685229576404446, 10.663694452939614, 9.724446822964925, 8.689939177199449, 7.744637954855222, 7.003851274975076, 6.105988031073847, 6.962158666111813, 7.848663985702381, 8.72376383033032, 9.717584285924222, 10.685355112688868, 11.749747615310136, 12.715826455780824, 13.593782359092538, 12.527053365729213, 12.832122619703984, 13.777850625530935, 14.728795398126705, 13.698304340536923, 12.64336938899844, 11.661712262918648, 10.68018533907113, 9.704756847844777, 8.726546577563775, 8.021657499919918, 7.1326217538814145, 7.927566280754912, 8.877924630595404, 9.708725301390748, 10.701842654659817, 11.624753701124046, 12.672168057951383, 13.624661412505326, 12.624818221305437, 11.627669878926529, 11.940751273472328, 12.90983460862344, 13.954140045428348, 14.682811481037499, 13.629443166781865, 12.636270034567127, 11.679378921627452, 10.753141542879057, 9.778072105749454, 8.999569162759949, 8.15809076303967, 8.889712817630206, 9.85718888933423, 10.690480979731205, 11.764667959673066, 12.679777394186857, 13.609439152827754, 12.78239482211602, 11.855022664225434, 10.876361882403243, 11.227998863871193, 12.198251886020982, 13.133947150294713, 14.162558169043319, 14.590298696533464, 13.67624501895079, 12.631893881112791, 11.702325622328676, 10.787434801291763, 10.014063772794437, 9.087656592116481, 9.842515931915559, 10.869913562161013, 11.64563826003502, 12.611701802985959, 13.593427823420145, 13.003403594686558, 12.056537554431113, 11.02048935523686, 10.089745035782995, 11.893397688517172, 12.907238018881054, 13.889262321233623, 14.845155961545712, 14.423954162508203, 13.590105889183858, 12.676457234896661, 11.728370150670541, 10.761782327902097, 9.979841228595875, 10.086604148397473, 10.874480373070707, 11.818913379959195, 12.60586551011148, 13.539138670953612, 14.502408746026036, 13.927187871084746, 12.926763102553025, 11.983324393733284, 10.960272981529503, 12.848569969458984, 13.88820417737677, 14.884462067603854, 14.468611952604713, 13.479214631931125, 12.645276725465022, 11.720188773960324, 10.812269461395601, 9.817231211315137, 9.053458224161432, 9.990455416941495, 10.831593148928942, 11.755162583559104, 12.700244014160633, 13.621917850740674, 14.587132393842722, 14.748904586086377, 13.705329663344777, 12.752984212715003, 11.798990884713431, 13.68273249704397, 14.716935239902366, 14.381670325930168, 13.465867444509133, 12.528442639730871, 11.589036487790938, 10.717662384133193, 9.786919724614922, 8.811724607554858, 8.068490855981715, 8.922984672737083, 9.892258933738763, 10.774958750078913, 11.734814480323616, 12.695828440568535, 13.746944694462496, 14.659346093321343, 14.514771650615822, 13.570663956535896, 12.561911848407926, 14.602492297644101, 14.429650073197529, 13.451626147780654, 12.480975744985928, 11.494110992158578, 10.656437623043269, 9.706524285450804, 8.736279164395176, 7.749288224256906, 7.128468209804199, 7.943882981554837, 8.879373833593345, 9.813393455990768, 10.790624317050085, 11.816838361409046, 12.728803105972258, 13.68225398831116, 14.63313787722121, 14.521582326109572, 13.487763862366037, 14.435967259277152, 13.521294157370031, 12.507047011790247, 11.525893929232165, 10.477210832278635, 9.609028900904736, 8.759363911472063, 7.823268500680332, 6.765991369872362, 6.100262421610274, 7.010681365390187, 7.919098670914803, 8.911421807396177, 9.847520909005846, 10.822617117972456, 11.771858874604916, 12.713323819234363, 13.666257640466249, 14.659002615297085, 14.4804095061526, 13.491830260917103, 12.564760288406289, 11.532121784755507, 10.571032602627053, 9.541920286393655, 8.607784337215719, 7.694930026747636, 6.7791538212811755, 5.805136476469359, 5.112195294548162, 5.987775605219403, 6.911627018864603, 7.895658305296343, 8.861422598280331, 9.800794963471857, 10.795110548738172, 11.764178656115211, 12.672279946363902, 13.66217391615505, 14.595279820518677, 12.535779491736475, 11.570134514518294, 10.604405281598016, 9.615585594078823, 8.610579034340807, 7.68028588481048, 6.6989048947715135, 5.806079264214761, 4.840269791917703, 4.155737308338325, 5.04182553276554, 5.922816206132317, 6.897951173413898, 7.895395867472053, 8.837021368406239, 9.880669531457654, 10.770308855202165, 11.663671913489289, 12.724908841097514, 13.635966598469635, 11.614289184123814, 10.643974317760156, 9.616977709736368, 8.669101465639354, 7.617434250973787, 6.673237364926017, 5.699043051959587, 4.739494457438848, 3.78310293145489, 3.1211185316017205, 4.051267179173727, 4.986737309029338, 5.9310044464434455, 6.930803457230546, 7.937975070153257, 8.820195918393843, 9.735001438872722, 10.677057941030172, 11.676615331789836, 12.608813006381498, 10.776926478819332, 9.715690631285263, 8.769520041669404, 7.771957217007227, 6.814751269171824, 5.819530390022935, 4.829707393053092, 3.818383390047259, 2.8259897422784865, 2.1456537822675257, 3.0385765753527516, 4.0655392902914915, 5.015109585099058, 5.901695373974444, 6.871897469292366, 7.816465147936451, 8.782127700135336, 9.797380059257994, 10.82105447742603, 11.825549259122312, 9.933213127786988, 8.87232971610832, 7.8309504726870305, 6.812166570921435, 5.815803951688451, 4.84994882753067, 3.8951155776176782, 2.921757735454197, 1.8886082647491236, 1.0709043183344642, 2.0953315612006778, 3.114734521826198, 3.974444594700656, 4.90164550775453, 5.959089428019942, 6.915594968291904, 7.92395363123457, 8.888215680851781, 9.87025892558636, 10.928970465595706, 9.064561469948814, 8.088571223006412, 7.079504674127, 6.027665771198935, 5.067426164652938, 4.037651764454835, 2.984687065456373, 1.937908028598578, 0.9450492917729442, 0.0, 1.0476392395281964, 2.0873247883614208, 3.032493502941389, 4.064203951211611, 5.023301102798786, 6.063023661562367, 7.097310533977856, 8.124603261315034, 9.192126590611709, 10.22463061707248, 9.841451700921155, 8.82731327780022, 7.876345951240147, 6.930391978726973, 5.9180782296807575, 4.933401385830907, 3.8890757043945503, 2.9298914731773342, 1.9574975817972455, 0.9770801457537982, 2.0511528987392893, 3.0950858615631622, 3.963847548933436, 4.895441657190325, 5.868044660368257, 6.933442176998087, 7.878652410911547, 8.935335747554758, 9.93652323209613, 10.999961712195933, 10.600900398983455, 9.627313498384849, 8.688028304172008, 7.760423482153252, 6.777727819648937, 5.793912231584941, 4.827083545001012, 3.913090358269925, 2.9907393889370715, 1.9990675475914026, 2.9418383156591945, 3.9208292765883033, 4.869103483375766, 5.854740758053629, 6.909596223391037, 7.924450220270293, 8.837068454062015, 9.845956495628629, 10.906915223713673, 11.893470212809879, 11.570852237524845, 10.675941409231163, 9.733762749322725, 8.783153613634529, 7.838345803895568, 6.792393628055928, 5.828153802660408, 4.957913478600712, 3.9600884230528286, 2.9256719004369574, 3.9046711515625088, 4.830702878462837, 5.85048555161878, 6.794301256286806, 7.7340863841482435, 8.733671850078544, 9.743366320654841, 10.723111019690364, 11.757977056447345, 12.69914746764058, 12.498537871159021, 11.645662676471657, 10.734556645447121, 9.75243903847578, 8.815832605983918, 7.741538206378598, 6.785826343349584, 5.923173575025291, 4.973343713822969, 3.99736918081756, 4.952396263995928, 5.8333902563269815, 6.764311515454742, 7.790577679040637, 8.706308539210879, 9.709857947308576, 10.723474810771105, 11.740419959958512, 12.691612295109717, 13.759382962874604], [13.676324065523358, 12.69756817177953, 11.659707005737507, 10.704710456221207, 9.655307234544656, 8.683068266910471, 7.836002170990861, 6.818933621915629, 5.903941901192757, 5.052557808191593, 5.976265397183487, 6.863963530342131, 7.793943215563178, 8.76545974566316, 9.708815966313393, 10.718138961346755, 11.769925294677117, 12.699129467548488, 13.717597839336896, 14.530449336193747, 12.679282188709916, 13.623518927741074, 12.667183616605213, 11.677191645363491, 10.678432533945351, 9.65689741048052, 8.812204208280217, 7.777696562514743, 6.8323953401705175, 6.091608660290371, 7.024038241331498, 7.901794961574231, 8.788300281164798, 9.762651051660933, 10.756471507254835, 11.72424233401948, 12.78863483664075, 13.754713677111438, 14.641421598620735, 13.57469260525741, 11.78448338017579, 12.73021138600274, 13.72199835566761, 12.691507298077829, 11.636572346539346, 10.654915220459554, 9.767942724386424, 8.792514233160071, 7.814303962879071, 7.109414885235213, 8.043783194686094, 8.86720257621733, 9.81756092605782, 10.747612522721361, 11.74072987599043, 12.66364092245466, 13.711055279281997, 14.672300652033522, 13.672457460833634, 12.675309118454726, 10.893112033944131, 11.862195369095243, 12.906500805900151, 13.69983322202879, 12.646464907773156, 11.653291775558419, 10.767136306942746, 9.84089892819435, 8.86582949106475, 8.087326548075243, 9.06925220384435, 9.829349113092624, 10.796825184796646, 11.729368201061817, 12.803555181003677, 13.71866461551747, 14.648326374158367, 13.830034061644216, 12.90266190375363, 11.92400112193144, 10.180359624342994, 11.150612646492783, 12.086307910766514, 13.11491892951512, 13.607320437524756, 12.69326675994208, 11.719651266428086, 10.79008300764397, 9.875192186607059, 9.101821158109733, 9.998818032921161, 10.782152227377976, 11.80954985762343, 12.68452548136563, 13.65058902431657, 14.632315044750756, 14.051042834214755, 13.10417679395931, 12.068128594765057, 11.137384275311192, 10.845758448988978, 11.85959877935286, 12.841623081705428, 13.797516722017518, 14.54672662859181, 13.682343736330294, 12.672564675521098, 11.821106291990533, 10.916355063610792, 10.039600376742197, 10.005170044792015, 10.842529313158561, 11.654129888072006, 12.647886868680809, 13.568147924463329, 14.493819110878507, 14.974827110612942, 13.974402342081222, 13.03096363326148, 12.0079122210577, 11.800930729930789, 12.840564937848574, 13.83682282807566, 14.786521875333841, 14.52685387145932, 13.625031319722805, 12.699943368218106, 11.733084767352324, 10.73804651727186, 9.776362322251476, 8.942816177413299, 9.783953909400747, 10.707523344030909, 11.652604774632438, 12.57427861121248, 13.539493154314528, 14.569133789964644, 14.752968902872972, 13.800623452243197, 12.846630124241626, 12.635093257515775, 13.669296000374171, 14.652162802421183, 14.513506684037328, 13.576081879259066, 12.636675727319133, 11.722386273558266, 10.746302284371156, 9.73253991351158, 8.791394954071759, 7.875345433208887, 8.844619694210568, 9.727319510550718, 10.68717524079542, 11.64818920104034, 12.6993054549343, 13.611706853793144, 14.552730165350322, 14.61830319606409, 13.60955108793612, 13.554853058115906, 14.627566482976814, 14.49926538730885, 13.528614984514123, 12.541750231686773, 11.704076862571464, 10.754163524979003, 9.783918403923375, 8.796927463785105, 7.851372307894243, 6.89624374202664, 7.831734594065148, 8.765754216462572, 9.742985077521888, 10.769199121880849, 11.68116386644406, 12.634614748782962, 13.585498637693016, 14.542162437392134, 14.535403101894232, 14.619379605991112, 14.568933396898226, 13.554686251318442, 12.57353316876036, 11.52485007180683, 10.65666814043293, 9.80700315100026, 8.870907740208528, 7.813630609400559, 6.875396988384403, 5.963042125861991, 6.871459431386606, 7.863782567867982, 8.79988166947765, 9.77497787844426, 10.724219635076718, 11.665684579706168, 12.618618400938054, 13.61136337576889, 14.474900019717579, 14.539469500445298, 13.612399527934484, 12.579761024283702, 11.618671842155248, 10.58955952592185, 9.655423576743914, 8.742569266275833, 7.826793060809372, 6.852775715997557, 5.887329861322291, 4.940136365691206, 5.863987779336407, 6.848019065768146, 7.813783358752135, 8.75315572394366, 9.747471309209976, 10.716539416587016, 11.624640706835708, 12.614534676626855, 13.547640580990482, 13.58341873126467, 12.617773754046489, 11.65204452112621, 10.66322483360702, 9.658218273869004, 8.727925124338675, 7.74654413429971, 6.853718503742957, 5.887909031445901, 4.930871875112454, 3.994186293237344, 4.87517696660412, 5.850311933885702, 6.847756627943858, 7.789382128878045, 8.833030291929461, 9.72266961567397, 10.616032673961094, 11.67726960156932, 12.58832735894144, 12.661928423652009, 11.69161355728835, 10.664616949264563, 9.716740705167549, 8.665073490501983, 7.720876604454213, 6.746682291487784, 5.787133696967045, 4.830742170983087, 3.89625309837585, 3.0036279396455305, 3.9390980695011413, 4.883365206915249, 5.883164217702351, 6.890335830625061, 7.772556678865647, 8.687362199344527, 9.629418701501978, 10.628976092261642, 11.561173766853303, 11.824565718347527, 10.763329870813457, 9.817159281197599, 8.819596456535422, 7.8623905087000185, 6.867169629551131, 5.877346632581288, 4.866022629575455, 3.873628981806683, 2.920788349041655, 1.9909373358245552, 3.0179000507632954, 3.9674703455708613, 4.854056134446249, 5.82425822976417, 6.768825908408255, 7.734488460607141, 8.7497408197298, 9.773415237897835, 10.777910019594117, 10.980852367315185, 9.919968955636516, 8.878589712215227, 7.859805810449631, 6.863443191216647, 5.897588067058866, 4.942754817145874, 3.9693969749823936, 2.93624750427732, 2.1118734067816822, 1.0476923216724814, 2.067095282298002, 2.9268053551724598, 3.854006268226334, 4.911450188491745, 5.867955728763707, 6.876314391706374, 7.840576441323585, 8.822619686058164, 9.88133122606751, 10.11220070947701, 9.136210462534608, 8.127143913655196, 7.075305010727131, 6.115065404181134, 5.0852910039830315, 4.0323263049845695, 2.9855472681267745, 1.9926885313011407, 1.0476392395281964, 0.0, 1.0396855488332244, 1.9848542634131927, 3.0165647116834142, 3.97566186327059, 5.01538442203417, 6.049671294449659, 7.0769640217868375, 8.144487351083512, 9.176991377544283, 10.889090940449352, 9.874952517328417, 8.923985190768343, 7.97803121825517, 6.965717469208954, 5.981040625359103, 4.9367149439227465, 3.9775307127055304, 3.0051368213254417, 2.0247193852819945, 1.039235672330932, 2.083168635154805, 2.9162083094052393, 3.8478024176621286, 4.820405420840061, 5.88580293746989, 6.831013171383351, 7.887696508026561, 8.888883992567933, 9.952322472667737, 11.648539638511652, 10.674952737913046, 9.735667543700204, 8.808062721681448, 7.8253670591771325, 6.841551471113137, 5.874722784529208, 4.960729597798121, 3.9626557688910786, 2.938703843053821, 1.995933074986029, 2.9749240359151377, 3.851256621382674, 4.836893896060537, 5.88844466853149, 6.876810980742096, 7.789429214533819, 8.798317256100434, 9.859275984185478, 10.845830973281684, 12.618491477053041, 11.72358064875936, 10.781401988850922, 9.830792853162725, 8.885985043423764, 7.83288359753732, 6.867041023991021, 5.89754977406313, 4.899724718515246, 3.8653081958993756, 2.9924285368778043, 3.9184602637781323, 4.843688509159686, 5.787504213827712, 6.72728934168915, 7.726874807619451, 8.736569278195748, 9.716313977231271, 10.751180013988252, 11.692350425181488, 13.546177110687218, 12.693301915999854, 11.775046614928513, 10.792929007957172, 9.85632257546531, 8.78202817585999, 7.824713564680197, 6.862809870487708, 5.912980009285386, 4.937005476279978, 4.040153649311223, 4.921147641642277, 5.852068900770037, 6.794476952661556, 7.699511496751785, 8.703060904849481, 9.71667776831201, 10.733622917499417, 11.684815252650623, 12.752585920415509], [12.636638516690136, 11.657882622946307, 10.620021456904285, 9.665024907387984, 8.615621685711432, 7.6433827180772465, 6.808865067686574, 5.818269965558371, 5.077590487770099, 6.029999569792605, 7.015950946016711, 7.903649079175356, 8.833628764396401, 9.805145294496384, 10.748501515146618, 11.75782451017998, 12.809610843510342, 13.738815016381713, 14.757283388170121, 15.570134885026974, 11.639596639876691, 12.583833378907851, 11.62749806777199, 10.637506096530268, 9.638746985112126, 8.617211861647295, 7.851331086213254, 6.8473953099452105, 6.006043926747859, 6.966609254526983, 7.89903883556811, 8.83185696938137, 9.827985829998022, 10.802336600494158, 11.79615705608806, 12.763927882852705, 13.828320385473974, 14.794399225944662, 15.68110714745396, 14.614378154090634, 10.744797831342565, 11.690525837169515, 12.682312806834386, 11.651821749244604, 10.596886797706121, 9.615229671626329, 8.837641471816893, 7.862212980590539, 6.987952549456413, 7.984415479471825, 8.918783788922706, 9.79726458402447, 10.834387888471392, 11.787298071554586, 12.780415424823655, 13.703326471287884, 14.750740828115221, 15.711986200866747, 14.712143009666859, 13.71499466728795, 9.853426485110907, 10.822509820262018, 11.866815257066927, 12.660147673195565, 11.606779358939932, 10.613606226725194, 9.836835054373214, 8.91059767562482, 8.03947807764209, 8.962327142311855, 9.944252798080962, 10.759411120899763, 11.808227273178868, 12.769053749895043, 13.843240729836904, 14.758350164350695, 15.688011922991592, 14.869719610477441, 13.942347452586855, 12.963686670764664, 9.140674075509772, 10.11092709765956, 11.046622361933292, 12.075233380681897, 12.567634888691531, 11.653581211108856, 10.789350013858554, 9.859781755074438, 9.0488407731844, 9.976821752346343, 10.873818627157773, 11.026409828873962, 11.755045780430443, 12.760030193317524, 13.602947811318035, 14.584673831752221, 15.090728383047978, 14.143862342792533, 13.10781414359828, 12.177069824144414, 9.806072900155753, 10.819913230519635, 11.801937532872202, 12.757831173184291, 13.507041079758585, 12.64265818749707, 11.742263422951567, 10.890805039421002, 10.090003650188134, 10.914600970978807, 10.92934342136346, 9.994445387718814, 10.806045962632261, 11.799802943241064, 12.675510943350382, 13.589173677217104, 14.524672784465064, 15.014087890914444, 14.070649182094703, 13.047597769890924, 10.761245181097564, 11.80087938901535, 12.797137279242433, 13.746836326500615, 14.451780610335662, 13.587487351215906, 12.698531883887904, 11.889369791608928, 11.034554766775093, 10.71069257172297, 9.869036747077624, 8.935869983961, 9.859439418591164, 10.804520849192693, 11.681641630099532, 12.634847720653125, 13.540796106907676, 14.456062147359297, 14.840309001076422, 13.88631567307485, 11.59540770868255, 12.629610451540948, 13.61247725358796, 14.574912549617489, 14.57610635698737, 13.59280712696575, 12.65671652302976, 11.68063253384265, 10.666870162983074, 9.725725203543252, 8.80967568268038, 7.996535768770822, 8.879235585110973, 9.794538259682474, 10.755552219927393, 11.667019984587627, 12.577882055814325, 13.5130446165171, 14.457152310597026, 14.649236636769343, 12.515167509282682, 13.58788093414359, 14.542521431737473, 14.568300533347346, 13.581435780519996, 12.743762411404687, 11.735990437622702, 10.765745316567074, 9.778754376428804, 8.785702557365736, 7.830573991498134, 6.983650668625403, 7.9176702910228265, 8.837601364670139, 9.735374323902025, 10.64733906846524, 11.600789950804142, 12.545813088859793, 13.502476888558911, 14.427860114670917, 13.579694057157887, 14.528877301208434, 14.594371800151665, 13.613218717593583, 12.564535620640052, 11.696353689266154, 10.846688699833484, 9.8861311594404, 8.82206052866934, 7.879994825129289, 6.897372375333484, 5.959451224630624, 6.922310980465735, 7.766056871498826, 8.741153080465436, 9.690394837097898, 10.625999030872945, 11.578932852104831, 12.571677826935666, 13.435214470884354, 14.432711091935785, 14.652085076767706, 13.619446573116925, 12.65835739098847, 11.629245074755072, 10.695109125577137, 9.782254815109058, 8.866478609642595, 7.8924612648307795, 6.903108534336202, 5.874466615162699, 4.9519795725804245, 5.9065474783658996, 6.779958560773312, 7.7193309259648375, 8.713646511231154, 9.676853867753794, 10.584955158002483, 11.57484912779363, 12.507955032157257, 14.623104280097893, 13.657459302879712, 12.691730069959434, 11.702910382440242, 10.697903822702227, 9.767610673171898, 8.786229683132934, 7.89340405257618, 6.9275945802791234, 5.946650548126366, 4.928516542708837, 3.9631687598481378, 4.908840346483455, 5.808071079110634, 6.74969658004482, 7.7933447430962355, 8.682984066840747, 9.57634712512787, 10.637584052736095, 11.548641810108215, 13.701613972485232, 12.731299106121574, 11.704302498097785, 10.756426254000772, 9.704759039335206, 8.760562153287436, 7.786367840321008, 6.8268192458002686, 5.870427719816311, 4.912031771389762, 3.9625599926007693, 3.0270898627451586, 3.91881332348013, 4.8434786688691265, 5.850650281791836, 6.732871130032422, 7.647676650511303, 8.589733152668753, 9.589290543428417, 10.521488218020078, 12.864251267180752, 11.803015419646682, 10.856844830030823, 9.859282005368646, 8.902076057533243, 7.9068551783843555, 6.917032181414513, 5.905708178408679, 4.913314530639907, 3.9365670220555664, 3.0067160088384663, 2.0657969186598644, 2.927784796737637, 3.8143705856130246, 4.784572680930945, 5.72914035957503, 6.694802911773916, 7.710055270896576, 8.73372968906461, 9.738224470760892, 12.02053791614841, 10.959654504469741, 9.918275261048452, 8.899491359282855, 7.903128740049872, 6.9372736158920905, 5.982440365979099, 5.009082523815618, 3.9759330531105443, 3.1276520797955936, 2.0634709946863925, 1.0274097334647774, 1.8871198063392354, 2.81432071939311, 3.8717646396585215, 4.828270179930484, 5.83662884287315, 6.8008908924903615, 7.78293413722494, 8.841645677234286, 11.151886258310233, 10.175896011367831, 9.166829462488419, 8.114990559560354, 7.154750953014358, 6.124976552816255, 5.072011853817793, 4.025232816959998, 3.032374080134365, 2.0873247883614208, 1.0396855488332244, 0.0, 0.9451687145799683, 1.9768791628501898, 2.935976314437365, 3.975698873200946, 5.009985745616435, 6.037278472953613, 7.104801802250289, 8.13730582871106, 11.928776489282576, 10.914638066161642, 9.963670739601568, 9.017716767088395, 8.005403018042179, 7.020726174192328, 5.976400492755971, 5.017216261538755, 4.044822370158666, 3.064404934115219, 2.0789212211641566, 1.0542462383725006, 1.8765227605720152, 2.8081168688289044, 3.780719872006837, 4.846117388636666, 5.791327622550126, 6.848010959193337, 7.849198443734709, 8.912636923834512, 12.688225187344877, 11.71463828674627, 10.775353092533429, 9.847748270514673, 8.865052608010357, 7.8812370199463615, 6.914408333362433, 6.000415146631346, 5.002341317724303, 3.9783893918870454, 3.0356186238192535, 2.0734591639099187, 2.81157107254945, 3.7972083472273126, 4.848759119698267, 5.837125431908873, 6.749743665700595, 7.7586317072672095, 8.819590435352254, 9.80614542444846, 13.658177025886266, 12.763266197592584, 11.821087537684146, 10.87047840199595, 9.925670592256989, 8.872569146370545, 7.906726572824246, 6.937235322896354, 5.939410267348471, 4.9049937447326, 4.018140577255802, 3.0921088503554737, 3.804002960326462, 4.747818664994488, 5.687603792855925, 6.687189258786226, 7.696883729362524, 8.676628428398047, 9.711494465155027, 10.652664876348263, 14.585862659520442, 13.732987464833078, 12.81473216376174, 11.832614556790398, 10.896008124298536, 9.821713724693215, 8.864399113513421, 7.902495419320933, 6.9526655581186105, 5.976691025113203, 5.065865689689221, 4.094796228219618, 4.8514052444127795, 5.754791403828332, 6.65982594791856, 7.663375356016258, 8.676992219478787, 9.693937368666194, 10.6451297038174, 11.712900371582286], [11.691469802110165, 10.712713908366336, 9.674852742324315, 8.719856192808015, 7.670452971131463, 6.698214003497278, 5.863696353106604, 4.873101250978403, 5.818807888617124, 6.771216970639631, 7.77399984788351, 8.661697981042154, 9.5916776662632, 10.563194196363183, 11.506550417013417, 12.515873412046778, 13.56765974537714, 14.496863918248511, 15.51533229003692, 16.401042000576325, 10.694427925296722, 11.638664664327882, 10.68232935319202, 9.6923373819503, 8.693578270532159, 7.672043147067327, 6.906162371633285, 5.902226595365242, 6.7472613275948845, 7.707826655374008, 8.640256236415135, 9.573074370228396, 10.586034731864821, 11.560385502360957, 12.554205957954858, 13.521976784719504, 14.586369287340773, 15.552448127811461, 16.512014263003312, 15.445285269639985, 9.799629116762596, 10.745357122589546, 11.737144092254418, 10.706653034664637, 9.651718083126154, 8.670060957046362, 7.892472757236924, 6.917044266010571, 7.729169950303438, 8.725632880318852, 9.660001189769734, 10.538481984871495, 11.575605289318418, 12.545346973421385, 13.538464326690454, 14.461375373154683, 15.50878972998202, 16.49639041904372, 15.54305012521621, 14.545901782837301, 8.908257770530938, 9.87734110568205, 10.921646542486958, 11.714978958615598, 10.661610644359964, 9.668437512145227, 8.891666339793247, 7.96542896104485, 8.780695478489116, 9.703544543158882, 10.68547019892799, 11.500628521746789, 11.890103754553978, 12.777625328136002, 13.708806966048982, 14.596138817258828, 15.526824196805432, 15.814888325057408, 14.887516167166822, 13.908855385344632, 8.195505360929802, 9.165758383079591, 10.101453647353324, 11.13006466610193, 11.622466174111564, 10.708412496528888, 9.844181299278585, 8.91461304049447, 9.790058174031426, 10.71803915319337, 11.6150360280048, 11.844881265190562, 10.817483634945107, 11.822468047832189, 12.657779096738068, 13.639505117172254, 14.61225613802675, 15.089031057372502, 14.052982858178249, 13.122238538724384, 8.860904185575786, 9.874744515939668, 10.856768818292235, 11.812662458604324, 12.561872365178617, 11.697489472917102, 10.797094708371597, 9.945636324841033, 10.83122105103516, 11.655818371825834, 11.820165304932573, 10.885267271287926, 9.868483817146926, 10.862240797755728, 11.730342228770414, 12.644004962637137, 13.579504069885097, 14.435912237659013, 15.015817896674672, 13.992766484470891, 9.816076466517597, 10.855710674435382, 11.851968564662466, 12.801667611920648, 13.506611895755695, 12.642318636635938, 11.753363169307935, 10.944201077028959, 11.775772167622119, 11.60151445529208, 10.759858630646736, 9.826691867530112, 8.921877273105828, 9.866958703707358, 10.736472915519565, 11.689679006073158, 12.595627392327708, 13.510893432779328, 14.463238883409103, 14.831484387654818, 10.650238994102583, 11.68444173696098, 12.667308539007992, 13.629743835037521, 14.457383887955949, 13.691980163071056, 12.755889559135065, 11.978154938747132, 11.557692046552184, 10.616547087112362, 9.70049756624949, 8.887357652339933, 7.941673439625638, 8.849369545102507, 9.810383505347426, 10.72185127000766, 11.632713341234357, 12.56787590193713, 13.511983596017057, 14.4940036347261, 11.569998794702714, 12.642712219563622, 13.597352717157506, 14.568003119952234, 14.477845305323136, 13.640171936207826, 12.626812321191812, 11.656567200136184, 10.669576259997914, 9.676524440934847, 8.721395875067243, 7.874472552194513, 6.980108145537493, 7.892432650090171, 8.790205609322058, 9.702170353885272, 10.655621236224174, 11.600644374279824, 12.557308173978942, 13.48269140009095, 12.63452534257792, 13.583708586628466, 14.59795573220825, 14.509628242396722, 13.460945145443192, 12.592763214069294, 11.743098224636624, 10.77695304300951, 9.71288241223845, 8.7708167086984, 7.788194258902594, 6.850273108199734, 5.9771422658857665, 6.820888156918858, 7.795984365885468, 8.745226122517929, 9.680830316292976, 10.633764137524862, 11.626509112355699, 12.490045756304387, 13.487542377355817, 14.524052696793445, 14.515856097920064, 13.55476691579161, 12.525654599558212, 11.591518650380277, 10.678664339912197, 9.762888134445735, 8.78887078963392, 7.797004726119716, 6.76528849873181, 5.842801456149535, 4.961378763785931, 5.834789846193344, 6.774162211384869, 7.768477796651186, 8.731685153173824, 9.639786443422516, 10.629680413213663, 11.56278631757729, 14.434675770720512, 14.553868827682852, 13.588139594762573, 12.599319907243382, 11.594313347505366, 10.664020197975038, 9.682639207936074, 8.78981357737932, 7.824004105082263, 6.840546739909879, 5.819338426277947, 4.853990643417248, 3.9636716319034866, 4.862902364530665, 5.804527865464852, 6.848176028516267, 7.737815352260779, 8.631178410547902, 9.692415338156128, 10.603473095528248, 14.598023497288372, 13.627708630924714, 12.600712022900925, 11.652835778803912, 10.601168564138346, 9.656971678090576, 8.682777365124148, 7.723228770603408, 6.766837244619451, 5.805927963173274, 4.85338187616988, 3.917911746314269, 2.9736446089001616, 3.898309954289158, 4.905481567211869, 5.787702415452454, 6.702507935931335, 7.644564438088786, 8.64412182884845, 9.57631950344011, 13.809419981760719, 12.74818413422665, 11.80201354461079, 10.804450719948614, 9.847244772113212, 8.852023892964324, 7.86220089599448, 6.850876892988647, 5.858483245219875, 4.846530984396603, 3.916679971179503, 2.975760881000901, 1.9826160821576688, 2.8692018710330562, 3.839403966350977, 4.783971644995062, 5.749634197193948, 6.764886556316608, 7.788560974484643, 8.793055756180925, 12.965706630728377, 11.904823219049709, 10.86344397562842, 9.844660073862823, 8.84829745462984, 7.882442330472059, 6.927609080559067, 5.954251238395586, 4.921101767690512, 4.03761604213663, 2.973434957027429, 1.9373736958058136, 0.9419510917592671, 1.8691520048131416, 2.926595925078553, 3.8831014653505154, 4.891460128293182, 5.855722177910393, 6.8377654226449724, 7.896476962654319, 12.097054972890202, 11.1210647259478, 10.111998177068388, 9.060159274140323, 8.099919667594326, 7.0701452673962235, 6.0171805683977615, 4.9704015315399666, 3.977542794714333, 3.032493502941389, 1.9848542634131927, 0.9451687145799683, 0.0, 1.0317104482702215, 1.9908075998573969, 3.030530158620978, 4.064817031036466, 5.092109758373644, 6.159633087670319, 7.19213711413109, 12.873945203862544, 11.859806780741609, 10.908839454181535, 9.962885481668362, 8.950571732622146, 7.965894888772296, 6.921569207335939, 5.962384976118724, 4.989991084738635, 4.009573648695187, 2.945044778967184, 1.901111816143311, 0.9313540459920467, 1.862948154248936, 2.835551157426868, 3.9009486740566977, 4.846158907970158, 5.902842244613368, 6.904029729154741, 7.967468209254544, 13.519132302894228, 12.545545402295621, 11.60626020808278, 10.678655386064024, 9.695959723559708, 8.712144135495713, 7.745315448911785, 6.7761735855589755, 5.760390219591102, 4.736438293753844, 3.7936675256860526, 2.814676564756944, 1.8664023579694813, 2.8520396326473443, 3.9035904051182975, 4.891956717328904, 5.804574951120626, 6.81346299268724, 7.874421720772284, 8.86097670986849, 14.489084141435617, 13.561256574660876, 12.599719293367475, 11.649110157679278, 10.704302347940317, 9.630618048237343, 8.664775474691044, 7.695284224763153, 6.69745916921527, 5.663042646599399, 4.759357978102828, 3.8333262512024993, 2.8588342457464933, 3.8026499504145193, 4.742435078275957, 5.742020544206258, 6.7517150147825555, 7.731459713818078, 8.766325750575058, 9.707496161768294, 15.416769775069794, 14.53097784190137, 13.572781065628536, 12.590663458657195, 11.654057026165333, 10.579762626560013, 9.62244801538022, 8.66054432118773, 7.710714459985409, 6.7347399269800015, 5.8070830905362465, 4.836013629066644, 3.906236529832811, 4.8096226892483624, 5.714657233338592, 6.718206641436289, 7.731823504898818, 8.748768654086224, 9.699960989237429, 10.767731657002315], [10.856407975838506, 9.877652082094677, 8.846756074210631, 7.891759524694331, 6.941053234278105, 6.017298290177595, 5.2530910466414085, 5.904811699248624, 6.850518336887346, 7.802927418909852, 8.80571029615373, 9.693408429312376, 10.623388114533421, 11.594904644633404, 12.538260865283638, 13.547583860317, 14.599370193647362, 15.528574366518733, 16.54704273830714, 17.432752448846546, 9.825468989264555, 10.782762823634569, 9.854232685078337, 8.864240713836615, 7.9641785336788, 6.991127433747644, 6.295557065168089, 6.9339370436354635, 7.778971775865106, 8.73953710364423, 9.671966684685357, 10.604784818498617, 11.617745180135042, 12.592095950631178, 13.58591640622508, 14.553687232989725, 15.618079735610994, 16.584158576081684, 17.543724711273537, 16.47699571791021, 8.89696596830003, 9.84269397412698, 10.84634015100305, 9.892062370518905, 8.933966788899092, 7.989145243726679, 7.290695624606254, 7.948754714280792, 8.76088039857366, 9.757343328589073, 10.691711638039955, 11.570192433141717, 12.607315737588639, 12.95146307594684, 13.905029196813, 14.78357055116595, 15.596503332526114, 16.520902885112775, 16.574760573486433, 15.577612231107524, 7.993859620245957, 8.962942955397068, 10.007248392201976, 10.90668119372586, 9.980694931040281, 8.987521798825544, 8.289889207162576, 8.997139409315071, 9.812405926759338, 10.735254991429104, 11.71718064719821, 12.53233897001701, 12.889973710526558, 11.969707397606385, 12.841215006893293, 13.728546858103138, 14.659232237649743, 15.483048352639116, 15.919226615437045, 14.940565833614855, 7.163794912659581, 8.13404793480937, 9.069743199083103, 10.098354217831709, 10.94155046079188, 10.027496783209205, 9.25682631554273, 9.94632348876469, 10.821768622301647, 11.749749601463591, 12.646746476275021, 12.84475122116314, 11.817353590917687, 11.014550117302571, 11.790187137582379, 12.771913158016565, 13.729974008330933, 14.408885326625288, 15.084693306448472, 14.153948986994607, 7.835152389990957, 8.848992720354838, 9.831017022707407, 10.786910663019496, 11.808598291808186, 11.016573759597419, 10.209739724635742, 10.977346773111254, 11.86293149930538, 12.687528820096055, 12.844958700424181, 11.910060666779534, 10.868353773119505, 10.05432286722611, 10.862750269614724, 11.761722832941322, 12.69722194018928, 13.473046666607102, 14.416485375426843, 15.024476932741113, 8.790324670932769, 9.829958878850555, 10.826216769077638, 11.77591581633582, 12.753337822385264, 11.961402923316255, 11.16600818557208, 11.97591152529918, 12.80748261589234, 12.633224903562303, 11.784652026138344, 10.85148526302172, 9.921747229078408, 9.05904077317774, 9.868880956363874, 10.807396876377343, 11.713345262631893, 12.548027861727418, 13.500373312357192, 14.454366640358764, 9.687373423050671, 10.721576165909067, 11.704442967956078, 12.666878263985607, 13.635504512132375, 13.024639983417568, 12.16853457539921, 13.009865387017353, 12.589402494822407, 11.648257535382585, 10.732208014519713, 9.912151047831541, 8.941543395598217, 8.029371133612306, 8.942791546191735, 9.839569140311845, 10.750431211538542, 11.60501033088522, 12.549118024965146, 13.531138063674188, 10.607133223650802, 11.67984664851171, 12.634487146105592, 13.60513754890032, 14.642921736822379, 13.957238848165238, 13.1796726740816, 12.688277648406405, 11.701286708268135, 10.70823488920507, 9.753106323337466, 8.906183000464734, 7.979978101510071, 7.072434238599971, 7.916917283200361, 8.819888224189457, 9.77333910652836, 10.637778803227913, 11.594442602927032, 12.519825829039037, 11.671659771526008, 12.620843015576554, 13.635090161156338, 14.560219364654083, 14.492655593713414, 13.624473662339515, 12.774808672906845, 11.808663491279733, 10.744592860508673, 9.802527156968623, 8.819904707172817, 7.881983556469956, 6.977012221858344, 6.000889745428658, 6.922696039763771, 7.862943992822115, 8.717964745241066, 9.670898566472951, 10.663643541303788, 11.527180185252474, 12.524676806303905, 13.561187125741533, 14.593825629392315, 14.586477364061832, 13.557365047828434, 12.623229098650498, 11.710374788182419, 10.794598582715958, 9.820581237904143, 8.828715174389936, 7.796998947002032, 6.874511904419757, 5.980555727687132, 5.0147914347031435, 5.900873885263172, 6.886195666955372, 7.768819582121914, 8.676920872370605, 9.666814842161752, 10.599920746525378, 13.4718101996686, 14.43745517688678, 14.619850043032795, 13.631030355513603, 12.626023795775588, 11.69573064624526, 10.714349656206295, 9.821524025649543, 8.855714553352486, 7.8722571881801, 6.8510488745481695, 5.88570109168747, 4.995382080173709, 4.042903953040465, 4.904975565053263, 5.892476319985363, 6.774949781208869, 7.668312839495991, 8.729549767104217, 9.640607524476335, 14.465966427133878, 14.659419079194935, 13.632422471171147, 12.684546227074133, 11.632879012408567, 10.688682126360797, 9.714487813394369, 8.75493921887363, 7.798547692889673, 6.837638411443496, 5.8850923244401026, 4.949622194584491, 4.005355057170384, 3.0783115427989585, 3.9782377430726465, 4.824836844400544, 5.739642364879424, 6.681698867036875, 7.681256257796538, 8.613453932388198, 14.84113043003094, 13.77989458249687, 12.833723992881012, 11.836161168218835, 10.878955220383435, 9.883734341234547, 8.893911344264703, 7.88258734125887, 6.890193693490098, 5.878241432666824, 4.948390419449725, 4.007471329271122, 3.0143265304278906, 2.0492034595428565, 2.9121601422117553, 3.8211060739431515, 4.786768626142037, 5.802020985264697, 6.7816990328851094, 7.786193814581392, 13.997417078998598, 12.93653366731993, 11.89515442389864, 10.876370522133044, 9.880007902900061, 8.914152778742281, 7.9593195288292895, 6.985961686665808, 5.952812215960735, 5.069326490406851, 4.00514540529765, 2.969084144076035, 1.9736615400294886, 1.0491535933229421, 1.9008441294937242, 2.8573496697656866, 3.865708332708353, 4.829970382325564, 5.812013627060143, 6.870725167069489, 13.128765421160425, 12.152775174218023, 11.143708625338611, 10.091869722410546, 9.13163011586455, 8.101855715666446, 7.048891016667984, 6.002111979810189, 5.009253242984555, 4.064203951211611, 3.0165647116834142, 1.9768791628501898, 1.0317104482702215, 0.0, 0.9590971515871755, 1.9988197103507566, 3.033106582766245, 4.060399310103422, 5.127922639400098, 6.160426665860869, 13.905655652132767, 12.891517229011832, 11.940549902451759, 10.994595929938585, 9.98228218089237, 8.997605337042518, 7.953279655606162, 6.994095424388946, 6.021701533008857, 5.041284096965409, 3.9767552272374056, 2.9328222644135327, 1.9630644942622681, 1.0546100904254099, 1.9328880089643026, 2.998285525594132, 3.943495759507592, 4.988444094328387, 5.989631578869759, 7.0530700589695625, 14.550842751164451, 13.577255850565844, 12.637970656353003, 11.710365834334247, 10.727670171829931, 9.743854583765936, 8.777025897182007, 7.807884033829197, 6.792100667861323, 5.768148742024065, 4.825377973956273, 3.846387013027165, 2.898112806239703, 2.1201571352207207, 3.000927256655732, 3.989293568866338, 4.90191180265806, 5.910799844224675, 6.971758572309719, 7.958313561405925, 15.52079458970584, 14.592967022931097, 13.631429741637696, 12.6808206059495, 11.736012796210538, 10.662328496507564, 9.696485922961266, 8.726994673033374, 7.729169617485491, 6.69475309486962, 5.791068426373049, 4.8650366994727205, 3.890544694016715, 3.1920446439493233, 4.061519364956274, 4.992251467623274, 5.88275607875039, 6.862500777785912, 7.897366814542893, 8.838537225736127, 16.448480223340017, 15.562688290171591, 14.604491513898758, 13.622373906927416, 12.685767474435554, 11.611473074830235, 10.654158463650441, 9.692254769457952, 8.74242490825563, 7.766450375250223, 6.838793538806468, 5.867724077336865, 4.9379469781030325, 4.1990173827831665, 5.033741520018909, 5.988806904582931, 6.903726836785134, 7.913706827814563, 8.864899162965768, 9.900184088957815], [9.89731082425133, 8.9185549305075, 7.887658922623456, 6.932662373107156, 5.98195608269093, 5.0582011385904195, 6.012484025198352, 6.819735173798304, 7.765441811437026, 8.717850893459532, 9.720633770703412, 10.608331903862057, 11.538311589083103, 12.509828119183085, 13.453184339833319, 14.46250733486668, 15.514293668197043, 16.443497841068414, 17.461966212856822, 18.347675923396228, 8.866371837677383, 9.823665672047396, 8.895135533491162, 7.905143562249441, 7.005081382091626, 6.032030282160468, 7.044463718402258, 7.848860518185144, 8.693895250414787, 9.65446057819391, 10.586890159235038, 11.519708293048298, 12.532668654684723, 13.507019425180859, 13.97101532414195, 14.763871988013952, 15.60867980558162, 16.57475864605231, 17.43752622845948, 17.39191919245989, 7.937868816712855, 8.883596822539806, 9.887242999415875, 8.93296521893173, 7.974869637311916, 7.030048092139503, 8.039602277840423, 8.863678188830473, 9.675803873123341, 10.672266803138754, 11.606635112589636, 12.485115907691398, 13.52223921213832, 13.734066487590411, 12.945932045225824, 13.824473399578773, 14.637406180938937, 15.5618057335256, 16.39885822051192, 16.492535705657204, 7.034762468658782, 8.003845803809893, 9.048151240614802, 9.947584042138686, 9.021597779453105, 8.028424647238367, 8.985315760178043, 9.912062883864753, 10.727329401309019, 11.650178465978785, 12.632104121747892, 13.447262444566691, 13.734573671886366, 12.752310809249956, 11.882117855306117, 12.769449706515962, 13.700135086062566, 14.52395120105194, 15.433366039289536, 15.865033191422024, 6.2046977610724054, 7.174950783222195, 8.110646047495926, 9.139257066244532, 9.982453309204704, 9.068399631622029, 9.952252868558197, 10.861246963314372, 11.736692096851328, 12.664673076013273, 13.561669950824703, 13.689351182522948, 12.661953552277495, 11.797153528946142, 10.831089985995202, 11.812816006429388, 12.770876856743756, 13.449788175038112, 14.42022326233609, 15.113046138581783, 6.876055238403782, 7.889895568767663, 8.87191987112023, 9.82781351143232, 10.84950114022101, 10.057476608010242, 10.90516627765121, 11.881038410403741, 12.777854973855062, 13.602452294645737, 13.68955866178399, 12.754660628139343, 11.712953734479314, 10.852745756975805, 9.903653118027547, 10.802625681354147, 11.738124788602104, 12.513949515019926, 13.457388223839667, 14.483708106992772, 7.831227519345594, 8.87086172726338, 9.867119617490461, 10.816818664748643, 11.794240670798088, 11.002305771729079, 11.861434738587548, 12.82829333945333, 13.722406090442021, 13.574207117530646, 12.629251987498153, 11.696085224381529, 10.766347190438216, 9.870018699660589, 8.909783804776698, 9.848299724790168, 10.754248111044717, 11.588930710140241, 12.541276160770016, 13.495269488771587, 8.728276271463494, 9.76247901432189, 10.745345816368902, 11.70778111239843, 12.676407360545198, 12.065542831830392, 12.863961128414678, 13.840045117601788, 13.53038470879075, 12.589239749350929, 11.673190228488057, 10.75675100919135, 9.786143356958025, 8.873971094972115, 7.983694394604559, 8.88047198872467, 9.791334059951366, 10.645913179298043, 11.59002087337797, 12.572040912087013, 9.648036072063627, 10.720749496924535, 11.675389994518415, 12.646040397313143, 13.683824585235202, 12.998141696578061, 13.875099227097067, 13.629259862374749, 12.642268922236479, 11.649217103173413, 10.69408853730581, 9.758597685267302, 8.824578062869879, 7.9170341999597795, 6.957820131613184, 7.860791072602281, 8.814241954941183, 9.678681651640737, 10.635345451339855, 11.560728677451863, 10.712562619938833, 11.66174586398938, 12.675993009569163, 13.601122213066906, 14.649805310020437, 14.045550418716594, 13.727538944103191, 12.761393762476077, 11.697323131705017, 10.755257428164967, 9.772634978369162, 8.817819502772892, 7.821612183218153, 6.845489706788467, 5.963598888176595, 6.903846841234939, 7.758867593653889, 8.711801414885775, 9.704546389716612, 10.5680830336653, 11.56557965471673, 12.602089974154358, 13.63472847780514, 14.5737951192802, 14.510095319024781, 13.575959369846846, 12.663105059378765, 11.747328853912302, 10.773311509100488, 9.781445445586282, 8.749729218198377, 7.8103478507226916, 6.825155689046941, 5.859391396062953, 4.9417767336759955, 5.927098515368196, 6.8097224305347375, 7.7178237207834295, 8.707717690574576, 9.640823594938203, 12.512713048081425, 13.478358025299606, 14.466216508316814, 14.58376062670995, 13.578754066971934, 12.648460917441607, 11.667079927402641, 10.774254296845887, 9.80844482454883, 8.824987459376446, 7.803779145744515, 6.838431362883815, 5.948112351370054, 4.887503914400274, 3.9458784134660876, 4.933379168398187, 5.815852629621692, 6.709215687908815, 7.770452615517041, 8.68151037288916, 13.506869275546704, 14.404518222057744, 14.585152742367494, 13.63727649827048, 12.585609283604914, 11.641412397557144, 10.667218084590715, 9.707669490069977, 8.751277964086018, 7.7903686826398415, 6.837822595636448, 5.902352465780837, 4.958085328366729, 3.9523731691986024, 3.019140591485471, 3.865739692813368, 4.780545213292248, 5.722601715449699, 6.722159106209362, 7.654356780801023, 14.517333894665686, 14.738991734084047, 13.792821144468189, 12.795258319806011, 11.838052371970612, 10.842831492821723, 9.85300849585188, 8.841684492846046, 7.849290845077273, 6.83097170386317, 5.901120690646071, 4.960201600467467, 3.967056801624236, 2.9232650859425005, 1.9530629906245798, 2.862008922355976, 3.8276714745548612, 4.842923833677521, 5.822601881297935, 6.827096662994217, 14.956514230585775, 13.895630818907106, 12.854251575485817, 11.83546767372022, 10.839105054487238, 9.873249930329457, 8.918416680416465, 7.945058838252984, 6.91190936754791, 6.0220567616031975, 4.957875676493996, 3.921814415272381, 2.9263918112258342, 1.99919089817196, 0.9417469779065487, 1.898252518178511, 2.9066111811211774, 3.870873230738389, 4.852916475472968, 5.911628015482314, 14.087862572747602, 13.1118723258052, 12.102805776925788, 11.050966873997723, 10.090727267451726, 9.060952867253622, 8.00798816825516, 6.961209131397364, 5.968350394571731, 5.023301102798786, 3.97566186327059, 2.935976314437365, 1.9908075998573969, 0.9590971515871755, 0.0, 1.039722558763581, 2.0740094311790696, 3.1013021585162472, 4.1688254878129225, 5.201329514273693, 14.830123009939935, 13.815984586819, 12.865017260258927, 11.919063287745754, 10.906749538699538, 9.922072694849687, 8.87774701341333, 7.918562782196114, 6.946168890816025, 5.965751454772577, 4.891678701787086, 3.847745738963213, 2.8779879688119485, 1.9463938605550593, 0.9737908573771271, 2.0391883740069567, 2.984398607920417, 4.029346942741212, 5.030534427282584, 6.093972907382387, 15.465766225714132, 14.492179325115526, 13.552894130902684, 12.625289308883929, 11.642593646379613, 10.658778058315617, 9.691949371731688, 8.722807508378878, 7.707024142411004, 6.683072216573747, 5.740301448505955, 4.7613104875768455, 3.813036280789383, 3.0119409053503703, 2.0418301050685566, 3.0301964172791633, 3.942814651070885, 4.951702692637499, 6.012661420722543, 6.999216409818748, 16.43571806425552, 15.507890497480778, 14.546353216187377, 13.59574408049918, 12.65093627076022, 11.577251971057246, 10.611409397510947, 9.641918147583056, 8.644093092035172, 7.609676569419301, 6.705991900922729, 5.779960174022401, 4.805468168566395, 4.042207341230536, 3.102422213369098, 4.033154316036099, 4.923658927163215, 5.903403626198737, 6.938269662955718, 7.879440074148953, 17.363403697889698, 16.477611764721274, 15.519414988448439, 14.537297381477098, 13.600690948985235, 12.526396549379916, 11.569081938200123, 10.607178244007633, 9.657348382805312, 8.681373849799904, 7.753717013356148, 6.782647551886545, 5.852870452652713, 5.026443020439956, 4.074644368431733, 5.029709752995756, 5.94462968519796, 6.954609676227388, 7.905802011378594, 8.941086937370642], [8.898514080030623, 7.919758186286793, 6.888862178402746, 5.933865628886447, 4.983159338470221, 5.989721962967013, 6.944004849574945, 7.859457732561885, 8.805164370200607, 9.757573452223113, 10.760356329466992, 11.648054462625637, 12.578034147846683, 13.549550677946666, 14.4929068985969, 14.971668947849858, 15.79233102899204, 16.72153520186341, 17.625741011489144, 18.52105334691957, 7.867575093456673, 8.824868927826685, 7.8963387892704535, 6.906346818028731, 6.006284637870917, 6.963551106537062, 7.975984542778852, 8.888583076948725, 9.733617809178368, 10.694183136957491, 11.626612717998619, 12.559430851811879, 13.572391213448304, 14.54674198394444, 14.905364068722422, 13.965565575177132, 14.755631218163687, 15.721710058634375, 16.57624014660485, 17.461811470619782, 6.921957334109123, 7.867685339936075, 8.871331516812145, 7.934168474711022, 6.9760728930912075, 7.957730019171, 8.971123102217016, 9.903400747594054, 10.715526431886921, 11.711989361902333, 12.646357671353215, 13.524838466454979, 14.5619617709019, 14.668415232170883, 13.880280789806296, 13.026166986741954, 13.784357593521005, 14.700519651670971, 15.537572138657291, 16.513575056302855, 5.995039909895201, 6.964123245046313, 8.008428681851221, 8.948787297917978, 8.037646047374217, 8.956106574269864, 9.91299768720954, 10.94203206284831, 11.7670519600726, 12.689901024742364, 13.67182668051147, 14.486985003330272, 14.668922416466838, 13.686659553830427, 12.816466599886589, 11.971143293679143, 12.847086498644634, 13.66266511919731, 14.572079957434907, 15.472974283581738, 5.164975202308825, 6.135228224458614, 7.070923488732346, 8.099534507480952, 8.998501577125817, 9.996081558653525, 10.879934795589694, 11.80950305437381, 12.776414655614909, 13.704395634776851, 14.601392509588281, 14.62369992710342, 13.596302296857967, 12.731502273526614, 11.765438730575674, 11.01450959359257, 11.90959077488913, 12.588502093183482, 13.558937180481461, 14.489681499935326, 6.014769156549153, 7.028609486913034, 8.0106337892656, 8.96652742957769, 9.93790776819287, 10.962794801292688, 11.832848204682707, 12.808720337435238, 13.775308160203682, 14.642174853409315, 14.623907406364461, 13.689009372719815, 12.647302479059785, 11.787094501556279, 10.83800186260802, 9.941339599499518, 10.876838706747478, 11.652663433165296, 12.596102141985037, 13.622422025138142, 6.969941437490965, 8.00957564540875, 9.005833535635832, 9.955532582894014, 10.882647298769948, 11.88786511616856, 12.789116665619044, 13.755975266484826, 14.719859276790642, 14.508555862111118, 13.563600732078624, 12.630433968962, 11.700695935018688, 10.804367444241063, 9.844132549357171, 8.987013642935539, 9.89296202919009, 10.727644628285612, 11.679990078915386, 12.633983406916958, 7.866990189608867, 8.901192932467264, 9.884059734514276, 10.846495030543805, 11.815121278690572, 12.798420508712193, 13.734511112648184, 14.710595101835294, 14.464733453371222, 13.5235884939314, 12.607538973068529, 11.691099753771821, 10.720492101538497, 9.808319839552588, 8.918043139185032, 8.01918590687004, 8.930047978096738, 9.784627097443414, 10.72873479152334, 11.710754830232384, 8.786749990208998, 9.859463415069905, 10.81410391266379, 11.784754315458517, 12.822538503380576, 13.731019373459862, 14.745649211330573, 14.56360860695522, 13.57661766681695, 12.583565847753885, 11.628437281886281, 10.692946429847774, 9.75892680745035, 8.851382944540253, 7.892168876193658, 6.999504990747653, 7.952955873086555, 8.817395569786108, 9.774059369485226, 10.699442595597233, 9.851276538084203, 10.80045978213475, 11.814706927714534, 12.73983613121228, 13.78851922816581, 14.773933660682196, 14.738174737187466, 13.704837191329412, 12.640766560558353, 11.698700857018302, 10.716078407222497, 9.752168247353364, 8.755960927798625, 7.77983845136894, 6.897947632757068, 6.042560759380311, 6.89758151179926, 7.8505153330311455, 8.843260307861982, 9.70679695181067, 10.7042935728621, 11.740803892299729, 12.77344239595051, 13.712509037425574, 14.72380977405079, 14.586595162931118, 13.67374085246304, 12.757964646996577, 11.783947302184762, 10.747415428477506, 9.693172647051712, 8.744696595303164, 7.759504433627414, 6.7937401406434255, 5.876125478256469, 5.0658124335135675, 5.948436348680109, 6.856537638928801, 7.846431608719947, 8.779537513083573, 11.651426966226795, 12.617071943444977, 13.604930426462184, 14.665993156908604, 14.589389860056208, 13.65909671052588, 12.677715720486916, 11.784890089930162, 10.819080617633105, 9.83562325246072, 8.81441493882879, 7.849067155968091, 6.894829376338611, 5.821852658980747, 4.88022715804656, 4.072093086543559, 4.9545665477670635, 5.847929606054186, 6.909166533662411, 7.820224291034531, 12.645583193692074, 13.543232140203115, 14.570228748226903, 14.647912291354753, 13.596245076689188, 12.652048190641418, 11.67785387767499, 10.718305283154251, 9.761913757170293, 8.801004475724117, 7.848458388720723, 6.912988258865112, 5.968721121451004, 4.944600697719455, 3.953489336065944, 3.0044536109587394, 3.9192591314376197, 4.86131563359507, 5.860873024354733, 6.793070698946394, 13.656047812811057, 14.599891497546475, 14.83254370323177, 13.834980878569594, 12.877774930734194, 11.882554051585306, 10.892731054615462, 9.881407051609628, 8.889013403840856, 7.870694262626751, 6.940843249409651, 5.999924159231049, 4.983834612914931, 3.915492614463353, 2.9452905191454324, 2.0007228405013473, 2.9663853927002326, 3.981637751822892, 4.961315799443305, 5.965810581139587, 14.609873700028661, 14.935353377670689, 13.8939741342494, 12.875190232483803, 11.87882761325082, 10.912972489093038, 9.958139239180046, 8.984781397016565, 7.951631926311492, 7.061779320366778, 5.997598235257577, 4.961536974035962, 3.9661143699894152, 3.038913456935541, 1.9814695366701298, 1.0369664363238824, 2.045325099266549, 3.00958714888376, 3.991630393618339, 5.050341933627685, 15.127585131511184, 14.151594884568782, 13.14252833568937, 12.090689432761305, 11.130449826215308, 10.100675426017204, 9.047710727018742, 8.000931690160947, 7.008072953335312, 6.063023661562368, 5.015384422034171, 3.9756988732009466, 3.0305301586209783, 1.9988197103507566, 1.039722558763581, 0.0, 1.0342868724154886, 2.0615795997526662, 3.129102929049342, 4.161606955510113, 15.869845568703516, 14.855707145582581, 13.904739819022508, 12.958785846509334, 11.946472097463118, 10.961795253613268, 9.91746957217691, 8.958285340959694, 7.985891449579605, 7.0054740135361575, 5.9314012605506665, 4.887468297726794, 3.9177105275755295, 2.9861164193186402, 2.0135134161407082, 1.0403916297862479, 1.985601863699708, 2.989624383977631, 3.9908118685190033, 5.054250348618806, 16.505488784477713, 15.531901883879105, 14.592616689666263, 13.665011867647507, 12.682316205143191, 11.698500617079196, 10.731671930495267, 9.762530067142459, 8.746746701174585, 7.722794775337327, 6.780024007269535, 5.801033046340426, 4.852758839552964, 4.051663464113951, 3.065450499728472, 2.0313996730584543, 2.9440179068501764, 3.9529059484167908, 5.000080314487003, 5.983304927215017, 17.475440623019104, 16.54761305624436, 15.58607577495096, 14.635466639262763, 13.690658829523802, 12.616974529820826, 11.651131956274527, 10.681640706346636, 9.683815650798753, 8.649399128182882, 7.74571445968631, 6.8196827327859815, 5.8451907273299755, 4.973728165607129, 4.033943037745692, 3.0343575718153906, 3.924862182942506, 4.904606881978029, 5.939472918735009, 6.880643329928245, 18.40312625665328, 17.517334323484853, 16.55913754721202, 15.57701994024068, 14.640413507748818, 13.566119108143496, 12.608804496963703, 11.646900802771214, 10.697070941568892, 9.721096408563485, 8.793439572119729, 7.822370110650126, 6.892593011416293, 5.95796384481655, 5.006165192808327, 4.030913008775047, 4.94583294097725, 5.95581293200668, 6.907005267157885, 7.942290193149932], [7.88135150822284, 6.902595614479011, 5.871699606594965, 4.916703057078665, 5.856417234489359, 6.862979858986151, 7.817262745594083, 8.805068771526201, 9.751919569058852, 10.704328651081358, 11.725889955761499, 12.613588088920144, 13.54356777414119, 14.515084304241173, 15.458440524891406, 15.893631789949103, 14.908688907484896, 15.837893080356267, 16.73772716413746, 17.633039499567882, 6.84909121425542, 7.806385048625433, 6.879176217462672, 5.88918424622095, 6.879542533890055, 7.836809002556199, 8.84924243879799, 9.834194115913041, 10.680373008036613, 11.640938335815736, 12.573367916856864, 13.506186050670124, 14.53792483974281, 15.512275610238946, 15.89017461508835, 14.887528417276377, 13.871989096656543, 14.838067937127231, 15.688226299253166, 16.573797623268096, 5.887670461693635, 6.8333984675205865, 7.837044644396656, 6.91700590290324, 7.849330789110345, 8.830987915190137, 9.844380998236154, 10.819809489462507, 11.662281630745166, 12.658744560760578, 13.59311287021146, 14.471593665313224, 15.508716969760146, 15.653225778536811, 14.865091336172224, 13.948129828841198, 12.90071547201386, 13.812505804319288, 14.649558291305608, 15.62556120895117, 4.960753037479713, 5.929836372630825, 6.974141809435732, 7.931624726110194, 8.910903943393356, 9.829364470289002, 10.786255583228678, 11.81528995886745, 12.713807158930845, 13.636656223600609, 14.618581879369716, 15.433740202188517, 15.653732962832763, 14.671470100196355, 13.801277146252517, 12.894129756684094, 11.96344437713749, 12.774651271845627, 13.684066110083224, 14.584960436230055, 4.130688329893336, 5.100941352043125, 6.036636616316857, 7.065247635065462, 8.124401148519595, 9.180615285403013, 10.251542998997278, 11.181111257781394, 12.191777735122253, 13.244727120675394, 14.277305204763335, 15.334462749069207, 14.581112843223892, 13.716312819892542, 12.750249276941602, 11.940883725720699, 11.025948653381986, 11.7004882458318, 12.670923333129778, 13.601667652583643, 4.984015690218683, 5.997856020582565, 6.976384908096944, 7.932278548409033, 8.953966177197723, 9.97885321029754, 11.026385945136584, 12.002258077889115, 12.96884590065756, 13.911572849559983, 14.873979764184556, 14.673819919085739, 13.63211302542571, 12.771905047922205, 11.822812408973947, 10.867713731627648, 9.993196585240334, 10.764649585813613, 11.708088294633354, 12.73440817778646, 5.939187971160495, 6.978822179078281, 7.971584654467175, 8.921283701725358, 9.8987057077748, 10.903923525173413, 11.829011476678112, 12.795870077543894, 13.790908327624358, 14.837955853994426, 14.548411278444549, 13.615244515327925, 12.685506481384612, 11.789177990606989, 10.828943095723098, 9.913387775063669, 9.009319907682945, 9.839630780933929, 10.791976231563703, 11.745969559565275, 6.897399158016167, 7.931601900874564, 8.914468702921575, 9.876903998951104, 10.845530247097871, 11.828829477119491, 12.764920081055482, 13.741004070242592, 14.754766441102168, 14.508399040297327, 13.592349519434455, 12.675910300137746, 11.705302647904421, 10.793130385918515, 9.902853685550959, 8.94556003899817, 8.046405856589594, 8.89661325009173, 9.840720944171657, 10.741163798639684, 7.817158958616298, 8.889872383477206, 9.844512881071088, 10.815163283865814, 11.852947471787873, 12.76142834186716, 13.776058179737872, 14.7463033007935, 14.561428213182879, 13.568376394119811, 12.613247828252208, 11.6777569762137, 10.743737353816277, 9.83619349090618, 8.876979422559584, 7.925879122875783, 7.069313751579412, 7.929381722434424, 8.886045522133541, 9.729851564004534, 8.881685506491502, 9.830868750542049, 10.845115896121833, 11.770245099619578, 12.818928196573108, 13.804342629089493, 14.748165215175817, 14.68964773769534, 13.62557710692428, 12.68351140338423, 11.700888953588425, 10.736978793719292, 9.740771474164552, 8.764648997734866, 7.882758179122995, 6.96893489150844, 6.009567664447577, 6.9625014856794625, 7.9552464605103, 8.73720592021797, 9.734702541269401, 10.77121286070703, 11.803851364357811, 12.742918005832871, 13.754218742458088, 14.688354691636023, 14.659704712017904, 13.743928506551441, 12.769911161739627, 11.732225974843434, 10.67798319341764, 9.729507141669092, 8.74431497999334, 7.778550687009353, 6.860936024622395, 5.992186565641697, 5.060422501328426, 5.968523791577118, 6.958417761368264, 7.809946481490873, 10.681835934634096, 11.647480911852277, 12.635339394869485, 13.696402125315904, 14.70140868505392, 14.645060570080744, 13.66367958004178, 12.770853949485026, 11.80504447718797, 10.821587112015585, 9.800378798383655, 8.835031015522956, 7.879639922704538, 6.806663205346674, 5.8650377044124875, 4.9984672186716885, 4.0665527004153805, 4.959915758702503, 5.939575502069712, 6.850633259441832, 11.675992162099375, 12.573641108610415, 13.600637716634203, 14.548513960731217, 14.582208936244053, 13.638012050196282, 12.663817737229854, 11.704269142709116, 10.747877616725157, 9.786968335278981, 8.834422248275587, 7.8989521184199765, 6.954684981005869, 5.9305645572743195, 4.938299882431871, 3.989264157324667, 3.0312452840859363, 3.9733017862433866, 4.891281992762034, 5.823479667353695, 12.728194157129735, 13.630300465953775, 14.553208445574503, 14.86926775098508, 13.890956945299994, 12.895736066151105, 11.905913069181262, 10.894589066175428, 9.902195418406656, 8.86866056210733, 7.93880954889023, 6.997890458711628, 5.969798472469796, 4.901456474018217, 3.931254378700296, 2.986686700056211, 2.078371545348549, 3.0026767692895096, 3.930562333112836, 4.935057114809118, 13.68202004434734, 14.685192467052797, 14.928261006664885, 13.909477104899288, 12.913114485666306, 11.947259361508525, 10.992426111595533, 10.019068269432053, 8.98591879872698, 8.059745619847357, 6.995564534738156, 5.959503273516541, 4.964080669469994, 4.03687975641612, 2.9794358361507083, 2.022930295878746, 1.0145716329360797, 1.9788336825532908, 2.9608769272878694, 4.019588467297216, 14.626851218417825, 15.185881756984267, 14.176815208104856, 13.12497630517679, 12.164736698630794, 11.13496229843269, 10.081997599434228, 9.035218562576434, 8.0423598257508, 7.097310533977856, 6.049671294449659, 5.009985745616435, 4.064817031036466, 3.033106582766245, 2.0740094311790696, 1.0342868724154886, 0.0, 1.0272927273371777, 2.094816056633853, 3.1273200830946237, 15.619870617712143, 15.821240771877088, 14.870273445317014, 13.924319472803841, 12.912005723757625, 11.927328879907774, 10.883003198471418, 9.923818967254201, 8.951425075874113, 7.971007639830665, 6.896934886845174, 5.853001924021301, 4.883244153870037, 3.951650045613148, 2.9790470424352153, 1.9136495258053858, 0.9684392918919259, 1.9553375115621425, 2.956524996103515, 4.019963476203318, 16.571504388881664, 16.497435510173613, 15.558150315960772, 14.630545493942016, 13.6478498314377, 12.664034243373704, 11.697205556789775, 10.728063693436965, 9.712280327469092, 8.688328401631834, 7.745557633564042, 6.766566672634934, 5.818292465847471, 4.993563861085018, 3.9387083957476103, 2.9046575690775924, 1.9268553350423943, 2.9357433766090084, 3.965793442071515, 4.949018054799529, 17.529998751472466, 17.513146682538864, 16.551609401245464, 15.601000265557268, 14.656192455818307, 13.582508156115333, 12.616665582569034, 11.647174332641143, 10.64934927709326, 9.614932754477389, 8.711248085980817, 7.785216359080489, 6.790801766294293, 5.846986061626267, 4.9072009337648295, 3.9076154678345283, 2.907699611134724, 3.8874443101702467, 4.920989039533756, 5.862159450726992, 18.457684385106642, 17.764517688922673, 16.880989352509093, 15.90400126842076, 15.605947134043323, 14.531652734438003, 13.57433812325821, 12.61243442906572, 11.662604567863399, 10.686630034857991, 9.758973198414235, 8.769125309508372, 7.838204050380611, 6.831221740835687, 5.879423088827465, 4.904170904794185, 3.9286703691694687, 4.938650360198898, 5.889842695350103, 6.923806313948679], [6.871888466951825, 5.92419932706376, 4.9848215908179645, 5.932991886054914, 6.872706063465608, 7.8792686879624, 8.83355157457033, 9.82135760050245, 10.768208398035101, 11.720617480057607, 12.742178784737748, 13.629876917896393, 14.559856603117439, 15.531373133217421, 16.474729353867655, 16.638155355294522, 15.653212472830315, 15.06079954722769, 15.860845096777624, 16.75615743220804, 5.821798486918241, 6.779092321288254, 6.024987243498741, 6.905473075197198, 7.8958313628663035, 8.853097831532448, 9.865531267774239, 10.85048294488929, 11.696661837012861, 12.657227164791985, 13.589656745833112, 14.522474879646373, 15.55421366871906, 16.528564439215195, 16.644650258038, 15.632051982621796, 14.616512662001963, 14.00314156512728, 14.811344231893328, 15.696915555908257, 4.860377734356457, 5.806105740183408, 6.809751917059478, 7.840242974649259, 8.865619618086594, 9.847276744166386, 10.860669827212403, 11.836098318438756, 12.678570459721415, 13.675033389736829, 14.60940169918771, 15.487882494289472, 16.525005798736395, 16.620638976279174, 15.628510507916566, 14.692653394186618, 13.64523903735928, 12.93562373695945, 13.77267622394577, 14.748679141591332, 3.933460310142535, 4.902543645293647, 5.946849082098554, 6.985490336568514, 8.038858650824148, 9.032031783038885, 9.988922895978561, 11.017957271617332, 12.056249958212721, 13.014431018343673, 14.058188596805387, 15.10734691908171, 16.156163071360815, 15.638883297938719, 14.564696317996859, 13.638653322029514, 12.70796794248291, 11.897769204485789, 12.807184042723385, 13.708078368870217, 3.1033956025561587, 4.073648624705948, 5.0093438889796795, 6.037954907728285, 7.097108421182419, 8.153322558065836, 9.224250271660102, 10.153818530444218, 11.164485007785077, 12.217434393338218, 13.250012477426159, 14.30717002173203, 15.334567651977483, 14.696861443053434, 13.730797900102495, 12.82402344757607, 11.770472218727406, 10.82360617847196, 11.79404126576994, 12.724785585223804, 4.009668107916428, 5.0235084382803095, 5.9490921807597665, 6.904985821071856, 7.926673449860545, 8.951560482960364, 9.999093217799407, 10.974965350551939, 11.941553173320383, 12.884280122222806, 13.84668703684738, 14.781585070492026, 14.622394865323383, 13.752453671083098, 12.80336103213484, 11.840150827245473, 10.888192286985495, 9.887767518453774, 10.831206227273515, 11.82566176001931, 4.96484038885824, 6.004474596776027, 6.944291927129997, 7.89399097438818, 8.871412980437622, 9.876630797836235, 10.801718749340933, 11.768577350206716, 12.763615600287178, 13.81066312665725, 14.842897539190496, 14.605526355225598, 13.675788321282285, 12.769726613767881, 11.80949171888399, 10.885824870681494, 9.961801464389273, 8.96274871357409, 9.915094164203865, 10.837223141798125, 5.949394602876941, 6.961112582543134, 7.894666470350048, 8.857101766379577, 9.822184972637876, 10.805484202659496, 11.741574806595487, 12.717658795782597, 13.731421166642173, 14.672566126081994, 14.582631359332128, 13.666192140035418, 12.695584487802094, 11.783412225816187, 10.883402308711851, 9.917997134615996, 8.998887413295922, 8.019731182731892, 8.963838876811819, 9.819153257109521, 6.895148417086135, 7.931791852534159, 8.824710648499561, 9.79536105129429, 10.833145239216348, 11.738083067407166, 12.752712905277876, 13.722958026333504, 14.709948966471774, 14.558658234017484, 13.60352966814988, 12.668038816111373, 11.73401919371395, 10.826475330803852, 9.857528045720477, 8.898316218493608, 8.02179530828574, 7.052499655074585, 8.009163454773702, 8.80784102247437, 7.959674964961339, 8.908858209011886, 9.837672930900252, 10.750442867048053, 11.799125964001583, 12.784540396517968, 13.724819940715822, 14.727435118276084, 14.615858946821952, 13.673793243281901, 12.691170793486096, 11.727260633616963, 10.731053314062224, 9.75493083763254, 8.873040019020667, 7.941371987126266, 6.973207619118371, 6.085619418319624, 7.06141529609307, 7.815195378687807, 8.812691999739238, 9.849202319176866, 10.881840822827648, 11.723115773261346, 12.734416509886563, 13.668552459064498, 14.639436500392828, 14.764025785920515, 13.77532867942217, 12.722507814741105, 11.668265033315311, 10.719788981566763, 9.734596819891012, 8.768832526907024, 7.851217864520068, 6.964623661259523, 6.0240624559992195, 5.074692627159888, 6.064586596951035, 6.88793593996071, 9.759825393103933, 10.725470370322114, 11.713328853339322, 12.771278623770776, 13.702164275098802, 14.596050911469737, 14.683776859410854, 13.7909512288541, 12.825141756557043, 11.841684391384659, 10.81040451274449, 9.845056729883792, 8.86992176260221, 7.796945045244346, 6.855319544310159, 5.970904314289514, 5.038989796033206, 4.0660845942852735, 5.017564960539549, 5.928622717911669, 10.753981620569212, 11.651630567080252, 12.67862717510404, 13.626503419201054, 14.678170633866621, 14.658109329565356, 13.683915016598927, 12.72436642207819, 11.76797489609423, 10.807065614648055, 9.85451952764466, 8.919049397789049, 7.9747822603749405, 6.950661836643391, 5.928581722329543, 4.979545997222338, 4.021527123983607, 3.079470621826157, 3.969271451231871, 4.901469125823532, 11.806183615599572, 12.708289924423612, 13.63119790404434, 14.601929936683891, 14.911054224669066, 13.915833345520177, 12.926010348550333, 11.9146863455445, 10.922292697775728, 9.888757841476401, 8.958906828259302, 8.017987738080699, 6.989895751838867, 5.921553753387289, 4.951351658069368, 4.006783979425283, 3.098468824717621, 2.0942499494241593, 3.0085517915826734, 3.981344593933578, 12.760009502817176, 13.763181925522634, 14.643299196377317, 14.936769832236465, 13.940407213003482, 12.974552088845702, 12.01971883893271, 11.046360996769229, 10.013211526064156, 9.079842899216429, 8.015661814107228, 6.979600552885612, 5.984177948839066, 5.0569770357851915, 3.99953311551978, 3.0430275752478178, 2.0346689123051513, 1.0704068626879402, 2.0388663857577067, 3.0452408849949606, 13.749969151057986, 14.725959398000388, 15.204107935442032, 14.152269032513967, 13.19202942596797, 12.162255025769866, 11.109290326771404, 10.06251128991361, 9.069652553087977, 8.124603261315032, 7.076964021786837, 6.037278472953612, 5.092109758373644, 4.060399310103422, 3.1013021585162472, 2.0615795997526662, 1.0272927273371777, 0.0, 1.0675233292966755, 2.1000273557574465, 14.742988550352305, 15.675385035699323, 15.886562274293263, 14.94060830178009, 13.928294552733874, 12.943617708884023, 11.899292027447666, 10.94010779623045, 9.967713904850362, 8.987296468806914, 7.913223715821423, 6.86929075299755, 5.899532982846286, 4.967938874589397, 3.9953358714114646, 2.929938354781635, 1.984728120868175, 0.9280447842249647, 1.929232268766337, 2.99267074886614, 15.694622321521823, 16.66820922212043, 16.57443914493702, 15.646834322918263, 14.664138660413947, 13.680323072349951, 12.713494385766023, 11.744352522413214, 10.72856915644534, 9.704617230608083, 8.76184646254029, 7.7828555016111824, 6.83458129482372, 6.009852690061267, 4.95499722472386, 3.9209463980538413, 2.9431441640186433, 1.9905056070822558, 2.938500714734337, 3.9217253274623514, 16.653116684112625, 17.71038400470325, 17.16476790318159, 16.61728909453352, 15.672481284794557, 14.598796985091582, 13.632954411545283, 12.663463161617392, 11.665638106069508, 10.631221583453637, 9.727536914957065, 8.801505188056737, 7.807090595270542, 6.863274890602516, 5.923489762741078, 4.923904296810777, 3.923988440110973, 2.9942134813567387, 3.8936963121965777, 4.834866723389813, 17.5808023177468, 16.887635621562836, 16.10389581938052, 16.64852483376618, 16.622235963019573, 15.547941563414252, 14.590626952234459, 13.628723258041969, 12.678893396839648, 11.70291886383424, 10.775262027390484, 9.78541413848462, 8.85449287935686, 7.847510569811936, 6.895711917803713, 5.920459733770434, 4.9449591981457175, 4.04541953138539, 4.911446407934852, 5.8965135866115], [5.940201364721988, 4.992512224833922, 5.870353700288793, 6.825350249805092, 7.894931055073611, 8.941678807487163, 9.895961694095094, 10.883767720027212, 11.830618517559863, 12.783027599582368, 13.809702114034422, 14.697400247193068, 15.627379932414113, 16.598896462514094, 17.542252683164328, 17.459990246163223, 16.475047363699016, 15.88263443809639, 15.068599974025874, 15.786952835384273, 4.882442385978372, 5.8274623440763165, 6.783797655212178, 7.7737896264539, 8.807127970844482, 9.879966210673375, 10.892399646915166, 11.906815737141953, 12.759071956537623, 13.719637284316747, 14.652066865357874, 15.584884999171134, 16.621736998015734, 17.596087768511868, 17.4664851489067, 16.453886873490497, 15.438347552870663, 14.82497645599598, 14.019099109141578, 14.727710959084488, 3.8766605987617266, 4.822388604588678, 5.826034781464747, 6.8565258390545285, 7.911460790593011, 8.893117916672804, 9.916569575270271, 10.891998066496624, 11.876225149564318, 12.874150640340845, 13.808518949791726, 14.868385430573216, 15.905508735020138, 16.955093296010226, 16.450345398785267, 15.514488285055318, 14.46707392822798, 13.75745862782815, 12.98043110119402, 13.779474544767563, 2.9497431745478044, 3.9188265096989157, 4.9631319465038235, 5.917967007271838, 6.971335321527472, 7.9645084537422095, 8.921399566681886, 9.950433942320657, 10.988726628916046, 11.946907689046999, 12.990665267508714, 14.039823589785037, 15.088639742064142, 16.1353077018327, 15.38653120886556, 14.460488212898214, 13.52980283335161, 12.719604095354489, 12.014938919971636, 12.738873772046448, 2.035872273259483, 3.006125295409272, 3.941820559683004, 4.970431578431609, 6.029585091885743, 7.085799228769161, 8.156726942363425, 9.086295201147541, 10.0969616784884, 11.149911064041541, 12.182489148129482, 13.239646692435354, 14.267044322680807, 15.29771323458573, 14.552632790971195, 13.645858338444771, 12.592307109596106, 11.645441069340661, 11.00179614301819, 11.755580988400036, 2.9421447786197525, 3.9559851089836338, 4.881568851463091, 5.83746249177518, 6.85915012056387, 7.884037153663687, 8.93156988850273, 9.907442021255262, 10.874029844023706, 11.81675679292613, 12.779163707550703, 13.71406174119535, 14.782642300995263, 14.574288561951798, 13.62519592300354, 12.661985718114174, 11.710027177854196, 10.709602409322475, 10.038961104521766, 10.758138430722635, 3.8973170595615643, 4.93695126747935, 5.876768597833322, 6.826467645091505, 7.803889651140947, 8.80910746853956, 9.734195420044259, 10.70105402091004, 11.696092270990505, 12.743139797360573, 13.775374209893819, 14.708540973010443, 14.497623212150986, 13.591561504636582, 12.63132660975269, 11.707659761550195, 10.783636355257974, 9.78458360444279, 9.049969677725663, 9.76969981250145, 4.881871273580265, 5.893589253246457, 6.827143141053372, 7.789578437082902, 8.754661643341201, 9.737960873362821, 10.674051477298812, 11.650135466485922, 12.663897837345498, 13.60504279678532, 14.611929294982392, 14.488027030904119, 13.517419378670795, 12.605247116684888, 11.705237199580552, 10.739832025484697, 9.820722304164622, 8.841566073600593, 8.042429137684366, 8.751629927812846, 5.82762508778946, 6.864268523237483, 7.7571873192028855, 8.727837721997613, 9.765621909919671, 10.67055973811049, 11.685189575981202, 12.65543469703683, 13.6424256371751, 14.545065442962835, 14.42536455901858, 13.489873706980074, 12.55585408458265, 11.648310221672553, 10.679362936589177, 9.720151109362309, 8.84363019915444, 7.874334545943286, 7.0837377701879225, 7.740317693177696, 6.892151635664664, 7.841334879715211, 8.770149601603578, 9.682919537751376, 10.731602634704906, 11.717017067221292, 12.657296611419147, 13.659911788979409, 14.625722491559644, 14.495628134150602, 13.513005684354797, 12.549095524485663, 11.552888204930925, 10.57676572850124, 9.694874909889368, 8.763206877994968, 7.795042509987072, 6.907454309188325, 6.021222353981788, 6.747672049391132, 7.745168670442562, 8.78167898988019, 9.814317493530972, 10.65559244396467, 11.666893180589886, 12.601029129767822, 13.571913171096151, 14.539778924170111, 14.59716357029087, 13.544342705609806, 12.490099924184012, 11.541623872435464, 10.556431710759712, 9.590667417775725, 8.673052755388769, 7.786458552128224, 6.845897346867921, 5.89652751802859, 5.024393654839752, 5.820412610664035, 8.692302063807258, 9.657947041025439, 10.645805524042647, 11.7037552944741, 12.634640945802126, 13.52852758217306, 14.567938303072275, 14.616446010012702, 13.650636537715645, 12.66717917254326, 11.632239403613191, 10.666891620752493, 9.691756653470911, 8.618779936113047, 7.677154435178861, 6.792739205158215, 5.860824686901907, 4.887919485153975, 3.9500416312428737, 4.861099388614994, 9.686458291272537, 10.584107237783577, 11.611103845807365, 12.558980089904379, 13.610647304569945, 14.535576102057522, 14.50940979775753, 13.54986120323679, 12.593469677252832, 11.632560395806657, 10.680014308803262, 9.74454417894765, 8.800277041533542, 7.776156617801993, 6.750416613198245, 5.80138088809104, 4.843362014852309, 3.9013055126948584, 2.9017481219351953, 3.833945796526856, 10.738660286302897, 11.640766595126937, 12.563674574747665, 13.534406607387217, 14.529229348770226, 14.798812784027845, 13.808989787058001, 12.797665784052167, 11.805272136283396, 10.771737279984071, 9.841886266766972, 8.90096717658837, 7.872875190346537, 6.804533191894959, 5.834331096577038, 4.8897634179329525, 3.979955239576692, 2.9647028804540323, 1.9410284622859977, 2.913821264636902, 11.692486173520502, 12.69565859622596, 13.575775867080642, 14.494197253473008, 14.923778694948137, 13.957923570790356, 13.003090320877364, 12.029732478713884, 10.990183100132707, 9.962822337724099, 8.898641252614897, 7.862579991393282, 6.867157387346736, 5.939956474292861, 4.88251255402745, 3.9260070137554877, 2.9176483508128213, 1.95338630119561, 0.9713430564610313, 1.9777175556982851, 12.73864930291284, 13.714639549855242, 14.520092646276908, 15.219792361810644, 14.259552755264647, 13.229778355066543, 12.17681365606808, 11.130034619210287, 10.137175882384653, 9.192126590611709, 8.144487351083512, 7.104801802250288, 6.159633087670319, 5.127922639400098, 4.1688254878129225, 3.1291029290493415, 2.094816056633853, 1.0675233292966755, 0.0, 1.032504026460771, 13.773783953528536, 14.664065187554177, 15.489418884536336, 16.008131631076765, 14.995817882030547, 14.011141038180696, 12.96681535674434, 12.007631125527123, 11.035237234147035, 10.054819798103587, 8.980747045118097, 7.936814082294225, 6.967056312142961, 6.0354622038860715, 5.062859200708139, 3.9974616840783104, 3.0522514501648503, 1.99556811352164, 0.9975451665364989, 2.0089536132714096, 14.725417724698055, 15.691220434259106, 16.560848256570228, 16.71435765221494, 15.731661989710624, 14.747846401646628, 13.7810177150627, 12.811875851709889, 11.796092485742015, 10.772140559904757, 9.829369791836966, 8.850378830907857, 7.902104624120395, 7.077376019357942, 6.022520554020534, 4.988469727350517, 4.010667493315319, 3.058028936378931, 2.006813612504499, 2.938008191867621, 15.683912087288856, 16.73984834510542, 17.607114179919066, 17.68481242383019, 16.74000461409123, 15.666320314388257, 14.700477740841958, 13.730986490914066, 12.733161435366183, 11.698744912750312, 10.79506024425374, 9.869028517353412, 8.869500714795304, 7.925685010127279, 6.985899882265842, 5.98631441633554, 4.976619945759243, 3.9968752467237203, 2.9620092099667397, 3.903179621159975, 16.611597720923033, 16.09539049881109, 16.92573071024922, 17.470359724634882, 17.689759292316246, 16.615464892710925, 15.658150281531134, 14.696246587338644, 13.746416726136323, 12.770442193130915, 11.842785356687159, 10.847824258009382, 9.916902998881621, 8.9099206893367, 7.958122037328477, 6.961513653506153, 5.947896790043624, 4.930951640856218, 3.979759305705014, 4.964826484381663], [4.921624116870625, 5.737828651293855, 6.75559924228735, 7.71059579180365, 8.780176597072169, 9.821291327782653, 10.775574214390584, 11.76901326202577, 12.71586405955842, 13.668273141580926, 14.711336089352857, 15.67821524241844, 16.608194927639488, 17.579711457739467, 18.5230676783897, 18.3895037408203, 17.404560858356096, 16.81214793275347, 15.837528915620243, 14.882158314201284, 3.8499383595176018, 4.794958317615546, 5.751293628751407, 6.741285599993129, 7.774623944383711, 8.847462184212604, 9.859895620454395, 10.874311710681182, 11.819612933025407, 12.780178260804531, 13.712607841845658, 14.645425975658918, 15.698164654496923, 16.74493946122991, 17.791468367693113, 17.383400368147573, 16.367861047527743, 15.754489950653058, 14.788028050735948, 13.8229164379015, 2.844156572300956, 3.789884578127907, 4.793530755003976, 5.824021812593758, 6.878956764132241, 7.860613890212033, 8.8840655488095, 9.859494040035854, 10.843721123103547, 11.841646613880075, 12.776014923330955, 13.835881404112445, 14.873004708559368, 15.922589269549457, 16.915706622818526, 16.444001779712394, 15.396587422885059, 14.686972122485228, 13.749360042788389, 12.874680023584574, 1.9172391480870332, 2.8863224832381444, 3.930627920043052, 4.8854629808110674, 5.938831295066701, 6.932004427281439, 7.888895540221115, 8.917929915859885, 9.956222602455274, 10.914403662586226, 11.95816124104794, 13.007319563324263, 14.056135715603368, 15.102803675371927, 16.176990655313787, 15.390001707555292, 14.459316328008688, 13.649117590011567, 12.783867861566005, 11.834079250863459, 1.0033682467987122, 1.9736212689485015, 2.909316533222233, 3.937927551970838, 4.997081065424973, 6.05329520230839, 7.124222915902655, 8.05379117468677, 9.06445765202763, 10.11740703758077, 11.149985121668712, 12.207142665974583, 13.234540296220036, 14.26520920812496, 15.231272751075899, 14.57537183310185, 13.521820604253184, 12.57495456399774, 11.77072508461256, 10.850786467217047, 1.9096407521589818, 2.923481082522863, 3.84906482500232, 4.804958465314409, 5.826646094103099, 6.8515331272029165, 7.89906586204196, 8.874937994794491, 9.841525817562935, 10.78425276646536, 11.746659681089932, 12.681557714734579, 13.750138274534493, 14.762717878361624, 14.569979480589955, 13.60676927570059, 12.639540672511274, 11.639115903979553, 10.807890046116135, 9.853343909539646, 2.8648130331007935, 3.9044472410185795, 4.844264571372551, 5.793963618630734, 6.7713856246801765, 7.776603442078789, 8.701691393583488, 9.66854999444927, 10.663588244529734, 11.710635770899803, 12.742870183433048, 13.676036946549672, 14.69674481857559, 14.536345062222997, 13.576110167339106, 12.65244331913661, 11.713149849915053, 10.714097099099869, 9.818898619320032, 8.864905291318461, 3.8493672471194946, 4.861085226785686, 5.794639114592601, 6.757074410622131, 7.7221576168804305, 8.70545684690205, 9.641547450838042, 10.617631440025152, 11.631393810884727, 12.572538770324549, 13.579425268521621, 14.556198946852605, 14.462202936257214, 13.550030674271305, 12.650020757166967, 11.684615583071112, 10.750235798821702, 9.77107956825767, 8.828033003234683, 7.846835406629857, 4.828017981021179, 5.831764496776712, 6.724683292742115, 7.695333695536842, 8.7331178834589, 9.63805571164972, 10.652685549520431, 11.622930670576059, 12.609921610714329, 13.512561416502065, 14.467689982369668, 14.434657264566491, 13.500637642169067, 12.59309377925897, 11.624146494175593, 10.664934666948724, 9.77314369381152, 8.803848040600364, 7.86934163573824, 6.835523171994707, 5.896982678541368, 6.846165922591915, 7.737645575142807, 8.650415511290605, 9.699098608244135, 10.684513040760521, 11.624792584958376, 12.627407762518638, 13.593218465098873, 14.535284168638924, 14.457789241941214, 13.49387908207208, 12.497671762517342, 11.521549286087657, 10.639658467475785, 9.707990435581383, 8.739826067573487, 7.836967803845402, 6.82805928613408, 5.8428775282081435, 6.840374149259574, 7.858736792250798, 8.810440083132772, 9.623088417503899, 10.634389154129115, 11.568525103307051, 12.53940914463538, 13.50727489770934, 14.50378367308208, 14.489126263196223, 13.434883481770429, 12.486407430021881, 11.50121526834613, 10.535450975362142, 9.617836312975186, 8.731242109714639, 7.790680904454336, 6.841311075615005, 5.957184469540254, 4.915618089481047, 7.787507542624269, 8.75315251984245, 9.738156586290263, 10.671251268013329, 11.602136919341355, 12.49602355571229, 13.535434276611504, 14.480349454775755, 14.595420095302062, 13.611962730129678, 12.577022961199606, 11.611675178338908, 10.636540211057326, 9.563563493699464, 8.621937992765277, 7.73752276274463, 6.805608244488322, 5.83270304274039, 4.882832445943375, 3.956304867432005, 8.781663770089548, 9.679312716600588, 10.706309324624376, 11.652493717637553, 12.595281702708375, 13.503072075596751, 14.47726638856318, 14.494644760823208, 13.53825323483925, 12.577343953393074, 11.62479786638968, 10.689327736534068, 9.74506059911996, 8.72094017538841, 7.695200170784661, 6.746164445677456, 5.788145572438725, 4.846089070281274, 3.846531679521611, 2.9291512753438678, 9.833865765119908, 10.735972073943948, 11.658880053564676, 12.62792023512039, 13.618386231163722, 14.441508753729805, 14.841493813518772, 13.830169810512938, 12.837776162744166, 11.804241306444842, 10.874390293227743, 9.92530497101864, 8.873513121775579, 7.805171123324, 6.834969028006079, 5.890401349361994, 4.9247387971631085, 3.9094864380404486, 2.8858120198724135, 1.8813172381761314, 10.787691652337513, 11.79086407504297, 12.670981345897653, 13.587710881206181, 14.584073500439164, 14.990427597251127, 14.035594347338135, 13.062236505174655, 12.022687126593478, 10.99532636418487, 9.931145279075668, 8.895084017854053, 7.8996614138075065, 6.972460500753632, 5.915016580488221, 4.958511040216258, 3.950152377273592, 2.985890327656381, 2.0038470829218022, 0.9452135292375141, 11.833854781729851, 12.809845028672253, 13.615298125093918, 14.515245070416015, 15.292056781725417, 14.262282381527314, 13.209317682528852, 12.162538645671058, 11.169679908845424, 10.22463061707248, 9.176991377544283, 8.137305828711058, 7.19213711413109, 6.160426665860869, 5.201329514273693, 4.161606955510113, 3.127320083094624, 2.1000273557574465, 1.032504026460771, 0.0, 12.868989432345547, 13.759270666371188, 14.584624363353347, 15.517893636956343, 16.02832190849132, 15.04364506464147, 13.999319383205114, 13.040135151987897, 12.067741260607809, 11.087323824564361, 10.013251071578871, 8.969318108754997, 7.999560338603733, 7.067966230346844, 6.095363227168912, 5.0299657105390825, 4.084755476625622, 3.0280721399824113, 2.0300491929972697, 0.9764495868106385, 13.820623203515066, 14.786425913076117, 15.656053735387239, 16.572885731091848, 16.764166016171398, 15.780350428107402, 14.813521741523473, 13.844379878170663, 12.82859651220279, 11.804644586365532, 10.86187381829774, 9.882882857368632, 8.934608650581168, 8.090915086381363, 7.036059621043956, 6.002008794373938, 4.961905924154713, 3.9530178825880986, 2.892059154503055, 1.9055041654068496, 14.779117566105867, 15.835053823922431, 16.702319658736076, 17.595761829715894, 17.720819609316603, 16.647135309613628, 15.68129273606733, 14.71180148613944, 13.713976430591556, 12.679559907975685, 11.700560656850133, 10.774528929949804, 9.754746256793862, 8.810930552125836, 7.871145424264397, 6.871559958334096, 5.8618654877577985, 4.882120788722276, 3.8472547519652958, 2.970037302704753, 15.706803199740044, 16.660171496572726, 17.670267253920198, 18.399873219291962, 18.67057428754162, 17.596279887936298, 16.638965276756505, 15.677061582564017, 14.727231721361695, 13.74366565145837, 12.737400987185602, 11.73306980000794, 10.802148540880179, 9.795166231335257, 8.843367579327033, 7.846759195504711, 6.833142332042182, 5.816197182854776, 4.86500484770357, 4.031684165926441], [15.938959460913525, 16.75516399533675, 17.793231038287537, 18.63955079835375, 18.39736450972225, 17.425125542088065, 16.483505018394066, 15.466436469318833, 14.551444748595962, 13.617958052677071, 12.57489510490514, 11.531294440734165, 10.601314755513119, 9.59085319587112, 8.647496975220886, 7.689224148305765, 6.7391559589695, 5.809951786098129, 4.791483414309721, 3.8335434688516146, 14.867273703560501, 15.812293661658444, 16.767619037104446, 17.667069609211467, 17.77727839167524, 16.704440151846345, 15.692006715604556, 14.657499069839082, 13.712197847494856, 12.751632519715733, 11.819202938674605, 10.886384804861345, 9.876838497429159, 8.830063690696171, 7.869113501394566, 6.856515225978364, 5.84097590535853, 4.968250191332496, 3.944515731278602, 2.8777867379152764, 13.861491916343855, 14.807219922170805, 15.701303112335793, 16.639247952529175, 16.877901830198454, 15.89624470411866, 14.872793045521192, 13.897364554294839, 12.913137471227145, 11.915211980450618, 10.980843670999736, 9.920977190218245, 8.889278759802671, 7.845102219635742, 6.852973751273133, 5.9171166375431845, 4.869702280715847, 3.9753947846913897, 2.9755515934915016, 1.9784032511125924, 12.89347260874877, 13.862555943899881, 14.691377724468593, 15.62462912932222, 16.027318921600514, 15.034145789385777, 14.0772546764461, 13.04822030080733, 12.009927614211941, 11.051746554080989, 10.007988975619275, 8.958830653342952, 7.910014501063846, 6.863346541295286, 5.789159561353426, 4.863116565386082, 3.9324311858394765, 2.940943121194864, 2.013570963304278, 1.0349101814820882, 11.962036926824663, 12.932289948974452, 13.659688413339659, 14.67709370048199, 15.522055325128036, 15.97945383467435, 14.908526121080085, 13.97895786229597, 12.96829138495511, 11.915341999401969, 10.882763915314028, 9.825606371008156, 8.798208740762703, 7.76753982885778, 6.8014762859068405, 5.819750265472655, 4.869926909594979, 3.9849954837766193, 2.9489472845823665, 2.018202965128501, 10.977688172953286, 11.989081790779727, 12.71994012155957, 13.67583376187166, 14.582649134060983, 15.587956584601354, 15.541657809142416, 14.565785676389885, 13.59919785362144, 12.656470904719017, 11.694063990094444, 10.759165956449797, 9.690585396649883, 8.678005792822752, 7.728913153874495, 6.859530308684361, 5.855645800430252, 4.855221031898531, 3.91178232307879, 3.015645522805901, 10.022515892011475, 10.92989105197534, 11.72474037518934, 12.699466125788458, 13.637909603483905, 14.643127420882518, 15.566194008007606, 15.538787220288864, 14.5437489702084, 13.58285390915346, 12.617450150993573, 11.684283387876949, 10.618369317472652, 9.673287886871123, 8.722782467125343, 7.81385626524834, 6.823814759519815, 5.780239836778215, 4.900773749874894, 4.004084141027087, 9.037961677992774, 9.973253066208231, 10.77436583196929, 11.718511363136884, 12.687137611283651, 13.627577014244485, 14.563667618180476, 15.539751607367586, 15.465154355988307, 14.524009396548486, 13.517122898351413, 12.54034922002043, 11.569741567787105, 10.609885837542402, 9.648871877297482, 8.758578009660003, 7.725594071428768, 6.723257367620413, 5.908314289916191, 5.02215402571569, 8.05931094409109, 9.002573796217206, 9.844321653819776, 10.733619663613679, 11.682647121852373, 12.694978149496816, 13.671485356475484, 14.641730477531112, 15.543470712547359, 15.355945902178785, 14.400817336311182, 13.465326484272675, 12.531306861875251, 11.566822732554737, 10.572447258054643, 9.613235430827775, 8.659784548488872, 7.690488895277719, 6.867005657412634, 6.03346626035084, 6.990346246570899, 7.939529490621446, 8.831359371419085, 9.778537847859916, 10.66574696197243, 11.651161394488815, 12.699378321037539, 13.646924868786229, 14.560173858162814, 15.502239561702865, 15.33401895247583, 14.489525928267453, 13.527918095606102, 12.551795619176417, 11.55835975909005, 10.570179662195116, 9.610302953264567, 8.65736913203268, 7.929521073618769, 7.026111904137403, 6.04620924821085, 7.066342504597565, 7.758564863429119, 8.805864941646622, 9.73045641608745, 10.664060394984784, 11.634944436313113, 12.602810189387073, 13.599318964759812, 14.533761112009598, 15.431738862112228, 15.43157239317944, 14.446380231503689, 13.480615938519701, 12.541243573328176, 11.54692798806186, 10.559448116383718, 9.668295923192417, 8.926349772760805, 7.9533713428645, 5.0901584790302215, 5.992477314686737, 6.830848360271627, 7.757702091137194, 8.76270865087521, 9.736561942579545, 10.665696789924212, 11.680039406899747, 12.638941928079795, 13.577303125799762, 14.485788789658367, 15.366779463025143, 15.444087363386133, 14.45250342018238, 13.528880598604488, 12.485232435553073, 11.553317917296765, 10.676903956067031, 9.839212143424913, 8.912684564913542, 4.096002251564943, 5.0663171179286, 5.84342078840998, 6.776459641512971, 7.8189603938684895, 8.729513422695083, 9.665834947112286, 10.625383541633024, 11.581775067616983, 12.542684349063158, 13.495230436066553, 14.430700565922164, 15.374967703336273, 15.417095830423886, 14.455618420585104, 13.546644206864938, 12.588625333626208, 11.663517928526147, 10.87203583159334, 9.93983815700168, 3.043800256534583, 4.073601631971307, 4.89085005946968, 5.801033124030133, 6.7958558654131425, 7.79107674456203, 8.727684052216045, 9.670750149280758, 10.66314379704953, 11.696678653348854, 12.626529666565954, 13.653492381504694, 14.705284230747756, 15.7431470748956, 15.451729303206566, 14.507161624562482, 13.541499072363596, 12.648738600928144, 11.832755491242537, 10.987672194169415, 2.0899743693169786, 3.0187096308722854, 3.878748767136703, 4.841242477944341, 5.837605097177325, 6.803460221335106, 7.7582934712480975, 8.731651313411579, 9.771200691992755, 10.798561454401362, 11.862742539510563, 12.898803800732178, 13.81589629562181, 14.743097208675685, 15.77186998784648, 15.470918028739947, 14.605298984776065, 13.672581687664364, 12.802440897067504, 11.923775903108032, 1.0438112399246404, 1.96356406081987, 2.934431987940437, 3.913708288734509, 4.873947895280506, 5.839652170680726, 6.892616869679188, 7.939395906536983, 8.915747947033573, 9.841451700921153, 10.88909094044935, 11.928776489282575, 12.873945203862544, 13.905655652132765, 14.830123009939932, 15.869845568703512, 15.619870617712145, 14.742988550352305, 13.773783953528534, 12.868989432345547, 0.0, 1.014138423120934, 1.9651057496810083, 2.911059722194181, 3.923373471240397, 4.9080503150902475, 5.952375996526604, 6.91156022774382, 7.883954119123909, 8.864371555167356, 9.938444308152846, 10.98237727097672, 11.952135041127985, 12.883729149384873, 13.856332152562805, 14.921729669192635, 15.866939903106095, 15.671033334577269, 14.771329120065033, 13.834262170025164, 0.9516337711695189, 1.9252206717681257, 2.8645058659809663, 3.7921106879997226, 4.774806350504038, 5.758621938568034, 6.725450625151963, 7.694592488504772, 8.710375854472645, 9.734327780309902, 10.677098548377694, 11.656089509306803, 12.604363716094266, 13.590000990772129, 14.644856456109537, 15.678907282779555, 16.71901015299878, 16.73349415743456, 15.749871737717582, 14.763316748621376, 1.921585609710908, 2.9738485826144387, 3.9107717893298033, 4.814986786623768, 5.759794596362729, 6.75710333503902, 7.722945908585318, 8.69243715851321, 9.690262214061093, 10.660932133155457, 11.63993138428101, 12.565963111181338, 13.58574578433728, 14.529561489005307, 15.469346616866744, 16.468932082797046, 17.478626553373346, 17.737202031709042, 16.705067335179823, 15.82784988591928, 2.849271243345084, 3.8026395401777675, 4.81273529752524, 5.794852904496581, 6.7314593369884435, 7.706247913361691, 8.675893435571233, 9.657697254937787, 10.652667680326095, 11.68231376666828, 12.687656496714428, 13.568650489045481, 14.499571748173242, 15.525837911759137, 16.44156877192938, 17.445118180027077, 18.458735043489604, 18.674009766069304, 17.7228174309181, 16.889496749140967], [16.820564105630222, 16.20345542761796, 16.793646266664286, 17.625412375232813, 17.472024064789068, 16.49978509715488, 15.55816457346088, 14.541096024385649, 13.626104303662778, 12.692617607743887, 11.649554659971956, 10.60595399580098, 9.675974310579935, 8.665512750937935, 7.722156530287702, 6.830406003265926, 5.931347120392607, 5.09076332136536, 4.072294949576952, 4.847681891972549, 15.748878348277199, 15.260585093939651, 15.753480613983509, 16.65293118609053, 17.500133841262002, 17.461840774018082, 16.449407337776293, 15.414899692010817, 14.469598469666591, 13.509033141887468, 12.57660356084634, 11.64378542703308, 10.670331376181556, 9.66270405693571, 8.769812071229143, 7.836509375938652, 6.855114328479464, 5.98238861445343, 4.958654154399536, 3.8919251610362102, 14.743096561060552, 14.255511354452013, 14.687164689214857, 15.625109529408238, 16.53034558604171, 16.910383127239587, 15.886931468642121, 14.911502977415768, 13.927275894348075, 12.929350403571547, 11.994982094120667, 10.935115613339176, 9.903417182923604, 8.859240642756674, 7.867112174394067, 6.9312550606641175, 5.883840703836781, 4.989533207812324, 3.9896900166124354, 2.9925416742335265, 13.775077253465467, 13.19271000961901, 13.677239301347658, 14.610490706201285, 15.468772431758703, 16.04828421250671, 15.091393099567034, 14.062358723928263, 13.024066037332874, 12.065884977201922, 11.022127398740206, 9.972969076463883, 8.924152924184778, 7.877484964416219, 6.8032979844743595, 5.8772549885070156, 4.94656960896041, 3.9550815443157976, 3.0277093864252125, 2.0490486046030223, 12.84364157154136, 12.181718684782341, 12.645549990218724, 13.662955277361055, 14.507916902007103, 15.562895137868635, 15.922664544201021, 14.993096285416906, 13.982429808076047, 12.929480422522905, 11.896902338434964, 10.839744794129093, 9.812347163883638, 8.781678251978715, 7.815614709027774, 6.833888688593589, 5.864258009379084, 4.9173919691236385, 3.8813437699293853, 2.95059945047552, 11.859292817669983, 11.178271122679865, 11.705801698438636, 12.661695338750725, 13.56851071094005, 14.573818161480421, 15.508324045823011, 15.57992409951082, 14.613336276742375, 13.670609327839951, 12.708202413215378, 11.773304379570732, 10.704723819770818, 9.692144215943687, 8.743051576995429, 7.791926794031379, 6.78804228577727, 5.7876175172455495, 4.844178808425808, 3.94804200815292, 10.904120536728172, 10.119080383875477, 10.710601952068405, 11.685327702667523, 12.623771180362972, 13.628988997761585, 14.552055584886674, 15.518914185752456, 15.557887393329334, 14.596992332274395, 13.615864452703748, 12.682697689587124, 11.616783619182828, 10.671702188581298, 9.711467293697407, 8.746252750595358, 7.756211244866833, 6.712636322125233, 5.833170235221912, 4.936480626374106, 9.919566322709471, 9.16244239810837, 9.760227408848355, 10.70437294001595, 11.672999188162718, 12.613438591123552, 13.549529195059543, 14.525613184246653, 15.53937555510623, 15.51269422312055, 14.505807724923477, 13.529034046592493, 12.558426394359168, 11.598570664114465, 10.637556703869546, 9.690974495007023, 8.657990556775786, 7.655653852967431, 6.84071077526321, 5.925229560565752, 8.940915588807787, 8.191763128117344, 8.830183230698841, 9.719481240492746, 10.66850869873144, 11.680839726375883, 12.657346933354551, 13.62759205441018, 14.529332289426426, 15.516306926775856, 15.379782676992107, 14.4442918249536, 13.510272202556177, 12.53304134149686, 11.504843743401663, 10.545631916174795, 9.592181033835892, 8.622885380624737, 7.799402142759653, 6.923747494376482, 7.871950891287597, 7.1287188225215825, 7.81722094829815, 8.764399424738983, 9.651608538851496, 10.637022971367882, 11.685239897916606, 12.632786445665296, 13.546035435041881, 14.488101138581932, 15.440506199162078, 15.468491268948378, 14.460314580953122, 13.484192104523437, 12.49075624443707, 11.502576147542136, 10.542699438611585, 9.5897656173797, 8.861917558965787, 7.916393138163045, 6.9278138929275475, 6.1161479528627, 6.744426440308185, 7.79172651852569, 8.716317992966516, 9.64992197186385, 10.62080601319218, 11.58867176626614, 12.585180541638879, 13.519622688888663, 14.417600438991293, 15.341451852636496, 15.378776716850709, 14.413012423866721, 13.473640058675196, 12.47932447340888, 11.491844601730737, 10.600692408539436, 9.858746258107823, 8.843652576890142, 5.9717631237469195, 5.042282762951872, 5.816709937150693, 6.743563668016261, 7.748570227754277, 8.722423519458612, 9.651558366803277, 10.665900983778812, 11.62480350495886, 12.563164702678828, 13.471650366537432, 14.352641039904208, 15.32777600718579, 15.3848999055294, 14.461277083951506, 13.417628920900091, 12.485714402643783, 11.60930044141405, 10.729493377450554, 9.802965798939184, 4.977606896281641, 4.116122566193734, 4.829282365289046, 5.762321218392037, 6.804821970747556, 7.715374999574149, 8.651696523991351, 9.61124511851209, 10.567636644496048, 11.528545925942224, 12.481092012945618, 13.41656214280123, 14.360829280215338, 15.384949703946887, 15.388014905932122, 14.479040692211957, 13.521021818973226, 12.595914413873166, 11.762317065618982, 10.83011939102732, 3.925404901251281, 3.0594632088503735, 3.8767116363487464, 4.786894700909199, 5.781717442292209, 6.776938321441097, 7.713545629095111, 8.656611726159825, 9.649005373928597, 10.682540230227922, 11.612391243445021, 12.639353958383762, 13.691145807626823, 14.729008651774667, 15.699210747092588, 15.439558109909498, 14.473895557710613, 13.581135086275163, 12.72303672526818, 11.877953428195056, 2.9715790140336766, 2.004571207751351, 2.864610344015769, 3.8271040548234074, 4.823466674056391, 5.789321798214172, 6.744155048127164, 7.717512890290645, 8.757062268871822, 9.78442303128043, 10.84860411638963, 11.884665377611245, 12.801757872500877, 13.728958785554752, 14.757731564725548, 15.71423710499751, 15.537695470123081, 14.604978173011382, 13.692722131093147, 12.814057137133673, 1.9254158846413383, 0.9494256376989358, 1.9202935648195032, 2.899569865613575, 3.859809472159572, 4.825513747559791, 5.878478446558253, 6.925257483416048, 7.901609523912639, 8.82731327780022, 9.874952517328417, 10.914638066161642, 11.85980678074161, 12.891517229011832, 13.815984586818999, 14.85570714558258, 15.821240771877088, 15.675385035699323, 14.664065187554177, 13.759270666371187, 1.014138423120934, 0.0, 0.9509673265600742, 1.8969212990732474, 2.9092350481194633, 3.8939118919693136, 4.9382375734056705, 5.897421804622886, 6.869815696002975, 7.850233132046423, 8.924305885031913, 9.968238847855787, 10.937996618007052, 11.86959072626394, 12.842193729441872, 13.907591246071702, 14.852801479985162, 15.909484816628373, 15.661610354090676, 14.715866814741862, 1.965772194290453, 1.0271552467049296, 1.9664404409177703, 2.8940452629365265, 3.876740925440842, 4.83328149363485, 5.800110180218779, 6.769252043571588, 7.785035409539461, 8.808987335376719, 9.75175810344451, 10.730749064373619, 11.679023271161082, 12.664660545838945, 13.719516011176353, 14.753566837846371, 15.793669708065597, 16.80255774963221, 16.63147638243428, 15.644921393338073, 2.935724032831842, 2.0757831575512427, 3.012706364266607, 3.916921361560572, 4.861729171299533, 5.8317628901058365, 6.797605463652134, 7.767096713580026, 8.764921769127909, 9.735591688222273, 10.714590939347826, 11.640622666248154, 12.660405339404097, 13.604221044072123, 14.54400617193356, 15.54359163786386, 16.553286108440158, 17.53303080747568, 17.58667197989652, 16.709454530635977, 3.8634096664660182, 3.045504424791738, 4.0556001821392105, 4.936034759456742, 5.872641191948604, 6.780907468428507, 7.750552990638048, 8.732356810004603, 9.727327235392911, 10.756973321735096, 11.762316051781244, 12.643310044112297, 13.574231303240058, 14.600497466825953, 15.516228326996195, 16.519777735093893, 17.53339459855642, 17.73304832609686, 17.216208346746868, 17.771101393857666], [17.577453484171034, 16.652014670768, 15.842678940104213, 16.67444504867274, 16.521056738228992, 15.548817770594809, 14.607197246900808, 13.590128697825577, 12.675136977102706, 11.741650281183812, 10.698587333411881, 9.654986669240905, 8.72500698401986, 7.714545424377861, 6.771189203727627, 5.935394934382049, 5.036336051508729, 4.221663651336631, 5.023262276137027, 5.798649218532622, 16.50576772681801, 15.709144337089693, 14.802513287423437, 15.701963859530457, 16.54916651470193, 16.510873447458007, 15.498440011216218, 14.463932365450741, 13.518631143106516, 12.558065815327392, 11.625636234286265, 10.692818100473005, 9.71936404962148, 8.711736730375634, 7.818844744669068, 6.941498307054775, 6.073035862337082, 5.279321633437042, 5.9096214809596095, 4.842892487596284, 15.499985939601364, 14.704070597602055, 13.736197362654785, 14.674142202848167, 15.579378259481638, 16.50935479251223, 16.454178527322423, 15.47875003609607, 14.50053976581507, 13.575872040272234, 12.652269957093832, 11.658225715116105, 10.746282762426151, 9.696698201436062, 8.818079500954141, 7.880896895489954, 6.834808030396855, 5.940500534372398, 4.94065734317251, 3.9435090007936004, 14.531966632006279, 13.641269252769051, 12.726271974787585, 13.659523379641211, 14.517805105198628, 15.510978237413365, 16.042360426127104, 15.013326050488335, 13.975033363892946, 13.016852303761993, 11.97309472530028, 10.923936403023957, 9.875120250744851, 8.828452290976292, 7.754265311034433, 6.828222315067089, 5.897536935520484, 4.906048870875871, 3.978676712985286, 3.0000159311630963, 13.600530950082172, 12.630277927932383, 11.69458266365865, 12.711987950800982, 13.556949575447028, 14.61192781130856, 15.510270128355948, 15.944063611976977, 14.933397134636119, 13.880447749082977, 12.847869664995036, 11.790712120689165, 10.763314490443712, 9.732645578538788, 8.766582035587849, 7.784856015153663, 6.815225335939157, 5.868359295683712, 4.832311096489459, 3.901566777035594, 12.684646514652142, 11.73685867423113, 10.754834371878562, 11.710728012190652, 12.617543384379974, 13.622850834920346, 14.557356719262936, 15.533228852015467, 15.564303603302449, 14.621576654400025, 13.659169739775452, 12.724271706130805, 11.655691146330891, 10.64311154250376, 9.694018903555502, 8.742894120591453, 7.739009612337344, 6.738584843805623, 5.795146134985882, 4.899009334712994, 11.72947423371033, 10.7487648701024, 9.759634625508331, 10.73436037610745, 11.672803853802897, 12.67802167120151, 13.601088258326598, 14.56794685919238, 15.562985109272844, 15.547959658834468, 14.566831779263822, 13.633665016147198, 12.567750945742901, 11.622669515141371, 10.66243462025748, 9.697220077155432, 8.707178571426907, 7.6636036486853065, 6.784137561781986, 5.887447952934179, 10.74492001969163, 9.792126884335293, 8.809260082288281, 9.753405613455875, 10.722031861602643, 11.662471264563477, 12.598561868499468, 13.574645857686578, 14.588408228546154, 15.505362246393297, 15.45677505148355, 14.480001373152566, 13.509393720919242, 12.549537990674539, 11.58852403042962, 10.641941821567094, 9.60895788333586, 8.606621179527504, 7.791678101823283, 6.8232491774005295, 9.766269285789946, 8.857239829555642, 7.879215904138768, 8.76851391393267, 9.717541372171365, 10.729872399815807, 11.706379606794476, 12.676624727850104, 13.57836496286635, 14.565339600215781, 15.422740488766653, 15.395259151513672, 14.461239529116249, 13.484008668056932, 12.455811069961735, 11.496599242734867, 10.543148360395964, 9.57385270718481, 8.750369469319727, 7.7491011913586405, 8.697304588269755, 7.8386684870577765, 6.8662536217380765, 7.813432098178907, 8.700641212291421, 9.686055644807807, 10.73427257135653, 11.68181911910522, 12.595068108481806, 13.537133812021857, 14.489538872602004, 15.397956178126622, 15.411281907513194, 14.435159431083509, 13.441723570997143, 12.453543474102208, 11.493666765171659, 10.540732943939773, 9.72692859307114, 8.741746835145204, 7.753167589909706, 6.826097617398894, 5.793459113748111, 6.840759191965614, 7.765350666406441, 8.698954645303775, 9.669838686632104, 10.637704439706065, 11.634213215078804, 12.56865536232859, 13.46663311243122, 14.390484526076422, 15.374515812508161, 15.363979750426793, 14.424607385235268, 13.430291799968952, 12.44281192829081, 11.55165973509951, 10.723757292213175, 9.6690062738723, 6.797116820729078, 5.831471843510898, 4.865742610590619, 5.792596341456186, 6.797602901194201, 7.771456192898537, 8.700591040243202, 9.714933657218737, 10.673836178398787, 11.612197376118754, 12.520683039977358, 13.401673713344135, 14.376808680625716, 15.39857478762832, 15.41224441051158, 14.368596247460165, 13.436681729203857, 12.560267767974123, 11.554847074432713, 10.628319495921343, 5.875626513116418, 4.905311646752761, 3.8783150387289718, 4.8113538918319625, 5.853854644187481, 6.764407673014074, 7.700729197431277, 8.660277791952016, 9.616669317935974, 10.57757859938215, 11.530124686385545, 12.465594816241156, 13.409861953655264, 14.433982377386814, 15.459722381990563, 15.43000801877203, 14.4719891455333, 13.54688174043324, 12.58767076260114, 11.65547308800948, 4.8763722278113555, 3.871914899404531, 2.925744309788672, 3.835927374349125, 4.830750115732134, 5.825970994881022, 6.762578302535037, 7.70564439959975, 8.698038047368522, 9.731572903667846, 10.661423916884946, 11.688386631823686, 12.740178481066748, 13.778041325214591, 14.748243420532512, 15.692811099176598, 15.424862884270688, 14.532102412835236, 13.548390422250339, 12.703307125177215, 3.9225463405937506, 2.9550222608769836, 1.9136430174556947, 2.8761367282633334, 3.872499347496317, 4.838354471654098, 5.793187721567089, 6.7665455637305705, 7.806094942311747, 8.833455704720354, 9.897636789829555, 10.93369805105117, 11.850790545940802, 12.777991458994677, 13.806764238165472, 14.763269778437435, 15.771628441380102, 15.500119072809884, 14.518075828075306, 13.639410834115832, 2.8763832112014125, 1.90039296425901, 0.9693262382594289, 1.9486025390535011, 2.9088421455994977, 3.874546420999717, 4.927511119998179, 5.974290156855974, 6.950642197352565, 7.876345951240147, 8.923985190768343, 9.963670739601568, 10.908839454181535, 11.940549902451757, 12.865017260258924, 13.904739819022504, 14.870273445317013, 15.886562274293262, 15.489418884536336, 14.584624363353345, 1.9651057496810083, 0.9509673265600742, 0.0, 0.945953972513173, 1.9582677215593889, 2.942944565409239, 3.987270246845596, 4.946454478062812, 5.918848369442901, 6.8992658054863485, 7.9733385584718395, 9.017271521295712, 9.987029291446976, 10.918623399703865, 11.891226402881797, 12.956623919511626, 13.901834153425087, 14.958517490068298, 15.95970497460967, 15.472756193282674, 2.916739520850527, 1.9781225732650038, 1.0714293720338925, 1.9990341940526486, 2.9817298565569637, 3.8823141670747754, 4.849142853658704, 5.8182847170115135, 6.834068082979387, 7.858020008816645, 8.800790776884437, 9.779781737813545, 10.728055944601008, 11.713693219278872, 12.76854868461628, 13.802599511286298, 14.842702381505521, 15.851590423072135, 16.91254915115718, 16.401810771878885, 3.886691359391916, 3.026750484111317, 2.1176952953827293, 3.0219102926766945, 3.9667181024156553, 4.880795563545762, 5.846638137092061, 6.816129387019952, 7.813954442567836, 8.7846243616622, 9.763623612787752, 10.68965533968808, 11.709438012844023, 12.65325371751205, 13.593038845373487, 14.592624311303787, 15.602318781880085, 16.582063480915608, 17.616929517672588, 17.46634390917679, 4.814376993026092, 3.9964717513518124, 3.178567379183803, 4.041023690572865, 4.977630123064727, 5.829940141868432, 6.7995856640779735, 7.7813894834445305, 8.776359908832838, 9.806005995175022, 10.81134872522117, 11.692342717552226, 12.623263976679986, 13.649530140265881, 14.565261000436122, 15.56881040853382, 16.582427271996348, 16.782080999536788, 17.664767589896908, 18.52799077239848], [18.49144792424649, 17.56600911084346, 16.756673380179674, 15.806811818315463, 15.57510276571582, 14.602863798081636, 13.661243274387635, 12.644174725312403, 11.729183004589533, 10.79569630867064, 9.75263336089871, 8.709032696727734, 7.779053011506687, 6.768591451864688, 5.825235231214454, 4.991352834464906, 4.092293951591587, 5.0214981244629575, 5.967021813239125, 6.744603191045796, 17.419762166893467, 16.623138777165153, 15.716507727498897, 14.834330629173179, 15.603212542188757, 15.564919474944835, 14.552486038703044, 13.51797839293757, 12.572677170593344, 11.61211184281422, 10.679682261773094, 9.746864127959833, 8.773410077108307, 7.7657827578624605, 6.872890772155895, 5.997456207137632, 5.128993762419939, 6.079156106563368, 6.855575453472783, 5.788846460109458, 16.413980379676822, 15.618065037677514, 14.650191802730244, 13.806508972490889, 14.633424286968467, 15.563400819999059, 15.508224554809251, 14.532796063582898, 13.554585793301898, 12.629918067759064, 11.706315984580662, 10.712271742602933, 9.800328789912978, 8.750744228922889, 7.897974051072021, 6.9368547955728115, 6.100267387062622, 6.886454506885571, 5.886611315685683, 4.889462973306774, 15.445961072081738, 14.55526369284451, 13.640266414863044, 12.791890149283933, 13.571851132685456, 14.565024264900194, 15.52191537783987, 15.581180758617178, 14.566010790730047, 13.607829730599095, 12.72357660175455, 11.674418279478227, 10.779167867031905, 9.732499907263346, 8.700219283547607, 7.7741762875802625, 6.843490908033657, 5.8520028433890445, 4.924630685498459, 3.9459699036762697, 14.514525390157631, 13.544272368007842, 12.60857710373411, 11.844354720443704, 12.610995602933857, 13.665973838795388, 14.564316155842777, 15.493884414626892, 15.575373486272357, 14.622324340633583, 13.65314243083136, 12.627221393763579, 11.709268462956885, 10.678599551051962, 9.712536008101022, 8.730809987666836, 7.761179308452331, 6.814313268196885, 5.778265069002632, 4.847520749548767, 13.619607639338973, 12.650853114306589, 11.668828811954022, 10.843094781833374, 11.671589411866803, 12.676896862407174, 13.611402746749764, 14.587274879502296, 15.55386270227074, 15.556490783187947, 14.594083868563374, 13.659185834918727, 12.601645118844065, 11.589065515016934, 10.639972876068676, 9.688848093104625, 8.684963584850516, 7.684538816318796, 6.741100107499055, 5.844963307226167, 12.664435358397162, 11.66275931017786, 10.67362906558379, 9.85408962851705, 10.726849881289725, 11.732067698688338, 12.655134285813427, 13.621992886679209, 14.617031136759671, 15.544375642059842, 15.512785751776994, 14.57961898866037, 13.513704918256073, 12.568623487654543, 11.608388592770652, 10.643174049668604, 9.65313254394008, 8.60955762119848, 7.730091534295159, 6.833401925447353, 11.679881144378461, 10.706121324410752, 9.72325452236374, 8.807451640942704, 9.776077889089471, 10.716517292050305, 11.652607895986296, 12.628691885173406, 13.642454256032982, 14.559408273880125, 15.455888207435727, 15.425955345665738, 14.455347693432413, 13.49549196318771, 12.534478002942791, 11.587895794080268, 10.554911855849033, 9.552575152040678, 8.737632074336457, 7.7582103020873605, 10.701230410476777, 9.771234269631101, 8.793210344214227, 7.822559941419499, 8.771587399658193, 9.783918427302636, 10.760425634281304, 11.730670755336932, 12.63241099035318, 13.61938562770261, 14.47678651625348, 15.412277368291987, 15.407193501629422, 14.429962640570105, 13.401765042474908, 12.44255321524804, 11.489102332909138, 10.519806679697984, 9.6963234418329, 8.684062316045472, 9.632265712956587, 8.773629611744608, 7.8012147464249075, 6.867478125665736, 7.754687239778249, 8.740101672294635, 9.78831859884336, 10.73586514659205, 11.649114135968635, 12.591179839508685, 13.543584900088831, 14.452002205613448, 15.444325342094823, 15.381113403596682, 14.387677543510316, 13.399497446615381, 12.439620737684832, 11.486686916452946, 10.66188971775797, 9.676707959832035, 8.688128714596537, 7.7610587420857255, 6.728420238434943, 5.894805219452443, 6.819396693893269, 7.753000672790604, 8.723884714118933, 9.691750467192893, 10.688259242565632, 11.622701389815417, 12.520679139918046, 13.444530553563249, 14.428561839994988, 15.394326132978975, 15.370561357748441, 14.376245772482125, 13.388765900803984, 12.497613707612683, 11.658718416900006, 10.603967398559131, 7.732077945415909, 6.766432968197729, 5.800703735277451, 4.846642368943014, 5.85164892868103, 6.825502220385365, 7.75463706773003, 8.768979684705565, 9.727882205885614, 10.66624340360558, 11.574729067464185, 12.455719740830961, 13.430854708112543, 14.452620815115147, 15.394246316049333, 15.314550219973338, 14.38263570171703, 13.506221740487296, 12.489808199119544, 11.563280620608174, 6.810587637803249, 5.840272771439592, 4.813276163415804, 3.86539991931879, 4.90790067167431, 5.8184537005009025, 6.754775224918104, 7.714323819438843, 8.670715345422801, 9.631624626868977, 10.584170713872371, 11.519640843727982, 12.463907981142091, 13.48802840487364, 14.51376840947739, 15.462804134584594, 15.417943118046473, 14.492835712946412, 13.522631887287972, 12.59043421269631, 5.822326200324528, 4.817868871917703, 3.8716982823018444, 2.8899734018359524, 3.884796143218962, 4.88001702236785, 5.816624330021864, 6.759690427086578, 7.7520840748553494, 8.785618931154675, 9.715469944371774, 10.742432659310515, 11.794224508553576, 12.832087352701418, 13.802289448019339, 14.746857126663425, 15.71251967886231, 15.47805638534841, 14.483351546937168, 13.638268249864046, 4.8685003131069235, 3.900976233390156, 2.8595969899688676, 1.9301827557501605, 2.926545374983144, 3.8924004991409253, 4.847233749053917, 5.820591591217398, 6.860140969798575, 7.887501732207183, 8.951682817316383, 9.987744078537999, 10.904836573427628, 11.832037486481504, 12.860810265652301, 13.817315805924263, 14.82567446886693, 15.789936518484142, 15.453036952762135, 14.574371958802663, 3.8223371837145854, 2.846346936772183, 1.915280210772602, 1.002648566540328, 1.9628881730863248, 2.928592448486544, 3.981557147485006, 5.028336184342801, 6.004688224839392, 6.930391978726974, 7.978031218255171, 9.017716767088395, 9.962885481668362, 10.994595929938583, 11.919063287745752, 12.958785846509333, 13.924319472803841, 14.94060830178009, 16.008131631076765, 15.517893636956344, 2.9110597221941816, 1.8969212990732474, 0.945953972513173, 0.0, 1.012313749046216, 1.9969905928960663, 3.041316274332423, 4.000500505549639, 4.972894396929728, 5.953311832973176, 7.027384585958667, 8.07131754878254, 9.041075318933805, 9.972669427190693, 10.945272430368625, 12.010669946998455, 12.955880180911915, 14.012563517555126, 15.013751002096498, 16.077189482196303, 3.8626934933637003, 2.921882110367103, 1.9825969161542623, 1.0549920941355062, 2.0376877566398215, 2.9363601945616025, 3.903188881145531, 4.87233074449834, 5.888114110466214, 6.912066036303472, 7.8548368043712635, 8.833827765300372, 9.782101972087835, 10.767739246765698, 11.822594712103106, 12.856645538773124, 13.896748408992348, 14.905636450558962, 15.966595178644006, 16.953150167740212, 4.8326453319050895, 3.9705100212134163, 3.028477328447748, 2.077868192759552, 3.0226760024985126, 3.9348415910325887, 4.9006841645788874, 5.870175414506779, 6.868000470054662, 7.838670389149026, 8.817669640274579, 9.743701367174907, 10.76348404033085, 11.707299744998876, 12.647084872860313, 13.646670338790614, 14.656364809366911, 15.636109508402434, 16.670975545159415, 17.61214595635265, 5.760330965539265, 4.940231288453911, 4.079099197627063, 3.096981590655722, 4.033588023147584, 4.883986169355259, 5.8536316915648, 6.835435510931357, 7.830405936319664, 8.860052022661849, 9.865394752707997, 10.746388745039052, 11.677310004166813, 12.703576167752708, 13.619307027922948, 14.622856436020646, 15.636473299483175, 16.653418448670582, 17.604610783821787, 18.672381451586674], [18.583805847648307, 17.605049953904476, 16.567188787862452, 15.612192238346154, 14.562789016669603, 13.590550049035418, 12.648929525341417, 11.631860976266186, 10.716869255543315, 9.783382559624425, 8.740319611852494, 7.696718947681518, 6.766739262460471, 5.756277702818472, 4.812921482168238, 4.117579223628321, 5.070948325175765, 6.000152498047136, 6.945822153966072, 7.756179049374753, 17.58676397083486, 17.619265199471965, 16.71263414980571, 15.830457051479991, 14.877615946865983, 14.552605725898621, 13.54017228965683, 12.505664643891354, 11.560363421547128, 10.599798093768005, 9.667368512726878, 8.734550378913617, 7.761096328062092, 6.753469008816245, 5.860577023109679, 5.123682596301047, 6.1076481360041175, 7.0578104801475465, 7.86715131180174, 6.8004223184384145, 16.879488825588105, 16.614191459984326, 15.646318225037056, 14.8026353947977, 13.907827691645693, 14.837804224676285, 14.495910805763035, 13.520482314536682, 12.542272044255682, 11.617604318712846, 10.694002235534445, 9.699957993556717, 8.788015040866764, 7.738430479876674, 6.885660302025805, 6.063081184736227, 7.0789217606468, 7.898030365214528, 6.89818717401464, 5.901038831635731, 16.00566529442648, 15.551390115151323, 14.636392837169856, 13.788016571590745, 12.846254537362682, 13.83942766957742, 14.654225121425824, 14.568867009570962, 13.55369704168383, 12.595515981552877, 11.711262852708334, 10.66210453043201, 9.76685411798569, 8.72018615821713, 7.949474491945512, 7.118104877799038, 7.855804657079872, 6.86431659243526, 5.9369444345446745, 4.958283652722485, 15.510651812464443, 14.540398790314654, 13.604703526040922, 12.840481142750516, 11.885399007611083, 12.836632349461562, 13.68728801304567, 14.616856271829786, 14.563059737226139, 13.610010591587365, 12.640828681785145, 11.614907644717363, 10.706012350425867, 9.675343438520944, 9.000502361256427, 8.074738577885611, 8.773493057498547, 7.826627017243101, 6.790578818048848, 5.859834498594983, 14.615734061645785, 13.6469795366134, 12.664955234260834, 11.839221204140186, 10.94599281654403, 11.847555373073348, 12.734374603952658, 13.710246736705189, 14.676834559473633, 14.54417703414173, 13.581770119517158, 12.646872085872511, 11.648150292424535, 10.635570688597404, 9.92793922922408, 9.147908571978663, 9.697277333896732, 8.696852565365012, 7.753413856545271, 6.857277056272383, 13.660561780703974, 12.658885732484672, 11.669755487890603, 10.850216050823862, 10.001253285966952, 10.902726209354512, 11.77810614301632, 12.744964743882102, 13.740002993962566, 14.626010108082381, 14.575015046768225, 13.641848283651601, 12.575934213247304, 11.630852782645775, 10.92180854247493, 10.102234528542642, 10.665446292986296, 9.621871370244696, 8.742405283341375, 7.845715674493569, 12.676007566685273, 11.702247746717564, 10.719380944670553, 9.803578063249516, 9.050481293766698, 9.839489149253199, 10.77557975318919, 11.7516637423763, 12.765426113235876, 13.641042739902664, 14.533033025586628, 14.52674569896082, 13.556138046727495, 12.660522422211208, 11.847897952647068, 11.07006226460814, 11.567225604895249, 10.564888901086894, 9.749945823382673, 8.754336724394172, 11.697356832783589, 10.767360691937913, 9.78933676652104, 8.81868636372631, 8.016149646194405, 8.906890284505529, 9.864347938019424, 10.834593059075052, 11.714045456375718, 12.701020093725148, 13.55393133440438, 14.489422186442887, 14.51770334081564, 13.617459317223544, 12.873772215638443, 12.089743180730528, 12.501416081955355, 11.5321204287442, 10.708637190879116, 9.680188738352284, 10.628392135263399, 9.769756034051419, 8.79734116873172, 7.863604547972548, 6.999249486314461, 7.859481562366996, 8.892240902581479, 9.839787450330169, 10.730748601991174, 11.672814305531224, 12.620729718239732, 13.529147023764349, 14.521470160245723, 14.689003810394857, 13.867993459075032, 13.04668741209787, 13.451934486731048, 12.499000665499162, 11.658016140064783, 10.672834382138847, 9.68425513690335, 8.757185164392537, 7.724546660741755, 6.890931641759255, 6.063958940429481, 6.858236998677979, 7.827807017857053, 8.795672770931013, 9.769893708588171, 10.699846207966317, 11.597823958068947, 12.52167537171415, 13.505706658145888, 14.471470951129875, 14.889815613575632, 14.023435737964615, 14.4010796498502, 13.509927456658898, 12.654844839206818, 11.600093820865943, 8.728204367722721, 7.762559390504541, 6.796830157584263, 5.842768791249826, 5.096211175217242, 5.930738546272741, 6.83178188588093, 7.846124502856464, 8.805027024036514, 9.743388221756481, 10.651873885615085, 11.532864558981862, 12.507999526263443, 13.529765633266047, 14.471391134200234, 15.017155084934624, 15.394949450763246, 14.518535489533512, 13.485934621426356, 12.559407042914986, 7.806714060110061, 6.836399193746404, 5.809402585722616, 4.861526341625602, 4.103066391850222, 4.923690026388278, 5.831920043069004, 6.791468637589743, 7.7478601635737006, 8.708769445019877, 9.661315532023272, 10.596785661878883, 11.541052799292991, 12.56517322302454, 13.59091322762829, 14.539948952735495, 15.497967825974225, 15.505149461992628, 14.518758309594784, 13.586560635003122, 6.834639949370745, 5.8298332384208, 4.8836626488049415, 3.8860998241427644, 3.079961863394874, 3.9852533482552257, 4.893769148172764, 5.836835245237477, 6.829228893006249, 7.862763749305574, 8.792614762522675, 9.819577477461415, 10.871369326704476, 11.819773603655204, 12.789975698973125, 13.73454337761721, 14.700205929816097, 15.715458288938756, 15.47947796924398, 14.634394672170858, 5.88081406215314, 4.913289982436372, 3.8719107390150835, 2.926309178056973, 2.0781810574094233, 2.969545317291825, 3.9243785672048164, 4.897736409368298, 5.9359334487693545, 6.9632942111779625, 8.013409790881436, 9.032812751506956, 9.892522824381414, 10.81972373743529, 11.848496516606083, 12.805002056878045, 13.813360719820713, 14.777622769437924, 15.759666014172502, 15.570498381109475, 4.834650932760802, 3.858660685818399, 2.9275939598188176, 1.9987749888471407, 1.0385353823011438, 1.916278699440328, 2.96924339843879, 4.016022435296585, 4.992374475793175, 5.9180782296807575, 6.965717469208954, 8.005403018042179, 8.950571732622148, 9.98228218089237, 10.906749538699534, 11.946472097463115, 12.912005723757623, 13.928294552733872, 14.995817882030547, 16.028321908491318, 3.9233734712403967, 2.909235048119463, 1.9582677215593889, 1.012313749046216, 0.0, 0.9846768438498503, 2.029002525286207, 2.9881867565034232, 3.960580647883512, 4.940998083926959, 6.01507083691245, 7.059003799736323, 8.028761569887587, 8.960355678144476, 9.932958681322408, 10.998356197952237, 11.943566431865698, 13.000249768508908, 14.00143725305028, 15.064875733150084, 4.874269351692657, 3.90068245109405, 2.961397256881209, 2.0337924348624528, 1.0510967723581377, 1.9240464455153865, 2.890875132099315, 3.860016995452124, 4.875800361419998, 5.899752287257256, 6.842523055325048, 7.821514016254156, 8.769788223041619, 9.755425497719482, 10.81028096305689, 11.844331789726908, 12.884434659946134, 13.893322701512748, 14.954281429597792, 15.940836418693998, 5.844221190234046, 4.949310361940363, 4.007131702031926, 3.05652256634373, 2.111714756604769, 2.9225278419863727, 3.888370415532671, 4.857861665460563, 5.855686721008446, 6.82635664010281, 7.805355891228362, 8.73138761812869, 9.751170291284632, 10.694985995952658, 11.634771123814096, 12.634356589744396, 13.644051060320693, 14.623795759356216, 15.658661796113197, 16.59983220730643, 6.771906823868222, 5.919031629180858, 5.057753571211242, 4.0756359642399005, 3.1598144123109995, 3.871672420309043, 4.841317942518584, 5.823121761885141, 6.818092187273448, 7.847738273615632, 8.85308100366178, 9.734074995992835, 10.664996255120595, 11.69126241870649, 12.60699327887673, 13.610542686974428, 14.624159550436957, 15.641104699624364, 16.59229703477557, 17.660067702540456], [17.599129003798456, 16.620373110054626, 15.582511944012605, 14.627515394496305, 13.578112172819754, 12.605873205185569, 11.664252681491567, 10.647184132416335, 9.732192411693465, 8.798705715774576, 7.7556427680026445, 6.712042103831668, 5.7820624186106215, 4.771600858968622, 3.8282446383183877, 4.837567633351749, 5.889353966682112, 6.818558139553483, 7.8179105713374675, 8.628267466746147, 16.602087126985012, 17.54632386601617, 16.58998855488031, 15.599996583638589, 14.601237472220449, 13.56792888204877, 12.55549544580698, 11.520987800041503, 10.575686577697278, 9.615121249918154, 8.682691668877027, 7.749873535063767, 6.7764194842122425, 5.768792164966395, 4.875900179259829, 5.843671006024475, 6.908063508645744, 7.874142349116433, 8.739239729173134, 7.672510735809809, 15.894811981738249, 16.8405399875652, 16.56915909852449, 15.650443936688987, 14.651564855222277, 13.890307045094238, 13.511233961913184, 12.535805470686832, 11.557595200405832, 10.632927474862996, 9.709325391684594, 8.715281149706867, 7.803338197016913, 6.753753636026824, 5.900983458175954, 6.783069594459654, 7.8304839512869915, 8.770118782585921, 7.770275591386034, 6.773127249007125, 15.02098845057663, 15.990071785727741, 15.55923371065729, 14.635825113482031, 13.589991700939267, 12.891930489995373, 13.669548277575975, 13.584190165721111, 12.569020197833979, 11.610839137703026, 10.726586008858483, 9.67742768658216, 8.78217727413584, 7.73550931436728, 6.9647976480956615, 7.838093287522465, 8.767755046163362, 7.84899343628511, 6.921621278394525, 5.9429604965723355, 15.952424132500736, 15.463239663802089, 14.527544399528356, 13.688289684641802, 12.629136171187668, 11.851955505611711, 12.702611169195821, 13.632179427979937, 13.578382893376288, 12.625333747737514, 11.656151837935294, 10.630230800867512, 9.721335506576018, 8.690666594671095, 8.015825517406576, 8.794726987609039, 9.705250769918866, 8.811303861092952, 7.775255661898699, 6.844511342444834, 15.538574935133225, 14.569820410100835, 13.587796107748268, 12.711417608909304, 11.689729980120614, 10.862878529223497, 11.749697760102809, 12.72556989285534, 13.692157715623784, 13.55950019029188, 12.597093275667307, 11.66219524202266, 10.663473448574686, 9.650893844747555, 8.94326238537423, 9.86789698170209, 10.681954177746585, 9.681529409214864, 8.738090700395123, 7.841953900122234, 14.583402654191413, 13.581726605972106, 12.592596361378037, 11.734387770217124, 10.744990449543536, 9.918049365504661, 10.79342929916647, 11.760287900032253, 12.755326150112715, 13.64133326423253, 13.590338202918376, 12.657171439801752, 11.591257369397455, 10.646175938795926, 9.937131698625079, 10.82222293826607, 11.650123136836148, 10.606548214094548, 9.727082127191226, 8.83039251834342, 13.598848440172713, 12.625088620204998, 11.642221818157987, 10.726418936736952, 9.794218457343282, 8.85481230540335, 9.79090290933934, 10.76698689852645, 11.780749269386027, 12.656365896052813, 13.548356181736777, 13.542068855110971, 12.571461202877646, 11.67584557836136, 10.863221108797218, 11.790050674331567, 12.551902448745102, 11.549565744936746, 10.685929706009581, 9.677177597881611, 12.620197706271028, 11.690201565425347, 10.712177640008473, 9.741527237213747, 8.75988680977099, 7.92221344065568, 8.879671094169574, 9.849916215225202, 10.729368612525867, 11.716343249875298, 12.56925449055453, 13.504745342593036, 13.533026496965793, 12.632782473373695, 11.889095371788592, 12.809731590453955, 13.486092925805206, 12.516797272594053, 11.636848075583258, 10.603029611839723, 11.551233008750838, 10.692596907538855, 9.720182042219156, 8.786445421459984, 7.742986649891045, 6.874804718517146, 7.907564058731628, 8.855110606480318, 9.746071758141323, 10.688137461681373, 11.63605287438988, 12.544470179914498, 13.536793316395872, 13.704326966545008, 12.883316615225182, 13.766675821821298, 14.4366113305809, 13.483677509349015, 12.580857013552222, 11.595675255626286, 10.607096010390789, 9.680026037879973, 8.64738753422919, 7.813772515246691, 6.807696104006065, 5.873560154828129, 6.843130174007202, 7.810995927081161, 8.78521686473832, 9.715169364116466, 10.613147114219096, 11.536998527864299, 12.521029814296037, 13.486794107280025, 13.905138769725781, 14.743424147688042, 15.385756493700052, 14.494604300508751, 13.577685712694258, 12.522934694353383, 9.651045241210161, 8.68540026399198, 7.7196710310717, 6.765609664737262, 5.876354851953218, 4.946061702422891, 5.847105042031079, 6.861447659006613, 7.820350180186663, 8.75871137790663, 9.667197041765235, 10.548187715132011, 11.523322682413593, 12.545088789416196, 13.486714290350383, 14.530362453401798, 15.462276971658106, 15.48040139813579, 14.408775494913796, 13.482247916402425, 8.7295549335975, 7.759240067233842, 6.732243459210053, 5.784367215113039, 4.883210068586198, 3.939013182538428, 4.847243199219153, 5.806791793739892, 6.76318331972385, 7.724092601170026, 8.676638688173421, 9.612108818029032, 10.55637595544314, 11.58049637917469, 12.60623638377844, 13.555272108885644, 14.513290982124374, 15.455347484281825, 15.441599183082223, 14.509401508490562, 7.813909959442308, 6.752674111908237, 5.806503522292378, 4.808940697630201, 3.9525044035852064, 3.0005765044053754, 3.909092304322913, 4.852158401387627, 5.844552049156399, 6.878086905455724, 7.807937918672824, 8.834900633611564, 9.886692482854626, 10.835096759805353, 11.805298855123274, 12.74986653376736, 13.715529085966246, 14.730781445088905, 15.74467457614762, 15.557235545658298, 6.865490906002991, 5.897966826286223, 4.856587582864934, 3.8491500515444095, 2.9507235975997554, 1.9848684734419744, 2.939701723354966, 3.9130595655184472, 4.9512566049195055, 5.9786173673281136, 7.028732947031585, 8.048135907657105, 8.907845980531564, 9.835046893585439, 10.863819672756234, 11.820325213028196, 12.828683875970864, 13.792945925588075, 14.774989170322653, 15.833700710332, 5.819327776610653, 4.84333752966825, 3.912270803668668, 2.921615862334577, 1.9613762557885805, 0.9316018555904777, 1.98456655458894, 3.031345591446735, 4.0076976319433255, 4.933401385830908, 5.981040625359104, 7.020726174192329, 7.965894888772297, 8.997605337042518, 9.922072694849685, 10.961795253613266, 11.927328879907774, 12.943617708884023, 14.011141038180698, 15.043645064641469, 4.9080503150902475, 3.8939118919693136, 2.942944565409239, 1.9969905928960663, 0.9846768438498503, 0.0, 1.0443256814363568, 2.003509912653573, 2.9759038040336616, 3.9563212400771093, 5.0303939930626, 6.074326955886473, 7.044084726037737, 7.9756788342946265, 8.948281837472559, 10.013679354102388, 10.958889588015849, 12.01557292465906, 13.016760409200431, 14.080198889300235, 5.746357769064051, 4.772770868465445, 3.833485674252604, 2.9058808522338477, 1.9231851897295322, 0.9393696016655363, 1.906198288249465, 2.8753401516022743, 3.8911235175701475, 4.915075443407405, 5.857846211475197, 6.836837172404305, 7.785111379191767, 8.77074865386963, 9.825604119207037, 10.859654945877056, 11.89975781609628, 12.908645857662894, 13.969604585747938, 14.956159574844143, 6.7163096076054405, 5.8213987793117585, 4.879220119403321, 3.928610983715125, 2.983803173976164, 1.9378509981365226, 2.9036935716828207, 3.873184821610712, 4.8710098771585955, 5.84167979625296, 6.820679047378511, 7.7467107742788395, 8.766493447434783, 9.710309152102809, 10.650094279964247, 11.649679745894547, 12.659374216470844, 13.639118915506367, 14.673984952263348, 15.615155363456584, 7.643995241239616, 6.791120046552254, 5.880014015527716, 4.897896408556375, 3.961289976064513, 2.8869955764591926, 3.8566410986687343, 4.83844491803529, 5.833415343423598, 6.863061429765781, 7.86840415981193, 8.749398152142984, 9.680319411270744, 10.70658557485664, 11.622316435026882, 12.62586584312458, 13.639482706587108, 14.656427855774513, 15.607620190925719, 16.675390858690605], [16.618036520869406, 15.639280627125576, 14.601419461083555, 13.646422911567255, 12.597019689890704, 11.624780722256519, 10.683160198562518, 9.666091649487287, 8.751099928764416, 7.864601676743948, 6.821538728972017, 5.777938064801041, 4.847958379579994, 3.837496819937995, 4.780853040588228, 5.790176035621589, 6.841962368951952, 7.771166541823323, 8.78337749686232, 9.593734392271, 15.620994644055962, 16.56523138308712, 15.60889607195126, 14.618904100709539, 13.620144989291399, 12.598609865826567, 11.62139140677635, 10.586883761010876, 9.64158253866665, 8.681017210887527, 7.7485876298464005, 6.815769496033139, 5.842315445181615, 4.834688125935768, 5.82850858152967, 6.796279408294315, 7.860671910915584, 8.826750751386273, 9.704706654697986, 8.637977661334661, 14.868034115371929, 15.813762121198879, 16.663710811013658, 15.633219753423877, 14.578284801885394, 13.596627675805601, 12.577129922882557, 11.601701431656204, 10.623491161375204, 9.69882343583237, 8.775221352653968, 7.781177110676238, 6.869234157986287, 5.819649596996197, 6.8127669502652655, 7.735677996729494, 8.783092353556832, 9.735585708110774, 8.735742516910886, 7.738594174531977, 13.976662769140273, 14.945746104291384, 15.990051541096292, 15.553844760667864, 14.5080113481251, 13.761940991566954, 12.805049878627278, 12.650086126690484, 11.634916158803353, 10.6767350986724, 9.792481969827856, 8.743323647551533, 7.848073235105214, 6.801405275336654, 7.875592255278514, 8.790701689792305, 9.720363448433202, 8.893319117721468, 7.965946959830882, 6.987286178008692, 14.90809845106438, 15.878351473214169, 15.450788372098781, 14.606309331827635, 13.5471558183735, 12.769975152797544, 11.838112770247124, 12.76768102903124, 12.644278854345663, 11.691229708706889, 10.722047798904667, 9.696126761836885, 8.787231467545391, 7.756562555640468, 8.722626098591407, 9.704352119025593, 10.657859172188706, 9.855629542529309, 8.819581343335056, 7.888837023881191, 15.75380225181711, 15.49306438267126, 14.511040080318693, 13.629437256095137, 12.607749627306447, 11.78089817640933, 10.885199361154111, 11.861071493906643, 12.777458033709735, 12.625396151261253, 11.66298923663668, 10.728091202992033, 9.72936940954406, 8.716789805716928, 9.650062966559062, 10.613333041631487, 11.617217549885595, 10.725855090651221, 9.78241638183148, 8.886279581558592, 15.544604786460317, 14.504970578542531, 13.515840333948463, 12.652407417402957, 11.66301009672937, 10.836069012690494, 9.928930900217773, 10.895789501083556, 11.832906917122775, 12.676928581771207, 12.65623416388775, 11.723067400771125, 10.657153330366828, 9.712071899765299, 10.643932279809912, 11.567658998195466, 12.597299633845582, 11.650873895530905, 10.771407808627583, 9.874718199779776, 14.582535335633821, 13.548332592775424, 12.565465790728412, 11.649662909307377, 10.712238104529115, 9.772831952589183, 8.926404510390643, 9.902488499577753, 10.827400313362496, 11.69196121359149, 12.583951499275456, 12.607964816080344, 11.63735716384702, 10.741741539330732, 11.57002168998205, 12.535486734260964, 13.560213684938933, 12.593891426373103, 11.729127688662574, 10.720375580534604, 13.663395688924021, 12.613445537995773, 11.635421612578899, 10.664771209784172, 9.677906456956823, 8.840233087841513, 7.915266411708254, 8.885511532763882, 9.764963930064544, 10.751938567413974, 11.604849808093208, 12.540340660131715, 12.598922457935164, 11.698678434343067, 12.595895952973425, 13.555107780200293, 14.508558662539196, 13.56112295403041, 12.68004605823625, 11.646227594492716, 12.594430991403831, 11.705089622168275, 10.690842476588491, 9.70968939403041, 8.661006297076879, 7.79282436570298, 6.943159376270309, 7.890705924018998, 8.78166707568, 9.72373277922005, 10.67164819192856, 11.580065497453177, 12.572388633934551, 12.77022292751438, 13.590117196410015, 14.512052011567636, 15.480937012017257, 14.528003190785372, 13.624054996205215, 12.63887323827928, 11.650293993043782, 10.723224020532966, 9.690585516882184, 8.754828067425297, 7.725715751191899, 6.791579802013963, 5.8787254915458815, 6.846591244619841, 7.820812182276998, 8.750764681655147, 9.648742431757775, 10.572593845402977, 11.556625131834716, 12.522389424818703, 13.461761790010229, 14.456077375276545, 15.491742090109831, 15.538929981945108, 14.620883695347251, 13.566132677006376, 10.694243223863154, 9.728598246644973, 8.762869013724693, 7.799381058877068, 6.794374499139052, 5.864081349608725, 4.882700359569759, 5.8970429765452925, 6.855945497725342, 7.794306695445311, 8.702792359303913, 9.58378303267069, 10.558917999952271, 11.580684106954875, 12.522309607889062, 13.565957770940477, 14.497872289196785, 15.470777490944718, 15.451973477566789, 14.525445899055418, 9.772752916250493, 8.802438049886835, 7.7754414418630455, 6.827565197766032, 5.801229715772032, 4.857032829724262, 3.882838516757833, 4.842387111278572, 5.798778637262529, 6.759687918708706, 7.7122340057121, 8.647704135567711, 9.59197127298182, 10.616091696713369, 11.641831701317118, 12.590867426424323, 13.548886299663053, 14.490942801820504, 15.490500192580168, 15.552599491143555, 8.8571079420953, 7.79587209456123, 6.849701504945371, 5.852138680283194, 4.89776622094987, 3.934510618831436, 2.944687621861593, 3.887753718926307, 4.844312401012511, 5.877847257311836, 6.8076982705289355, 7.834660985467676, 8.886452834710738, 9.790771078368996, 10.760973173686917, 11.705540852331001, 12.671203404529887, 13.686455763652546, 14.700348894711263, 15.704843676407545, 7.909816587439348, 6.94229250772258, 5.900913264301291, 4.892348034197402, 3.895985414964419, 2.9301302908066376, 1.975297040893646, 2.9486548830571273, 3.906930923483148, 4.934291685891756, 5.9844072655952285, 7.003810226220749, 7.8635202990952076, 8.790721212149082, 9.819493991319877, 10.77599953159184, 11.784358194534507, 12.748620244151718, 13.730663488886297, 14.789375028895643, 6.863653458047009, 5.8876632111046066, 4.956596485105025, 3.965941543770934, 3.0057019372249374, 1.9759275370268345, 0.9488157100374455, 1.9955947468952404, 2.9633719505069687, 3.8890757043945507, 4.936714943922747, 5.976400492755972, 6.92156920733594, 7.953279655606162, 8.877747013413329, 9.917469572176909, 10.883003198471418, 11.899292027447666, 12.966815356744341, 13.999319383205112, 5.952375996526604, 4.9382375734056705, 3.987270246845596, 3.041316274332423, 2.029002525286207, 1.0443256814363568, 0.0, 0.959184231217216, 1.9315781225973048, 2.9119955586407524, 3.9860683116262434, 5.030001274450116, 5.99975904460138, 6.93135315285827, 7.903956156036202, 8.969353672666031, 9.914563906579492, 10.971247243222702, 11.972434727764075, 13.035873207863878, 6.711824694588904, 5.738237793990297, 4.798952599777457, 3.871347777758701, 2.888652115254386, 1.9048365271903904, 0.9380078406064619, 1.9071497039592713, 2.9229330699271445, 3.9339829604783567, 4.876753728546149, 5.855744689475257, 6.804018896262719, 7.7896561709405825, 8.844511636277991, 9.87856246294801, 10.87297994972996, 11.881867991296573, 12.942826719381618, 13.929381708477823, 7.681776533130293, 6.786865704836611, 5.844687044928175, 4.894077909239979, 3.9492700995010175, 2.9033179236613766, 1.939078098265857, 2.9085693481937485, 3.906394403741632, 4.8605873133239115, 5.839586564449463, 6.765618291349791, 7.785400964505734, 8.72921666917376, 9.669001797035197, 10.668587262965497, 11.678281733541795, 12.658026432577318, 13.692892469334298, 14.634062880527534, 8.60946216676447, 7.756586972077106, 6.845480941052571, 5.86336333408123, 4.926756901589368, 3.852462501984047, 2.896750638955033, 3.873829444618327, 4.868799870006634, 5.898445956348818, 6.887311676882882, 7.768305669213936, 8.699226928341696, 9.725493091927591, 10.641223952097832, 11.64477336019553, 12.658390223658058, 13.675335372845463, 14.626527707996669, 15.694298375761555], [15.65885228965219, 14.680096395908361, 13.64223522986634, 12.68723868035004, 11.63783545867349, 10.665596491039304, 9.723975967345304, 8.706907418270072, 7.791915697547201, 6.940531604546036, 5.990413547188057, 4.94681288301708, 4.016833197796034, 4.796681051155211, 5.740037271805445, 6.7493602668388055, 7.801146600169169, 8.73035077304054, 9.742561728079536, 10.552918623488218, 14.661810412838747, 15.606047151869907, 14.649711840734046, 13.659719869492324, 12.660960758074184, 11.639425634609353, 10.700178004634662, 9.665670358869187, 8.720369136524962, 7.849892029103567, 6.91746244806244, 5.984644314249179, 5.011190263397655, 5.793872357152984, 6.7876928127468865, 7.7554636395115315, 8.819856142132801, 9.78593498260349, 10.663890885915203, 9.597161892551878, 13.908849884154712, 14.854577889981663, 15.704526579796443, 14.674035522206662, 13.619100570668179, 12.637443444588387, 11.655916520740869, 10.680488029514516, 9.702277759233516, 8.86769825404841, 7.944096170870008, 6.950051928892278, 6.040450908290676, 6.778833828213413, 7.771951181482481, 8.694862227946711, 9.742276584774048, 10.69476993932799, 9.694926748128102, 8.697778405749194, 13.017478537923056, 13.986561873074168, 15.030867309879076, 15.658542662707237, 14.605174348451603, 13.612001216236866, 12.65511010329719, 11.728872724548795, 10.753803287419194, 9.84560991688844, 8.961356788043895, 7.912198465767572, 7.019715167029502, 7.7605895065538695, 8.834776486495729, 9.749885921009522, 10.679547679650419, 9.852503348938685, 8.925131191048099, 7.946470409225909, 13.948914219847163, 14.919167241996952, 15.854862506270685, 15.565493563044852, 14.506340049590717, 13.729159384014762, 12.79729700146434, 12.229250229987857, 11.763165982961503, 10.860104526922928, 9.890922617120706, 8.865001580052924, 8.092335286638372, 8.715746786857684, 9.681810329808624, 10.66353635024281, 11.617043403405923, 10.814813773746526, 9.778765574552272, 8.848021255098407, 14.794618020599893, 15.808458350963775, 15.470224311535912, 14.588621487312354, 13.566933858523663, 12.740082407626549, 11.844383592371328, 11.198226945641293, 11.820920755418907, 11.794270969477292, 10.83186405485272, 9.896966021208073, 9.041335104436554, 9.675974036934145, 10.609247197776277, 11.572517272848701, 12.57640178110281, 11.685039321868437, 10.741600613048696, 9.845463812775808, 15.749790301541704, 15.46415480975975, 14.47502456516568, 13.611591648620173, 12.622194327946586, 11.795253243907712, 10.88811513143499, 10.199662193453367, 10.876369638831948, 11.72039130348038, 11.88870818808251, 10.955541424965887, 9.987941648477651, 10.671256130982515, 11.603116511027126, 12.52684322941268, 13.556483865062797, 12.610058126748122, 11.7305920398448, 10.833902430996993, 15.54171956685104, 14.507516823992642, 13.52465002194563, 12.608847140524594, 11.671422335746332, 10.7320161838064, 9.88558874160786, 9.165708331735194, 9.870863035071668, 10.735423935300663, 11.627414220984626, 11.894875640156066, 10.968145481957842, 11.700925770547949, 12.529205921199265, 13.494670965478178, 14.519397916156148, 13.55307565759032, 12.68831191987979, 11.67955981175182, 14.622579920141238, 13.572629769212991, 12.594605843796117, 11.623955441001389, 10.63709068817404, 9.79941731905873, 8.87445064292547, 8.115067771515449, 8.808426651773717, 9.795401289123147, 10.648312529802379, 11.583803381840886, 11.929710776045987, 12.657862665560284, 13.55508018419064, 14.514292011417508, 15.46774289375641, 14.520307185247626, 13.639230289453467, 12.605411825709933, 13.553615222621048, 12.664273853385492, 11.650026707805708, 10.668873625247626, 9.620190528294096, 8.752008596920197, 7.902343607487525, 7.11059067957287, 7.825129797389171, 8.767195500929223, 9.71511091363773, 10.623528219162347, 11.615851355643722, 12.551950457253389, 13.527046666219999, 14.476288422852459, 15.484349974938151, 15.487187422002588, 14.583239227422432, 13.598057469496496, 12.609478224260998, 11.682408251750184, 10.649769748099402, 9.714012298642515, 8.684899982409116, 7.75076403323118, 6.837909722763098, 6.066476000173713, 6.864274903986169, 7.794227403364316, 8.692205153466945, 9.616056567112148, 10.600087853543886, 11.565852146527874, 12.5052245117194, 13.499540096985715, 14.535204811819, 15.484574640658332, 15.580067926564467, 14.525316908223592, 11.65342745508037, 10.68778247786219, 9.722053244941911, 8.758565290094285, 7.753558730356269, 6.823265580825941, 5.841884590786975, 5.0934014431072985, 5.8994082194345125, 6.83776941715448, 7.746255081013083, 8.62724575437986, 9.602380721661442, 10.624146828664044, 11.56577232959823, 12.609420492649646, 13.541335010905954, 14.514240212653887, 15.582256423597014, 15.484630130272635, 10.73193714746771, 9.761622281104051, 8.734625673080263, 7.786749428983248, 6.760413946989249, 5.8162170609414785, 4.842022747975049, 4.02441466119169, 4.842241358971699, 5.803150640417876, 6.755696727421269, 7.6911668572768805, 8.635433994690988, 9.659554418422537, 10.685294423026287, 11.634330148133492, 12.592349021372222, 13.534405523529673, 14.533962914289337, 15.466160588880998, 9.816292173312517, 8.755056325778448, 7.808885736162588, 6.811322911500411, 5.856950452167086, 4.893694850048652, 3.903871853078809, 2.9815302362272456, 3.885128169795295, 4.91866302609462, 5.84851403931172, 6.87547675425046, 7.927268603493522, 8.83158684715178, 9.8017889424697, 10.746356621113787, 11.712019173312672, 12.727271532435331, 13.741164663494047, 14.745659445190329, 8.869000818656565, 7.901476738939796, 6.860097495518508, 5.851532265414619, 4.855169646181635, 3.889314522023854, 2.934481272110862, 2.042431400358066, 2.947746692265932, 3.97510745467454, 5.025223034378012, 6.044625995003533, 6.904336067877991, 7.831536980931865, 8.86030976010266, 9.816815300374623, 10.82517396331729, 11.789436012934502, 12.77147925766908, 13.830190797678426, 7.822837689264226, 6.846847442321823, 5.915780716322241, 4.9251257749881505, 3.9648861684421535, 2.9351117682440506, 1.9079999412546615, 1.0585816935024468, 2.0041877192897526, 2.9298914731773347, 3.977530712705531, 5.017216261538755, 5.962384976118724, 6.994095424388945, 7.918562782196112, 8.958285340959693, 9.923818967254201, 10.94010779623045, 12.007631125527125, 13.040135151987895, 6.911560227743821, 5.897421804622887, 4.946454478062813, 4.000500505549639, 2.9881867565034232, 2.003509912653573, 0.959184231217216, 0.0, 0.9723938913800888, 1.9528113274235364, 3.0268840804090273, 4.0708170432329, 5.040574813384164, 5.972168921641053, 6.944771924818985, 8.010169441448815, 8.955379675362275, 10.012063012005486, 11.013250496546858, 12.076688976646661, 7.67100892580612, 6.697422025207514, 5.758136830994673, 4.830532008975918, 3.8478363464716026, 2.8640207584076065, 1.8971920718236779, 0.9831988850925905, 1.9989822510604638, 2.9747987292611406, 3.9175694973289326, 4.896560458258041, 5.844834665045504, 6.830471939723367, 7.8853274050607745, 8.919378231730793, 9.913795718512743, 10.922683760079357, 11.983642488164401, 12.970197477260607, 8.64096076434751, 7.7460499360538275, 6.803871276145392, 5.853262140457195, 4.908454330718234, 3.8625021548785927, 2.898262329483073, 2.0529668033641886, 2.9968398944102077, 3.9014030821066954, 4.880402333232247, 5.806434060132576, 6.826216733288518, 7.770032437956544, 8.709817565817982, 9.709403031748282, 10.71909750232458, 11.698842201360103, 12.733708238117083, 13.674878649310319, 9.568646397981686, 8.715771203294322, 7.804665172269787, 6.8225475652984455, 5.885941132806583, 4.811646733201263, 3.8559348701722485, 3.0182268997887665, 4.010095185180347, 4.9731003624872985, 5.928127445665666, 6.80912143799672, 7.740042697124481, 8.766308860710376, 9.682039720880617, 10.685589128978314, 11.699205992440843, 12.716151141628249, 13.667343476779454, 14.73511414454434], [14.686458398272103, 13.707702504528275, 12.669841338486252, 11.714844788969952, 10.665441567293401, 9.693202599659216, 8.751582075965215, 7.734513526889983, 6.819521806167112, 5.968137713165947, 5.038938926487432, 3.9953382623164555, 4.9253179475375015, 5.7690749425353, 6.712431163185534, 7.721754158218895, 8.773540491549257, 9.702744664420628, 10.714955619459625, 11.525312514868304, 13.689416521458659, 14.633653260489819, 13.677317949353958, 12.687325978112236, 11.688566866694096, 10.667031743229265, 9.727784113254572, 8.693276467489097, 7.747975245144872, 6.898417408402943, 5.965987827361816, 5.033169693548555, 5.9196750131391225, 6.766266248533073, 7.760086704126975, 8.72785753089162, 9.79225003351289, 10.758328873983578, 11.636284777295291, 10.569555783931966, 12.936455992774624, 13.882183998601574, 14.732132688416355, 13.701641630826574, 12.64670667928809, 11.665049553208299, 10.683522629360779, 9.708094138134426, 8.729883867853426, 7.916223633347785, 6.992621550169384, 5.998577308191654, 6.948935658032144, 7.751227719593502, 8.74434507286257, 9.6672561193268, 10.714670476154136, 11.667163830708079, 10.66732063950819, 9.670172297129282, 12.045084646542968, 13.01416798169408, 14.058473418498988, 14.686148771327147, 13.632780457071513, 12.639607324856776, 11.6827162119171, 10.756478833168705, 9.781409396039104, 8.894135296187816, 8.009882167343271, 6.960723845066948, 7.92819991677097, 8.732983397933959, 9.807170377875819, 10.72227981238961, 11.651941571030507, 10.824897240318775, 9.897525082428189, 8.918864300605998, 12.976520328467075, 13.946773350616864, 14.882468614890595, 15.633684200167377, 14.593635986823113, 13.679582309240438, 12.63523117140244, 11.705662912618324, 10.790772091581413, 9.908629906222306, 8.939447996420082, 7.9135269593523, 8.940924589597753, 9.688140678237772, 10.654204221188712, 11.635930241622898, 12.589437294786011, 11.787207665126614, 10.75115946593236, 9.820415146478496, 13.822224129219805, 14.836064459583687, 15.818088761936256, 15.532386327433612, 14.510698698644921, 13.676850425320577, 12.76320177103338, 11.815114686807261, 10.848526864038817, 10.842796348776668, 9.880389434152095, 8.945491400507448, 9.889924407395934, 10.648367928314233, 11.581641089156367, 12.544911164228791, 13.5487956724829, 12.657433213248526, 11.713994504428785, 10.817857704155896, 14.777396410161616, 15.817030618079402, 15.418789405286939, 14.555356488741431, 13.565959168067844, 12.73202126160174, 11.806933310097042, 10.899013997532322, 9.903975747451858, 10.74799741210029, 10.937233567381886, 10.004066804265262, 10.836530951437032, 11.643650022362603, 12.575510402407216, 13.49923712079277, 14.528877756442887, 13.58245201812821, 12.702985931224887, 11.806296322377081, 15.56768618816338, 15.4512816641139, 14.468414862066888, 13.552611980645851, 12.61518717586759, 11.675781023927657, 10.804406920269912, 9.87366426075164, 8.898469143691578, 9.763030043920573, 10.655020329604536, 10.943401019455441, 11.816734784917223, 12.673319661928037, 13.501599812579355, 14.467064856858268, 15.491791807536238, 14.525469548970408, 13.657408492672614, 12.648656384544644, 15.589108034195156, 14.516394609334249, 13.538370683917375, 12.567720281122646, 11.580855528295297, 10.743182159179987, 9.793268821587523, 8.823023700531895, 7.836032760393626, 8.823007397743057, 9.675918638422289, 10.611409490460796, 11.54542911285822, 12.522659973917536, 13.548874018276496, 14.460838762839707, 15.41428964517861, 15.492701076627714, 14.60832686224629, 13.574508398502756, 14.522711795413871, 13.60803869350675, 12.593791547926966, 11.612638465368883, 10.563955368415353, 9.695773437041455, 8.846108447608783, 7.910013036817051, 6.852735906009081, 7.794801609549132, 8.74271702225764, 9.651134327782255, 10.64345746426363, 11.579556565873297, 12.554652774839907, 13.503894531472366, 14.511956083558061, 15.464889904789947, 15.552335800215255, 14.567154042289319, 13.578574797053822, 12.651504824543007, 11.618866320892225, 10.657777138763773, 9.628664822530373, 8.694528873352438, 7.781674562884356, 6.865898357417894, 5.8918810126060785, 6.821833511984226, 7.719811262086855, 8.643662675732056, 9.627693962163795, 10.593458255147782, 11.532830620339308, 12.527146205605623, 13.56281092043891, 14.512180749278242, 15.50207471906939, 15.494413481016416, 12.622524027873194, 11.656879050655013, 10.691149817734734, 9.702330130215543, 8.697323570477527, 7.767030420947199, 6.785649430908233, 5.892823800351479, 4.9270143280544225, 5.86537552577439, 6.773861189632993, 7.654851862999769, 8.62998683028135, 9.651752937283954, 10.59337843821814, 11.637026601269556, 12.568941119525864, 13.541846321273797, 14.609862532216924, 15.520920289589045, 11.701033720260533, 10.730718853896875, 9.703722245873086, 8.755846001776073, 7.704178787110506, 6.759981901062736, 5.785787588096307, 4.826238993575568, 3.8698474675916095, 4.830756749037786, 5.783302836041179, 6.7187729658967905, 7.663040103310898, 8.687160527042447, 9.712900531646197, 10.661936256753402, 11.619955129992132, 12.562011632149582, 13.561569022909246, 14.493766697500908, 10.788686064692605, 9.727450217158536, 8.781279627542677, 7.783716802880499, 6.829344343547175, 5.866088741428741, 4.876265744458898, 3.905127926183978, 2.912734278415206, 3.946269134714531, 4.876120147931631, 5.903082862870371, 6.9548747121134324, 7.859192955771691, 8.829395051089612, 9.773962729733697, 10.739625281932582, 11.754877641055241, 12.768770772113959, 13.77326555381024, 9.841394710036653, 8.873870630319885, 7.832491386898596, 6.823926156794707, 5.827563537561724, 4.861708413403942, 3.906875163490951, 3.0085022715909164, 1.9753528008858432, 3.002713563294451, 4.052829142997923, 5.072232103623444, 5.931942176497902, 6.859143089551776, 7.8879158687225726, 8.844421408994535, 9.852780071937202, 10.817042121554413, 11.799085366288992, 12.857796906298338, 8.795231580644314, 7.819241333701912, 6.8881746077023305, 5.89751966636824, 4.937280059822243, 3.9075056596241393, 2.8803938326347502, 2.0246525647352973, 1.0317938279096637, 1.9574975817972455, 3.0051368213254417, 4.044822370158666, 4.989991084738635, 6.021701533008856, 6.946168890816024, 7.985891449579604, 8.951425075874113, 9.967713904850362, 11.035237234147036, 12.067741260607807, 7.88395411912391, 6.869815696002976, 5.918848369442902, 4.972894396929728, 3.960580647883512, 2.9759038040336616, 1.9315781225973048, 0.9723938913800888, 0.0, 0.9804174360434474, 2.0544901890289387, 3.0984231518528116, 4.068180922004076, 4.999775030260965, 5.972378033438897, 7.0377755500687265, 7.982985783982187, 9.039669120625398, 10.04085660516677, 11.104295085266573, 8.643402817186209, 7.669815916587602, 6.730530722374762, 5.802925900356006, 4.820230237851691, 3.836414649787695, 2.869585963203767, 1.9555927764726793, 1.0332418071398262, 2.002404837881052, 2.945175605948844, 3.9241665668779526, 4.872440773665415, 5.858078048343279, 6.912933513680686, 7.946984340350705, 8.941401827132655, 9.950289868699269, 11.011248596784313, 11.997803585880519, 9.613354655727598, 8.718443827433916, 7.77626516752548, 6.825656031837283, 5.880848222098322, 4.834896046258682, 3.870656220863162, 3.0253606947442773, 2.0310994504895703, 2.9290091907266067, 3.908008441852158, 4.8340401687524865, 5.853822841908429, 6.797638546576455, 7.737423674437893, 8.737009140368194, 9.746703610944492, 10.726448309980015, 11.761314346736995, 12.70248475793023, 10.541040289361774, 9.68816509467441, 8.777059063649876, 7.794941456678535, 6.8583350241866725, 5.784040624581352, 4.828328761552338, 3.9906207911688556, 3.0443547412597103, 4.000706471107209, 4.955733554285577, 5.836727546616631, 6.7676488057443915, 7.793914969330286, 8.709645829500529, 9.713195237598226, 10.726812101060755, 11.743757250248162, 12.694949585399367, 13.762720253164254], [13.706040962228654, 12.727285068484825, 11.689423902442803, 10.734427352926502, 9.685024131249952, 8.712785163615766, 7.771164639921768, 6.754096090846535, 5.839104370123664, 4.9877202771224995, 4.05954895596727, 4.9472470891259155, 5.877226774346962, 6.749492378578748, 7.692848599228982, 8.702171594262342, 9.753957927592705, 10.683162100464076, 11.695373055503072, 12.505729950911753, 12.708999085415211, 13.65323582444637, 12.696900513310508, 11.706908542068787, 10.708149430650646, 9.686614307185815, 8.747366677211126, 7.7128590314456495, 6.767557809101424, 6.026771129221277, 5.128907885320048, 5.985078520358014, 6.871583839948583, 7.746683684576521, 8.740504140170422, 9.708274966935068, 10.772667469556337, 11.738746310027025, 12.616702213338739, 11.549973219975413, 11.956038556731178, 12.901766562558128, 13.751715252372906, 12.721224194783124, 11.666289243244641, 10.684632117164849, 9.703105193317331, 8.727676702090978, 7.749466431809978, 7.04457735416612, 6.155541608127616, 6.950486135001113, 7.900844484841604, 8.731645155636949, 9.724762508906018, 10.647673555370247, 11.695087912197584, 12.647581266751526, 11.647738075551638, 10.65058973317273, 11.06466721049952, 12.033750545650632, 13.07805598245554, 13.7057313352837, 12.652363021028066, 11.659189888813328, 10.702298775873652, 9.776061397125257, 8.800991959995656, 8.02248901700615, 7.181010617285872, 7.912632671876407, 8.880108743580431, 9.713400833977406, 10.787587813919266, 11.702697248433058, 12.632359007073955, 11.805314676362222, 10.877942518471636, 9.899281736649446, 11.996102892423627, 12.966355914573416, 13.902051178847149, 14.653266764123929, 13.613218550779665, 12.69916487319699, 11.654813735358992, 10.725245476574877, 9.810354655537965, 9.036983627040637, 8.110576446362682, 8.86543578616176, 9.892833416407214, 10.66855811428122, 11.63462165723216, 12.616347677666345, 13.569854730829459, 12.767625101170061, 11.731576901975808, 10.800832582521943, 12.841806693176357, 13.85564702354024, 14.837671325892806, 15.57431237063541, 14.552624741846719, 13.655259879291048, 12.607727144452005, 11.75626876092144, 10.851517532541699, 9.974762845673101, 9.109524002643674, 9.897400227316908, 10.841833234205396, 11.62878536435768, 12.562058525199813, 13.525328600272237, 14.529213108526346, 13.637850649291973, 12.694411940472232, 11.798275140199344, 13.796978974118169, 14.836613182035954, 15.832871072263037, 15.44569209835851, 14.456294777684922, 13.622356871218821, 12.697268919714123, 11.7893496071494, 10.794311357068937, 10.030538369915229, 10.17187787002239, 10.955975631074722, 11.788439778246493, 12.624067458406051, 13.555927838450662, 14.479654556836216, 15.509295192486332, 14.562869454171658, 13.683403367268335, 12.776071030467229, 14.659812642797773, 15.694015385656169, 15.358750471683967, 14.44294759026293, 13.505522785484668, 12.566116633544736, 11.694742529886993, 10.763999870368721, 9.788804753308657, 9.045571001735512, 9.900064818490883, 10.869339079492562, 11.752038895832712, 12.711894626077415, 13.672908586322334, 14.724024840216295, 15.636426239075142, 15.491851796369621, 14.547744102289695, 13.538991994161725, 15.579572443397904, 15.406730218951328, 14.428706293534454, 13.458055890739725, 12.471191137912376, 11.633517768797066, 10.683604431204603, 9.713359310148975, 8.726368370010706, 8.105548355557996, 8.920963127308635, 9.856453979347142, 10.790473601744566, 11.767704462803882, 12.793918507162845, 13.705883251726057, 14.65933413406496, 15.610218022975014, 15.498662471863371, 14.464844008119837, 15.413047405030952, 14.498374303123828, 13.484127157544044, 12.502974074985962, 11.454290978032432, 10.586109046658533, 9.736444057225862, 8.800348646434129, 7.74307151562616, 7.077342567364072, 7.987761511143987, 8.896178816668602, 9.888501953149978, 10.824601054759645, 11.799697263726255, 12.748939020358716, 13.690403964988166, 14.643337786220052, 15.636082761050888, 15.4574896519064, 14.468910406670902, 13.541840434160088, 12.509201930509306, 11.548112748380852, 10.519000432147452, 9.584864482969516, 8.672010172501436, 7.756233967034973, 6.7822166222231575, 6.08927544030196, 6.964855750973202, 7.888707164618403, 8.872738451050143, 9.83850274403413, 10.777875109225656, 11.772190694491972, 12.741258801869014, 13.649360092117705, 14.639254061908852, 15.57235996627248, 13.512859637490275, 12.547214660272093, 11.581485427351815, 10.592665739832622, 9.587659180094606, 8.657366030564278, 7.675985040525312, 6.783159409968558, 5.817349937671501, 5.132817454092123, 6.0189056785193396, 6.899896351886116, 7.8750313191676975, 8.872476013225851, 9.814101514160038, 10.857749677211453, 11.747389000955968, 12.640752059243091, 13.701988986851317, 14.613046744223437, 12.591369329877613, 11.621054463513955, 10.594057855490167, 9.646181611393153, 8.594514396727586, 7.650317510679815, 6.676123197713386, 5.7165746031926465, 4.760183077208689, 4.098198677355519, 5.028347324927526, 5.963817454783137, 6.908084592197245, 7.907883602984345, 8.915055215907056, 9.797276064147644, 10.712081584626524, 11.654138086783975, 12.65369547754364, 13.5858931521353, 11.75400662457313, 10.69277077703906, 9.746600187423201, 8.749037362761024, 7.791831414925621, 6.7966105357767335, 5.806787538806891, 4.795463535801057, 3.803069888032285, 3.122733928021324, 4.01565672110655, 5.042619436045291, 5.992189730852856, 6.878775519728244, 7.848977615046165, 8.79354529369025, 9.759207845889136, 10.774460205011795, 11.78835333607051, 12.792848117766793, 10.8218121460801, 9.849409861862117, 8.808030618440828, 7.789246716675232, 6.792884097442249, 5.827028973284468, 4.872195723371476, 3.8988378812079953, 2.865688410502922, 2.0479844640882625, 3.072411706954476, 4.091814667579996, 4.951524740454454, 5.8787256535083285, 6.907498432679125, 7.864003972951087, 8.872362635893754, 9.836624685510966, 10.818667930245544, 11.87737947025489, 9.775649016687762, 8.79965876974536, 7.868592043745778, 6.877937102411686, 5.917697495865689, 4.8879230956675865, 3.860811268678198, 2.9149881743523762, 1.9221294375267424, 0.9770801457537982, 2.0247193852819945, 3.0644049341152186, 4.009573648695187, 5.041284096965408, 5.965751454772576, 7.005474013536157, 7.971007639830665, 8.987296468806914, 10.054819798103589, 11.08732382456436, 8.864371555167358, 7.850233132046424, 6.899265805486349, 5.953311832973176, 4.94099808392696, 3.9563212400771093, 2.9119955586407524, 1.9528113274235364, 0.9804174360434474, 0.0, 1.074072752985491, 2.118005715809364, 3.087763485960628, 4.019357594217517, 4.991960597395449, 6.057358114025279, 7.002568347938739, 8.05925168458195, 9.060439169123322, 10.123877649223125, 9.623820253229656, 8.65023335263105, 7.710948158418209, 6.7833433363994535, 5.8006476738951385, 4.816832085831143, 3.8500033992472145, 2.936010212516127, 2.0136592431832736, 1.0219874018376043, 1.9647581699053962, 2.943749130834505, 3.8920233376219677, 4.877660612299831, 5.9325160776372385, 6.966566904307257, 7.960984391089208, 8.969872432655823, 10.030831160740867, 11.017386149837073, 10.593772091771045, 9.698861263477363, 8.756682603568928, 7.806073467880731, 6.86126565814177, 5.8153134823021295, 4.8510736569066095, 3.9808333328469137, 2.9830082772990303, 1.948591754683159, 2.9275910058087105, 3.8536227327090384, 4.873405405864981, 5.817221110533007, 6.757006238394444, 7.756591704324745, 8.766286174901044, 9.746030873936567, 10.780896910693547, 11.722067321886783, 11.521457725405222, 10.668582530717858, 9.757476499693324, 8.775358892721982, 7.83875246023012, 6.7644580606248, 5.808746197595785, 4.9460934292714915, 3.9962635680691703, 3.0202890350637617, 3.9753161182421293, 4.856310110573183, 5.787231369700944, 6.813497533286839, 7.729228393457079, 8.732777801554777, 9.746394665017306, 10.763339814204713, 11.714532149355918, 12.782302817120804], [12.709030014512352, 11.730274120768524, 10.692412954726501, 9.737416405210201, 8.68801318353365, 7.715774215899465, 6.796766498659929, 5.779697949584697, 4.8647062288618255, 4.013322135860661, 4.937029724852555, 5.8247278580112, 6.7547075432322465, 7.7262240733322285, 8.669580293982463, 9.678903289015825, 10.730689622346187, 11.659893795217558, 12.678362167005966, 13.56407187754537, 11.71198813769891, 12.656224876730068, 11.699889565594207, 10.709897594352485, 9.711138482934345, 8.689603359469514, 7.772968535949286, 6.738460890183811, 5.793159667839586, 5.052372987959439, 5.984802569000566, 6.862559289243299, 7.7490646088338675, 8.723415379330001, 9.717235834923905, 10.68500666168855, 11.74939916430982, 12.715478004780508, 13.675044139972355, 12.60831514660903, 10.881965803745686, 11.827693809572636, 12.754704304656604, 11.724213247066823, 10.66927829552834, 9.687621169448548, 8.728707052055492, 7.7532785608291395, 6.775068290548139, 6.070179212904281, 7.004547522355162, 7.827966903886398, 8.778325253726889, 9.70837685039043, 10.701494203659498, 11.62440525012373, 12.671819606951066, 13.659420296012769, 12.706080002185255, 11.708931659806346, 9.990594457514028, 10.95967779266514, 12.003983229470048, 12.731333194021861, 11.677964879766227, 10.68479174755149, 9.727900634611814, 8.801663255863419, 7.8265938187338175, 7.048090875744311, 8.030016531513418, 8.790113440761692, 9.757589512465715, 10.690132528730885, 11.764319508672745, 12.67942894318654, 13.609090701827437, 12.879387429347712, 11.952015271457126, 10.973354489634936, 10.922030139438135, 11.892283161587924, 12.827978425861655, 13.67886862286209, 12.638820409517827, 11.724766731935151, 10.680415594097154, 9.750847335313038, 8.835956514276127, 8.0625854857788, 8.959582360590229, 9.742916555047044, 10.770314185292499, 11.645289809034699, 12.611353351985638, 13.593079372419824, 14.546586425582941, 13.84169785415555, 12.805649654961297, 11.874905335507432, 11.767733940190865, 12.781574270554747, 13.763598572907316, 14.59991422937357, 13.57822660058488, 12.68086173802921, 11.633329003190166, 10.781870619659601, 9.87711939127986, 9.000364704411265, 9.958529916871221, 10.774880996202192, 11.71931400309068, 12.60551705911116, 13.538790219953292, 14.502060295025716, 15.505944803279824, 14.711923402277462, 13.76848469345772, 12.872347893184832, 12.722906221132677, 13.762540429050462, 14.758798319277547, 15.509300553703403, 14.519903233029815, 13.514685415631202, 12.589597464126504, 11.780435371847528, 10.82167050786682, 9.926747708845708, 9.98205184974423, 10.823189581731679, 11.74675901636184, 12.69184044696337, 13.613514283543411, 14.57872882664546, 15.540672171294888, 15.636942207157146, 14.757476120253823, 13.850143783452719, 13.595283773069765, 14.62948651592816, 15.612353317975172, 15.517020343248422, 14.57959553847016, 13.640189386530228, 12.761621945889198, 11.785537956702088, 10.771775585842512, 9.83063062640269, 8.914581105539819, 9.8838553665415, 10.76655518288165, 11.726410913126353, 12.687424873371272, 13.66689604897484, 14.577758120201537, 15.512920680904312, 15.621816855275185, 14.613064747147215, 14.515043573669896, 15.587756998530804, 15.502779046519944, 14.532128643725217, 13.545263890897868, 12.707590521782558, 11.757677184190094, 10.787432063134466, 9.800441122996196, 8.890607980225175, 7.935479414357572, 8.87097026639608, 9.804989888793504, 10.78222074985282, 11.73525038828924, 12.647215132852452, 13.600666015191354, 14.545689153247006, 15.502352952946124, 15.538916761105327, 15.579570121545101, 15.57244705610932, 14.558199910529536, 13.577046827971454, 12.528363731017924, 11.660181799644025, 10.810516810211352, 9.87442139941962, 8.817144268611651, 7.914632660715334, 7.002277798192923, 7.910695103717538, 8.903018240198913, 9.76593293588604, 10.74102914485265, 11.69027090148511, 12.625875095260158, 13.578808916492044, 14.57155389132288, 15.435090535271568, 15.542983159656393, 14.615913187145578, 13.583274683494796, 12.622185501366342, 11.593073185132944, 10.658937235955008, 9.746082925486926, 8.830306720020465, 7.856289375208649, 6.926565533653222, 5.979372038022138, 6.903223451667339, 7.887254738099078, 8.779834625160525, 9.71920699035205, 10.713522575618367, 11.676729932141006, 12.584831222389697, 13.574725192180845, 14.507831096544471, 14.586932390475765, 13.621287413257583, 12.655558180337305, 11.666738492818112, 10.661731933080096, 9.73143878354977, 8.750057793510802, 7.85723216295405, 6.891422690656993, 5.970107547443385, 5.033421965568276, 5.914412638935052, 6.889547606216634, 7.807947143497848, 8.749572644432034, 9.793220807483449, 10.68286013122796, 11.576223189515083, 12.63746011712331, 13.54851787449543, 13.665442082863104, 12.695127216499445, 11.668130608475657, 10.720254364378643, 9.668587149713076, 8.724390263665306, 7.750195950698877, 6.7906473561781375, 5.83425583019418, 4.935488770706781, 4.042863611976462, 4.978333741832073, 5.918689387867346, 6.843354733256341, 7.850526346179052, 8.732747194419638, 9.647552714898517, 10.589609217055967, 11.589166607815631, 12.521364282407292, 12.82807937755862, 11.76684353002455, 10.820672940408691, 9.823110115746514, 8.865904167911111, 7.870683288762224, 6.880860291792381, 5.869536288786548, 4.877142641017776, 3.960024021372587, 3.030173008155487, 4.057135723094227, 4.927660861124853, 5.814246650000239, 6.78444874531816, 7.729016423962245, 8.69467897616113, 9.70993133528379, 10.714280583085019, 11.718775364781301, 11.895884899065589, 10.92348261484761, 9.88210337142632, 8.863319469660723, 7.866956850427741, 6.901101726269959, 5.946268476356968, 4.972910634193487, 3.939761163488413, 3.1220572170737535, 2.086927994003413, 3.106330954628934, 3.8869958707264507, 4.814196783780325, 5.833425679693634, 6.789931219965596, 7.7982898829082625, 8.762551932525474, 9.744595177260052, 10.803306717269399, 10.84972176967325, 9.873731522730848, 8.942664796731268, 7.952009855397178, 6.991770248851181, 5.961995848653078, 4.934884021663689, 3.989060927337867, 2.9962021905122334, 2.0511528987392893, 1.039235672330932, 2.0789212211641566, 2.945044778967184, 3.9767552272374056, 4.891678701787085, 5.9314012605506665, 6.896934886845173, 7.913223715821423, 8.980747045118099, 10.01325107157887, 9.938444308152848, 8.924305885031913, 7.9733385584718395, 7.027384585958666, 6.01507083691245, 5.0303939930626, 3.9860683116262434, 3.0268840804090273, 2.0544901890289387, 1.074072752985491, 0.0, 1.043932962823873, 2.013690732975137, 2.9452848412320263, 3.9178878444099583, 4.983285361039788, 5.928495594953247, 6.985178931596458, 7.98636641613783, 9.049804896237633, 10.682162179863273, 9.708575279264666, 8.769290085051825, 7.841685263033068, 6.858989600528753, 5.875174012464758, 4.908345325880829, 3.93920346252802, 2.9234200965601467, 1.8994681707228889, 0.956697402655097, 1.9356883635842057, 2.8839625703716685, 3.8695998450495313, 4.924455310386939, 5.958506137056958, 6.886911638103716, 7.895799679670331, 8.956758407755375, 9.94331339685158, 11.652114018404662, 10.72428645162992, 9.76274917033652, 8.812140034648323, 7.8673322249093625, 6.793647925206388, 5.82780535166009, 4.858314101732199, 3.860489046184315, 2.8260725235684436, 1.9531928645468724, 2.8792245914472003, 3.8763944581486807, 4.820210162816706, 5.759995290678144, 6.759580756608445, 7.7692752271847425, 8.749019926220265, 9.783885962977246, 10.725056374170482, 12.579799652038838, 11.694007718870415, 10.735810942597581, 9.75369333562624, 8.817086903134378, 7.742792503529058, 6.785477892349266, 5.823574198156777, 4.873744336954455, 3.8977698039490463, 3.0009179769802907, 3.8819119693113446, 4.812833228439105, 5.82718290165055, 6.732217445740779, 7.735766853838476, 8.749383717301004, 9.766328866488411, 10.717521201639617, 11.785291869404503], [11.729873526269385, 10.751117632525556, 9.713256466483534, 8.758259916967233, 7.708856695290681, 6.736617727656496, 5.902100077265823, 4.91150497513762, 4.023344249397598, 4.975753331420105, 5.978536208663985, 6.866234341822629, 7.796214027043676, 8.767730557143658, 9.711086777793891, 10.720409772827253, 11.772196106157615, 12.701400279028986, 13.719868650817395, 14.605578361356798, 10.73283164945594, 11.6770683884871, 10.72073307735124, 9.730741106109518, 8.731981994691376, 7.710446871226544, 6.93160655648506, 5.897098910719585, 4.9517976883753585, 5.912363016154482, 6.844792597195609, 7.7776107310088705, 8.790571092645296, 9.764921863141431, 10.758742318735333, 11.726513145499979, 12.790905648121248, 13.756984488591936, 14.716550623783785, 13.64982163042046, 9.838032840921814, 10.783760846748764, 11.775547816413635, 10.745056758823853, 9.69012180728537, 8.708464681205578, 7.887345072591267, 6.911916581364913, 5.933706311083912, 6.930169241099325, 7.864537550550206, 8.74301834565197, 9.780141650098892, 10.74988333420186, 11.743000687470929, 12.665911733935157, 13.713326090762495, 14.700926779824197, 13.747586485996685, 12.750438143617776, 8.946661494690156, 9.915744829841268, 10.960050266646176, 11.753382682774815, 10.70001436851918, 9.706841236304443, 8.88653865514759, 7.960301276399193, 6.9852318392695905, 7.908080903939355, 8.89000655970846, 9.705164882527264, 10.753981034806369, 11.731639012542317, 12.805825992484177, 13.720935426997968, 14.650597185638865, 13.923320392171586, 12.995948234281, 12.01728745245881, 9.878097176614263, 10.848350198764052, 11.784045463037785, 12.700918111615044, 11.66086989827078, 10.746816220688105, 9.839053614632927, 8.909485355848812, 7.994594534811901, 8.922575513973843, 9.819572388785271, 10.657967996812616, 11.685365627058069, 12.68679629284613, 13.65285983579707, 14.634585856231256, 15.58809290939437, 14.885630816979424, 13.84958261778517, 12.918838298331305, 10.723800977366993, 11.737641307730875, 12.719665610083442, 13.621963718126525, 12.600276089337834, 11.735893197076319, 10.79196702372594, 9.940508640195375, 9.035757411815634, 9.860354732606307, 10.818519945066264, 11.048691626091315, 11.769595633290237, 12.76335261389904, 13.631454044913724, 14.545116778780443, 15.480615886028403, 15.755856365101335, 14.812417656281594, 13.916280856008706, 11.678973258308805, 12.71860746622659, 13.714865356453673, 14.5344129405885, 13.545015619914912, 12.673323436166976, 11.748235484662278, 10.939073392383301, 9.980308528402594, 10.78673773704075, 10.923282985450125, 9.990116222333501, 10.82298908924914, 11.768070519850669, 12.637584731662875, 13.590790822216464, 14.496739208471014, 15.41200524892264, 15.801409083077697, 14.894076746276593, 12.551350810245895, 13.58555355310429, 14.568420355151302, 15.464413860261933, 14.495787612115166, 13.686852478425399, 12.750761874489408, 11.973027254101474, 10.985815132162873, 10.779971441915752, 9.86392192105288, 9.050782007143322, 9.842785255768948, 10.750481361245816, 11.711495321490736, 12.622963086150966, 13.533825157377663, 14.468987718080442, 15.413095412160368, 15.656997709971085, 13.471110610846026, 14.543824035706933, 15.498464533300815, 15.576061606549088, 14.589196853721738, 13.751523484606428, 12.790236675995201, 11.819991554939573, 10.833000614801303, 9.839948795738236, 8.884820229870632, 8.037896906997902, 8.881219961680804, 9.793544466233481, 10.691317425465368, 11.603282170028578, 12.55673305236748, 13.501756190423135, 14.458419990122254, 15.383803216234261, 14.535637158721231, 15.484820402771778, 15.602132873353407, 14.620979790795325, 13.572296693841794, 12.704114762467896, 11.854449773035226, 10.918354362243495, 9.861077231435527, 8.934241063501789, 7.951618613705984, 7.0136974630031235, 7.878254082029078, 8.721999973062168, 9.697096182028778, 10.646337938661237, 11.581942132436287, 12.534875953668173, 13.52762092849901, 14.391157572447698, 15.388654193499129, 15.659846149969448, 14.627207646318666, 13.666118464190212, 12.637006147956814, 11.702870198778879, 10.7900158883108, 9.874239682844339, 8.900222338032524, 7.957354772708702, 6.928712853535199, 6.006225810952924, 6.862490579929243, 7.735901662336654, 8.675274027528179, 9.669589612794494, 10.632796969317136, 11.540898259565827, 12.530792229356974, 13.463898133720601, 15.630865353299635, 14.665220376081454, 13.699491143161175, 12.710671455641984, 11.705664895903968, 10.77537174637364, 9.793990756334676, 8.901165125777924, 7.935355653480867, 7.000896786498865, 5.982762781081337, 5.017414998220637, 5.864783448046798, 6.764014180673976, 7.7056396816081625, 8.749287844659579, 9.63892716840409, 10.532290226691213, 11.593527154299439, 12.504584911671559, 14.709375045686974, 13.739060179323316, 12.712063571299527, 11.764187327202514, 10.712520112536948, 9.768323226489178, 8.79412891352275, 7.834580319002011, 6.878188793018054, 5.966278009762261, 5.01680623097327, 4.0813361011176585, 4.874756425043473, 5.799421770432469, 6.80659338335518, 7.6888142315957655, 8.603619752074646, 9.545676254232097, 10.545233644991761, 11.477431319583422, 13.872012340382494, 12.810776492848424, 11.864605903232565, 10.867043078570388, 9.909837130734987, 8.914616251586098, 7.9247932546162545, 6.9134692516104215, 5.92107560384165, 4.990813260428066, 4.060962247210966, 3.120043157032365, 3.8837278983009798, 4.770313687176367, 5.740515782494288, 6.685083461138373, 7.650746013337259, 8.665998372459919, 9.670347620261147, 10.674842401957429, 12.939817861889463, 11.967415577671483, 10.926036334250194, 9.907252432484597, 8.910889813251615, 7.945034689093832, 6.990201439180841, 6.01684359701736, 4.983694126312287, 4.165990179897626, 3.117717233058893, 2.081655971837278, 2.8430629079025778, 3.770263820956452, 4.789492716869761, 5.745998257141723, 6.75435692008439, 7.718618969701601, 8.70066221443618, 9.759373754445527, 11.893654732497124, 10.917664485554722, 9.986597759555142, 8.99594281822105, 8.035703211675052, 7.0059288114769505, 5.978816984487562, 5.03299389016174, 4.040135153336107, 3.0950858615631622, 2.083168635154805, 1.0542462383725006, 1.901111816143311, 2.9328222644135327, 3.8477457389632126, 4.887468297726794, 5.853001924021301, 6.869290752997551, 7.936814082294227, 8.969318108754997, 10.982377270976722, 9.968238847855787, 9.017271521295713, 8.07131754878254, 7.059003799736324, 6.074326955886473, 5.030001274450116, 4.070817043232901, 3.0984231518528116, 2.118005715809364, 1.043932962823873, 0.0, 0.9697577701512643, 1.9013518784081533, 2.8739548815860854, 3.939352398215915, 4.884562632129375, 5.941245968772586, 6.942433453313958, 8.005871933413761, 11.723668663674703, 10.750081763076096, 9.810796568863255, 8.8831917468445, 7.900496084340183, 6.916680496276188, 5.949851809692259, 4.9807099463394495, 3.9649265803715763, 2.9409746545343185, 1.9982038864665268, 1.019212925537418, 1.9048060821286987, 2.8904433568065615, 3.941994129277515, 4.930360441488121, 5.842978675279844, 6.851866716846459, 7.912825444931503, 8.899380434027709, 12.693620502216092, 11.765792935441352, 10.804255654147951, 9.853646518459755, 8.908838708720793, 7.835154409017818, 6.869311835471519, 5.899820585543628, 4.9019955299957445, 3.8675790073798733, 2.9638943388833012, 2.0378626119829732, 2.897237969905711, 3.841053674573737, 4.7808388024351745, 5.780424268365476, 6.790118738941773, 7.769863437977295, 8.804729474734277, 9.745899885927512, 13.621306135850269, 12.735514202681847, 11.777317426409013, 10.795199819437672, 9.85859338694581, 8.784298987340488, 7.826984376160695, 6.865080681968206, 5.915250820765884, 4.939276287760476, 4.01161945131672, 3.0405499898471176, 3.944640253992029, 4.848026413407581, 5.7530609574978095, 6.756610365595507, 7.770227229058036, 8.787172378245442, 9.738364713396647, 10.806135381161534], [10.76011575611812, 9.781359862374291, 8.743498696332269, 7.7885021468159685, 6.739098925139417, 5.766859957505232, 4.932342307114558, 3.941747204986356, 4.887453842625077, 5.8398629246475835, 6.8426458018914635, 7.730343935050108, 8.660323620271154, 9.631840150371136, 10.57519637102137, 11.584519366054732, 12.636305699385094, 13.565509872256465, 14.583978244044873, 15.46968795458428, 9.763073879304674, 10.707310618335836, 9.750975307199974, 8.760983335958253, 7.7622242245401125, 6.74068910107528, 5.974808325641239, 4.970872549373196, 5.815907281602837, 6.776472609381961, 7.708902190423088, 8.64172032423635, 9.654680685872775, 10.62903145636891, 11.622851911962812, 12.590622738727458, 13.655015241348726, 14.621094081819415, 15.580660217011266, 14.51393122364794, 8.868275070770549, 9.8140030765975, 10.805790046262372, 9.77529898867259, 8.720364037134107, 7.738706911054315, 6.961118711244878, 5.985690220018524, 6.797815904311391, 7.7942788343268035, 8.728647143777685, 9.607127938879449, 10.644251243326371, 11.613992927429338, 12.607110280698407, 13.530021327162636, 14.577435683989973, 15.565036373051676, 14.611696079224165, 13.614547736845257, 7.976903724538891, 8.945987059690003, 9.990292496494911, 10.783624912623551, 9.730256598367918, 8.73708346615318, 7.9603122938012, 7.034074915052804, 7.849341432497069, 8.772190497166834, 9.754116152935941, 10.569274475754742, 11.618090628033848, 12.595748605769796, 13.669935585711656, 14.585045020225447, 15.514706778866344, 14.89307816232285, 13.965706004432263, 12.987045222610073, 8.908339406462998, 9.878592428612787, 10.81428769288652, 11.73116034146378, 10.691112128119517, 9.777058450536842, 8.912827253286538, 7.983258994502423, 8.85870412803938, 9.786685107201322, 10.683681982012752, 11.522077590040094, 11.748837680937154, 12.753822093824235, 13.589133142730116, 14.570859163164302, 15.543610184018794, 15.855388587130687, 14.819340387936434, 13.888596068482569, 9.75404320721573, 10.767883537579612, 11.749907839932181, 12.652205947975261, 11.63051831918657, 10.766135426925056, 9.865740662379551, 9.014282278848986, 9.899867005043113, 10.724464325833786, 11.682629538293744, 11.81662131727997, 10.799837863138972, 11.793594843747774, 12.66169627476246, 13.575359008629182, 14.510858115877141, 15.367266283651059, 15.782175426432858, 14.88603862615997, 10.709215488157541, 11.748849696075327, 12.745107586302412, 13.564655170437236, 12.575257849763648, 11.710964590643892, 10.822009123315889, 10.012847031036912, 10.844418121630072, 11.65084733026823, 11.69121267663878, 10.758045913522157, 9.853231319097874, 10.798312749699404, 11.667826961511611, 12.621033052065203, 13.526981438319753, 14.442247478771375, 15.39459292940115, 15.762838433646866, 11.58159304009463, 12.615795782953025, 13.598662585000037, 14.49465609011067, 13.526029841963902, 12.76062611707901, 11.824535513143019, 11.046800892755085, 11.849924725390352, 11.54790113310441, 10.631851612241539, 9.818711698331978, 8.873027485617683, 9.780723591094553, 10.741737551339472, 11.653205315999704, 12.564067387226402, 13.499229947929177, 14.443337642009103, 15.425357680718147, 12.50135284069476, 13.574066265555668, 14.52870676314955, 15.479547789633875, 14.560361489536195, 13.69322498182668, 12.835673611825408, 12.09744145297483, 11.600930305989962, 10.607878486926895, 9.652749921059291, 8.80582659818656, 7.911462191529539, 8.823786696082218, 9.721559655314104, 10.633524399877317, 11.586975282216219, 12.53199842027187, 13.488662219970989, 14.414045446082996, 13.565879388569966, 14.515062632620513, 15.529309778200297, 15.44098228838877, 14.39229919143524, 13.524117260061342, 12.67445227062867, 11.708307089001558, 10.644236458230498, 9.702170754690448, 8.719548304894642, 7.781627154191781, 6.908496311877814, 7.752242202910905, 8.727338411877515, 9.676580168509975, 10.612184362285022, 11.565118183516908, 12.557863158347745, 13.421399802296433, 14.418896423347864, 15.455406742785492, 15.447210143912113, 14.486120961783659, 13.45700864555026, 12.522872696372325, 11.610018385904244, 10.694242180437783, 9.720224835625968, 8.728358772111761, 7.696642544723857, 6.774155502141582, 5.8927328097779785, 6.76614389218539, 7.705516257376916, 8.699831842643231, 9.66303919916587, 10.571140489414562, 11.56103445920571, 12.494140363569336, 15.366029816712558, 15.4852228736749, 14.519493640754622, 13.530673953235429, 12.525667393497413, 11.595374243967086, 10.61399325392812, 9.721167623371368, 8.755358151074311, 7.771900785901925, 6.750692472269995, 5.785344689409295, 4.895025677895534, 5.794256410522712, 6.735881911456898, 7.779530074508314, 8.669169398252825, 9.562532456539948, 10.623769384148174, 11.534827141520294, 15.52937754328042, 14.559062676916762, 13.532066068892973, 12.58418982479596, 11.532522610130393, 10.588325724082623, 9.614131411116194, 8.654582816595456, 7.698191290611498, 6.737282009165321, 5.784735922161928, 4.8492657923063165, 3.904998654892209, 4.829664000281205, 5.836835613203915, 6.7190564614445005, 7.633861981923381, 8.575918484080832, 9.575475874840496, 10.507673549432157, 14.740774027752767, 13.679538180218698, 12.733367590602839, 11.735804765940662, 10.77859881810526, 9.783377938956372, 8.793554941986528, 7.782230938980695, 6.789837291211923, 5.777885030388649, 4.84803401717155, 3.9071149269929473, 2.9139701281497157, 3.8005559170251026, 4.770758012343023, 5.715325690987108, 6.680988243185994, 7.696240602308654, 8.700589850109884, 9.705084631806166, 13.897060676720425, 12.836177265041757, 11.794798021620467, 10.776014119854871, 9.779651500621888, 8.813796376464106, 7.858963126551115, 6.885605284387633, 5.85245581368256, 4.9689700881286765, 3.9047890030194754, 2.8687277417978603, 1.8733051377513137, 2.800506050805188, 3.8197349467184973, 4.77624048699046, 5.784599149933126, 6.748861199550338, 7.730904444284917, 8.789615984294263, 12.863412502648387, 11.887422255705985, 10.956355529706405, 9.965700588372314, 9.005460981826317, 7.975686581628215, 6.948534614389809, 5.901755577532014, 4.90889684070638, 3.963847548933436, 2.9162083094052393, 1.8765227605720152, 0.9313540459920467, 1.9630644942622681, 2.8779879688119485, 3.9177105275755295, 4.883244153870037, 5.899532982846286, 6.967056312142962, 7.999560338603732, 11.952135041127985, 10.93799661800705, 9.987029291446976, 9.041075318933803, 8.028761569887587, 7.044084726037737, 5.99975904460138, 5.040574813384165, 4.068180922004076, 3.087763485960628, 2.013690732975137, 0.9697577701512643, 0.0, 0.9315941082568892, 1.9041971114348213, 2.969594628064651, 3.914804861978111, 4.971488198621321, 5.972675683162693, 7.036114163262496, 12.587778256902183, 11.614191356303577, 10.674906162090736, 9.74730134007198, 8.764605677567664, 7.780790089503667, 6.813961402919738, 5.844819539566929, 4.8290361735990555, 3.8050842477617977, 2.8623134796940057, 1.883322518764897, 0.9350483119774345, 1.9206855866552974, 2.972236359126251, 3.960602671336857, 4.873220905128579, 5.882108946695194, 6.943067674780238, 7.929622663876444, 13.557730095443572, 12.629902528668831, 11.66836524737543, 10.717756111687233, 9.772948301948272, 8.699264002245297, 7.733421428698998, 6.763930178771107, 5.766105123223223, 4.731688600607352, 3.82800393211078, 2.901972205210452, 1.9274801997544466, 2.8712959044224724, 3.81108103228391, 4.810666498214211, 5.820360968790508, 6.80010566782603, 7.834971704583011, 8.776142115776246, 14.485415729077749, 13.599623795909325, 12.641427019636492, 11.65930941266515, 10.722702980173288, 9.648408580567967, 8.691093969388174, 7.729190275195685, 6.779360413993363, 5.803385880987955, 4.875729044544198, 3.9046595830745963, 2.9748824838407644, 3.878268643256316, 4.7833031873465455, 5.786852595444243, 6.800469458906772, 7.817414608094178, 8.768606943245382, 9.836377611010269], [9.896122970052135, 8.917367076308306, 7.88647106842426, 6.931474518907961, 5.980768228491734, 5.0329986066066725, 4.198480956216, 4.873341313243245, 5.819047950881966, 6.771457032904473, 7.774239910148353, 8.661938043306998, 9.591917728528044, 10.563434258628027, 11.50679047927826, 12.516113474311622, 13.567899807641984, 14.497103980513355, 15.515572352301763, 16.401282062841165, 8.865183983478186, 9.822477817848199, 8.893947679291967, 7.903955708050245, 7.00389352789243, 6.006827750176721, 5.2409469747426805, 5.902466657630084, 6.7475013898597265, 7.70806671763885, 8.640496298679977, 9.573314432493238, 10.586274794129665, 11.5606255646258, 12.554446020219702, 13.522216846984348, 14.586609349605617, 15.552688190076305, 16.512254325268152, 15.445525331904827, 7.93668096251366, 8.882408968340611, 9.88605514521668, 8.931777364732536, 7.9736817831127205, 7.004845560155756, 6.2360855341808445, 6.917284328275413, 7.72941001256828, 8.725872942583692, 9.660241252034574, 10.538722047136337, 11.57584535158326, 12.545587035686228, 13.538704388955297, 14.461615435419526, 15.509029792246864, 16.496630481308564, 15.543290187481052, 14.546141845102143, 7.045309616282002, 8.014392951433113, 9.058698388238021, 9.946396187939492, 8.996395247469358, 8.003222115254621, 7.235279116737167, 7.965669023309692, 8.780935540753958, 9.703784605423722, 10.68571026119283, 11.50086858401163, 12.549684736290736, 13.024317488031794, 13.828511715861175, 14.71584356707102, 15.646528946617625, 15.82467227057974, 14.897300112689154, 13.918639330866963, 7.976745298206109, 8.946998320355899, 9.882693584629632, 10.89393161677972, 9.957250777220958, 9.043197099638283, 8.20221622511732, 8.914853102759311, 9.790298236296268, 10.71827921545821, 11.61527609026964, 12.453671698296983, 12.680431789194046, 12.06916020772798, 12.777483846550261, 13.759209866984447, 14.717270717298819, 15.396182035593172, 15.750934496193324, 14.820190176739459, 8.82244909895884, 9.836289429322722, 10.818313731675289, 11.774207371987378, 10.896656968288012, 10.032274076026496, 9.155129634210333, 9.945876387105875, 10.831461113300001, 11.656058434090674, 12.614223646550633, 12.74821542553686, 11.731431971395864, 11.10893295765152, 11.850046978582606, 12.749019541909206, 13.684518649157166, 14.460343375574986, 15.403782084394727, 15.81763273441686, 9.777621379900651, 10.817255587818437, 11.81351347804552, 12.763212525303702, 11.84139649886509, 10.977103239745333, 10.11139809514667, 10.9444411392938, 11.77601222988696, 12.582441438525118, 12.622806784895669, 11.689640021779045, 10.784825427354766, 10.11365086360315, 10.856177665331757, 11.794693585345227, 12.700641971599778, 13.535324570695302, 14.487670021325076, 15.441663349326648, 10.674670132018557, 11.708872874876953, 12.691739676923964, 13.654174972953493, 12.792168491065343, 12.040340299846644, 11.1139244849738, 11.978395001011974, 12.78151883364724, 12.479495241361299, 11.563445720498427, 10.750305806588866, 9.804621593874575, 9.083981224037716, 9.930088255159617, 10.826865849279729, 11.737727920506426, 12.592307039853104, 13.53641473393303, 14.518434772642074, 11.594429932618688, 12.667143357479596, 13.621783855073478, 14.592434257868206, 13.826500138637636, 12.972939164594314, 12.12506258365619, 13.02903556123172, 12.53252441424685, 11.539472595183783, 10.58434402931618, 9.737420706443448, 8.84305629978643, 8.12704432902538, 8.904213992168243, 9.807184933157341, 10.760635815496244, 11.625075512195798, 12.581739311894916, 13.507122538006923, 12.658956480493893, 13.60813972454444, 14.622386870124224, 15.547516073621969, 14.84340029851758, 14.020347886732846, 13.097169619094135, 12.639901197258446, 11.575830566487387, 10.633764862947336, 9.65114241315153, 8.71322126244867, 7.840090420134703, 7.055499835854068, 7.9099927487316535, 8.85024070179, 9.70526145420895, 10.658195275440836, 11.650940250271672, 12.51447689422036, 13.51197351527179, 14.548483834709419, 15.5811223383602, 15.417715070040547, 14.388602753807149, 13.454466804629213, 12.541612494161134, 11.625836288694671, 10.651818943882857, 9.659952880368651, 8.628236652980746, 7.705749610398471, 6.824326918034868, 6.069401525128554, 6.888170594231054, 7.873492375923256, 8.756116291089798, 9.66421758133849, 10.654111551129636, 11.587217455493263, 14.459106908636485, 15.424751885854667, 15.45108774901151, 14.462268061492319, 13.457261501754303, 12.526968352223975, 11.54558736218501, 10.652761731628257, 9.6869522593312, 8.703494894158815, 7.682286580526884, 6.7169387976661845, 5.826619786152423, 5.097514043465876, 5.892272274021146, 6.879773028953247, 7.762246490176753, 8.655609548463875, 9.716846476072101, 10.627904233444221, 15.453263136101764, 15.49065678517365, 14.463660177149862, 13.515783933052848, 12.464116718387283, 11.519919832339513, 10.545725519373084, 9.586176924852346, 8.629785398868387, 7.668876117422211, 6.716330030418817, 5.780859900563206, 4.836592763149098, 4.132921633224369, 4.96553445204053, 5.812133553368428, 6.7269390738473085, 7.668995576004759, 8.668552966764423, 9.600750641356084, 15.672368136009656, 14.611132288475586, 13.664961698859727, 12.66739887419755, 11.71019292636215, 10.714972047213262, 9.725149050243418, 8.713825047237584, 7.721431399468812, 6.709479138645538, 5.779628125428438, 4.8387090352498365, 3.845564236406605, 3.1038135499682666, 3.899456851179639, 4.808402782911036, 5.774065335109921, 6.789317694232581, 7.768995741852994, 8.773490523549276, 14.828654784977314, 13.767771373298645, 12.726392129877356, 11.70760822811176, 10.711245608878777, 9.745390484720996, 8.790557234808004, 7.817199392644523, 6.784049921939449, 5.900564196385566, 4.836383111276365, 3.8003218500547495, 2.804899246008203, 2.103763683748352, 2.888140838461608, 3.8446463787335707, 4.853005041676237, 5.8172670912934485, 6.799310336028027, 7.858021876037373, 13.795006610905277, 12.819016363962875, 11.887949637963295, 10.897294696629203, 9.937055090083206, 8.907280689885104, 7.880128722646698, 6.833349685788903, 5.84049094896327, 4.895441657190325, 3.8478024176621286, 2.808116868828904, 1.862948154248936, 1.0546100904254099, 1.9463938605550593, 2.9861164193186402, 3.9516500456131474, 4.967938874589397, 6.035462203886072, 7.067966230346843, 12.883729149384875, 11.86959072626394, 10.918623399703867, 9.972669427190693, 8.960355678144477, 7.9756788342946265, 6.93135315285827, 5.972168921641054, 4.999775030260965, 4.019357594217517, 2.9452848412320263, 1.9013518784081533, 0.9315941082568892, 0.0, 0.9726030031779322, 2.0380005198077615, 2.9832107537212216, 4.039894090364432, 5.041081574905804, 6.104520055005607, 13.51937236515907, 12.545785464560463, 11.606500270347622, 10.678895448328866, 9.69619978582455, 8.712384197760555, 7.745555511176627, 6.7764136478238175, 5.760630281855945, 4.736678356018687, 3.793907587950895, 2.8149166270217862, 1.8666424202343237, 1.065547044795311, 2.040642250869362, 3.0290085630799677, 3.94162679687169, 4.950514838438304, 6.011473566523348, 6.998028555619554, 14.489324203700459, 13.56149663692572, 12.599959355632318, 11.649350219944122, 10.70454241020516, 9.630858110502187, 8.665015536955888, 7.695524287027997, 6.697699231480113, 5.663282708864242, 4.75959804036767, 3.8335663134673412, 2.8590743080113357, 2.1374345535239136, 3.077219681385351, 4.0319664618369035, 4.9224710729640195, 5.902215771999542, 6.937081808756522, 7.878252219949758, 15.417009837334636, 14.531217904166214, 13.57302112789338, 12.590903520922039, 11.654297088430177, 10.580002688824857, 9.622688077645064, 8.660784383452574, 7.710954522250253, 6.734979989244844, 5.8073231528010885, 4.8362536913314855, 3.906476592097653, 3.1444072923577573, 4.049441836447986, 5.02852189879656, 5.943441830998764, 6.953421822028194, 7.904614157179399, 8.939899083171445], [8.923519966874204, 7.944764073130375, 6.913868065246328, 5.958871515730029, 5.008165225313802, 4.084410281213293, 5.038693167821225, 5.8459443164211775, 6.791650954059899, 7.744060036082406, 8.746842913326285, 9.63454104648493, 10.564520731705976, 11.536037261805959, 12.479393482456192, 13.488716477489554, 14.540502810819916, 15.469706983691287, 16.488175355479694, 17.3738850660191, 7.892580980300254, 8.849874814670267, 7.921344676114035, 6.931352704872313, 6.031290524714498, 5.058239424783341, 6.070672861025131, 6.875069660808017, 7.720104393037659, 8.680669720816782, 9.61309930185791, 10.54591743567117, 11.558877797307597, 12.533228567803732, 13.527049023397634, 14.49481985016228, 15.559212352783549, 16.525291193254237, 17.48485732844609, 16.418128335082763, 6.964077959335728, 7.909805965162679, 8.913452142038748, 7.959174361554604, 7.001078779934788, 6.056257234762376, 7.065811420463296, 7.8898873314533455, 8.702013015746212, 9.698475945761626, 10.632844255212508, 11.51132505031427, 12.548448354761192, 13.51819003886416, 13.919722902602949, 14.798264256955898, 15.611197038316062, 16.535596590902728, 16.515893190658986, 15.518744848280077, 6.07270661310407, 7.041789948255182, 8.086095385060089, 8.973793184761558, 8.047806922075978, 7.05463378986124, 8.011524902800916, 8.938272026487626, 9.75353854393189, 10.676387608601656, 11.658313264370763, 12.473471587189563, 13.522287739468668, 13.72610166662708, 12.855908712683242, 13.743240563893087, 14.673925943439691, 15.497742058429067, 15.869903115867086, 14.891242334044895, 7.004142295028177, 7.974395317177966, 8.910090581451698, 9.921328613601787, 9.008662451827577, 8.094608774244902, 8.97846201118107, 9.887456105937245, 10.7629012394742, 11.690882218636144, 12.587879093447574, 13.426274701474915, 13.63574440965462, 12.770944386323267, 11.804880843372327, 12.786606863806513, 13.744667714120885, 14.423579032415239, 15.394014119713217, 15.79279317991739, 7.849846095780909, 8.86368642614479, 9.845710728497359, 10.801604368809448, 9.948068642894631, 9.083685750633116, 9.931375420274083, 10.907247553026615, 11.804064116477933, 12.628661437268608, 13.586826649728566, 13.720818428714793, 12.686744591856439, 11.826536614352932, 10.877443975404674, 11.776416538731274, 12.711915645979232, 13.487740372397052, 14.431179081216793, 15.457498964369899, 8.805018376722721, 9.844652584640507, 10.84091047486759, 11.790609522125772, 10.892808173471709, 10.028514914351952, 10.88764388121042, 11.854502482076203, 12.748615233064893, 13.555044441703052, 13.595409788073603, 12.662243024956979, 11.740138047815341, 10.843809557037716, 9.883574662153825, 10.822090582167295, 11.728038968421846, 12.562721567517368, 13.515067018147143, 14.469060346148714, 9.702067128840623, 10.736269871699019, 11.71913667374603, 12.68157196977556, 11.843580165671963, 11.091751974453263, 11.890170271037551, 12.866254260224661, 13.754121836825172, 13.45209824453923, 12.536048723676357, 11.7229088097668, 10.75993421433515, 9.847761952349241, 8.957485251981685, 9.854262846101797, 10.765124917328494, 11.61970403667517, 12.563811730755097, 13.54583176946414, 10.621826929440754, 11.694540354301662, 12.649180851895544, 13.619831254690272, 12.877911813244255, 12.024350839200933, 12.90130836971994, 13.871553490775568, 13.50512741742478, 12.512075598361713, 11.55694703249411, 10.710023709621382, 9.798368920247004, 8.890825057336906, 7.931610988990311, 8.834581929979409, 9.788032812318312, 10.652472509017864, 11.609136308716982, 12.53451953482899, 11.68635347731596, 12.635536721366506, 13.64978386694629, 14.574913070444035, 13.894811973124199, 13.071759561339466, 13.873415405157886, 13.612504200436376, 12.548433569665317, 11.606367866125266, 10.623745416329461, 9.685824265626604, 8.795403040595279, 7.819280564165593, 6.9373897455537215, 7.877637698612067, 8.732658451031016, 9.685592272262902, 10.67833724709374, 11.541873891042426, 12.539370512093857, 13.575880831531485, 14.608519335182267, 15.547585976657329, 14.830102519009179, 14.073004125028483, 13.514215497339066, 12.598439291872603, 11.624421947060789, 10.632555883546583, 9.600839656158676, 8.678352613576404, 7.7969299212128, 6.8331822534400795, 5.915567591053122, 6.900889372745324, 7.783513287911865, 8.691614578160557, 9.681508547951704, 10.61461445231533, 13.486503905458552, 14.452148882676733, 15.44000736569394, 15.43487106467025, 14.429864504932235, 13.499571355401908, 12.518190365362942, 11.625364734806189, 10.659555262509132, 9.676097897336748, 8.654889583704815, 7.6895418008441165, 6.799222789330355, 5.861294771777401, 4.919669270843214, 5.907170025775315, 6.78964348699882, 7.683006545285942, 8.744243472894167, 9.655301230266288, 14.48066013292383, 15.378309079434871, 15.436263180327796, 14.488386936230782, 13.436719721565215, 12.492522835517445, 11.518328522551016, 10.558779928030278, 9.60238840204632, 8.641479120600144, 7.688933033596749, 6.753462903741138, 5.80919576632703, 4.926164026575729, 3.9929314488625978, 4.839530550190496, 5.754336070669376, 6.696392572826826, 7.695949963586489, 8.62814763817815, 15.491124752042813, 15.583735291653516, 14.637564702037658, 13.64000187737548, 12.682795929540081, 11.687575050391192, 10.697752053421349, 9.686428050415515, 8.694034402646743, 7.68208214182347, 6.75223112860637, 5.811312038427769, 4.818167239584537, 3.8970559433196272, 2.9268538480017066, 3.835799779733103, 4.8014623319319885, 5.816714691054648, 6.7963927386750616, 7.800887520371344, 15.801257788155244, 14.740374376476575, 13.698995133055286, 12.68021123128969, 11.683848612056707, 10.717993487898926, 9.763160237985934, 8.789802395822454, 7.756652925117381, 6.873167199563498, 5.808986114454297, 4.772924853232682, 3.777502249186135, 2.972981755549087, 1.9155378352836758, 2.8720433755556383, 3.880402038498305, 4.8446640881155165, 5.826707332850095, 6.885418872859441, 14.76760961408321, 13.791619367140807, 12.860552641141227, 11.869897699807137, 10.90965809326114, 9.879883693063036, 8.85273172582463, 7.805952688966835, 6.813093952141202, 5.868044660368257, 4.820405420840061, 3.7807198720068365, 2.835551157426868, 1.9328880089643026, 0.9737908573771271, 2.0135134161407082, 2.9790470424352153, 3.9953358714114646, 5.06285920070814, 6.095363227168911, 13.856332152562807, 12.842193729441872, 11.891226402881799, 10.945272430368625, 9.93295868132241, 8.948281837472559, 7.903956156036202, 6.944771924818986, 5.972378033438897, 4.991960597395449, 3.9178878444099583, 2.8739548815860854, 1.9041971114348213, 0.9726030031779322, 0.0, 1.0653975166298295, 2.0106077505432896, 3.0672910871865, 4.068478571727872, 5.131917051827675, 14.491975368337004, 13.518388467738397, 12.579103273525556, 11.6514984515068, 10.668802789002484, 9.684987200938489, 8.71815851435456, 7.749016651001751, 6.733233285033878, 5.70928135919662, 4.766510591128828, 3.7875196301997187, 2.839245423412256, 2.038150047973243, 1.0680392476914295, 2.0564055599020357, 2.969023793693758, 3.977911835260372, 5.038870563345416, 6.025425552441622, 15.461927206878393, 14.534099640103653, 13.572562358810252, 12.621953223122055, 11.677145413383094, 10.603461113680119, 9.63761854013382, 8.668127290205929, 7.670302234658045, 6.635885712042175, 5.732201043545603, 4.806169316645274, 3.831677311189268, 3.068416483853409, 2.1286313559919714, 3.0593634586589715, 3.9498680697860875, 4.92961276882161, 5.96447880557859, 6.905649216771826, 16.38961284051257, 15.503820907344148, 14.545624131071314, 13.563506524099973, 12.62690009160811, 11.552605692002789, 10.595291080822996, 9.633387386630506, 8.683557525428185, 7.707582992422777, 6.779926155979021, 5.808856694509418, 4.879079595275586, 4.052652163062829, 3.1008535110546065, 4.055918895618628, 4.970838827820832, 5.980818818850262, 6.932011154001467, 7.967296079993513], [7.858122450244375, 6.879366556500545, 5.848470548616499, 4.893473999100199, 3.942767708683973, 4.949330333180765, 5.9036132197886975, 6.891419245720816, 7.838270043253466, 8.790679125275972, 9.812240429956114, 10.69993856311476, 11.629918248335805, 12.601434778435788, 13.544790999086022, 14.554113994119383, 15.605900327449746, 16.53510450032112, 17.553572872109527, 18.43928258264893, 6.8271834636704245, 7.7844772980404375, 6.855947159484206, 5.865955188242483, 4.965893008084668, 5.923159476750814, 6.935592912992604, 7.920544590107656, 8.766723482231226, 9.72728881001035, 10.659718391051477, 11.592536524864737, 12.624275313937426, 13.598626084433562, 14.592446540027463, 15.00595720496338, 15.78563862246193, 16.751717462932618, 17.601875825058553, 17.483525851712592, 5.898680442705898, 6.84440844853285, 7.848054625408919, 6.8937768449247745, 5.935681263304959, 6.917338389384751, 7.930731472430768, 8.906159963657121, 9.74863210493978, 10.745095034955192, 11.679463344406074, 12.557944139507837, 13.59506744395476, 14.58358755549399, 14.920672419592545, 14.066558616528201, 14.814364997819247, 15.726155330124675, 16.563207817110992, 16.58414236490991, 5.00730909647424, 5.976392431625352, 7.0206978684302594, 7.908395668131729, 6.997254417587969, 7.915714944483615, 8.872606057423292, 9.901640433062063, 10.800157633125458, 11.723006697795222, 12.70493235356433, 13.52009067638313, 14.568906828662236, 14.727051183616677, 13.856858229672838, 13.01153492346539, 13.877093902942876, 14.688300797651014, 15.59771563588861, 15.956639850674724, 5.938744778398347, 6.9089978005481365, 7.844693064821868, 8.855931096971958, 7.958109947339569, 8.955689928867278, 9.839543165803446, 10.769111424587562, 11.779777901928421, 12.73750130782971, 13.63449818264114, 14.472893790668483, 14.636693926644213, 13.771893903312863, 12.805830360361924, 12.054901223378817, 12.939598179187373, 13.614137771637186, 14.584572858935164, 15.51531717838903, 6.897665216024069, 7.91150554638795, 8.784441356601956, 9.740334996914045, 8.897516138406623, 9.92240317150644, 10.792456574896459, 11.76832870764899, 12.734916530417435, 13.675280526462174, 14.633445738922132, 14.72940100250606, 13.687694108846031, 12.827486131342527, 11.878393492394268, 10.981731229285765, 11.90684611104572, 12.678299111619, 13.62173782043874, 14.648057703591846, 7.852837496965881, 8.892471704883667, 9.779641102972187, 10.72934015023037, 9.8422556689837, 10.847473486382313, 11.748725035832797, 12.715583636698579, 13.679467647004394, 14.601663530896618, 14.60399236186487, 13.670825598748246, 12.741087564804934, 11.84475907402731, 10.884524179143419, 10.027405272721786, 10.922969433488333, 11.753280306739315, 12.70562575736909, 13.659619085370661, 8.811048683821552, 9.845251426679948, 10.730015646192237, 11.692450942221766, 10.793027661183954, 11.776326891205574, 12.712417495141565, 13.688501484328675, 14.684974250764673, 14.517495761169059, 13.601446240306187, 12.731491383558067, 11.760883731324743, 10.848711469338836, 9.95843476897128, 9.059577536656288, 9.960055382394982, 10.810262775897117, 11.754370469977044, 12.65481332444507, 9.730808484421685, 10.803521909282592, 11.66005982434175, 12.630710227136479, 11.827359308756247, 12.708925755953244, 13.723555593823955, 14.693800714879583, 14.57052493405461, 13.577473114991543, 12.62234454912394, 11.733338059634022, 10.799318437236598, 9.8917745743265, 8.932560505979906, 8.0398966205339, 8.9829632773848, 9.84303124823981, 10.799695047938929, 11.64350108980992, 10.79533503229689, 11.744518276347437, 12.673022106742442, 13.585792042890242, 12.84425946863619, 13.756334478091777, 14.6956626292619, 14.677901717066206, 13.613831086295146, 12.671765382755096, 11.68914293295929, 10.751221782256433, 9.796352557584873, 8.820230081155188, 7.938339262543316, 7.082952389166558, 7.923217190252963, 8.876151011484849, 9.868895986315685, 10.650855446023357, 11.648352067074788, 12.684862386512416, 13.717500890163198, 14.558464949103536, 13.77955001452117, 14.713685963699106, 14.579613013968896, 13.663836808502433, 12.689819463690618, 11.697953400176413, 10.666237172788506, 9.743750130206234, 8.79989606341366, 7.834131770429673, 6.916517108042717, 6.106204063299815, 6.974072027133811, 7.882173317382503, 8.87206728717365, 9.72359600729626, 12.595485460439482, 13.561130437657663, 14.548988920674871, 15.606627799612966, 14.74729777973341, 14.564968872031738, 13.583587881992772, 12.690762251436018, 11.724952779138961, 10.741495413966577, 9.720287100334644, 8.754939317473946, 7.864620305960185, 6.862244288766995, 5.920618787832808, 5.112484716329806, 5.980202226220766, 6.8735652845078885, 7.853225027875098, 8.764282785247218, 13.589641687904761, 14.487290634415801, 15.51428724243959, 15.553784452860612, 14.502117238195044, 13.557920352147274, 12.583726039180846, 11.624177444660107, 10.667785918676149, 9.706876637229973, 8.754330550226578, 7.818860420370967, 6.87459328295686, 5.984992327505703, 4.993880965852192, 4.044845240744987, 4.944894809891322, 5.886951312048772, 6.804931518567419, 7.73712919315908, 14.641843682935122, 15.543949991759161, 15.702962218667487, 14.70539939400531, 13.74819344616991, 12.752972567021022, 11.763149570051178, 10.751825567045344, 9.759431919276572, 8.7474796584533, 7.8176286452362, 6.876709555057598, 5.8835647562143665, 4.955884244249601, 3.98568214893168, 3.041114470287595, 3.9920210711539346, 4.916326295094896, 5.8442118589182215, 6.848706640614504, 15.595669570152726, 15.805771893106405, 14.764392649685115, 13.745608747919519, 12.749246128686536, 11.783391004528756, 10.828557754615764, 9.855199912452283, 8.82205044174721, 7.938564716193327, 6.874383631084126, 5.838322369862511, 4.8428997658159645, 4.038379272178917, 2.9809353519135056, 2.07735806611013, 2.9282211587414655, 3.8924832083586764, 4.874526453093255, 5.933237993102601, 15.833007130713039, 14.857016883770637, 13.925950157771057, 12.935295216436966, 11.975055609890969, 10.945281209692865, 9.918129242454459, 8.871350205596665, 7.878491468771031, 6.933442176998087, 5.88580293746989, 4.8461173886366655, 3.9009486740566977, 2.9982855255941323, 2.0391883740069567, 1.0403916297862479, 1.9136495258053858, 2.929938354781635, 3.997461684078311, 5.029965710539082, 14.921729669192636, 13.907591246071702, 12.956623919511628, 12.010669946998455, 10.998356197952239, 10.013679354102388, 8.969353672666031, 8.010169441448815, 7.0377755500687265, 6.057358114025279, 4.983285361039788, 3.939352398215915, 2.969594628064651, 2.0380005198077615, 1.0653975166298295, 0.0, 0.94521023391346, 2.0018935705566703, 3.0030810550980425, 4.066519535197846, 15.557372884966833, 14.583785984368227, 13.644500790155385, 12.71689596813663, 11.734200305632314, 10.750384717568318, 9.78355603098439, 8.81441416763158, 7.798630801663707, 6.774678875826449, 5.831908107758657, 4.852917146829548, 3.9046429400420855, 3.079914335279632, 2.0250588699422245, 0.9910080432722064, 1.9036262770639283, 2.9125143186305427, 3.9734730467155863, 4.960028035811792, 16.527324723508222, 15.599497156733483, 14.637959875440082, 13.687350739751885, 12.742542930012924, 11.668858630309948, 10.70301605676365, 9.733524806835758, 8.735699751287875, 7.701283228672004, 6.797598560175432, 5.871566833275104, 4.877152240488907, 3.933336535820881, 2.9935514079594436, 1.9939659420291425, 2.884470553156258, 3.8642152521917805, 4.899081288948761, 5.840251700141996, 17.4550103571424, 16.56921842397398, 15.611021647701143, 14.628904040729802, 13.69229760823794, 12.618003208632619, 11.660688597452825, 10.698784903260336, 9.748955042058014, 8.772980509052607, 7.845323672608851, 6.855475783702985, 5.924554524575225, 4.917572215030303, 3.965773563022079, 2.990521378988799, 3.9054413111910025, 4.915421302220432, 5.866613637371637, 6.901898563363684], [6.9129122163309145, 5.934156322587085, 4.903260314703039, 3.9482637651867396, 4.887977942597433, 5.894540567094225, 6.848823453702157, 7.836629479634277, 8.783480277166927, 9.735889359189432, 10.757450663869573, 11.645148797028218, 12.575128482249264, 13.546645012349247, 14.49000123299948, 15.499324228032842, 15.877128199376822, 16.806332372248193, 17.706166456029386, 18.60147879145981, 5.881973229756965, 6.839267064126978, 5.910736925570746, 4.920744954329024, 5.911103241998129, 6.868369710664274, 7.8808031469060635, 8.865754824021117, 9.711933716144687, 10.67249904392381, 11.604928624964938, 12.537746758778198, 13.569485547850885, 14.54383631834702, 15.537656773940922, 15.855967709168302, 14.84042838854847, 15.806507229019157, 16.656665591145092, 17.542236915160025, 4.953470208792438, 5.899198214619389, 6.902844391495458, 5.948566611011314, 6.880891497218419, 7.862548623298212, 8.875941706344229, 9.851370197570581, 10.69384233885324, 11.690305268868652, 12.624673578319534, 13.503154373421298, 14.54027767786822, 15.528797789407449, 15.83353062806415, 14.916569120733124, 13.869154763905787, 14.780945096211214, 15.617997583197534, 16.594000500843098, 4.062098862560781, 5.0311821977118925, 6.0754876345168, 6.963185434218269, 7.94246465150143, 8.860925178397077, 9.817816291336753, 10.846850666975524, 11.745367867038919, 12.668216931708683, 13.65014258747779, 14.465300910296591, 15.514117062575696, 15.639909392088281, 14.769716438144442, 13.86256904857602, 12.931883669029416, 13.743090563737553, 14.65250540197515, 15.553399728121981, 4.993534544484888, 5.963787566634677, 6.899482830908409, 7.910720863058498, 8.90332018125303, 9.900900162780738, 10.784753399716907, 11.714321658501023, 12.724988135841881, 13.68271154174317, 14.5797084165546, 15.418104024581943, 15.549552135115821, 14.684752111784467, 13.718688568833528, 12.909323017612625, 11.994387945273912, 12.668927537723725, 13.639362625021704, 14.570106944475569, 5.952454982110609, 6.96629531247449, 7.839231122688496, 8.795124763000585, 9.816812391789275, 10.841699424889093, 11.73766680880992, 12.713538941562451, 13.680126764330895, 14.620490760375635, 15.578655972835593, 15.642259210977668, 14.60055231731764, 13.740344339814133, 12.791251700865875, 11.836153023519573, 10.96163587713226, 11.733088877705539, 12.67652758652528, 13.702847469678385, 6.9076272630524205, 7.947261470970207, 8.834430869058727, 9.784129916316909, 10.761551922366353, 11.766769739764966, 12.691857691269664, 13.658716292135447, 14.624677880917854, 15.546873764810078, 15.516850570336478, 14.583683807219854, 13.653945773276542, 12.757617282498916, 11.797382387615025, 10.881827066955594, 9.977759199574873, 10.808070072825855, 11.76041552345563, 12.7144088514572, 7.865838449908093, 8.90004119276649, 9.784805412278777, 10.747240708308306, 11.712323914566607, 12.695623144588227, 13.631713748524218, 14.607797737711328, 15.621560108570904, 15.46270599508252, 14.546656474219647, 13.644349592029675, 12.67374193979635, 11.761569677810442, 10.871292977442886, 9.913999330890096, 9.014845148481522, 9.865052541983657, 10.809160236063583, 11.70960309053161, 8.785598250508224, 9.858311675369132, 10.71484959042829, 11.685499993223019, 12.723284181145077, 13.628222009335897, 14.642851847206607, 15.613096968262235, 15.51573516796807, 14.522683348905003, 13.5675547830374, 12.646196268105628, 11.712176645708205, 10.804632782798107, 9.845418714451512, 8.894318414767708, 8.037753043471339, 8.89782101432635, 9.854484814025469, 10.69829085589646, 9.85012479838343, 10.799308042433976, 11.727811872828982, 12.640581808976782, 13.689264905930312, 14.674679338446698, 15.614958882644553, 15.623111950979666, 14.559041320208607, 13.616975616668556, 12.634353166872751, 11.696432016169894, 10.70921076605648, 9.733088289626794, 8.851197471014922, 7.937374183400366, 6.978006956339502, 7.930940777571388, 8.923685752402225, 9.705645212109896, 10.703141833161327, 11.739652152598955, 12.772290656249737, 13.613254715190076, 14.624555451815292, 15.558691400993228, 15.524823247882356, 14.609047042415893, 13.635029697604079, 12.643163634089873, 11.611447406701966, 10.688960364119694, 9.712754271885267, 8.74698997890128, 7.829375316514323, 6.960625857533623, 6.028861793220352, 6.936963083469044, 7.92685705326019, 8.7783857733828, 11.650275226526022, 12.615920203744203, 13.60377868676141, 14.661417565699505, 15.592303217027531, 15.510179105945198, 14.528798115906232, 13.635972485349479, 12.670163013052422, 11.686705647880038, 10.665497334248105, 9.700149551387407, 8.809830539873646, 7.775102497238601, 6.833476996304414, 5.966906510563614, 5.034991992307306, 5.928355050594429, 6.908014793961637, 7.819072551333758, 12.6444314539913, 13.542080400502341, 14.56907700852613, 15.516953252623143, 15.447327472108505, 14.503130586060735, 13.528936273094306, 12.569387678573568, 11.61299615258961, 10.652086871143434, 9.699540784140039, 8.764070654284428, 7.81980351687032, 6.899003849166245, 5.906739174323798, 4.957703449216593, 3.999684575977862, 4.941741078135313, 5.8597212846539595, 6.791918959245621, 13.696633449021661, 14.598739757845701, 15.521647737466429, 15.65060962791877, 14.693403680083371, 13.698182800934482, 12.708359803964639, 11.697035800958805, 10.704642153190033, 9.69268989236676, 8.76283887914966, 7.8219197889710586, 6.828774990127827, 5.869895765910143, 4.899693670592222, 3.9551259919481367, 3.046810837240475, 3.971116061181436, 4.899001625004762, 5.903496406701044, 14.650459336239265, 15.653631758944723, 15.709602883598576, 14.69081898183298, 13.694456362599997, 12.728601238442216, 11.773767988529224, 10.800410146365744, 9.76726067566067, 8.883774950106787, 7.819593864997587, 6.783532603775972, 5.788109999729425, 4.983589506092377, 3.9261455858269656, 2.991369587770672, 1.9830109248280055, 2.947272974445217, 3.9293162191797957, 4.9880277591891415, 15.59529051030975, 15.802227117684097, 14.871160391684517, 13.880505450350427, 12.92026584380443, 11.890491443606326, 10.86333947636792, 9.816560439510125, 8.823701702684492, 7.878652410911547, 6.831013171383351, 5.791327622550126, 4.846158907970158, 3.9434957595075923, 2.984398607920417, 1.985601863699708, 0.9684392918919259, 1.984728120868175, 3.0522514501648503, 4.084755476625621, 15.866939903106097, 14.852801479985162, 13.901834153425089, 12.955880180911915, 11.9435664318657, 10.958889588015849, 9.914563906579492, 8.955379675362275, 7.982985783982187, 7.002568347938739, 5.928495594953248, 4.884562632129375, 3.9148048619781113, 2.983210753721222, 2.0106077505432896, 0.94521023391346, 0.0, 1.0566833366432105, 2.057870821184583, 3.121309301284386, 16.502583118880295, 15.528996218281687, 14.589711024068846, 13.66210620205009, 12.679410539545774, 11.695594951481779, 10.72876626489785, 9.75962440154504, 8.743841035577166, 7.719889109739908, 6.777118341672116, 5.798127380743008, 4.8498531739555455, 4.025124569193092, 2.970269103855684, 1.9362182771856664, 0.9584160431504684, 1.9673040847170826, 3.0282628128021263, 4.014817801898332, 17.472534957421686, 16.544707390646938, 15.583170109353539, 14.632560973665342, 13.68775316392638, 12.614068864223407, 11.648226290677108, 10.678735040749217, 9.680909985201334, 8.646493462585463, 7.742808794088892, 6.816777067188563, 5.822362474402367, 4.878546769734341, 3.9387616418729037, 2.9391761759426025, 1.9392603192427982, 2.9190050182783205, 3.953871055035301, 4.895041466228537, 18.400220591055863, 17.514428657887432, 16.5562318816146, 15.574114274643259, 14.637507842151397, 13.563213442546077, 12.605898831366284, 11.643995137173794, 10.694165275971473, 9.718190742966065, 8.79053390652231, 7.800686017616446, 6.869764758488685, 5.862782448943761, 4.910983796935539, 3.9357316129022593, 2.9602310772775424, 3.970211068306972, 4.921403403458177, 5.956688329450224], [5.943843682726861, 4.996154542838795, 4.056776806593, 5.004947101829949, 5.944661279240643, 6.951223903737435, 7.905506790345367, 8.893312816277486, 9.840163613810137, 10.792572695832643, 11.814134000512784, 12.701832133671429, 13.631811818892475, 14.603328348992457, 15.546684569642691, 16.55600756467605, 16.581257257055277, 15.988844331452654, 16.788889881002586, 17.684202216433007, 4.893753702693277, 5.85104753706329, 5.096942459273775, 5.977428290972234, 6.967786578641339, 7.925053047307483, 8.937486483549273, 9.922438160664326, 10.768617052787897, 11.729182380567021, 12.661611961608148, 13.594430095421409, 14.626168884494096, 15.600519654990231, 16.59434011058413, 16.560096766846762, 15.544557446226927, 14.931186349352243, 15.739389016118292, 16.62496034013322, 3.932332950131493, 4.8780609559584445, 5.881707132834514, 6.912198190424295, 7.937574833861629, 8.919231959941422, 9.932625042987437, 10.90805353421379, 11.750525675496451, 12.746988605511863, 13.681356914962745, 14.559837710064508, 15.59696101451143, 16.58548112605066, 16.556555292141528, 15.620698178411581, 14.573283821584244, 13.863668521184414, 14.700721008170733, 15.676723925816296, 3.0054155259175706, 3.9744988610686818, 5.018804297873589, 6.078403564254035, 7.131771878509669, 8.124945010724407, 9.081836123664083, 10.110870499302854, 11.149163185898242, 12.107344246029195, 13.151101824490908, 14.200260146767231, 15.249076299046337, 16.295744258814896, 15.49274110222182, 14.566698106254478, 13.636012726707873, 12.825813988710753, 13.73522882694835, 14.63612315309518, 3.9368512078416775, 4.907104229991467, 5.842799494265199, 6.871410513013804, 7.9305640264679385, 8.986778163351357, 10.048773232044237, 10.978341490828353, 11.989007968169211, 13.041957353722353, 14.074535437810294, 15.131692982116165, 16.15909061236162, 15.624906227278396, 14.658842684327457, 13.752068231801035, 12.69851700295237, 11.751650962696925, 12.722086049994903, 13.652830369448768, 4.921199961713054, 5.910551792093942, 6.782547786045286, 7.738441426357375, 8.760129055146065, 9.785016088245882, 10.832548823084926, 11.808420955837457, 12.775008778605901, 13.717735727508325, 14.680142642132898, 15.615040675777545, 15.550439649548348, 14.68049845530806, 13.731405816359802, 12.768195611470436, 11.816237071210459, 10.815812302678738, 11.75925101149848, 12.753706544244276, 5.876372242654865, 6.9160064505726515, 7.777747532415517, 8.7274465796737, 9.704868585723142, 10.710086403121755, 11.635174354626454, 12.602032955492236, 13.5970712055727, 14.644118731942768, 15.676353144476014, 15.533571139450563, 14.60383310550725, 13.697771397992843, 12.737536503108952, 11.813869654906457, 10.889846248614237, 9.890793497799054, 10.843138948428829, 11.76526792602309, 6.860926456673566, 7.872644436339758, 8.728122075635566, 9.690557371665095, 10.655640577923396, 11.638939807945016, 12.575030411881007, 13.551114401068117, 14.564876771927693, 15.506021731367515, 15.510676143557092, 14.594236924260384, 13.62362927202706, 12.711457010041151, 11.811447092936813, 10.846041918840958, 9.926932197520886, 8.947775966956856, 9.891883661036783, 10.747198041334487, 7.823193201311101, 8.843323706330784, 9.65816625378508, 10.628816656579808, 11.666600844501867, 12.571538672692686, 13.586168510563397, 14.556413631619025, 15.543404571757295, 15.486703018242448, 14.531574452374844, 13.596083600336337, 12.662063977938914, 11.754520115028816, 10.785572829945439, 9.82636100271857, 8.949840092510703, 7.980544439299549, 8.937208238998666, 9.735885806699336, 8.887719749186305, 9.836902993236851, 10.67112853618577, 11.583898472333571, 12.632581569287101, 13.617996001803487, 14.558275546001342, 15.560890723561604, 15.543903731046916, 14.601838027506865, 13.61921557771106, 12.655305417841927, 11.659098098287188, 10.682975621857503, 9.801084803245631, 8.86941677135123, 7.901252403343335, 7.013664202544588, 7.989460080318034, 8.743240162912773, 9.740736783964204, 10.777247103401832, 11.743923044175736, 12.556571378546865, 13.567872115172081, 14.502008064350017, 15.472892105678346, 15.665730379059104, 14.69171303424729, 13.650552598966069, 12.596309817540275, 11.647833765791727, 10.662641604115976, 9.696877311131988, 8.779262648745032, 7.892668445484487, 6.9521072402241835, 6.002737411384852, 6.992631381175999, 7.815980724185676, 10.687870177328898, 11.65351515454708, 12.641373637564287, 13.604734229056294, 14.53561988038432, 15.429506516755255, 15.585481452549443, 14.69265582199269, 13.726846349695633, 12.743388984523248, 11.722180670891316, 10.756832888030617, 9.797966546827173, 8.72498982946931, 7.783364328535124, 6.898949098514478, 5.96703458025817, 4.994129378510237, 5.945609744764514, 6.856667502136634, 11.682026404794177, 12.579675351305218, 13.606671959329006, 14.55454820342602, 15.52876466375134, 15.559813922703945, 14.585619609737517, 13.626071015216779, 12.66967948923282, 11.708770207786644, 10.75622412078325, 9.820753990927638, 8.87648685351353, 7.878706620868355, 6.856626506554508, 5.907590781447303, 4.949571908208572, 4.007515406051121, 4.897316235456835, 5.8295139100484965, 12.734228399824538, 13.636334708648578, 14.559242688269306, 15.529974720908857, 15.750087016726582, 14.754866137577693, 13.76504314060785, 12.753719137602015, 11.761325489833244, 10.74937322900997, 9.81952221579287, 8.87860312561427, 7.885458326771037, 6.849598537612254, 5.879396442294333, 4.9348287636502475, 4.026513608942586, 3.0222947336491237, 3.9365965758076378, 4.909389378158543, 13.688054287042142, 14.6912267097476, 15.571343980602283, 15.74750231847619, 14.751139699243208, 13.785284575085425, 12.830451325172433, 11.857093483008953, 10.82394401230388, 9.940458286749998, 8.876277201640796, 7.840215940419181, 6.844793336372635, 5.985021820010156, 4.927577899744745, 3.9710723594727826, 2.962713696530116, 1.9984516469129048, 2.966911169982671, 3.9732856692199254, 14.67801393528295, 15.654004182225352, 15.927843728327726, 14.937188786993634, 13.976949180447637, 12.947174780249535, 11.92002281301113, 10.873243776153334, 9.8803850393277, 8.935335747554756, 7.88769650802656, 6.848010959193336, 5.9028422446133675, 4.988444094328387, 4.029346942741212, 2.989624383977631, 1.9553375115621425, 0.9280447842249647, 1.99556811352164, 3.0280721399824113, 15.671033334577269, 15.909484816628371, 14.958517490068298, 14.012563517555124, 13.000249768508908, 12.015572924659057, 10.9712472432227, 10.012063012005484, 9.039669120625396, 8.059251684581948, 6.985178931596458, 5.941245968772585, 4.971488198621321, 4.039894090364432, 3.0672910871865, 2.0018935705566703, 1.0566833366432105, 0.0, 1.0011874845413724, 2.0646259646411758, 16.62266710574679, 16.585679554924898, 15.646394360712057, 14.7187895386933, 13.736093876188985, 12.75227828812499, 11.78544960154106, 10.81630773818825, 9.800524372220377, 8.776572446383119, 7.833801678315327, 6.854810717386218, 5.906536510598755, 5.0818079058363015, 4.026952440498894, 2.9929016138288764, 2.015099379793679, 1.0624608228572912, 2.010455930509372, 2.993680543237387, 17.58116146833759, 17.60139072729015, 16.63985344599675, 15.689244310308553, 14.744436500569591, 13.670752200866618, 12.704909627320319, 11.735418377392428, 10.737593321844544, 9.703176799228673, 8.799492130732101, 7.873460403831773, 6.879045811045577, 5.935230106377551, 4.9954449785161135, 3.9958595125858123, 2.9959436558860086, 2.066168697131774, 2.965651527971613, 3.9068219391648484, 18.508847101971767, 17.8156804057878, 17.03194060360548, 16.630797611286468, 15.694191178794608, 14.619896779189288, 13.662582168009495, 12.700678473817005, 11.750848612614684, 10.774874079609276, 9.84721724316552, 8.857369354259657, 7.926448095131895, 6.919465785586972, 5.967667133578749, 4.992414949545469, 4.016914413920753, 3.1173747471604254, 3.983401623709887, 4.968468802386536], [4.942656198185489, 3.994967058297423, 4.872808533752294, 5.8278050832685935, 6.897385888537112, 7.944133640950664, 8.898416527558595, 9.886222553490715, 10.833073351023366, 11.785482433045871, 12.815321485054156, 13.703019618212801, 14.632999303433847, 15.60451583353383, 16.54787205418406, 17.557195049217423, 17.472592530235517, 16.88017960463289, 16.066145140562373, 16.784498001920774, 3.892566218151905, 4.849860052521918, 5.806195363657779, 6.796187334899502, 7.829525679290084, 8.902363919118978, 9.914797355360768, 10.915347897877554, 11.761526790001126, 12.72209211778025, 13.654521698821377, 14.587339832634637, 15.627356369035468, 16.6017071395316, 17.595527595125503, 17.451432040026994, 16.435892719407164, 15.822521622532479, 15.016644275678077, 15.725256125620987, 2.93114546559012, 3.8768734714170714, 4.880519648293141, 5.911010705882923, 6.965945657421406, 7.947602783501198, 8.971054442098666, 9.946482933325019, 10.930710016392712, 11.92863550716924, 12.863003816620122, 13.922870297401612, 14.959993601848534, 16.009578162838622, 17.00269551610769, 16.512033451591815, 15.46461909476448, 14.755003794364649, 13.977976267730519, 14.777019711304062, 2.004228041376198, 2.973311376527309, 4.017616813332217, 5.077216079712663, 6.130584393968297, 7.123757526183034, 8.08064863912271, 9.109683014761481, 10.14797570135687, 11.106156761487822, 12.149914339949536, 13.19907266222586, 14.247888814504964, 15.294556774273524, 16.368743754215384, 15.458033379434713, 14.527347999888109, 13.717149261890988, 13.012484086508135, 13.736418938582947, 2.935663723300305, 3.905916745450094, 4.841612009723826, 5.870223028472431, 6.929376541926565, 7.985590678809983, 9.047585747502865, 9.97715400628698, 10.98782048362784, 12.04076986918098, 13.073347953268922, 14.130505497574793, 15.157903127820248, 16.18857203972517, 15.550177957507692, 14.64340350498127, 13.589852276132605, 12.64298623587716, 11.999341309554689, 12.753126154936535, 3.9200124771716816, 4.90936430755257, 5.781360301503913, 6.737253941816002, 7.758941570604692, 8.78382860370451, 9.831361338543553, 10.807233471296085, 11.773821294064529, 12.716548242966953, 13.678955157591526, 14.613853191236172, 15.682433751036086, 15.571833728488295, 14.622741089540037, 13.659530884650671, 12.707572344390694, 11.707147575858974, 11.036506271058265, 11.755683597259134, 4.875184758113493, 5.914818966031279, 6.776560047874144, 7.726259095132327, 8.703681101181768, 9.708898918580381, 10.63398687008508, 11.600845470950862, 12.595883721031324, 13.642931247401396, 14.675165659934642, 15.608332423051266, 15.495168378687486, 14.589106671173079, 13.628871776289188, 12.705204928086692, 11.781181521794474, 10.78212877097929, 10.047514844262162, 10.76724497903795, 5.8597389721321935, 6.871456951798386, 7.726934591094194, 8.689369887123723, 9.654453093382022, 10.637752323403642, 11.573842927339633, 12.549926916526744, 13.56368928738632, 14.50483424682614, 15.511720745023213, 15.48557219744062, 14.514964545207295, 13.602792283221389, 12.702782366117049, 11.737377192021194, 10.818267470701123, 9.839111240137091, 9.039974304220864, 9.749175094349345, 6.825170254325959, 7.842136221789412, 8.656978769243707, 9.627629172038436, 10.665413359960494, 11.570351188151312, 12.584981026022023, 13.55522614707765, 14.54221708721592, 15.444856893003656, 15.422909725555082, 14.487418873516575, 13.553399251119151, 12.645855388209053, 11.676908103125674, 10.717696275898806, 9.84117536569094, 8.871879712479785, 8.08128293672442, 8.737862859714195, 7.889696802201163, 8.83888004625171, 9.669941051644399, 10.582710987792199, 11.631394084745729, 12.616808517262115, 13.557088061459968, 14.55970323902023, 15.525513941600465, 15.493173300687102, 14.510550850891297, 13.546640691022164, 12.550433371467426, 11.57431089503774, 10.692420076425869, 9.760752044531465, 8.79258767652357, 7.904999475724824, 7.018767520518287, 7.745217215927631, 8.742713836979062, 9.77922415641669, 10.742735559634363, 11.555383894005493, 12.566684630630709, 13.500820579808645, 14.471704621136974, 15.439570374210934, 15.594708736827371, 14.541887872146306, 13.487645090720513, 12.539169038971965, 11.553976877296213, 10.588212584312226, 9.67059792192527, 8.784003718664723, 7.84344251340442, 6.894072684565089, 6.021938821376251, 6.817957777200534, 9.689847230343757, 10.655492207561938, 11.643350690579146, 12.603546744514922, 13.534432395842948, 14.428319032213883, 15.467729753113098, 15.613991176549202, 14.648181704252146, 13.664724339079761, 12.629784570149692, 11.664436787288993, 10.689301820007412, 9.616325102649547, 8.67469960171536, 7.790284371694714, 6.858369853438406, 5.885464651690474, 4.947586797779373, 5.858644555151493, 10.684003457809036, 11.581652404320076, 12.608649012343864, 13.556525256440878, 14.527577179209969, 15.435367552098345, 15.50695496429403, 14.547406369773292, 13.591014843789333, 12.630105562343157, 11.677559475339763, 10.742089345484152, 9.797822208070043, 8.773701784338494, 7.747961779734744, 6.79892605462754, 5.8409071813888085, 4.898850679231358, 3.899293288471694, 4.831490963063355, 11.736205452839396, 12.638311761663436, 13.561219741284164, 14.531951773923716, 15.526774515306725, 15.756053622119065, 14.766230625149221, 13.754906622143388, 12.762512974374616, 11.750560713551343, 10.820709700334243, 9.879790610155641, 8.870420356883036, 7.802078358431458, 6.831876263113537, 5.8873085844694515, 4.977500406113191, 3.9622480469905312, 2.9385736288224966, 3.911366431173401, 12.690031340057, 13.693203762762458, 14.573321033617141, 15.491742420009507, 15.75232718378458, 14.7864720596268, 13.831638809713807, 12.858280967550327, 11.825131496845254, 10.94164577129137, 9.877464686182169, 8.841403424960554, 7.845980820914008, 6.93750164082936, 5.880057720563949, 4.923552180291987, 3.91519351734932, 2.950931467732109, 1.9688882229975302, 2.975262722234784, 13.73619446944934, 14.712184716391741, 15.517637812813406, 15.93837627153501, 14.978136664989012, 13.948362264790909, 12.921210297552502, 11.874431260694708, 10.881572523869075, 9.93652323209613, 8.888883992567933, 7.849198443734709, 6.904029729154741, 5.989631578869759, 5.030534427282584, 3.9908118685190033, 2.9565249961035147, 1.929232268766337, 0.9975451665364989, 2.0300491929972697, 14.771329120065035, 15.661610354090676, 15.959704974609672, 15.013751002096498, 14.001437253050282, 13.016760409200431, 11.972434727764075, 11.013250496546858, 10.04085660516677, 9.060439169123322, 7.986366416137831, 6.942433453313958, 5.972675683162694, 5.041081574905805, 4.068478571727873, 3.003081055098043, 2.057870821184583, 1.0011874845413724, 0.0, 1.0634384800998034, 15.722962891234554, 16.688765600795605, 16.64758184525343, 15.719977023234673, 14.737281360730357, 13.753465772666361, 12.786637086082433, 11.817495222729622, 10.801711856761749, 9.777759930924491, 8.834989162856699, 7.855998201927591, 6.907723995140128, 6.0829953903776754, 5.028139925040268, 3.9940890983702495, 3.016286864335051, 2.0636483073986636, 1.009268445968, 1.9924930586960143, 16.681457253825357, 17.73739351164192, 17.64104093053812, 16.690431794849925, 15.745623985110964, 14.67193968540799, 13.706097111861691, 12.7366058619338, 11.738780806385916, 10.704364283770046, 9.800679615273474, 8.874647888373145, 7.871955548258806, 6.92813984359078, 5.988354715729343, 4.9887692497990415, 3.979074779222744, 2.9993300801872214, 1.9644640434302407, 2.9056344546234762, 17.609142887459534, 17.092935665347586, 17.923275876785716, 17.63198509582784, 16.69537866333598, 15.62108426373066, 14.663769652550867, 13.701865958358377, 12.752036097156056, 11.776061564150648, 10.848404727706892, 9.850279091472885, 8.919357832345124, 7.9123755228002, 6.960576870791978, 5.963968486969655, 4.950351623507126, 3.9334064743197197, 2.982214139168515, 3.9672813178451642], [3.945174530059986, 4.761379064483216, 5.779149655476711, 6.73414620499301, 7.803727010261529, 8.844841740972015, 9.799124627579946, 10.79256367521513, 11.73941447274778, 12.691823554770286, 13.734886502542217, 14.701765655607801, 15.631745340828846, 16.60326187092883, 17.546618091579063, 18.555941086612425, 18.381010445166734, 17.788597519564107, 16.81397850243088, 15.858607901011922, 2.873488772706963, 3.818508730804907, 4.774844041940768, 5.7648360131824905, 6.798174357573073, 7.8710125974019665, 8.883446033643757, 9.897862123870542, 10.843163346214768, 11.803728673993891, 12.736158255035019, 13.668976388848279, 14.721715067686283, 15.76848987441927, 16.81501878088247, 17.82761705629867, 17.34431063433838, 16.730939537463694, 15.764477637546586, 14.799366024712137, 1.867706985490317, 2.8134349913172683, 3.817081168193338, 4.847572225783119, 5.902507177321602, 6.884164303401394, 7.907615961998861, 8.883044453225214, 9.867271536292908, 10.865197027069435, 11.799565336520317, 12.859431817301807, 13.89655512174873, 14.946139682738819, 15.939257036007888, 16.95353577853677, 16.373037009695697, 15.663421709295866, 14.725809629599027, 13.851129610395212, 0.9407895612763947, 1.909872896427506, 2.954178333232414, 4.01377759961286, 5.067145913868494, 6.060319046083231, 7.017210159022907, 8.046244534661678, 9.084537221257067, 10.04271828138802, 11.086475859849735, 12.135634182126058, 13.184450334405163, 14.231118294173722, 15.305305274115582, 16.231348270082925, 15.435765914819326, 14.625567176822205, 13.760317448376643, 12.810528837674097, 1.8722252432005018, 2.842478265350291, 3.7781735296240226, 4.806784548372628, 5.865938061826762, 6.9221521987101795, 7.984147267403062, 8.913715526187177, 9.924382003528036, 10.977331389081177, 12.009909473169118, 13.06706701747499, 14.094464647720443, 15.125133559625366, 16.091197102576306, 15.551821419912487, 14.498270191063822, 13.551404150808377, 12.747174671423197, 11.827236054027685, 2.8565739970718784, 3.8459258274527666, 4.71792182140411, 5.673815461716199, 6.6955030905048885, 7.720390123604707, 8.76792285844375, 9.743794991196282, 10.710382813964726, 11.65310976286715, 12.615516677491723, 13.55041471113637, 14.618995270936283, 15.631574874763414, 15.546429067400593, 14.583218862511227, 13.615990259321912, 12.61556549079019, 11.784339632926773, 10.829793496350284, 3.81174627801369, 4.851380485931476, 5.7131215677743405, 6.6628206150325235, 7.640242621081966, 8.64546043848058, 9.570548389985278, 10.53740699085106, 11.532445240931523, 12.579492767301593, 13.611727179834839, 14.544893942951463, 15.56560181497738, 15.512794649033635, 14.552559754149744, 13.628892905947248, 12.689599436725691, 11.690546685910506, 10.79534820613067, 9.8413548781291, 4.796300492032391, 5.808018471698583, 6.663496110994391, 7.625931407023921, 8.591014613282221, 9.574313843303841, 10.510404447239832, 11.486488436426942, 12.500250807286518, 13.44139576672634, 14.448282264923412, 15.425055943254396, 15.438652523067852, 14.526480261081943, 13.626470343977605, 12.66106516988175, 11.72668538563234, 10.747529155068309, 9.804482590045323, 8.823284993440495, 5.774951225934076, 6.778697741689609, 7.593540289143904, 8.56419069193863, 9.60197487986069, 10.50691270805151, 11.521542545922221, 12.49178766697785, 13.47877860711612, 14.381418412903855, 15.336546978771459, 15.411106851377129, 14.477087228979705, 13.569543366069608, 12.60059608098623, 11.641384253759362, 10.749593280622157, 9.780297627411002, 8.845791222548879, 7.811972758805345, 6.843915923454265, 7.793099167504812, 8.606502571544596, 9.519272507692394, 10.567955604645924, 11.55337003716231, 12.493649581360167, 13.496264758920429, 14.462075461500664, 15.404141165040715, 15.434238828751852, 14.470328668882718, 13.47412134932798, 12.497998872898295, 11.616108054286423, 10.684440022392021, 9.716275654384127, 8.81341739065604, 7.804508872944717, 6.819327115018781, 7.788052921814314, 8.805670037163694, 9.67929707953456, 10.491945413905688, 11.503246150530904, 12.43738209970884, 13.408266141037169, 14.37613189411113, 15.372640669483868, 15.46557585000686, 14.411333068581067, 13.462857016832519, 12.477664855156767, 11.51190056217278, 10.594285899785824, 9.707691696525277, 8.767130491264975, 7.817760662425643, 6.933634056350892, 5.892067676291684, 8.744103690994942, 9.709748668213123, 10.607013582692051, 11.540108264415117, 12.470993915743144, 13.364880552114078, 14.404291273013293, 15.349206451177544, 15.5718696821127, 14.588412316940316, 13.553472548010244, 12.588124765149546, 11.612989797867964, 10.540013080510102, 9.598387579575915, 8.713972349555268, 7.78205783129896, 6.809152629551028, 5.859282032754013, 4.932754454242643, 9.738259918460221, 10.635908864971261, 11.5944411545537, 12.521350714039341, 13.464138699110164, 14.37192907199854, 15.346123384964969, 15.471094347633846, 14.514702821649887, 13.553793540203712, 12.601247453200317, 11.665777323344706, 10.721510185930597, 9.697389762199048, 8.671649757595299, 7.722614032488094, 6.764595159249363, 5.822538657091912, 4.822981266332249, 3.9056008621545057, 10.790461913490581, 11.692568222314621, 12.547011883494, 13.496777231522179, 14.48724322756551, 15.310365750131593, 15.81794340032941, 14.806619397323576, 13.814225749554804, 12.78069089325548, 11.85083988003838, 10.901754557829276, 9.849962708586215, 8.781620710134638, 7.811418614816717, 6.866850936172632, 5.9011883839737465, 4.885936024851087, 3.862261606683052, 2.85776682498677, 11.744287800708186, 12.747460223413643, 13.559113175826976, 14.45656787760797, 15.452930496840953, 15.849910539726602, 14.89507728981361, 13.92171944765013, 12.888569976945057, 11.971775950995507, 10.907594865886306, 9.871533604664691, 8.876111000618145, 7.948910087564271, 6.8914661672988595, 5.934960627026897, 4.926601964084231, 3.96233991446702, 2.980296669732441, 1.9216631160481525, 12.790450930100524, 13.766441177042926, 14.503429955023242, 15.384102066817803, 16.041575145088814, 15.011800744890712, 13.984648777652307, 12.937869740794511, 11.945011003968878, 10.999961712195933, 9.952322472667737, 8.912636923834512, 7.967468209254544, 7.0530700589695625, 6.093972907382387, 5.054250348618806, 4.019963476203318, 2.9926707488661406, 2.0089536132714096, 0.9764495868106385, 13.834262170025164, 14.715866814741862, 15.47275619328267, 16.077189482196303, 15.064875733150085, 14.080198889300235, 13.035873207863878, 12.076688976646661, 11.104295085266573, 10.123877649223125, 9.049804896237635, 8.005871933413761, 7.036114163262497, 6.104520055005608, 5.131917051827676, 4.0665195351978465, 3.121309301284386, 2.0646259646411758, 1.0634384800998034, 0.0, 14.785895941194683, 15.74302206144679, 16.544185565316564, 16.783415503334474, 15.800719840830158, 14.816904252766163, 13.850075566182234, 12.880933702829426, 11.865150336861552, 10.841198411024294, 9.898427642956502, 8.919436682027394, 7.9711624752399315, 7.114465499570725, 6.059610034233318, 5.025559207563299, 3.9854563373440746, 2.97656829577746, 1.9156095676924165, 0.9290545785962111, 15.755567152916505, 16.791649972293104, 17.5904514886654, 17.689177832244926, 16.744370022505965, 15.67068572280299, 14.704843149256691, 13.7353518993288, 12.737526843780916, 11.703110321165045, 10.724111070039493, 9.798079343139165, 8.778296669983222, 7.834480965315197, 6.894695837453759, 5.895110371523458, 4.8854159009471605, 3.905671201911638, 2.8708051651546573, 1.9935877158941144, 16.683252786550682, 17.636621083383364, 18.646716840730836, 18.63073113322284, 17.69412470073098, 16.61983030112566, 15.662515689945867, 14.700611995753377, 13.750782134551056, 12.76721606464773, 11.760951400374962, 10.7566202131973, 9.825698954069539, 8.818716644524617, 7.866917992516394, 6.870309608694071, 5.856692745231542, 4.839747596044136, 3.8885552608929315, 3.055234579115802], [16.89059323208304, 17.70679776650627, 18.744864809457056, 18.495133960229282, 17.445730738552733, 16.473491770918546, 15.531871247224545, 14.514802698149314, 13.599810977426444, 12.666324281507553, 11.623261333735622, 10.579660669564646, 9.6496809843436, 8.6392194247016, 7.695863204051366, 6.737590377136247, 5.787522187799981, 4.85831801492861, 3.8398496431402016, 2.8819096976820955, 15.81890747473002, 16.763927432827963, 17.71925280827396, 18.04251956649345, 17.009181222102868, 15.936342982273976, 14.923909546032185, 13.889401900266709, 12.944100677922483, 11.98353535014336, 11.051105769102232, 10.118287635288972, 9.097908433002276, 8.051133626269289, 7.010772923262292, 5.998174647846089, 4.982635327226255, 4.016616420162976, 2.992881960109083, 1.9261529667457573, 14.813125687513374, 15.758853693340324, 16.65293688350531, 17.16473961216456, 16.10980466062608, 15.128147534546285, 14.104695875948817, 13.129267384722464, 12.14504030165477, 11.147114810878243, 10.212746501427363, 9.152880020645872, 8.11575671619895, 7.066172155208861, 6.073054801939793, 5.05877605941091, 4.011361702583573, 3.023761013521871, 2.023917822321983, 1.0267694799430735, 13.845106379918288, 14.8141897150694, 15.64301149563811, 16.576262900491734, 16.978952692770033, 15.985779560555295, 15.02888844761562, 13.999854071976849, 12.96156138538146, 12.003380325250507, 10.959622746788792, 9.910464424512469, 8.861648272233364, 7.8149803124648045, 6.740793332522944, 5.8147503365556, 4.884064957008995, 3.8925768923643824, 2.9652047344737973, 1.986543952651607, 12.913670697994181, 13.88392372014397, 14.611322184509175, 15.628727471651507, 16.473689096297555, 16.931087605843867, 15.860159892249603, 14.930591633465488, 13.919925156124629, 12.866975770571488, 11.834397686483547, 10.777240142177675, 9.749842511932222, 8.719173600027299, 7.753110057076359, 6.771384036642174, 5.821560680764498, 4.936629254946138, 3.900581055751885, 2.96983673629802, 11.929321944122805, 12.940715561949245, 13.671573892729088, 14.627467533041177, 15.534282905230501, 16.539590355770873, 16.493291580311936, 15.517419447559403, 14.550831624790959, 13.608104675888535, 12.645697761263962, 11.710799727619316, 10.642219167819402, 9.62963956399227, 8.680546925044013, 7.81116407985388, 6.8072795715997705, 5.80685480306805, 4.863416094248309, 3.9672792939754196, 10.974149663180993, 11.881524823144858, 12.676374146358857, 13.651099896957975, 14.589543374653424, 15.594761192052037, 16.517827779177125, 16.490420991458382, 15.495382741377918, 14.534487680322979, 13.569083922163092, 12.635917159046468, 11.57000308864217, 10.624921658040641, 9.674416238294862, 8.765490036417859, 7.775448530689333, 6.731873607947733, 5.852407521044412, 4.955717912196605, 9.989595449162293, 10.92488683737775, 11.725999603138806, 12.670145134306402, 13.63877138245317, 14.579210785414004, 15.515301389349995, 16.491385378537103, 16.416788127157826, 15.475643167718005, 14.468756669520932, 13.491982991189948, 12.521375338956624, 11.56151960871192, 10.600505648467001, 9.710211780829521, 8.677227842598287, 7.674891138789931, 6.85994806108571, 5.973787796885208, 9.010944715260608, 9.954207567386725, 10.795955424989293, 11.685253434783197, 12.634280893021892, 13.646611920666334, 14.623119127645003, 15.593364248700631, 16.47572638158992, 16.307579673348304, 15.3524511074807, 14.416960255442193, 13.48294063304477, 12.518456503724256, 11.524081029224162, 10.564869201997293, 9.61141831965839, 8.642122666447237, 7.818639428582153, 6.985100031520359, 7.941980017740418, 8.891163261790965, 9.782993142588602, 10.730171619029434, 11.617380733141948, 12.602795165658334, 13.651012092207058, 14.598558639955748, 15.492429527205374, 16.434495230745426, 16.28565272364535, 15.441159699436971, 14.479551866775621, 13.503429390345936, 12.50999353025957, 11.521813433364635, 10.561936724434085, 9.6090029032022, 8.881154844788288, 7.977745675306922, 6.997843019380369, 8.017976275767083, 8.710198634598637, 9.75749871281614, 10.682090187256968, 11.615694166154302, 12.586578207482631, 13.554443960556592, 14.531574633802371, 15.461527133180518, 16.359504883283147, 16.38320616434896, 15.398014002673207, 14.43224970968922, 13.492877344497694, 12.498561759231379, 11.511081887553237, 10.619929694361936, 9.877983543930323, 8.905005114034019, 6.04179225019974, 6.944111085856256, 7.782482131441145, 8.709335862306713, 9.714342422044728, 10.688195713749064, 11.593462811095131, 12.607805428070666, 13.566707949250715, 14.505069146970682, 15.413554810829286, 16.294545484196064, 16.395721134555654, 15.404137191351898, 14.480514369774006, 13.436866206722591, 12.504951688466283, 11.62853772723655, 10.790845914594431, 9.86431833608306, 5.047636022734461, 6.017950889098119, 6.795054559579498, 7.728093412682489, 8.770594165038009, 9.681147193864602, 10.593600968283205, 11.553149562803943, 12.509541088787902, 13.470450370234078, 14.422996457237472, 15.358466587093083, 16.302733724507192, 16.368729601593405, 15.407252191754623, 14.498277978034457, 13.540259104795727, 12.615151699695666, 11.823669602762859, 10.891471928171198, 3.9954340277041016, 5.025235403140826, 5.842483830639198, 6.752666895199652, 7.747489636582661, 8.742710515731549, 9.655450073386964, 10.598516170451678, 11.556137095601414, 12.58967195190074, 13.51952296511784, 14.54648568005658, 15.501748385051895, 16.388334173927284, 16.403363074376085, 15.458795395732, 14.493132843533115, 13.600372372097663, 12.784389262412056, 11.939305965338933, 3.041608140486497, 3.970343402041804, 4.830382538306221, 5.79287624911386, 6.789238868346843, 7.731226242506025, 8.686059492419018, 9.659417334582498, 10.61875561807205, 11.64611638048066, 12.696231960184132, 13.715634920809652, 14.461083394653494, 15.38828430770737, 16.407513203620677, 16.422551799909467, 15.556932755945583, 14.624215458833882, 13.754074668237022, 12.87540967427755, 1.9954450110941593, 2.9151978319893885, 3.8860657591099557, 4.865342059904028, 5.825581666450025, 6.6779596246545285, 7.66064040462635, 8.707419441484145, 9.675196645095872, 10.600900398983454, 11.64853963851165, 12.688225187344875, 13.519132302894228, 14.55084275116445, 15.465766225714129, 16.50548878447771, 16.571504388881664, 15.694622321521823, 14.725417724698053, 13.820623203515066, 0.9516337711695189, 1.965772194290453, 2.916739520850527, 3.8626934933637, 4.874269351692656, 5.74635776906405, 6.711824694588905, 7.67100892580612, 8.643402817186209, 9.623820253229656, 10.682162179863273, 11.723668663674703, 12.587778256902181, 13.51937236515907, 14.491975368337002, 15.557372884966831, 16.502583118880292, 16.62266710574679, 15.722962891234552, 14.785895941194683, 0.0, 0.9735869005986069, 1.9128720948114475, 2.8404769168302035, 3.8231725793345186, 4.806988167398514, 5.773816853982443, 6.742958717335252, 7.758742083303126, 8.782694009140384, 9.725464777208176, 10.704455738137284, 11.652729944924747, 12.63836721960261, 13.693222684940018, 14.727273511610036, 15.767376381829262, 16.776264423395876, 16.7015055088871, 15.714950519790895, 0.9699518385413892, 2.02221481144492, 2.959138018160284, 3.8633530154542495, 4.808160825193211, 5.805469563869501, 6.7713121374158, 7.740803387343691, 8.738628442891574, 9.709298361985939, 10.68829761311149, 11.61432934001182, 12.634112013167762, 13.577927717835788, 14.517712845697226, 15.517298311627526, 16.526992782203823, 17.506737481239345, 17.656701106349338, 16.779483657088797, 1.897637472175565, 2.8510057690082484, 3.8611015263557213, 4.843219133327063, 5.779825565818925, 6.754614142192171, 7.724259664401712, 8.706063483768268, 9.701033909156576, 10.730679995498761, 11.73602272554491, 12.617016717875963, 13.547937977003723, 14.574204140589618, 15.48993500075986, 16.493484408857558, 17.507101272320085, 18.524046421507492, 18.674451202087614, 17.841130520310486], [17.84771935233515, 17.230610674322886, 17.820801513369215, 17.521547059630677, 16.472143837954125, 15.499904870319941, 14.55828434662594, 13.54121579755071, 12.626224076827839, 11.692737380908945, 10.649674433137013, 9.606073768966038, 8.676094083744992, 7.6656325241029935, 6.72227630345276, 5.803250756560996, 4.904191873687677, 4.063608074660431, 3.0451397028720226, 3.855496598280703, 16.776033594982128, 16.28774034064458, 16.780635860688438, 17.68008643279546, 17.49526913735482, 16.46196054718314, 15.44952711094135, 14.415019465175874, 13.469718242831648, 12.509152915052525, 11.576723334011398, 10.643905200198137, 9.670451149346613, 8.662823830100766, 7.7699318443942005, 6.809354129233722, 5.940891684516029, 4.990203320761584, 3.96646886070769, 2.899739867344364, 15.770251807765483, 15.282666601156942, 15.714319935919786, 16.652264776113167, 17.083391561224683, 16.10173443514489, 15.078282776547425, 14.102854285321072, 13.118627202253379, 12.120701711476851, 11.18633340202597, 10.126466921244479, 9.089343616797557, 8.039759055807467, 7.046641702538399, 6.032362960009516, 4.984948603182179, 3.9973479141204775, 2.9975047229205893, 2.0003563805416804, 14.802232500170398, 14.219865256323938, 14.704394548052587, 15.637645952906214, 16.49373324305256, 16.9593664611539, 16.002475348214222, 14.973440972575453, 13.935148285980064, 12.976967225849112, 11.933209647387399, 10.884051325111075, 9.83523517283197, 8.788567213063411, 7.714380233121551, 6.788337237154207, 5.8576518576076015, 4.866163792962989, 3.9387916350724037, 2.960130853250214, 13.87079681824629, 13.20887393148727, 13.672705236923653, 14.690110524065984, 15.532877713300959, 16.58785594916249, 16.83374679284821, 15.904178534064096, 14.893512056723237, 13.840562671170096, 12.807984587082155, 11.750827042776283, 10.723429412530828, 9.692760500625905, 8.726696957674966, 7.7449709372407805, 6.795147581363104, 5.910216155544745, 4.874167956350492, 3.9434236368966267, 12.886448064374914, 12.205426369384794, 12.732956945143565, 13.688850585455654, 14.593471522233905, 15.598778972774276, 16.52246862856825, 16.49100634815801, 15.524418525389567, 14.581691576487144, 13.61928466186257, 12.684386628217924, 11.61580606841801, 10.603226464590879, 9.65413382564262, 8.784750980452486, 7.780866472198377, 6.780441703666656, 5.837002994846915, 4.940866194574027, 11.931275783433103, 11.146235630580406, 11.737757198773334, 12.712482949372452, 13.648731991656827, 14.65394980905544, 15.566200167631914, 16.533058768497696, 16.468969641976525, 15.508074580921587, 14.5426708227617, 13.609504059645076, 12.543589989240779, 11.59850855863925, 10.64800313889347, 9.739076937016465, 8.74903543128794, 7.70546050854634, 6.825994421643019, 5.929304812795213, 10.946721569414402, 10.189597644813299, 10.787382655553284, 11.729333751309806, 12.697959999456573, 13.627583173868793, 14.563673777804784, 15.539757766991894, 16.553520137851468, 16.449230068316613, 15.44234357011954, 14.465569891788556, 13.494962239555232, 12.535106509310529, 11.57409254906561, 10.68379868142813, 9.650814743196893, 8.648478039388538, 7.833534961684316, 6.947374697483816, 9.968070835512718, 9.218918374822273, 9.85733847740377, 10.744442051786601, 11.693469510025295, 12.694984309121123, 13.65244196263502, 14.622687083690648, 15.502139480991312, 16.489114118340744, 16.32603800807931, 15.390547156040801, 14.456527533643378, 13.492043404322864, 12.49766792982277, 11.538456102595902, 10.585005220256999, 9.615709567045844, 8.79222632918076, 7.9509027410814115, 8.899106137992527, 8.155874069226511, 8.844376195003079, 9.789360236032838, 10.676569350145352, 11.64757558698259, 12.680334927197075, 13.627881474945765, 14.518842626606768, 15.460908330146818, 16.408823742855326, 16.41474660003558, 15.453138767374229, 14.477016290944544, 13.483580430858177, 12.495400333963243, 11.535523625032692, 10.582589803800806, 9.854741745386894, 8.943548384867976, 7.954969139632478, 7.143303199567629, 7.771581687013114, 8.816687329819544, 9.741278804260372, 10.646331023293573, 11.615901042472649, 12.583766795546609, 13.557987733203765, 14.487940232581911, 15.385917982684541, 16.30976939632974, 16.371600903271815, 15.405836610287828, 14.466464245096303, 13.472148659829987, 12.484668788151843, 11.593516594960542, 10.85157044452893, 9.870807823595072, 6.998918370451849, 6.069438009656801, 6.843865183855622, 7.768524479310116, 8.773531039048132, 9.718832570888335, 10.619875910496525, 11.63421852747206, 12.593121048652108, 13.531482246372075, 14.43996791023068, 15.320958583597456, 16.296093550879036, 16.377724091950505, 15.454101270372613, 14.410453107321198, 13.47853858906489, 12.602124627835156, 11.756648624155485, 10.830121045644114, 6.0047621429865705, 5.143277812898663, 5.856437611993975, 6.787282029685893, 7.829782782041412, 8.711784051003873, 9.620014067684599, 10.579562662205337, 11.535954188189296, 12.496863469635471, 13.449409556638866, 14.384879686494477, 15.329146823908586, 16.353267247640133, 16.38083909235323, 15.471864878633063, 14.513846005394333, 13.588738600294272, 12.789472312323912, 11.857274637732251, 4.952560147956211, 4.0866184555553025, 4.903866883053675, 5.8118555122030555, 6.806678253586065, 7.77334737287082, 8.681863172788358, 9.624929269853071, 10.58255019500281, 11.616085051302136, 12.545936064519235, 13.572898779457976, 14.528161484453289, 15.414747273328677, 16.3849493686466, 16.432382296330605, 15.46671974413172, 14.57395927269627, 13.75019197197311, 12.905108674899987, 3.998734260738606, 3.0317264544562805, 3.8917655907206985, 4.852064866117264, 5.848427485350247, 6.757639341907419, 7.7124725918204105, 8.685830433983892, 9.645168717473446, 10.672529479882055, 11.722645059585526, 12.742048020211046, 13.487496494054888, 14.414697407108763, 15.433926303022071, 16.390431843294035, 16.53051965654419, 15.597802359432489, 14.719877377798076, 13.841212383838604, 2.952571131346268, 1.9765808844038655, 2.9474488115244326, 3.9245306769074313, 4.884770283453428, 5.704372724055922, 6.687053504027744, 7.733832540885539, 8.701609744497267, 9.627313498384847, 10.674952737913044, 11.714638286746268, 12.545545402295621, 13.577255850565843, 14.492179325115522, 15.531901883879103, 16.497435510173613, 16.668209222120428, 15.691220434259106, 14.786425913076119, 1.9252206717681257, 1.0271552467049296, 1.9781225732650038, 2.921882110367103, 3.90068245109405, 4.772770868465444, 5.738237793990298, 6.697422025207514, 7.669815916587603, 8.65023335263105, 9.708575279264666, 10.750081763076096, 11.614191356303575, 12.545785464560463, 13.518388467738395, 14.583785984368225, 15.528996218281685, 16.585679554924894, 16.688765600795605, 15.743022061446792, 0.9735869005986069, 0.0, 0.9392851942128406, 1.8668900162315967, 2.849585678735912, 3.833401266799908, 4.800229953383837, 5.769371816736646, 6.78515518270452, 7.809107108541777, 8.75187787660957, 9.730868837538678, 10.67914304432614, 11.664780319004004, 12.719635784341412, 13.75368661101143, 14.793789481230654, 15.802677522797268, 16.863636250882312, 16.672076640043002, 1.943538739139996, 1.0486279108463132, 1.9855511175616776, 2.889766114855642, 3.834573924594603, 4.831882663270894, 5.797725236817193, 6.767216486745085, 7.765041542292968, 8.735711461387332, 9.714710712512884, 10.640742439413213, 11.660525112569156, 12.604340817237182, 13.54412594509862, 14.54371141102892, 15.553405881605217, 16.53315058064074, 17.56801661739772, 17.736609777340906, 2.871224372774172, 2.0183491780868086, 3.0284449354342815, 3.9088795127518123, 4.8454859452436745, 5.781027241593565, 6.750672763803106, 7.732476583169663, 8.72744700855797, 9.757093094900155, 10.762435824946303, 11.643429817277358, 12.574351076405119, 13.600617239991013, 14.516348100161254, 15.519897508258952, 16.53351437172148, 17.550459520908888, 18.243363593451793, 18.798256640562595], [18.64888285620492, 17.72344404280189, 16.914108312138104, 16.582261865417838, 15.532858643741285, 14.5606196761071, 13.618999152413098, 12.601930603337866, 11.686938882614996, 10.753452186696105, 9.710389238924174, 8.666788574753198, 7.736808889532152, 6.726347329890152, 5.782991109239918, 4.863965562348156, 3.9649066794748364, 3.150234279302739, 3.984424897084863, 4.794781792493543, 17.577197098851897, 16.780573709123583, 15.873942659457327, 16.77339323156435, 16.55598394314198, 15.522675352970301, 14.51024191672851, 13.475734270963034, 12.530433048618809, 11.569867720839685, 10.637438139798558, 9.704620005985298, 8.731165955133772, 7.723538635887925, 6.830646650181359, 5.870068935020882, 5.001606490303189, 4.207892261403149, 4.90575405492053, 3.839025061557205, 16.571415311635253, 15.775499969635945, 14.807626734688675, 15.745571574882057, 16.616021203122727, 16.48943209143218, 15.465980432834716, 14.490551941608363, 13.512341671327363, 12.587673945784527, 11.664071862606125, 10.670027620628398, 9.758084667938443, 8.708500106948353, 7.823746265984944, 6.809467523456061, 5.92423379739502, 4.936633108333319, 3.9367899171334306, 2.9396415747545213, 15.60339600404017, 14.712698624802941, 13.797701346821476, 14.730952751675103, 15.554448048839717, 16.547621181054456, 16.46517401539104, 15.538936636642642, 14.52376666875551, 13.565585608624557, 12.681332479780014, 11.632174157503691, 10.736923745057368, 9.690255785288809, 8.653665427334392, 7.727622431367047, 6.796937051820442, 5.805448987175829, 4.878076829285244, 3.8994160474630544, 14.671960322116062, 13.701707299966273, 12.766012035692542, 13.783417322834874, 14.593592519088117, 15.648570754949649, 16.536096843448423, 16.48812071609226, 15.53312936429782, 14.580080218659045, 13.610898308856825, 12.584977271789043, 11.66271460674367, 10.632045694838746, 9.665982151887807, 8.68425613145362, 7.734432775575945, 6.8495013497575865, 5.813453150563333, 4.8827088311094675, 13.756075886686034, 12.808288046265023, 11.826263743912454, 12.782157384224544, 13.654186328021064, 14.659493778561435, 15.58318343435541, 16.559055567107944, 16.456973610115835, 15.514246661213411, 14.551839746588838, 13.616941712944191, 12.55509126263085, 11.542511658803718, 10.59341901985546, 9.724036174665326, 8.720151666411217, 7.7197268978794975, 6.776288189059756, 5.880151388786867, 12.800903605744223, 11.820194242136292, 10.831063997542223, 11.805789748141342, 12.709446797443986, 13.714664614842599, 14.626914973419073, 15.593773574284855, 16.58881182436532, 16.440629665647855, 15.48195601697454, 14.548789253857915, 13.482875183453618, 12.537793752852089, 11.58728833310631, 10.678362131229305, 9.688320625500781, 8.644745702759181, 7.76527961585586, 6.868590007008053, 11.816349391725522, 10.863556256369185, 9.880689454322173, 10.790048557096965, 11.758674805243732, 12.688297979655951, 13.624388583591942, 14.600472572779053, 15.614234943638628, 16.48985157030542, 16.38162876433238, 15.404855086001396, 14.434247433768071, 13.474391703523368, 12.513377743278449, 11.623083875640969, 10.590099937409734, 9.587763233601379, 8.772820155897158, 7.886659891696656, 10.837698657823838, 9.928669201589534, 8.95064527617266, 9.80515685757376, 10.754184315812454, 11.755699114908282, 12.713156768422179, 13.683401889477807, 14.562854286778471, 15.549828924127901, 16.402740164807135, 16.32983235025364, 15.395812727856217, 14.431328598535703, 13.43695312403561, 12.477741296808741, 11.524290414469839, 10.554994761258685, 9.731511523393602, 8.820530563392532, 9.768733960303647, 8.91009785909167, 7.937682993771968, 8.850075041819997, 9.73728415593251, 10.708290392769749, 11.741049732984234, 12.688596280732924, 13.579557432393926, 14.521623135933977, 15.469538548642484, 16.3779558541671, 16.39242396158707, 15.416301485157383, 14.422865625071017, 13.434685528176082, 12.474808819245533, 11.521874998013647, 10.794026939599735, 9.813176207179096, 8.824596961943598, 7.897526989432786, 6.864888485782004, 7.877402135606704, 8.80199361004753, 9.707045829080732, 10.676615848259807, 11.644481601333768, 12.618702538990924, 13.54865503836907, 14.4466327884717, 15.370484202116902, 16.354515488548643, 16.345121804500668, 15.405749439309142, 14.411433854042826, 13.423953982364685, 12.532801789173384, 11.790855638741771, 10.740435645906192, 7.86854619276297, 6.90290121554479, 5.937171982624512, 6.829239285097275, 7.834245844835291, 8.779547376675493, 9.680590716283684, 10.694933333259218, 11.653835854439267, 12.592197052159234, 13.500682716017838, 14.381673389384614, 15.356808356666196, 16.3785744636688, 16.393386464585454, 15.349738301534039, 14.417823783277731, 13.541409822047997, 12.626276446466605, 11.699748867955234, 6.944047337199411, 5.976741018786653, 4.9497444107628645, 5.847996835473052, 6.890497587828571, 7.772498856791031, 8.680728873471757, 9.640277467992496, 10.596668993976454, 11.55757827542263, 12.510124362426025, 13.445594492281636, 14.389861629695744, 15.413982053427294, 16.43972205803104, 16.411150072845906, 15.453131199607174, 14.528023794507114, 13.659100134635032, 12.726902460043371, 5.891845342169051, 4.9433442714384235, 3.9971736818225647, 4.872570317990214, 5.8673930593732235, 6.8340621786579785, 7.742577978575516, 8.68564407564023, 9.64326500078997, 10.676799857089296, 11.606650870306396, 12.633613585245136, 13.588876290240448, 14.475462079115836, 15.445664174433757, 16.390231853077843, 16.406004938344562, 15.51324446690911, 14.61981979428423, 13.774736497211107, 4.938019454951447, 3.971011648669122, 2.9850723894895874, 3.9127796719044223, 4.909142291137406, 5.818354147694578, 6.773187397607569, 7.74654523977105, 8.705883523260606, 9.733244285669215, 10.783359865372686, 11.802762825998206, 12.548211299842047, 13.475412212895922, 14.49464110880923, 15.451146649081192, 16.459505312023857, 16.53708755364533, 15.589505200109196, 14.710840206149724, 3.8918563255591088, 2.9158660786167063, 2.0407556102933215, 2.98524548269459, 3.945485089240587, 4.765087529843081, 5.747768309814903, 6.794547346672698, 7.7623245502844265, 8.688028304172008, 9.735667543700204, 10.775353092533429, 11.60626020808278, 12.637970656353001, 13.552894130902681, 14.592616689666261, 15.55815031596077, 16.57443914493702, 16.560848256570228, 15.656053735387239, 2.8645058659809663, 1.9664404409177703, 1.0714293720338925, 1.9825969161542623, 2.961397256881209, 3.8334856742526036, 4.798952599777458, 5.758136830994673, 6.730530722374763, 7.71094815841821, 8.769290085051825, 9.810796568863255, 10.674906162090734, 11.606500270347622, 12.579103273525554, 13.644500790155384, 14.589711024068844, 15.646394360712055, 16.647581845253427, 16.544185565316564, 1.9128720948114475, 0.9392851942128406, 0.0, 0.9276048220187562, 1.9103004845230713, 2.8941160725870674, 3.860944759170996, 4.8300866225238055, 5.845869988491678, 6.869821914328936, 7.812592682396728, 8.791583643325836, 9.7398578501133, 10.725495124791163, 11.78035059012857, 12.814401416798589, 13.854504287017814, 14.863392328584428, 15.924351056669472, 16.910906045765678, 2.882823933352837, 1.9879131050591539, 1.046265923348837, 1.9504809206428018, 2.8952887303817625, 3.8925974690580536, 4.858440042604352, 5.827931292532243, 6.825756348080127, 7.796426267174491, 8.775425518300043, 9.701457245200372, 10.721239918356314, 11.66505562302434, 12.604840750885778, 13.604426216816078, 14.614120687392376, 15.593865386427899, 16.62873142318488, 17.569901834378115, 3.8105095669870126, 2.957634372299649, 2.107138007149911, 2.969594318538972, 3.906200751030834, 4.841742047380723, 5.811387569590265, 6.793191388956822, 7.788161814345129, 8.817807900687313, 9.823150630733462, 10.704144623064515, 11.635065882192276, 12.66133204577817, 13.577062905948413, 14.58061231404611, 15.59422917750864, 16.611174326696045, 17.56236666184725, 18.630137329612136], [18.62627065270123, 17.6475147589574, 16.60965359291538, 15.654657043399078, 14.605253821722528, 13.633014854088342, 12.69139433039434, 11.674325781319109, 10.759334060596238, 9.82584736467735, 8.782784416905418, 7.7391837527344425, 6.809204067513396, 5.798742507871396, 4.855386287221163, 3.9363607403294, 3.0373018574560806, 3.9665060303274515, 4.91202971910362, 5.722386614512299, 17.629228775887785, 17.678130871300656, 16.7714998216344, 15.889322723308682, 15.628379121123222, 14.595070530951544, 13.582637094709753, 12.548129448944279, 11.602828226600053, 10.64226289882093, 9.709833317779802, 8.777015183966542, 7.803561133115017, 6.795933813869169, 5.903041828162603, 4.942464113002126, 4.074001668284433, 5.024164012427862, 5.833358876939286, 4.766629883575961, 16.921953630641028, 16.673057131813017, 15.705183896865748, 14.861501066626392, 15.688416381103972, 15.561827269413428, 14.53837561081596, 13.562947119589607, 12.584736849308607, 11.660069123765773, 10.736467040587371, 9.742422798609642, 8.830479845919687, 7.780895284929598, 6.896141443966188, 5.8818627014373055, 5.045275292927116, 5.864237930352075, 4.8643947391521865, 3.867246396773277, 16.500953166217244, 15.610255786980014, 14.695258508998547, 13.846882243419438, 14.626843226820961, 15.620016359035699, 15.537569193372281, 14.611331814623886, 13.596161846736756, 12.637980786605803, 11.753727657761258, 10.704569335484935, 9.809318923038614, 8.762650963270055, 7.839274763317436, 6.913231767350092, 5.982546387803486, 6.733053809194585, 5.805681651304, 4.82702086948181, 15.569517484293135, 14.599264462143346, 13.663569197869613, 12.899346814579209, 13.665987697069362, 14.720965932930893, 15.608492021429667, 15.560515894073506, 14.605524542279065, 13.652475396640291, 12.68329348683807, 11.657372449770287, 10.748477155478792, 9.717808243573868, 8.85159148787085, 7.869865467436665, 6.920042111558989, 7.777106171776342, 6.741057972582089, 5.810313653128223, 14.67459973347448, 13.705845208442092, 12.723820906089525, 11.898086875968879, 12.726581506002308, 13.73188895654268, 14.655578612336654, 15.631450745089186, 15.529368788097079, 14.586641839194655, 13.624234924570082, 12.689336890925436, 11.69061509747746, 10.678035493650329, 9.779028355838506, 8.943035461529718, 7.952794179700643, 8.647331719898252, 7.703893011078512, 6.807756210805623, 13.719427452532669, 12.717751404313363, 11.728621159719294, 10.909081722652555, 11.78184197542523, 12.787059792823843, 13.699310151400317, 14.666168752266099, 15.661207002346561, 15.513024843629099, 14.61747985182115, 13.684313088704526, 12.618399018300229, 11.6733175876987, 10.772897669089355, 9.897361418093697, 8.93667085725803, 9.572350524777937, 8.692884437874616, 7.796194829026809, 12.734873238513968, 11.761113418546255, 10.778246616499244, 9.862443735078209, 10.831069983224976, 11.760693157637196, 12.696783761573187, 13.672867750760297, 14.686630121619872, 15.562246748286661, 15.545984182344728, 14.569210504013745, 13.59860285178042, 12.660001039506414, 11.698987079261494, 10.865189154159195, 9.89958490835138, 10.515368055620135, 9.700424977915914, 8.813202396222866, 11.756222504612284, 10.826226363766605, 9.84820243834973, 8.877552035555004, 9.826579493793698, 10.828094292889526, 11.785551946403421, 12.75579706745905, 13.635249464759715, 14.622224102109145, 15.475135342788377, 15.49418776826599, 14.560168145868566, 13.616937934518749, 12.724861342252868, 11.830127895700466, 10.876677013361563, 11.482599583277441, 10.659116345412357, 9.739054410180978, 10.687257807092093, 9.828621705880114, 8.856206840560414, 7.922470219801241, 8.809679333913754, 9.780685570750993, 10.813444910965476, 11.760991458714166, 12.65195261037517, 13.594018313915221, 14.541933726623729, 15.450351032148346, 15.563134025520291, 14.688482427690062, 13.719082585689458, 12.787072127067809, 11.9364231004934, 12.449479820032403, 11.716881811893478, 10.731700053967542, 9.743120808732044, 8.816050836221232, 7.783412332570449, 6.949797313587948, 7.874388788028774, 8.779441007061976, 9.74901102624105, 10.71687677931501, 11.691097716972168, 12.621050216350314, 13.519027966452944, 14.442879380098146, 15.426910666529885, 15.674580738415576, 14.740904740190057, 13.763820452934553, 12.885568263612551, 13.46040661119214, 12.713710511035513, 11.658959492694638, 8.787070039551416, 7.821425062333236, 6.855695829412957, 5.901634463078519, 6.906641022816535, 7.851942554656738, 8.752985894264926, 9.76732851124046, 10.726231032420511, 11.664592230140478, 12.573077893999082, 13.454068567365859, 14.42920353464744, 15.450969641650044, 15.736803060399966, 14.757539799904562, 13.879438064525598, 14.469014644066753, 13.54480029325505, 12.61827271474368, 7.865579731938756, 6.895264865575099, 5.86826825755131, 4.920392013454296, 5.962892765809815, 6.844894034772275, 7.753124051453001, 8.71267264597374, 9.669064171957698, 10.629973453403874, 11.582519540407269, 12.51798967026288, 13.462256807676988, 14.486377231408538, 15.512117236012287, 15.825179275489381, 14.914745480855041, 15.45562861652587, 14.577623981423478, 13.645426306831817, 6.819450164187808, 5.870949093457179, 4.9247785038413205, 3.9449654959714584, 4.939788237354468, 5.906457356639223, 6.814973156556761, 7.758039253621474, 8.715660178771213, 9.749195035070539, 10.679046048287638, 11.706008763226379, 12.661271468221692, 13.54785725709708, 14.518059352415001, 15.462627031059085, 15.867619219592427, 16.44084928892787, 15.538343641072675, 14.693260343999553, 5.865624276970204, 4.898616470687878, 3.9126772115083432, 2.9851748498856665, 3.98153746911865, 4.890749325675822, 5.845582575588813, 6.8189404177522945, 7.778278701241851, 8.805639463650458, 9.85575504335393, 10.87515800397945, 11.62060647782329, 12.547807390877166, 13.567036286790474, 14.523541827062436, 15.531900490005103, 16.496162539622315, 16.50802904689764, 15.62936405293817, 4.819461147577865, 3.843470900635462, 2.9683604323120774, 2.057640660675834, 3.0178802672218312, 3.837482707824325, 4.8201634877961475, 5.866942524653942, 6.834719728265671, 7.760423482153253, 8.808062721681448, 9.847748270514673, 10.678655386064024, 11.710365834334246, 12.625289308883925, 13.665011867647506, 14.630545493942014, 15.646834322918263, 16.71435765221494, 16.572885731091848, 3.792110687999722, 2.894045262936526, 1.9990341940526486, 1.0549920941355062, 2.0337924348624528, 2.9058808522338473, 3.8713477777587015, 4.830532008975918, 5.802925900356007, 6.783343336399454, 7.841685263033069, 8.8831917468445, 9.747301340071978, 10.678895448328866, 11.651498451506798, 12.716895968136628, 13.662106202050088, 14.718789538693299, 15.719977023234671, 16.783415503334474, 2.8404769168302035, 1.8668900162315967, 0.9276048220187562, 0.0, 0.9826956625043153, 1.966511250568311, 2.9333399371522395, 3.902481800505049, 4.9182651664729224, 5.94221709231018, 6.884987860377972, 7.8639788213070805, 8.812253028094544, 9.797890302772407, 10.852745768109815, 11.886796594779833, 12.926899464999057, 13.93578750656567, 14.996746234650715, 15.98330122374692, 3.8104287553715928, 2.91551792707791, 1.973485234312242, 1.0228760986240457, 1.9676839083630067, 2.9649926470392973, 3.9308352205855956, 4.9003264705134875, 5.898151526061371, 6.868821445155735, 7.847820696281286, 8.773852423181614, 9.793635096337557, 10.737450801005583, 11.67723592886702, 12.67682139479732, 13.686515865373618, 14.666260564409141, 15.701126601166122, 16.642297012359357, 4.738114389005768, 3.8852391943184053, 3.0241071034915574, 2.041989496520216, 2.9785959290120783, 3.9141372253619675, 4.883782747571509, 5.865586566938066, 6.860556992326373, 7.890203078668557, 8.895545808714704, 9.776539801045757, 10.707461060173518, 11.733727223759413, 12.649458083929655, 13.653007492027353, 14.666624355489882, 15.683569504677287, 16.634761839828492, 17.70253250759338], [17.643574990196914, 16.664819096453083, 15.626957930411063, 14.671961380894762, 13.622558159218212, 12.650319191584027, 11.708698667890026, 10.691630118814794, 9.776638398091924, 8.843151702173035, 7.800088754401104, 6.756488090230127, 5.826508405009081, 4.816046845367081, 3.8726906247168476, 3.0664824512701836, 4.019851552817627, 4.949055725688998, 5.894725381607934, 6.705082277016615, 16.64653311338347, 17.590769852414628, 16.634434541278768, 15.644442570037047, 14.645683458618906, 13.612374868447228, 12.599941432205437, 11.565433786439963, 10.620132564095737, 9.659567236316613, 8.727137655275486, 7.794319521462226, 6.820865470610702, 5.813238151364854, 4.920346165658289, 4.07258582394291, 5.05655136364598, 6.006713707789409, 6.816054539443602, 5.749325546080277, 15.93925796813671, 16.884985973963662, 16.687879559370064, 15.844196729130708, 14.95892446400383, 14.579131606909112, 13.555679948311644, 12.580251457085291, 11.602041186804291, 10.677373461261457, 9.753771378083055, 8.759727136105326, 7.8477841834153725, 6.798199622425283, 5.945429444574415, 5.011984412378089, 6.027824988288662, 6.846933592856391, 5.847090401656502, 4.849942059277593, 16.74150940210655, 16.592951449484328, 15.677954171502863, 14.829577905923754, 13.89735130972082, 14.815115679724903, 14.554873530867965, 13.62863615211957, 12.61346618423244, 11.655285124101487, 10.771031995256942, 9.72187367298062, 8.8266232605343, 7.77995530076574, 6.993051101408244, 6.0670081054409, 6.965096083165033, 7.715749471698901, 6.788377313808316, 5.809716531986126, 16.552213146797452, 15.581960124647662, 14.646264860373929, 13.882042477083525, 12.93649577996922, 13.775140695341241, 14.625796358925351, 14.57782023156919, 13.62282887977475, 12.669779734135975, 11.700597824333753, 10.674676787265971, 9.765781492974478, 8.735112581069554, 8.00536782596166, 7.023641805527474, 7.902591806920536, 8.759801834280658, 7.723753635086405, 6.793009315632539, 15.657295395978796, 14.688540870946408, 13.706516568593841, 12.880782538473195, 11.997089588902167, 12.786063718953027, 13.672882949832339, 14.64875508258487, 14.546673125592763, 13.60394617669034, 12.641539262065766, 11.70664122842112, 10.707919434973146, 9.695339831146015, 8.932804693929313, 8.096811799620525, 8.93534387506219, 9.63002738240257, 8.686588673582829, 7.790451873309939, 14.702123115036985, 13.700447066817679, 12.71131682222361, 11.891777385156871, 11.05235005832509, 11.841234555234191, 12.716614488896, 13.683473089761783, 14.678511339842245, 14.530329181124783, 13.634784189316836, 12.701617426200212, 11.635703355795915, 10.690621925194385, 9.926674007180162, 9.051137756184504, 9.919220552619578, 10.555046187282255, 9.675580100378932, 8.778890491531124, 13.717568901018284, 12.743809081050571, 11.76094227900356, 10.845139397582525, 10.101578066124835, 10.77799749513288, 11.71408809906887, 12.69017208825598, 13.703934459115557, 14.579551085782345, 14.563288519840414, 13.58651484150943, 12.615907189276106, 11.720291564759819, 10.852763417352302, 10.018965492250002, 10.88213460371293, 11.498063718124452, 10.68312064042023, 9.795898058727182, 12.7389181671166, 11.80892202627092, 10.830898100854046, 9.86024769805932, 9.067246418552543, 9.84539863038521, 10.802856283899107, 11.773101404954735, 12.6525538022554, 13.63952843960483, 14.492439680284061, 14.511492105761674, 13.57747248336425, 12.677228459772154, 11.878637680343676, 11.03864640837239, 11.859226708723112, 12.465295245781759, 11.641812007916673, 10.721750072685294, 11.66995346959641, 10.811317368384428, 9.838902503064729, 8.905165882305557, 8.0503462586726, 8.797989908246677, 9.830749248461162, 10.778295796209852, 11.669256947870855, 12.611322651410905, 13.559238064119413, 14.46765536964403, 14.580438363015976, 13.748772952943467, 12.872858923780266, 11.995590639739731, 12.918972795854948, 13.43217548253672, 12.699577474397794, 11.714395716471858, 10.72581647123636, 9.798746498725546, 8.766107995074764, 7.932492976092264, 7.115055712787619, 7.796745344557661, 8.766315363736735, 9.734181116810696, 10.708402054467852, 11.638354553845998, 12.536332303948628, 13.46018371759383, 14.444215004025569, 14.734871263668982, 13.894681078280865, 12.972338965606475, 13.8681179589741, 14.443102273696457, 13.69640617353983, 12.641655155198954, 9.769765702055732, 8.804120724837551, 7.838391491917272, 6.884330125582835, 6.14730794757538, 6.869246892152423, 7.770290231760612, 8.784632848736146, 9.743535369916195, 10.681896567636162, 11.590382231494766, 12.471372904861543, 13.446507872143124, 14.468273979145728, 14.890579398490773, 13.966058312576484, 14.861987759887146, 15.451710306571071, 14.527495955759367, 13.600968377247996, 8.848275394443071, 7.877960528079413, 6.850963920055625, 5.903087675958611, 5.154163164208359, 5.86219837226796, 6.770428388948686, 7.729976983469425, 8.686368509453382, 9.647277790899558, 10.599823877902953, 11.535294007758564, 12.479561145172672, 13.503681568904222, 14.529421573507971, 15.033697788161303, 15.89729517621659, 16.438324279030187, 15.560319643927794, 14.628121969336133, 7.802145826692124, 6.8536447559614935, 5.907474166345635, 4.9276611584757735, 4.131058635753012, 4.923761694134908, 5.8322774940524456, 6.775343591117159, 7.732964516266898, 8.766499372566223, 9.696350385783322, 10.723313100722063, 11.678575805717376, 12.565161594592764, 13.535363689910685, 14.47993136855477, 15.445593920753655, 16.460846279876314, 16.52103930357699, 15.675956006503869, 6.84831993947452, 5.881312133192194, 4.895372874012658, 3.9678705123899816, 3.1292778297675614, 3.908053663171507, 4.862886913084498, 5.8362447552479795, 6.795583038737535, 7.822943801146143, 8.873059380849616, 9.892462341475136, 10.637910815318975, 11.56511172837285, 12.584340624286158, 13.54084616455812, 14.549204827500787, 15.513466877117999, 16.49551012185258, 16.612059715442484, 5.802156810082181, 4.826166563139778, 3.9510560948163924, 3.0403363231801492, 2.0896321546592818, 2.85478704532001, 3.837467825291832, 4.884246862149627, 5.852024065761356, 6.777727819648938, 7.825367059177134, 8.865052608010359, 9.695959723559708, 10.72767017182993, 11.64259364637961, 12.68231620514319, 13.647849831437698, 14.664138660413947, 15.731661989710622, 16.764166016171394, 4.774806350504038, 3.876740925440842, 2.9817298565569637, 2.0376877566398215, 1.0510967723581377, 1.9231851897295322, 2.8886521152543865, 3.8478363464716026, 4.820230237851692, 5.800647673895139, 6.858989600528753, 7.900496084340182, 8.764605677567662, 9.69619978582455, 10.668802789002482, 11.734200305632312, 12.679410539545772, 13.736093876188983, 14.737281360730355, 15.800719840830158, 3.823172579334519, 2.849585678735912, 1.9103004845230713, 0.9826956625043153, 0.0, 0.9838155880639958, 1.9506442746479244, 2.9197861380007337, 3.935569503968607, 4.959521429805864, 5.902292197873656, 6.8812831588027645, 7.829557365590227, 8.81519464026809, 9.870050105605497, 10.904100932275515, 11.94420380249474, 12.953091844061355, 14.014050572146399, 15.000605561242605, 4.793124417875909, 3.8982135895822254, 2.956034929673789, 2.0054257939855926, 1.0606179842466317, 1.9822969845349823, 2.9481395580812806, 3.917630808009172, 4.915455863557056, 5.886125782651419, 6.8651250337769705, 7.791156760677299, 8.81093943383324, 9.754755138501267, 10.694540266362704, 11.694125732293005, 12.703820202869302, 13.683564901904825, 14.718430938661806, 15.659601349855041, 5.720810051510084, 4.86793485682272, 4.006656798853104, 3.024539191881763, 2.1087176399528618, 2.9314415628576524, 3.901087085067194, 4.88289090443375, 5.877861329822057, 6.907507416164241, 7.912850146210389, 8.793844138541443, 9.724765397669204, 10.751031561255099, 11.66676242142534, 12.670311829523037, 13.683928692985566, 14.700873842172971, 15.652066177324176, 16.719836845089063], [16.65975940213292, 15.68100350838909, 14.643142342347067, 13.688145792830767, 12.638742571154216, 11.666503603520031, 10.72488307982603, 9.707814530750799, 8.792822810027928, 7.859336114109038, 6.8162731663371074, 5.772672502166131, 4.8426928169450845, 3.8322312573030852, 2.8888750366528515, 3.8981980316862126, 4.949984365016576, 5.879188537887947, 6.8785409696719295, 7.688897865080611, 15.662717525319474, 16.606954264350634, 15.650618953214773, 14.660626981973051, 13.66186787055491, 12.628559280383234, 11.616125844141443, 10.581618198375967, 9.636316976031742, 8.675751648252618, 7.7433220672114915, 6.8105039333982305, 5.837049882546705, 4.8294225633008585, 3.9365305775942927, 4.904301404358939, 5.968693906980207, 6.9347727474508964, 7.799870127507598, 6.733141134144272, 14.955442380072716, 15.901170385899666, 16.662399154053173, 15.631908096463391, 14.576973144924908, 13.595316018845116, 12.571864360247648, 11.596435869021295, 10.618225598740295, 9.69355787319746, 8.76995579001906, 7.7759115480413294, 6.863968595351377, 5.814384034361288, 4.961613856510418, 5.843699992794118, 6.891114349621455, 7.830749180920386, 6.830905989720498, 5.833757647341589, 15.757693814042558, 16.72677714919367, 16.498603312322825, 15.575194715147566, 14.529361302604801, 13.831300091660909, 13.57105794280397, 12.644820564055575, 11.629650596168442, 10.67146953603749, 9.787216407192947, 8.738058084916624, 7.842807672470304, 6.796139712701744, 6.025428046430125, 6.898723685856929, 7.828385444497826, 8.699565059762897, 7.7721929018723115, 6.793532120050122, 16.689129495966665, 16.402609265467625, 15.466914001193892, 14.627659286307336, 13.568505772853202, 12.791325107277247, 13.641980770861355, 13.594004643505194, 12.639013291710752, 11.685964146071978, 10.716782236269758, 9.690861199201976, 8.78196590491048, 7.751296993005558, 7.0764559157410405, 7.855357385943503, 8.76588116825333, 9.712747208508775, 8.7075692231504, 7.776824903696535, 16.477944536798763, 15.509190011766371, 14.527165709413804, 13.650787210574839, 12.629099581786148, 11.802248130889033, 12.689067361768343, 13.664939494520874, 13.562857537528767, 12.620130588626344, 11.65772367400177, 10.722825640357124, 9.724103846909149, 8.711524243082017, 8.003892783708695, 8.928527380036554, 9.798633236394982, 10.613842970466566, 9.670404261646825, 8.774267461373935, 15.52277225585695, 14.521096207637642, 13.531965963043573, 12.673757371882658, 11.68436005120907, 10.857418967170197, 11.732798900832005, 12.699657501697788, 13.694695751778251, 13.546513593060787, 12.650968601252838, 11.717801838136214, 10.651887767731917, 9.706806337130388, 8.997762096959544, 9.882853336600533, 10.78250991395237, 11.53886177534625, 10.659395688442928, 9.76270607959512, 14.538218041838249, 13.564458221870535, 12.581591419823523, 11.665788538402488, 10.733588059008817, 9.794181907068884, 10.730272511004875, 11.706356500191985, 12.720118871051561, 13.59573549771835, 13.579472931776417, 12.602699253445433, 11.632091601212109, 10.736475976695822, 9.923851507131683, 10.850681072666031, 11.745423965045722, 12.481879306188448, 11.625299307675117, 10.616547199547147, 13.559567307936565, 12.629571167090884, 11.65154724167401, 10.680896838879283, 9.699256411436524, 8.861583042321215, 9.81904069583511, 10.789285816890738, 11.668738214191404, 12.655712851540834, 13.508624092220066, 13.527676517697676, 12.593656895300253, 11.693412871708157, 10.949725770123058, 11.870361988788419, 12.722516070055905, 13.449110833845754, 12.576217677248794, 11.54239921350526, 12.490602610416374, 11.631966509204391, 10.659551643884692, 9.72581502312552, 8.68235625155658, 7.814174320182682, 8.846933660397164, 9.794480208145854, 10.685441359806859, 11.62750706334691, 12.575422476055417, 13.483839781580034, 13.596622774951978, 12.76495736487947, 11.943947013559647, 12.827306220155762, 13.782262157187741, 14.415991070600716, 13.520226615217759, 12.535044857291822, 11.546465612056325, 10.619395639545509, 9.586757135894727, 8.753142116912226, 7.7470657056716, 6.812929756493665, 7.782499775672738, 8.750365528746698, 9.724586466403856, 10.654538965782002, 11.552516715884632, 12.476368129529835, 13.460399415961573, 13.751055675604984, 12.965769168060246, 13.804054546022506, 14.731407320306893, 15.426917861760453, 14.517055314359794, 13.46230429601892, 10.590414842875697, 9.624769865657516, 8.659040632737236, 7.704979266402798, 6.815724453618754, 5.885431304088426, 6.786474643696615, 7.800817260672149, 8.7597197818522, 9.698080979572167, 10.60656664343077, 11.487557316797547, 12.462692284079129, 13.484458391081732, 13.961667488270155, 14.797773892992515, 15.72527712121994, 16.419770999801326, 15.348145096579332, 14.421617518067961, 9.668924535263036, 8.698609668899378, 7.671613060875589, 6.723736816778575, 5.822579670251733, 4.878382784203963, 5.786612800884689, 6.746161395405428, 7.702552921389386, 8.663462202835563, 9.616008289838957, 10.551478419694568, 11.495745557108677, 12.519865980840226, 13.545605985443975, 14.49464171055118, 15.41465207142705, 16.3567085735845, 16.380968784747758, 15.448771110156098, 8.753279561107844, 7.692043713573773, 6.745873123957915, 5.748310299295738, 4.891874005250743, 3.939946106070911, 4.848461905988449, 5.791528003053163, 6.749148928202902, 7.782683784502227, 8.712534797719327, 9.739497512658067, 10.69476021765338, 11.581346006528769, 12.55154810184669, 13.496115780490776, 14.461778332689661, 15.47703069181232, 16.481379939613547, 16.496605147323834, 7.804860507668527, 6.837336427951759, 5.7959571845304705, 4.788519653209946, 3.8900931992652916, 2.9242380751075103, 3.879071325020502, 4.852429167183983, 5.811767450673539, 6.839128213082147, 7.889243792785619, 8.90864675341114, 9.65409522725498, 10.581296140308854, 11.600525036222162, 12.557030576494125, 13.565389239436792, 14.529651289054003, 15.511694533788582, 16.570406073797926, 6.758697378276189, 5.782707131333786, 4.851640405334204, 3.8609854640001133, 2.9007458574541167, 1.8709714572560139, 2.853652237227836, 3.900431274085631, 4.868208477697359, 5.793912231584941, 6.841551471113138, 7.881237019946362, 8.712144135495713, 9.743854583765934, 10.658778058315614, 11.698500617079194, 12.664034243373703, 13.680323072349951, 14.747846401646626, 15.780350428107397, 5.758621938568034, 4.83328149363485, 3.8823141670747754, 2.9363601945616025, 1.9240464455153865, 0.9393696016655363, 1.9048365271903904, 2.8640207584076065, 3.836414649787695, 4.816832085831143, 5.875174012464758, 6.916680496276187, 7.7807900895036655, 8.712384197760555, 9.684987200938487, 10.750384717568316, 11.695594951481777, 12.752278288124987, 13.75346577266636, 14.816904252766163, 4.806988167398515, 3.833401266799908, 2.8941160725870674, 1.966511250568311, 0.9838155880639958, 0.0, 0.9668286865839286, 1.935970549936738, 2.951753915904611, 3.9757058417418687, 4.918476609809661, 5.897467570738769, 6.845741777526231, 7.8313790522040945, 8.886234517541503, 9.920285344211521, 10.960388214430747, 11.969276255997361, 13.030234984082405, 14.01678997317861, 5.776940005939904, 4.882029177646221, 3.9398505177377845, 2.9892413820495882, 2.0444335723106275, 0.9984813964709863, 1.9643239700172845, 2.933815219945176, 3.9316402754930593, 4.9023101945874235, 5.881309445712975, 6.807341172613303, 7.827123845769246, 8.770939550437271, 9.710724678298709, 10.710310144229009, 11.720004614805307, 12.69974931384083, 13.73461535059781, 14.675785761791046, 6.70462563957408, 5.851750444886716, 4.940644413862181, 3.958526806890839, 3.021920374398977, 1.9476259747936564, 2.917271497003198, 3.8990753163697542, 4.894045741758061, 5.923691828100245, 6.929034558146394, 7.810028550477448, 8.740949809605208, 9.767215973191103, 10.682946833361344, 11.686496241459041, 12.70011310492157, 13.717058254108977, 14.668250589260182, 15.736021257025069], [15.692930715548991, 14.714174821805162, 13.67631365576314, 12.72131710624684, 11.671913884570289, 10.699674916936104, 9.758054393242103, 8.740985844166872, 7.8259941234440005, 6.926593836137487, 5.883530888365556, 4.839930224194579, 3.9099505389735327, 2.899488979331533, 3.8428451999817668, 4.852168195015127, 5.903954528345491, 6.8331587012168615, 7.845369656255858, 8.65572655166454, 14.695888838735547, 15.640125577766707, 14.683790266630846, 13.693798295389124, 12.695039183970984, 11.673504060506152, 10.68338356616989, 9.648875920404414, 8.703574698060189, 7.743009370281066, 6.810579789239939, 5.877761655426678, 4.904307604575154, 3.8966802853293063, 4.890500740923208, 5.858271567687853, 6.922664070309122, 7.888742910779811, 8.766698814091527, 7.699969820728201, 13.988613693488785, 14.934341699315736, 15.72965687608162, 14.699165818491839, 13.644230866953356, 12.662573740873563, 11.639122082276096, 10.663693591049743, 9.685483320768743, 8.760815595225909, 7.837213512047507, 6.843169270069777, 5.931226317379824, 4.881641756389735, 5.874759109658803, 6.797670156123033, 7.84508451295037, 8.797577867504314, 7.797734676304427, 6.8005863339255175, 14.79086512745863, 15.759948462609742, 16.70134749062291, 15.641748224242464, 14.58837990998683, 13.595206777772093, 12.638315664832417, 11.712078286084022, 10.696908318196892, 9.73872725806594, 8.854474129221394, 7.805315806945071, 6.910065394498751, 5.863397434730191, 6.937584414672051, 7.852693849185844, 8.78235560782674, 9.666393746346827, 8.739021588456241, 7.760360806634051, 15.722300809382737, 16.69255383153253, 16.388796212705245, 15.544317172434098, 14.485163658979964, 13.707982993404007, 12.776120610853585, 12.661262365533641, 11.706271013739201, 10.753221868100429, 9.784039958298205, 8.758118921230423, 7.849223626938928, 6.818554715034005, 7.784618257984945, 8.76634427841913, 9.719851331582245, 10.66671737183769, 9.674397909734328, 8.743653590280463, 16.568004610135468, 16.431072223277724, 15.449047920925157, 14.5674450967016, 13.54575746791291, 12.718906017015794, 11.823207201760573, 12.799079334513104, 12.630115259557215, 11.687388310654791, 10.724981396030218, 9.790083362385571, 8.791361568937596, 7.778781965110465, 8.712055125952599, 9.675325201025023, 10.679209709279132, 11.580671657050493, 10.637232948230752, 9.741096147957863, 16.482612627066782, 15.442978419148995, 14.453848174554926, 13.59041525800942, 12.601017937335833, 11.774076853296958, 10.866938740824235, 11.833797341690017, 12.77091475772924, 12.613771315089235, 11.718226323281286, 10.785059560164662, 9.719145489760365, 8.774064059158835, 9.705924439203448, 10.629651157589002, 11.659291793239118, 12.505690461930177, 11.626224375026855, 10.729534766179048, 15.505046728422178, 14.486340433381887, 13.503473631334876, 12.58767074991384, 11.650245945135579, 10.710839793195646, 9.864412350997105, 10.840496340184215, 11.765408153968961, 12.629969054197955, 12.646730653804864, 11.66995697547388, 10.699349323240556, 9.803733698724269, 10.632013849375587, 11.5974788936545, 12.62220584433247, 13.448707992772375, 12.592127994259046, 11.583375886131076, 14.526395994520493, 13.551453378602236, 12.573429453185362, 11.602779050390636, 10.615914297563286, 9.778240928447977, 8.853274252314716, 9.823519373370344, 10.70297177067101, 11.68994640802044, 12.542857648699671, 12.594934239726124, 11.6609146173287, 10.760670593736604, 11.657888112366962, 12.61709993959383, 13.570550821932732, 14.415939520429681, 13.543046363832723, 12.509227900089188, 13.457431297000303, 12.598795195788322, 11.626380330468622, 10.647697234636873, 9.599014137683342, 8.730832206309444, 7.88116721687677, 8.82871376462546, 9.719674916286465, 10.661740619826515, 11.609656032535023, 12.51807333805964, 12.663880496980426, 11.832215086907917, 12.652109355803551, 13.574044170961173, 14.62429741672335, 15.382819757184643, 14.487055301801687, 13.501873543875751, 12.513294298640254, 11.58622432612944, 10.553585822478658, 9.69283590803176, 8.663723591798362, 7.729587642620426, 6.816733332152344, 7.784599085226303, 8.758820022883462, 9.688772522261608, 10.586750272364238, 11.51060168600944, 12.49463297244118, 12.818313397633432, 13.67393151030415, 14.550792496827917, 15.573442579842501, 16.393746548344378, 15.483884000943723, 14.429132982602848, 11.557243529459626, 10.591598552241445, 9.625869319321167, 8.671807952986727, 7.732382339745515, 6.802089190215187, 5.820708200176221, 6.835050817151755, 7.793953338331805, 8.732314536051772, 9.640800199910377, 10.521790873277153, 11.496925840558735, 12.518691947561338, 13.460317448495525, 14.50396561154694, 15.435880129803248, 16.376493859459686, 16.31497378316326, 15.38844620465189, 10.635753221846965, 9.665438355483307, 8.638441747459519, 7.690565503362504, 6.7392375563784945, 5.7950406703307245, 4.820846357364295, 5.780394951885034, 6.736786477868992, 7.6976957593151685, 8.650241846318563, 9.585711976174174, 10.529979113588283, 11.554099537319832, 12.579839541923581, 13.528875267030786, 14.447823384843119, 15.38987988700057, 16.389437277760234, 16.41559979674003, 9.720108247691773, 8.658872400157703, 7.7127018105418435, 6.715138985879666, 5.835774061556332, 4.872518459437898, 3.882695462468055, 4.825761559532769, 5.782320241618973, 6.815855097918298, 7.745706111135398, 8.772668826074138, 9.727931531069451, 10.61451731994484, 11.58471941526276, 12.529287093906845, 13.49494964610573, 14.51020200522839, 15.514551253029621, 16.519046034725903, 8.771689194252456, 7.804165114535688, 6.762785871114399, 5.7553483397938745, 4.833993255570881, 3.8681381314131, 2.913304881500108, 3.8866627236635893, 4.84493876408961, 5.872299526498218, 6.92241510620169, 7.941818066827211, 8.68726654067105, 9.614467453724926, 10.633696349638235, 11.590201889910198, 12.598560552852865, 13.562822602470076, 14.544865847204655, 15.603577387214001, 7.725526064860118, 6.749535817917715, 5.818469091918133, 4.827814150584042, 3.8675745440380456, 2.8378001438399427, 1.8868235506439075, 2.9336025875017024, 3.9013797911134303, 4.827083545001012, 5.874722784529209, 6.9144083333624335, 7.745315448911784, 8.777025897182005, 9.691949371731686, 10.731671930495267, 11.697205556789775, 12.713494385766024, 13.7810177150627, 14.81352174152347, 6.725450625151963, 5.800110180218779, 4.849142853658704, 3.9031888811455313, 2.8908751320993153, 1.906198288249465, 0.9380078406064619, 1.8971920718236779, 2.869585963203767, 3.850003399247214, 4.908345325880829, 5.949851809692259, 6.8139614029197375, 7.745555511176627, 8.71815851435456, 9.78355603098439, 10.72876626489785, 11.78544960154106, 12.786637086082433, 13.850075566182236, 5.773816853982444, 4.800229953383837, 3.8609447591709958, 2.9333399371522395, 1.9506442746479244, 0.9668286865839286, 0.0, 0.9691418633528093, 1.9849252293206825, 3.0088771551579403, 3.951647923225732, 4.930638884154841, 5.878913090942303, 6.8645503656201665, 7.919405830957574, 8.953456657627592, 9.993559527846816, 11.00244756941343, 12.063406297498474, 13.04996128659468, 6.743768692523833, 5.848857864230149, 4.906679204321713, 3.9560700686335166, 3.011262258894556, 1.965310083054915, 1.0010702576593953, 1.9705615075872867, 2.9683865631351702, 3.935481508003495, 4.914480759129047, 5.840512486029375, 6.860295159185318, 7.804110863853344, 8.743895991714782, 9.743481457645082, 10.75317592822138, 11.732920627256902, 12.767786664013883, 13.708957075207119, 7.671454326158009, 6.818579131470645, 5.907473100446109, 4.925355493474767, 3.9887490609829057, 2.9144546613775852, 1.9587427983485708, 2.9358216040118648, 3.930792029400172, 4.960438115742356, 5.962205871562466, 6.84319986389352, 7.77412112302128, 8.800387286607176, 9.716118146777417, 10.719667554875114, 11.733284418337643, 12.75022956752505, 13.701421902676255, 14.769192570441142], [14.723788852196181, 13.745032958452352, 12.707171792410332, 11.752175242894031, 10.70277202121748, 9.730533053583295, 8.788912529889295, 7.7718439808140625, 6.856852260091191, 6.005468167090027, 5.007214662095466, 3.9636139979244898, 3.0336343127034437, 3.8686308426843423, 4.811987063334576, 5.821310058367937, 6.8730963916983, 7.802300564569671, 8.814511519608667, 9.62486841501735, 13.726746975382738, 14.670983714413898, 13.714648403278037, 12.724656432036316, 11.725897320618175, 10.704362197153344, 9.765114567178653, 8.730606921413177, 7.785305699068951, 6.866693144010977, 5.93426356296985, 5.001445429156589, 4.027991378305065, 4.865822148682115, 5.859642604276017, 6.827413431040663, 7.8918059336619315, 8.85788477413262, 9.735840677444335, 8.66911168408101, 13.019471830135975, 13.965199835962926, 14.769463142340435, 13.738972084750653, 12.68403713321217, 11.702380007132378, 10.720853083284858, 9.745424592058505, 8.767214321777505, 7.88449936895582, 6.960897285777418, 5.966853043799688, 5.057252023198086, 5.850783619742544, 6.843900973011612, 7.766812019475842, 8.814226376303179, 9.766719730857123, 8.766876539657234, 7.769728197278326, 13.82172326410582, 14.790806599256932, 15.779388530207633, 14.723479225251227, 13.670110910995593, 12.676937778780855, 11.72004666584118, 10.793809287092785, 9.818739849963183, 8.86241103179585, 7.978157902951304, 6.928999580674981, 6.036516281936912, 6.832539298083001, 7.906726278024861, 8.821835712538654, 9.75149747117955, 10.635535609699636, 9.70816345180905, 8.729502669986859, 14.753158946029927, 15.723411968179716, 16.659107232453447, 15.671014654091456, 14.630966440747192, 13.716912763164517, 12.67256162532652, 11.742993366542404, 10.828102545505493, 9.876905641830337, 8.907723732028115, 7.881802694960333, 7.109136401545782, 7.787696578386814, 8.753760121337754, 9.73548614177194, 10.688993194935053, 11.635859235190498, 10.643539773087136, 9.712795453633271, 15.598862746782657, 16.612703077146538, 16.418189784277967, 15.536586960054409, 14.514899331265719, 13.688047880368604, 12.792349065113383, 12.181425830733884, 11.753799033287125, 10.811072084384701, 9.848665169760128, 8.913767136115482, 8.058136219343963, 8.747923828463275, 9.681196989305409, 10.644467064377833, 11.648351572631942, 12.549813520403301, 11.60637481158356, 10.710238011310672, 16.55403502772447, 16.412120282501803, 15.422990037907736, 14.559557121362229, 13.570159800688641, 12.743218716649768, 11.836080604177045, 11.182861078545958, 11.859568523924535, 11.737455088819145, 10.90550930298992, 9.972342539873296, 9.00474276338506, 9.743205922511645, 10.675066302556258, 11.598793020941812, 12.628433656591929, 13.474832325282986, 12.595366238379663, 11.698676629531857, 16.474188591774986, 15.455482296734697, 14.472615494687686, 13.556812613266649, 12.619387808488387, 11.679981656548454, 10.833554214349915, 10.148907216827785, 10.854061920164256, 11.71862282039325, 11.888450433394459, 10.911676755063475, 9.984946596865251, 10.772875562077079, 11.601155712728398, 12.56662075700731, 13.59134770768528, 14.417849856125184, 13.561269857611855, 12.552517749483885, 15.495537857873302, 14.520595241955046, 13.542571316538172, 12.571920913743444, 11.585056160916094, 10.747382791800785, 9.822416115667526, 9.09826665660804, 9.791625536866304, 10.778600174215734, 11.631511414894968, 11.88053151335082, 10.946511890953396, 11.729812457089414, 12.627029975719772, 13.58624180294664, 14.539692685285543, 15.38508138378249, 14.512188227185531, 13.478369763441997, 14.426573160353112, 13.56793705914113, 12.59552219382143, 11.616839097989681, 10.56815600103615, 9.699974069662252, 8.85030908022958, 8.09378956466546, 8.80832868248176, 9.75039438602181, 10.69830979873032, 11.606727104254936, 11.949477770605121, 12.801356950260727, 13.621251219156362, 14.543186034313983, 15.59343928007616, 16.351961620537452, 15.456197165154496, 14.47101540722856, 13.482436161993062, 12.555366189482248, 11.522727685831466, 10.66197777138457, 9.63286545515117, 8.698729505973235, 7.785875195505153, 7.049674885266304, 7.847473789078758, 8.777426288456907, 9.675404038559535, 10.599255452204737, 11.583286738636476, 12.549051031620463, 13.488423396811989, 14.482738982078304, 15.507858738732802, 16.415960028981495, 16.45302586429653, 15.398274845955656, 12.526385392812434, 11.560740415594253, 10.595011182673975, 9.640949816339537, 8.701524203098325, 7.7712310535679965, 6.78985006352903, 6.0766003281998895, 6.882607104527102, 7.820968302247071, 8.729453966105673, 9.61044463947245, 10.585579606754031, 11.607345713756635, 12.548971214690821, 13.592619377742237, 14.513988937819756, 15.407351996106879, 16.468588923715107, 16.3575880680047, 11.604895085199773, 10.634580218836115, 9.607583610812327, 8.659707366715313, 7.708379419731304, 6.764182533683534, 5.789988220717104, 5.00761354628428, 5.825440244064289, 6.786349525510466, 7.7388956125138595, 8.67436574236947, 9.61863287978358, 10.642753303515128, 11.668493308118878, 12.563876001011431, 13.478681521490312, 14.420738023647763, 15.420295414407427, 16.352493088999086, 10.689250111044581, 9.628014263510511, 8.681843673894653, 7.684280849232476, 6.8049159249091415, 5.841660322790707, 4.851837325820864, 3.964729121319836, 4.868327054887885, 5.90186191118721, 6.83171292440431, 7.85867563934305, 8.758789667716643, 9.645375456592031, 10.615577551909952, 11.560145230554038, 12.525807782752924, 13.541060141875583, 14.545409389676811, 15.549904171373093, 9.740831057605265, 8.773306977888497, 7.731927734467208, 6.724490203146684, 5.803135118923691, 4.837279994765909, 3.8824467448529174, 3.0256302854506565, 3.9309455773585227, 4.95830633976713, 6.008421919470603, 7.027824880096124, 7.718124677318242, 8.645325590372117, 9.664554486285425, 10.621060026557387, 11.629418689500055, 12.593680739117266, 13.575723983851844, 14.63443552386119, 8.694667928212926, 7.718677681270524, 6.787610955270942, 5.7969560139368514, 4.836716407390854, 3.806942007192752, 2.8559654139967168, 2.0417805785950374, 2.987386604382343, 3.9130903582699252, 4.960729597798122, 6.0004151466313465, 6.776173585558975, 7.807884033829196, 8.722807508378876, 9.762530067142457, 10.728063693436965, 11.744352522413214, 12.811875851709889, 13.84437987817066, 7.694592488504771, 6.769252043571588, 5.8182847170115135, 4.87233074449834, 3.8600169954521246, 2.8753401516022743, 1.9071497039592713, 0.9831988850925905, 1.9555927764726793, 2.936010212516127, 3.93920346252802, 4.9807099463394495, 5.844819539566928, 6.7764136478238175, 7.7490166510017495, 8.814414167631579, 9.75962440154504, 10.81630773818825, 11.817495222729622, 12.880933702829426, 6.742958717335252, 5.769371816736645, 4.830086622523805, 3.902481800505049, 2.9197861380007337, 1.935970549936738, 0.9691418633528093, 0.0, 1.0157833659678732, 2.039735291805131, 2.982506059872923, 3.9614970208020317, 4.909771227589494, 5.895408502267357, 6.950263967604765, 7.984314794274782, 9.024417664494006, 10.03330570606062, 11.094264434145664, 12.08081942324187, 7.7129105558766415, 6.817999727582958, 5.875821067674522, 4.925211931986326, 3.980404122247365, 2.9344519464077243, 1.9702121210122046, 1.0697679182715982, 2.013641009317617, 2.966339644650686, 3.9453388957762376, 4.871370622676566, 5.891153295832509, 6.834969000500535, 7.774754128361972, 8.774339594292274, 9.784034064868571, 10.763778763904094, 11.798644800661075, 12.73981521185431, 8.640596189510818, 7.787720994823453, 6.876614963798918, 5.894497356827577, 4.9578909243357145, 3.8835965247303945, 2.92788466170138, 2.0350280146961763, 3.026896300087757, 4.038036925031289, 4.9930640082096565, 5.87405800054071, 6.804979259668471, 7.831245423254366, 8.746976283424608, 9.750525691522306, 10.764142554984835, 11.78108770417224, 12.732280039323445, 13.800050707088332], [13.708005486228307, 12.729249592484479, 11.691388426442456, 10.736391876926156, 9.686988655249605, 8.71474968761542, 7.773129163921421, 6.756060614846189, 5.8410688941233175, 4.989684801122153, 4.005697119347605, 2.962096455176629, 3.892076140397675, 4.863592670497657, 5.806948891147891, 6.8162718861812515, 7.868058219511615, 8.797262392382986, 9.815730764171395, 10.64065178098522, 12.710963609414865, 13.655200348446023, 12.698865037310162, 11.70887306606844, 10.7101139546503, 9.688578831185469, 8.74933120121078, 7.714823555445303, 6.769522333101078, 5.865175601263116, 4.932746020221989, 3.999927886408728, 4.886433205999296, 5.86078397649543, 6.854604432089332, 7.822375258853977, 8.886767761475246, 9.852846601945934, 10.751624043412207, 9.684895050048882, 12.003688464168105, 12.949416469995056, 13.75367977637256, 12.723188718782778, 11.668253767244295, 10.686596641164503, 9.705069717316984, 8.729641226090632, 7.7514309558096315, 6.882981826207959, 5.959379743029557, 4.965335501051827, 5.915693850892318, 6.845745447555859, 7.838862800824927, 8.761773847289156, 9.809188204116493, 10.782503096824994, 9.782659905625106, 8.785511563246198, 12.805939898137947, 13.775023233289058, 14.76360516423976, 13.707695859283353, 12.65432754502772, 11.661154412812982, 10.704263299873306, 9.778025921124911, 8.80295648399531, 7.860893489047989, 6.976640360203444, 5.9274820379271205, 6.894958109631143, 7.827501125896315, 8.901688105838176, 9.816797540351967, 10.746459298992864, 11.651318975667508, 10.723946817776921, 9.74528603595473, 13.737375580062054, 14.707628602211843, 15.643323866485574, 14.655231288123582, 13.615183074779319, 12.701129397196643, 11.656778259358646, 10.72721000057453, 9.812319179537619, 8.875388099082478, 7.906206189280254, 6.880285152212473, 7.907682782457926, 8.78265840620013, 9.748721949151069, 10.730447969585255, 11.683955022748368, 12.630821063003813, 11.659323139055008, 10.728578819601143, 14.583079380814784, 15.596919711178666, 16.532170534947152, 15.576276894635063, 14.554589265846372, 13.657224403290702, 12.609691668451658, 11.71886931330771, 10.752281490539266, 9.809554541636842, 8.84714762701227, 7.912249593367622, 8.856682600256107, 9.74288565627659, 10.676158817118722, 11.639428892191146, 12.643313400445255, 13.565596886371173, 12.622158177551432, 11.726021377278544, 15.538251661756595, 16.577885869674382, 16.438773403875608, 15.575340487330102, 14.585943166656515, 13.759002082617641, 12.840175117236871, 11.932255804672149, 10.937217554591685, 10.735937546071286, 9.903991760242059, 8.970824997125435, 9.803289144297205, 10.73816775032496, 11.670028130369571, 12.593754848755125, 13.623395484405242, 14.490615691250857, 13.611149604347535, 12.714459995499729, 16.410629213693685, 16.47126566270257, 15.48839886065556, 14.572595979234523, 13.63517117445626, 12.695765022516328, 11.837648727409741, 10.90690606789147, 9.931710950831405, 10.7962718510604, 10.886932890646598, 9.910159212315614, 10.783492977777396, 11.743348708022099, 12.59611754054171, 13.561582584820624, 14.586309535498593, 15.433633222093055, 14.577053223579727, 13.568301115451757, 16.511321223841172, 15.53637860792292, 14.558354682506046, 13.587704279711318, 12.600839526883968, 11.763166157768659, 10.826510628727352, 9.856265507671724, 8.869274567533454, 9.856249204882884, 10.709160445562116, 10.923044312461034, 11.745058271865542, 12.700285603034434, 13.621991803533085, 14.581203630759953, 15.534654513098856, 16.40086474975036, 15.527971593153403, 14.494153129409868, 15.442356526320983, 14.583720425109002, 13.611305559789303, 12.632622463957555, 11.583939367004024, 10.715757435630126, 9.866092446197454, 8.943254843956877, 7.885977713148908, 8.82804341668896, 9.775958829397467, 10.684376134922084, 11.676699271403459, 12.581278376509959, 13.556374585476568, 14.505616342109029, 15.44122053588408, 16.394154357115966, 16.471980531122366, 15.486798773196432, 14.498219527960934, 13.57114955545012, 12.538511051799338, 11.677761137352444, 10.648648821119044, 9.714512871941109, 8.801658561473028, 7.899140164557721, 6.925122819745906, 7.855075319124054, 8.753053069226683, 9.676904482871885, 10.660935769303624, 11.595180065784444, 12.53455243097597, 13.528868016242285, 14.492075372764928, 15.40017666301362, 16.390070632804765, 16.41405821192353, 13.542168758780306, 12.576523781562125, 11.610794548641847, 10.65673318230741, 9.717307569066199, 8.78701441953587, 7.805633429496904, 6.9260656074913065, 5.96025613519425, 6.898617332914217, 7.80710299677282, 8.688093670139597, 9.663228637421179, 10.623292584121765, 11.564918085055952, 12.608566248107367, 13.498205571851882, 14.391568630139005, 15.452805557747231, 16.363863315119353, 12.620678451167645, 11.650363584803987, 10.623366976780199, 9.675490732683185, 8.724162785699178, 7.779965899651407, 6.805771586684978, 5.859480800715394, 4.903089274731436, 5.863998556177613, 6.816544643181007, 7.752014773036618, 8.696281910450725, 9.65870017388026, 10.66587178680297, 11.548092635043558, 12.462898155522439, 13.40495465767989, 14.404512048439553, 15.336709723031214, 11.705033477012453, 10.643797629478383, 9.697627039862525, 8.700064215200348, 7.820699290877014, 6.857443688758581, 5.867620691788738, 4.938369733323804, 3.9459760855550323, 4.9795109418543575, 5.909361955071457, 6.9363246700101975, 7.743006301748771, 8.629592090624158, 9.599794185942079, 10.544361864586165, 11.51002441678505, 12.52527677590771, 13.529626023708937, 14.53412080540522, 10.756614423573138, 9.78909034385637, 8.747711100435081, 7.7402735691145566, 6.818918484891563, 5.853063360733782, 4.898230110820791, 4.04141365141853, 3.0085946080256694, 4.035955370434277, 5.01034809056356, 6.029751051189081, 6.702341311350369, 7.6295422244042435, 8.648771120317551, 9.605276660589514, 10.613635323532181, 11.577897373149392, 12.55994061788397, 13.618652157893317, 9.7104512941808, 8.734461047238398, 7.803394321238816, 6.812739379904724, 5.852499773358727, 4.822725373160624, 3.87174877996459, 3.0575639445629106, 2.06503563504949, 2.990739388937072, 3.9626557688910786, 5.002341317724303, 5.760390219591102, 6.792100667861323, 7.7070241424110035, 8.746746701174585, 9.712280327469092, 10.72856915644534, 11.796092485742015, 12.828596512202786, 8.710375854472643, 7.785035409539462, 6.834068082979387, 5.888114110466214, 4.875800361419998, 3.891123517570147, 2.9229330699271445, 1.9989822510604638, 1.0332418071398262, 2.0136592431832736, 2.9234200965601467, 3.9649265803715767, 4.8290361735990555, 5.760630281855945, 6.733233285033877, 7.798630801663706, 8.743841035577166, 9.800524372220377, 10.801711856761749, 11.865150336861552, 7.758742083303124, 6.785155182704518, 5.845869988491677, 4.918265166472922, 3.9355695039686065, 2.951753915904611, 1.9849252293206825, 1.0157833659678732, 0.0, 1.0239519258372578, 1.9667226939050497, 2.9457136548341585, 3.8939878616216212, 4.8796251362994845, 5.934480601636892, 6.96853142830691, 8.008634298526136, 9.01752234009275, 10.078481068177794, 11.065036057274, 8.728693921844513, 7.8337830935508315, 6.891604433642396, 5.940995297954199, 4.996187488215238, 3.931016522371817, 2.9651739488255187, 1.9956826988976275, 0.997857643349744, 1.9505562786828126, 2.929555529808364, 3.855587256708692, 4.875369929864634, 5.81918563453266, 6.758970762394098, 7.758556228324399, 8.768250698900697, 9.74799539793622, 10.782861434693201, 11.724031845886437, 9.65637955547869, 8.803504360791326, 7.873179539763011, 6.891061932791669, 5.954455500299807, 4.880161100694487, 3.9228464895146944, 2.9609427953222056, 2.011112934119884, 3.022253559063415, 3.977280642241783, 4.858274634572837, 5.789195893700597, 6.815462057286492, 7.731192917456733, 8.73474232555443, 9.74835918901696, 10.765304338204366, 11.716496673355572, 12.784267341120458], [12.684053560391048, 11.705297666647219, 10.667436500605199, 9.712439951088898, 8.663036729412347, 7.690797761778161, 6.7491772380841635, 5.732108689008931, 4.81711696828606, 3.9657328752848953, 3.037561554129666, 3.925259687288311, 4.855239372509358, 5.826755902609339, 6.7701121232595725, 7.779435118292933, 8.831221451623296, 9.760425624494667, 10.778893996283076, 11.66460370682248, 11.687011683577605, 12.631248422608765, 11.674913111472904, 10.684921140231182, 9.686162028813042, 8.66462690534821, 7.725379275373521, 6.690871629608045, 5.74557040726382, 5.004783727383673, 4.106920483482444, 4.96309111852041, 5.849596438110979, 6.823947208607112, 7.817767664201014, 8.78553849096566, 9.849930993586929, 10.816009834057617, 11.775575969249465, 10.70884697588614, 10.979736538330847, 11.925464544157798, 12.729727850535301, 11.69923679294552, 10.644301841407037, 9.662644715327245, 8.681117791479727, 7.705689300253374, 6.727479029972374, 6.022589952328516, 5.133554206290012, 5.928498733163509, 6.878857083004, 7.808908679667541, 8.80202603293661, 9.724937079400839, 10.772351436228176, 11.759952125289878, 10.806611831462364, 9.809463489083456, 11.781987972300689, 12.7510713074518, 13.7396532384025, 12.683743933446095, 11.630375619190461, 10.637202486975724, 9.680311374036048, 8.754073995287653, 7.779004558158052, 7.000501615168545, 6.159023215448268, 6.890645270038803, 7.858121341742826, 8.790664358007998, 9.864851337949858, 10.77996077246365, 11.709622531104547, 12.675270901504765, 11.74789874361418, 10.769237961791989, 12.713423654224796, 13.683676676374585, 14.619371940648318, 13.631279362286325, 12.591231148942061, 11.677177471359386, 10.632826333521388, 9.703258074737272, 8.788367253700361, 8.014996225203035, 7.088589044525078, 7.843448384324155, 8.870846014569608, 9.745821638311812, 10.711885181262751, 11.693611201696937, 12.64711825486005, 13.593984295115495, 12.683275064892266, 11.752530745438401, 13.559127454977528, 14.57296778534141, 15.508218609109894, 14.552324968797805, 13.530637340009115, 12.633272477453444, 11.5857397426144, 10.734281359083836, 9.829530130704095, 8.952775443835499, 8.08753660080607, 8.875412825479303, 9.81984583236779, 10.706048888388272, 11.639322049230405, 12.602592124302829, 13.606476632556937, 14.529822955133682, 13.64611010338869, 12.749973303115802, 14.514299735919339, 15.553933943837125, 16.436437043726755, 15.461711293127637, 14.47231397245405, 13.467096155055437, 12.542008203550738, 11.732846111271762, 10.774081247291054, 9.879158448269942, 9.149890468184786, 9.933988229237118, 10.766452376408887, 11.701330982436643, 12.633191362481254, 13.556918080866808, 14.586558716516924, 15.454841760013366, 14.635101530184793, 13.738411921336986, 15.38667728785643, 16.420880030714827, 16.380737873521568, 15.464934992100535, 14.527510187322273, 13.58810403538234, 12.716729931724595, 11.785987272206324, 10.81079215514626, 10.067558403573116, 10.217361212389198, 10.873322444427297, 11.746656209889078, 12.706511940133781, 13.559280772653393, 14.524745816932306, 15.549472767610276, 16.397859290855564, 15.569731504127297, 14.560979395999327, 16.306437088456562, 16.42871762078893, 15.450693695372056, 14.48004329257733, 13.49317853974998, 12.65550517063467, 11.705591833042206, 10.735346711986578, 9.748355771848308, 9.1275357573956, 9.83494758508046, 10.770438437118967, 11.70445805951639, 12.628870943844015, 13.526643903075902, 14.438608647639114, 15.392059529978017, 16.33708266803367, 16.52064987370097, 15.48683140995744, 16.435034806868554, 15.520361704961433, 14.506114559381649, 13.524961476823567, 12.476278379870037, 11.608096448496138, 10.758431459063466, 9.822336048271733, 8.765058917463763, 8.099329969201676, 8.901745968915812, 9.810163274440427, 10.713580559639613, 11.557326450672702, 12.532422659639312, 13.481664416271773, 14.417268610046824, 15.37020243127871, 16.362947406109548, 16.479477053744002, 15.490897808508505, 14.56382783599769, 13.531189332346909, 12.570100150218455, 11.540987833985056, 10.60685188480712, 9.69399757433904, 8.778221368872577, 7.804204024060762, 7.111262842139564, 7.878840208745027, 8.802691622390228, 9.697817057539778, 10.571228139947188, 11.510600505138713, 12.504916090405029, 13.468123446927672, 14.376224737176363, 15.36611870696751, 16.299224611331137, 14.534847039327877, 13.569202062109696, 12.603472829189418, 11.614653141670225, 10.609646581932209, 9.679353432401882, 8.697972442362916, 7.805146811806162, 6.839337339509106, 6.1548048559297275, 6.932890136291165, 7.813880809657941, 8.700109925657333, 9.59934065828451, 10.540966159218696, 11.584614322270111, 12.474253646014626, 13.36761670430175, 14.428853631909975, 15.339911389282095, 13.613356731715216, 12.643041865351558, 11.61604525732777, 10.668169013230756, 9.616501798565189, 8.672304912517419, 7.69811059955099, 6.738562005030251, 5.782170479046293, 5.1201860791931235, 5.942331782699351, 6.877801912554962, 7.710082902654007, 8.634748248043003, 9.641919860965714, 10.524140709206302, 11.438946229685182, 12.381002731842633, 13.380560122602297, 14.312757797193958, 12.72898540284971, 11.667749555315641, 10.721578965699782, 9.724016141037605, 8.813818816763225, 7.818597937614338, 6.828774940644495, 5.817450937638661, 4.825057289869889, 4.144721329858928, 4.929641178878375, 5.956603893817116, 6.719054375911514, 7.605640164786902, 8.575842260104823, 9.520409938748909, 10.486072490947794, 11.501324850070453, 12.505674097871681, 13.510168879567964, 11.780566349410394, 10.813042269693629, 9.77166302627234, 8.764225494951814, 7.814871499279854, 6.849016375122073, 5.894183125209081, 4.9208252830456, 3.887675812340526, 3.069971865925867, 3.986396164726302, 5.005799125351823, 5.678389385513112, 6.6055902985669865, 7.6248191944802945, 8.581324734752258, 9.589683397694925, 10.553945447312136, 11.535988692046715, 12.594700232056061, 10.734403220018056, 9.758412973075654, 8.827346247076074, 7.836691305741982, 6.876451699195985, 5.846677298997882, 4.882798670515802, 3.9369755761899805, 2.9441168393643466, 1.9990675475914026, 2.938703843053821, 3.9783893918870454, 4.736438293753845, 5.768148742024066, 6.683072216573746, 7.722794775337327, 8.688328401631834, 9.704617230608083, 10.772140559904757, 11.804644586365528, 9.7343277803099, 8.808987335376719, 7.858020008816645, 6.912066036303472, 5.899752287257256, 4.915075443407405, 3.9339829604783567, 2.9747987292611406, 2.002404837881052, 1.0219874018376043, 1.8994681707228889, 2.940974654534319, 3.805084247761798, 4.736678356018687, 5.709281359196619, 6.7746788758264485, 7.719889109739908, 8.776572446383119, 9.777759930924491, 10.841198411024294, 8.782694009140382, 7.809107108541776, 6.869821914328935, 5.942217092310179, 4.959521429805864, 3.9757058417418687, 3.0088771551579403, 2.039735291805131, 1.0239519258372578, 0.0, 0.9427707680677918, 1.9217617289969007, 2.8700359357843634, 3.855673210462226, 4.910528675799634, 5.944579502469653, 6.984682372688877, 7.993570414255492, 9.054529142340536, 10.041084131436742, 9.752645847681771, 8.824818280907031, 7.863280999613631, 6.912671863925435, 5.967864054186474, 4.894179754483499, 3.9283371809372007, 2.9588459310093094, 1.961020875461426, 0.9266043528455546, 1.9056036039711062, 2.831635330871434, 3.851418004027377, 4.795233708695402, 5.73501883655684, 6.734604302487141, 7.744298773063439, 8.72404347209896, 9.758909508855941, 10.700079920049177, 10.680331481315948, 9.794539548147526, 8.836342771874694, 7.854225164903352, 6.91761873241149, 5.843324332806169, 4.886009721626376, 3.9241060274338873, 2.974276166231566, 1.9983016332261574, 2.953328716404525, 3.8343227087355785, 4.76524396786334, 5.791510131449234, 6.707240991619475, 7.7107903997171725, 8.724407263179701, 9.741352412367107, 10.692544747518312, 11.760315415283198], [11.752332611857257, 10.773576718113429, 9.735715552071406, 8.780719002555106, 7.731315780878553, 6.759076813244368, 5.840069096004832, 4.8230005469296, 3.908008826206729, 3.056624733205564, 3.980332322197458, 4.868030455356102, 5.798010140577149, 6.769526670677131, 7.712882891327364, 8.722205886360726, 9.773992219691088, 10.70319639256246, 11.721664764350868, 12.607374474890271, 10.755290735043813, 11.699527474074973, 10.743192162939112, 9.75320019169739, 8.754441080279248, 7.732905956814417, 6.816271133294189, 5.781763487528714, 4.836462265184489, 4.095675585304342, 5.028105166345469, 5.905861886588202, 6.79236720617877, 7.7667179766749035, 8.760538432268806, 9.728309259033452, 10.79270176165472, 11.758780602125409, 12.718346737317257, 11.651617743953931, 10.036965770263055, 10.982693776090006, 11.798006902001507, 10.767515844411726, 9.712580892873243, 8.73092376679345, 7.772009649400396, 6.7965811581740425, 5.8183708878930425, 5.113481810249184, 6.047850119700065, 6.871269501231301, 7.821627851071791, 8.751679447735333, 9.744796801004401, 10.66770784746863, 11.715122204295968, 12.70272289335767, 11.749382599530156, 10.752234257151247, 10.839217204232897, 11.808300539384009, 12.807932289868706, 11.774635791366766, 10.721267477111132, 9.728094344896395, 8.771203231956719, 7.844965853208322, 6.869896416078721, 6.091393473089214, 7.073319128858321, 7.833416038106595, 8.800892109810617, 9.73343512607579, 10.80762210601765, 11.722731540531441, 12.652393299172338, 13.618041669572557, 12.690669511681971, 11.71200872985978, 11.770652886157004, 12.740905908306793, 13.676601172580526, 12.722171220206995, 11.682123006862732, 10.768069329280056, 9.723718191442057, 8.794149932657941, 7.879259111621031, 7.105888083123703, 8.002884957935132, 8.786219152391947, 9.8136167826374, 10.688592406379604, 11.654655949330543, 12.636381969764729, 13.589889022927842, 14.536755063183287, 13.626045832960058, 12.695301513506193, 12.616356686909734, 13.630197017273616, 14.599110467030565, 13.643216826718476, 12.621529197929785, 11.724164335374113, 10.67663160053507, 9.825173217004505, 8.920421988624764, 8.043667301756168, 9.001832514216124, 9.818183593547095, 10.762616600435582, 11.648819656456064, 12.582092817298197, 13.54536289237062, 14.54924740062473, 15.472593723201474, 14.588880871456482, 13.692744071183593, 13.571528967851545, 14.611163175769331, 15.527328901647424, 14.552603151048306, 13.563205830374718, 12.557988012976105, 11.632900061471407, 10.82373796919243, 9.864973105211723, 8.970050306190611, 10.002284718723857, 10.87675899730491, 11.70922314447668, 12.644101750504435, 13.575962130549046, 14.4996888489346, 15.529329484584716, 16.397612528081158, 15.577872298252585, 14.681182689404778, 14.443906519788635, 15.478109262647031, 16.44503936675127, 15.48260407072174, 14.513977822574972, 13.571517055234528, 12.635426451298537, 11.857691830910603, 10.870479708972002, 9.955017674370328, 9.871278508194916, 10.840552769196595, 11.723252585536745, 12.643037070788557, 13.604051031033476, 14.515518795693707, 15.426380866920404, 16.361543427623182, 16.51250227219509, 15.50375016406712, 15.363666320388766, 16.436379745249674, 16.393464463439848, 15.422814060645122, 14.435949307817772, 13.598275938702463, 12.64836260111, 11.678117480054372, 10.691126539916102, 9.847305382880272, 8.892176817012668, 9.827667669051175, 10.761687291448599, 11.686100175776222, 12.583873135008108, 13.495837879571319, 14.449288761910221, 15.394311899965876, 16.350975699664993, 16.42960217802523, 16.42819286826397, 16.463132473029223, 15.44888532744944, 14.467732244891359, 13.419049147937828, 12.55086721656393, 11.701202227131258, 10.765106816339525, 9.707829685531557, 8.871330063370431, 7.95897520084802, 8.867392506372635, 9.77080979157182, 10.614555682604909, 11.589651891571519, 12.538893648203977, 13.474497841979028, 14.427431663210914, 15.42017663804175, 16.28371328199044, 16.4336685765763, 15.506598604065482, 14.4739601004147, 13.512870918286247, 12.483758602052848, 11.549622652874913, 10.636768342406832, 9.72099213694037, 8.746974792128555, 7.883262936308319, 6.936069440677235, 7.859920854322436, 8.755046289471984, 9.628457371879394, 10.56782973707092, 11.562145322337235, 12.525352678859877, 13.433453969108568, 14.423347938899715, 15.356453843263342, 15.477617807395669, 14.511972830177488, 13.54624359725721, 12.557423909738016, 11.55241735, 10.622124200469674, 9.640743210430708, 8.747917579873954, 7.782108107576898, 6.926804950098482, 5.990119368223373, 6.871110041590149, 7.75733915758954, 8.656569890216716, 9.598195391150902, 10.641843554202318, 11.53148287794683, 12.424845936233954, 13.48608286384218, 14.3971406212143, 14.556127499783008, 13.58581263341935, 12.558816025395561, 11.610939781298548, 10.55927256663298, 9.61507568058521, 8.640881367618782, 7.681332773098043, 6.724941247114085, 5.892186173361878, 4.999561014631559, 5.93503114448717, 6.767312134586215, 7.691977479975209, 8.69914909289792, 9.581369941138506, 10.496175461617387, 11.438231963774838, 12.437789354534502, 13.369987029126163, 13.671756170917503, 12.610520323383433, 11.664349733767574, 10.666786909105397, 9.75658958483102, 8.76136870568213, 7.771545708712287, 6.760221705706453, 5.767828057937681, 4.916721424027684, 3.986870410810584, 5.013833125749324, 5.776283607843721, 6.662869396719108, 7.633071492037029, 8.577639170681113, 9.543301722879999, 10.558554082002658, 11.562903329803888, 12.56739811150017, 12.723337117478186, 11.75581303776142, 10.714433794340131, 9.706996263019606, 8.757642267347645, 7.791787143189865, 6.836953893276873, 5.863596051113392, 4.830446580408318, 4.012742633993659, 3.04362539665851, 4.063028357284031, 4.735618617445319, 5.662819530499194, 6.682048426412503, 7.638553966684465, 8.646912629627131, 9.611174679244343, 10.593217923978921, 11.651929463988267, 11.677173988085848, 10.701183741143446, 9.770117015143866, 8.779462073809773, 7.819222467263777, 6.789448067065674, 5.825569438583594, 4.879746344257772, 3.8868876074321386, 2.9418383156591945, 1.995933074986029, 3.0356186238192535, 3.7936675256860526, 4.825377973956274, 5.740301448505954, 6.780024007269535, 7.745557633564042, 8.76184646254029, 9.829369791836966, 10.861873818297736, 10.677098548377693, 9.75175810344451, 8.800790776884437, 7.8548368043712635, 6.842523055325048, 5.857846211475197, 4.876753728546149, 3.9175694973289326, 2.945175605948844, 1.9647581699053962, 0.956697402655097, 1.9982038864665268, 2.8623134796940057, 3.793907587950895, 4.766510591128827, 5.8319081077586565, 6.777118341672116, 7.833801678315327, 8.834989162856699, 9.898427642956502, 9.725464777208174, 8.751877876609568, 7.812592682396727, 6.884987860377971, 5.902292197873656, 4.918476609809661, 3.951647923225732, 2.982506059872923, 1.9667226939050497, 0.9427707680677918, 0.0, 0.9789909609291088, 1.9272651677165713, 2.9129024423944343, 3.9677579077318423, 5.001808734401861, 6.0419116046210855, 7.0507996461877, 8.111758374272744, 9.09831336336895, 10.695416615749563, 9.767589048974823, 8.806051767681423, 7.855442631993227, 6.9106348222542655, 5.836950522551291, 4.871107949004992, 3.901616699077101, 2.9037916435292175, 1.8693751209133465, 0.9964954618917754, 1.9225271887921034, 2.9196970554935833, 3.8635127601616093, 4.803297888023047, 5.802883353953348, 6.8125778245296456, 7.792322523565168, 8.82718856032215, 9.768358971515385, 11.62310224938374, 10.737310316215318, 9.779113539942484, 8.796995932971143, 7.860389500479282, 6.786095100873961, 5.828780489694168, 4.866876795501679, 3.9170469342993575, 2.9410724012939493, 2.0442205743251938, 2.9252145666562477, 3.8561358257840084, 4.870485498995453, 5.775520043085682, 6.779069451183379, 7.792686314645908, 8.809631463833314, 9.76082379898452, 10.828594466749406], [10.773341650928147, 9.794585757184318, 8.756724591142296, 7.801728041625997, 6.752324819949445, 5.78008585231526, 4.936191593658284, 3.919123044583052, 3.004131323860181, 3.956540405882687, 4.959323283126567, 5.847021416285212, 6.777001101506259, 7.74851763160624, 8.691873852256474, 9.701196847289836, 10.752983180620198, 11.68218735349157, 12.700655725279978, 13.586365435819381, 9.776299774114703, 10.720536513145863, 9.764201202010002, 8.77420923076828, 7.775450119350141, 6.753914995885308, 5.912393630947642, 4.877885985182167, 3.932584762837941, 4.893150090617064, 5.825579671658192, 6.758397805471453, 7.77135816710788, 8.745708937604013, 9.739529393197916, 10.707300219962562, 11.77169272258383, 12.737771563054519, 13.697337698246367, 12.630608704883041, 9.057974809333945, 10.003702815160896, 10.8190159410724, 9.78852488348262, 8.733589931944136, 7.751932805864343, 6.868132147053849, 5.8927036558274954, 4.9144933855464945, 5.910956315561907, 6.845324625012788, 7.723805420114552, 8.760928724561474, 9.73067040866444, 10.72378776193351, 11.64669880839774, 12.694113165225078, 13.68171385428678, 12.728373560459266, 11.731225218080358, 9.860226243303789, 10.8293095784549, 11.8289413289396, 10.796850807433579, 9.743482493177945, 8.750309360963207, 7.8673257296101715, 6.941088350861776, 5.966018913732173, 6.888867978401937, 7.870793634171044, 8.685951956989845, 9.73476810926895, 10.712426087004896, 11.786613066946757, 12.701722501460551, 13.631384260101449, 14.597032630501667, 13.669660472611081, 12.69099969078889, 10.791661925227896, 11.761914947377685, 12.697610211651416, 11.744386236273808, 10.704338022929544, 9.790284345346869, 8.81984068909551, 7.890272430311395, 6.975381609274483, 7.903362588436425, 8.800359463247855, 9.638755071275197, 10.666152701520652, 11.66758336730871, 12.63364691025965, 13.615372930693836, 14.568879983856952, 15.515746024112397, 14.605036793889168, 13.674292474435303, 11.637365725980626, 12.651206056344508, 13.621325483097378, 12.665431842785289, 11.643744213996598, 10.779361321735083, 9.772754098188523, 8.921295714657958, 8.016544486278217, 8.84114180706889, 9.799307019528847, 10.670719512430345, 11.615152519318833, 12.627732123145964, 13.561083778227303, 14.524353853299727, 15.528238361553836, 16.451584684130584, 15.567871832385592, 14.671735032112704, 12.592538006922437, 13.632172214840223, 14.552606815846381, 13.577881065247263, 12.588483744573676, 11.65411051062956, 10.72902255912486, 9.919860466845885, 8.961095602865177, 9.767524811503334, 10.79975922403658, 11.009329147870918, 11.736553837862774, 12.681635268464303, 13.551149480276507, 14.504355570830098, 15.410303957084649, 16.32556999753627, 16.556863259181696, 15.660173650333888, 13.464915558859525, 14.499118301717921, 15.470317280950226, 14.507881984920697, 13.53925573677393, 12.667639552887982, 11.73154894895199, 10.953814328564057, 9.966602206625456, 10.75249217968305, 10.850269469124026, 10.06999493268074, 10.756350004382583, 11.664046109859449, 12.625060070104368, 13.5365278347646, 14.447389905991297, 15.382552466694072, 16.326660160773997, 16.482741124996224, 14.384675359459656, 15.457388784320564, 16.400361459099738, 15.492773684443902, 14.573587384346222, 13.600238417635651, 12.74268704763438, 12.004454888783803, 11.029038589923408, 10.826296343809382, 9.871167777941778, 9.057109832535321, 9.794784710294437, 10.707109214847113, 11.604882174079, 12.516846918642212, 13.470297800981115, 14.415320939036766, 15.371984738735884, 16.297367964847894, 15.449201907334862, 16.39838515138541, 16.427876288378545, 15.446723205820465, 14.398040108866935, 13.529858177493036, 12.680193188060366, 11.744097777268635, 10.686820646460667, 9.85032102429954, 8.93796616177713, 8.032910388540543, 8.791818830642711, 9.6355647216758, 10.61066093064241, 11.559902687274871, 12.495506881049918, 13.448440702281804, 14.44118567711264, 15.304722321061329, 16.30221894211276, 16.48558956499459, 15.452951061343807, 14.491861879215353, 13.462749562981955, 12.52861361380402, 11.61575930333594, 10.69998309786948, 9.725965753057665, 8.862253897237428, 7.915060401606345, 7.025438736490343, 7.776055328542876, 8.649466410950286, 9.588838776141811, 10.583154361408127, 11.546361717930766, 12.454463008179458, 13.444356977970605, 14.377462882334232, 16.456608768324774, 15.490963791106594, 14.525234558186316, 13.536414870667125, 12.531408310929109, 11.60111516139878, 10.619734171359816, 9.726908540803064, 8.761099068506008, 7.905795911027592, 6.969110329152483, 6.036627923758056, 6.778348196660431, 7.677578929287608, 8.619204430221794, 9.66285259327321, 10.55249191701772, 11.445854975304844, 12.50709190291307, 13.41814966028519, 15.535118460712114, 14.564803594348456, 13.537806986324668, 12.589930742227654, 11.538263527562089, 10.594066641514319, 9.61987232854789, 8.660323734027152, 7.703932208043194, 6.871177134290988, 5.978551975560669, 5.100549026655077, 5.788321173657106, 6.712986519046101, 7.720158131968812, 8.602378980209398, 9.517184500688277, 10.459241002845728, 11.458798393605392, 12.390996068197053, 14.650747131846614, 13.589511284312545, 12.643340694696686, 11.64577787003451, 10.735580545760127, 9.740359666611239, 8.750536669641395, 7.739212666635562, 6.74681901886679, 5.895712384956793, 4.9658613717396936, 4.1392560825697835, 4.797292646914613, 5.68387843579, 6.654080531107921, 7.598648209752006, 8.56431076195089, 9.57956312107355, 10.58391236887478, 11.588407150571062, 13.702328078407294, 12.734803998690529, 11.69342475526924, 10.685987223948718, 9.736633228276755, 8.770778104118973, 7.8159448542059815, 6.8425870120425, 5.809437541337427, 4.991733594922767, 4.022616357587619, 3.100868897374696, 3.756627656516211, 4.683828569570085, 5.703057465483394, 6.6595630057553565, 7.667921668698023, 8.632183718315234, 9.614226963049813, 10.672938503059159, 12.656164949014956, 11.680174702072554, 10.749107976072974, 9.758453034738885, 8.798213428192888, 7.768439027994784, 6.804560399512702, 5.858737305186881, 4.865878568361247, 3.9208292765883033, 2.9749240359151377, 2.0734591639099187, 2.814676564756944, 3.846387013027165, 4.7613104875768455, 5.801033046340427, 6.766566672634934, 7.782855501611183, 8.850378830907859, 9.88288285736863, 11.656089509306803, 10.730749064373619, 9.779781737813545, 8.833827765300372, 7.821514016254156, 6.836837172404306, 5.855744689475257, 4.896560458258041, 3.924166566877952, 2.943749130834505, 1.9356883635842057, 1.019212925537418, 1.883322518764897, 2.8149166270217862, 3.7875196301997187, 4.852917146829548, 5.798127380743008, 6.8548107173862185, 7.855998201927591, 8.919436682027394, 10.704455738137284, 9.730868837538678, 8.791583643325836, 7.8639788213070805, 6.881283158802765, 5.89746757073877, 4.930638884154841, 3.9614970208020317, 2.9457136548341585, 1.9217617289969007, 0.9789909609291088, 0.0, 0.9482742067874625, 1.9339114814653255, 2.988766946802733, 4.022817773472751, 5.062920643691975, 6.07180868525859, 7.132767413343634, 8.11932240243984, 11.674407576678673, 10.746580009903932, 9.78504272861053, 8.834433592922334, 7.889625783183374, 6.815941483480399, 5.850098909934101, 4.88060766000621, 3.8827826044583267, 2.8483660818424554, 1.9446814133458834, 1.0186496864455552, 1.9407060945644745, 2.8845217992325005, 3.824306927093938, 4.823892393024239, 5.833586863600536, 6.813331562636058, 7.848197599393039, 8.789368010586275, 12.60209321031285, 11.716301277144426, 10.758104500871593, 9.775986893900251, 8.839380461408389, 7.7650860618030695, 6.807771450623277, 5.845867756430788, 4.896037895228467, 3.9200633622230585, 2.9924065257793018, 2.0213370643096997, 2.9522583234374604, 3.891494538066344, 4.796529082156574, 5.800078490254271, 6.8136953537168, 7.830640502904206, 8.781832838055411, 9.849603505820298], [9.825067444140684, 8.846311550396855, 7.808450384354834, 6.853453834838534, 5.804050613161983, 4.8318116455277975, 3.997293995137124, 3.006698893008921, 3.9524055306476433, 4.904814612670149, 5.907597489914029, 6.795295623072674, 7.72527530829372, 8.696791838393702, 9.640148059043936, 10.649471054077297, 11.70125738740766, 12.63046156027903, 13.648929932067439, 14.534639642606844, 8.828025567327241, 9.772262306358401, 8.81592699522254, 7.8259350239808185, 6.827175912562678, 5.805640789097846, 5.0397600136638045, 4.035824237395761, 4.880858969625404, 5.841424297404528, 6.773853878445655, 7.706672012258916, 8.71963237389534, 9.693983144391476, 10.687803599985378, 11.655574426750023, 12.719966929371292, 13.68604576984198, 14.64561190503383, 13.578882911670505, 8.109700602546482, 9.055428608373433, 9.870741734284938, 8.840250676695156, 7.785315725156673, 6.803658599076881, 6.026070399267443, 5.050641908041089, 5.862767592333958, 6.85923052234937, 7.793598831800251, 8.672079626902015, 9.709202931348937, 10.678944615451904, 11.672061968720973, 12.594973015185202, 13.64238737201254, 14.62998806107424, 13.67664776724673, 12.67949942486782, 8.911952036516325, 9.881035371667437, 10.880667122152136, 9.848576600646117, 8.795208286390483, 7.802035154175745, 7.025263981823765, 6.0990266030753695, 6.914293120519636, 7.8371421851894, 8.819067840958507, 9.634226163777308, 10.683042316056413, 11.66070029379236, 12.73488727373422, 13.649996708248013, 14.57965846688891, 15.54530683728913, 14.617934679398545, 13.639273897576354, 9.843387718440432, 10.813640740590222, 11.749336004863952, 10.796112029486347, 9.756063816142083, 8.842010138559408, 7.977778941309104, 7.048210682524989, 7.923655816061946, 8.85163679522389, 9.748633670035318, 10.58702927806266, 11.614426908308115, 12.615857574096173, 13.581921117047113, 14.563647137481299, 15.517154190644414, 16.46402023089986, 15.553311000676631, 14.622566681222766, 10.689091519193164, 11.702931849557046, 12.673051276309916, 11.717157635997827, 10.695470007209137, 9.831087114947621, 8.930692350402117, 8.079233966871552, 8.96481869306568, 9.789416013856354, 10.74758122631631, 11.618993719217809, 11.734886175116408, 12.72864315572521, 13.596744586739895, 14.510407320606614, 15.445906427854574, 16.302314595628495, 16.516146039173055, 15.620009238900167, 11.644263800134976, 12.683898008052761, 13.60433260905892, 12.629606858459802, 11.640209537786214, 10.775916278666458, 9.886960811338454, 9.077798719059478, 9.90936980965264, 10.715799018290797, 11.748033430824043, 11.693094225499593, 10.78827963107531, 11.73336106167684, 12.602875273489046, 13.556081364042635, 14.462029750297186, 15.37729579074881, 16.329641241378585, 16.60844785712135, 12.516641352072066, 13.550844094930461, 14.522043074162765, 13.559607778133236, 12.590981529986468, 11.825577805101576, 10.889487201165585, 10.111752580777651, 10.91487641341292, 11.700766386470514, 11.566899924218971, 10.753760010309414, 9.80807579759512, 10.715771903071987, 11.676785863316907, 12.588253627977137, 13.499115699203834, 14.434278259906613, 15.37838595398654, 16.360405992695583, 13.436401152672197, 14.509114577533104, 15.452087252312278, 14.54449947765644, 13.62531317755876, 12.758176669849245, 11.900625299847974, 11.162393140997397, 11.977312796710871, 11.542926798904327, 10.587798233036724, 9.740874910163994, 8.846510503506973, 9.758835008059652, 10.656607967291539, 11.568572711854749, 12.522023594193652, 13.467046732249306, 14.423710531948425, 15.349093758060432, 14.500927700547402, 15.450110944597949, 16.464358090177733, 15.499581293410204, 14.642213337438704, 13.805585391987778, 12.872732335285919, 12.166870232939976, 11.57928477020793, 10.63721906666788, 9.654596616872075, 8.716675466169216, 7.843544623855248, 8.687290514888339, 9.662386723854949, 10.611628480487408, 11.547232674262458, 12.500166495494344, 13.492911470325181, 14.356448114273869, 15.3539447353253, 16.390455054762928, 16.382258455889545, 15.421169273761091, 14.392056957527693, 13.457921008349757, 12.545066697881678, 11.629290492415215, 10.6552731476034, 9.663407084089195, 8.63169085670129, 7.709203814119016, 6.827781121755413, 7.701192204162825, 8.64056456935435, 9.634880154620665, 10.598087511143307, 11.506188801391998, 12.496082771183145, 13.429188675546772, 16.301078128689994, 16.420271185652332, 15.454541952732054, 14.465722265212863, 13.460715705474847, 12.530422555944519, 11.549041565905554, 10.6562159353488, 9.690406463051744, 8.70694909787936, 7.685740784247429, 6.7203930013867295, 5.830073989872968, 6.729304722500147, 7.6709302234343335, 8.71457838648575, 9.60421771023026, 10.497580768517384, 11.55881769612561, 12.46987545349773, 16.46442585525785, 15.494110988894194, 14.467114380870406, 13.519238136773392, 12.467570922107827, 11.523374036060057, 10.549179723093628, 9.58963112857289, 8.633239602588931, 7.672330321142756, 6.719784234139362, 5.784314104283751, 4.840046966869643, 5.76471231225864, 6.771883925181349, 7.654104773421936, 8.568910293900817, 9.510966796058268, 10.510524186817932, 11.442721861409593, 15.599021338634074, 14.537785491100005, 13.591614901484146, 12.594052076821969, 11.68385475254759, 10.688633873398702, 9.698810876428858, 8.687486873423024, 7.695093225654252, 6.7129333423660835, 5.783082329148984, 4.842163238970382, 3.84901844012715, 4.735604229002537, 5.705806324320458, 6.6503740029645435, 7.616036555163429, 8.631288914286088, 9.635638162087318, 10.6401329437836, 14.650602285194758, 13.683078205477992, 12.641698962056703, 11.634261430736178, 10.684907435064218, 9.719052310906436, 8.764219060993444, 7.790861218829963, 6.757711748124889, 5.904018400106112, 4.8398373149969105, 3.803776053775295, 2.8083534497287483, 3.7355543627826227, 4.754783258695932, 5.711288798967894, 6.719647461910561, 7.683909511527772, 8.665952756262351, 9.724664296271698, 13.60443915580242, 12.628448908860017, 11.697382182860437, 10.706727241526345, 9.746487634980348, 8.716713234782246, 7.752834606300165, 6.807011511974343, 5.81415277514871, 4.869103483375765, 3.8512566213826744, 2.81157107254945, 1.8664023579694813, 2.898112806239703, 3.813036280789383, 4.852758839552964, 5.818292465847471, 6.834581294823721, 7.902104624120397, 8.934608650581168, 12.604363716094266, 11.679023271161082, 10.728055944601008, 9.782101972087835, 8.769788223041619, 7.785111379191768, 6.804018896262719, 5.844834665045504, 4.8724407736654145, 3.8920233376219673, 2.8839625703716685, 1.9048060821286987, 0.9350483119774345, 1.8666424202343237, 2.839245423412256, 3.9046429400420855, 4.8498531739555455, 5.906536510598756, 6.907723995140128, 7.9711624752399315, 11.652729944924747, 10.67914304432614, 9.7398578501133, 8.812253028094544, 7.829557365590228, 6.845741777526232, 5.878913090942303, 4.909771227589494, 3.893987861621621, 2.870035935784363, 1.9272651677165713, 0.9482742067874625, 0.0, 0.9856372746778629, 2.040492740015271, 3.0745435666852887, 4.114646436904513, 5.123534478471127, 6.184493206556171, 7.171048195652377, 12.622681783466136, 11.694854216691395, 10.733316935397994, 9.782707799709797, 8.837899989970836, 7.7642156902678625, 6.798373116721564, 5.828881866793672, 4.831056811245789, 3.7966402886299178, 2.8929556201333457, 1.9669238932330178, 0.9924318877770121, 1.936247592445038, 2.8760327203064757, 3.875618186236777, 4.885312656813075, 5.865057355848597, 6.899923392605578, 7.841093803798813, 13.550367417100313, 12.66457548393189, 11.706378707659056, 10.724261100687714, 9.787654668195852, 8.713360268590533, 7.7560456574107395, 6.794141963218251, 5.8443121020159285, 4.868337569010521, 3.940680732566764, 2.969611271097162, 2.0398341718633297, 2.943220331278882, 3.8482548753691113, 4.851804283466809, 5.865421146929338, 6.882366296116744, 7.833558631267948, 8.901329299032835], [8.96070736042425, 7.98195146668042, 6.944090300638398, 5.989093751122098, 4.939690529445547, 3.967451561811362, 3.132933911420688, 3.9923361676867843, 4.938042805325506, 5.8904518873480125, 6.893234764591892, 7.780932897750537, 8.710912582971583, 9.682429113071565, 10.6257853337218, 11.63510832875516, 12.686894662085523, 13.616098834956894, 14.634567206745302, 15.520276917284708, 7.963665483610805, 8.907902222641965, 7.951566911506105, 6.9615749402643825, 5.962815828846242, 4.941280705381411, 4.1753999299473685, 5.021461512073624, 5.866496244303266, 6.82706157208239, 7.759491153123517, 8.692309286936778, 9.705269648573204, 10.67962041906934, 11.67344087466324, 12.641211701427887, 13.705604204049155, 14.671683044519844, 15.631249179711695, 14.56452018634837, 7.124063327868622, 8.069791333695573, 9.006381650568501, 7.975890592978721, 6.920955641440238, 5.939298515360446, 5.1705384893855335, 6.036279182718952, 6.84840486701182, 7.8448677970272325, 8.779236106478113, 9.657716901579878, 10.6948402060268, 11.664581890129767, 12.657699243398836, 13.580610289863065, 14.628024646690402, 15.615625335752103, 14.662285041924594, 13.665136699545686, 8.05525506084712, 9.024338395998232, 10.016307038435702, 8.984216516929681, 7.930848202674047, 6.93767507045931, 6.169732071941856, 7.084663877753233, 7.899930395197498, 8.822779459867263, 9.804705115636368, 10.619863438455171, 11.668679590734277, 12.646337568470223, 13.720524548412083, 14.635633982925876, 15.565295741566773, 16.530944111966996, 15.60357195407641, 14.624911172254219, 8.986690742771227, 9.956943764921016, 10.892639029194747, 9.93175194576991, 8.891703732425647, 7.9776500548429725, 7.13666918032201, 8.033847957202852, 8.909293090739808, 9.837274069901753, 10.73427094471318, 11.572666552740523, 12.600064182985978, 13.134707252523292, 13.843030891345574, 14.82475691177976, 15.782817762094128, 16.461729080388483, 16.538948275354496, 15.608203955900631, 9.887996143754151, 10.901836474118033, 11.80869119259348, 10.852797552281391, 9.8311099234927, 8.966727031231185, 8.089582589415022, 9.064871241549415, 9.950455967743542, 10.775053288534217, 11.733218500994171, 12.604630993895672, 12.720523449794271, 12.174480002446831, 12.915594023377919, 13.814566586704515, 14.750065693952475, 15.525890420370297, 16.469329129190037, 16.60564651357803, 10.843168424695962, 11.882802632613748, 12.739972525342484, 11.765246774743366, 10.775849454069778, 9.911556194950021, 9.04585105035136, 10.012709651217142, 10.895007084330501, 11.70143629296866, 12.733670705501906, 12.678731500177456, 11.773916905753174, 11.17919790839846, 11.92172471012707, 12.860240630140536, 13.766189016395087, 14.600871615490613, 15.553217066120387, 16.50721039412196, 11.740217176813868, 12.774419919672265, 13.657682990446329, 12.6952476944168, 11.726621446270032, 10.974793255051335, 10.04837744017849, 11.0244614293656, 11.900513688090781, 12.686403661148377, 12.552537198896834, 11.739397284987277, 10.793713072272983, 10.149528268833027, 10.99563529995493, 11.892412894075038, 12.803274965301735, 13.657854084648415, 14.601961778728342, 15.583981817437385, 12.659976977413999, 13.732690402274907, 14.587727168595842, 13.680139393940005, 12.760953093842325, 11.907392119799004, 11.059515538860879, 12.029760659916507, 12.962950071388732, 12.52856407358219, 11.573435507714587, 10.726512184841857, 9.832147778184837, 9.192591373820692, 9.969761036963556, 10.87273197795265, 11.826182860291553, 12.690622556991109, 13.647286356690227, 14.572669582802234, 13.724503525289204, 14.673686769339751, 15.600689450996533, 14.635221209693768, 13.777853253722268, 12.954800841937537, 12.031622574298824, 13.034237751859086, 12.564922044885794, 11.622856341345743, 10.640233891549938, 9.702312740847079, 8.829181898533111, 8.121046880649379, 8.975539793526966, 9.915787746585309, 10.77080849900426, 11.723742320236147, 12.716487295066983, 13.580023939015671, 14.577520560067102, 15.61403087950473, 16.646669383155512, 15.607894115907062, 14.713143799607248, 13.956045405626554, 13.09605645902325, 12.614927767093079, 11.640910422281264, 10.649044358767059, 9.617328131379153, 8.69484108879688, 7.813418396433276, 7.134948569923865, 7.953717639026367, 8.939039420718567, 9.821663335885109, 10.7297646261338, 11.719658595924948, 12.652764500288574, 15.524653953431796, 16.490298930649978, 16.440179227409917, 15.451359539890726, 14.44635298015271, 13.516059830622382, 12.534678840583418, 11.641853210026664, 10.676043737729607, 9.692586372557223, 8.671378058925292, 7.706030276064593, 6.815711264550831, 6.163061088261187, 6.957819318816458, 7.945320073748558, 8.827793534972063, 9.721156593259186, 10.782393520867412, 11.693451278239532, 16.518810180897077, 16.47974826357206, 15.45275165554827, 14.504875411451255, 13.45320819678569, 12.50901131073792, 11.534816997771491, 10.575268403250753, 9.618876877266795, 8.657967595820619, 7.705421508817225, 6.769951378961614, 5.825684241547506, 5.19846867801968, 6.031081496835842, 6.877680598163739, 7.7924861186426195, 8.73454262080007, 9.734100011559734, 10.666297686151395, 16.58465861331194, 15.523422765777871, 14.577252176162013, 13.579689351499836, 12.669492027225456, 11.674271148076567, 10.684448151106723, 9.67312414810089, 8.680730500332118, 7.698570617043947, 6.768719603826847, 5.827800513648245, 4.834655714805013, 4.169360594763578, 4.9650038959749505, 5.873949827706347, 6.839612379905232, 7.854864739027892, 8.834542786648305, 9.839037568344587, 15.636239559872623, 14.668715480155857, 13.627336236734568, 12.619898705414045, 11.670544709742082, 10.7046895855843, 9.749856335671307, 8.776498493507827, 7.743349022802754, 6.889655674783974, 5.825474589674773, 4.789413328453158, 3.793990724406611, 3.169310728543663, 3.953687883256919, 4.910193423528882, 5.918552086471548, 6.88281413608876, 7.864857380823338, 8.923568920832684, 14.590076430480284, 13.614086183537882, 12.683019457538302, 11.692364516204211, 10.732124909658214, 9.70235050946011, 8.738471880978029, 7.792648786652207, 6.799790049826574, 5.854740758053629, 4.836893896060537, 3.7972083472273126, 2.8520396326473443, 2.1201571352207207, 3.0119409053503703, 4.051663464113951, 4.993563861085018, 6.009852690061268, 7.077376019357944, 8.090915086381365, 13.59000099077213, 12.664660545838947, 11.713693219278873, 10.7677392467657, 9.755425497719484, 8.770748653869633, 7.789656170940583, 6.830471939723368, 5.858078048343279, 4.877660612299831, 3.8695998450495313, 2.8904433568065615, 1.9206855866552974, 1.065547044795311, 2.038150047973243, 3.079914335279632, 4.025124569193093, 5.081807905836303, 6.0829953903776754, 7.114465499570726, 12.638367219602612, 11.664780319004006, 10.725495124791165, 9.797890302772409, 8.815194640268093, 7.831379052204096, 6.864550365620167, 5.895408502267358, 4.8796251362994845, 3.855673210462226, 2.9129024423944343, 1.9339114814653255, 0.9856372746778629, 0.0, 1.0548554653374078, 2.088906292007426, 3.1290091622266507, 4.1378972037932655, 5.19885593187831, 6.185410920974515, 13.608319058144001, 12.680491491369258, 11.718954210075857, 10.76834507438766, 9.8235372646487, 8.749852964945726, 7.784010391399427, 6.814519141471536, 5.816694085923652, 4.7822775633077805, 3.878592894811209, 2.952561167910881, 1.978069162454875, 1.0718875087286024, 2.01167263659004, 3.0112581025203413, 4.020952573096639, 5.000697272132161, 6.035563308889142, 6.976733720082377, 14.536004691778178, 13.650212758609753, 12.692015982336919, 11.709898375365578, 10.773291942873715, 9.698997543268396, 8.741682932088603, 7.779779237896114, 6.829949376693792, 5.853974843688383, 4.926318007244627, 3.9552485457750253, 3.025471446541193, 2.078860247562446, 2.9838947916526752, 3.9874441997503727, 5.001061063212902, 6.018006212400308, 6.969198547551512, 8.036969215316399], [8.006827323060488, 7.028071429316658, 5.990210263274636, 5.035213713758337, 3.985810492081785, 3.0163710335218634, 3.970653920129795, 4.9584599460619145, 5.905310743594565, 6.857719825617071, 7.900782773389002, 8.835788363087945, 9.76576804830899, 10.737284578408973, 11.680640799059207, 12.689963794092568, 13.74175012742293, 14.670954300294301, 15.68942267208271, 16.57513238262211, 6.989416106517418, 7.946709940887431, 6.997686874142343, 6.007694902900621, 5.008935791482481, 3.9902001770919124, 5.002633613333702, 5.987585290448754, 6.833764182572325, 7.7943295103514485, 8.726759091392575, 9.659577225205835, 10.71231590404384, 11.734475884406747, 12.728296340000648, 13.696067166765294, 14.760459669386563, 15.726538509857251, 16.6861046450491, 15.619375651685774, 6.069207862531212, 7.0149358683581635, 8.018582045234233, 7.024810064689222, 5.9698751131507395, 4.988217987070947, 5.997772172771867, 6.973200663998221, 7.815672805280879, 8.812135735296291, 9.746504044747173, 10.624984839848935, 11.662108144295857, 12.711692705285946, 13.704810058555015, 14.635465755200473, 15.68288011202781, 16.67048080108951, 15.717140507261998, 14.71999216488309, 7.000399595509712, 7.969482930660823, 9.01378836746573, 8.033135988640183, 6.979767674384549, 5.9865945421698115, 6.9434856551094875, 7.9725200307482575, 8.867198333466556, 9.790047398136322, 10.771973053905429, 11.587131376724228, 12.635947529003333, 13.682615488771892, 13.923947960374672, 14.811279811584518, 15.741965191131122, 16.565781306120495, 16.658427419413812, 15.679766637591623, 7.9318352774338186, 8.902088299583609, 9.83778356385734, 8.980671417480412, 7.940623204136148, 7.026569526553474, 7.910422763489642, 8.839991022273757, 9.850657499614616, 10.80454200817081, 11.70153888298224, 12.53993449100958, 13.567332121255035, 13.838983634014697, 12.872920091063758, 13.854646111497944, 14.812706961812315, 15.49161828010667, 16.462053367404646, 16.663059421238035, 8.916184031305196, 9.905535861686085, 10.777531855637427, 9.901717023991893, 8.880029395203202, 8.015646502941687, 8.863336172582654, 9.839208305335186, 10.80579612810363, 11.742321226803274, 12.700486439263232, 13.571898932164729, 13.75478383954787, 12.894575862044363, 11.945483223096105, 12.844455786422703, 13.779954893670663, 14.555779620088483, 15.499218328908224, 16.52553821206133, 9.871356312247007, 10.910990520164793, 11.772731602007658, 10.814166246453867, 9.82476892578028, 8.960475666660523, 9.819604633518992, 10.786463234384774, 11.75034724469059, 12.668704231237717, 13.700938643770963, 13.73028227264841, 12.808177295506772, 11.911848804729146, 10.951613909845255, 11.890129829858724, 12.796078216113274, 13.630760815208799, 14.583106265838573, 15.537099593840145, 10.770106376532054, 11.80430911939045, 12.70660246215683, 11.744167166127301, 10.775540917980534, 10.023712726761836, 10.822131023346122, 11.798215012533232, 12.755853848450869, 13.653671599417434, 13.604087971367788, 12.79094805745823, 11.82797346202658, 10.915801200040672, 10.025524499673116, 10.922302093793226, 11.833164165019923, 12.6877432843666, 13.631850978446527, 14.61387101715557, 11.689866177132185, 12.762579601993092, 13.636646640306344, 12.729058865650506, 11.809872565552826, 10.956311591509506, 11.833269122028511, 12.80351424308414, 13.79050518322241, 13.580114846053144, 12.62498628018554, 11.778062957312812, 10.866408167938435, 9.958864305028337, 8.999650236681742, 9.902621177670838, 10.85607206000974, 11.720511756709294, 12.677175556408413, 13.60255878252042, 12.75439272500739, 13.703575969057937, 14.649608922707035, 13.68414068140427, 12.82677272543277, 12.003720313648039, 12.805376157466457, 13.807991335026719, 13.616472817356748, 12.674407113816697, 11.691784664020892, 10.753863513318034, 9.86344228828671, 8.887319811857024, 8.005428993245152, 8.945676946303497, 9.800697698722447, 10.753631519954332, 11.746376494785169, 12.609913138733857, 13.607409759785288, 14.643920079222916, 15.676558582873698, 14.656813587617563, 13.76206327131775, 13.004964877337056, 13.869810042190883, 13.666478539564032, 12.692461194752218, 11.700595131238012, 10.668878903850107, 9.746391861267835, 8.86496916890423, 7.901221501131509, 6.983606838744553, 7.968928620436753, 8.851552535603295, 9.759653825851986, 10.749547795643133, 11.68265370000676, 14.554543153149982, 15.520188130368163, 16.50804661338537, 15.704976438126991, 14.72981103652999, 13.932463329742294, 13.586229613054371, 12.693403982497617, 11.72759451020056, 10.744137145028176, 9.722928831396246, 8.757581048535547, 7.867262037021785, 6.929334019468831, 5.987708518534644, 6.975209273466744, 7.85768273469025, 8.751045792977372, 9.812282720585598, 10.723340477957718, 15.548699380615261, 16.4463483271263, 16.504302428019223, 15.556426183922209, 14.504758969256644, 13.560562083208874, 12.586367770242445, 11.626819175721707, 10.670427649737748, 9.709518368291572, 8.756972281288178, 7.8215021514325676, 6.87723501401846, 5.994203274267159, 5.060970696554028, 5.907569797881925, 6.822375318360805, 7.764431820518256, 8.76398921127792, 9.696186885869581, 16.559163999734245, 16.578278231115277, 15.632107641499417, 14.63454481683724, 13.72434749256286, 12.729126613413971, 11.739303616444127, 10.727979613438293, 9.735585965669522, 8.7501213895149, 7.820270376297801, 6.879351286119198, 5.886206487275967, 4.9650951910110575, 3.9948930956931363, 4.9038390274245325, 5.869501579623418, 6.884753938746078, 7.86443198636649, 8.868926768062773, 16.691095025210025, 15.723570945493261, 14.682191702071972, 13.674754170751449, 12.725400175079486, 11.759545050921705, 10.804711801008713, 9.831353958845233, 8.79820448814016, 7.9412064472549275, 6.8770253621457265, 5.840964100924111, 4.845541496877565, 4.041021003240517, 2.9835770829751054, 3.9400826232470676, 4.948441286189734, 5.912703335806945, 6.894746580541524, 7.95345812055087, 15.644931895817688, 14.668941648875286, 13.737874922875706, 12.747219981541615, 11.786980374995618, 10.757205974797515, 9.793327346315436, 8.847504251989614, 7.8546455151639805, 6.909596223391036, 5.888444668531491, 4.848759119698267, 3.903590405118298, 3.000927256655732, 2.0418301050685566, 3.065450499728472, 3.9387083957476103, 4.95499722472386, 6.022520554020535, 7.036059621043956, 14.644856456109535, 13.719516011176351, 12.768548684616277, 11.822594712103104, 10.810280963056888, 9.825604119207037, 8.844511636277991, 7.8853274050607745, 6.912933513680685, 5.932516077637238, 4.924455310386939, 3.941994129277515, 2.972236359126251, 2.040642250869362, 1.0680392476914295, 2.0250588699422245, 2.9702691038556845, 4.026952440498895, 5.028139925040267, 6.059610034233317, 13.693222684940016, 12.71963578434141, 11.780350590128569, 10.852745768109813, 9.870050105605497, 8.886234517541501, 7.919405830957573, 6.950263967604764, 5.934480601636891, 4.910528675799633, 3.967757907731842, 2.988766946802733, 2.040492740015271, 1.0548554653374078, 0.0, 1.034050826670018, 2.0741536968892427, 3.083041738455857, 4.1440004665409, 5.130555455637106, 14.663174523481405, 13.735346956706666, 12.773809675413265, 11.823200539725068, 10.878392729986107, 9.804708430283133, 8.838865856736835, 7.869374606808943, 6.87154955126106, 5.837133028645188, 4.890007340886276, 3.963975613985948, 2.944192940830005, 2.000377236161979, 1.0605921083005416, 2.037008725426954, 3.046703196003252, 4.026447895038774, 5.0613139317957545, 6.00248434298899, 15.590860157115582, 14.70506822394716, 13.746871447674327, 12.764753840702985, 11.828147408211123, 10.753853008605804, 9.79653839742601, 8.83463470323352, 7.884804842031199, 6.908830309025791, 5.926847671221747, 4.922516484044084, 3.991595224916323, 2.9846129153714, 2.0328142633631767, 3.033564162386611, 4.04718102584914, 5.064126175036546, 6.01531851018775, 7.064131206210678], [6.97277649639047, 5.99402060264664, 4.956159436604618, 4.001162887088318, 2.951759665411767, 3.958322289908559, 4.91260517651649, 5.90041120244861, 6.84726199998126, 7.7996710820037665, 8.842734029775697, 9.809613182841279, 10.739592868062324, 11.711109398162307, 12.65446561881254, 13.663788613845902, 14.715574947176265, 15.644779120047636, 16.663247491836042, 17.609183209292134, 5.955365279847401, 6.912659114217414, 5.963636047472325, 4.9736440762306025, 3.9748849648124622, 4.932151433478608, 5.944584869720398, 6.9295365468354495, 7.77571543895902, 8.736280766738144, 9.668710347779271, 10.601528481592531, 11.654267160430535, 12.701041967163523, 13.702121159753982, 14.669891986518628, 15.734284489139897, 16.700363329610585, 17.712748356720336, 16.653426478355797, 5.035157035861194, 5.980885041688145, 6.984531218564214, 5.999608171571236, 4.944673220032753, 5.926330346112545, 6.939723429158562, 7.915151920384916, 8.757624061667574, 9.754086991682986, 10.688455301133867, 11.566936096235631, 12.604059400682553, 13.653643961672643, 14.646761314941712, 15.05756665980041, 15.805373041091453, 16.71716337339688, 16.75119133393202, 15.754042991553112, 5.966348768839693, 6.935432103990805, 7.979737540795712, 7.01422699477819, 6.006246374315763, 6.924706901211409, 7.881598014151085, 8.910632389789855, 9.809149589853252, 10.731998654523016, 11.713924310292123, 12.529082633110924, 13.57789878539003, 14.624566745158589, 14.847866272945044, 14.002542966737598, 14.868101946215083, 15.67930884092322, 16.588723679160818, 16.713817464261645, 6.8977844507638, 7.868037472913589, 8.803732737187321, 7.96176242361842, 6.967101904067363, 7.964681885595072, 8.848535122531239, 9.778103381315354, 10.788769858656213, 11.746493264557504, 12.643490139368934, 13.481885747396277, 14.50928337764173, 14.76290194658507, 13.79683840363413, 13.045909266651025, 13.930606222459579, 14.605145814909392, 15.57558090220737, 16.506325221661236, 7.882133204635177, 8.871485035016065, 9.743481028967409, 8.928195723923105, 7.9065080951344155, 8.931395128234234, 9.801448531624251, 10.777320664376782, 11.743908487145227, 12.684272483189968, 13.642437695649926, 14.513850188551425, 14.678702152118241, 13.818494174614733, 12.869401535666475, 11.972739272557973, 12.897854154317926, 13.669307154891206, 14.612745863710947, 15.639065746864052, 8.837305485576989, 9.876939693494775, 10.73868077533764, 9.84064494638508, 8.851247625711492, 9.856465443110105, 10.757716992560589, 11.724575593426371, 12.688459603732186, 13.610655487624411, 14.642889900157657, 14.661833642020456, 13.732095608077143, 12.835767117299516, 11.875532222415625, 11.018413315993994, 11.91397747676054, 12.744288350011521, 13.696633800641296, 14.650627128642867, 9.80205672709376, 10.833577679261882, 11.68905531855769, 10.770645866058514, 9.802019617911746, 10.785318847933366, 11.721409451869357, 12.697493441056467, 13.693966207492466, 14.595622855804129, 14.592454283578393, 13.722499426830277, 12.751891774596952, 11.839719512611044, 10.949442812243486, 10.050585579928496, 10.951063425667188, 11.801270819169323, 12.74537851324925, 13.645821367717277, 10.72181652769389, 11.794529952554798, 12.619099496707204, 11.755537565581719, 10.836351265484039, 11.717917712681036, 12.732547550551747, 13.702792671607375, 14.689783611745645, 14.568481158263749, 13.613352592396145, 12.72434610290623, 11.790326480508806, 10.882782617598709, 9.923568549252112, 9.030904663806108, 9.973971320657006, 10.834039291512017, 11.790703091211135, 12.634509133082126, 11.786343075569096, 12.735526319619643, 13.632061779107895, 12.710619381335482, 11.853251425363982, 12.765326434819569, 13.704654585989692, 14.707269763549954, 14.604839129567353, 13.662773426027302, 12.680150976231497, 11.74222982552864, 10.787360600857081, 9.811238124427396, 8.929347305815522, 8.073960432438765, 8.914225233525169, 9.867159054757055, 10.859904029587893, 11.641863489295563, 12.639360110346994, 13.675870429784622, 14.70485628709786, 13.683292287548776, 12.788541971248963, 13.722677920426898, 14.693561961755227, 14.654844851774639, 13.680827506962824, 12.688961443448619, 11.657245216060712, 10.73475817347844, 9.790904106685868, 8.825139813701881, 7.907525151314923, 7.097212106572022, 7.965080070406018, 8.87318136065471, 9.863075330445858, 10.714604050568466, 13.586493503711688, 14.55213848092987, 15.539996963947077, 14.731455138058205, 13.756289736461202, 14.650176372832137, 14.574595925264978, 13.681770294708224, 12.715960822411168, 11.732503457238783, 10.71129514360685, 9.745947360746152, 8.855628349232392, 7.853252332039202, 6.911626831105015, 6.103492759602013, 6.971210269492973, 7.8645733277800955, 8.844233071147306, 9.755290828519424, 14.580649731176967, 15.478298677688008, 16.505295285711796, 15.71269758768243, 14.749434519828222, 14.54892839541948, 13.574734082453052, 12.615185487932314, 11.658793961948355, 10.69788468050218, 9.745338593498785, 8.809868463643173, 7.865601326229066, 6.976000370777911, 5.984889009124399, 5.035853284017194, 5.935902853163529, 6.8779593553209795, 7.795939561839627, 8.728137236431287, 15.632851726207328, 16.53495803503137, 16.66615846816944, 15.668595643507262, 14.739201489442117, 13.743980610293228, 12.754157613323384, 11.74283361031755, 10.750439962548779, 9.738487701725505, 8.808636688508406, 7.867717598329804, 6.874572799486573, 5.946892287521808, 4.976690192203887, 4.032122513559802, 4.983029114426142, 5.907334338367102, 6.835219902190429, 7.8397146838867116, 16.586677613424932, 16.757621772163283, 15.716242528741994, 14.70880499742147, 13.740254171958743, 12.774399047800962, 11.81956579788797, 10.84620795572449, 9.813058485019416, 8.929572759465533, 7.865391674356332, 6.829330413134717, 5.833907809088171, 5.029387315451123, 3.9719433951857117, 3.0683661093823367, 3.919229202013672, 4.8834912516308835, 5.865534496365463, 6.924246036374809, 16.67898272248771, 15.702992475545308, 14.771925749545728, 13.781270808211637, 12.82103120166564, 11.791256801467537, 10.827378172985455, 9.86235824886887, 8.869499512043237, 7.924450220270293, 6.876810980742096, 5.837125431908872, 4.891956717328903, 3.9892935688663385, 3.030196417279163, 2.0313996730584543, 2.9046575690775924, 3.9209463980538417, 4.988469727350517, 6.002008794373937, 15.678907282779557, 14.753566837846373, 13.8025995112863, 12.856645538773126, 11.84433178972691, 10.85965494587706, 9.87856246294801, 8.919378231730793, 7.946984340350705, 6.966566904307257, 5.958506137056958, 4.930360441488121, 3.960602671336857, 3.0290085630799677, 2.0564055599020357, 0.9910080432722064, 1.9362182771856664, 2.992901613828877, 3.9940890983702495, 5.025559207563298, 14.727273511610038, 13.753686611011432, 12.81440141679859, 11.886796594779835, 10.904100932275519, 9.920285344211523, 8.953456657627594, 7.984314794274784, 6.96853142830691, 5.944579502469653, 5.001808734401861, 4.0228177734727515, 3.0745435666852887, 2.088906292007426, 1.034050826670018, 0.0, 1.0401028702192248, 2.048990911785839, 3.109949639870883, 4.096504628967088, 15.697225350151427, 14.709171776460002, 13.7476344951666, 12.797025359478404, 11.852217549739443, 10.778533250036467, 9.812690676490169, 8.843199426562277, 7.845374371014394, 6.810957848398523, 5.831958597272972, 4.905926870372643, 3.8861441972167006, 2.9423284925486746, 2.002543364687237, 1.002957898756936, 2.012652369333234, 2.9923970683687564, 4.027263105125737, 4.968433516318973, 16.624910983785604, 15.678893043700496, 14.720696267427662, 13.738578660456321, 12.801972227964459, 11.727677828359138, 10.770363217179344, 9.808459522986855, 8.858629661784533, 7.87506359188121, 6.868798927608442, 5.864467740430779, 4.9335464813030185, 3.9265641717580952, 2.974765519749872, 1.9995133357165928, 3.0131301991791215, 4.030075348366528, 4.981267683517732, 6.03008037954066], [5.954496173180445, 4.975740279436616, 3.9448442715525704, 2.989847722036271, 3.9393405133234585, 4.945903137820251, 5.900186024428183, 6.887992050360301, 7.8348428478929515, 8.787251929915458, 9.830314877687389, 10.797194030752971, 11.727173715974017, 12.698690246074, 13.642046466724233, 14.651369461757595, 15.703155795087957, 16.632359967959328, 17.650828339747736, 18.6041144139514, 4.923557186606497, 5.88085102097651, 4.952320882420278, 3.962328911178555, 4.962465812724154, 5.919732281390299, 6.932165717632089, 7.917117394747141, 8.763296286870712, 9.723861614649836, 10.656291195690963, 11.589109329504224, 12.641848008342228, 13.688622815075215, 14.689702007665675, 15.65747283443032, 15.79884443169894, 16.76492327216963, 17.615081634295564, 17.69352934857502, 3.995054165641969, 4.94078217146892, 5.9444283483449905, 4.990150567860846, 5.932254067944444, 6.913911194024236, 7.927304277070254, 8.902732768296607, 9.745204909579266, 10.74166783959468, 11.676036149045562, 12.554516944147323, 13.591640248594246, 14.641224809584335, 15.634342162853404, 15.874985163883595, 14.827570807056258, 15.739361139361684, 16.576413626348003, 16.794145861772336, 4.926245898620469, 5.895329233771581, 6.939634670576488, 6.004769391067801, 6.993827222227455, 7.9122877491231005, 8.869178862062777, 9.898213237701547, 10.796730437764944, 11.71957950243471, 12.701505158203817, 13.516663481022617, 14.565479633301722, 15.612147593070281, 15.72813248129491, 14.820985091726492, 13.890299712179887, 14.701506606888023, 15.61092144512562, 16.511815771272452, 5.857681580544576, 6.8279346026943655, 7.763629866968097, 6.95230481990803, 7.954682751979054, 8.952262733506762, 9.83611597044293, 10.765684229227046, 11.776350706567905, 12.734074112469198, 13.631070987280628, 14.469466595307969, 15.496864225553423, 15.643168154934935, 14.677104611983996, 13.867739060763094, 12.952803988424384, 13.627343580874195, 14.597778668172174, 15.528522987626038, 6.842030334415953, 7.831382164796841, 8.703378158748185, 7.95356475851836, 8.894088943046107, 9.918975976145925, 10.789029379535943, 11.764901512288475, 12.731489335056919, 13.671853331101662, 14.63001854356162, 15.501431036463117, 15.558968360468107, 14.6987603829646, 13.749667744016342, 12.794569066670043, 11.92005192028273, 12.691504920856008, 13.63494362967575, 14.661263512828855, 7.797202615357765, 8.83683682327555, 9.698577905118416, 8.942569911834685, 9.838828473623185, 10.844046291021797, 11.745297840472281, 12.712156441338063, 13.676040451643878, 14.598236335536106, 15.630470748069351, 15.542099850370322, 14.61236181642701, 13.716033325649384, 12.755798430765493, 11.840243110106064, 10.936175242725342, 11.766486115976324, 12.718831566606099, 13.67282489460767, 8.781756829376466, 9.793474809042658, 10.648952448338466, 9.989207899409031, 10.789600465823439, 11.772899695845059, 12.70899029978105, 13.68507428896816, 14.681547055404158, 15.583203703715823, 15.505072517370115, 14.602765635180143, 13.632157982946818, 12.71998572096091, 11.829709020593354, 10.872415374040566, 9.973261191631991, 10.823468585134126, 11.767576279214053, 12.66801913368208, 9.744014293658694, 10.764154079033684, 11.57899662648798, 10.974099598932236, 11.823932113395731, 12.705498560592728, 13.720128398463439, 14.690373519519067, 15.677364459657337, 15.481099392055471, 14.525970826187868, 13.604612311256096, 12.670592688858672, 11.763048825948575, 10.80383475760198, 9.852734457918178, 8.996169086621808, 9.85623705747682, 10.812900857175938, 11.65670689904693, 10.8085408415339, 11.757724085584446, 12.591958908888671, 11.929181414686, 12.840832273275675, 13.752907282731261, 14.692235433901384, 15.694850611461646, 15.517457363359075, 14.575391659819024, 13.592769210023219, 12.654848059320361, 11.667626809206947, 10.691504332777262, 9.80961351416539, 8.895790226550835, 7.936422999489972, 8.889356820721858, 9.882101795552694, 10.664061255260366, 11.661557876311797, 12.698068195749425, 13.664753416878636, 12.901854320899293, 13.776122819160655, 14.71025876833859, 15.68114280966692, 15.567463085566361, 14.593445740754547, 13.601579677240341, 12.569863449852434, 11.647376407270162, 10.671170315035734, 9.705406022051747, 8.78779135966479, 7.919041900684092, 6.98727783637082, 7.895379126619512, 8.885273096410659, 9.73680181653327, 12.608691269676491, 13.574336246894672, 14.56219472991188, 13.95001717140872, 14.743870584372894, 15.63775722074383, 15.4872141590567, 14.594388528499946, 13.62857905620289, 12.645121691030505, 11.623913377398573, 10.658565594537874, 9.768246583024112, 8.733518540389069, 7.791893039454883, 6.925322553714083, 5.993408035457775, 6.886771093744898, 7.866430837112107, 8.777488594484227, 13.60284749714177, 14.50049644365281, 15.527493051676599, 14.931259621032945, 15.737015367739914, 15.461546629211202, 14.487352316244774, 13.527803721724036, 12.571412195740077, 11.610502914293901, 10.657956827290507, 9.722486697434896, 8.778219560020787, 7.857419892316713, 6.865155217474267, 5.916119492367062, 4.958100619128331, 5.9001571212857815, 6.818137327804428, 7.750335002396089, 14.65504949217213, 15.55715580099617, 16.4800637806169, 15.906686138515783, 15.651819723233839, 14.65659884408495, 13.666775847115106, 12.655451844109272, 11.6630581963405, 10.65110593551723, 9.72125492230013, 8.780335832121526, 7.787191033278295, 6.828311809060612, 5.8581097137426905, 4.913542035098605, 4.005226880390944, 4.929532104331905, 5.857417668155231, 6.843223162330845, 15.608875379389735, 16.612047802095194, 16.668018926749042, 15.649235024983447, 14.652872405750465, 13.687017281592684, 12.732184031679692, 11.758826189516212, 10.725676718811139, 9.842190993257256, 8.778009908148055, 7.741948646926439, 6.746526042879893, 5.942005549242845, 4.884561628977433, 3.9497856309211405, 2.941426967978474, 3.9056890175956855, 4.887732262330264, 5.9071194533922275, 16.55370655346022, 16.74309534576453, 15.81202861976495, 14.82137367843086, 13.861134071884862, 12.831359671686759, 11.821755519518387, 10.774976482660593, 9.78211774583496, 8.837068454062015, 7.789429214533818, 6.749743665700594, 5.8045749511206255, 4.90191180265806, 3.942814651070885, 2.944017906850176, 1.9268553350423943, 2.9431441640186438, 4.010667493315319, 4.961905924154713, 16.71901015299878, 15.793669708065595, 14.842702381505521, 13.896748408992348, 12.884434659946132, 11.899757816096281, 10.87297994972996, 9.913795718512743, 8.941401827132655, 7.960984391089207, 6.886911638103716, 5.842978675279843, 4.873220905128579, 3.94162679687169, 2.969023793693758, 1.9036262770639283, 0.9584160431504684, 2.015099379793679, 3.0162868643350516, 3.9854563373440746, 15.76737638182926, 14.793789481230654, 13.854504287017813, 12.926899464999057, 11.94420380249474, 10.960388214430745, 9.993559527846816, 9.024417664494008, 8.008634298526134, 6.9846823726888765, 6.041911604621085, 5.062920643691976, 4.114646436904514, 3.1290091622266507, 2.0741536968892427, 1.0401028702192248, 0.0, 1.0088880415666144, 2.069846769651658, 3.0564017587478634, 16.73732822037065, 15.696752624371692, 14.735215343078291, 13.784606207390095, 12.839798397651133, 11.76611409794816, 10.800271524401861, 9.83078027447397, 8.832955218926086, 7.798538696310215, 6.819539445184663, 5.893507718284335, 4.873725045128392, 3.9299093404603664, 2.990124212598929, 1.9905387466686277, 0.9808442760923298, 1.9605889751278522, 2.995455011884833, 3.9366254230780684, 17.61984218844487, 16.66647389161219, 15.708277115339353, 14.726159508368012, 13.78955307587615, 12.71525867627083, 11.757944065091037, 10.796040370898547, 9.846210509696226, 8.862644439792902, 7.856379775520134, 6.852048588342471, 5.92112732921471, 4.914145019669787, 3.9623463676615645, 2.9870941836282845, 2.001815034127074, 3.0117950251565038, 3.9629873603077086, 4.998272286299756], [4.994346480302532, 4.018859178583247, 2.994315983735709, 3.9493125332520087, 4.941948810541134, 5.948511435037926, 6.902794321645858, 7.890600347577977, 8.837451145110627, 9.789860227133133, 10.832923174905064, 11.799802327970646, 12.729782013191691, 13.701298543291674, 14.644654763941908, 15.65397775897527, 16.705764092305632, 17.051305154309947, 17.85135070385988, 18.746663039290304, 3.9442565002689483, 4.901550334638961, 4.034481636416485, 4.921793722394293, 5.955132066784875, 6.922340578607974, 7.934774014849764, 8.919725691964818, 9.765904584088387, 10.726469911867511, 11.658899492908638, 12.591717626721898, 13.644456305559903, 14.69123111229289, 15.69231030488335, 16.660081131647996, 16.60701826908422, 15.993647172209537, 16.801849838975585, 17.687421162990518, 2.986166124075355, 3.9318941299023065, 4.9355403067783765, 5.949615379076583, 6.924920322005166, 7.906577448084958, 8.929912574287929, 9.905341065514282, 10.747813206796941, 11.744276136812353, 12.678644446263235, 13.557125241364998, 14.59424854581192, 15.64383310680201, 16.636950460071077, 16.683159001268873, 15.635744644441537, 14.926129344041707, 15.763181831028026, 16.73918474867359, 3.917357857053855, 4.886441192204966, 5.930746629009874, 6.964234202283538, 7.986493476288176, 8.904954003183823, 9.861845116123499, 10.89087949176227, 11.79933873498262, 12.722187799652383, 13.70411345542149, 14.519271778240292, 15.568087930519397, 16.614755890287956, 16.555201925079114, 15.629158929111771, 14.698473549565167, 13.888274811568046, 14.797689649805642, 15.698583975952474, 4.848793538977962, 5.8190465611277515, 6.754741825401483, 7.783352844150088, 8.842506357604222, 9.89872049448764, 10.828782224503653, 11.758350483287769, 12.769016960628628, 13.736682409686871, 14.633679284498301, 15.472074892525644, 16.499472522771097, 16.652056196501555, 15.685992653550613, 14.814529054658328, 13.760977825809663, 12.814111785554218, 13.784546872852196, 14.715291192306061, 5.833142292849339, 6.822494123230227, 7.69449011718157, 8.65038375749366, 9.67207138628235, 10.696958419382169, 11.744491154221212, 12.720363286973743, 13.686951109742187, 14.629678058644611, 15.592084973269184, 16.504039333680794, 16.56785640203472, 15.707648424531216, 14.758555785582958, 13.803457108236657, 12.878697894067752, 11.878273125536031, 12.821711834355773, 13.806361792127746, 6.788314573791151, 7.827948781708938, 8.689689863551802, 9.639388910809984, 10.616810916859428, 11.622028734258041, 12.54711668576274, 13.513975286628522, 14.509013536708984, 15.556061063079055, 16.5882954756123, 16.550987891936934, 15.621249857993623, 14.724921367216, 13.764686472332109, 12.849131151672678, 11.945063284291956, 10.953254320656347, 11.905599771286122, 12.81792317390656, 7.772868787809852, 8.784586767476044, 9.640064406771852, 10.602499702801381, 11.567582909059682, 12.550882139081303, 13.486972743017294, 14.463056732204404, 15.47681910306398, 16.417964062503803, 16.51396055893673, 15.611653676746757, 14.641046024513432, 13.728873762527526, 12.83859706215997, 11.88130341560718, 10.982149233198605, 10.010236789814149, 10.954344483894076, 11.799853289217957, 8.751519521711536, 9.75526603746707, 10.570108584921366, 11.540758987716092, 12.578543175638151, 13.483481003828972, 14.498110841699683, 15.46835596275531, 16.45534690289358, 16.489987433622087, 15.534858867754483, 14.613500352822712, 13.679480730425288, 12.77193686751519, 11.812722799168595, 10.861622499484792, 10.005057128188422, 9.043005262156843, 9.999669061855961, 10.788541054582806, 9.820484219231727, 10.769667463282273, 11.583070867322057, 12.495840803469855, 13.544523900423385, 14.529938332939771, 15.470217877137628, 16.47283305469789, 16.526345404925692, 15.58427970138564, 14.601657251589835, 13.663736100886977, 12.676514850773563, 11.700392374343878, 10.818501555732006, 9.90467826811745, 8.945311041056586, 8.07612502540188, 9.051920903175327, 9.795895410796243, 10.764621217591776, 11.782238332941155, 12.655865375312022, 13.46851370968315, 14.479814446308366, 15.413950395486301, 16.38483443681463, 16.576351127132977, 15.602333782321162, 14.610467718806957, 13.57875149141905, 12.656264448836778, 11.68005835660235, 10.714294063618363, 9.796679401231406, 8.927929942250707, 7.996165877937434, 7.065198234242144, 8.055092204033292, 8.868635972069146, 11.720671986772404, 12.686316963990585, 13.583581878469513, 14.516676560192579, 15.447562211520605, 16.34144884789154, 16.496102200623316, 15.603276570066562, 14.637467097769505, 13.654009732597121, 12.632801418965188, 11.66745363610449, 10.777134624590728, 9.742406581955684, 8.800781081021498, 7.934210595280697, 7.002296077024389, 6.05659020136753, 7.008070567621806, 7.909322750020104, 12.714828214237683, 13.612477160748723, 14.571009450331161, 15.497919009816803, 16.440706994887627, 16.47043467077782, 15.49624035781139, 14.536691763290651, 13.580300237306693, 12.619390955860517, 11.666844868857122, 10.731374739001511, 9.787107601587403, 8.866307933883327, 7.874043259040881, 6.925007533933676, 5.966988660694945, 5.069976228908414, 5.959777058314127, 6.882169157931966, 13.767030209268043, 14.669136518092083, 15.52358017927146, 16.473345527299642, 16.660707764800453, 15.665486885651564, 14.67566388868172, 13.664339885675886, 12.671946237907115, 11.659993977083843, 10.730142963866744, 9.78922387368814, 8.79607907484491, 7.837199850627226, 6.8669977553093045, 5.922430076665219, 5.014114921957558, 4.0847555565064155, 4.999057398664929, 5.83433512076423, 14.720856096485647, 15.724028519191105, 16.535681471604438, 16.65812306655006, 15.661760447317079, 14.695905323159298, 13.741072073246306, 12.767714231082826, 11.734564760377753, 10.85107903482387, 9.78689794971467, 8.750836688493054, 7.755414084446508, 6.95089359080946, 5.893449670544048, 4.9586736724877545, 3.950315009545088, 3.060912469770196, 4.0293719928399625, 4.898231411825613, 15.740474758140243, 16.716465005082647, 16.820916661331566, 15.830261719997473, 14.870022113451476, 13.840247713253373, 12.830643561085001, 11.783864524227207, 10.791005787401573, 9.845956495628629, 8.798317256100432, 7.758631707267209, 6.81346299268724, 5.910799844224675, 4.951702692637499, 3.9529059484167908, 2.9357433766090084, 1.9905056070822558, 3.058028936378931, 3.9530178825880986, 16.733494157434563, 16.80255774963221, 15.851590423072135, 14.905636450558962, 13.893322701512746, 12.908645857662895, 11.881867991296575, 10.922683760079359, 9.95028986869927, 8.969872432655823, 7.895799679670331, 6.851866716846458, 5.882108946695194, 4.950514838438305, 3.977911835260372, 2.9125143186305427, 1.9673040847170826, 1.0624608228572912, 2.0636483073986636, 2.97656829577746, 16.776264423395876, 15.802677522797268, 14.863392328584426, 13.93578750656567, 12.953091844061355, 11.96927625599736, 11.00244756941343, 10.033305706060622, 9.017522340092748, 7.99357041425549, 7.0507996461876985, 6.07180868525859, 5.123534478471128, 4.137897203793265, 3.083041738455857, 2.048990911785839, 1.0088880415666144, 0.0, 1.0609587280850437, 2.047513717181249, 17.746216261937263, 16.699360921589367, 15.737823640295968, 14.787214504607771, 13.84240669486881, 12.768722395165835, 11.802879821619536, 10.833388571691644, 9.835563516143761, 8.80114699352789, 7.822147742402339, 6.8961160155020105, 5.876333342346068, 4.932517637678042, 3.992732509816604, 2.993147043886303, 1.983452573310005, 1.0037078742744827, 2.0161543255472845, 2.95732473674052, 18.622450485662544, 17.66908218882986, 16.71088541255703, 15.728767805585688, 14.792161373093826, 13.717866973488505, 12.760552362308712, 11.798648668116222, 10.8488188069139, 9.865252737010577, 8.858988072737809, 7.854656885560146, 6.923735626432386, 5.916753316887462, 4.964954664879239, 3.98970248084596, 3.004423331344749, 2.0549139243031345, 3.0061062594543393, 4.0189715999622075], [3.933387752217489, 2.9856986123294234, 3.863540087784295, 4.8185366373005944, 5.888117442569113, 6.934865194982664, 7.889148081590596, 8.876954107522716, 9.823804905055365, 10.77621398707787, 11.819276934849801, 12.786156087915385, 13.71613577313643, 14.687652303236414, 15.631008523886647, 16.640331518920007, 17.69211785225037, 17.88944805060089, 17.075413586530374, 17.774217468704343, 2.883297772183905, 3.840591606553918, 4.796926917689779, 5.786918888931502, 6.820257233322083, 7.893095473150977, 8.905528909392768, 9.906079451909555, 10.752258344033125, 11.712823671812249, 12.645253252853376, 13.578071386666636, 14.63081006550464, 15.677584872237627, 16.678664064828087, 17.646434891592733, 17.445161165375165, 16.831790068500478, 16.02591272164608, 16.714975592404556, 1.9252073959903113, 2.8709354018172624, 3.874581578693332, 4.905072636283113, 5.960007587821596, 6.941664713901388, 7.965116372498855, 8.940544863725208, 9.924771946792902, 10.922697437569429, 11.857065747020311, 12.916932227801802, 13.954055532248724, 15.003640093238813, 15.996757446507882, 17.011036189036766, 16.47388754073248, 15.76427224033265, 14.98724471369852, 15.76673917808763, 2.8563991289688113, 3.8254824641199225, 4.86978790092483, 5.919691459490068, 6.973059773745701, 7.940041269000252, 8.896932381939928, 9.9259667575787, 10.964259444174088, 11.90060910040946, 12.882534756178567, 13.879078764677095, 14.9278949169562, 15.97456287672476, 17.048749856666618, 16.467301825402714, 15.53661644585611, 14.726417707858989, 14.021752532476135, 14.726138405366514, 3.7878348108929183, 4.758087833042707, 5.693783097316439, 6.722394116065044, 7.781547629519179, 8.837761766402597, 9.863869490320083, 10.793437749104198, 11.804104226445057, 12.857053611998198, 13.812100585255378, 14.831881878962447, 15.859279509207902, 16.889948421112823, 16.559446403475693, 15.652671950949271, 14.599120722100606, 13.652254681845161, 13.00860975552269, 13.742845621720102, 4.772183564764295, 5.761535395145183, 6.633531389096526, 7.589425029408615, 8.611112658197305, 9.635999691297123, 10.683532426136166, 11.659404558888697, 12.625992381657142, 13.568719330559565, 14.531126245184138, 15.466024278828785, 16.5346048386287, 16.581102174456294, 15.632009535508038, 14.668799330618672, 13.716840790358695, 12.716416021826975, 12.045774717026266, 12.745403064042701, 5.727355845706107, 6.766990053623894, 7.628731135466757, 8.57843018272494, 9.555852188774383, 10.561070006172995, 11.486157957677694, 12.453016558543476, 13.44805480862394, 14.495102334994009, 15.527336747527254, 16.46050351064388, 16.504436824655485, 15.59837511714108, 14.638140222257189, 13.714473374054693, 12.790449967762475, 11.79139721694729, 11.056783290230163, 11.756964445821517, 6.711910059724808, 7.723628039391, 8.579105678686807, 9.541540974716336, 10.506624180974637, 11.489923410996257, 12.426014014932248, 13.402098004119358, 14.415860374978934, 15.357005334418755, 16.363891832615828, 16.494840643408622, 15.524232991175296, 14.612060729189388, 13.71205081208505, 12.746645637989195, 11.827535916669124, 10.848379686105092, 10.049242750188865, 10.738894561132913, 7.690560793626492, 8.694307309382026, 9.50914985683632, 10.479800259631048, 11.517584447553107, 12.422522275743926, 13.437152113614637, 14.407397234670265, 15.394388174808535, 16.297027980596273, 16.43217817152308, 15.496687319484574, 14.56266769708715, 13.655123834177052, 12.686176549093675, 11.726964721866807, 10.850443811658941, 9.881148158447786, 9.090551382692421, 9.727582326497762, 8.759525491146682, 9.708708735197229, 10.522112139237011, 11.434882075384811, 12.483565172338341, 13.468979604854727, 14.409259149052582, 15.411874326612844, 16.37768502919308, 16.5024417466551, 15.519819296859296, 14.555909136990163, 13.559701817435425, 12.58357934100574, 11.701688522393868, 10.770020490499466, 9.801856122491571, 8.914267921692824, 8.028035966486287, 8.734936682711199, 9.703662489506732, 10.721279604856111, 11.594906647226976, 12.407554981598105, 13.418855718223321, 14.352991667401257, 15.323875708729586, 16.291741461803547, 16.603977182795372, 15.551156318114305, 14.496913536688512, 13.548437484939964, 12.563245323264212, 11.597481030280225, 10.679866367893268, 9.793272164632723, 8.85271095937242, 7.9033411305330885, 7.031207267344252, 7.807677243984101, 10.65971325868736, 11.62535823590554, 12.522623150384467, 13.455717832107535, 14.386603483435561, 15.280490119806496, 16.31990084070571, 16.623259622517203, 15.657450150220145, 14.67399278504776, 13.639053016117689, 12.67370523325699, 11.698570265975409, 10.625593548617546, 9.68396804768336, 8.799552817662715, 7.867638299406407, 6.894733097658474, 5.956855243747373, 6.84836402193506, 11.653869486152638, 12.551518432663679, 13.510050722246115, 14.436960281731759, 15.379748266802581, 16.287538639690958, 16.51622341026203, 15.55667481574129, 14.600283289757332, 13.639374008311156, 12.686827921307762, 11.75135779145215, 10.807090654038042, 9.782970230306493, 8.757230225702743, 7.8081945005955395, 6.850175627356808, 5.908119125199358, 4.908561734439695, 5.821210429846922, 12.706071481182999, 13.608177790007039, 14.462621451186415, 15.412386799214596, 16.402852795257928, 16.726445613736608, 15.736622616766764, 14.72529861376093, 13.732904965992159, 12.720952705168886, 11.791101691951786, 10.850182601773184, 9.857037802929952, 8.811346804399458, 7.8411447090815365, 6.896577030437451, 5.986768852081192, 4.971516492958532, 3.947842074790497, 4.773376392679186, 13.659897368400603, 14.66306979110606, 15.474722743519392, 16.372177445300387, 16.722719175402123, 15.756864051244342, 14.80203080133135, 13.82867295916787, 12.795523488462797, 11.912037762908913, 10.847856677799712, 9.811795416578097, 8.81637281253155, 7.94677008679736, 6.889326166531949, 5.9328206262599865, 4.92446196331732, 3.960199913700109, 2.9781566689655303, 3.837272683740569, 14.706060497792942, 15.682050744735344, 16.419039522715657, 16.891220448082517, 15.93098084153652, 14.901206441338417, 13.891602289170045, 12.844823252312251, 11.851964515486618, 10.906915223713673, 9.859275984185476, 8.819590435352252, 7.8744217207722835, 6.971758572309718, 6.012661420722543, 5.000080314487003, 3.9657934420715146, 2.938500714734337, 2.006813612504499, 2.892059154503055, 15.749871737717582, 16.63147638243428, 16.91254915115718, 15.966595178644006, 14.95428142959779, 13.96960458574794, 12.942826719381616, 11.9836424881644, 11.011248596784311, 10.030831160740863, 8.956758407755373, 7.912825444931501, 6.943067674780237, 6.011473566523348, 5.038870563345416, 3.9734730467155863, 3.0282628128021263, 2.010455930509372, 1.009268445968, 1.9156095676924165, 16.701505508887102, 16.863636250882312, 15.92435105666947, 14.996746234650715, 14.014050572146399, 13.030234984082403, 12.063406297498474, 11.094264434145666, 10.078481068177792, 9.054529142340535, 8.111758374272743, 7.132767413343633, 6.184493206556171, 5.198855931878308, 4.1440004665409, 3.109949639870883, 2.069846769651658, 1.0609587280850437, 0.0, 0.9865549890962053, 17.671176720608926, 17.685714681534105, 16.724177400240706, 15.773568264552509, 14.828760454813548, 13.755076155110574, 12.789233581564275, 11.819742331636384, 10.8219172760885, 9.78750075347263, 8.808501502347077, 7.882469775446749, 6.862687102290806, 5.91887139762278, 4.979086269761343, 3.9795008038310415, 2.969806333254744, 1.9900616342192214, 0.9551955974622409, 1.8963660086554763, 18.598862354243103, 18.102204111315586, 17.697239172501767, 16.715121565530424, 15.778515133038564, 14.704220733433244, 13.746906122253451, 12.785002428060961, 11.83517256685864, 10.851606496955315, 9.845341832682546, 8.841010645504884, 7.910089386377124, 6.903107076832201, 5.951308424823978, 4.954700041001655, 3.9410831775391264, 2.92413802835172, 1.9729456932005154, 2.9580128718771643], [3.0161199514637747, 3.8323244858870043, 4.8500950768805, 5.805091626396799, 6.874672431665317, 7.915787162375803, 8.870070048983735, 9.86350909661892, 10.81035989415157, 11.762768976174076, 12.805831923946007, 13.772711077011591, 14.702690762232637, 15.67420729233262, 16.617563512982855, 17.626886508016216, 18.67867284134658, 18.717652098160315, 17.743033081027093, 16.787662479608134, 1.944434194110752, 2.889454152208695, 3.8457894633445564, 4.835781434586279, 5.869119778976861, 6.941958018805755, 7.954391455047545, 8.96880754527433, 9.914108767618556, 10.87467409539768, 11.807103676438807, 12.739921810252067, 13.792660489090071, 14.839435295823058, 15.885964202286258, 16.89856247770246, 17.96295498032373, 17.659994116059906, 16.6935322161428, 15.728420603308349, 0.938652406894106, 1.884380412721057, 2.8880265895971267, 3.9185176471869076, 4.97345259872539, 5.955109724805182, 6.978561383402649, 7.953989874629003, 8.938216957696696, 9.936142448473223, 10.870510757924105, 11.930377238705596, 12.967500543152518, 14.017085104142607, 15.010202457411676, 16.02448119994056, 17.071895556767895, 16.592476287892076, 15.654864208195239, 14.780184188991424, 1.8698441398726058, 2.8389274750237172, 3.8832329118286246, 4.933136470393862, 5.986504784649496, 6.953486279904046, 7.910377392843722, 8.939411768482493, 9.977704455077882, 10.914054111313254, 11.89597976708236, 12.892523775580889, 13.941339927859994, 14.988007887628553, 16.062194867570412, 16.988237863537755, 16.364820493415536, 15.554621755418415, 14.689372026972855, 13.739583416270309, 2.801279821796713, 3.7715328439465026, 4.707228108220234, 5.735839126968839, 6.794992640422974, 7.851206777306391, 8.877314501223877, 9.806882760007992, 10.817549237348851, 11.870498622901993, 12.825545596159172, 13.845326889866241, 14.872724520111696, 15.90339343201662, 16.86945697496756, 16.480875998508697, 15.427324769660032, 14.480458729404587, 13.676229250019409, 12.756290632623896, 3.7856285756680896, 4.774980406048979, 5.646976400000321, 6.6028700403124105, 7.6245576691011, 8.649444702200919, 9.696977437039962, 10.672849569792493, 11.639437392560938, 12.582164341463361, 13.544571256087934, 14.479469289732581, 15.548049849532495, 16.560629453359628, 16.475483645996803, 15.512273441107439, 14.545044837918121, 13.5446200693864, 12.713394211522985, 11.758848074946496, 4.740800856609901, 5.780435064527688, 6.642176146370552, 7.591875193628735, 8.569297199678177, 9.57451501707679, 10.499602968581488, 11.46646156944727, 12.461499819527734, 13.508547345897805, 14.54078175843105, 15.473948521547674, 16.494656393573592, 16.441849227629845, 15.481614332745956, 14.55794748454346, 13.6186540153219, 12.619601264506716, 11.724402784726882, 10.77040945672531, 5.725355070628602, 6.737073050294795, 7.5925506895906025, 8.554985985620132, 9.52006919187843, 10.503368421900051, 11.439459025836042, 12.415543015023152, 13.429305385882728, 14.37045034532255, 15.377336843519622, 16.354110521850608, 16.367707101664063, 15.455534839678155, 14.555524922573817, 13.590119748477962, 12.655739964228548, 11.676583733664518, 10.733537168641535, 9.752339572036707, 6.704005804530286, 7.70775232028582, 8.522594867740116, 9.493245270534842, 10.531029458456901, 11.43596728664772, 12.450597124518431, 13.42084224557406, 14.40783318571233, 15.310472991500065, 16.265601557367667, 16.34016142997334, 15.406141807575917, 14.49859794466582, 13.529650659582442, 12.570438832355574, 11.678647859218366, 10.709352206007212, 9.77484580114509, 8.741027337401556, 7.772970502050477, 8.722153746101023, 9.535557150140807, 10.448327086288606, 11.497010183242136, 12.482424615758521, 13.422704159956377, 14.425319337516639, 15.391130040096874, 16.333195743636924, 16.363293407348063, 15.39938324747893, 14.403175927924192, 13.427053451494507, 12.545162632882635, 11.613494600988233, 10.645330232980339, 9.74247196925225, 8.733563451540928, 7.748381693614992, 8.717107500410526, 9.734724615759905, 10.608351658130772, 11.4209999925019, 12.432300729127116, 13.366436678305051, 14.33732071963338, 15.30518647270734, 16.30169524808008, 16.394630428603072, 15.340387647177279, 14.39191159542873, 13.40671943375298, 12.440955140768992, 11.523340478382035, 10.636746275121489, 9.696185069861187, 8.746815241021855, 7.862688634947103, 6.821122254887896, 9.673158269591154, 10.638803246809335, 11.536068161288263, 12.469162843011329, 13.400048494339355, 14.29393513071029, 15.333345851609504, 16.278261029773756, 16.500924260708913, 15.517466895536527, 14.482527126606456, 13.517179343745758, 12.542044376464176, 11.469067659106313, 10.527442158172127, 9.64302692815148, 8.711112409895172, 7.73820720814724, 6.788336611350225, 5.861809032838854, 10.667314497056433, 11.564963443567473, 12.523495733149911, 13.450405292635553, 14.393193277706375, 15.300983650594752, 16.27517796356118, 16.400148926230056, 15.443757400246099, 14.482848118799923, 13.530302031796529, 12.594831901940918, 11.65056476452681, 10.62644434079526, 9.60070433619151, 8.651668611084306, 7.693649737845575, 6.751593235688124, 5.752035844928461, 4.834655440750717, 11.719516492086793, 12.621622800910833, 13.47606646209021, 14.42583181011839, 15.416297806161722, 16.239420328727803, 16.723177605862972, 15.71185360285714, 14.719459955088368, 13.707507694265091, 12.777656681047992, 11.830809136425488, 10.779017287182427, 9.71067528873085, 8.740473193412928, 7.795905514768844, 6.830242962569958, 5.814990603447298, 4.791316185279263, 3.786821403582981, 12.673342379304398, 13.676514802009855, 14.488167754423188, 15.385622456204182, 16.381985075437164, 16.743419040340548, 15.788585790427557, 14.815227948264077, 13.782078477559004, 12.898592752005118, 11.834411666895917, 10.798350405674302, 9.802927801627757, 8.877964666160482, 7.820520745895071, 6.864015205623109, 5.8556565426804426, 4.891394493063231, 3.909351248328652, 2.8507176946443638, 13.719505508696736, 14.695495755639138, 15.432484533619453, 16.313156645414015, 16.917535830632726, 15.887761430434622, 14.878157278266254, 13.831378241408459, 12.838519504582825, 11.89347021280988, 10.845830973281684, 9.80614542444846, 8.86097670986849, 7.958313561405924, 6.999216409818748, 5.983304927215018, 4.949018054799529, 3.921725327462352, 2.9380081918676204, 1.9055041654068496, 14.763316748621376, 15.644921393338073, 16.401810771878882, 16.953150167740212, 15.940836418693996, 14.956159574844145, 13.929381708477822, 12.970197477260605, 11.997803585880517, 11.017386149837069, 9.943313396851579, 8.899380434027707, 7.929622663876443, 6.998028555619554, 6.025425552441622, 4.960028035811792, 4.014817801898332, 2.993680543237387, 1.9924930586960143, 0.9290545785962111, 15.714950519790895, 16.672076640043002, 16.910906045765678, 15.98330122374692, 15.000605561242605, 14.016789973178609, 13.04996128659468, 12.080819423241872, 11.065036057273998, 10.04108413143674, 9.098313363368948, 8.11932240243984, 7.171048195652377, 6.185410920974514, 5.130555455637106, 4.096504628967088, 3.0564017587478634, 2.047513717181249, 0.9865549890962053, 0.0, 16.684621731512717, 17.720704550889316, 17.71073238933691, 16.760123253648715, 15.815315443909753, 14.74163114420678, 13.775788570660481, 12.80629732073259, 11.808472265184706, 10.774055742568835, 9.795056491443283, 8.869024764542955, 7.849242091387012, 6.905426386718986, 5.9656412588575485, 4.966055792927247, 3.9563613223509493, 2.9766166233154268, 1.9417505865584461, 1.0645331372979032, 17.612307365146894, 18.565675661979576, 18.683794161597973, 17.70167655462663, 16.76507012213477, 15.69077572252945, 14.733461111349657, 13.771557417157167, 12.821727555954846, 11.83816148605152, 10.831896821778752, 9.82756563460109, 8.896644375473329, 7.889662065928407, 6.937863413920184, 5.94125503009786, 4.927638166635331, 3.9106930174479255, 2.9595006822967207, 2.126180000519591], [17.860545070624433, 18.67674960504766, 18.696313396411746, 17.741316846895447, 16.691913625218895, 15.680218357290801, 14.72593547068287, 13.708866921607639, 12.699831693106908, 11.747422611084403, 10.704359663312472, 9.660758999141496, 8.73077931392045, 7.720317754278452, 6.776961533628218, 5.767638538594857, 4.817570349258592, 3.888366176387221, 2.869897804598813, 1.9119578591407065, 16.78885931327141, 17.733879271369354, 18.150000494610136, 17.160008523368415, 16.126670178977832, 15.05383193914894, 14.04139850290715, 13.006890857141675, 12.06158963479745, 11.101024307018326, 10.168594725977199, 9.235776592163939, 8.183037913325935, 7.136263106592947, 6.089734200129747, 5.077135924713545, 4.012743422092276, 3.046664581621587, 2.022930121567694, 0.9562011282043682, 15.783077526054763, 16.728805531881715, 17.622888722046696, 18.042407674742776, 16.987472723204295, 16.005815597124503, 14.982363938527037, 14.006935447300684, 13.02270836423299, 12.024782873456463, 11.090414564005583, 10.030548083224092, 8.99342477877717, 7.943840217787081, 6.950722864518013, 5.93644412198913, 4.889029765161793, 3.901429076100092, 2.9015858849002036, 1.9044375425212943, 14.815058218459678, 15.78414155361079, 16.612963334179497, 17.546214739033125, 17.880826024418827, 16.887652892204088, 15.93076177926441, 14.901727403625639, 13.86343471703025, 12.905253656899298, 11.861496078437582, 10.81233775616126, 9.763521603882154, 8.716853644113595, 7.642666664171735, 6.716623668204391, 5.7859382886577855, 4.794450224013173, 3.8670780661225876, 2.9450383152424098, 13.88362253653557, 14.85387555868536, 15.581274023050565, 16.598679310192896, 17.443640934838946, 17.832960937492658, 16.762033223898392, 15.832464965114278, 14.82179848777342, 13.768849102220278, 12.736271018132337, 11.679113473826465, 10.651715843581012, 9.621046931676089, 8.65498338872515, 7.673257368290964, 6.723434012413288, 5.868613250027, 4.859075418342687, 3.9283310988888225, 12.899273782664194, 13.910667400490636, 14.641525731270477, 15.597419371582566, 16.504234743771892, 17.509542194312264, 17.395164911960723, 16.41929277920819, 15.45270495643975, 14.509978007537326, 13.547571092912753, 12.612673059268106, 11.544092499468192, 10.531512895641061, 9.582420256692803, 8.746427362384017, 7.756186080554942, 6.765349165658852, 5.8219104568391105, 4.925773656566222, 11.944101501722383, 12.851476661686249, 13.646325984900246, 14.621051735499364, 15.559495213194815, 16.564713030593428, 17.48777961771852, 17.39229432310717, 16.397256073026707, 15.43636101197177, 14.470957253811882, 13.537790490695258, 12.471876420290961, 11.526794989689432, 10.576289569943652, 9.700753318947996, 8.733942893280135, 7.690367970538535, 6.810901883635214, 5.914212274787408, 10.959547287703682, 11.894838675919141, 12.695951441680196, 13.640096972847793, 14.60872322099456, 15.549162623955395, 16.485253227891388, 17.461337217078498, 17.318661458806616, 16.377516499366795, 15.370630001169722, 14.393856322838738, 13.423248670605414, 12.46339294036071, 11.502378980115791, 10.668581055013494, 9.635722205189088, 8.633385501380733, 7.818442423676512, 6.932282159476012, 9.980896553801998, 10.924159405928116, 11.765907263530682, 12.655205273324588, 13.604232731563282, 14.616563759207725, 15.593070966186394, 16.563316087242022, 17.445678220131306, 17.209453004997094, 16.25432443912949, 15.318833587090984, 14.38481396469356, 13.420329835373046, 12.482575391814963, 11.523363564588095, 10.569912682249193, 9.60061702903804, 8.777133791172956, 7.943594394111162, 8.911931856281807, 9.861115100332354, 10.75294498112999, 11.700123457570825, 12.587332571683339, 13.572747004199725, 14.620963930748449, 15.568510478497139, 16.46238136574676, 17.404447069286814, 17.18752605529414, 16.343033031085763, 15.387779844345285, 14.461923752936737, 13.468487892850371, 12.480307795955436, 11.520431087024887, 10.567497265793001, 9.83964920737909, 8.936240037897726, 7.967794857921758, 8.987928114308474, 9.680150473140026, 10.727450551357531, 11.652042025798359, 12.585646004695693, 13.556530046024022, 14.524395799097983, 15.50152647234376, 16.43147897172191, 17.329456721824535, 17.34170052693976, 16.35650836526401, 15.390744072280022, 14.451371707088496, 13.45705612182218, 12.469576250144039, 11.578424056952738, 10.836477906521125, 9.863499476624822, 7.011744088741129, 7.914062924397645, 8.752433969982535, 9.679287700848104, 10.68429426058612, 11.658147552290455, 12.56341464963652, 13.577757266612055, 14.536659787792104, 15.47502098551207, 16.383506649370673, 17.26449732273745, 17.354215497146456, 16.3626315539427, 15.439008732364808, 14.395360569313393, 13.463446051057085, 12.587032089827352, 11.749340277185235, 10.822812698673864, 6.01758786127585, 6.987902727639508, 7.765006398120887, 8.69804525122388, 9.740546003579398, 10.651099032405993, 11.563552806824594, 12.523101401345333, 13.479492927329291, 14.440402208775467, 15.392948295778861, 16.32841842563447, 17.27268556304858, 17.327223964184206, 16.365746554345424, 15.456772340625259, 14.498753467386528, 13.573646062286468, 12.782163965353663, 11.849966290762001, 4.965385866245491, 5.995187241682215, 6.812435669180587, 7.722618733741042, 8.717441475124051, 9.71266235427294, 10.625401911928353, 11.568468008993067, 12.526088934142805, 13.559623790442132, 14.489474803659231, 15.516437518597971, 16.471700223593285, 17.35828601246867, 17.361857436966886, 16.417289758322802, 15.451627206123916, 14.558866734688465, 13.742883625002861, 12.897800327929737, 4.011559979027886, 4.940295240583193, 5.80033437684761, 6.76282808765525, 7.7591907068882335, 8.701178081047415, 9.656011330960407, 10.629369173123887, 11.588707456613442, 12.61606821902205, 13.666183798725523, 14.685586759351043, 15.431035233194883, 16.358236146248757, 17.377465042162065, 17.38104616250027, 16.515427118536387, 15.582709821424684, 14.712569030827828, 13.833904036868354, 2.9653968496355487, 3.8851496705307778, 4.856017597651345, 5.835293898445418, 6.795533504991415, 7.647911463195918, 8.63059224316774, 9.677371280025536, 10.645148483637263, 11.570852237524845, 12.618491477053041, 13.658177025886266, 14.489084141435617, 15.520794589705838, 16.435718064255518, 17.4754406230191, 17.529998751472466, 16.653116684112625, 15.683912087288858, 14.779117566105867, 1.921585609710908, 2.935724032831842, 3.886691359391916, 4.8326453319050895, 5.844221190234046, 6.7163096076054405, 7.681776533130295, 8.640960764347511, 9.6133546557276, 10.593772091771047, 11.652114018404662, 12.693620502216092, 13.55773009544357, 14.489324203700459, 15.461927206878391, 16.527324723508222, 17.472534957421683, 17.58116146833759, 16.681457253825357, 15.755567152916505, 0.9699518385413892, 1.943538739139996, 2.882823933352837, 3.810428755371593, 4.793124417875909, 5.776940005939904, 6.743768692523833, 7.712910555876642, 8.728693921844515, 9.752645847681773, 10.695416615749565, 11.674407576678673, 12.622681783466136, 13.608319058144, 14.663174523481407, 15.697225350151426, 16.73732822037065, 17.746216261937263, 17.671176720608923, 16.684621731512717, 0.0, 1.057267320590626, 2.0188046018840264, 2.9694137375722227, 3.9142215473111834, 4.987905847014158, 5.953748420560457, 6.923239670488348, 7.9210647260362315, 8.955481248652102, 9.934480499777655, 10.860512226677983, 11.880294899833926, 12.824110604501952, 13.76389573236339, 14.76348119829369, 15.773175668869987, 16.75292036790551, 17.78778640466249, 17.74915486881062, 0.9276856336341759, 1.8810539304668592, 2.891149687814332, 3.8732672947856734, 4.809873727277536, 5.884168126882856, 6.853813649092397, 7.880174103995344, 8.875144529383652, 9.904790615725837, 10.911055279998605, 11.863199604542128, 12.794120863669889, 13.820387027255784, 14.736117887426024, 15.739667295523722, 16.75328415898625, 17.770229308173658, 18.721421643324863, 18.81080173203231], [18.896347263181465, 18.2792385851692, 17.63904607582112, 16.684049526304822, 15.634646304628271, 14.662407336994086, 13.720786813300085, 12.703718264224854, 11.743902326084088, 10.791493244061583, 9.748430296289651, 8.704829632118676, 7.77484994689763, 6.7643883872556305, 5.821032166605397, 4.825631058686951, 3.9265721758136314, 3.0149801638141174, 1.9965117920257094, 2.907361789579709, 17.82466150582844, 17.336368251490892, 17.82926377153475, 17.656530715447104, 16.63355465016467, 15.560716410335777, 14.548282974093986, 13.513775328328512, 12.568474105984286, 11.607908778205163, 10.675479197164035, 9.742661063350775, 8.769207012499251, 7.761579693253403, 6.844332706775879, 5.831734431359677, 4.963271986641984, 4.069747116963899, 3.046012656910005, 2.013468448794994, 16.818879718611797, 16.331294512003254, 16.7629478467661, 17.70089268695948, 17.509130274877453, 16.52747314879766, 15.504021490200193, 14.52859299897384, 13.55038272869284, 12.625715003150006, 11.702112919971604, 10.708068677993875, 9.796125725303922, 8.746541164313832, 7.785411762323739, 6.771133019794856, 5.934545611284666, 4.958696396690717, 3.958853205490829, 2.9617048631119203, 15.850860411016711, 15.268493167170252, 15.7530224588989, 16.686273863752525, 17.542361153898874, 17.46010618569619, 16.503215072756515, 15.57697769400812, 14.561807726120989, 13.603626665990037, 12.719373537145492, 11.670215214869168, 10.774964802422847, 9.728296842654288, 8.69993398476236, 7.773890988795016, 6.843205609248411, 5.851717544603798, 4.924345386713213, 4.002305635833036, 14.919424729092604, 14.257501842333584, 14.721333147769966, 15.738738434912298, 16.581505624147272, 17.636483860008802, 17.455730032241856, 16.52616177345774, 15.571170421663298, 14.618121276024524, 13.648939366222303, 12.62301832915452, 11.708983164171638, 10.678314252266714, 9.712250709315775, 8.730524688881589, 7.780701333003914, 6.925880570617625, 5.916342738933315, 4.985598419479449, 13.935075975221228, 13.254054280231108, 13.781584855989879, 14.737478496301968, 15.642099433080219, 16.64740688362059, 17.57109653941457, 17.461602490249753, 16.49501466748131, 15.552287718578889, 14.589880803954316, 13.654982770309669, 12.601359820058818, 11.588780216231687, 10.639687577283429, 9.80369468297464, 8.813453401145567, 7.822616486249479, 6.879177777429738, 5.983040977156849, 12.979903694279416, 12.19486354142672, 12.786385109619648, 13.761110860218766, 14.697359902503141, 15.702577719901754, 16.61482807847823, 17.581686679344013, 17.439565784068268, 16.47867072301333, 15.528224574402508, 14.595057811285884, 13.529143740881587, 12.584062310280057, 11.633556890534278, 10.75802063953862, 9.791210213870762, 8.747635291129162, 7.8681692042258415, 6.971479595378034, 11.995349480260716, 11.238225555659612, 11.836010566399597, 12.77796166215612, 13.746587910302887, 14.676211084715106, 15.612301688651097, 16.588385677838207, 17.60214804869778, 17.43478381995742, 16.427897321760348, 15.451123643429364, 14.48051599119604, 13.520660260951336, 12.559646300706417, 11.725848375604118, 10.692989525779716, 9.69065282197136, 8.875709744267139, 7.989549480066637, 11.016698746359031, 10.267546285668587, 10.905966388250084, 11.793069962632915, 12.742097420871609, 13.743612219967437, 14.701069873481332, 15.67131499453696, 16.550767391837624, 17.537742029187058, 17.311591759720116, 16.376100907681607, 15.442081285284186, 14.477597155963672, 13.539842712405592, 12.580630885178724, 11.627180002839822, 10.657884349628667, 9.834401111763583, 8.999530651927726, 9.947734048838841, 9.204501980072825, 9.893004105849393, 10.837988146879152, 11.725197260991665, 12.696203497828904, 13.728962838043387, 14.676509385792077, 15.56747053745308, 16.509536240993132, 17.45745165370164, 17.400300351676385, 16.44504716493591, 15.519191073527367, 14.525755213441, 13.537575116546066, 12.577698407615514, 11.624764586383629, 10.896916527969717, 9.99217629571429, 9.003597050478792, 8.191931110413943, 8.820209597859428, 9.865315240665858, 10.789906715106685, 11.694958934139887, 12.66452895331896, 13.63239470639292, 14.606615644050077, 15.536568143428223, 16.434545893530853, 17.358397307176055, 17.413775685854638, 16.44801139287065, 15.508639027679125, 14.51432344241281, 13.526843570734666, 12.635691377543365, 11.893745227111753, 10.919435734441386, 8.047546281298164, 7.118065920503114, 7.892493094701936, 8.81715239015643, 9.822158949894446, 10.767460481734648, 11.668503821342837, 12.682846438318371, 13.64174895949842, 14.580110157218387, 15.488595821076991, 16.36958649444377, 17.34472146172535, 17.41989887453333, 16.496276052955437, 15.45262788990402, 14.520713371647712, 13.644299410417979, 12.805276535001799, 11.878748956490428, 7.053390053832884, 6.191905723744977, 6.905065522840289, 7.835909940532206, 8.878410692887725, 9.760411961850185, 10.66864197853091, 11.628190573051649, 12.584582099035607, 13.545491380481783, 14.498037467485178, 15.433507597340789, 16.377774734754897, 17.401895158486447, 17.423013874936053, 16.514039661215886, 15.556020787977156, 14.630913382877095, 13.838100223170226, 12.905902548578565, 6.001188058802525, 5.135246366401616, 5.952494793899989, 6.860483423049368, 7.855306164432378, 8.821975283717132, 9.73049108363467, 10.673557180699383, 11.63117810584912, 12.664712962148446, 13.594563975365546, 14.621526690304286, 15.543872656818543, 16.430458445693933, 17.400660541011852, 17.474557078913428, 16.508894526714542, 15.616134055279092, 14.798819882819423, 13.9537365857463, 5.04736217158492, 4.080354365302594, 4.940393501567012, 5.900692776963576, 6.89705539619656, 7.806267252753731, 8.761100502666723, 9.734458344830204, 10.693796628319758, 11.721157390728365, 12.77127297043184, 13.79067593105736, 14.503207666420142, 15.430408579474017, 16.449637475387323, 17.406143015659286, 17.572694439127012, 16.63997714201531, 15.76850528864439, 14.889840294684918, 4.001199042192582, 3.0252087952501787, 3.996076722370746, 4.973158587753744, 5.933398194299741, 6.753000634902234, 7.7356814148740565, 8.78246045173185, 9.750237655343579, 10.67594140923116, 11.723580648759357, 12.763266197592582, 13.561256574660876, 14.592967022931097, 15.507890497480776, 16.54761305624436, 17.513146682538864, 17.71038400470325, 16.739848345105422, 15.835053823922433, 2.9738485826144387, 2.0757831575512427, 3.026750484111317, 3.970510021213416, 4.949310361940363, 5.821398779311757, 6.786865704836611, 7.746049936053827, 8.718443827433916, 9.698861263477363, 10.72428645162992, 11.76579293544135, 12.62990252866883, 13.561496636925717, 14.53409964010365, 15.599497156733479, 16.544707390646938, 17.60139072729015, 17.73739351164192, 16.791649972293104, 2.02221481144492, 1.0486279108463132, 1.9879131050591539, 2.91551792707791, 3.898213589582225, 4.882029177646221, 5.848857864230149, 6.817999727582959, 7.8337830935508315, 8.824818280907031, 9.767589048974823, 10.746580009903932, 11.694854216691395, 12.680491491369258, 13.735346956706666, 14.70917177646, 15.696752624371692, 16.699360921589367, 17.685714681534105, 17.720704550889316, 1.057267320590626, 0.0, 0.9615372812934003, 1.9121464169815967, 2.8569542267205574, 3.930638526423532, 4.89648109996983, 5.865972349897722, 6.863797405445605, 7.898213928061477, 8.877213179187029, 9.803244906087357, 10.8230275792433, 11.766843283911326, 12.706628411772764, 13.706213877703064, 14.715908348279362, 15.695653047314885, 16.730519084071865, 17.6716894952651, 1.9230895640731784, 0.9697212672404952, 1.9798170245879678, 2.931259814877767, 3.867866247369629, 4.879783104746202, 5.849428626955743, 6.8312324463223, 7.826202871710607, 8.85584895805279, 9.862113622325559, 10.805932283951503, 11.736853543079263, 12.763119706665158, 13.678850566835399, 14.682399974933096, 15.696016838395625, 16.712961987583032, 17.664154322734237, 18.731924990499124], [18.694125854313572, 17.715369960569742, 16.677508794527718, 15.72251224501142, 14.673109023334868, 13.700870055700683, 12.759249532006683, 11.742180982931451, 10.782365044790689, 9.829955962768183, 8.786893014996252, 7.743292350825277, 6.81331266560423, 5.8028511059622305, 4.859494885311997, 3.86409377739355, 2.965034894520231, 2.103968355953902, 2.95804907331911, 3.8688990708731095, 17.697083977500125, 17.82683963247242, 16.920208582806165, 16.6949934341537, 15.672017368871272, 14.599179129042378, 13.586745692800587, 12.552238047035113, 11.606936824690887, 10.646371496911764, 9.713941915870636, 8.781123782057376, 7.807669731205851, 6.800042411960003, 5.882795425482478, 4.870197150066276, 4.001734705348583, 3.1616263380543126, 4.007549938203405, 2.9750057300883945, 17.617681234984094, 16.821765892984782, 15.853892658037513, 16.791837498230894, 16.547592993584054, 15.565935867504262, 14.542484208906794, 13.567055717680441, 12.588845447399441, 11.664177721856607, 10.740575638678205, 9.746531396700476, 8.834588444010521, 7.7850038830204324, 6.823874481030338, 5.809595738501455, 4.9730083299912655, 4.229144166222142, 4.92039048678423, 3.9232421444053207, 16.64966192738901, 15.758964548151779, 14.843967270170312, 15.777218675023938, 16.600328461133206, 16.49856890440279, 15.541677791463115, 14.61544041271472, 13.60027044482759, 12.642089384696638, 11.757836255852093, 10.70867793357577, 9.813427521129448, 8.766759561360889, 7.7670078003815854, 6.8409648044142415, 5.910279424867636, 5.266998698695803, 5.885882668006614, 4.945681970811891, 15.7182262454649, 14.74797322331511, 13.812277959041378, 14.82968324618371, 15.639472931381604, 16.694451167243134, 16.494192750948454, 15.56462449216434, 14.6096331403699, 13.656583994731125, 12.687402084928904, 11.661481047861121, 10.752585753569626, 9.721916841664703, 8.779324524935001, 7.797598504500815, 6.847775148623139, 6.34116172470963, 6.859719073912169, 5.928974754458304, 14.80234181003487, 13.854553969613857, 12.87252966726129, 13.82842330757338, 14.70006674031455, 15.705374190854922, 16.62891787950613, 16.500065208956357, 15.533477386187913, 14.59075043728549, 13.628343522660916, 12.69344548901627, 11.668433635678046, 10.655854031850915, 9.706761392902656, 8.870768498593867, 7.880527216764793, 7.277000384727815, 7.822554112408592, 6.926417312135704, 13.847169529093058, 12.866460165485128, 11.877329920891059, 12.852055671490177, 13.755327209737473, 14.760545027136086, 15.672649418569792, 16.639508019435574, 16.478028502774873, 15.517133441719933, 14.595298390021735, 13.662131626905111, 12.596217556500815, 11.651136125899285, 10.700630706153506, 9.825094455157846, 8.86440389432218, 8.2020191896075, 8.811545539204696, 7.9148559303568895, 12.862615315074358, 11.90982217971802, 10.926955377671009, 11.835928969390451, 12.804555217537219, 13.73403242480667, 14.670123028742662, 15.646207017929772, 16.659969388789346, 16.50185763557665, 15.494971137379576, 14.518197459048592, 13.547589806815267, 12.587734076570564, 11.626720116325645, 10.792922191223344, 9.827317945415531, 9.145036720449697, 9.819086079245993, 8.932925815045493, 11.883964581172673, 10.97493512493837, 9.996911199521495, 10.851037269867247, 11.80006472810594, 12.801433560059001, 13.758891213572896, 14.729136334628524, 15.608588731929188, 16.59556336927862, 16.378665575339344, 15.443174723300837, 14.509155100903413, 13.5446709715829, 12.65259437931702, 11.757860932764617, 10.804410050425714, 10.112268248107004, 10.777777446742437, 9.866796486741368, 10.814999883652483, 9.956363782440503, 8.983948917120804, 9.895955454113484, 10.783164568225997, 11.754024837920468, 12.786784178134951, 13.734330725883641, 14.625291877544644, 15.567357581084694, 16.515272993793204, 16.467374167295617, 15.512120980555139, 14.616215464754212, 13.646815622753609, 12.71480516413196, 11.86415613755755, 11.079148484861966, 11.840292862948571, 10.859442130527931, 9.870862885292434, 8.943792912781621, 7.911154409130839, 8.92328254790019, 9.847874022341017, 10.752780274231451, 11.722350293410525, 12.690216046484485, 13.664436984141641, 14.594389483519787, 15.492367233622417, 16.41621864726762, 16.527884482654972, 15.602313775479727, 14.668637777254208, 13.691553489998704, 12.813301300676702, 12.090075276021702, 12.837121562090607, 11.786701569255028, 8.914812116111806, 7.949167138893626, 6.983437905973347, 7.875119697390762, 8.880126257128778, 9.825281821826213, 10.726325161434401, 11.740667778409936, 12.699570299589984, 13.637931497309951, 14.546417161168556, 15.427407834535332, 16.402542801816914, 16.574201257142406, 15.664536097464117, 14.685272836968712, 13.807171101589748, 13.098683308896316, 13.67254236981544, 12.74601479130407, 7.990313260548247, 7.023006942135488, 5.9960103341117, 6.893877247766538, 7.9363780001220565, 8.81823330194175, 9.726463318622475, 10.686011913143213, 11.642403439127172, 12.603312720573348, 13.555858807576742, 14.491328937432353, 15.435596074846462, 16.45971649857801, 16.591273919444735, 15.752912312553532, 14.842478517919192, 14.085297281355432, 14.705366057983868, 13.773168383392207, 6.938111265517888, 5.989610194787259, 5.0434396051714, 5.9184507302837, 6.9132734716667095, 7.879796623808696, 8.788312423726234, 9.731378520790948, 10.688999445940684, 11.72253430224001, 12.65238531545711, 13.67934803039585, 14.582335375525142, 15.46892116440053, 16.43912325971845, 16.756643083010925, 15.795352256656578, 15.07051795375743, 15.666085717633067, 14.821002420559942, 5.984285378300283, 5.017277572017958, 4.0313383128384235, 4.958660084197908, 5.955022703430892, 6.864088592845295, 7.818921842758287, 8.792279684921768, 9.751617968411322, 10.77897873081993, 11.829094310523402, 12.848497271148922, 13.541670385126741, 14.468871298180616, 15.488100194093924, 16.444605734365886, 16.85915216906905, 16.09436104049365, 16.63577112345803, 15.75710612949856, 4.938122248907945, 3.962132001965543, 3.087021533642158, 4.031125894988076, 4.991365501534073, 5.810821974993798, 6.79350275496562, 7.840281791823415, 8.808058995435143, 9.733762749322723, 10.78140198885092, 11.821087537684145, 12.599719293367475, 13.631429741637696, 14.546353216187375, 15.586075774950956, 16.551609401245464, 17.164767903181588, 17.607114179919062, 16.702319658736073, 3.910771789329803, 3.012706364266607, 2.1176952953827293, 3.028477328447748, 4.007131702031926, 4.87922011940332, 5.8446870449281745, 6.80387127614539, 7.776265167525479, 8.756682603568926, 9.76274917033652, 10.80425565414795, 11.668365247375428, 12.599959355632317, 13.572562358810249, 14.637959875440078, 15.583170109353539, 16.63985344599675, 17.64104093053812, 17.5904514886654, 2.959138018160284, 1.9855511175616776, 1.046265923348837, 1.973485234312242, 2.9560349296737884, 3.939850517737784, 4.906679204321713, 5.875821067674522, 6.891604433642396, 7.863280999613631, 8.806051767681423, 9.78504272861053, 10.733316935397994, 11.718954210075857, 12.773809675413265, 13.747634495166597, 14.73521534307829, 15.737823640295964, 16.724177400240702, 17.710732389336908, 2.0188046018840264, 0.9615372812934003, 0.0, 0.9506091356881963, 1.895416945427157, 2.9691012451301315, 3.93494381867643, 4.904435068604322, 5.902260124152205, 6.936676646768076, 7.915675897893627, 8.841707624793955, 9.861490297949898, 10.805306002617924, 11.745091130479361, 12.744676596409661, 13.754371066985959, 14.734115766021482, 15.768981802778463, 16.710152213971696, 2.884626845366579, 1.9312585485338956, 1.060872083801074, 1.9697225335843664, 2.9063289660762286, 3.9182458234528017, 4.887891345662343, 5.8696951650289, 6.864665590417207, 7.894311676759391, 8.90057634103216, 9.8443950026581, 10.77531626178586, 11.801582425371755, 12.717313285541996, 13.720862693639694, 14.734479557102222, 15.75142470628963, 16.702617041440835, 17.77038770920572], [17.743516718625376, 16.764760824881545, 15.726899658839525, 14.771903109323224, 13.722499887646673, 12.750260920012488, 11.808640396318486, 10.791571847243254, 9.831755909102494, 8.879346827079988, 7.836283879308057, 6.792683215137081, 5.862703529916034, 4.852241970274035, 3.9088857496238005, 2.913484641705354, 2.0144257588320347, 2.9436299317034056, 3.908658209007306, 4.819508206561306, 16.74647484181193, 17.69071158084309, 16.73437626970723, 15.744384298465508, 14.721408233183075, 13.648569993354181, 12.63613655711239, 11.601628911346916, 10.65632768900269, 9.695762361223567, 8.76333278018244, 7.8305146463691795, 6.857060595517655, 5.8494332762718075, 4.9321862897942825, 3.91958801437808, 3.051125569660387, 4.001287913803816, 4.9581590738916015, 3.925614865776591, 17.69877566054282, 17.69593323043706, 16.728059995489794, 15.884377165250438, 15.596983857895857, 14.615326731816065, 13.591875073218597, 12.616446581992244, 11.638236311711244, 10.71356858616841, 9.789966502990008, 8.79592226101228, 7.883979308322326, 6.834394747332237, 5.873265345342142, 4.85898660281326, 4.02239919430307, 5.009999883364771, 5.870999622472426, 4.8738512800935165, 17.52382926484129, 16.633131885604058, 15.718134607622593, 14.869758342043484, 15.649719325445007, 15.547959768714595, 14.591068655774919, 13.664831277026524, 12.649661309139393, 11.69148024900844, 10.807227120163896, 9.758068797887573, 8.862818385441253, 7.816150425672693, 6.81639866469339, 5.890355668726046, 4.95967028917944, 5.951158353824053, 6.828557749928046, 5.849896968105856, 16.592393582917182, 15.622140560767392, 14.686445296493659, 13.922222913203255, 14.688863795693408, 15.743842031554939, 15.543583615260259, 14.614015356476143, 13.659024004681703, 12.705974859042929, 11.736792949240707, 10.710871912172925, 9.801976617881431, 8.771307705976508, 7.828715389246804, 6.846989368812619, 5.897166012934943, 6.844032053190388, 7.763934071206135, 6.833189751752269, 15.697475832098528, 14.728721307066138, 13.746697004713571, 12.920962974592925, 13.749457604626354, 14.754765055166725, 15.678308743817931, 15.54945607326816, 14.582868250499716, 13.640141301597293, 12.67773438697272, 11.742836353328073, 10.717824499989849, 9.705244896162718, 8.75615225721446, 7.920159362905672, 6.929918081076597, 7.779870713208574, 8.723309422028315, 7.830632309429669, 14.742303551156716, 13.740627502937409, 12.75149725834334, 11.931957821276601, 12.804718074049276, 13.80993589144789, 14.722040282881593, 15.688898883747376, 15.527419367086676, 14.566524306031736, 13.644689254333539, 12.711522491216915, 11.645608420812618, 10.700526990211088, 9.750021570465309, 8.87448531946965, 7.913794758633984, 8.704889518088258, 9.657234968718033, 8.819070927650854, 13.757749337138016, 12.783989517170301, 11.80112271512329, 10.885319833702255, 11.853946081849022, 12.783423289118472, 13.719513893054463, 14.695597882241573, 15.70936025310115, 15.551248499888452, 14.544362001691379, 13.567588323360395, 12.59698067112707, 11.637124940882368, 10.676110980637448, 9.842313055535149, 8.876708809727335, 9.647907048930456, 10.592014743010383, 9.836078494846914, 12.779098603236331, 11.84910246239065, 10.871078536973776, 9.90042813417905, 10.849455592417744, 11.850824424370803, 12.8082820778847, 13.778527198940328, 14.657979596240992, 15.644954233590422, 15.428056439651147, 14.49256558761264, 13.558545965215217, 12.594061835894703, 11.701985243628823, 10.80725179707642, 9.853800914737517, 10.615138576587762, 11.550706110506827, 10.761930508805026, 11.710133905716141, 10.851497804504158, 9.879082939184459, 8.945346318425287, 9.8325554325378, 10.80341570223227, 11.836175042446754, 12.783721590195444, 13.674682741856447, 14.616748445396498, 15.564663858105005, 15.516765031607418, 14.561511844866942, 13.665606329066016, 12.696206487065412, 11.764196028443763, 10.913547001869354, 11.582018813342724, 12.590927331054047, 11.75457615259159, 10.765996907356092, 9.838926934845276, 8.806288431194494, 7.972673412211994, 8.89726488665282, 9.802171138543253, 10.771741157722328, 11.739606910796288, 12.713827848453445, 13.64378034783159, 14.54175809793422, 15.465609511579423, 15.577275346966777, 14.65170463979153, 13.718028641566011, 12.740944354310507, 11.862692164988506, 12.59294560450246, 13.582839574293608, 12.681835591318686, 9.809946138175464, 8.844301160957283, 7.878571928037003, 6.924510561702565, 7.929517121440581, 8.874672686138014, 9.775716025746204, 10.790058642721739, 11.748961163901788, 12.687322361621755, 13.595808025480359, 14.476798698847135, 15.451933666128717, 15.623592121454209, 14.71392696177592, 13.734663701280516, 12.856561965901552, 13.601553637377075, 14.567676391879099, 13.641148813367728, 8.888455830562803, 7.918140964199145, 6.891144356175356, 5.943268112078342, 6.985768864433861, 7.8676241662535515, 8.775854182934278, 9.735402777455016, 10.691794303438975, 11.65270358488515, 12.605249671888545, 13.540719801744157, 14.484986939158265, 15.509107362889814, 15.640664783756536, 14.802303176865335, 13.891869382230995, 14.58816760983619, 15.587725000595855, 14.668302405455865, 7.842326262811854, 6.893825192081225, 5.9476546024653665, 4.967841594595504, 5.962664335978514, 6.929187488120499, 7.837703288038037, 8.78076938510275, 9.738390310252491, 10.771925166551817, 11.701776179768917, 12.728738894707657, 13.631726239836945, 14.518312028712334, 15.488514124030255, 15.806033947322728, 14.844743120968381, 15.573388282238188, 16.548444660245053, 15.7161364426236, 6.8885003755942495, 5.921492569311924, 4.93555331013239, 4.008050948509712, 5.004413567742696, 5.9134794571570986, 6.86831270707009, 7.841670549233571, 8.801008832723127, 9.828369595131736, 10.878485174835207, 11.897888135460727, 12.591061249438544, 13.51826216249242, 14.537491058405728, 15.49399659867769, 15.90854303338085, 16.597231368974406, 17.518130066070018, 16.652240151562218, 5.842337246201911, 4.866346999259508, 3.9912365309361233, 3.08051675929988, 4.040756365845877, 4.860212839305602, 5.842893619277424, 6.889672656135219, 7.857449859746947, 8.783153613634529, 9.830792853162725, 10.87047840199595, 11.649110157679278, 12.6808206059495, 13.595744080499179, 14.63546663926276, 15.601000265557268, 16.61728909453352, 17.684812423830195, 17.595761829715894, 4.814986786623768, 3.916921361560572, 3.0219102926766945, 2.077868192759552, 3.0565225663437303, 3.9286109837151244, 4.894077909239979, 5.853262140457194, 6.825656031837283, 7.806073467880731, 8.812140034648323, 9.853646518459753, 10.717756111687232, 11.64935021994412, 12.621953223122052, 13.687350739751881, 14.632560973665342, 15.689244310308553, 16.690431794849925, 17.689177832244926, 3.863353015454249, 2.889766114855642, 1.9504809206428018, 1.0228760986240457, 2.0054257939855926, 2.9892413820495882, 3.956070068633517, 4.925211931986326, 5.940995297954199, 6.912671863925434, 7.855442631993226, 8.834433592922334, 9.782707799709797, 10.76834507438766, 11.823200539725068, 12.797025359478402, 13.784606207390095, 14.78721450460777, 15.773568264552509, 16.760123253648715, 2.9694137375722227, 1.9121464169815967, 0.9506091356881963, 0.0, 0.9448078097389608, 2.0184921094419352, 2.9843346829882336, 3.953825932916125, 4.951650988464008, 5.986067511079879, 6.9650667622054305, 7.891098489105759, 8.910881162261703, 9.854696866929729, 10.794481994791166, 11.794067460721466, 12.803761931297764, 13.783506630333287, 14.818372667090268, 15.759543078283503, 3.835235981054775, 2.881867684222092, 2.0012310048675115, 1.0191133978961702, 1.9557198303880323, 2.9676366877646054, 3.937282209974147, 4.919086029340703, 5.91405645472901, 6.943702541071194, 7.949967205343962, 8.893785866969903, 9.824707126097664, 10.850973289683559, 11.766704149853801, 12.770253557951499, 13.783870421414028, 14.800815570601433, 15.752007905752638, 16.819778573517524], [16.798708908886415, 15.819953015142584, 14.782091849100564, 13.827095299584263, 12.777692077907712, 11.805453110273527, 10.863832586579527, 9.846764037504295, 8.886948099363533, 7.934539017341027, 6.891476069569096, 5.84787540539812, 4.917895720177073, 3.9074341605350735, 2.96407793988484, 2.005864467023552, 2.9592335685709954, 3.8884377414423663, 4.853466018746267, 5.764316016300267, 15.80166703207297, 16.74590377110413, 15.789568459968269, 14.799576488726547, 13.776600423444114, 12.70376218361522, 11.69132874737343, 10.656821101607955, 9.71151987926373, 8.750954551484606, 7.818524970443479, 6.885706836630218, 5.912252785778694, 4.904625466532846, 4.0117334808262815, 3.011967839696278, 3.9959333793993475, 4.946095723542777, 5.902966883630562, 4.8704226755155515, 16.75396785080386, 17.69969585663081, 16.73760205728516, 15.707110999695379, 14.652176048156896, 13.670518922077104, 12.647067263479636, 11.671638772253283, 10.693428501972283, 9.768760776429449, 8.845158693251047, 7.851114451273317, 6.939171498583365, 5.8895869375932755, 4.96564517066034, 3.9513664281314576, 4.96720700404203, 5.9548076931037315, 6.815807432211387, 5.818659089832478, 17.685159583782358, 17.57793969534302, 16.662942417361553, 15.814566151782445, 14.957969293967452, 14.603151958975634, 13.646260846035958, 12.720023467287563, 11.704853499400432, 10.74667243926948, 9.862419310424935, 8.813260988148611, 7.918010575702292, 6.871342615933732, 5.9324331171616125, 5.0063901211942685, 5.904478098918401, 6.895966163563013, 7.773365559667007, 6.794704777844817, 17.537201392656144, 16.566948370506353, 15.63125310623262, 14.867030722942216, 13.997113764215852, 14.835758679587874, 14.598775805521297, 13.669207546737182, 12.714216194942741, 11.761167049303968, 10.791985139501746, 9.766064102433964, 8.857168808142468, 7.826499896237546, 6.944749841715027, 5.963023821280842, 6.8419738226739035, 7.788839862929349, 8.708741880945096, 7.7779975614912304, 16.64228364183749, 15.6735291168051, 14.691504814452532, 13.865770784331886, 13.057707573148798, 13.84668170319966, 14.733500934078972, 14.6046482635292, 13.638060440760755, 12.695333491858332, 11.732926577233759, 10.798028543589112, 9.799306750141136, 8.786727146314005, 7.872186709682682, 7.0361938153738945, 7.874725890815557, 8.724678522947535, 9.668117231767276, 8.77544011916863, 15.687111360895678, 14.68543531267637, 13.696305068082301, 12.876765631015562, 12.11296804257172, 12.901852539480824, 13.777232473142634, 14.744091074008416, 14.582611557347715, 13.621716496292775, 12.726171504484826, 11.793004741368202, 10.727090670963905, 9.782009240362376, 8.866056022933531, 7.9905197719378735, 8.858602568372945, 9.64969732782722, 10.602042778456994, 9.763878737389815, 14.702557146876977, 13.728797326909262, 12.745930524862251, 11.830127643441216, 11.162196050371467, 11.838615479379513, 12.774706083315504, 13.750790072502614, 14.76455244336219, 14.606683864472492, 13.654675835008405, 12.67790215667742, 11.707294504444096, 10.75315939335059, 9.79214543310567, 8.958347508003373, 9.821516619466296, 10.592714858669417, 11.536822552749344, 10.780886304585875, 13.723906412975293, 12.793910272129612, 11.815886346712738, 10.845235943918011, 10.127864402799174, 10.906016614631843, 11.863474268145739, 12.833719389201367, 13.71317178650203, 14.70014642385146, 14.538370272968173, 13.602879420929666, 12.668859798532242, 11.710096288362925, 10.818019696097045, 9.97802842412576, 10.798608724476479, 11.559946386326724, 12.495513920245788, 11.706738318543987, 12.654941715455102, 11.796305614243119, 10.82389074892342, 9.890154128164248, 9.11096424291923, 9.85860789249331, 10.891367232707793, 11.838913780456483, 12.729874932117486, 13.671940635657537, 14.619856048366044, 14.627078864924444, 13.671825678183968, 12.781640781534238, 11.812240939533634, 10.934972655493102, 11.858354811608315, 12.526826623081686, 13.535735140793008, 12.69938396233055, 11.710804717095053, 10.783734744584237, 9.751096240933455, 8.917481221950954, 8.17567369703425, 8.857363328804293, 9.826933347983367, 10.794799101057327, 11.769020038714483, 12.69897253809263, 13.59695028819526, 14.520801701840462, 14.687589180283803, 13.767739092259752, 12.834063094034233, 11.911720981359846, 12.807499974727467, 13.537753414241422, 14.52764738403257, 13.626643401057647, 10.754753947914425, 9.789108970696244, 8.823379737775964, 7.869318371441526, 7.207925931822011, 7.929864876399054, 8.830908216007243, 9.845250832982778, 10.804153354162827, 11.742514551882794, 12.651000215741398, 13.531990889108174, 14.507125856389756, 14.73962657392243, 13.829961414244142, 12.905440328329854, 13.801369775640513, 14.546361447116036, 15.51248420161806, 14.58595662310669, 9.833263640301764, 8.862948773938106, 7.835952165914317, 6.888075921817303, 6.214781148454991, 6.922816356514591, 7.831046373195317, 8.790594967716055, 9.746986493700014, 10.70789577514619, 11.660441862149584, 12.595911992005195, 13.540179129419304, 14.564299553150853, 14.756699236224758, 13.973079803914674, 14.836677191969956, 15.532975419575152, 16.532532810334814, 15.613110215194826, 8.787134072550815, 7.838633001820186, 6.892462412204328, 5.9126494043344655, 5.191676619999644, 5.984379678381539, 6.892895478299077, 7.835961575363791, 8.79358250051353, 9.827117356812856, 10.756968370029956, 11.783931084968696, 12.686918430097986, 13.573504218973374, 14.543706314291295, 14.976810574372067, 15.789550930707343, 16.51819609197715, 17.49325246998401, 16.66094425236256, 7.833308185333211, 6.866300379050885, 5.880361119871351, 4.952858758248674, 4.189895814014193, 4.968671647418138, 5.92350489733113, 6.896862739494611, 7.856201022984166, 8.883561785392775, 9.933677365096248, 10.953080325721768, 11.646253439699585, 12.57345435275346, 13.592683248666768, 14.54918878893873, 15.557547451881398, 16.52180950149861, 17.50385274623319, 17.59704796130118, 6.787145055940872, 5.811154808998469, 4.9360443406750845, 4.025324569038841, 3.150250138905913, 3.9154050295666414, 4.898085809538463, 5.944864846396258, 6.912642050007987, 7.838345803895569, 8.885985043423766, 9.92567059225699, 10.704302347940319, 11.73601279621054, 12.65093627076022, 13.6906588295238, 14.656192455818308, 15.672481284794557, 16.740004614091234, 17.720819609316603, 5.759794596362729, 4.861729171299533, 3.9667181024156557, 3.022676002498513, 2.111714756604769, 2.9838031739761637, 3.949270099501018, 4.908454330718234, 5.880848222098323, 6.861265658141771, 7.867332224909363, 8.908838708720793, 9.772948301948272, 10.70454241020516, 11.677145413383093, 12.742542930012922, 13.687753163926383, 14.744436500569593, 15.745623985110965, 16.744370022505965, 4.808160825193211, 3.8345739245946033, 2.895288730381763, 1.9676839083630067, 1.0606179842466317, 2.0444335723106275, 3.011262258894556, 3.980404122247365, 4.996187488215238, 5.9678640541864745, 6.910634822254266, 7.889625783183375, 8.837899989970838, 9.823537264648701, 10.878392729986109, 11.852217549739441, 12.839798397651133, 13.842406694868808, 14.828760454813548, 15.815315443909753, 3.9142215473111834, 2.8569542267205574, 1.895416945427157, 0.9448078097389608, 0.0, 1.0736842997029745, 2.039526873249273, 3.009018123177164, 4.006843178725048, 5.04125970134092, 6.020258952466471, 6.9462906793668, 7.966073352522742, 8.909889057190767, 9.849674185052205, 10.849259650982505, 11.858954121558803, 12.838698820594326, 13.873564857351306, 14.814735268544542, 4.780043790793736, 3.8266754939610528, 2.946038814606472, 1.963921207635131, 1.0480996557062303, 2.0228288780256447, 2.9924744002351864, 3.974278219601742, 4.969248644990049, 5.998894731332233, 7.005159395605001, 7.948978057230944, 8.879899316358705, 9.9061654799446, 10.82189634011484, 11.825445748212537, 12.839062611675066, 13.856007760862472, 14.807200096013677, 15.874970763778563], [15.725024609183441, 14.746268715439612, 13.70840754939759, 12.75341099988129, 11.704007778204739, 10.731768810570554, 9.790148286876551, 8.77307973780132, 7.813263799660558, 6.860854717638052, 5.817791769866122, 4.774191105695145, 3.8442114204740987, 2.833749860832099, 1.8903936401818653, 2.899716635215226, 3.951502968545589, 4.88070714141696, 5.899175513205368, 6.8380003160032405, 14.727982732369997, 15.672219471401156, 14.715884160265295, 13.725892189023574, 12.702916123741142, 11.630077883912248, 10.617644447670457, 9.583136801904981, 8.637835579560756, 7.677270251781633, 6.744840670740506, 5.812022536927245, 4.83856848607572, 3.8309411668298723, 2.9380491811233065, 3.905820007887952, 4.970212510509221, 5.93629135097991, 6.9486763780896625, 5.944106975218526, 15.680283551100885, 16.626011556927835, 15.663917757582187, 14.633426699992405, 13.578491748453922, 12.59683462237413, 11.573382963776663, 10.59795447255031, 9.61974420226931, 8.695076476726475, 7.771474393548074, 6.777430151570344, 5.86548719888039, 4.815902637890301, 3.963132460039432, 4.845218596323131, 5.892632953150468, 6.880233642212169, 7.829387386191484, 6.832239043812574, 16.611475284079386, 17.580558619230498, 16.635608372123478, 15.576009105743031, 14.522640791487397, 13.52946765927266, 12.572576546332984, 11.646339167584589, 10.631169199697458, 9.672988139566506, 8.788735010721961, 7.739576688445638, 6.844326275999317, 5.797658316230757, 5.0269466499591395, 5.900242289385942, 6.8299040480268385, 7.821392112671451, 8.748764270562036, 7.7920135165211075, 17.542910966003493, 17.401090661938614, 16.46539539766488, 15.626140682778324, 14.56698716932419, 13.789806503748233, 13.525091505818324, 12.595523247034208, 11.640531895239768, 10.687482749600996, 9.718300839798772, 8.69237980273099, 7.783484508439494, 6.752815596534571, 6.077974519270055, 6.856875989472516, 7.767399771782341, 8.714265812037786, 9.706050619621385, 8.77530630016752, 17.47642593326975, 16.50767140823736, 15.525647105884794, 14.649268607045826, 13.627580978257136, 12.80072952736002, 13.68754875823933, 13.530963963826226, 12.564376141057782, 11.621649192155358, 10.659242277530785, 9.724344243886138, 8.725622450438163, 7.713042846611031, 7.005411387237709, 7.930045983565568, 8.800151839923995, 9.650104472055972, 10.593543180875713, 9.77274885784492, 16.521253652327935, 15.519577604108632, 14.530447359514563, 13.672238768353646, 12.682841447680058, 11.855900363641183, 12.731280297302993, 13.698138898168775, 13.508927257644741, 12.548032196589801, 11.65248720478185, 10.719320441665227, 9.65340637126093, 8.7083249406594, 7.999280700488558, 8.884371940129547, 9.784028517481381, 10.575123276935656, 11.52746872756543, 10.761187476066105, 15.536699438309235, 14.562939618341524, 13.580072816294512, 12.664269934873477, 11.732069455479804, 10.792663303539872, 11.728753907475863, 12.704837896662973, 13.718600267522548, 13.532999564769518, 12.58099153530543, 11.604217856974445, 10.633610204741121, 9.737994580224834, 8.925370110660698, 9.852199676195045, 10.746942568574733, 11.518140807777854, 12.46224850185778, 11.615028596018133, 14.55804870440755, 13.628052563561873, 12.650028638144999, 11.679378235350272, 10.697737807907512, 9.860064438792202, 10.817522092306097, 11.787767213361725, 12.66721961066239, 13.65419424801182, 13.464685973265198, 12.52919512122669, 11.595175498829267, 10.69493147523717, 9.951244373652072, 10.871880592317433, 11.724034673584915, 12.48537233543516, 13.420939869354225, 12.540880609976245, 13.48908400688736, 12.630447905675378, 11.65803304035568, 10.72429641959651, 9.680837648027568, 8.81265571665367, 9.845415056868152, 10.792961604616842, 11.683922756277845, 12.625988459817895, 13.573903872526403, 13.553394565221469, 12.598141378480992, 11.766475968408482, 10.945465617088662, 11.828824823684776, 12.783780760716752, 13.452252572190122, 14.461161089901445, 13.533526253762808, 12.544947008527311, 11.617877036016496, 10.585238532365715, 9.751623513383215, 8.745547102142588, 7.811411152964651, 8.780981172143726, 9.748846925217686, 10.723067862874842, 11.653020362252988, 12.550998112355618, 13.47484952600082, 13.613904880580828, 12.752574279133997, 11.96728777158926, 12.80557314955152, 13.732925923835904, 14.463179363349859, 15.453073333141006, 14.460785692489905, 11.588896239346683, 10.623251262128502, 9.657522029208224, 8.703460662873786, 7.81420585008974, 6.883912700559413, 7.784956040167602, 8.799298657143137, 9.758201178323185, 10.696562376043152, 11.605048039901757, 12.486038713268533, 13.461173680550115, 13.724461760796675, 12.96318609179917, 13.79929249652153, 14.72679572474895, 15.471787396224473, 16.346626493050316, 15.420098914538947, 10.667405931734022, 9.697091065370364, 8.670094457346575, 7.722218213249562, 6.82106106672272, 5.87686418067495, 6.785094197355676, 7.744642791876415, 8.701034317860373, 9.661943599306548, 10.614489686309943, 11.549959816165554, 12.494226953579663, 13.518347377311212, 13.889923913779786, 14.83895963888699, 15.762103141078393, 16.45840136868359, 17.379450181218743, 16.447252506627084, 9.75176095757883, 8.69052511004476, 7.744354520428901, 6.746791695766724, 5.890355401721729, 4.938427502541898, 5.846943302459436, 6.790009399524149, 7.747630324673888, 8.781165180973213, 9.711016194190313, 10.737978909129053, 11.61323413039501, 12.499819919270399, 13.47002201458832, 14.414589693232404, 15.38025224543129, 16.39550460455395, 17.39985385235518, 17.49508654379482, 8.803341904139513, 7.835817824422745, 6.794438581001456, 5.787001049680932, 4.888574595736278, 3.922719471578497, 4.877552721491488, 5.85091056365497, 6.810248847144525, 7.837609609553133, 8.880575919209802, 9.899978879835322, 10.57256913999661, 11.499770053050485, 12.518998948963793, 13.475504489235755, 14.483863152178422, 15.448125201795634, 16.430168446530214, 17.48887998653956, 7.7571787747471745, 6.7811885278047725, 5.850121801805191, 4.8594668604711, 3.899227253925103, 2.869452853727, 3.8521336336988226, 4.8989126705566175, 5.866689874168346, 6.792393628055928, 7.83288359753732, 8.872569146370545, 9.630618048237343, 10.662328496507564, 11.577251971057244, 12.616974529820824, 13.582508156115333, 14.598796985091582, 15.666320314388257, 16.64713530961363, 6.7571033350390195, 5.8317628901058365, 4.880795563545762, 3.9348415910325887, 2.9225278419863727, 1.9378509981365226, 2.903317923661377, 3.862502154878593, 4.834896046258682, 5.8153134823021295, 6.793647925206388, 7.835154409017817, 8.699264002245297, 9.630858110502185, 10.603461113680117, 11.668858630309947, 12.614068864223407, 13.670752200866618, 14.67193968540799, 15.670685722802991, 5.805469563869501, 4.831882663270894, 3.8925974690580536, 2.9649926470392973, 1.9822969845349823, 0.9984813964709863, 1.965310083054915, 2.9344519464077243, 3.931016522371817, 4.894179754483499, 5.836950522551291, 6.815941483480399, 7.764215690267862, 8.749852964945724, 9.804708430283132, 10.778533250036467, 11.76611409794816, 12.768722395165835, 13.755076155110574, 14.74163114420678, 4.987905847014158, 3.930638526423532, 2.9691012451301315, 2.0184921094419352, 1.0736842997029745, 0.0, 0.9658425735462983, 1.9353338234741897, 2.933158879022073, 3.9675754016379443, 4.946574652763496, 5.872606379663824, 6.892389052819767, 7.836204757487793, 8.775989885349231, 9.775575351279532, 10.78526982185583, 11.765014520891352, 12.799880557648333, 13.741050968841568, 5.85372809049671, 4.900359793664027, 3.942163017391194, 2.960045410419853, 2.0234389779279907, 0.9491445783226701, 1.9187901005322117, 2.9005939198987676, 3.8955643452870747, 4.925210431629258, 5.931475095902027, 6.8752937575279685, 7.806215016655729, 8.832481180241624, 9.748212040411866, 10.751761448509564, 11.765378311972093, 12.7823234611595, 13.733515796310705, 14.801286464075591], [14.75918203563714, 13.780426141893312, 12.742564975851291, 11.78756842633499, 10.73816520465844, 9.765926237024255, 8.824305713330254, 7.807237164255023, 6.877932660500597, 5.92552357847809, 4.882460630706159, 3.8388599665351832, 2.9088802813141372, 1.898418721672138, 2.8417749423223717, 3.851097937355733, 4.902884270686096, 5.832088443557467, 6.850556815345875, 7.803842889549539, 13.762140158823698, 14.706376897854858, 13.750041586718996, 12.760049615477275, 11.761290504059135, 10.694746744752285, 9.682313308510494, 8.64780566274502, 7.702504440400794, 6.741939112621671, 5.809509531580543, 4.876691397767282, 3.903237346915758, 2.8956100276699113, 3.889430483263813, 4.857201310028459, 5.921593812649728, 6.887672653120417, 7.90005768023017, 6.909949548764825, 14.714440977554586, 15.660168983381537, 14.728586618422225, 13.698095560832444, 12.643160609293961, 11.661503483214169, 10.638051824616701, 9.662623333390348, 8.684413063109348, 7.759745337566513, 6.836143254388111, 5.842099012410381, 4.93015605972043, 3.8805714987303404, 4.873688851999408, 5.796599898463638, 6.8440142552909755, 7.831614944352677, 8.79522995973778, 7.798081617358871, 15.645632710533087, 16.614716045684197, 15.700277232963515, 14.64067796658307, 13.587309652327436, 12.594136520112698, 11.637245407173022, 10.711008028424628, 9.695838060537495, 8.737657000406543, 7.853403871561998, 6.804245549285675, 5.908995136839357, 4.862327177070797, 5.936514157012656, 6.851623591526449, 7.781285350167346, 8.772773414811958, 9.700145572702544, 8.757856090067405, 16.577068392457196, 17.547321414606987, 16.616824414171905, 15.588213395423299, 14.548165182079035, 13.63411150449636, 12.589760366658362, 11.660192107874247, 10.705200756079805, 9.752151610441032, 8.782969700638809, 7.757048663571027, 6.848153369279533, 5.8174844573746105, 6.78354800032555, 7.765274020759735, 8.71878107392285, 9.665647114178295, 10.671893193167682, 9.741148873713817, 17.487464635914726, 17.43214248093712, 16.450118178584553, 15.568515354360995, 14.546827725572305, 13.71997627467519, 12.824277459419969, 12.595632824666263, 11.629045001897818, 10.686318052995395, 9.723911138370822, 8.789013104726175, 7.790291311278201, 6.77771170745107, 7.710984868293204, 8.674254943365629, 9.678139451619739, 10.601485774196481, 11.544924483016223, 10.738591431391217, 17.483682884726175, 16.44404867680839, 15.454918432214322, 14.591485515668815, 13.602088194995227, 12.775147110956354, 11.868008998483631, 12.834867599349414, 12.573596118484778, 11.612701057429838, 10.717156065621891, 9.783989302505267, 8.71807523210097, 7.772993801499441, 8.704854181544054, 9.628580899929608, 10.658221535579724, 11.526504579076166, 12.47885002970594, 11.727030049612402, 16.50254201185553, 15.487410691041283, 14.504543888994272, 13.588741007573235, 12.651316202794973, 11.71191005085504, 10.865482608656501, 11.841566597843611, 12.766478411628356, 12.597668425609555, 11.64566039614547, 10.668886717814486, 9.698279065581161, 8.802663441064874, 9.630943591716193, 10.596408635995106, 11.621135586673075, 12.469522109918364, 13.41362980399829, 12.580871169564432, 15.52389127795385, 14.552523636261633, 13.574499710844758, 12.60384930805003, 11.61698455522268, 10.779311186107371, 9.854344509974112, 10.82458963102974, 11.704042028330404, 12.691016665679834, 12.529354834105238, 11.59386398206673, 10.659844359669307, 9.75960033607721, 10.656817854707567, 11.616029681934435, 12.569480564273338, 13.43675363757567, 14.372321171494734, 13.506723183522544, 14.454926580433659, 13.596290479221677, 12.623875613901978, 11.648767492296267, 10.600084395342737, 9.731902463968838, 8.882237474536167, 9.829784022284855, 10.72074517394586, 11.66281087748591, 12.610726290194417, 12.618063426061509, 11.662810239321033, 10.831144829248522, 11.651039098144157, 12.572973913301777, 13.623227159063953, 14.403633874330632, 15.412542392041955, 14.499368827309107, 13.51078958207361, 12.583719609562795, 11.551081105912013, 10.693906165691157, 9.664793849457757, 8.730657900279821, 7.8178035898117395, 8.785669342885699, 9.759890280542857, 10.689842779921003, 11.587820530023633, 12.511671943668835, 12.678573741420868, 11.817243139974037, 12.672861252644756, 13.54972223916852, 14.572372322183105, 15.414560665490368, 16.404454635281514, 15.426628266036204, 12.554738812892982, 11.5890938356748, 10.623364602754522, 9.669303236420085, 8.733452597404911, 7.803159447874583, 6.821778457835617, 7.8361210748111505, 8.7950235959912, 9.733384793711167, 10.641870457569771, 11.522861130936548, 12.49799609821813, 12.789130621636716, 13.668759572854665, 14.54344158613853, 15.475356104394837, 16.423168698364982, 17.312469066596613, 16.385941488085244, 11.63324850528032, 10.662933638916662, 9.635937030892874, 8.68806078679586, 7.74030781403789, 6.79611092799012, 5.8219166150236905, 6.78146520954443, 7.737856735528387, 8.698766016974563, 9.651312103977958, 10.586782233833569, 11.531049371247677, 12.555169794979227, 13.570257041902913, 14.4524778901435, 15.367283410622381, 16.30933991277983, 17.308897303539492, 17.41309508017338, 10.717603531125128, 9.656367683591059, 8.7101970939752, 7.712634269313023, 6.836844319215727, 5.873588717097293, 4.8837657201274505, 5.826831817192164, 6.783390499278368, 7.816925355577693, 8.746776368794793, 9.773739083733533, 10.647391556848712, 11.5339773457241, 12.504179441042021, 13.448747119686107, 14.414409671884993, 15.429662031007652, 16.434011278808878, 17.438506060505162, 9.769184477685812, 8.801660397969044, 7.760281154547755, 6.752843623227231, 5.835063513230276, 4.869208389072495, 3.914375139159503, 4.887732981322984, 5.846009021749005, 6.873369784157613, 7.914733345663502, 8.934136306289023, 9.60672656645031, 10.533927479504186, 11.553156375417494, 12.509661915689456, 13.518020578632123, 14.482282628249335, 15.464325872983913, 16.523037412993258, 8.723021348293473, 7.747031101351071, 6.81596437535149, 5.825309434017399, 4.865069827471402, 3.8352954272732984, 2.8878938083033026, 3.9346728451610975, 4.902450048772826, 5.828153802660408, 6.867041023991021, 7.906726572824246, 8.664775474691044, 9.696485922961266, 10.611409397510945, 11.651131956274526, 12.616665582569034, 13.632954411545283, 14.700477740841958, 15.68129273606733, 7.7229459085853165, 6.797605463652135, 5.846638137092061, 4.9006841645788874, 3.888370415532671, 2.9036935716828207, 1.939078098265857, 2.898262329483073, 3.870656220863162, 4.8510736569066095, 5.827805351660089, 6.869311835471518, 7.733421428698997, 8.665015536955886, 9.637618540133818, 10.703016056763648, 11.648226290677108, 12.704909627320319, 13.706097111861691, 14.704843149256693, 6.771312137415798, 5.797725236817191, 4.858440042604351, 3.930835220585595, 2.94813955808128, 1.9643239700172845, 1.0010702576593953, 1.9702121210122046, 2.9651739488255187, 3.9283371809372007, 4.871107949004992, 5.8500989099341005, 6.798373116721563, 7.784010391399426, 8.838865856736835, 9.812690676490169, 10.800271524401861, 11.802879821619536, 12.789233581564275, 13.775788570660481, 5.953748420560457, 4.89648109996983, 3.93494381867643, 2.9843346829882336, 2.039526873249273, 0.9658425735462983, 0.0, 0.9694912499278914, 1.9673163054757747, 3.001732828091646, 3.980732079217198, 4.906763806117526, 5.926546479273469, 6.870362183941495, 7.8101473118029325, 8.809732777733233, 9.81942724830953, 10.799171947345053, 11.834037984102034, 12.77520839529527, 6.819570664043009, 5.866202367210326, 4.908005590937492, 3.925887983966151, 2.989281551474289, 1.9149871518689685, 0.9576725406891755, 1.9347513463524695, 2.929721771740777, 3.9593678580829605, 4.965632522355729, 5.909451183981671, 6.840372443109431, 7.866638606695326, 8.782369466865568, 9.785918874963265, 10.799535738425794, 11.8164808876132, 12.767673222764405, 13.835443890529291], [13.789690785709249, 12.81093489196542, 11.7730737259234, 10.8180771764071, 9.768673954730549, 8.796434987096363, 7.854814463402363, 6.83774591432713, 5.922754193604259, 4.980509691595799, 3.937446743823868, 2.8938460796528918, 1.9638663944318457, 2.8679099716000294, 3.811266192250263, 4.820589187283624, 5.872375520613987, 6.801579693485358, 7.820048065273767, 8.77333413947743, 12.792648908895808, 13.736885647926966, 12.780550336791105, 11.790558365549384, 10.791799254131243, 9.749732857869995, 8.737299421628204, 7.702791775862728, 6.757490553518503, 5.796925225739379, 4.864495644698252, 3.931677510884991, 2.9582234600334667, 3.8651012775978026, 4.858921733191704, 5.82669255995635, 6.891085062577619, 7.857163903048308, 8.869548930158063, 7.879440798692716, 13.744949727626697, 14.690677733453647, 13.783572731539934, 12.753081673950152, 11.69814672241167, 10.716489596331877, 9.69303793773441, 8.717609446508057, 7.739399176227057, 6.814731450684222, 5.89112936750582, 4.89708512552809, 3.987484104926488, 4.850062748658232, 5.8431801019273, 6.76609114839153, 7.813505505218867, 8.801106194280568, 9.764721209665671, 8.767572867286763, 14.676141460605198, 15.64522479575631, 14.755263346081223, 13.695664079700778, 12.642295765445144, 11.649122633230407, 10.692231520290731, 9.765994141542336, 8.750824173655204, 7.792643113524251, 6.908389984679706, 5.859231662403383, 4.966748363665314, 5.831818426998688, 6.906005406940547, 7.8211148414543405, 8.750776600095238, 9.74226466473985, 10.669636822630435, 9.727347339995296, 15.607577142529305, 16.577830164679096, 15.671810527289614, 14.643199508541008, 13.603151295196744, 12.689097617614069, 11.644746479776071, 10.715178220991955, 9.760186869197513, 8.80713772355874, 7.837955813756516, 6.812034776688735, 6.039368483274184, 6.786975707302502, 7.753039250253441, 8.734765270687626, 9.688272323850741, 10.635138364106187, 11.641384443095573, 10.710640123641708, 16.51797338598684, 17.502163057717144, 16.520138755364577, 15.564245115052488, 14.542557486263798, 13.645192623708127, 12.597659888869083, 11.650618937783971, 10.684031115015527, 9.741304166113103, 8.77889725148853, 7.843999217843884, 6.988368301072366, 7.747202957378962, 8.680476118221096, 9.64374619329352, 10.64763070154763, 11.570977024124373, 12.514415732944114, 11.708082681319109, 17.47314566692865, 17.41353992673628, 16.424409682142212, 15.560976765596706, 14.571579444923119, 13.744638360884245, 12.837500248411523, 12.252628996817556, 11.628582231602486, 10.667687170547547, 9.835741384718322, 8.902574621601698, 7.934974845113463, 8.742485051427332, 9.674345431471945, 10.598072149857499, 11.627712785507615, 12.495995829004057, 13.448341279633832, 12.696521299540294, 17.472033261783423, 16.456901940969175, 15.474035138922163, 14.558232257501126, 13.620807452722865, 12.681401300782932, 11.834973858584393, 11.218675135099383, 11.923829838435857, 11.652654538727264, 10.81868251512286, 9.841908836791877, 8.915178678593653, 9.772154690992766, 10.600434841644084, 11.565899885922997, 12.590626836600967, 13.439013359846255, 14.383121053926182, 13.550362419492322, 16.49338252788174, 15.522014886189524, 14.54399096077265, 13.573340557977922, 12.586475805150572, 11.748802436035263, 10.823835759902003, 10.168034574879638, 10.861393455137906, 11.848368092487336, 11.746254447117728, 10.810763595079221, 9.876743972681798, 10.7290915860051, 11.626309104635459, 12.585520931862327, 13.53897181420123, 14.406244887503561, 15.341812421422626, 14.476214433450433, 15.424417830361548, 14.565781729149567, 13.593366863829868, 12.618258742224159, 11.569575645270628, 10.70139371389673, 9.851728724464058, 9.163557482937058, 9.878096600753361, 10.820162304293412, 11.768077717001919, 11.834963039074, 10.879709852333523, 11.800636079176414, 12.620530348072048, 13.542465163229668, 14.592718408991844, 15.373125124258523, 16.382033641969848, 15.468860077236997, 14.4802808320015, 13.553210859490685, 12.520572355839903, 11.663397415619048, 10.634285099385648, 9.700149150207713, 8.787294839739632, 8.119442803537902, 8.917241707350358, 9.847194206728505, 10.745171956831134, 11.669023370476337, 11.895473354433358, 12.786734389901929, 13.642352502572647, 14.519213489096412, 15.541863572110996, 16.384051915418258, 17.373945885209405, 16.396119515964095, 13.524230062820871, 12.55858508560269, 11.592855852682412, 10.638794486347974, 9.702943847332802, 8.772650697802474, 7.791269707763508, 7.1463682464714875, 7.952375022798702, 8.890736220518669, 9.799221884377273, 10.68021255774405, 11.65534752502563, 12.558186589293816, 13.499812090228003, 14.543460253279418, 15.433099577023933, 16.326462635311056, 17.387699562919284, 17.355432738013135, 12.60273975520821, 11.632424888844552, 10.605428280820764, 9.65755203672375, 8.709799063965782, 7.765602177918011, 6.791407864951582, 6.077381464555878, 6.895208162335888, 7.856117443782065, 8.80866353078546, 9.74413366064107, 10.668928833663314, 11.59359417905231, 12.600765791975022, 13.482986640215609, 14.39779216069449, 15.33984866285194, 16.339406053611604, 17.271603728203264, 11.687094781053018, 10.625858933518948, 9.67968834390309, 8.682125519240913, 7.806335569143618, 6.843079967025185, 5.853256970055342, 5.034497039591434, 5.938094973159484, 6.971629829458809, 7.888487109887684, 8.915449824826425, 9.67790030692082, 10.564486095796209, 11.53468819111413, 12.479255869758216, 13.444918421957102, 14.46017078107976, 15.46452002888099, 16.46901481057727, 10.738675727613703, 9.771151647896936, 8.729772404475646, 7.722334873155122, 6.804554763158167, 5.838699639000386, 4.883866389087395, 4.0953982037222545, 5.000713495630121, 6.028074258038729, 6.945242095735611, 7.964645056361132, 8.63723531652242, 9.564436229576295, 10.583665125489604, 11.540170665761567, 12.548529328704234, 13.512791378321445, 14.494834623056024, 15.55354616306537, 9.692512598221365, 8.716522351278963, 7.785455625279381, 6.794800683945289, 5.834561077399292, 4.804786677201189, 3.857385058231194, 3.1115484968666354, 4.057154522653941, 4.9579134786007115, 5.89754977406313, 6.937235322896354, 7.695284224763153, 8.726994673033374, 9.641918147583056, 10.681640706346636, 11.647174332641145, 12.663463161617393, 13.730986490914068, 14.711801486139441, 8.692437158513208, 7.767096713580027, 6.816129387019952, 5.870175414506779, 4.857861665460563, 3.873184821610712, 2.9085693481937485, 2.0529668033641886, 3.0253606947442773, 3.9808333328469137, 4.858314101732198, 5.899820585543628, 6.763930178771107, 7.695524287027996, 8.668127290205929, 9.733524806835758, 10.678735040749219, 11.73541837739243, 12.736605861933802, 13.735351899328803, 7.740803387343689, 6.767216486745083, 5.827931292532242, 4.900326470513487, 3.9176308080091715, 2.933815219945176, 1.9705615075872867, 1.0697679182715982, 1.9956826988976275, 2.9588459310093094, 3.9016166990771013, 4.88060766000621, 5.828881866793672, 6.814519141471536, 7.869374606808943, 8.843199426562279, 9.830780274473971, 10.833388571691646, 11.819742331636386, 12.806297320732591, 6.923239670488348, 5.865972349897722, 4.904435068604322, 3.953825932916125, 3.009018123177164, 1.9353338234741897, 0.9694912499278914, 0.0, 0.9978250555478835, 2.0322415781637546, 3.0112408292893065, 3.9372725561896345, 4.957055229345578, 5.900870934013604, 6.840656061875041, 7.840241527805342, 8.84993599838164, 9.829680697417164, 10.864546734174144, 11.80571714536738, 7.7890619139709, 6.835693617138217, 5.877496840865383, 4.895379233894042, 3.9587728014021804, 2.88447840179686, 1.9271637906170669, 0.9652600964245781, 1.9602305218128855, 2.989876608155069, 3.9961412724278373, 4.939959934053778, 5.870881193181539, 6.897147356767434, 7.812878216937676, 8.816427625035374, 9.830044488497903, 10.846989637685308, 11.798181972836513, 12.8659526406014], [12.791865730161367, 11.813109836417539, 10.775248670375516, 9.820252120859216, 8.770848899182663, 7.798609931548478, 6.8569894078544795, 5.839920858779247, 4.924929138056377, 4.0509024237697915, 3.0078394759978613, 1.9642388118268852, 2.894218497047931, 3.8657350271479127, 4.809091247798147, 5.8184142428315075, 6.870200576161871, 7.799404749033242, 8.81787312082165, 9.771159195025316, 11.794823853347923, 12.739060592379083, 11.782725281243222, 10.7927333100015, 9.793974198583358, 8.772439075118527, 7.807692153802198, 6.773184508036723, 5.827883285692496, 4.8673179579133725, 3.9348883768722454, 3.0020702430589843, 3.888575562649552, 4.862926333145686, 5.8567467887395885, 6.8245176155042335, 7.888910118125502, 8.854988958596191, 9.867373985705946, 8.8772658542406, 12.747124672078812, 13.692852677905762, 12.837540020305617, 11.807048962715836, 10.752114011177353, 9.77045688509756, 8.763430669908404, 7.788002178682051, 6.80979190840105, 5.885124182858215, 4.961522099679813, 3.9674778577020833, 4.917836207542574, 5.847887804206115, 6.841005157475183, 7.763916203939413, 8.81133056076675, 9.798931249828453, 10.762546265213555, 9.765397922834646, 13.678316405057313, 14.647399740208424, 13.825656078255218, 12.766056811874773, 11.712688497619139, 10.719515365404401, 9.762624252464725, 8.83638687371633, 7.821216905829198, 6.863035845698246, 5.978782716853701, 4.9296243945773774, 5.897100466281399, 6.8296434825465715, 7.903830462488431, 8.818939897002224, 9.748601655643121, 10.740089720287733, 11.667461878178319, 10.72517239554318, 14.60975208698142, 15.580005109131209, 14.742203259463608, 13.713592240715002, 12.673544027370738, 11.759490349788063, 10.715139211950065, 9.78557095316595, 8.830579601371507, 7.877530455732734, 6.908348545930511, 5.88242750886273, 6.909825139108183, 7.784800762850385, 8.750864305801326, 9.732590326235512, 10.686097379398625, 11.63296341965407, 12.639209498643456, 11.708465179189592, 15.520148330438953, 16.533988660802834, 15.590531487538572, 14.634637847226482, 13.612950218437792, 12.715585355882121, 11.668052621043078, 10.721011669957965, 9.754423847189521, 8.811696898287098, 7.849289983662525, 6.914391950017879, 7.858824956906365, 8.745028012926845, 9.678301173768979, 10.641571248841403, 11.645455757095512, 12.568802079672256, 13.512240788491997, 12.705907736866992, 16.475320611380766, 17.514954819298552, 16.518749922155433, 15.544024171556314, 14.554626850882727, 13.549409033484114, 12.624321081979415, 11.694013213856945, 10.69897496377648, 9.738079902721541, 8.906134116892316, 7.972967353775692, 8.805431500947464, 9.740310106975215, 10.672170487019828, 11.595897205405382, 12.625537841055499, 13.49382088455194, 14.446166335181715, 13.694346355088177, 17.34769816331785, 17.454726996517053, 16.471860194470043, 15.55605731304901, 14.618632508270748, 13.679226356330815, 12.832798914132276, 11.904763711241213, 10.929568594181148, 10.723047270901258, 9.889075247296855, 8.912301568965871, 9.785635334427655, 10.745491064672358, 11.598259897191967, 12.56372494147088, 13.58845189214885, 14.436838415394138, 15.380946109474065, 14.548187475040205, 17.49120758342962, 16.519839941737406, 15.541816016320531, 14.571165613525805, 13.584300860698455, 12.746627491583146, 11.821660815449887, 10.854123151021467, 9.867132210883197, 10.854106848232627, 10.860677521149798, 9.92518666911129, 10.747200628515799, 11.702427959684693, 12.624134160183342, 13.58334598741021, 14.536796869749113, 15.404069943051445, 16.33963747697051, 15.474039488998317, 16.42224288590943, 15.56360678469745, 14.591191919377751, 13.616083797772042, 12.567400700818512, 11.699218769444613, 10.849553780011941, 9.941112487306622, 8.883835356498652, 9.825901060038703, 10.773816472747212, 10.949386113106069, 11.750166508167524, 12.72628898459721, 13.618355403619931, 14.540290218777553, 15.59054346453973, 16.370950179806407, 17.37985869751773, 16.46668513278488, 15.478105887549383, 14.551035915038568, 13.518397411387786, 12.66122247116693, 11.632110154933532, 10.697974205755596, 9.785119895287515, 8.896997807907466, 7.922980463095651, 8.852932962473798, 9.750910712576427, 10.674762126221628, 11.658793412653367, 12.532249015408611, 13.471621380600137, 14.465936965866453, 15.429144322389094, 16.337245612637787, 17.327139582428934, 17.39394457151198, 14.522055118368755, 13.556410141150574, 12.590680908230295, 11.636619541895858, 10.700768902880686, 9.770475753350357, 8.789094763311391, 7.923923250841051, 6.958113778543995, 7.896474976263962, 8.804960640122566, 9.68595131348934, 10.661086280770922, 11.560361533745933, 12.50198703468012, 13.545635197731535, 14.435274521476048, 15.328637579763171, 16.3898745073714, 17.300932264743516, 13.600564810756094, 12.630249944392435, 11.603253336368647, 10.655377092271634, 9.707624119513666, 8.763427233465896, 7.789232920499466, 6.857338444065139, 5.900946918081181, 6.861856199527358, 7.814402286530751, 8.749872416386362, 9.671103778115432, 10.595769123504427, 11.602940736427138, 12.485161584667724, 13.399967105146604, 14.342023607304055, 15.34158099806372, 16.27377867265538, 12.684919836600901, 11.623683989066832, 10.677513399450973, 9.679950574788796, 8.804160624691502, 7.840905022573069, 6.851082025603226, 5.936227376673549, 4.943833728904777, 5.977368585204102, 6.890662054339801, 7.917624769278541, 8.680075251372939, 9.566661040248325, 10.536863135566247, 11.48143081421033, 12.447093366409216, 13.462345725531875, 14.466694973333107, 15.471189755029389, 11.736500783161585, 10.76897670344482, 9.72759746002353, 8.720159928703005, 7.802379818706052, 6.83652469454827, 5.881691444635279, 5.039271294768274, 4.006452251375414, 5.030992741387292, 5.9474170401877275, 6.966820000813248, 7.639410260974537, 8.566611174028411, 9.585840069941721, 10.542345610213683, 11.55070427315635, 12.514966322773562, 13.49700956750814, 14.555721107517487, 10.690337653769246, 9.714347406826844, 8.783280680827264, 7.792625739493173, 6.832386132947176, 5.802611732749073, 4.855210113779078, 4.0554215879126545, 3.062893278399234, 3.9600884230528286, 4.899724718515246, 5.939410267348471, 6.69745916921527, 7.729169617485491, 8.644093092035172, 9.683815650798753, 10.649349277093261, 11.66563810606951, 12.733161435366185, 13.713976430591556, 9.690262214061091, 8.764921769127909, 7.813954442567836, 6.868000470054662, 5.855686721008446, 4.8710098771585955, 3.9063944037416323, 2.9968398944102077, 2.0310994504895703, 2.9830082772990303, 3.860489046184315, 4.9019955299957445, 5.766105123223223, 6.6976992314801125, 7.6703022346580445, 8.735699751287875, 9.680909985201335, 10.737593321844546, 11.738780806385918, 12.737526843780918, 8.738628442891573, 7.765041542292966, 6.825756348080126, 5.89815152606137, 4.915455863557055, 3.9316402754930593, 2.9683865631351702, 2.013641009317617, 0.997857643349744, 1.961020875461426, 2.903791643529218, 3.8827826044583267, 4.831056811245789, 5.816694085923652, 6.87154955126106, 7.845374371014394, 8.832955218926086, 9.835563516143761, 10.8219172760885, 11.808472265184706, 7.9210647260362315, 6.863797405445605, 5.902260124152205, 4.951650988464008, 4.006843178725047, 2.933158879022073, 1.9673163054757747, 0.9978250555478835, 0.0, 1.0344165226158712, 2.013415773741423, 2.939447500641751, 3.959230173797694, 4.903045878465719, 5.842831006327157, 6.842416472257458, 7.852110942833756, 8.831855641869279, 9.86672167862626, 10.807892089819495, 8.786886969518784, 7.8335186726861, 6.875321896413267, 5.893204289441925, 4.956597856950063, 3.8823034573447432, 2.9249888461649505, 1.9630851519724617, 1.01325529077014, 2.042901377112324, 3.0491660413850923, 3.9421348785058954, 4.873056137633656, 5.89932230121955, 6.815053161389792, 7.818602569487489, 8.83221943295002, 9.849164582137426, 10.800356917288632, 11.868127585053518], [11.757449207545497, 10.778693313801668, 9.740832147759646, 8.785835598243345, 7.736432376566793, 6.7641934089326075, 5.822572885238609, 4.805504336163376, 3.8905126154405054, 3.0391285224393405, 2.110957201284111, 2.9986553344427564, 3.9286350196638025, 4.900151549763784, 5.843507770414018, 6.852830765447378, 7.9046170987777415, 8.833821271649112, 9.852289643437521, 10.805575717641187, 10.760407330732052, 11.704644069763212, 10.748308758627351, 9.75831678738563, 8.759557675967487, 7.738022552502656, 6.798774922527966, 5.7642672767624905, 4.818966054418265, 4.078179374538118, 3.1803161306368892, 4.036486765674855, 4.922992085265423, 5.897342855761557, 6.891163311355459, 7.858934138120104, 8.923326640741374, 9.889405481212062, 10.901790508321817, 9.91168237685647, 11.71270814946294, 12.658436155289891, 11.803123497689747, 10.772632440099965, 9.717697488561482, 8.73604036248169, 7.754513438634173, 6.779084947407819, 5.800874677126819, 5.095985599482961, 4.206949853444457, 5.001894380317954, 5.9522527301584445, 6.882304326821986, 7.875421680091054, 8.798332726555284, 9.845747083382621, 10.833347772444323, 11.733216184307919, 10.73606784192901, 12.643899882441442, 13.612983217592554, 12.813048885556945, 11.757139580600542, 10.703771266344908, 9.710598134130171, 8.753707021190495, 7.827469642442098, 6.852400205312497, 6.0738972623229905, 5.232418862602713, 5.964040917193248, 6.93151698889727, 7.864060005162442, 8.938246985104302, 9.853356419618095, 10.783018178258992, 11.774506242903604, 12.674503096459734, 11.695842314637543, 13.575335564365549, 14.545588586515338, 13.733286028189378, 12.704675009440772, 11.664626796096508, 10.750573118513833, 9.706221980675833, 8.776653721891718, 7.861762900854807, 7.088391872357479, 6.161984691679523, 6.9168440314786, 7.944241661724054, 8.819217285466257, 9.785280828417196, 10.767006848851382, 11.720513902014495, 12.66737994226994, 13.60987941773782, 12.679135098283956, 14.48573180782308, 15.499572138186963, 14.581614256264341, 13.625720615952252, 12.604032987163562, 11.706668124607889, 10.659135389768846, 9.807677006238281, 8.902925777858542, 8.026171090989944, 7.160932247960516, 7.94880847263375, 8.893241479522235, 9.779444535542718, 10.71271769638485, 11.675987771457274, 12.679872279711383, 13.603218602288127, 14.546657311107868, 13.676577655961356, 15.440904088764892, 16.480538296682678, 15.5098326908812, 14.535106940282082, 13.545709619608495, 12.540491802209882, 11.615403850705183, 10.806241758426207, 9.847476894445501, 8.952554095424388, 8.223286115339231, 9.007383876391563, 9.839848023563333, 10.774726629591088, 11.7065870096357, 12.630313728021253, 13.65995436367137, 14.528237407167811, 15.480582857797586, 14.665016274182541, 16.31328164070198, 17.347484383560378, 16.427543155985045, 15.465107859955516, 14.496481611808749, 13.554020844468305, 12.617930240532313, 11.84019562014438, 10.85298349820578, 9.937521463604105, 9.290756859543643, 9.946718091581742, 10.820051857043524, 11.779907587288227, 12.632676419807838, 13.598141464086751, 14.62286841476472, 15.47125493801001, 16.415362632089938, 15.487583748844882, 17.233041441302113, 17.355321973634485, 16.37729804821761, 15.406647645422884, 14.419782892595535, 13.582109523480225, 12.632196185887762, 11.661951064832135, 10.674960124693865, 10.054140110241153, 10.26985855072589, 10.959603191727162, 11.78161715113167, 12.736844482300562, 13.658550682799213, 14.61776251002608, 15.571213392364983, 16.438486465667317, 17.37405399958638, 16.413435762802994, 17.36163915971411, 16.446966057806986, 15.432718912227203, 14.451565829669121, 13.402882732715591, 12.534700801341693, 11.685035811909021, 10.748940401117288, 9.69166327030932, 9.02593432204723, 9.828350321761366, 10.736767627285984, 11.640184912485164, 12.483930803518255, 13.459027012484865, 14.408268769117324, 15.343872962892375, 16.29680678412426, 17.289551758955096, 17.406081406589557, 16.41750216135406, 15.490432188843245, 14.457793685192463, 13.49670450306401, 12.467592186830611, 11.533456237652675, 10.620601927184595, 9.704825721718132, 8.730808376906317, 8.037867194985118, 8.805444561590582, 9.729295975235784, 10.62442141038533, 11.49783249279274, 12.437204857984266, 13.431520443250582, 14.394727799773223, 15.302829090021914, 16.29272305981306, 17.22582896417669, 15.461451392173432, 14.49580641495525, 13.530077182034972, 12.54125749451578, 11.536250934777764, 10.605957785247437, 9.62457679520847, 8.731751164651717, 7.7659416923546605, 7.081409208775282, 7.859494489136719, 8.740485162503496, 9.626714278502885, 10.525945011130062, 11.467570512064249, 12.511218675115664, 13.400857998860177, 14.2942210571473, 15.355457984755526, 16.26651574212765, 14.53996108456077, 13.569646218197112, 12.542649610173324, 11.59477336607631, 10.543106151410743, 9.598909265362973, 8.624714952396545, 7.665166357875806, 6.708774831891848, 6.046790432038678, 6.868936135544906, 7.804406265400517, 8.63668725549956, 9.561352600888556, 10.568524213811267, 11.450745062051853, 12.365550582530734, 13.307607084688184, 14.307164475447848, 15.23936215003951, 13.655589755695265, 12.594353908161196, 11.648183318545337, 10.65062049388316, 9.740423169608782, 8.745202290459893, 7.75537929349005, 6.744055290484216, 5.751661642715444, 5.071325682704483, 5.85624553172393, 6.8832082466626705, 7.645658728757067, 8.532244517632455, 9.502446612950376, 10.44701429159446, 11.412676843793346, 12.427929202916005, 13.432278450717234, 14.436773232413517, 12.707170702255949, 11.739646622539183, 10.698267379117894, 9.69082984779737, 8.741475852125408, 7.7756207279676275, 6.820787478054636, 5.847429635891155, 4.814280165186081, 3.9965762187714216, 4.913000517571857, 5.932403478197378, 6.604993738358665, 7.5321946514125395, 8.551423547325848, 9.50792908759781, 10.516287750540478, 11.48054980015769, 12.462593044892268, 13.521304584901614, 11.66100757286361, 10.685017325921208, 9.753950599921628, 8.763295658587536, 7.80305605204154, 6.773281651843437, 5.809403023361357, 4.863579929035535, 3.8707211922099014, 2.9256719004369574, 3.8653081958993756, 4.9049937447326, 5.663042646599398, 6.694753094869619, 7.6096765694193, 8.64939912818288, 9.614932754477389, 10.631221583453637, 11.698744912750312, 12.679559907975685, 10.660932133155455, 9.735591688222273, 8.7846243616622, 7.838670389149026, 6.82635664010281, 5.84167979625296, 4.8605873133239115, 3.9014030821066954, 2.9290091907266067, 1.948591754683159, 2.8260725235684436, 3.867579007379873, 4.7316886006073515, 5.663282708864241, 6.635885712042173, 7.701283228672002, 8.646493462585463, 9.703176799228673, 10.704364283770046, 11.703110321165047, 9.709298361985937, 8.73571146138733, 7.79642626717449, 6.868821445155734, 5.886125782651419, 4.9023101945874235, 3.935481508003495, 2.966339644650686, 1.9505562786828126, 0.9266043528455546, 1.8693751209133465, 2.848366081842455, 3.7966402886299173, 4.7822775633077805, 5.837133028645188, 6.810957848398523, 7.798538696310215, 8.80114699352789, 9.78750075347263, 10.774055742568835, 8.955481248652102, 7.898213928061476, 6.936676646768076, 5.98606751107988, 5.041259701340919, 3.9675754016379443, 3.001732828091646, 2.0322415781637546, 1.0344165226158712, 0.0, 0.9789992511255516, 1.9050309780258798, 2.9248136511818226, 3.8686293558498486, 4.808414483711286, 5.807999949641587, 6.817694420217885, 7.797439119253407, 8.832305156010388, 9.773475567203624, 9.821303492134655, 8.867935195301971, 7.909738419029138, 6.927620812057797, 5.991014379565935, 4.9167199799606145, 3.9594053687808213, 2.9975016745883325, 2.0476718133860112, 1.0716972803806029, 2.0267243635589702, 2.907718355890024, 3.838639615017785, 4.86490577860368, 5.780636638773921, 6.784186046871619, 7.7978029103341475, 8.814748059521554, 9.765940394672759, 10.833711062437645], [10.778449956419943, 9.799694062676114, 8.761832896634093, 7.806836347117793, 6.757433125441241, 5.785194157807056, 4.843573634113056, 3.8265050850378244, 2.9115133643149536, 2.060129271313789, 3.0899564524096625, 3.9776545855683083, 4.907634270789354, 5.879150800889336, 6.82250702153957, 7.831830016572931, 8.883616349903294, 9.812820522774665, 10.831288894563073, 11.784574968766737, 9.781408079606498, 10.72564481863766, 9.769309507501799, 8.779317536260077, 7.780558424841937, 6.759023301377105, 5.819775671402415, 4.78526802563694, 3.8399668032927137, 3.099180123412567, 4.031609704453694, 4.964427838266955, 5.901991336390975, 6.876342106887109, 7.870162562481012, 8.837933389245658, 9.902325891866926, 10.868404732337615, 11.880789759447369, 10.890681627982023, 10.733708898337387, 11.679436904164337, 10.824124246564196, 9.793633188974415, 8.738698237435932, 7.7570411113561395, 6.775514187508622, 5.800085696282268, 4.8218754260012675, 4.116986348357409, 5.05135465780829, 5.929835452910054, 6.931251981283997, 7.861303577947538, 8.854420931216607, 9.777331977680836, 10.824746334508173, 11.812347023569874, 12.712215435433473, 11.715067093054564, 11.664900631315888, 12.633983966467, 11.834049634431395, 10.778140329474992, 9.724772015219358, 8.73159888300462, 7.7747077700649445, 6.848470391316548, 5.873400954186946, 5.09489801119744, 6.076823666966546, 6.891981989785348, 7.910516240022822, 8.843059256287994, 9.917246236229854, 10.832355670743647, 11.762017429384544, 12.753505494029156, 13.653502347585288, 12.674841565763098, 12.596336313239995, 13.566589335389784, 12.754286777063827, 11.725675758315221, 10.685627544970957, 9.771573867388282, 8.727222729550283, 7.797654470766167, 6.882763649729256, 6.109392621231929, 7.006389496043356, 7.8447851040707, 8.872182734316155, 9.798216536591807, 10.764280079542747, 11.746006099976933, 12.699513153140048, 13.646379193395493, 14.588878668863375, 13.65813434940951, 13.580685067111371, 14.57003689749226, 13.60261500513879, 12.646721364826702, 11.625033736038011, 10.727668873482338, 9.680136138643295, 8.82867775511273, 7.9239265267329895, 7.047171839864394, 8.005337052324348, 8.876749545225849, 9.821182552114337, 10.758443786668268, 11.6917169475104, 12.654987022582825, 13.658871530836933, 14.58221785341368, 15.52565656223342, 14.65557690708691, 14.535857348053183, 15.530598430532766, 14.53083343975565, 13.556107689156532, 12.566710368482944, 11.561492551084331, 10.636404599579633, 9.827242507300657, 8.868477643319949, 7.973554844298837, 9.005789256832083, 9.935324948983663, 10.767789096155434, 11.712870526756964, 12.673105421640855, 13.609312979146804, 14.63895361479692, 15.507236658293364, 16.459582108923136, 15.644015525308095, 15.409596972205412, 16.431410706906505, 15.448543904859495, 14.486108608829966, 13.517482360683198, 12.575021593342754, 11.638930989406763, 10.86119636901883, 9.873984247080228, 8.958522212478554, 9.965408710675627, 10.874659164173842, 11.747992929635625, 12.707848659880328, 13.599194831812994, 14.577140715212302, 15.601867665890271, 16.45025418913556, 17.39436188321549, 16.466582999970434, 16.329356772805543, 17.35661200842588, 16.378588083009006, 15.47100030835317, 14.519951485734866, 13.507620458090424, 12.650069088089152, 11.878587617857406, 10.891596677719136, 9.89854485865607, 9.888672278904444, 10.824163130942951, 11.739466123640321, 12.651790628192998, 13.549563587424885, 14.461528331988095, 15.414979214326998, 16.36000235238265, 17.31666615208177, 17.392435013928544, 17.393883320680747, 17.425965308932536, 16.411718163352752, 15.430565080794672, 14.381881983841142, 13.513700052467243, 12.664035063034571, 11.72793965224284, 10.670662521434872, 9.867825525262205, 8.955470662739796, 9.863887968264411, 10.736500243988596, 11.580246135021685, 12.555342343988295, 13.504584100620754, 14.440188294395805, 15.39312211562769, 16.385867090458525, 17.249403734407217, 17.39650141247961, 16.469431439968798, 15.436792936318014, 14.47570375418956, 13.446591437956162, 12.512455488778226, 11.599601178310145, 10.683824972843684, 9.70980762803187, 8.879758398200094, 7.932564902569011, 8.856416316214212, 9.72073674188876, 10.59414782429617, 11.533520189487696, 12.527835774754012, 13.491043131276653, 14.399144421525344, 15.389038391316491, 16.32214429568012, 16.44045064329898, 15.474805666080801, 14.509076433160523, 13.52025674564133, 12.515250185903314, 11.584957036372987, 10.603576046334021, 9.71075041577727, 8.744940943480213, 7.923300411990258, 6.9866148301151485, 7.867605503481925, 8.723029610006316, 9.622260342633492, 10.563885843567679, 11.607534006619094, 12.497173330363607, 13.39053638865073, 14.451773316258956, 15.362831073631076, 15.518960335686321, 14.548645469322663, 13.521648861298875, 12.573772617201861, 11.522105402536294, 10.577908516488524, 9.603714203522095, 8.644165609001357, 7.687774083017399, 6.888681635253654, 5.996056476523335, 6.931526606378946, 7.73300258700299, 8.657667932391986, 9.664839545314697, 10.547060393555283, 11.461865914034163, 12.403922416191614, 13.403479806951278, 14.33567748154294, 14.634589006820818, 13.573353159286748, 12.62718256967089, 11.629619745008712, 10.719422420734332, 9.724201541585444, 8.7343785446156, 7.723054541609767, 6.730660893840995, 5.913216885919459, 4.983365872702359, 6.0103285876411, 6.741974060260497, 7.628559849135884, 8.598761944453805, 9.54332962309789, 10.508992175296775, 11.524244534419434, 12.528593782220664, 13.533088563916946, 13.686169953381501, 12.718645873664736, 11.677266630243446, 10.669829098922921, 9.720475103250962, 8.75461997909318, 7.7997867291801875, 6.826428887016706, 5.793279416311632, 4.975575469896973, 4.040120858550286, 5.0455503107205795, 5.701309069862095, 6.628509982915969, 7.647738878829277, 8.60424441910124, 9.612603082043908, 10.576865131661119, 11.558908376395697, 12.617619916405044, 12.640006823989163, 11.66401657704676, 10.73294985104718, 9.742294909713088, 8.782055303167091, 7.752280902968989, 6.788402274486908, 5.842579180161087, 4.849720443335453, 3.9046711515625088, 2.9924285368778043, 4.018140577255802, 4.759357978102828, 5.791068426373049, 6.7059919009227285, 7.74571445968631, 8.711248085980817, 9.727536914957065, 10.79506024425374, 11.700560656850131, 11.63993138428101, 10.714590939347826, 9.763623612787752, 8.817669640274579, 7.805355891228363, 6.820679047378512, 5.839586564449463, 4.880402333232247, 3.908008441852158, 2.9275910058087105, 1.9531928645468724, 2.9638943388833017, 3.828003932110781, 4.75959804036767, 5.732201043545602, 6.797598560175431, 7.742808794088891, 8.799492130732101, 9.800679615273474, 10.724111070039493, 10.68829761311149, 9.714710712512884, 8.775425518300043, 7.847820696281286, 6.865125033776971, 5.881309445712976, 4.914480759129047, 3.945338895776237, 2.929555529808364, 1.9056036039711062, 0.9964954618917754, 1.9446814133458834, 2.892955620133346, 3.878592894811209, 4.890007340886276, 5.831958597272971, 6.819539445184662, 7.822147742402337, 8.808501502347076, 9.795056491443281, 9.934480499777655, 8.877213179187029, 7.915675897893628, 6.965066762205432, 6.020258952466471, 4.946574652763497, 3.980732079217198, 3.0112408292893065, 2.013415773741423, 0.9789992511255516, 0.0, 0.9260317269003281, 1.9458144000562707, 2.8896301047242967, 3.8294152325857342, 4.829000698516035, 5.8386951690923325, 6.818439868127855, 7.853305904884835, 8.79447631607807, 10.800302743260207, 9.846934446427523, 8.88873767015469, 7.906620063183349, 6.970013630691487, 5.895719231086167, 4.938404619906374, 3.976500925713885, 3.026671064511563, 2.0506965315061545, 1.0477251124334186, 1.9287191047644723, 2.859640363892233, 3.885906527478128, 4.80163738764837, 5.805186795746067, 6.818803659208596, 7.835748808396002, 8.786941143547207, 9.854711811312093], [9.852418229519616, 8.873662335775787, 7.835801169733764, 6.880804620217464, 5.831401398540913, 4.859162430906728, 3.9175419072127284, 2.9004733581374964, 1.9854816374146256, 2.9378907194371315, 3.980953667209062, 4.903686312468636, 5.833665997689683, 6.805182527789665, 7.748538748439898, 8.75786174347326, 9.809648076803622, 10.738852249674993, 11.757320621463402, 12.710606695667067, 8.855376352706172, 9.799613091737331, 8.84327778060147, 7.853285809359749, 6.854526697941608, 5.832991574476776, 4.893743944502087, 3.8592362987366116, 2.9139350763923857, 3.8745004041715094, 4.806929985212636, 5.739748119025897, 6.792486797863902, 7.8023738337874375, 8.79619428938134, 9.763965116145986, 10.828357618767255, 11.794436459237943, 12.806821486347697, 11.816713354882351, 9.80767717143706, 10.75340517726401, 9.898092519663868, 8.867601462074086, 7.812666510535603, 6.831009384455811, 5.849482460608294, 4.87405396938194, 3.895843699100939, 4.8923066291163515, 5.8266749385672325, 6.705155733668996, 7.7422790381159174, 8.787335304847867, 9.780452658116936, 10.703363704581164, 11.750778061408502, 12.738378750470204, 13.6382471623338, 12.641098819954891, 10.738868904415561, 11.707952239566673, 10.908017907531068, 9.852108602574663, 8.79874028831903, 7.805567156104292, 6.848676043164616, 5.9224386644162195, 4.947369227286617, 5.870218291956382, 6.852143947725488, 7.66730227054429, 8.716118422823396, 9.762786382591955, 10.836973362533815, 11.758387397643975, 12.688049156284873, 13.679537220929484, 14.579534074485615, 13.600873292663424, 11.670304586339668, 12.640557608489457, 11.828255050163499, 10.799644031414893, 9.759595818070629, 8.845542140487954, 7.801191002649954, 6.871622743865839, 5.9567319228289275, 6.884712901990871, 7.781709776802298, 8.620105384829643, 9.647503015075095, 10.678171926980019, 11.644235469930958, 12.625961490365144, 13.625544880040376, 14.572410920295821, 15.514910395763701, 14.584166076309836, 12.654653340211045, 13.644005170591933, 12.676583278238462, 11.720689637926373, 10.699002009137683, 9.80163714658201, 8.754104411742967, 7.902646028212402, 6.997894799832661, 7.822492120623336, 8.78065733308329, 9.65206982598479, 10.596502832873277, 11.609082436700408, 12.558175075648666, 13.52144515072109, 14.525329658975199, 15.508249580314008, 16.45168828913375, 15.581608633987237, 13.609825621152856, 14.604566703632438, 13.604801712855322, 12.630075962256203, 11.640678641582616, 10.635460824184003, 9.710372872679304, 8.901210780400328, 7.9424459164196195, 8.74887512505778, 9.781109537591025, 10.710645229742605, 11.543109376914375, 12.488190807515904, 13.448425702399796, 14.413640245501844, 15.44328088115196, 16.433268385193692, 17.385613835823467, 16.570047252208422, 14.483565245305085, 15.505378980006178, 14.522512177959166, 13.560076881929637, 12.59145063378287, 11.648989866442426, 10.712899262506435, 9.935164642118501, 8.9479525201799, 9.733842493237496, 10.740728991434569, 11.088644619126296, 11.774999690828139, 12.682695796305005, 13.643709756549924, 14.555177521210156, 15.466039592436854, 16.401202153139632, 17.34530984721956, 17.392614726870757, 15.403325045905216, 16.430580281525554, 15.45255635610868, 14.544968581452842, 13.593919758834538, 12.581588731190095, 11.724037361188824, 10.985805202338247, 10.010388903477851, 10.673865139415012, 10.814704005804773, 10.075759518980876, 10.813434396739993, 11.72575890129267, 12.623531860524556, 13.535496605087769, 14.488947487426671, 15.433970625482326, 16.390634425181442, 17.316017651293453, 16.46785159378042, 17.41703483783097, 16.465518638509373, 15.500050397206605, 14.610819918714482, 13.628997453328628, 12.696144396626769, 11.990282294280826, 10.993685757862396, 10.793857252162534, 9.881502389640124, 9.051560074986098, 9.810468517088268, 10.654214408121357, 11.629310617087967, 12.578552373720427, 13.514156567495478, 14.467090388727364, 15.4598353635582, 16.32337200750689, 17.320868628558323, 17.395463166869124, 16.36282466321834, 15.401735481089887, 14.372623164856488, 13.438487215678553, 12.525632905210474, 11.609856699744011, 10.635839354932196, 9.805790125100422, 8.85859662946934, 8.044088422935898, 8.794705014988432, 9.668116097395842, 10.607488462587368, 11.601804047853683, 12.565011404376326, 13.473112694625017, 14.463006664416165, 15.396112568779792, 17.366482370199307, 16.400837392981128, 15.43510816006085, 14.446288472541658, 13.441281912803642, 12.510988763273314, 11.52960777323435, 10.636782142677596, 9.67097267038054, 8.849332138890587, 7.912646557015477, 7.0552776102036105, 7.796997883105987, 8.696228615733164, 9.63785411666735, 10.681502279718766, 11.57114160346328, 12.464504661750404, 13.52574158935863, 14.43679934673075, 16.444992062586646, 15.47467719622299, 14.447680588199201, 13.499804344102188, 12.448137129436622, 11.503940243388852, 10.529745930422424, 9.570197335901685, 8.613805809917727, 7.814713362153983, 6.922088203423663, 6.119198713100632, 6.806970860102662, 7.731636205491657, 8.738807818414369, 9.621028666654956, 10.535834187133837, 11.477890689291288, 12.477448080050952, 13.409645754642613, 15.560620733721148, 14.499384886187078, 13.55321429657122, 12.555651471909043, 11.645454147634663, 10.650233268485774, 9.66041027151593, 8.649086268510096, 7.656692620741324, 6.839248612819787, 5.909397599602688, 5.157905769015338, 5.8159423333601685, 6.702528122235556, 7.672730217553477, 8.617297896197563, 9.582960448396449, 10.598212807519108, 11.602562055320336, 12.607056837016618, 14.612201680281828, 13.644677600565062, 12.603298357143773, 11.595860825823252, 10.646506830151289, 9.680651705993508, 8.725818456080516, 7.752460613917035, 6.719311143211961, 5.901607196797301, 4.966152585450613, 4.119518583820251, 4.7752773429617665, 5.702478256015641, 6.72170715192895, 7.678212692200912, 8.68657135514358, 9.65083340476079, 10.632876649495369, 11.691588189504715, 13.56603855088949, 12.590048303947087, 11.658981577947507, 10.668326636613418, 9.708087030067421, 8.678312629869318, 7.714434001387237, 6.768610907061415, 5.775752170235782, 4.830702878462837, 3.9184602637781323, 3.0921088503554737, 3.8333262512024993, 4.8650366994727205, 5.779960174022401, 6.8196827327859815, 7.78521635908049, 8.801505188056739, 9.869028517353414, 10.774528929949804, 12.565963111181336, 11.640622666248152, 10.689655339688079, 9.743701367174905, 8.73138761812869, 7.7467107742788395, 6.765618291349791, 5.806434060132576, 4.8340401687524865, 3.853622732709039, 2.8792245914472003, 2.0378626119829732, 2.9019722052104524, 3.8335663134673417, 4.806169316645274, 5.871566833275104, 6.816777067188564, 7.873460403831775, 8.874647888373147, 9.798079343139166, 11.614329340011817, 10.640742439413211, 9.70145724520037, 8.773852423181614, 7.791156760677299, 6.807341172613303, 5.8405124860293745, 4.871370622676565, 3.8555872567086924, 2.8316353308714346, 1.9225271887921034, 1.0186496864455552, 1.9669238932330178, 2.9525611679108805, 3.963975613985948, 4.905926870372643, 5.893507718284335, 6.89611601550201, 7.882469775446749, 8.869024764542955, 10.860512226677983, 9.803244906087357, 8.841707624793957, 7.891098489105761, 6.9462906793668, 5.872606379663825, 4.906763806117526, 3.9372725561896345, 2.939447500641751, 1.9050309780258798, 0.9260317269003281, 0.0, 1.0197826731559427, 1.9635983778239687, 2.9033835056854063, 3.9029689716157074, 4.912663442192005, 5.892408141227527, 6.927274177984508, 7.868444589177743, 11.726334470160536, 10.772966173327852, 9.814769397055018, 8.832651790083677, 7.896045357591816, 6.821750957986495, 5.864436346806702, 4.902532652614212, 3.952702791411891, 2.9767282584064825, 1.9737568393337468, 1.0026873778641443, 1.933608636991905, 2.9598748005777997, 3.8756056607480414, 4.879155068845739, 5.892771932308268, 6.909717081495674, 7.860909416646878, 8.928680084411765], [8.832635556363673, 7.8538796626198435, 6.816018496577821, 5.861021947061522, 4.81161872538497, 3.8393797577507853, 3.004862107360112, 2.014267005231909, 2.9611178027645595, 3.913526884787066, 4.956589832558997, 5.923468985624579, 6.8534486708456255, 7.824965200945607, 8.768321421595841, 9.777644416629203, 10.829430749959565, 11.758634922830936, 12.777103294619344, 13.730389368823008, 7.835593679550229, 8.779830418581389, 7.823495107445528, 6.833503136203806, 5.834744024785666, 4.813208901320834, 4.047328125886793, 3.043392349618749, 3.8895712417423196, 4.850136569521443, 5.7825661505625705, 6.715384284375832, 7.768122963213837, 8.814897769946825, 9.815976962537283, 10.783747789301929, 11.848140291923198, 12.814219132393886, 13.82660415950364, 12.836496028038294, 8.787894498281117, 9.733622504108068, 8.878309846507925, 7.847818788918144, 6.792883837379661, 5.811226711299869, 5.033638511490431, 4.058210020264077, 4.871479864450873, 5.867942794466286, 6.802311103917167, 7.680791899018931, 8.717915203465852, 9.767499764455941, 10.76061711772501, 11.723146377737107, 12.770560734564445, 13.758161423626145, 14.658029835489744, 13.660881493110836, 9.719086231259618, 10.68816956641073, 9.888235234375124, 8.856144712869105, 7.802776398613471, 6.809603266398733, 6.0328320940467535, 5.106594715298357, 5.923005392636552, 6.8458544573063165, 7.8277801130754225, 8.642938435894225, 9.69175458817333, 10.738422547941889, 11.81260952788375, 12.738652523851094, 13.669337903397698, 14.66082596804231, 15.588198125932896, 14.620655965819369, 10.650521913183725, 11.620774935333515, 10.83229116045794, 9.803680141709334, 8.76363192836507, 7.849578250782396, 6.985347053532092, 6.055778794747976, 6.932368088178862, 7.860349067340805, 8.757345942152233, 9.595741550179577, 10.623139180425031, 11.653808092329955, 12.619871635280894, 13.60159765571508, 14.606833627153202, 15.553699667408647, 16.534693068919648, 15.603948749465781, 11.634870667055102, 12.62422249743599, 11.680619388532904, 10.724725748220814, 9.703038119432124, 8.838655227170609, 7.938260462625103, 7.086802079094539, 7.973530965182595, 8.79812828597327, 9.756293498433225, 10.627705991334725, 11.572138998223213, 12.584718602050344, 13.533811240998602, 14.497081316071027, 15.500965824325135, 16.489538327426832, 17.432977036246573, 16.60139130714318, 12.590042947996913, 13.611665712059024, 12.611900721281907, 11.63717497068279, 10.647777650009202, 9.783484390889445, 8.894528923561442, 8.085366831282466, 8.918082081769555, 9.724511290407714, 10.75674570294096, 11.68628139509254, 11.780711518852323, 12.725792949453853, 13.595307161266057, 14.548513251819648, 15.454461638074198, 16.36972767852582, 17.322073129155594, 17.589829925364366, 13.509073239849075, 14.512477988432764, 13.529611186385752, 12.567175890356223, 11.598549642209456, 10.833145917324563, 9.897055313388572, 9.119320693000638, 9.923588685529834, 10.70947865858743, 11.716365156784503, 11.746191898086426, 10.800507685372132, 11.708203790848998, 12.669217751093917, 13.58068551575415, 14.491547586980847, 15.426710147683622, 16.370817841763547, 17.352837880472595, 14.428833040449206, 15.43767928995214, 14.459655364535266, 13.552067589879428, 12.632881289781748, 11.765744782072233, 10.908193412070961, 10.169961253220384, 10.986025068827786, 11.649501304764946, 11.580230120813736, 10.733306797941006, 9.838942391283986, 10.751266895836663, 11.64903985506855, 12.561004599631762, 13.514455481970664, 14.459478620026315, 15.416142419725434, 16.341525645837443, 15.493359588324411, 16.442542832374958, 15.472617646935957, 14.507149405633191, 13.649781449661692, 12.813153504210765, 11.880300447508906, 11.174438345162963, 11.96932192321233, 11.629650954444893, 10.647028504649088, 9.709107353946228, 8.83597651163226, 9.67972240266535, 10.65481861163196, 11.60406036826442, 12.539664562039468, 13.492598383271353, 14.48534335810219, 15.348880002050878, 16.34637662310231, 17.382886942539937, 16.545412154925923, 15.479822311846485, 14.585071995546672, 13.814398067899782, 12.944734332233333, 12.21855302456212, 11.647705035380413, 10.655838971866208, 9.624122744478303, 8.701635701896029, 7.820213009532425, 8.693624091939835, 9.63299645713136, 10.627312042397676, 11.590519398920316, 12.498620689169007, 13.488514658960154, 14.421620563323781, 17.293510016467007, 17.412703073429345, 16.446973840509067, 15.458154152989875, 14.45314759325186, 13.522854443721531, 12.541473453682567, 11.648647823125813, 10.682838350828757, 9.699380985656372, 8.678172672024441, 7.712824889163742, 6.822505877649981, 7.721736610277158, 8.663362111211343, 9.707010274262759, 10.59664959800727, 11.490012656294393, 12.551249583902619, 13.46230734127474, 17.456857743034867, 16.48654287667121, 15.459546268647419, 14.511670024550405, 13.46000280988484, 12.51580592383707, 11.54161161087064, 10.582063016349903, 9.625671490365944, 8.664762208919768, 7.7122161219163745, 6.776745992060763, 5.832478854646656, 6.7571442000356505, 7.764315812958362, 8.646536661198947, 9.561342181677826, 10.503398683835277, 11.502956074594941, 12.435153749186602, 16.58040340687709, 15.51916755934302, 14.57299696972716, 13.575434145064984, 12.665236820790604, 11.670015941641715, 10.680192944671871, 9.668868941666037, 8.676475293897266, 7.705365230143096, 6.7755142169259965, 5.834595126747394, 4.8414503279041625, 5.728036116779549, 6.69823821209747, 7.642805890741555, 8.60846844294044, 9.623720802063099, 10.628070049864329, 11.632564831560611, 15.631984353437772, 14.664460273721007, 13.623081030299717, 12.615643498979193, 11.66628950330723, 10.70043437914945, 9.745601129236457, 8.772243287072977, 7.7390938163679035, 6.896450287883123, 5.832269202773922, 4.796207941552307, 3.8007853375057605, 4.727986250559635, 5.747215146472944, 6.703720686744906, 7.712079349687572, 8.676341399304784, 9.658384644039362, 10.699959786031375, 14.585821224045434, 13.609830977103032, 12.678764251103452, 11.68810930976936, 10.727869703223362, 9.69809530302526, 8.73421667454318, 7.788393580217358, 6.795534843391724, 5.85048555161878, 4.843688509159686, 3.8040029603264616, 2.8588342457464933, 3.8905446940167145, 4.805468168566395, 5.845190727329976, 6.790801766294292, 7.807090595270542, 8.869500714795304, 9.754746256793862, 13.58574578433728, 12.660405339404097, 11.709438012844023, 10.76348404033085, 9.751170291284634, 8.766493447434783, 7.785400964505734, 6.826216733288518, 5.853822841908429, 4.873405405864982, 3.8763944581486802, 2.897237969905711, 1.9274801997544466, 2.8590743080113357, 3.831677311189268, 4.877152240488907, 5.822362474402366, 6.879045811045577, 7.871955548258806, 8.778296669983224, 12.634112013167762, 11.660525112569156, 10.721239918356314, 9.793635096337558, 8.810939433833243, 7.827123845769246, 6.860295159185317, 5.891153295832508, 4.875369929864635, 3.8514180040273773, 2.9196970554935833, 1.9407060945644745, 0.9924318877770121, 1.978069162454875, 2.944192940830005, 3.8861441972167006, 4.873725045128392, 5.876333342346067, 6.862687102290806, 7.849242091387012, 11.880294899833926, 10.8230275792433, 9.8614902979499, 8.910881162261703, 7.966073352522742, 6.892389052819768, 5.926546479273469, 4.957055229345578, 3.959230173797694, 2.9248136511818226, 1.9458144000562707, 1.0197826731559427, 0.0, 0.9438157046680259, 1.8836008325294635, 2.8831862984597647, 3.8928807690360623, 4.872625468071584, 5.907491504828565, 6.8486619160218005, 12.746117143316479, 11.792748846483795, 10.834552070210961, 9.85243446323962, 8.915828030747758, 7.841533631142438, 6.884219019962645, 5.922315325770156, 4.972485464567834, 3.988919394664509, 2.982654730391741, 1.9783235432140784, 1.0474022840863177, 1.9507884435018696, 2.8558229875920986, 3.859372395689796, 4.872989259152325, 5.889934408339731, 6.8411267434909355, 7.908897411255822], [7.888819851695647, 6.9100639579518175, 5.872202791909795, 4.917206242393496, 3.867803020716944, 2.8955640530827598, 2.061046402692086, 2.958082709899935, 3.9049335074325855, 4.857342589455092, 5.900405537227023, 6.867284690292605, 7.7972643755136515, 8.768780905613633, 9.712137126263867, 10.721460121297229, 11.773246454627591, 12.702450627498962, 13.72091899928737, 14.674205073491034, 6.891777974882203, 7.836014713913364, 6.879679402777502, 5.88968743153578, 4.89092832011764, 3.869393196652809, 3.103512421218767, 3.987208054286775, 4.833386946410346, 5.793952274189469, 6.7263818552305965, 7.659199989043858, 8.711938667881862, 9.758713474614849, 10.759792667205309, 11.727563493969955, 12.791955996591224, 13.758034837061912, 14.770419864171666, 13.78031173270632, 7.844078793613092, 8.789806799440044, 7.934494141839899, 6.904003084250118, 5.849068132711635, 4.867411006631843, 4.098650980656931, 5.002025724932103, 5.815295569118899, 6.811758499134312, 7.746126808585193, 8.624607603686957, 9.66173090813388, 10.711315469123969, 11.704432822393038, 12.666962082405133, 13.71437643923247, 14.701977128294171, 15.601845540157768, 14.60469719777886, 8.77527052659159, 9.744353861742702, 8.944419529707098, 7.912329008201079, 6.858960693945445, 5.865787561730707, 5.097844563213253, 6.050410419966383, 6.866821097304578, 7.7896701619743425, 8.77159581774345, 9.58675414056225, 10.635570292841356, 11.682238252609915, 12.756425232551775, 13.68246822851912, 14.613153608065724, 15.604641672710336, 16.53201383060092, 15.564471670487393, 9.706706208515698, 10.676959230665487, 9.888475455789914, 8.859864437041308, 7.819816223697044, 6.90576254611437, 6.0647816715934075, 6.994349930377523, 7.876183792846888, 8.804164772008832, 9.70116164682026, 10.539557254847603, 11.566954885093057, 12.597623796997981, 13.56368733994892, 14.545413360383106, 15.550649331821228, 16.497515372076673, 17.47850877358767, 16.547764454133805, 10.691054962387074, 11.680406792767963, 10.736803683864878, 9.780910043552788, 8.759222414764098, 7.894839522502584, 7.017695080686419, 7.9935672134389515, 8.917346669850621, 9.741943990641296, 10.700109203101253, 11.571521696002751, 12.51595470289124, 13.246367511175436, 13.945860459258084, 14.84483302258468, 15.78033212983264, 16.55615685625046, 17.4995955650702, 17.545207011811204, 11.646227243328886, 12.667850007390998, 11.668085016613881, 10.693359266014763, 9.703961945341176, 8.839668686221419, 7.973963541622757, 8.940822142488539, 9.86189778643758, 10.66832699507574, 11.700561407608985, 12.630097099760565, 12.724527223520349, 12.251085417127065, 12.951991146007234, 13.890507066020701, 14.796455452275252, 15.631138051370778, 16.58348350200055, 17.537476830002124, 12.630781457347586, 13.568662283764738, 12.585795481717726, 11.623360185688197, 10.65473393754143, 9.90290574632273, 8.976489931449887, 9.952573920636997, 10.86740439019786, 11.653294363255457, 12.66018086145253, 12.690007602754452, 11.744323390040158, 11.221415777561631, 12.025901735835095, 12.922679329955203, 13.8335414011819, 14.68812052052858, 15.632228214608507, 16.58814986026595, 13.60943219124927, 14.493863585284114, 13.51583965986724, 12.608251885211402, 11.689065585113722, 10.8355046110704, 9.987628030132276, 10.957873151187904, 11.929840773495812, 12.593317009432972, 12.524045825481762, 11.677122502609034, 10.782758095952012, 10.264478882549296, 11.00002747284372, 11.902998413832815, 12.856449296171718, 13.720888992871274, 14.677552792570392, 15.5768376256308, 14.678396888769461, 15.543049087847715, 14.52880194226793, 13.563333700965165, 12.705965744993666, 11.882913333208933, 10.959735065570221, 11.962350243130484, 12.913137627880356, 12.573466659112919, 11.590844209317114, 10.652923058614256, 9.779792216300287, 9.192934389377983, 10.005806229407131, 10.946054182465474, 11.801074934884426, 12.754008756116312, 13.746753730947148, 14.584191981844237, 15.581688602895667, 16.555619957506597, 15.601596450257896, 14.536006607178459, 13.641256290878646, 12.88415789689795, 12.024168950294648, 12.992034703368608, 12.59152074004844, 11.599654676534234, 10.567938449146329, 9.645451406564057, 8.764028714200451, 8.206836078652469, 8.983984074906532, 9.969305856598732, 10.851929771765274, 11.760031062013965, 12.749925031805112, 13.65693254311714, 16.528821996260362, 17.49446697347854, 16.52931295341539, 15.584169457687889, 14.609004056090885, 13.811656349303188, 13.020194082270772, 12.59246352779384, 11.626654055496783, 10.643196690324398, 9.621988376692467, 8.656640593831769, 7.766321582318007, 7.234948596989789, 7.988085754696623, 8.975586509628723, 9.858059970852228, 10.751423029139351, 11.786561563695978, 12.697619321068098, 17.52297822372564, 17.430358581339235, 16.403361973315445, 15.455485729218431, 14.403818514552865, 13.459621628505095, 12.485427315538667, 11.525878721017929, 10.56948719503397, 9.608577913587794, 8.6560318265844, 7.720561696728789, 6.776294559314682, 6.270356186748282, 7.061347932716007, 7.907947034043904, 8.822752554522785, 9.764809056680235, 10.7382680543883, 11.670465728979961, 17.52421911154512, 16.462983264011047, 15.516812674395187, 14.51924984973301, 13.60905252545863, 12.613831646309741, 11.624008649339897, 10.612684646334063, 9.620290998565292, 8.649180934811122, 7.7193299215940225, 6.77841083141542, 5.7852660325721885, 5.241248103492181, 5.9952703318551155, 6.904216263586512, 7.869878815785397, 8.849662830915776, 9.777548394739103, 10.692247790301966, 16.575800058105795, 15.608275978389031, 14.566896734967742, 13.559459203647219, 12.610105207975256, 11.644250083817475, 10.689416833904483, 9.716058991741003, 8.68290952103593, 7.840265992551149, 6.776084907441948, 5.740023646220333, 4.7446010421737865, 4.241198237272266, 4.9839543191370845, 5.940459859409047, 6.861557694562346, 7.825819744179557, 8.807862988914136, 9.756144081363349, 15.529636928713458, 14.553646681771056, 13.622579955771476, 12.631925014437385, 11.671685407891388, 10.641911007693285, 9.678032379211206, 8.732209284885384, 7.73935054805975, 6.794301256286806, 5.787504213827712, 4.747818664994488, 3.8026499504145193, 3.1920446439493233, 4.042207341230536, 4.973728165607128, 5.846986061626266, 6.863274890602516, 7.925685010127279, 8.810930552125836, 14.529561489005305, 13.604221044072121, 12.653253717512047, 11.707299744998874, 10.694985995952658, 9.710309152102807, 8.729216669173761, 7.770032437956544, 6.797638546576455, 5.817221110533008, 4.820210162816706, 3.841053674573737, 2.8712959044224724, 2.1374345535239136, 3.068416483853409, 3.9333365358208807, 4.87854676973434, 5.935230106377551, 6.92813984359078, 7.834480965315197, 13.577927717835786, 12.60434081723718, 11.665055623024339, 10.737450801005583, 9.754755138501267, 8.770939550437271, 7.804110863853343, 6.834969000500534, 5.819185634532661, 4.795233708695403, 3.8635127601616093, 2.8845217992325005, 1.936247592445038, 1.0718875087286024, 2.000377236161979, 2.9423284925486746, 3.929909340460366, 4.932517637678042, 5.91887139762278, 6.905426386718986, 12.824110604501952, 11.766843283911326, 10.805306002617925, 9.854696866929729, 8.909889057190767, 7.836204757487794, 6.870362183941495, 5.900870934013604, 4.90304587846572, 3.8686293558498486, 2.8896301047242967, 1.9635983778239687, 0.9438157046680259, 0.0, 0.9397851278614376, 1.9393705937917387, 2.9490650643680363, 3.928809763403559, 4.963675800160539, 5.9048462113537745, 13.689932847984505, 12.73656455115182, 11.778367774878987, 10.796250167907646, 9.859643735415784, 8.785349335810464, 7.828034724630671, 6.866131030438182, 5.91630116923586, 4.932735099332535, 3.926470435059767, 2.922139247882104, 1.9912179887543435, 1.0069727388338436, 1.912007282924073, 2.91555669102177, 3.929173554484299, 4.946118703671705, 5.8973110388229095, 6.965081706587796], [6.94903472383421, 5.97027883009038, 4.932417664048358, 3.977421114532058, 2.9280178928555065, 1.9557789252213218, 2.9100618118292534, 3.897867837761373, 4.844718635294023, 5.797127717316529, 6.8401906650884605, 7.8070698181540426, 8.737049503375088, 9.708566033475071, 10.651922254125305, 11.661245249158666, 12.713031582489029, 13.6422357553604, 14.660704127148808, 15.613990201352472, 5.951992847020765, 6.896229586051926, 5.939894274916065, 4.949902303674342, 3.951143192256202, 2.929608068791371, 3.9420415050331608, 4.9269931821482125, 5.773172074271783, 6.733737402050907, 7.666166983092034, 8.598985116905295, 9.6517237957433, 10.698498602476286, 11.699577795066746, 12.667348621831392, 13.731741124452661, 14.69781996492335, 15.710204992033104, 14.720096860567757, 6.904293665751655, 7.850021671578606, 6.994709013978461, 5.964217956388681, 4.909283004850198, 3.9276258787704057, 4.937180064471326, 5.9126085556976795, 6.755080696980337, 7.751543626995749, 8.68591193644663, 9.564392731548395, 10.601516035995317, 11.651100596985406, 12.644217950254475, 13.60674721026657, 14.654161567093908, 15.641762256155609, 16.541630668019206, 15.544482325640297, 7.835485398730154, 8.804568733881265, 8.00463440184566, 6.972543880339641, 5.919175566084007, 4.92600243386927, 5.882893546808946, 6.911927922447716, 7.806606225166015, 8.72945528983578, 9.711380945604885, 10.526539268423688, 11.575355420702794, 12.622023380471353, 13.696210360413213, 14.622253356380558, 15.552938735927162, 16.544426800571774, 17.471798958462358, 16.50425679834883, 8.766921080654262, 9.737174102804051, 8.948690327928476, 7.9200793091798705, 6.880031095835607, 5.965977418252932, 6.8498306551891, 7.779398913973216, 8.790065391314075, 9.74394989987027, 10.640946774681696, 11.47934238270904, 12.506740012954495, 13.537408924859418, 13.933512199364301, 14.915238219798487, 15.873299070112855, 16.55221038840721, 17.522645475705186, 17.487549581995243, 9.751269834525639, 10.740621664906527, 9.797018556003438, 8.84112491569135, 7.81943728690266, 6.955054394641146, 7.802744064282112, 8.778616197034644, 9.745204019803088, 10.681729118502734, 11.639894330962688, 12.511306823864189, 13.455739830752677, 13.955167970344904, 13.006075331396646, 13.905047894723243, 14.840547001971203, 15.616371728389025, 16.559810437208764, 17.58613032036187, 10.70644211546745, 11.728064879529558, 10.728299888752442, 9.753574138153324, 8.764176817479736, 7.899883558359981, 8.759012525218449, 9.72587112608423, 10.689755136390048, 11.608112122937177, 12.640346535470423, 13.569882227622003, 13.664312351381787, 12.972440913029688, 12.012206018145797, 12.950721938159264, 13.856670324413814, 14.69135292350934, 15.643698374139115, 16.597691702140686, 11.69099632948615, 12.628877155903298, 11.646010353856287, 10.683575057826758, 9.71494880967999, 8.963120618461293, 9.761538915045579, 10.737622904232689, 11.695261740150327, 12.593079491116894, 13.599965989313967, 13.62979273061589, 12.684108517901596, 11.976393308341214, 11.086116607973658, 11.982894202093766, 12.893756273320463, 13.748335392667142, 14.692443086747069, 15.648364732404513, 12.669647063387835, 13.554078457422674, 12.5760545320058, 11.668466757349963, 10.749280457252283, 9.895719483208962, 10.772677013727968, 11.742922134783596, 12.729913074921866, 13.53310213729441, 13.4638309533432, 12.616907630470472, 11.72254322381345, 11.019456413328879, 10.060242344982283, 10.963213285971378, 11.91666416831028, 12.781103865009836, 13.737767664708954, 14.637052497769362, 13.738611760908025, 14.603263959986275, 13.589016814406492, 12.623548573103726, 11.766180617132227, 10.943128205347495, 11.744784049165913, 12.747399226726175, 13.71320992930641, 13.513251786974356, 12.530629337178551, 11.592708186475694, 10.719577344161724, 9.947911920157566, 9.066021101545694, 10.006269054604036, 10.861289807022988, 11.814223628254874, 12.80696860308571, 13.6444068539828, 14.64190347503423, 15.615834829645157, 14.661811322396456, 13.59622147931702, 12.701471163017207, 11.944372769036512, 12.80921793389034, 13.7770836869643, 13.531305867909879, 12.539439804395673, 11.507723577007766, 10.585236534425494, 9.703813842061889, 8.96181360943205, 8.044198947045095, 9.029520728737294, 9.912144643903837, 10.820245934152528, 11.810139903943675, 12.717147415255702, 15.589036868398924, 16.554681845617104, 15.589527825553947, 14.644384329826448, 13.669218928229446, 12.87187122144175, 13.805243065866463, 13.532248655655279, 12.566439183358222, 11.582981818185837, 10.561773504553905, 9.596425721693207, 8.706106710179444, 7.9899261277693725, 7.048300626835186, 8.035801381767286, 8.91827484299079, 9.811637901277914, 10.84677643583454, 11.75783419320666, 16.583193095864203, 17.48084204237524, 16.573503023547687, 15.625626779450672, 14.662363711596466, 13.878919741326214, 13.425212443400106, 12.465663848879368, 11.50927232289541, 10.548363041449234, 9.595816954445839, 8.660346824590228, 7.716079687176119, 7.054795382567701, 6.12156280485457, 6.968161906182466, 7.882967426661347, 8.825023928818798, 9.798482926526862, 10.730680601118523, 17.619756108034785, 17.402768391872485, 16.456597802256624, 15.459034977594447, 14.548837653320067, 13.553616774171179, 12.563793777201335, 11.552469774195501, 10.560076126426729, 9.58896606267256, 8.65911504945546, 7.718195959276858, 6.725051160433626, 6.025687299311599, 5.055485203993678, 5.964431135725074, 6.93009368792396, 7.90987770305434, 8.837763266877666, 9.752462662440529, 17.515585185967232, 16.54806110625047, 15.50668186282918, 14.499244331508656, 13.549890335836693, 12.584035211678913, 11.62920196176592, 10.65584411960244, 9.622694648897367, 8.780051120412587, 7.715870035303386, 6.679808774081771, 5.684386170035224, 5.101613111541059, 4.044169191275647, 5.000674731547609, 5.921772566700909, 6.8860346163181205, 7.868077861052699, 8.816358953501911, 16.469422056574896, 15.493431809632494, 14.562365083632914, 13.571710142298823, 12.611470535752826, 11.581696135554722, 10.617817507072644, 9.671994412746821, 8.679135675921188, 7.7340863841482435, 6.72728934168915, 5.687603792855925, 4.742435078275957, 4.061519364956274, 3.1024222133690986, 4.033943037745691, 4.9072009337648295, 5.923489762741078, 6.985899882265842, 7.871145424264398, 15.469346616866742, 14.544006171933558, 13.593038845373485, 12.647084872860312, 11.634771123814096, 10.650094279964245, 9.669001797035198, 8.709817565817982, 7.737423674437893, 6.757006238394445, 5.759995290678145, 4.7808388024351745, 3.8110810322839104, 3.077219681385351, 2.1286313559919714, 2.993551407959443, 3.9387616418729032, 4.9954449785161135, 5.988354715729343, 6.894695837453759, 14.517712845697224, 13.544125945098617, 12.604840750885776, 11.67723592886702, 10.694540266362704, 9.710724678298709, 8.74389599171478, 7.774754128361971, 6.758970762394099, 5.735018836556841, 4.803297888023048, 3.8243069270939385, 2.8760327203064757, 2.01167263659004, 1.0605921083005416, 2.002543364687237, 2.9901242125989285, 3.992732509816604, 4.979086269761343, 5.9656412588575485, 13.76389573236339, 12.706628411772764, 11.745091130479363, 10.794481994791166, 9.849674185052205, 8.775989885349231, 7.8101473118029325, 6.840656061875041, 5.842831006327158, 4.808414483711286, 3.8294152325857342, 2.9033835056854063, 1.8836008325294635, 0.9397851278614376, 0.0, 0.9995854659303011, 2.0092799365065988, 2.9890246355421213, 4.0238906722991015, 4.965061083492337, 14.629717975845942, 13.676349679013258, 12.718152902740425, 11.736035295769083, 10.799428863277221, 9.725134463671901, 8.767819852492108, 7.8059161582996195, 6.856086297097297, 5.872520227193974, 4.866255562921205, 3.861924375743542, 2.9310031166157815, 1.9240208070708584, 0.9722221550626353, 1.9757715631603325, 2.9893884266228614, 4.006333575810268, 4.957525910961472, 6.025296578726358], [5.969818597633534, 4.991062703889705, 3.953201537847682, 2.9982049883313824, 1.9488017666548307, 2.955364391151623, 3.9096472777595546, 4.897453303691674, 5.844304101224324, 6.796713183246831, 7.839776131018761, 8.806655284084343, 9.736634969305388, 10.708151499405371, 11.651507720055605, 12.660830715088967, 13.712617048419329, 14.6418212212907, 15.660289593079108, 16.613575667282774, 4.952407381090465, 5.909701215460478, 4.960678148715389, 3.9706861774736666, 2.9719270660555264, 3.929193534721672, 4.941626970963462, 5.926578648078514, 6.772757540202084, 7.733322867981208, 8.665752449022335, 9.598570582835595, 10.6513092616736, 11.698084068406587, 12.699163260997047, 13.666934087761692, 14.731326590382961, 15.69740543085365, 16.709790457963404, 15.71968232649806, 5.904708199821353, 6.850436205648304, 6.026994073484042, 4.9966502728143, 3.9417153212758174, 4.92337244735561, 5.936765530401626, 6.91219402162798, 7.754666162910638, 8.75112909292605, 9.685497402376932, 10.563978197478695, 11.601101501925617, 12.650686062915707, 13.643803416184776, 14.606332676196871, 15.653747033024208, 16.64134772208591, 17.541216133949508, 16.544067791570598, 6.835899932799852, 7.804983267950964, 7.036919461351242, 6.0112690960212545, 5.003288475558827, 5.921749002454474, 6.87864011539415, 7.90767449103292, 8.806191691096316, 9.72904075576608, 10.710966411535187, 11.526124734353989, 12.574940886633094, 13.621608846401653, 14.695795826343513, 15.005500865494534, 15.871059844972022, 16.682266739680156, 17.591681577917754, 17.503842264279136, 7.767335614723959, 8.737588636873749, 7.987415543610089, 6.958804524861484, 5.964144005310427, 6.961723986838137, 7.845577223774304, 8.77514548255842, 9.785811959899279, 10.743535365800568, 11.640532240611998, 12.47892784863934, 13.506325478884794, 14.536994390789717, 14.799796302391066, 14.04886716540796, 14.933564121216518, 15.60810371366633, 16.578538800964306, 17.50928312041817, 8.751684368595335, 9.741036198976225, 8.881131465478258, 7.925237825166169, 6.90355019637748, 7.928437229477298, 8.798490632867317, 9.774362765619848, 10.740950588388293, 11.681314584433032, 12.63947979689299, 13.510892289794489, 14.455325296682975, 14.821452073371669, 13.87235943442341, 12.97569717131491, 13.900812053074866, 14.672265053648143, 15.615703762467884, 16.64202364562099, 9.706856649537146, 10.746490857454932, 9.812412798227262, 8.837687047628144, 7.848289726954557, 8.853507544353171, 9.754759093803655, 10.721617694669437, 11.685501704975252, 12.607697588867476, 13.639932001400721, 14.569467693552303, 14.663897817312085, 13.838725016056452, 12.878490121172561, 12.02137121475093, 12.916935375517477, 13.747246248768459, 14.699591699398233, 15.653585027399805, 10.691410863555847, 11.70312884322204, 10.730123263331109, 9.76768796730158, 8.799061719154812, 9.782360949176432, 10.718451553112423, 11.694535542299533, 12.691008308735531, 13.592664957047193, 14.599551455244265, 14.629378196546192, 13.683693983831894, 12.842677411367978, 11.952400711000422, 11.053543478685432, 11.954021324424126, 12.80422871792626, 13.748336412006188, 14.648779266474214, 11.670061597457531, 12.638191366897496, 11.660167441480622, 10.752579666824785, 9.833393366727105, 10.714959813924102, 11.729589651794813, 12.69983477285044, 13.68682571298871, 14.532687603224709, 14.4634164192735, 13.616493096400772, 12.72212868974375, 11.885740516355643, 10.926526448009048, 10.033862562563044, 10.976929219413943, 11.836997190268955, 12.793660989968073, 13.637467031839064, 12.739026294977721, 13.687376869461097, 12.673129723881313, 11.707661482578548, 10.850293526607048, 11.762368536062635, 12.701696687232758, 13.70431186479302, 14.670122567373255, 14.512837252904657, 13.530214803108851, 12.592293652405994, 11.719162810092024, 10.81419602318433, 9.932305204572458, 9.076918331195703, 9.917183132282107, 10.870116953513993, 11.862861928344829, 12.6448213880525, 13.642318009103931, 14.67882832854156, 13.745924231871278, 12.680334388791842, 11.785584072492028, 12.719720021669964, 13.690604062998293, 14.658469816072254, 14.530891333840179, 13.539025270325974, 12.507309042938067, 11.584822000355794, 10.70339930799219, 9.828097712458815, 8.910483050071859, 8.100170005328959, 8.968037969162955, 9.876139259411646, 10.866033229202793, 11.717561949325404, 14.589451402468626, 15.555096379686807, 14.67364073502877, 13.72849723930127, 12.753331837704268, 13.647218474075203, 14.686629194974417, 14.531834121585579, 13.566024649288522, 12.582567284116138, 11.561358970484205, 10.596011187623507, 9.705692176109745, 8.856210230796137, 7.914584729861951, 7.106450658358949, 7.974168168249909, 8.867531226537032, 9.847190969904242, 10.758248727276362, 15.583607629933905, 16.481256576444945, 15.657615933022507, 14.709739688925493, 13.746476621071288, 14.654266993959666, 14.424797909330406, 13.465249314809668, 12.50885778882571, 11.547948507379534, 10.59540242037614, 9.659932290520528, 8.71566515310642, 7.978958269534846, 6.987846907881335, 6.03881118277413, 6.938860751920465, 7.880917254077915, 8.798897460596564, 9.731095135188225, 16.635809624964264, 17.537915933788305, 16.610186661962807, 15.685166206408331, 14.769581149526635, 14.55320224010148, 13.563379243131637, 12.552055240125803, 11.559661592357031, 10.588551528602862, 9.658700515385762, 8.717781425207159, 7.724636626363927, 6.949850186278744, 5.979648090960823, 5.035080412316738, 5.9859870131830775, 6.910292237124038, 7.838177800947365, 8.752877196510227, 17.589635512181868, 17.54764657218077, 16.50626732875948, 15.498829797438958, 14.549475801766995, 13.583620677609213, 12.62878742769622, 11.65542958553274, 10.622280114827667, 9.779636586342889, 8.715455501233688, 7.679394240012072, 6.683971635965525, 6.03234521420806, 4.974901293942648, 4.071324008139273, 4.922187100770608, 5.886449150387819, 6.868492395122399, 7.81677348757161, 17.469007522505198, 16.493017275562796, 15.561950549563216, 14.571295608229125, 13.611056001683128, 12.581281601485024, 11.617402973002944, 10.671579878677122, 9.678721141851488, 8.733671850078544, 7.726874807619451, 6.687189258786226, 5.742020544206258, 4.992251467623275, 4.033154316036099, 3.0343575718153906, 3.9076154678345283, 4.923904296810778, 5.98631441633554, 6.871559958334096, 16.468932082797046, 15.54359163786386, 14.592624311303787, 13.646670338790614, 12.634356589744398, 11.649679745894547, 10.668587262965499, 9.709403031748282, 8.737009140368194, 7.756591704324746, 6.759580756608445, 5.780424268365476, 4.8106664982142116, 4.031966461836904, 3.059363458658972, 1.9939659420291425, 2.9391761759426025, 3.995859512585813, 4.9887692497990415, 5.895110371523457, 15.517298311627526, 14.54371141102892, 13.604426216816078, 12.676821394797322, 11.694125732293006, 10.71031014422901, 9.743481457645082, 8.774339594292274, 7.7585562283244, 6.734604302487142, 5.802883353953348, 4.82389239302424, 3.875618186236777, 3.0112581025203413, 2.037008725426954, 1.002957898756936, 1.9905387466686277, 2.993147043886303, 3.9795008038310415, 4.966055792927246, 14.763481198293691, 13.706213877703066, 12.744676596409665, 11.794067460721468, 10.849259650982507, 9.775575351279532, 8.809732777733233, 7.8402415278053414, 6.842416472257458, 5.807999949641587, 4.829000698516036, 3.9029689716157074, 2.8831862984597647, 1.9393705937917387, 0.9995854659303011, 0.0, 1.0096944705762978, 1.98943916961182, 3.0243052063688007, 3.9654756175620363, 15.629303441776244, 14.67593514494356, 13.717738368670727, 12.735620761699385, 11.799014329207523, 10.724719929602202, 9.767405318422409, 8.805501624229919, 7.855671763027598, 6.872105693124274, 5.865841028851506, 4.861509841673843, 3.9305885825460827, 2.9236062730011594, 1.9718076209929363, 0.9965554369596568, 2.0101723004221856, 3.027117449609592, 3.9783097847607967, 5.027122480783724], [4.973651897088116, 3.994896003344287, 2.9639999954602407, 2.009003445943941, 2.9584962372311283, 3.9650588617279205, 4.919341748335852, 5.907147774267972, 6.853998571800622, 7.806407653823128, 8.849470601595058, 9.81634975466064, 10.746329439881686, 11.717845969981669, 12.661202190631903, 13.670525185665264, 14.722311518995626, 15.651515691866997, 16.669984063655406, 17.62327013785907, 3.9427129105141674, 4.90000674488418, 3.9714766063279474, 2.9814846350862254, 3.981621536631824, 4.93888800529797, 5.9513214415397595, 6.936273118654811, 7.782452010778382, 8.743017338557506, 9.675446919598633, 10.608265053411893, 11.661003732249897, 12.707778538982884, 13.708857731573344, 14.67662855833799, 15.741021060959259, 16.70709990142995, 17.7194849285397, 16.729376797074355, 4.895013729245055, 5.840741735072006, 5.037792531096601, 4.009306291768516, 4.9514097918521145, 5.933066917931907, 6.946460000977924, 7.921888492204277, 8.764360633486936, 9.760823563502349, 10.695191872953231, 11.573672668054993, 12.610795972501915, 13.660380533492004, 14.653497886761073, 15.616027146773169, 15.808415083148585, 16.72020541545401, 17.557257902440334, 17.5537622621469, 5.826205462223555, 6.795288797374667, 6.047717918963801, 5.02392511497547, 6.012982946135125, 6.931443473030771, 7.888334585970447, 8.917368961609217, 9.815886161672614, 10.73873522634238, 11.720660882111487, 12.535819204930286, 13.584635357209391, 14.63130331697795, 15.70549029691981, 15.801829367818819, 14.871143988272214, 15.682350882980352, 16.59176572121795, 17.49266004736478, 6.757641144147662, 7.727894166297451, 7.000071562564305, 5.9714605438157, 6.9738384758867245, 7.971418457414433, 8.8552716943506, 9.784839953134716, 10.795506430475575, 11.753229836376867, 12.650226711188298, 13.488622319215638, 14.516019949461093, 15.546688861366016, 15.657948888076326, 14.848583336855421, 13.93364826451671, 14.608187856966524, 15.578622944264502, 16.509367263718367, 7.741989898019039, 8.731341728399928, 7.928614122738119, 6.97272048242603, 7.913244666953777, 8.938131700053596, 9.808185103443613, 10.784057236196144, 11.750645058964588, 12.691009055009332, 13.64917426746929, 14.520586760370787, 15.465019767259275, 15.679604659056931, 14.730512020108673, 13.77541334276237, 12.900896196375058, 13.672349196948337, 14.615787905768078, 15.642107788921184, 8.69716217896085, 9.736796386878636, 8.92381386910835, 7.961725635742354, 8.857984197530854, 9.863202014929467, 10.76445356437995, 11.731312165245733, 12.695196175551548, 13.617392059443775, 14.64962647197702, 15.5791621641286, 15.59320609251934, 14.696877601741715, 13.736642706857824, 12.821087386198391, 11.917019518817671, 12.747330392068653, 13.699675842698428, 14.653669170699999, 9.681716392979551, 10.693434372645743, 9.874188412328401, 9.0083636233167, 9.808756189731108, 10.792055419752728, 11.72814602368872, 12.70423001287583, 13.700702779311827, 14.602359427623492, 15.609245925820565, 15.583609911272474, 14.613002259039149, 13.70082999705324, 12.810553296685685, 11.853259650132893, 10.95410546772432, 11.804312861226455, 12.748420555306382, 13.648863409774409, 10.660367126881235, 11.664113642636769, 10.804232590477914, 9.993255322839905, 10.8430878373034, 11.724654284500398, 12.739284122371108, 13.709529243426736, 14.696520183565006, 15.542382073801008, 15.473110889849798, 14.585456587348427, 13.651436964951003, 12.743893102040905, 11.78467903369431, 10.833578734010505, 9.977013362714137, 10.837081333569149, 11.793745133268267, 12.637551175139258, 11.729331824401426, 12.678515068451972, 11.817194872878606, 10.948337138593669, 11.859987997183344, 12.77206300663893, 13.711391157809054, 14.714006335369316, 15.679817037949551, 15.522531723480954, 14.539909273685149, 13.601988122982291, 12.648471085299278, 11.672348608869592, 10.79045779025772, 9.876634502643164, 8.9172672755823, 9.870201096814187, 10.862946071645025, 11.644905531352695, 12.642402152404125, 13.678912471841754, 12.88998938086857, 11.921010044806962, 12.795278543068324, 13.72941449224626, 14.700298533574589, 15.66816428664855, 15.540585804416477, 14.548719740902271, 13.517003513514364, 12.594516470932092, 11.652014591128065, 10.686250298144078, 9.768635635757121, 8.899886176776421, 7.96812211246315, 8.876223402711842, 9.86611737250299, 10.717646092625598, 13.58953554576882, 14.555180522987001, 13.817705884026061, 12.96917289531639, 13.763026308280564, 14.656912944651499, 15.696323665550713, 15.541528592161876, 14.57571911986482, 13.592261754692435, 12.571053441060503, 11.605705658199804, 10.715386646686042, 9.7143628164814, 8.772737315547213, 7.906166829806413, 6.974252311550105, 7.867615369837227, 8.847275113204438, 9.758332870576556, 14.583691773234099, 15.48134071974514, 14.80513345588771, 13.950415344940614, 14.756171091647584, 15.663961464535962, 15.434492379906704, 14.474943785385966, 13.518552259402007, 12.557642977955831, 11.605096890952437, 10.669626761096826, 9.725359623682717, 8.838264168409044, 7.845999493566596, 6.896963768459392, 5.9389448952206605, 6.881001397378111, 7.798981603896759, 8.731179278488419, 15.63589376826446, 16.5380000770885, 15.75770418482801, 14.925841862423452, 15.779275620102931, 15.562896710677776, 14.573073713707933, 13.561749710702099, 12.569356062933327, 11.598245999179158, 10.668394985962058, 9.727475895783456, 8.734331096940224, 7.809156085152941, 6.83895398983502, 5.894386311190935, 4.986071156483273, 5.910376380424234, 6.838261944247561, 7.743182725933931, 16.589719655482064, 17.592892078187525, 16.769805477160986, 15.885632508509243, 15.559170272343291, 14.59331514818551, 13.638481898272518, 12.665124056109038, 11.631974585403965, 10.789331056919185, 9.725149971809984, 8.689088710588369, 7.693666106541822, 6.922849825335175, 5.865405905069763, 4.93062990701347, 3.922271244070804, 4.886533293688015, 5.8685765384225945, 6.8070790169953135, 17.53455082955255, 17.5027117461391, 16.571645020139517, 15.580990078805424, 14.620750472259427, 13.590976072061324, 12.627097443579242, 11.68127434925342, 10.688415612427786, 9.743366320654841, 8.736569278195747, 7.696883729362523, 6.751715014782555, 5.88275607875039, 4.923658927163214, 3.9248621829425057, 2.907699611134724, 3.9239884401109735, 4.976619945759243, 5.861865487757799, 17.478626553373346, 16.55328610844016, 15.602318781880086, 14.656364809366913, 13.644051060320697, 12.659374216470846, 11.678281733541796, 10.71909750232458, 9.746703610944492, 8.766286174901044, 7.7692752271847425, 6.790118738941772, 5.820360968790508, 4.9224710729640195, 3.9498680697860875, 2.884470553156258, 1.9392603192427982, 2.9959436558860086, 3.979074779222744, 4.8854159009471605, 16.526992782203827, 15.553405881605219, 14.614120687392377, 13.686515865373622, 12.703820202869306, 11.72000461480531, 10.753175928221381, 9.784034064868571, 8.768250698900697, 7.74429877306344, 6.8125778245296456, 5.833586863600536, 4.885312656813074, 4.020952573096639, 3.046703196003252, 2.012652369333234, 0.9808442760923298, 1.983452573310005, 2.969806333254744, 3.9563613223509493, 15.773175668869987, 14.715908348279362, 13.75437106698596, 12.803761931297764, 11.858954121558803, 10.78526982185583, 9.81942724830953, 8.849935998381639, 7.852110942833756, 6.817694420217885, 5.838695169092333, 4.912663442192005, 3.8928807690360623, 2.9490650643680363, 2.0092799365065988, 1.0096944705762978, 0.0, 0.9797446990355224, 2.014610735792503, 2.9557811469857387, 16.63899791235254, 15.685629615519856, 14.727432839247022, 13.745315232275681, 12.808708799783819, 11.7344144001785, 10.777099788998706, 9.815196094806216, 8.865366233603895, 7.8818001637005715, 6.875535499427803, 5.871204312250141, 4.94028305312238, 3.933300743577457, 2.981502091569234, 2.0062499075359543, 1.0209707580347442, 2.030950749064174, 2.982143084215379, 4.017428010207427], [3.9939071980525935, 3.0151513043087643, 1.990608109461226, 2.9456046589775258, 3.938240936266651, 4.944803560763443, 5.899086447371375, 6.886892473303494, 7.833743270836144, 8.78615235285865, 9.829215300630581, 10.796094453696163, 11.726074138917209, 12.697590669017192, 13.640946889667426, 14.650269884700787, 15.70205621803115, 16.631260390902522, 17.64972876269093, 18.603014836894594, 2.9629682114786444, 3.9202620458486575, 3.030773762142002, 3.91808584811981, 4.951424192510392, 5.918632704333492, 6.931066140575282, 7.916017817690333, 8.762196709813903, 9.722762037593027, 10.655191618634154, 11.588009752447414, 12.640748431285418, 13.687523238018406, 14.688602430608867, 15.656373257373513, 16.720765759994784, 16.997355046484017, 17.805557713250067, 17.709121496109884, 3.915269030209533, 4.860997036036484, 4.097089686910655, 4.945907504802101, 5.9212124477306824, 6.902869573810475, 7.926204700013447, 8.9016331912398, 9.744105332522457, 10.74056826253787, 11.674936571988752, 12.553417367090514, 13.590540671537436, 14.640125232527526, 15.633242585796594, 16.59577184580869, 16.63945251871602, 15.92983721831619, 16.766889705302507, 17.742892622948073, 4.846460763188032, 5.815544098339144, 5.107015074777855, 5.960526328009055, 6.982785602013693, 7.901246128909339, 8.858137241849015, 9.887171617487786, 10.795630860708135, 11.7184799253779, 12.700405581147008, 13.515563903965807, 14.564380056244913, 15.611048016013472, 16.68523499595533, 16.632866803386253, 15.702181423839649, 14.891982685842528, 15.801397524080125, 16.702291850226956, 5.777896445112139, 6.748149467261928, 6.138704385906788, 6.908061756849285, 7.943641131765292, 8.941221113293, 9.825074350229169, 10.754642609013285, 11.765309086354144, 12.732974535412389, 13.629971410223819, 14.46836701825116, 15.495764648496614, 16.526433560401536, 16.637693587111848, 15.81823692893281, 14.764685700084145, 13.8178196598287, 14.788254747126679, 15.718999066580544, 6.762245198983516, 7.7515970293644045, 7.078452677686875, 7.909321695459615, 8.883047322832345, 9.907934355932163, 10.777987759322182, 11.753859892074713, 12.720447714843157, 13.66317466374558, 14.625581578370154, 15.500331459406308, 16.444764466294796, 16.659349358092452, 15.710256719144194, 14.755158041797891, 13.880640895410583, 12.881980999810514, 13.825419708630255, 14.735464698261923, 7.717417479925327, 8.757051687843113, 8.073652424057105, 8.89832684877594, 9.827786853409423, 10.833004670808036, 11.73425622025852, 12.701114821124301, 13.664998831430117, 14.589557668180024, 15.62179208071327, 16.554958843829894, 16.57295079155486, 15.676622300777236, 14.716387405893345, 13.800832085233912, 12.896764217853194, 11.95696219493083, 12.909307645560604, 13.747026080040738, 8.701971693944028, 9.71368967361022, 9.024026967277155, 9.944964836350286, 10.778558845609677, 11.761858075631297, 12.697948679567288, 13.674032668754398, 14.670505435190396, 15.574525036359741, 16.581411534556814, 16.563354610307996, 15.59274695807467, 14.680574696088762, 13.790297995721206, 12.833004349168414, 11.933850166759843, 11.013944664088632, 11.958052358168558, 12.728956195352135, 9.680622427845712, 10.684368943601246, 9.954071145426669, 10.924721548221395, 11.81289049318197, 12.694456940378966, 13.709086778249677, 14.679331899305305, 15.666322839443575, 16.51454768253726, 16.45285558888532, 15.565201286383948, 14.631181663986524, 13.723637801076427, 12.764423732729831, 11.813323433046026, 10.95675806174966, 10.046713136431325, 11.003376936130444, 11.717643960716984, 10.749587125365903, 11.698770369416449, 10.96703342782736, 11.879803363975158, 12.829790653061913, 13.7418656625175, 14.681193813687623, 15.683808991247885, 16.64961969382812, 16.502276422516474, 15.51965397272067, 14.581732822017813, 13.628215784334799, 12.652093307905114, 11.770202489293242, 10.856379201678685, 9.897011974617824, 9.079832899676363, 10.018097600705508, 10.72499831693042, 11.693724123725952, 12.711341239075331, 12.039827935817325, 12.852476270188452, 13.765081198946893, 14.699217148124829, 15.670101189453158, 16.637966942527118, 16.520330503451998, 15.528464439937792, 14.496748212549885, 13.574261169967613, 12.631759290163586, 11.665994997179599, 10.748380334792643, 9.879630875811943, 8.947866811498672, 8.068906108516627, 9.021268901563472, 9.797738878203324, 12.64977489290658, 13.61541987012476, 12.967544438974816, 13.900639120697882, 14.732828964159133, 15.626715600530067, 16.66612632142928, 16.5212732911974, 15.555463818900341, 14.572006453727957, 13.550798140096024, 12.585450357235326, 11.695131345721563, 10.69410751551692, 9.752482014582734, 8.885911528841934, 7.953997010585627, 7.060298075642012, 7.9469168779665935, 8.838425656154282, 13.643931120371859, 14.541580066882899, 13.954972010836464, 14.881881570322106, 15.725973747526153, 16.63376412041453, 16.414237078942225, 15.454688484421487, 14.498296958437528, 13.537387676991353, 12.584841589987958, 11.649371460132347, 10.705104322718238, 9.818008867444565, 8.825744192602118, 7.876708467494914, 6.918689594256183, 6.073684103182896, 6.898623368658916, 7.811272064066144, 14.696133115402219, 15.598239424226259, 14.907542739776764, 15.857308087804943, 16.7490782759815, 16.542641409713298, 15.552818412743454, 14.54149440973762, 13.549100761968848, 12.577990698214679, 11.64813968499758, 10.707220594818978, 9.714075795975745, 8.788900784188463, 7.818698688870542, 6.874131010226457, 5.9658158555187955, 5.088463430780898, 5.937903709009718, 6.763438026898408, 15.649959002619823, 16.65313142532528, 15.91964403210974, 16.817098733890735, 16.538914971378812, 15.573059847221032, 14.61822659730804, 13.644868755144559, 12.611719284439486, 11.769075755954706, 10.704894670845505, 9.66883340962389, 8.673410805577344, 7.902594524370697, 6.845150604105285, 5.910374606048992, 4.902015943106326, 4.064620344044679, 4.968218303184751, 5.8273343179597905, 16.69612213201216, 17.672112378954562, 16.863960811306008, 16.560734777840945, 15.600495171294948, 14.570720771096845, 13.606842142614763, 12.66101904828894, 11.668160311463307, 10.723111019690363, 9.71631397723127, 8.676628428398045, 7.731459713818077, 6.862500777785912, 5.903403626198736, 4.904606881978029, 3.8874443101702463, 2.9942134813567387, 3.9968752467237203, 4.882120788722276, 17.737202031709046, 17.533030807475683, 16.582063480915608, 15.636109508402434, 14.623795759356218, 13.639118915506367, 12.658026432577318, 11.698842201360101, 10.726448309980013, 9.746030873936565, 8.749019926220264, 7.769863437977294, 6.80010566782603, 5.902215771999542, 4.92961276882161, 3.8642152521917805, 2.9190050182783205, 2.066168697131774, 2.9993300801872214, 3.905671201911638, 17.506737481239348, 16.53315058064074, 15.593865386427899, 14.666260564409143, 13.683564901904827, 12.699749313840831, 11.732920627256902, 10.763778763904092, 9.747995397936219, 8.72404347209896, 7.792322523565167, 6.813331562636058, 5.865057355848596, 5.000697272132161, 4.026447895038775, 2.9923970683687564, 1.9605889751278522, 1.0037078742744827, 1.9900616342192214, 2.9766166233154268, 16.752920367905514, 15.695653047314886, 14.734115766021485, 13.783506630333289, 12.838698820594328, 11.765014520891352, 10.799171947345053, 9.829680697417162, 8.831855641869279, 7.797439119253407, 6.8184398681278555, 5.892408141227527, 4.872625468071584, 3.928809763403559, 2.9890246355421213, 1.98943916961182, 0.9797446990355224, 0.0, 1.0348660367569806, 1.9760364479502162, 17.618742611388065, 16.665374314555383, 15.707177538282547, 14.725059931311206, 13.788453498819344, 12.714159099214022, 11.756844488034229, 10.79494079384174, 9.845110932639418, 8.861544862736094, 7.855280198463326, 6.850949011285663, 5.920027752157902, 4.9130454426129795, 3.961246790604757, 2.985994606571477, 2.0007154570702665, 1.0512060500286515, 2.0023983851798564, 3.0376833111719037], [2.9781921547552477, 2.0305030148671825, 2.9083444903220537, 3.863341039838353, 4.932921845106872, 5.979669597520424, 6.933952484128356, 7.921758510060475, 8.868609307593125, 9.821018389615631, 10.864081337387562, 11.830960490453144, 12.76094017567419, 13.732456705774172, 14.675812926424406, 15.685135921457768, 16.73692225478813, 17.666126427659503, 18.030609183992613, 18.729413066166586, 1.9281021747216638, 2.885396009091677, 3.841731320227538, 4.8317232914692605, 5.865061635859842, 6.937899875688736, 7.9503333119305255, 8.950883854447316, 9.797062746570885, 10.75762807435001, 11.690057655391136, 12.622875789204397, 13.6756144680424, 14.722389274775388, 15.723468467365848, 16.691239294130494, 17.755631796751764, 17.78698566596272, 16.98110831910832, 17.6701711898668, 2.8804029934525524, 3.8261309992795036, 4.829777176155574, 5.859544948151552, 6.8348498910801325, 7.816507017159925, 8.839958675757392, 9.815387166983745, 10.77897136927944, 11.77543429929485, 12.709802608745733, 13.588283403847496, 14.625406708294419, 15.674991269284508, 16.668108622553575, 17.630637882565672, 17.42908313819472, 16.71946783779489, 15.942440311160759, 16.721934775549872, 3.811594726431052, 4.780678061582163, 5.824983498387071, 6.874163771358506, 7.896423045363143, 8.81488357225879, 9.771774685198466, 10.800809060837237, 11.830496897465117, 12.753345962134881, 13.735271617903988, 14.55042994072279, 15.599246093001895, 16.645914052770454, 17.720101032712314, 17.422497422864957, 16.49181204331835, 15.68161330532123, 14.976948129938375, 15.681334002828756, 4.7430304083551595, 5.713283430504949, 6.64897869477868, 7.6775897135272855, 8.736743226981421, 9.792957363864838, 10.73871179357862, 11.668280052362736, 12.678946529703595, 13.731895915256736, 14.6648374469808, 15.503233055008142, 16.530630685253595, 17.561299597158516, 17.51464200093793, 16.607867548411512, 15.554316319562847, 14.607450279307402, 13.963805352984929, 14.698041219182343, 5.727379162226536, 6.716730992607424, 7.588726986558767, 8.544620626870856, 9.566308255659546, 10.591195288759364, 11.638728023598407, 12.614600156350939, 13.581187979119383, 14.523914928021807, 15.48632184264638, 16.421219876291026, 17.479630503051776, 17.536297771918534, 16.587205132970276, 15.623994928080911, 14.672036387820937, 13.671611619289216, 13.000970314488505, 13.700598661504943, 6.682551443168348, 7.722185651086135, 8.583926732928997, 9.53362578018718, 10.511047786236624, 11.516265603635237, 12.441353555139935, 13.408212156005717, 14.40325040608618, 15.45029793245625, 16.482532344989494, 17.415699108106118, 17.459632422117725, 16.553570714603318, 15.593335819719428, 14.669668971516932, 13.745645565224715, 12.746592814409532, 12.011978887692402, 12.712160043283758, 7.667105657187049, 8.678823636853242, 9.534301276149048, 10.496736572178577, 11.461819778436878, 12.445119008458498, 13.381209612394489, 14.357293601581599, 15.371055972441175, 16.312200931880998, 17.31908743007807, 17.450036240870862, 16.479428588637536, 15.567256326651629, 14.667246409547289, 13.701841235451434, 12.782731514131363, 11.803575283567334, 11.004438347651105, 11.694090158595154, 8.645756391088733, 9.649502906844267, 10.464345454298561, 11.434995857093288, 12.472780045015346, 13.377717873206167, 14.392347711076878, 15.362592832132506, 16.349583772270776, 17.252223578058516, 17.387373768985324, 16.451882916946815, 15.517863294549391, 14.610319431639294, 13.641372146555915, 12.682160319329046, 11.80563940912118, 10.836343755910027, 10.04574698015466, 10.682777923960003, 9.714721088608924, 10.66390433265947, 11.477307736699252, 12.39007767284705, 13.43876076980058, 14.424175202316967, 15.364454746514824, 16.367069924075086, 17.33288062665532, 17.457637344117344, 16.47501489432154, 15.511104734452404, 14.514897414897666, 13.53877493846798, 12.656884119856109, 11.725216087961705, 10.757051719953813, 9.869463519155065, 8.983231563948527, 9.69013228017344, 10.658858086968973, 11.676475202318352, 12.550102244689217, 13.362750579060345, 14.374051315685561, 15.308187264863497, 16.279071306191824, 17.246937059265782, 17.55519654020898, 16.50635191557655, 15.452109134150753, 14.503633082402205, 13.518440920726453, 12.552676627742466, 11.63506196535551, 10.748467762094963, 9.807906556834661, 8.858536727995329, 7.986402864806491, 8.762872841446343, 11.6149088561496, 12.580553833367782, 13.477818747846708, 14.410913429569774, 15.3417990808978, 16.235685717268737, 17.275096438167946, 17.55613932795438, 16.590329855657323, 15.606872490484937, 14.585664176853005, 13.620316393992306, 12.653765863437652, 11.580789146079788, 10.6391636451456, 9.754748415124954, 8.822833896868646, 7.849928695120714, 6.912050841209613, 7.803559619397301, 12.60906508361488, 13.50671403012592, 14.465246319708356, 15.392155879193998, 16.334943864264822, 17.2427342371532, 17.449103115699206, 16.489554521178466, 15.533162995194509, 14.572253713748333, 13.619707626744939, 12.684237496889327, 11.739970359475219, 10.738165827768734, 9.712425823164985, 8.76339009805778, 7.805371224819049, 6.863314722661598, 5.863757331901935, 6.7764060273091635, 13.66126707864524, 14.56337338746928, 15.417817048648656, 16.367582396676838, 17.35804839272017, 17.57750744647028, 16.587684449500436, 15.576360446494604, 14.583966798725832, 13.61285673497166, 12.68300572175456, 11.742086631575958, 10.748941832732726, 9.766542401861699, 8.796340306543778, 7.851772627899693, 6.941964449543432, 5.926712090420772, 4.903037672252737, 5.728571990141427, 14.615092965862845, 15.618265388568302, 16.429918340981633, 17.32737304276263, 17.573781008135793, 16.607925883978012, 15.653092634065022, 14.679734791901542, 13.646585321196468, 12.803941792711687, 11.739760707602485, 10.70369944638087, 9.708276842334325, 8.9019656842596, 7.84452176399419, 6.888016223722228, 5.879657560779561, 4.91539551116235, 3.9333522664277707, 4.79246828120281, 15.661256095255183, 16.637246342197585, 17.3742351201779, 17.595600814597926, 16.63536120805193, 15.605586807853825, 14.641708179371745, 13.695885085045923, 12.70302634822029, 11.757977056447345, 10.751180013988252, 9.711494465155027, 8.766325750575058, 7.897366814542893, 6.938269662955717, 5.939472918735008, 4.920989039533756, 3.893696312196578, 2.9620092099667397, 3.8472547519652958, 16.705067335179823, 17.586671979896522, 17.616929517672588, 16.670975545159415, 15.658661796113199, 14.673984952263348, 13.6928924693343, 12.733708238117083, 11.761314346736995, 10.780896910693547, 9.783885962977246, 8.804729474734277, 7.834971704583012, 6.937081808756522, 5.96447880557859, 4.899081288948761, 3.953871055035301, 2.9656515279716134, 1.9644640434302407, 2.8708051651546573, 17.65670110634934, 17.56801661739772, 16.62873142318488, 15.701126601166123, 14.718430938661808, 13.734615350597812, 12.767786664013883, 11.798644800661075, 10.782861434693201, 9.758909508855943, 8.82718856032215, 7.84819759939304, 6.899923392605578, 6.0355633088891425, 5.061313931795755, 4.027263105125737, 2.995455011884833, 2.0161543255472845, 0.9551955974622409, 1.9417505865584461, 17.78778640466249, 16.730519084071865, 15.768981802778466, 14.81837266709027, 13.873564857351308, 12.799880557648333, 11.834037984102034, 10.864546734174143, 9.86672167862626, 8.832305156010388, 7.853305904884837, 6.927274177984509, 5.907491504828566, 4.96367580016054, 4.023890672299102, 3.024305206368801, 2.014610735792503, 1.0348660367569806, 0.0, 0.9411704111932354, 18.653608648145042, 17.70024035131236, 16.742043575039528, 15.759925968068186, 14.823319535576324, 13.749025135971003, 12.79171052479121, 11.82980683059872, 10.879976969396399, 9.896410899493075, 8.890146235220307, 7.8858150480426445, 6.954893788914884, 5.94791147936996, 4.9961128273617375, 3.999504443539414, 2.985887580076885, 1.9689424308894792, 1.0177500957382744, 2.002817274414923], [2.0370217435620126, 2.8870959315767504, 3.849514901515289, 4.804511451031589, 5.8740922563001075, 6.920840008713659, 7.875122895321591, 8.86292892125371, 9.809779718786361, 10.762188800808866, 11.805251748580798, 12.77213090164638, 13.702110586867425, 14.673627116967408, 15.616983337617642, 16.626306332651, 17.678092665981364, 18.607296838852736, 18.807566218324997, 17.85219561690604, 0.9869317635284285, 1.9442255978984413, 2.9005609090343025, 3.8905528802760245, 4.9238912246666064, 5.9967294644955, 7.00916290073729, 8.043670546502765, 8.98897176884699, 9.949537096626115, 10.881966677667242, 11.814784811480502, 12.867523490318506, 13.914298297051493, 14.960827203514693, 15.973425478930896, 17.037817981552166, 18.003896822022856, 17.758065353440703, 16.792953740606254, 1.9927135507450744, 2.9384415565720254, 3.942087733448095, 4.918374536958315, 5.893679479886897, 6.875336605966689, 7.898788264564156, 8.87421675579051, 9.858443838858204, 10.856369329634731, 11.790737639085613, 12.780192426123602, 13.817315730570524, 14.866900291560613, 15.860017644829682, 16.874296387358566, 17.9217107441859, 17.657009425189983, 16.719397345493142, 15.844717326289327, 2.9343772771705092, 3.9034606123216204, 4.947766049126528, 5.93299336016527, 6.9552526341699075, 7.873713161065553, 8.83060427400523, 9.859638649644001, 10.89793133623939, 11.834280992474762, 12.816206648243869, 13.742338962998895, 14.791155115278, 15.83782307504656, 16.912010054988418, 17.83805305095576, 17.42935363071344, 16.61915489271632, 15.753905164270758, 14.804116553568212, 3.865812959094616, 4.836065981244405, 5.771761245518137, 6.800372264266742, 7.859525777720877, 8.913688145449216, 9.797541382385385, 10.7271096411695, 11.737776118510359, 12.7907255040635, 13.74577247732068, 14.695142077284247, 15.722539707529702, 16.753208619434623, 17.719272162385565, 17.5454091358066, 16.491857906957936, 15.544991866702492, 14.740762387317313, 13.8208237699218, 4.850161712965993, 5.8395135433468806, 6.711509537298224, 7.667403177610313, 8.689090806399003, 9.71397783949882, 10.750454791478397, 11.726326924230928, 12.692914746999373, 13.635641695901796, 14.59804861052637, 15.532946644171016, 16.60152720397093, 17.614106807798063, 17.528375544163513, 16.56516533927415, 15.609577975216027, 14.609153206684306, 13.777927348820889, 12.8233812122444, 5.805333993907805, 6.8449682018255915, 7.706709283668455, 8.656408330926638, 9.63383033697608, 10.639048154374693, 11.564136105879392, 12.530994706745174, 13.526032956825638, 14.56202470033624, 15.594259112869485, 16.527425875986108, 17.54813374801203, 17.494741125796555, 16.534506230912665, 15.61083938271017, 14.683187152619807, 13.684134401804622, 12.788935922024786, 11.834942594023214, 6.789888207926506, 7.801606187592698, 8.657083826888504, 9.619519122918033, 10.584602329176334, 11.567901559197955, 12.503992163133946, 13.480076152321056, 14.493838523180631, 15.434983482620453, 16.441869980817525, 17.418643659148508, 17.420598999830773, 16.508426737844864, 15.608416820740526, 14.643011646644672, 13.720273101526455, 12.741116870962424, 11.798070305939438, 10.81687270933461, 7.76853894182819, 8.772285457583724, 9.587128005038018, 10.557778407832746, 11.595562595754805, 12.500500423945624, 13.515130261816335, 14.485375382871963, 15.472366323010233, 16.37500612879797, 17.330134694665574, 17.39305332814005, 16.459033705742627, 15.551489842832527, 14.582542557749152, 13.623330730522284, 12.743180996516273, 11.773885343305118, 10.839378938442994, 9.80556047469946, 8.83750363934838, 9.786686883398927, 10.600090287438709, 11.51286022358651, 12.56154332054004, 13.546957753056425, 14.48723729725428, 15.489852474814542, 16.45566317739478, 17.39772888093483, 17.416185305514773, 16.452275145645636, 15.4560678260909, 14.479945349661214, 13.598054531049343, 12.666386499154942, 11.698222131147048, 10.807005106550156, 9.798096588838833, 8.812914830912897, 9.78164063770843, 10.799257753057809, 11.672884795428674, 12.485533129799803, 13.49683386642502, 14.430969815602955, 15.401853856931284, 16.369719610005244, 17.366228385377983, 17.447522326769782, 16.393279545343987, 15.444803493595439, 14.459611331919687, 13.4938470389357, 12.576232376548743, 11.6896381732882, 10.749076968027897, 9.799707139188564, 8.927221772245007, 7.885655392185799, 10.737691406889057, 11.703336384107239, 12.600601298586165, 13.533695980309233, 14.464581631637259, 15.358468268008194, 16.397878988907408, 17.34279416707166, 17.53150026685056, 16.548042901678173, 15.52683458804624, 14.561486805185542, 13.594936274630886, 12.521959557273021, 11.580334056338835, 10.695918826318191, 9.764004308061883, 8.79109910631395, 7.8528697486481285, 6.926342170136758, 11.731847634354336, 12.629496580865377, 13.588028870447813, 14.514938429933457, 15.457726415004279, 16.365516787892656, 17.339711100859084, 17.430724932371703, 16.474333406387746, 15.513424124941569, 14.560878037938174, 13.625407908082563, 12.681140770668454, 11.679336238961968, 10.653596234358218, 9.704560509251014, 8.746541636012283, 7.804485133854834, 6.8049277430951705, 5.89918857804862, 12.784049629384697, 13.686155938208737, 14.540599599388113, 15.490364947416294, 16.480830943459626, 17.303953466025707, 17.52885486069367, 16.517530857687838, 15.525137209919066, 14.554027146164897, 13.624176132947797, 12.683257042769196, 11.690112243925961, 10.707712813054934, 9.737510717737013, 8.792943039092929, 7.883134860736668, 6.867882501614008, 5.844208083445973, 4.851354540880884, 13.737875516602301, 14.741047939307759, 15.55270089172109, 16.450155593502085, 17.446518212735068, 17.54909629517125, 16.59426304525826, 15.620905203094777, 14.587755732389704, 13.745112203904924, 12.680931118795723, 11.644869857574108, 10.64944725352756, 9.843136095452838, 8.785692175187426, 7.829186634915463, 6.820827971972797, 5.8565659223555855, 4.874522677621006, 3.915250831942267, 14.78403864599464, 15.760028892937042, 16.497017670917355, 17.37768978271192, 17.576531619245166, 16.546757219047063, 15.582878590564981, 14.637055496239158, 13.644196759413525, 12.69914746764058, 11.692350425181486, 10.652664876348261, 9.707496161768294, 8.838537225736127, 7.8794400741489525, 6.880643329928244, 5.862159450726992, 4.834866723389814, 3.903179621159975, 2.970037302704753, 15.82784988591928, 16.709454530635977, 17.466343909176786, 17.61214595635265, 16.599832207306434, 15.615155363456585, 14.634062880527535, 13.674878649310319, 12.70248475793023, 11.722067321886783, 10.725056374170482, 9.745899885927512, 8.776142115776247, 7.878252219949758, 6.905649216771826, 5.840251700141996, 4.895041466228537, 3.906821939164849, 2.9056344546234762, 1.9935877158941144, 16.7794836570888, 17.736609777340906, 17.56990183437812, 16.64229701235936, 15.659601349855045, 14.67578576179105, 13.70895707520712, 12.73981521185431, 11.724031845886437, 10.700079920049179, 9.768358971515385, 8.789368010586276, 7.841093803798813, 6.976733720082378, 6.002484342988991, 4.968433516318973, 3.9366254230780684, 2.95732473674052, 1.8963660086554763, 1.0645331372979032, 17.749154868810624, 17.6716894952651, 16.7101522139717, 15.759543078283503, 14.814735268544542, 13.741050968841568, 12.77520839529527, 11.805717145367378, 10.807892089819495, 9.773475567203624, 8.794476316078072, 7.868444589177744, 6.848661916021801, 5.904846211353775, 4.965061083492338, 3.9654756175620367, 2.9557811469857387, 1.9760364479502162, 0.9411704111932354, 0.0, 18.6768405024448, 18.641410762505593, 17.683213986232758, 16.70109637926142, 15.764489946769558, 14.690195547164238, 13.732880935984445, 12.770977241791956, 11.821147380589634, 10.83758131068631, 9.831316646413542, 8.82698545923588, 7.896064200108119, 6.889081890563196, 5.937283238554973, 4.94067485473265, 3.9270579912701207, 2.9101128420827145, 1.9589205069315097, 1.0616468632216878], [18.788230704258606, 18.874671357973323, 17.836604315022537, 16.88160776550624, 15.812026960237722, 14.752532723656627, 13.798249837048695, 12.781181287973464, 11.772146059472734, 10.819736977450228, 9.776674029678297, 8.733073365507321, 7.803093680286275, 6.792632120644275, 5.8492758999940415, 4.839952904960681, 3.889884715624416, 2.960680542753045, 1.942212170964637, 0.9842722255065306, 17.716544946905582, 18.661564905003527, 18.685128699185622, 17.6951367279439, 16.661798383553318, 15.588960143724423, 14.576526707482632, 13.542019061717157, 12.596717839372932, 11.636152511593808, 10.703722930552681, 9.770904796739421, 8.797450745887895, 7.789823426642048, 6.858654553049609, 5.846056277633407, 4.926584526452769, 3.9743502152557637, 2.95061575520187, 1.8838867618385442, 16.710763159688938, 17.656491165515888, 18.550574355680872, 18.59230895980458, 17.5373740082661, 16.555716882186307, 15.532265223588839, 14.556836732362486, 13.578626462081486, 12.653958736538652, 11.73035665336025, 10.73631241138252, 9.824369458692566, 8.774784897702476, 7.799733608597469, 6.785454866068586, 5.816715398795969, 4.8291147097342675, 3.8292715185343793, 2.8321231761554704, 15.742743852093854, 16.711827187244964, 17.540648967813674, 18.473900372667302, 18.481523051299575, 17.488349919084836, 16.53145880614516, 15.605221427396765, 14.590051459509635, 13.631870399378682, 12.747617270534137, 11.698458948257814, 10.69120723751633, 9.644539277747771, 8.570352297805911, 7.644309301838566, 6.713623922291961, 5.7221358576473484, 4.794763699756763, 3.872723948876586, 14.811308170169747, 15.781561192319536, 16.50895965668474, 17.526364943827073, 18.371326568473123, 18.528324903468498, 17.483973765630502, 16.554405506846386, 15.599414155051944, 14.64636500941317, 13.663956651766513, 12.606799107460642, 11.579401477215189, 10.548732565310265, 9.582669022359326, 8.60094300192514, 7.651119646047464, 6.7962988836611755, 5.786761051976864, 4.856016732522999, 13.82695941629837, 14.838353034124813, 15.569211364904653, 16.525105005216744, 17.43192037740607, 18.43722782794644, 18.3228505455949, 17.34697841284237, 16.380390590073926, 15.437663641171502, 14.47525672654693, 13.540358692902283, 12.471778133102369, 11.459198529275238, 10.51010589032698, 9.674112996018192, 8.683871714189117, 7.693034799293028, 6.749596090473287, 5.853459290200399, 12.87178713535656, 13.779162295320425, 14.574011618534422, 15.54873736913354, 16.48718084682899, 17.492398664227604, 18.415465251352693, 18.319979956741346, 17.324941706660884, 16.364046645605946, 15.398642887446059, 14.465476124329435, 13.399562053925138, 12.454480623323608, 11.503975203577829, 10.62843895258217, 9.661628526914312, 8.618053604172712, 7.738587517269391, 6.8418979084215845, 11.887232921337858, 12.822524309553318, 13.623637075314372, 14.56778260648197, 15.536408854628737, 16.47684825758957, 17.41293886152556, 18.38902285071267, 18.246347092440793, 17.30520213300097, 16.2983156348039, 15.321541956472915, 14.35093430423959, 13.391078573994887, 12.430064613749968, 11.596266688647669, 10.563407838823265, 9.56107113501491, 8.746128057310688, 7.859967793110188, 10.908582187436174, 11.851845039562292, 12.693592897164859, 13.582890906958765, 14.531918365197459, 15.544249392841902, 16.52075659982057, 17.4910017208762, 18.373363853765483, 18.13713863863127, 17.182010072763667, 16.24651922072516, 15.312499598327737, 14.348015469007223, 13.41026102544914, 12.451049198222272, 11.49759831588337, 10.528302662672216, 9.704819424807132, 8.871280027745339, 9.839617489915984, 10.78880073396653, 11.680630614764167, 12.627809091205002, 13.515018205317515, 14.500432637833901, 15.548649564382625, 16.496196112131315, 17.390066999380938, 18.33213270292099, 18.115211688928316, 17.270718664719936, 16.315465477979462, 15.389609386570914, 14.396173526484548, 13.407993429589613, 12.448116720659064, 11.495182899427178, 10.767334841013266, 9.863925671531902, 8.895480491555935, 9.91561374794265, 10.607836106774203, 11.655136184991708, 12.579727659432535, 13.51333163832987, 14.484215679658199, 15.45208143273216, 16.429212105977935, 17.359164605356085, 18.25714235545871, 18.269386160573937, 17.284193998898186, 16.3184297059142, 15.379057340722673, 14.384741755456357, 13.397261883778215, 12.506109690586914, 11.764163540155302, 10.791185110258999, 7.939429722375306, 8.841748558031822, 9.680119603616712, 10.60697333448228, 11.611979894220296, 12.585833185924631, 13.491100283270695, 14.50544290024623, 15.464345421426279, 16.402706619146247, 17.31119228300485, 18.192182956371624, 18.281901130780632, 17.290317187576875, 16.366694365998985, 15.32304620294757, 14.391131684691262, 13.514717723461528, 12.677025910819411, 11.750498332308041, 6.945273494910027, 7.915588361273684, 8.692692031755064, 9.625730884858056, 10.668231637213575, 11.57878466604017, 12.491238440458769, 13.450787034979507, 14.407178560963466, 15.368087842409642, 16.320633929413034, 17.256104059268644, 18.200371196682752, 18.254909597818383, 17.2934321879796, 16.384457974259437, 15.426439101020705, 14.501331695920644, 13.709849598987839, 12.777651924396178, 5.893071499879667, 6.922872875316392, 7.740121302814764, 8.650304367375218, 9.645127108758228, 10.640347987907116, 11.553087545562528, 12.496153642627242, 13.453774567776978, 14.487309424076305, 15.417160437293404, 16.444123152232144, 17.39938585722746, 18.285971646102848, 18.289543070601063, 17.34497539195698, 16.379312839758093, 15.486552368322641, 14.670569258637038, 13.825485961563913, 4.939245612662063, 5.86798087421737, 6.728020010481787, 7.690513721289427, 8.68687634052241, 9.62886371468159, 10.583696964594582, 11.557054806758062, 12.516393090247616, 13.543753852656224, 14.593869432359698, 15.613272392985218, 16.35872086682906, 17.285921779882933, 18.30515067579624, 18.308731796134445, 17.443112752170563, 16.51039545505886, 15.640254664462004, 14.76158967050253, 3.8930824832697244, 4.812835304164954, 5.783703231285521, 6.762979532079594, 7.723219138625591, 8.575597096830093, 9.558277876801915, 10.605056913659709, 11.572834117271437, 12.49853787115902, 13.546177110687216, 14.58586265952044, 15.416769775069792, 16.448480223340013, 17.363403697889694, 18.403126256653277, 18.457684385106642, 17.580802317746798, 16.611597720923037, 15.706803199740044, 2.849271243345084, 3.8634096664660182, 4.814376993026093, 5.760330965539266, 6.771906823868221, 7.643995241239615, 8.60946216676447, 9.568646397981686, 10.541040289361774, 11.521457725405222, 12.579799652038837, 13.621306135850267, 14.485415729077745, 15.417009837334634, 16.389612840512566, 17.455010357142395, 18.400220591055856, 18.508847101971764, 17.609142887459534, 16.683252786550682, 1.897637472175565, 2.871224372774172, 3.8105095669870126, 4.738114389005768, 5.7208100515100835, 6.704625639574079, 7.671454326158008, 8.640596189510816, 9.65637955547869, 10.680331481315948, 11.62310224938374, 12.602093210312848, 13.550367417100311, 14.536004691778174, 15.590860157115582, 16.6249109837856, 17.61984218844487, 18.622450485662544, 18.5988623542431, 17.612307365146894, 0.9276856336341759, 1.9230895640731784, 2.884626845366579, 3.835235981054775, 4.780043790793736, 5.853728090496711, 6.81957066404301, 7.789061913970901, 8.786886969518784, 9.821303492134655, 10.800302743260207, 11.726334470160536, 12.746117143316479, 13.689932847984505, 14.629717975845942, 15.629303441776242, 16.63899791235254, 17.61874261138806, 18.653608648145042, 18.676840502444797, 0.0, 0.9533682968326833, 1.963464054180156, 2.9455816611514973, 3.8821880936433595, 4.95648249324868, 5.926128015458222, 6.9524884703611685, 7.947458895749476, 8.97710498209166, 9.983369646364428, 10.98770083354209, 11.918622092669851, 12.944888256255746, 13.89668690826397, 14.900236316361667, 15.913853179824196, 16.9307983290116, 17.881990664162807, 18.949761331927693], [18.900058954884475, 17.921303061140645, 16.88323601818986, 15.928239468673558, 14.85865866340504, 13.799164426823944, 12.844881540216013, 11.827812991140782, 10.818777762640051, 9.866368680617546, 8.823305732845615, 7.779705068674638, 6.849725383453592, 5.839263823811592, 4.895907603161358, 3.8865846081279978, 2.974463069444993, 2.045258896573622, 1.026790524785214, 1.937640522339214, 18.669913243738268, 18.306089518731387, 17.731760402352936, 16.741768431111215, 15.708430086720634, 14.63559184689174, 13.62315841064995, 12.588650764884473, 11.643349542540248, 10.682784214761124, 9.750354633719997, 8.817536499906737, 7.844082449055213, 6.836455129809365, 5.905286256216926, 4.892687980800724, 4.011162880273345, 3.1000258497234032, 2.0762913896695094, 2.8372550586712273, 17.664131456521623, 17.30101577924375, 17.732669114006594, 17.638940662971898, 16.584005711433417, 15.602348585353623, 14.578896926756155, 13.603468435529802, 12.625258165248802, 11.700590439705966, 10.776988356527564, 9.782944114549837, 8.871001161859883, 7.821416600869794, 6.846365311764786, 5.832086569235903, 4.982436504916028, 4.114802588816957, 3.114959397617069, 3.7854914729881535, 16.696112148926538, 16.238214434410747, 16.722743726139395, 17.65599513099302, 17.528154754466893, 16.534981622252154, 15.578090509312476, 14.651853130564081, 13.636683162676949, 12.678502102545997, 11.794248973701453, 10.74509065142513, 9.84984023897881, 8.803172279210251, 7.776435975306348, 6.850392979339004, 5.919707599792399, 5.007823736730038, 4.080451578839453, 4.826092245709269, 15.764676467002431, 15.227223109574078, 15.691054415010461, 16.70845970215279, 17.55122689138777, 17.574956606635816, 16.530605468797816, 15.6010372100137, 14.646045858219258, 13.692996712580484, 12.723814802778264, 11.697893765710482, 10.785485154715627, 9.754816242810703, 8.788752699859764, 7.807026679425578, 6.8572033235479015, 6.081986762743865, 5.093594355792899, 5.809385029355682, 14.780327713131054, 14.223775547471602, 14.751306123230373, 15.707199763542462, 16.611820700320717, 17.617128150861088, 17.483518877890827, 16.536477926805716, 15.569890104037274, 14.62716315513485, 13.664756240510277, 12.72985820686563, 11.677861810602806, 10.665282206775675, 9.716189567827417, 8.880196673518629, 7.889955391689555, 6.999868103109063, 6.056429394289322, 6.806827587033082, 13.825155432189243, 13.164584808667215, 13.756106376860142, 14.73083212745926, 15.66708116974364, 16.672298987142252, 17.584549345718724, 17.509479470704694, 16.51444122062423, 15.553546159569294, 14.604726564946496, 13.671559801829872, 12.605645731425575, 11.660564300824046, 10.710058881078266, 9.834522630082608, 8.873832069246943, 7.924886907988746, 7.0454208210854254, 7.795266205254268, 12.840601218170542, 12.207946822900107, 12.805731833640092, 13.747682929396618, 14.716309177543385, 15.6459323519556, 16.582022955891592, 17.558106945078702, 17.45243076994123, 16.51128581050141, 15.504399312304336, 14.527625633973352, 13.557017981740028, 12.597162251495325, 11.636148291250406, 10.802350366148106, 9.836746120340294, 8.867904438830944, 8.052961361126723, 8.81333608994287, 11.861950484268858, 11.237267552909081, 11.875687655490578, 12.762791229873413, 13.711818688112105, 14.713333487207931, 15.670791140721828, 16.641036261777458, 17.52048865907812, 17.34322231613171, 16.388093750264105, 15.452602898225598, 14.518583275828174, 13.55409914650766, 12.66202255424178, 11.757882502038306, 10.804431619699404, 9.83513596648825, 9.011652728623167, 9.824648324578021, 10.792985786748668, 10.17422324731332, 10.862725373089887, 11.80770941411965, 12.694918528232161, 13.665924765069398, 14.698684105283883, 15.646230653032573, 16.537191804693574, 17.479257508233626, 17.321295366428753, 16.476802342220378, 15.5215491554799, 14.625643639678973, 13.65624379767837, 12.714826733405648, 11.754950024475098, 10.802016203243213, 10.0741681448293, 10.817293968364584, 9.848848788388619, 9.161652377654438, 9.789930865099922, 10.835036507906356, 11.759627982347181, 12.664680201380381, 13.634250220559457, 14.602115973633417, 15.576336911290573, 16.50628941066872, 17.404267160771347, 17.484273994270577, 16.537312657579733, 15.611741950404488, 14.678065952178969, 13.691575059272392, 12.70409518759425, 11.812942994402949, 11.070996843971336, 11.744553407091681, 8.89279801920799, 8.08778718774361, 8.862214361942431, 9.786873657396926, 10.791880217134942, 11.737181748975143, 12.638225088583333, 13.652567705558868, 14.611470226738916, 15.549831424458883, 16.458317088317486, 17.339307761684264, 17.53501978946218, 16.583629432067166, 15.67352766981502, 14.629879506763604, 13.697964988507296, 12.821551027277563, 12.145348867568215, 12.703866629140723, 7.898641791742711, 7.161626990985472, 7.874786790080783, 8.805631207772702, 9.848131960128221, 10.730133229090681, 11.638363245771407, 12.597911840292145, 13.554303366276104, 14.51521264772228, 15.467758734725674, 16.403228864581283, 17.347496001995392, 17.548221842308674, 16.600265491795636, 15.69129127807547, 14.73327240483674, 13.808164999736679, 13.193642376875893, 13.73102022122886, 6.846439796712351, 6.1049676336421115, 6.9222160611404835, 7.8302046902898645, 8.825027431672874, 9.791696550957628, 10.700212350875166, 11.64327844793988, 12.600899373089618, 13.634434229388944, 14.564285242606044, 15.591247957544784, 16.513593924059037, 17.400179712934424, 17.596376374417098, 16.651808695773013, 15.686146143574128, 14.793385672138676, 14.15436203652509, 14.778854258396596, 5.892613909494747, 5.0500756325430896, 5.910114768807507, 6.870414044204073, 7.866776663437056, 8.775988519994227, 9.73082176990722, 10.7041796120707, 11.663517895560254, 12.690878657968863, 13.740994237672336, 14.760397198297856, 15.472928933660636, 16.40012984671451, 17.419358742627818, 17.61556509995048, 16.749946055986598, 15.817228758874895, 15.124047442350056, 15.714957967335213, 4.846450780102408, 3.994930062490674, 4.965797989611241, 5.94287985499424, 6.903119461540237, 7.72272190214273, 8.705402682114553, 9.752181718972349, 10.719958922584075, 11.645662676471657, 12.693301915999854, 13.732987464833078, 14.53097784190137, 15.562688290171591, 16.47761176472127, 17.517334323484853, 17.764517688922677, 16.887635621562836, 16.09539049881109, 16.660171496572726, 3.8026395401777675, 3.045504424791738, 3.9964717513518124, 4.940231288453912, 5.919031629180859, 6.791120046552253, 7.756586972077107, 8.715771203294324, 9.688165094674412, 10.66858253071786, 11.694007718870415, 12.735514202681845, 13.599623795909324, 14.531217904166212, 15.503820907344144, 16.56921842397397, 17.514428657887432, 17.815680405787802, 17.09293566534759, 17.636621083383364, 2.8510057690082484, 2.0183491780868086, 2.9576343722996494, 3.8852391943184057, 4.867934856822721, 5.851750444886717, 6.818579131470646, 7.787720994823455, 8.803504360791328, 9.794539548147526, 10.737310316215318, 11.716301277144426, 12.66457548393189, 13.650212758609753, 14.70506822394716, 15.678893043700494, 16.666473891612185, 17.66908218882986, 18.10220411131559, 18.565675661979576, 1.8810539304668592, 0.9697212672404952, 1.9312585485338956, 2.881867684222092, 3.8266754939610528, 4.900359793664027, 5.866202367210326, 6.835693617138217, 7.8335186726861, 8.867935195301971, 9.846934446427523, 10.772966173327852, 11.792748846483795, 12.73656455115182, 13.676349679013258, 14.675935144943558, 15.685629615519856, 16.66537431455538, 17.70024035131236, 18.641410762505593, 0.9533682968326833, 0.0, 1.0100957573474727, 1.992213364318814, 2.928819796810676, 4.003114196415996, 4.972759718625538, 5.9991201735284845, 6.994090598916792, 8.023736685258976, 9.030001349531744, 10.034332536709407, 10.965253795837167, 11.991519959423062, 12.943318611431286, 13.946868019528983, 14.960484882991512, 15.977430032178919, 16.928622367330124, 17.99639303509501], [17.889963197537, 16.91120730379317, 15.873140260842385, 14.918143711326085, 13.848562906057566, 12.789068669476471, 11.83478578286854, 10.817717233793308, 9.808682005292578, 8.856272923270073, 7.813209975498142, 6.769609311327166, 5.839629626106119, 4.82916806646412, 3.885811845813886, 2.8764888507805253, 1.972300445024199, 1.043096272152828, 2.036886282132687, 2.9477362796866866, 18.63529379051134, 17.677999956141328, 16.72166464500547, 15.731672673763745, 14.698334329373163, 13.625496089544269, 12.613062653302478, 11.578555007537002, 10.633253785192776, 9.672688457413653, 8.740258876372526, 7.807440742559265, 6.83398669170774, 5.8263593724618925, 4.895190498869454, 3.8825922234532513, 3.009000255852551, 2.1007542542532387, 3.086387147016982, 3.8473508160187, 18.674227213869095, 17.88263797678585, 16.914764741838585, 16.628844905624426, 15.573909954085943, 14.592252828006151, 13.568801169408683, 12.59337267818233, 11.61516240790133, 10.690494682358494, 9.766892599180093, 8.772848357202365, 7.860905404512411, 6.811320843522322, 5.8362695544173135, 4.821990811888431, 3.9802738804952336, 3.168272082421068, 4.125055154964541, 4.795587230335626, 17.70620790627401, 16.81983663195285, 15.904839353971386, 16.83809075882501, 16.518058997119418, 15.52488586490468, 14.567994751965005, 13.64175737321661, 12.626587405329477, 11.668406345198525, 10.784153216353982, 9.734994894077659, 8.839744481631337, 7.793076521862778, 6.7742733508855535, 5.8482303549182095, 4.917544975371604, 4.206126614894729, 5.090547336186925, 5.836188003056742, 16.774772224349903, 15.808845307116183, 14.873150042842452, 15.890555329984783, 16.69009480056092, 16.564860849288344, 15.520509711450345, 14.590941452666229, 13.635950100871787, 12.682900955233013, 11.713719045430793, 10.68779800836301, 9.778902714071515, 8.748233802166592, 7.786590075438968, 6.804864055004783, 5.855040699127107, 5.280289640908556, 6.103690113140372, 6.8194807867031555, 15.790423470478526, 14.915426053414933, 13.933401751062364, 14.889295391374453, 15.750688609493867, 16.742892544751214, 16.473423120543355, 15.526382169458246, 14.559794346689802, 13.617067397787379, 12.654660483162806, 11.719762449518159, 10.675699186182012, 9.66311958235488, 8.714026943406623, 7.878034049097836, 6.887792767268761, 6.216128300926742, 7.066525151636795, 7.816923344380555, 14.835251189536715, 13.927332249286202, 12.938202004692133, 13.912927755291252, 14.80594907891679, 15.798063381032378, 16.67344331469419, 16.499383713357226, 15.504345463276762, 14.543450402221822, 13.602563940525702, 12.669397177409078, 11.60348310700478, 10.658401676403251, 9.707896256657472, 8.832360005661814, 7.871669444826148, 7.141147105806425, 8.055516578432899, 8.80536196260174, 13.850696975518014, 12.970694263519094, 11.987827461472083, 12.886550838569768, 13.855177086716536, 14.734826320931067, 15.670916924867058, 16.647000914054168, 16.450268145520436, 15.509123186080615, 14.502236687883542, 13.525463009552558, 12.554855357319234, 11.59499962707453, 10.633985666829611, 9.800187741727312, 8.8345834959195, 8.084164636648623, 9.02827233072855, 9.823431847290344, 12.87204624161633, 12.035807208739444, 11.05778328332257, 11.901659139046563, 12.850686597285256, 13.802227456183397, 14.759685109697292, 15.72993023075292, 16.609382628053584, 16.341059691710914, 15.38593112584331, 14.450440273804803, 13.51642065140738, 12.551936522086866, 11.659859929820986, 10.765126483268585, 9.811675600929682, 9.05139616430593, 9.986963698224994, 10.834744081925495, 11.80308154409614, 11.017235866241577, 10.044821000921878, 10.9465773232928, 11.833786437405312, 12.754818734044864, 13.787578074259347, 14.735124622008037, 15.62608577366904, 16.568151477209092, 16.31913274200796, 15.474639717799581, 14.519386531059105, 13.623481015258179, 12.654081173257575, 11.722070714635926, 10.871421688061519, 10.018276401060891, 11.027184918772214, 11.827389725712058, 10.85894454573609, 10.004664996582695, 8.972026492931914, 9.973904417079506, 10.898495891520332, 11.753574170355847, 12.72314418953492, 13.691009942608881, 14.665230880266037, 15.595183379644183, 16.493161129746813, 16.482111369849783, 15.53515003315894, 14.609579325983693, 13.675903327758174, 12.69881904050267, 11.82056685118067, 11.029203192220628, 12.019097162011775, 12.754649164439154, 9.902893776555462, 9.0100392226947, 8.044309989774423, 8.925741566570077, 9.930748126308092, 10.826075717950609, 11.727119057558797, 12.741461674534332, 13.70036419571438, 14.638725393434347, 15.547211057292952, 16.42820173065973, 16.532857165041385, 15.581466807646372, 14.671801647968083, 13.692538387472679, 12.814436652093717, 12.037811225095242, 13.093449185608653, 13.713962386488197, 8.908737549090183, 8.083879025936563, 7.0568824179127745, 7.944499116945853, 8.986999869301373, 9.819027198066145, 10.72725721474687, 11.686805809267609, 12.643197335251568, 13.604106616697743, 14.556652703701138, 15.49212283355675, 16.436389970970858, 16.54605921788788, 15.5985394699487, 14.760177863057498, 13.84974406842316, 13.024425197554358, 14.023982588314022, 14.741115978576333, 7.856535554059823, 7.050482278588333, 6.104311688972475, 6.969072599463016, 7.963895340846025, 8.880590519933092, 9.78910631985063, 10.732172416915343, 11.68979334206508, 12.723328198364406, 13.653179211581506, 14.680141926520246, 15.555397147786204, 16.441982936661592, 16.66461707080959, 15.763908633514891, 14.802617807160548, 14.009645869956355, 14.98470224796322, 15.788950015744069, 6.9027096668422185, 6.060171389890562, 5.092210396639498, 6.009281953377224, 7.0056445726102075, 7.864882488969691, 8.819715738882683, 9.793073581046164, 10.752411864535718, 11.779772626944325, 12.822738936600995, 13.842141897226515, 14.514732157387803, 15.441933070441678, 16.461161966354986, 16.727665037692358, 15.866417719573016, 15.033488956692574, 15.954387653788187, 16.725053724682688, 5.85654653744988, 5.0050258198381465, 4.147893617443232, 5.081747764167392, 6.041987370713389, 6.811615871118194, 7.794296651090017, 8.84107568794781, 9.808852891559539, 10.734556645447121, 11.775046614928513, 12.814732163761738, 13.572781065628536, 14.604491513898758, 15.519414988448437, 16.559137547212018, 16.880989352509097, 16.103895819380515, 16.92573071024922, 17.6702672539202, 4.81273529752524, 4.0556001821392105, 3.1785673791838036, 4.079099197627063, 5.057753571211242, 5.880014015527717, 6.845480941052571, 7.804665172269787, 8.777059063649876, 9.757476499693324, 10.735810942597581, 11.777317426409011, 12.64142701963649, 13.573021127893378, 14.54562413107131, 15.61102164770114, 16.5562318816146, 17.03194060360548, 17.923275876785716, 18.64671684073084, 3.8611015263557213, 3.028444935434281, 2.107138007149911, 3.0241071034915574, 4.006656798853104, 4.940644413862181, 5.90747310044611, 6.876614963798919, 7.873179539763011, 8.836342771874692, 9.779113539942484, 10.758104500871593, 11.706378707659056, 12.692015982336919, 13.746871447674327, 14.72069626742766, 15.708277115339353, 16.71088541255703, 17.697239172501764, 18.68379416159797, 2.891149687814332, 1.9798170245879678, 1.060872083801074, 2.0012310048675115, 2.946038814606472, 3.942163017391194, 4.908005590937492, 5.877496840865383, 6.875321896413267, 7.9097384190291375, 8.88873767015469, 9.814769397055018, 10.834552070210961, 11.778367774878987, 12.718152902740425, 13.717738368670725, 14.727432839247022, 15.707177538282545, 16.742043575039524, 17.683213986232758, 1.963464054180156, 1.0100957573474727, 0.0, 0.9821176069713413, 1.9187240394632035, 2.993018439068524, 3.9626639612780656, 4.989024416181012, 5.983994841569319, 7.013640927911503, 8.019905592184271, 9.024236779361933, 9.955158038489694, 10.981424202075589, 11.933222854083812, 12.93677226218151, 13.950389125644039, 14.967334274831444, 15.91852660998265, 16.986297277747536], [16.90784559056566, 15.92908969682183, 14.891022653871044, 13.936026104354744, 12.866445299086225, 11.80695106250513, 10.852668175897199, 9.835599626821967, 8.826564398321237, 7.874155316298731, 6.831092368526801, 5.7874917043558245, 4.857512019134778, 3.8470504594927784, 2.9036942388425446, 1.8943712438091835, 0.9953123609358646, 1.9245165338072356, 2.942984905595644, 3.90092485105375, 17.653176183539998, 16.695882349169985, 15.739547038034123, 14.749555066792402, 13.71621672240182, 12.643378482572926, 11.630945046331135, 10.59643740056566, 9.651136178221435, 8.690570850442311, 7.758141269401185, 6.825323135587924, 5.851869084736399, 4.844241765490551, 3.9130728918981124, 2.90047461648191, 2.032012171764217, 2.982174515907646, 3.992485770479939, 4.8294684229900415, 18.626592538945886, 17.680864533118935, 16.677218356242864, 15.646727298653085, 14.591792347114602, 13.61013522103481, 12.586683562437342, 11.611255071210989, 10.633044800929989, 9.708377075387155, 8.784774992208753, 7.790730750231023, 6.87878779754107, 5.82920323655098, 4.854151947445972, 3.8398732049170894, 3.0032857964068995, 3.990886485468601, 4.990729676668489, 5.777704837306968, 18.54294266273746, 17.65224528350023, 16.73724800551876, 15.888871739939654, 15.535941390148077, 14.54276825793334, 13.585877144993663, 12.659639766245268, 11.644469798358138, 10.686288738227185, 9.80203560938264, 8.752877287106317, 7.857626874659997, 6.810958914891437, 5.7972852667972194, 4.8712422708298755, 3.9405568912832702, 4.932044955927883, 5.859417113818468, 6.818305610028084, 17.611506980813353, 16.64125395866356, 15.705558694389829, 14.941336311099425, 15.707977193589578, 15.582743242317001, 14.538392104479003, 13.608823845694888, 12.653832493900447, 11.700783348261673, 10.731601438459451, 9.70568040139167, 8.796785107100174, 7.76611619519525, 6.809601991350634, 5.827875970916449, 4.878052615038773, 5.824918655294218, 6.8609668544884705, 7.7917111739423355, 16.7165892299947, 15.747834704962308, 14.765810402609741, 13.940076372489095, 14.768571002522524, 15.760774937779871, 15.491305513572016, 14.544264562486905, 13.577676739718461, 12.634949790816037, 11.672542876191464, 10.737644842546818, 9.698711102093677, 8.686131498266546, 7.737038859318289, 6.9010459650095015, 5.910804683180427, 6.760757315312404, 7.704196024132145, 8.771019249716518, 15.761416949052887, 14.75974090083358, 13.77061065623951, 12.951071219172771, 13.823831471945446, 14.815945774061035, 15.691325707722845, 15.517266106385883, 14.52222785630542, 13.56133279525048, 12.625575856437367, 11.692409093320743, 10.626495022916446, 9.681413592314916, 8.730908172569137, 7.8553719215734805, 6.894681360737814, 7.685776120192088, 8.638121570821863, 9.592114898823434, 14.776862735034186, 13.803102915066471, 12.82023611301946, 11.904433231598425, 12.873059479745192, 13.752708713959723, 14.688799317895715, 15.664883307082825, 15.473280061432101, 14.53213510199228, 13.525248603795207, 12.548474925464223, 11.577867273230899, 10.618011542986196, 9.656997582741276, 8.823199657638979, 7.857595411831165, 8.628793651034286, 9.572901345114213, 10.581653453242183, 13.798212001132502, 12.86821586028682, 11.890191934869947, 10.91954153207522, 11.868568990313914, 12.820109849212054, 13.777567502725951, 14.747812623781579, 15.627265021082243, 15.364071607622577, 14.408943041754974, 13.473452189716467, 12.539432567319043, 11.57494843799853, 10.68287184573265, 9.78813839918025, 8.834687516841347, 9.596025178691592, 10.531592712610657, 11.565411176354191, 12.729247303612311, 11.870611202400328, 10.898196337080629, 9.964459716321457, 10.85166883043397, 11.772701127073521, 12.805460467288006, 13.753007015036696, 14.643968166697698, 15.586033870237749, 15.342144657919622, 14.497651633711245, 13.542398446970768, 12.646492931169844, 11.67709308916924, 10.745082630547593, 9.894433603973184, 10.562905415446554, 11.571813933157877, 12.556995691083813, 11.785110305252262, 10.858040332741446, 9.825401829090664, 8.991786810108163, 9.91637828454899, 10.771456563384504, 11.74102658256358, 12.70889233563754, 13.683113273294696, 14.613065772672842, 15.511043522775472, 15.505123285761444, 14.558161949070604, 13.632591241895359, 12.69891524366984, 11.721830956414337, 10.843578767092335, 11.57383220660629, 12.563726176397438, 13.48425512981091, 10.829059536071634, 9.863414558853453, 8.897685325933173, 7.943623959598735, 8.948630519336751, 9.843958110979266, 10.745001450587456, 11.75934406756299, 12.718246588743039, 13.656607786463006, 14.56509345032161, 15.446084123688387, 15.555869080953048, 14.604478723558037, 13.694813563879748, 12.715550303384346, 11.837448568005382, 12.582440239480905, 13.638078199994316, 14.443568351859952, 9.890855156061525, 8.937254362095315, 7.910257754071526, 6.962381509974512, 8.004882262330032, 8.836909591094804, 9.74513960777553, 10.704688202296268, 11.661079728280226, 12.621989009726402, 13.574535096729797, 14.510005226585408, 15.454272363999516, 15.569071133799543, 14.621551385860364, 13.783189778969165, 12.872755984334825, 13.56905421194002, 14.568611602699685, 15.470721943948089, 8.838653161031164, 7.912938589977395, 6.966768000361537, 5.9869549924916745, 6.981777733874684, 7.898472912961751, 8.806988712879289, 9.750054809944002, 10.70767573509374, 11.741210591393067, 12.671061604610166, 13.698024319548907, 14.573279540814863, 15.45986532969025, 15.687628986721256, 14.786920549426558, 13.825629723072211, 14.554274884342018, 15.529331262348883, 16.518555981115824, 7.88482727381356, 6.940605967208095, 5.95466670802856, 5.027164346405883, 6.023526965638866, 6.88276488199835, 7.837598131911341, 8.810955974074822, 9.770294257564377, 10.797655019972986, 11.840621329629654, 12.860024290255174, 13.532614550416461, 14.459815463470337, 15.479044359383645, 15.750676953604023, 14.88942963548468, 15.578117971078237, 16.499016668173848, 17.45465969005444, 6.838664144421221, 5.885460397155679, 5.0103499288322935, 4.09963015719605, 5.059869763742047, 5.829498264146853, 6.8121790441186745, 7.858958080976469, 8.826735284588198, 9.752439038475778, 10.792929007957172, 11.832614556790396, 12.590663458657195, 13.622373906927416, 14.537297381477096, 15.577019940240676, 15.90400126842076, 16.648524833766178, 17.47035972463488, 18.399873219291955, 5.794852904496581, 4.936034759456743, 4.041023690572865, 3.096981590655722, 4.0756359642399005, 4.897896408556376, 5.863363334081229, 6.822547565298445, 7.794941456678534, 8.77535889272198, 9.75369333562624, 10.79519981943767, 11.659309412665149, 12.590903520922037, 13.563506524099969, 14.628904040729799, 15.574114274643259, 16.630797611286468, 17.63198509582784, 18.63073113322284, 4.843219133327063, 3.9088795127518132, 2.9695943185389724, 2.041989496520216, 3.024539191881763, 3.958526806890839, 4.925355493474767, 5.894497356827577, 6.891061932791669, 7.854225164903351, 8.796995932971143, 9.775986893900251, 10.724261100687714, 11.709898375365578, 12.764753840702985, 13.738578660456318, 14.72615950836801, 15.728767805585685, 16.715121565530424, 17.70167655462663, 3.8732672947856734, 2.931259814877767, 1.9697225335843664, 1.0191133978961702, 1.963921207635131, 2.960045410419853, 3.925887983966151, 4.895379233894042, 5.893204289441925, 6.927620812057796, 7.906620063183348, 8.832651790083675, 9.852434463239618, 10.796250167907644, 11.736035295769081, 12.735620761699382, 13.74531523227568, 14.725059931311202, 15.759925968068183, 16.70109637926142, 2.9455816611514973, 1.992213364318814, 0.9821176069713413, 0.0, 0.936606432491862, 2.0109008320971826, 2.9805463543067243, 4.006906809209671, 5.001877234597978, 6.0315233209401615, 7.03778798521293, 8.042119172390592, 8.973040431518353, 9.999306595104247, 10.951105247112471, 11.954654655210168, 12.968271518672697, 13.985216667860104, 14.93640900301131, 16.004179670776196], [15.971239158073798, 14.99248326432997, 13.954416221379184, 12.999419671862883, 11.929838866594364, 10.87034463001327, 9.916061743405338, 8.898993194330107, 7.8899579658293755, 6.937548883806869, 5.894485936034939, 4.850885271863962, 3.920905586642916, 2.910444027000916, 1.9670878063506825, 0.9577648113173216, 1.9319187934277267, 2.8611229662990976, 3.8795913380875056, 4.837531283545612, 16.716569751048137, 15.759275916678124, 14.802940605542263, 13.812948634300541, 12.779610289909959, 11.706772050081065, 10.694338613839275, 9.659830968073798, 8.714529745729573, 7.75396441795045, 6.821534836909323, 5.888716703096062, 4.915262652244537, 3.9076353329986895, 2.97646645940625, 1.9638681839900478, 2.968618604256079, 3.918780948399508, 4.929092202971801, 5.766074855481903, 17.689986106454025, 16.744258100627075, 15.740611923751004, 14.710120866161223, 13.65518591462274, 12.673528788542948, 11.65007712994548, 10.674648638719127, 9.696438368438127, 8.771770642895293, 7.848168559716891, 6.854124317739161, 5.9421813650492075, 4.892596804059118, 3.91754551495411, 2.9032667724252272, 3.9398922288987617, 4.927492917960463, 5.927336109160351, 6.714311269798829, 18.634914262007374, 17.756607975097204, 16.712302538292295, 15.652703271911848, 14.599334957656215, 13.606161825441477, 12.649270712501801, 11.723033333753406, 10.707863365866276, 9.749682305735323, 8.865429176890778, 7.816270854614455, 6.9210204421681345, 5.8743524823995745, 4.884333461455382, 3.958290465488038, 4.877163323775132, 5.868651388419745, 6.79602354631033, 7.754912042519944, 18.548113413305217, 17.577860391155426, 16.642165126881693, 15.877942743591289, 15.045213419922083, 14.646136809825139, 13.601785671987141, 12.672217413203025, 11.717226061408585, 10.764176915769813, 9.79499500596759, 8.769073968899807, 7.860178674608311, 6.829509762703388, 5.896650186008797, 4.914924165574612, 5.814659047530635, 6.76152508778608, 7.797573286980333, 8.728317606434198, 17.653195662486564, 16.684441137454172, 15.702416835101605, 14.876682804980959, 14.10580722885503, 14.82416850528801, 14.554699081080154, 13.607658129995043, 12.641070307226599, 11.698343358324175, 10.735936443699602, 9.801038410054955, 8.785759296751841, 7.7731796929247094, 6.824087053976451, 5.988094159667664, 6.847411115672289, 7.697363747804266, 8.640802456624007, 9.70762568220838, 16.69802338154475, 15.696347333325443, 14.707217088731374, 13.887677651664635, 13.161067698277952, 13.879339341569175, 14.754719275230983, 14.580659673894022, 13.585621423813558, 12.624726362758619, 11.71262405109553, 10.779457287978905, 9.713543217574609, 8.768461786973079, 7.817956367227301, 6.942420116231643, 7.831287793229676, 8.62238255268395, 9.574728003313725, 10.528721331315296, 15.713469167526048, 14.739709347558335, 13.756842545511324, 12.841039664090289, 12.210295706077698, 12.816102281467861, 13.752192885403852, 14.728276874590962, 14.550838690378157, 13.609693730938336, 12.612296798453372, 11.635523120122388, 10.664915467889063, 9.70505973764436, 8.74404577739944, 7.910247852297141, 8.794201844323027, 9.565400083526148, 10.509507777606075, 11.518259885734045, 14.734818433624364, 13.804822292778685, 12.82679836736181, 11.856147964567084, 11.175964058505405, 11.883503416720192, 12.840961070234089, 13.811206191289717, 14.69065858859038, 14.451119802280743, 13.49599123641314, 12.560500384374633, 11.62648076197721, 10.661996632656695, 9.769920040390815, 8.92992876841953, 9.77129394933321, 10.532631611183454, 11.468199145102519, 12.502017608846053, 13.665853736104173, 12.807217634892192, 11.834802769572493, 10.901066148813321, 10.159063898625462, 10.836094694581659, 11.868854034796144, 12.816400582544833, 13.707361734205836, 14.649427437745887, 14.429192852577788, 13.584699828369411, 12.629446641628935, 11.733541125828008, 10.764141283827405, 9.88687299978687, 10.831040036465046, 11.499511847938416, 12.508420365649739, 13.493602123575675, 12.721716737744124, 11.79464676523331, 10.762008261582528, 9.928393242600027, 9.223773352740482, 9.834850130892642, 10.804420150071717, 11.772285903145677, 12.746506840802834, 13.67645934018098, 14.57443709028361, 14.59217148041961, 13.64521014372877, 12.719639436553523, 11.785963438328004, 10.863621325653614, 11.780185199584198, 12.510438639098153, 13.5003326088893, 14.420861562302772, 11.765665968563496, 10.800020991345315, 9.834291758425037, 8.880230392090597, 8.256025587528242, 8.907351678487403, 9.808395018095593, 10.822737635071128, 11.781640156251177, 12.720001353971144, 13.628487017829748, 14.509477691196524, 14.642917275611214, 13.691526918216201, 12.781861758537913, 11.857340672623623, 12.774055000497244, 13.519046671972767, 14.574684632486179, 15.380174784351814, 10.827461588553387, 9.873860794587177, 8.846864186563389, 7.898987942466374, 7.262880804161221, 7.900303158602941, 8.808533175283667, 9.768081769804406, 10.724473295788364, 11.68538257723454, 12.637928664237934, 13.573398794093546, 14.517665931507654, 14.656119328457708, 13.708599580518529, 12.924980148208443, 13.809362416826687, 14.505660644431883, 15.505218035191547, 16.407328376439953, 9.775259593523026, 8.849545022469258, 7.903374432853399, 6.923561424983537, 6.239776275705874, 6.961866480469888, 7.870382280387426, 8.81344837745214, 9.771069302601877, 10.804604158901203, 11.734455172118302, 12.761417887057043, 13.636673108323002, 14.52325889719839, 14.77467718137942, 13.928710918665836, 14.762236155564075, 15.49088131683388, 16.465937694840743, 17.455162413607688, 8.821433706305422, 7.877212399699957, 6.891273140520422, 5.963770778897745, 5.237995469720423, 5.946158449506488, 6.900991699419479, 7.87434954158296, 8.833687825072515, 9.861048587481122, 10.904014897137793, 11.923417857763313, 12.596008117924601, 13.523209030978476, 14.542437926891784, 14.8924673228433, 15.826036067976544, 16.5147244035701, 17.43562310066571, 18.391266122546305, 7.775270576913083, 6.822066829647541, 5.946956361324156, 5.036236589687912, 4.1983497946121435, 4.892891831654991, 5.875572611626812, 6.922351648484607, 7.8901288520963355, 8.815832605983918, 9.856322575465311, 10.896008124298536, 11.654057026165335, 12.685767474435556, 13.600690948985235, 14.640413507748816, 15.605947134043324, 16.622235963019573, 17.68975929231625, 18.67057428754162, 6.731459336988443, 5.872641191948605, 4.977630123064727, 4.033588023147584, 3.1598144123109995, 3.961289976064513, 4.926756901589367, 5.8859411328065825, 6.858335024186672, 7.838752460230119, 8.81708690313438, 9.85859338694581, 10.722702980173288, 11.654297088430177, 12.626900091608109, 13.692297608237938, 14.637507842151399, 15.69419117879461, 16.695378663335983, 17.69412470073098, 5.779825565818924, 4.845485945243675, 3.9062007510308345, 2.9785959290120783, 2.1087176399528618, 3.021920374398977, 3.9887490609829053, 4.9578909243357145, 5.954455500299808, 6.917618732411491, 7.8603895004792825, 8.83938046140839, 9.787654668195854, 10.773291942873717, 11.828147408211125, 12.801972227964457, 13.78955307587615, 14.792161373093824, 15.778515133038564, 16.76507012213477, 4.809873727277535, 3.867866247369629, 2.9063289660762286, 1.9557198303880323, 1.0480996557062303, 2.0234389779279907, 2.989281551474289, 3.9587728014021804, 4.956597856950064, 5.991014379565936, 6.970013630691487, 7.896045357591816, 8.915828030747758, 9.859643735415784, 10.799428863277221, 11.799014329207521, 12.808708799783819, 13.788453498819342, 14.823319535576323, 15.764489946769558, 3.882188093643359, 2.928819796810676, 1.9187240394632035, 0.936606432491862, 0.0, 1.0742943996053205, 2.043939921814862, 3.070300376717809, 4.065270802106117, 5.0949168884483, 6.101181552721068, 7.105512739898732, 8.036433999026492, 9.062700162612387, 10.01449881462061, 11.018048222718308, 12.031665086180837, 13.048610235368244, 13.99980257051945, 15.067573238284336], [14.917016983786864, 13.938261090043035, 12.900399924001013, 11.945403374484712, 10.896000152808162, 9.844505885521782, 8.89022299891385, 7.873154449838619, 6.864119221337888, 5.911710139315382, 4.868647191543451, 3.8250465273724745, 2.8950668421514285, 1.8846052825094288, 0.9412490618591951, 1.950572056892556, 3.002358390222919, 3.93156256309429, 4.950030934882697, 5.9079708803408035, 15.677127310692665, 14.733437172186637, 13.777101861050776, 12.787109889809054, 11.753771545418472, 10.680933305589578, 9.668499869347787, 8.633992223582311, 7.688691001238086, 6.728125673458962, 5.795696092417835, 4.862877958604574, 3.8894239077530495, 2.881796588507202, 1.9889046028006363, 2.956675429565282, 4.0210679321865515, 4.9871467726572405, 5.999531799766992, 6.840369255087223, 16.629428129423555, 15.718419356135586, 14.714773179259517, 13.684282121669735, 12.629347170131252, 11.64769004405146, 10.624238385453992, 9.64880989422764, 8.67059962394664, 7.745931898403804, 6.822329815225403, 5.828285573247673, 4.916342620557721, 3.866758059567631, 3.013987881716762, 3.896074018000461, 4.943488374827798, 5.931089063889499, 6.930932255089387, 7.781383622135245, 17.560619862402053, 16.730769230605713, 15.686463793800806, 14.626864527420361, 13.573496213164727, 12.58032308094999, 11.623431968010314, 10.697194589261919, 9.682024621374786, 8.723843561243834, 7.839590432399289, 6.790432110122966, 5.895181697676647, 4.848513737908087, 4.077802071636469, 4.951097711063272, 5.880759469704168, 6.872247534348781, 7.799619692239366, 8.741158094843778, 18.49205554432616, 17.538706239282927, 16.603010975009195, 15.57439995626059, 14.534351742916327, 13.620298065333651, 12.575946927495654, 11.646378668711538, 10.691387316917096, 9.738338171278322, 8.7691562614761, 7.743235224408318, 6.8343399301168235, 5.803671018211901, 5.1288299409473845, 5.907731411149846, 6.818255193459671, 7.765121233715116, 8.801169432909369, 9.72445087849019, 18.42557051159242, 17.45681598656003, 16.474791684207464, 15.598413185368496, 14.576725556579806, 13.74987410568269, 13.528860336588666, 12.581819385503554, 11.61523156273511, 10.672504613832686, 9.710097699208113, 8.775199665563466, 7.776477872115493, 6.763898268288361, 6.056266808915039, 6.980901405242898, 7.851007261601325, 8.700959893733302, 9.644398602553043, 10.711221828137417, 17.470398230650606, 16.4687221824313, 15.479591937837233, 14.621383346676316, 13.631986026002728, 12.805044941963853, 13.680424875625663, 13.554820929402531, 12.559782679322069, 11.59888761826713, 10.703342626459182, 9.770175863342558, 8.704261792938262, 7.759180362336731, 7.050136122165888, 7.935227361806877, 8.834883939158711, 9.625978698612986, 10.57832414924276, 11.532317477244332, 16.485844016631905, 15.512084196664194, 14.529217394617183, 13.613414513196147, 12.681214033802474, 11.741807881862542, 12.677898485798533, 13.653982474985643, 13.524999945886668, 12.583854986446847, 11.631846956982761, 10.655073278651777, 9.684465626418453, 8.788850001902166, 7.976225532338027, 8.903055097872375, 9.797797990252063, 10.568996229455184, 11.51310392353511, 12.52185603166308, 15.50719328273022, 14.577197141884543, 13.599173216467669, 12.628522813672943, 11.646882386230182, 10.809209017114872, 11.766666670628767, 12.736911791684395, 13.61636418898506, 13.470669960810131, 12.515541394942527, 11.58005054290402, 10.646030920506597, 9.7457868969145, 9.002099795329402, 9.922736013994763, 10.774890095262245, 11.53622775711249, 12.471795291031555, 13.490025188298915, 14.43822858521003, 13.579592483998049, 12.60717761867835, 11.67344099791918, 10.629982226350238, 9.76180029497634, 10.794559635190822, 11.742106182939512, 12.633067334600515, 13.575133038140565, 13.448743011107176, 12.604249986898798, 11.648996800158322, 10.817331390085814, 9.996321038765991, 10.879680245362106, 11.834636182394082, 12.503107993867452, 13.512016511578775, 14.482670832085478, 13.494091586849981, 12.567021614339167, 11.534383110688385, 10.700768091705886, 9.694691680465258, 8.760555731287322, 9.730125750466396, 10.697991503540356, 11.672212441197512, 12.602164940575658, 13.500142690678288, 13.611721638948998, 12.664760302258157, 11.803429700811328, 11.01814319326659, 11.85642857122885, 12.783781345513233, 13.514034785027189, 14.503928754818336, 15.409930270812575, 12.538040817669353, 11.572395840451172, 10.606666607530894, 9.652605241196456, 8.76335042841241, 7.833057278882083, 8.734100618490272, 9.748443235465807, 10.707345756645855, 11.645706954365822, 12.554192618224427, 13.435183291591203, 13.662467434140602, 12.775317182474007, 12.0140415134765, 12.850147918198859, 13.77765114642628, 14.522642817901803, 15.578280778415214, 16.369243492861617, 11.616550510056692, 10.646235643693034, 9.619239035669246, 8.671362791572232, 7.77020564504539, 6.82600875899762, 7.734238775678346, 8.693787370199084, 9.650178896183043, 10.611088177629219, 11.563634264632613, 12.499104394488224, 13.443371531902333, 13.739909592715513, 12.940779335457115, 13.88981506056432, 14.812958562755723, 15.509256790360919, 16.50881418112058, 17.396397084949754, 10.7009055359015, 9.63966968836743, 8.693499098751571, 7.695936274089394, 6.839499980044399, 5.887572080864568, 6.796087880782106, 7.7391539778468195, 8.696774902996559, 9.730309759295885, 10.660160772512985, 11.687123487451725, 12.56237870871768, 13.448964497593069, 14.006856936318007, 14.893545831021713, 15.76583230149311, 16.494477462762916, 17.469533840769778, 18.44423112211749, 9.752486482462183, 8.784962402745416, 7.743583159324126, 6.7361456280036025, 5.8377191740589485, 4.871864049901167, 5.826697299814159, 6.80005514197764, 7.759393425467195, 8.786754187875804, 9.829720497532472, 10.849123458157992, 11.52171371831928, 12.448914631373155, 13.468143527286463, 14.424649067558425, 15.433007730501092, 16.397269780118304, 17.379313024852884, 18.43802456486223, 8.706323353069845, 7.730333106127443, 6.799266380127861, 5.80861143879377, 4.848371832247773, 3.8185974320496703, 4.801278212021492, 5.848057248879287, 6.815834452491016, 7.741538206378598, 8.78202817585999, 9.821713724693215, 10.579762626560013, 11.611473074830235, 12.526396549379914, 13.566119108143495, 14.531652734438003, 15.547941563414252, 16.61546489271093, 17.596279887936298, 7.70624791336169, 6.780907468428507, 5.829940141868432, 4.883986169355259, 3.871672420309043, 2.8869955764591926, 3.852462501984047, 4.811646733201263, 5.784040624581352, 6.7644580606248, 7.742792503529058, 8.784298987340488, 9.648408580567967, 10.580002688824855, 11.552605692002787, 12.618003208632617, 13.563213442546077, 14.619896779189288, 15.62108426373066, 16.61983030112566, 6.754614142192171, 5.781027241593564, 4.841742047380723, 3.9141372253619675, 2.9314415628576524, 1.9476259747936564, 2.914454661377585, 3.883596524730394, 4.880161100694488, 5.843324332806169, 6.786095100873961, 7.7650860618030695, 8.713360268590533, 9.698997543268396, 10.753853008605804, 11.727677828359136, 12.715258676270828, 13.717866973488503, 14.704220733433242, 15.690775722529448, 5.884168126882855, 4.879783104746202, 3.9182458234528017, 2.9676366877646054, 2.0228288780256447, 0.9491445783226701, 1.9149871518689685, 2.88447840179686, 3.8823034573447432, 4.9167199799606145, 5.895719231086166, 6.821750957986494, 7.841533631142437, 8.785349335810462, 9.7251344636719, 10.7247199296022, 11.734414400178498, 12.71415909921402, 13.749025135971001, 14.690195547164237, 4.9564824932486795, 4.003114196415996, 2.993018439068524, 2.0109008320971826, 1.0742943996053205, 0.0, 0.9696455222095416, 1.9960059771124885, 2.9909764025007957, 4.02062248884298, 5.026887153115748, 6.03121834029341, 6.962139599421171, 7.988405763007066, 8.94020441501529, 9.943753823112987, 10.957370686575516, 11.974315835762923, 12.925508170914128, 13.993278838679014], [13.94737146157732, 12.968615567833492, 11.930754401791472, 10.975757852275171, 9.92635463059862, 8.900646783995315, 7.946363897387384, 6.929295348312152, 5.920260119811421, 4.967851037788915, 3.9247880900169845, 2.881187425846008, 1.951207740624962, 0.9407461809829624, 1.884102401633196, 2.893425396666557, 3.9452117299969203, 4.874415902868291, 5.8928842746567, 6.850824220114806, 14.719812699512874, 13.78957807066017, 12.833242759524309, 11.843250788282587, 10.809912443892005, 9.737074204063111, 8.72464076782132, 7.690133122055844, 6.744831899711619, 5.784266571932495, 4.851836990891368, 3.919018857078107, 2.9455648062265825, 1.9379374869807355, 2.931757942574637, 3.899528769339283, 4.963921271960552, 5.930000112431241, 6.942385139540995, 7.810014777296765, 15.672113518243762, 14.774560254609119, 13.77091407773305, 12.740423020143268, 11.685488068604785, 10.703830942524993, 9.680379283927525, 8.704950792701172, 7.726740522420172, 6.802072796877337, 5.878470713698936, 4.8844264717212065, 3.972483519031254, 2.9228989580411646, 3.9160163113102326, 4.8389273577744625, 5.8863417146018, 6.873942403663501, 7.8737855948633895, 8.751029144344786, 16.603305251222263, 15.786910129079248, 14.74260469227434, 13.683005425893894, 12.62963711163826, 11.636463979423523, 10.679572866483847, 9.753335487735452, 8.73816551984832, 7.779984459717367, 6.895731330872824, 5.846573008596501, 4.951322596150181, 3.904654636381621, 4.97884161632348, 5.893951050837273, 6.8236128094781705, 7.815100874122783, 8.742473032013368, 9.710803617053319, 17.53474093314637, 16.59484713775646, 15.65915187348273, 14.630540854734123, 13.59049264138986, 12.676438963807184, 11.632087825969187, 10.702519567185071, 9.747528215390629, 8.794479069751855, 7.825297159949634, 6.799376122881853, 5.890480828590357, 4.859811916685435, 5.825875459636374, 6.807601480070559, 7.761108533233673, 8.707974573489118, 9.74402277268337, 10.674767092137236, 18.445137176603904, 17.48950440391026, 16.507480101557693, 15.551586461245604, 14.529898832456913, 13.632533969901242, 12.5850012350622, 11.63796028397709, 10.671372461208646, 9.728645512306223, 8.76623859768165, 7.831340564037002, 6.832618770589026, 5.8200391667618945, 6.7533123276040286, 7.716582402676453, 8.720466910930561, 9.643813233507304, 10.587251942327045, 11.654075167911419, 18.440043752860145, 17.401721217497563, 16.412590972903494, 15.54915805635799, 14.559760735684403, 13.732819651645528, 12.825681539172807, 12.610961827876068, 11.615923577795606, 10.655028516740666, 9.759483524932715, 8.826316761816091, 7.7604026914117945, 6.815321260810265, 7.747181640854878, 8.670908359240432, 9.700548994890548, 10.568832038386988, 11.521177489016763, 12.475170817018334, 17.455489538841444, 16.445083231730457, 15.462216429683446, 14.54641354826241, 13.608988743484149, 12.669582591544216, 11.823155149345677, 12.799239138532787, 12.581140844360204, 11.639995884920383, 10.687987855456294, 9.71121417712531, 8.740606524891986, 7.844990900375699, 8.673271051027017, 9.63873609530593, 10.6634630459839, 11.511849569229186, 12.455957263309113, 13.464709371437083, 16.47683880493976, 15.510196176950807, 14.532172251533932, 13.561521848739206, 12.574657095911856, 11.736983726796547, 10.812017050663288, 11.782262171718916, 12.66171456901958, 12.526810859283664, 11.57168229341606, 10.636191441377553, 9.70217181898013, 8.801927795388034, 9.699145314018391, 10.65835714124526, 11.611808023584162, 12.479081096886492, 13.414648630805557, 14.448467094549091, 15.407874107419572, 14.54923800620759, 13.57682314088789, 12.606440032985443, 11.557756936031913, 10.689575004658014, 9.839910015225342, 10.787456562974032, 11.678417714635035, 12.620483418175086, 12.504883909580709, 11.660390885372331, 10.705137698631855, 9.873472288559347, 10.693366557454981, 11.615301372612603, 12.66555461837478, 13.445961333641455, 14.454869851352777, 15.440051609278713, 14.463737109059522, 13.536667136548708, 12.504028632897926, 11.65157870638033, 10.622466390146933, 9.688330440968997, 8.775476130500916, 9.743341883574876, 10.717562821232033, 11.647515320610179, 12.545493070712809, 12.66786253742253, 11.72090120073169, 10.859570599284861, 11.71518871195558, 12.592049698479347, 13.61469978149393, 14.456888124801191, 15.446782094592338, 16.36731104800581, 13.507686339878894, 12.542041362660713, 11.576312129740435, 10.622250763405997, 9.691125138094087, 8.760831988563758, 7.779450998524792, 8.793793615500327, 9.752696136680376, 10.691057334400343, 11.599542998258947, 12.480533671625723, 12.718608332614135, 11.83145808094754, 12.711087032165489, 13.585769045449355, 14.517683563705663, 15.465496157675805, 16.521134118189217, 17.32662427005485, 12.586196032266233, 11.615881165902575, 10.588884557878787, 9.641008313781773, 8.697980354727067, 7.753783468679296, 6.779589155712866, 7.739137750233605, 8.695529276217563, 9.656438557663739, 10.608984644667133, 11.544454774522745, 12.488721911936853, 12.796050491189046, 13.637824854146105, 14.58686057925331, 15.54487945249204, 16.452110130134923, 17.451667520894585, 18.353777862142987, 11.670551058111041, 10.609315210576971, 9.663144620961113, 8.665581796298936, 7.794516859904903, 6.831261257786469, 5.841438260816626, 6.78450435788134, 7.7410630399675435, 8.774597896266869, 9.704448909483968, 10.731411624422709, 11.605064097537888, 12.491649886413276, 13.461851981731197, 14.406419660375281, 15.372082212574167, 16.387334571696826, 17.391683819498056, 18.396178601194336, 10.722132004671725, 9.754607924954957, 8.713228681533668, 7.705791150213145, 6.792736053919452, 5.82688092976167, 4.872047679848679, 5.84540552201216, 6.803681562438181, 7.831042324846789, 8.872405886352679, 9.891808846978199, 10.564399107139486, 11.491600020193362, 12.51082891610667, 13.467334456378632, 14.4756931193213, 15.43995516893851, 16.42199841367309, 17.480709953682435, 9.675968875279386, 8.699978628336984, 7.768911902337402, 6.778256961003312, 5.818017354457315, 4.788242954259212, 3.8455663489924783, 4.892345385850273, 5.8601225894620015, 6.785826343349584, 7.824713564680197, 8.864399113513421, 9.62244801538022, 10.654158463650441, 11.56908193820012, 12.608804496963701, 13.57433812325821, 14.590626952234459, 15.658150281531134, 16.638965276756508, 8.675893435571231, 7.750552990638048, 6.7995856640779735, 5.8536316915648, 4.841317942518584, 3.8566410986687343, 2.896750638955033, 3.855934870172249, 4.828328761552338, 5.808746197595785, 6.785477892349265, 7.826984376160694, 8.691093969388174, 9.622688077645062, 10.595291080822994, 11.660688597452824, 12.605898831366284, 13.662582168009495, 14.663769652550867, 15.662515689945868, 7.724259664401712, 6.750672763803105, 5.811387569590265, 4.883782747571509, 3.9010870850671937, 2.917271497003198, 1.9587427983485708, 2.92788466170138, 3.9228464895146944, 4.886009721626376, 5.828780489694168, 6.807771450623276, 7.756045657410739, 8.741682932088601, 9.796538397426009, 10.770363217179344, 11.757944065091037, 12.760552362308712, 13.746906122253451, 14.733461111349657, 6.853813649092397, 5.849428626955743, 4.887891345662343, 3.9372822099741467, 2.992474400235186, 1.9187901005322117, 0.9576725406891755, 1.9271637906170669, 2.9249888461649505, 3.9594053687808217, 4.938404619906374, 5.864436346806702, 6.884219019962645, 7.828034724630671, 8.767819852492108, 9.767405318422409, 10.777099788998706, 11.756844488034229, 12.79171052479121, 13.732880935984445, 5.926128015458222, 4.972759718625539, 3.9626639612780656, 2.9805463543067243, 2.043939921814862, 0.9696455222095416, 0.0, 1.0263604549029468, 2.021330880291254, 3.0509769666334376, 4.057241630906206, 5.061572818083869, 5.99249407721163, 7.0187602407975245, 7.970558892805748, 8.974108300903445, 9.987725164365974, 11.00467031355338, 11.955862648704585, 13.023633316469471], [12.921011006674375, 11.942255112930546, 10.904393946888526, 9.949397397372225, 8.899994175695674, 7.90434977913744, 6.950066892529508, 5.932998343454275, 4.967658677193728, 4.0152495951712215, 2.9721866473992904, 1.9285859832283139, 0.9986062980072676, 1.967106635885909, 2.910462856536143, 3.919785851569504, 4.971572184899867, 5.900776357771238, 6.9192447295596455, 7.877184675017752, 13.757909005320386, 12.836976628042475, 11.880641316906614, 10.890649345664892, 9.85731100127431, 8.784472761445416, 7.772039325203626, 6.737531679438151, 5.7922304570939245, 4.831665129314801, 3.899235548273674, 2.966417414460413, 1.9929633636088884, 2.9642979418836823, 3.958118397477584, 4.92588922424223, 5.990281726863499, 6.956360567334188, 7.9687455944439405, 8.836375232199712, 14.710209824051274, 13.821958811991426, 12.818312635115356, 11.787821577525575, 10.732886625987092, 9.7512294999073, 8.727777841309832, 7.752349350083479, 6.774139079802478, 5.849471354259643, 4.9258692710812415, 3.9318250291035124, 3.02222400850191, 3.9492594129441114, 4.9423767662131795, 5.865287812677409, 6.912702169504746, 7.900302858566447, 8.900146049766334, 9.732832963711342, 15.641401557029775, 14.834308686461554, 13.790003249656646, 12.7304039832762, 11.677035669020567, 10.68386253680583, 9.726971423866154, 8.800734045117759, 7.785564077230626, 6.827383017099674, 5.943129888255129, 4.893971565978806, 4.0014882672407355, 4.931015091284568, 6.005202071226428, 6.92031150574022, 7.849973264381116, 8.841461329025728, 9.768833486916314, 10.692607436419875, 16.572837238953884, 15.642245695138769, 14.706550430865036, 13.67793941211643, 12.637891198772166, 11.723837521189491, 10.679486383351493, 9.749918124567378, 8.794926772772936, 7.841877627134163, 6.872695717331939, 5.846774680264158, 5.0741083868496055, 5.886172371588382, 6.852235914539321, 7.833961934973506, 8.78746898813662, 9.734335028392065, 10.770383227586318, 11.675900220066287, 17.483233482411414, 16.53690296129257, 15.55487865894, 14.59898501862791, 13.57729738983922, 12.67993252728355, 11.632399792444506, 10.685358841359394, 9.71877101859095, 8.776044069688526, 7.813637155063954, 6.878739121419307, 6.023108204647787, 6.846399621664841, 7.779672782506975, 8.742942857579399, 9.746827365833507, 10.670173688410252, 11.613612397229993, 12.673342777743688, 18.438405763353227, 17.482862084333977, 16.48309709355686, 15.508371342957743, 14.518974022284155, 13.513756204885542, 12.588668253380844, 11.658360385258373, 10.663322135177909, 9.70242707412297, 8.870481288293744, 7.93731452517712, 6.969714748688885, 7.841681715713212, 8.773542095757824, 9.697268814143378, 10.726909449793494, 11.595192493289936, 12.54753794391971, 13.501531271921282, 18.437293358208002, 17.422162037393747, 16.439295235346737, 15.523492353925704, 14.586067549147442, 13.64666139720751, 12.80023395500897, 12.18393523152396, 11.628539401742508, 10.687394442302686, 9.853422418698283, 8.8766487403673, 7.949918582169075, 8.871351355278646, 9.699631505929963, 10.665096550208876, 11.689823500886845, 12.538210024132134, 13.48231771821206, 14.49106982634003, 17.458642624306318, 16.4872749826141, 15.509251057197226, 14.538600654402499, 13.55173590157515, 12.71406253245984, 11.78909585632658, 11.133294671304215, 11.826653551562483, 11.627417088480202, 10.78099435069315, 9.845503498654644, 8.91148387625722, 9.828288250290981, 10.725505768921337, 11.684717596148205, 12.638168478487108, 13.50544155178944, 14.441009085708505, 15.441474529875013, 16.389677926786128, 15.531041825574146, 14.558626960254447, 13.583518838648736, 12.534835741695206, 11.666653810321307, 10.816988820888636, 10.128817579361636, 10.843356697177938, 11.785422400717989, 11.7141959668578, 10.869702942649422, 9.914449755908946, 10.89057223233863, 11.719727012357927, 12.641661827515549, 13.691915073277725, 14.472321788544402, 15.481230306255725, 16.434120173661576, 15.445540928426079, 14.518470955915264, 13.485832452264482, 12.628657512043624, 11.599545195810226, 10.66540924663229, 9.75255493616421, 9.08470289996248, 9.882501803774936, 10.812454303153082, 11.710432053255712, 11.877174594699621, 10.93021325800878, 11.876670543064145, 12.741549166858526, 13.618410153382293, 14.641060236396877, 15.483248579704139, 16.473142549495286, 17.361379612388674, 14.48949015924545, 13.52384518202727, 12.558115949106991, 11.604054582772553, 10.66820394375738, 9.737910794227052, 8.756529804188085, 8.111628342896065, 8.917635119223279, 9.855996316943246, 10.76448198080185, 11.645472654168627, 11.927920389891225, 12.848558024726824, 13.737447487068435, 14.612129500352301, 15.54404401860861, 16.491856612578754, 17.547494573092166, 18.320692834437715, 13.56799985163279, 12.597684985269131, 11.570688377245343, 10.62281213314833, 9.67505916039036, 8.73086227434259, 7.75666796137616, 7.0426415609804565, 7.8604682587604655, 8.821377540206642, 9.773923627210037, 10.709393757065648, 11.634188930087893, 12.55885427547689, 13.5660258883996, 14.448246736640188, 15.363052257119069, 16.305108759276518, 17.30466615003618, 18.23686382462784, 12.652354877477597, 11.591119029943528, 10.644948440327669, 9.647385615665492, 8.771595665568196, 7.808340063449763, 6.81851706647992, 5.9997571360160125, 6.9033550695840615, 7.936889925883387, 8.853747206312264, 9.880709921251004, 10.6431604033454, 11.529746192220788, 12.49994828753871, 13.444515966182795, 14.41017851838168, 15.42543087750434, 16.429780125305566, 17.43427490700185, 11.703935824038279, 10.736411744321513, 9.695032500900224, 8.6875949695797, 7.769814859582746, 6.803959735424964, 5.849126485511973, 5.060658300146833, 5.965973592054699, 6.993334354463307, 7.910502192160189, 8.929905152785711, 9.602495412946999, 10.529696326000874, 11.548925221914182, 12.505430762186144, 13.513789425128811, 14.478051474746023, 15.460094719480601, 16.518806259489946, 10.65777269464594, 9.681782447703538, 8.750715721703958, 7.7600607803698685, 6.799821173823871, 5.770046773625769, 4.822645154655772, 4.076808593291213, 5.0224146190785195, 5.923173575025291, 6.862809870487708, 7.902495419320933, 8.660544321187732, 9.692254769457954, 10.607178244007633, 11.646900802771214, 12.612434429065722, 13.62872325804197, 14.696246587338646, 15.677061582564018, 9.657697254937787, 8.732356810004603, 7.78138948344453, 6.835435510931356, 5.82312176188514, 4.83844491803529, 3.873829444618327, 3.018226899788767, 3.9906207911688556, 4.946093429271492, 5.823574198156776, 6.865080681968206, 7.729190275195685, 8.660784383452574, 9.633387386630506, 10.698784903260336, 11.643995137173796, 12.700678473817007, 13.701865958358379, 14.70061199575338, 8.706063483768268, 7.732476583169661, 6.793191388956821, 5.865586566938065, 4.88289090443375, 3.899075316369754, 2.9358216040118648, 2.0350280146961763, 2.9609427953222056, 3.9241060274338877, 4.866876795501679, 5.845867756430788, 6.794141963218251, 7.779779237896114, 8.834634703233522, 9.808459522986857, 10.796040370898549, 11.798648668116224, 12.785002428060963, 13.771557417157169, 7.880174103995343, 6.831232446322299, 5.869695165028899, 4.919086029340703, 3.974278219601742, 2.9005939198987676, 1.9347513463524695, 0.9652600964245781, 1.9630851519724617, 2.997501674588333, 3.976500925713885, 4.902532652614213, 5.922315325770156, 6.866131030438182, 7.8059161582996195, 8.80550162422992, 9.815196094806218, 10.794940793841741, 11.829806830598722, 12.770977241791957, 6.952488470361168, 5.9991201735284845, 4.989024416181012, 4.006906809209671, 3.070300376717809, 1.9960059771124885, 1.0263604549029468, 0.0, 0.9949704253883073, 2.0246165117304913, 3.03088117600326, 4.035212363180923, 4.966133622308684, 5.992399785894579, 6.944198437902802, 7.9477478460004995, 8.961364709463028, 9.978309858650434, 10.929502193801639, 11.997272861566525], [11.926040581286069, 10.94728468754224, 9.909423521500218, 8.954426971983917, 7.9050237503073655, 6.909379353749132, 5.9550964671412, 4.938027918065967, 3.9900562150221583, 3.037647132999652, 1.9945841852277213, 0.9509835210567451, 1.8809632062777912, 2.8914247659197905, 3.834780986570024, 4.844103981603385, 5.895890314933748, 6.825094487805119, 7.843562859593527, 8.801502805051634, 12.808079144118064, 11.859374165870905, 10.903038854735044, 9.913046883493323, 8.87970853910274, 7.806870299273847, 6.794436863032057, 5.759929217266581, 4.814627994922356, 3.8540626671432325, 2.9216330861021054, 1.9888149522888443, 2.8753202718794117, 3.8886160719175638, 4.882436527511466, 5.850207354276111, 6.91459985689738, 7.880678697368069, 8.893063724477823, 9.83134565758802, 13.760379962848953, 12.844356349819856, 11.840710172943787, 10.810219115354005, 9.755284163815523, 8.77362703773573, 7.7501753791382635, 6.77474688791191, 5.79653661763091, 4.8718688920880755, 3.9482668089096733, 2.9542225669319437, 3.9045809167724332, 4.873577542977992, 5.86669489624706, 6.78960594271129, 7.8370202995386276, 8.82462098860033, 9.824464179800218, 10.727803389099648, 14.691571695827454, 13.856706224289987, 12.812400787485078, 11.752801521104633, 10.699433206849, 9.706260074634262, 8.749368961694586, 7.823131582946189, 6.8079616150590585, 5.849780554928106, 4.96552742608356, 3.9163691038072375, 4.883845175511259, 5.855333221318449, 6.929520201260308, 7.844629635774101, 8.774291394414998, 9.76577945905961, 10.693151616950196, 11.671812398772387, 15.623007377751561, 14.664643232967201, 13.728947968693468, 12.700336949944862, 11.660288736600599, 10.746235059017923, 9.701883921179924, 8.772315662395808, 7.817324310601369, 6.864275164962595, 5.89509325516037, 4.86917221809259, 5.896569848338044, 6.8104905016222625, 7.776554044573202, 8.758280065007387, 9.711787118170502, 10.658653158425947, 11.6947013576202, 12.625445677074065, 16.533403621209093, 15.559300499121, 14.577276196768432, 13.621382556456343, 12.599694927667652, 11.70233006511198, 10.654797330272936, 9.707756379187826, 8.741168556419382, 7.798441607516958, 6.836034692892386, 5.901136659247739, 6.8455696661362255, 7.770717751698722, 8.703990912540856, 9.66726098761328, 10.671145495867389, 11.594491818444133, 12.537930527263875, 13.604753752848248, 17.488575902150906, 16.505259622162406, 15.505494631385291, 14.530768880786173, 13.541371560112585, 12.536153742713973, 11.611065791209274, 10.680757923086805, 9.685719673006341, 8.724824611951401, 7.8928788261221765, 6.9597120630055525, 7.792176210177323, 8.737257640778854, 9.697492535662745, 10.62158694417726, 11.651227579827376, 12.519510623323818, 13.471856073953592, 14.425849401955164, 18.360953454087994, 17.406071898536148, 16.423205096489138, 15.460769800459607, 14.49214355231284, 13.549682784972395, 12.613592181036404, 11.664699310430516, 10.65093693957094, 9.709791980131119, 8.875819956526716, 7.899046278195732, 8.772380043657513, 9.732235773902216, 10.623581945834884, 11.589414680242758, 12.614141630920727, 13.462528154166016, 14.406635848245942, 15.415387956373912, 18.453613049694624, 17.482245408002406, 16.504221482585532, 15.533571079790805, 14.546706326963456, 13.709032957848146, 12.784066281714889, 11.867378441791608, 10.880387501653338, 10.649814626308634, 9.847422230379658, 8.911931378341151, 9.73394533774566, 10.689172668914551, 11.649456208826258, 12.608668036053126, 13.562118918392029, 14.429759681823322, 15.365327215742386, 16.39914567948592, 17.384648352174434, 16.526012250962452, 15.553597385642753, 14.578489264037042, 13.529806167083512, 12.661624235709613, 11.811959246276944, 10.954367778076762, 9.897090647268794, 10.839156350808844, 10.780623846544307, 9.93613082233593, 10.736911217397385, 11.71303369382707, 12.643677452262848, 13.56561226742047, 14.615865513182646, 15.396639918578284, 16.405548436289607, 17.390730194215543, 16.440511353814387, 15.51344138130357, 14.480802877652788, 13.62362793743193, 12.594515621198532, 11.660379672020596, 10.747525361552517, 9.910253098677606, 8.936235753865791, 9.866188253243937, 10.764166003346567, 10.943602474386129, 11.75267471949722, 12.699132004552585, 13.63850436974411, 14.542360593287214, 15.565010676301798, 16.40756670973802, 17.397460679529168, 18.31798963294264, 15.484460584633757, 14.518815607415576, 13.553086374495297, 12.59902500816086, 11.663174369145686, 10.732881219615358, 9.751500229576394, 8.93717854161119, 7.971369069314134, 8.909730267034101, 9.818215930892706, 10.699206604259482, 11.674341571541063, 12.573616824516074, 13.515242325450261, 14.558890488501676, 15.448529812246191, 16.341892870533314, 17.403129798141542, 18.31418755551366, 14.562970277021096, 13.592655410657438, 12.56565880263365, 11.617782558536636, 10.670029585778666, 9.725832699730896, 8.751638386764467, 7.870593734835278, 6.914202208851321, 7.875111490297497, 8.827657577300892, 9.763127707156503, 10.684359068885572, 11.609024414274568, 12.61619602719728, 13.498416875437867, 14.413222395916748, 15.355278898074198, 16.354836288833862, 17.28703396342552, 13.647325302865903, 12.586089455331834, 11.639918865715975, 10.642356041053798, 9.766566090956504, 8.80331048883807, 7.813487491868227, 6.9494826674436885, 5.957089019674917, 6.990623875974242, 7.903917345109942, 8.930880060048683, 9.693330542143078, 10.579916331018467, 11.550118426336388, 12.494686104980474, 13.46034865717936, 14.475601016302019, 15.479950264103246, 16.48444504579953, 12.698906249426587, 11.731382169709821, 10.690002926288532, 9.682565394968007, 8.764785284971053, 7.7989301608132715, 6.84409691090028, 6.052526585538414, 5.019707542145554, 6.044248032157433, 6.960672330957868, 7.980075291583389, 8.652665551744677, 9.579866464798553, 10.59909536071186, 11.555600900983823, 12.56395956392649, 13.528221613543701, 14.51026485827828, 15.568976398287626, 11.652743120034248, 10.676752873091846, 9.745686147092266, 8.755031205758174, 7.794791599212178, 6.765017199014075, 5.817615580044079, 5.068676878682794, 4.076148569169374, 4.973343713822969, 5.912980009285387, 6.952665558118611, 7.71071445998541, 8.742424908255632, 9.657348382805312, 10.697070941568892, 11.6626045678634, 12.67889339683965, 13.746416726136324, 14.727231721361697, 10.652667680326093, 9.727327235392911, 8.776359908832838, 7.830405936319664, 6.818092187273448, 5.833415343423598, 4.868799870006634, 4.010095185180347, 3.04435474125971, 3.9962635680691703, 4.873744336954455, 5.915250820765885, 6.779360413993364, 7.710954522250253, 8.683557525428185, 9.748955042058014, 10.694165275971475, 11.750848612614686, 12.752036097156058, 13.75078213455106, 9.701033909156575, 8.727447008557968, 7.788161814345128, 6.860556992326372, 5.877861329822057, 4.894045741758061, 3.9307920294001724, 3.026896300087757, 2.011112934119884, 2.974276166231566, 3.917046934299358, 4.896037895228467, 5.844312102015929, 6.829949376693793, 7.8848048420312, 8.858629661784535, 9.846210509696228, 10.848818806913902, 11.835172566858642, 12.821727555954848, 8.875144529383652, 7.826202871710607, 6.864665590417207, 5.91405645472901, 4.969248644990049, 3.895564345287075, 2.929721771740777, 1.9602305218128855, 1.01325529077014, 2.0476718133860112, 3.0266710645115626, 3.9527027914118906, 4.972485464567834, 5.91630116923586, 6.856086297097297, 7.8556717630275985, 8.865366233603897, 9.84511093263942, 10.8799769693964, 11.821147380589636, 7.947458895749476, 6.9940905989167925, 5.98399484156932, 5.001877234597979, 4.065270802106117, 2.9909764025007957, 2.021330880291254, 0.9949704253883073, 0.0, 1.029646086342184, 2.0359107506149523, 3.040241937792615, 3.971163196920376, 4.9974293605062705, 5.949228012514494, 6.9527774206121915, 7.96639428407472, 8.983339433262127, 9.934531768413333, 11.00230243617822], [10.896394494943882, 9.917638601200053, 8.879777435158033, 7.9247808856417326, 6.875377663965181, 5.879733267406947, 4.925450380799015, 3.9083818317237835, 2.971077905175645, 2.0186688231531384, 1.0392599209035083, 1.980629607398929, 2.910609292619975, 3.921070852261974, 4.864427072912208, 5.8737500679455685, 6.925536401275932, 7.854740574147303, 8.87320894593571, 9.831148891393816, 11.800883191531613, 10.8435893571616, 9.887254046025738, 8.897262074784017, 7.8985029633658765, 6.853562410976996, 5.879340212263107, 4.844832566497631, 3.899531344153405, 3.0410484312974133, 2.108618850256286, 3.018461038631028, 3.9049663582215954, 4.918262158259747, 5.912082613853649, 6.8798534406182945, 7.944245943239563, 8.910324783710251, 9.922709810820006, 10.860991743930205, 12.776813892945627, 11.848663096649238, 10.918663356164087, 9.888172298574306, 8.833237347035823, 7.851580220956031, 6.8350787283693135, 5.85965023714296, 4.881439966861959, 4.058854656242255, 3.135252573063854, 3.9838686532741274, 4.934227003114617, 5.903223629320176, 6.896340982589244, 7.819252029053474, 8.86666638588081, 9.854267074942513, 10.854110266142401, 11.757449475441833, 13.708005625924129, 12.911464441482241, 11.897304136716128, 10.837704870335683, 9.78433655608005, 8.791163423865312, 7.834272310925636, 6.908034932177239, 5.932965495047637, 5.036766319082286, 4.160721582222109, 4.946015190149421, 5.9134912618534425, 6.8849793076606325, 7.959166287602493, 8.874275722116284, 9.803937480757181, 10.795425545401793, 11.722797703292379, 12.70145848511457, 14.639441307848235, 13.74954658219825, 12.813851317924518, 11.785240299175912, 10.745192085831649, 9.831138408248973, 8.786787270410974, 7.857219011626858, 6.942328190589947, 6.051260929116775, 5.090287411298919, 5.898818304434773, 6.926215934680227, 7.840136587964446, 8.806200130915386, 9.787926151349572, 10.741433204512685, 11.68829924476813, 12.724347443962383, 13.655091763416248, 15.557429088203685, 14.64420384835205, 13.662179545999482, 12.706285905687393, 11.684598276898702, 10.78723341434303, 9.739700679503986, 8.888242295973422, 7.9317670966516625, 6.98904014774924, 6.0892349675799124, 6.930782745589922, 7.875215752478408, 8.800363838040907, 9.73363699888304, 10.696907073955463, 11.700791582209572, 12.624137904786316, 13.567576613606057, 14.634399839190431, 16.512601369145496, 15.590162971393458, 14.590397980616341, 13.615672230017223, 12.626274909343635, 11.621057091945023, 10.695969140440324, 9.871356463319085, 8.876318213238621, 7.915423152183683, 7.151588834958628, 7.989358149347735, 8.821822296519507, 9.766903727121036, 10.727138622004928, 11.651233030519442, 12.680873666169559, 13.549156709666, 14.501502160295775, 15.455495488297347, 17.384978921082585, 16.490975247767196, 15.508108445720186, 14.545673149690657, 13.57704690154389, 12.634586134203445, 11.698495530267454, 10.855297850662797, 9.841535479803222, 8.9003905203634, 8.21905957916304, 8.928692364537914, 9.802026129999698, 10.7618818602444, 11.653228032177067, 12.61906076658494, 13.64378771726291, 14.492174240508199, 15.436281934588125, 16.445034042716095, 18.304738721682714, 17.416176549286572, 16.438152623869698, 15.530564849213862, 14.579516026595558, 13.567184998951115, 12.709633628949843, 11.820455925742252, 10.833464985603982, 9.840413166540916, 9.198161270345288, 9.941577464683334, 10.763591424087842, 11.718818755256736, 12.679102295168441, 13.63831412239531, 14.591765004734212, 15.459405768165505, 16.39497330208457, 17.4287917658281, 18.414294438516617, 17.518663338187586, 16.504416192607803, 15.523263110049722, 14.474580013096192, 13.606398081722293, 12.756733092289624, 11.820637681497892, 10.763360550689924, 10.097631602427832, 10.131362886509937, 10.965776908678112, 11.766557303739567, 12.742679780169253, 13.67332353860503, 14.595258353762652, 15.645511599524829, 16.426286004920467, 17.43519452263179, 18.420376280557726, 17.47015744015657, 16.543087467645755, 15.510448963994973, 14.56840178344461, 13.539289467211212, 12.605153518033276, 11.692299207565197, 10.776523002098736, 9.802505657286922, 9.10956447536572, 9.877141841971184, 10.800993255616385, 11.696118690765934, 12.569529773173343, 13.508902138364869, 14.503217723631185, 15.466425080153828, 16.37452637040252, 17.364420340193668, 18.29752624455729, 16.51410667097594, 15.54846169375776, 14.582732460837482, 13.612954774896382, 12.607948215158366, 11.677655065628038, 10.696274075589074, 9.803448445032322, 8.837638972735265, 8.153106489155885, 8.931191769517323, 9.812182442884097, 10.698411558883489, 11.597642291510665, 12.539267792444852, 13.582915955496267, 14.472555279240781, 15.365918337527905, 16.427155265136133, 17.33821302250825, 15.59261636336328, 14.622301496999622, 13.595304888975834, 12.64742864487882, 11.614803431791346, 10.670606545743576, 9.696412232777147, 8.736863638256409, 7.780472112272451, 7.118487712419281, 7.940633415925508, 8.876103545781119, 9.708384535880164, 10.633049881269159, 11.64022149419187, 12.522442342432457, 13.437247862911338, 14.379304365068789, 15.378861755828453, 16.311059430420112, 14.676971389208088, 13.615735541674018, 12.66956495205816, 11.672002127395983, 10.796212177298688, 9.816899570840496, 8.827076573870652, 7.815752570864819, 6.823358923096047, 6.143022963085086, 6.927942812104533, 7.954905527043273, 8.71735600913767, 9.603941798013057, 10.574143893330978, 11.518711571975064, 12.48437412417395, 13.499626483296609, 14.503975731097839, 15.508470512794121, 13.72855233576877, 12.761028256052004, 11.719649012630715, 10.712211481310192, 9.794431371313237, 8.828576247155455, 7.873742997242464, 6.9191269162717575, 5.8859774455666845, 5.068273499152024, 5.984697797952459, 7.00410075857798, 7.676691018739269, 8.603891931793143, 9.623120827706453, 10.579626367978415, 11.587985030921082, 12.552247080538294, 13.534290325272872, 14.593001865282218, 12.682389206376431, 11.70639895943403, 10.77533223343445, 9.784677292100358, 8.824437685554361, 7.794663285356259, 6.847261666386263, 5.935277209416138, 4.9424184725905045, 3.99736918081756, 4.937005476279978, 5.976691025113203, 6.7347399269800015, 7.766450375250223, 8.681373849799904, 9.721096408563485, 10.686630034857991, 11.70291886383424, 12.770442193130915, 13.743665651458372, 11.682313766668278, 10.756973321735094, 9.80600599517502, 8.860052022661847, 7.847738273615631, 6.863061429765781, 5.898445956348818, 4.9731003624872985, 4.000706471107209, 3.0202890350637617, 3.8977698039490463, 4.939276287760476, 5.803385880987955, 6.734979989244844, 7.707582992422776, 8.772980509052605, 9.718190742966065, 10.774874079609276, 11.776061564150648, 12.767216064647734, 10.73067999549876, 9.757093094900153, 8.817807900687312, 7.890203078668556, 6.907507416164241, 5.923691828100245, 4.960438115742356, 4.038036925031289, 3.022253559063415, 1.9983016332261574, 2.9410724012939493, 3.920063362223058, 4.868337569010521, 5.853974843688384, 6.908830309025792, 7.875063591881211, 8.862644439792902, 9.865252737010577, 10.851606496955316, 11.838161486051522, 9.904790615725837, 8.85584895805279, 7.89431167675939, 6.943702541071194, 5.998894731332233, 4.925210431629258, 3.9593678580829605, 2.989876608155069, 2.042901377112324, 1.0716972803806029, 2.0506965315061545, 2.9767282584064825, 3.98891939466451, 4.932735099332536, 5.872520227193974, 6.872105693124275, 7.881800163700572, 8.861544862736094, 9.896410899493075, 10.83758131068631, 8.97710498209166, 8.023736685258976, 7.013640927911504, 6.031523320940162, 5.0949168884483, 4.02062248884298, 3.050976966633438, 2.0246165117304913, 1.029646086342184, 0.0, 1.0062646642727684, 2.0105958514504314, 2.941517110578192, 3.967783274164087, 4.9195819261723095, 5.923131334270007, 6.936748197732536, 7.953693346919942, 8.904885682071146, 9.972656349836033], [9.890129830671116, 8.911373936927287, 7.873512770885264, 6.918516221368964, 5.869112999692413, 4.873468603134179, 3.919185716526247, 2.902117167451015, 1.9648132409028765, 1.0124041588803703, 2.0455245851762767, 2.9868942716716975, 3.9168739568927435, 4.927335516534743, 5.870691737184977, 6.880014732218338, 7.931801065548701, 8.861005238420072, 9.87947361020848, 10.837413555666586, 10.794618527258844, 9.837324692888831, 8.88098938175297, 7.890997410511249, 6.892238299093108, 5.8472977467042275, 4.873075547990338, 3.8385679022248627, 2.893266679880637, 2.051455010979148, 2.9838845920202752, 3.9167027258335363, 4.9112310224943645, 5.924526822532516, 6.918347278126419, 7.886118104891064, 8.950510607512333, 9.916589447983021, 10.928974475092776, 11.867256408202975, 11.77054922867286, 10.84239843237647, 9.912398691891319, 8.881907634301538, 7.826972682763055, 6.845315556683262, 5.828814064096545, 4.853385572870192, 3.87517530258919, 3.0692612359239906, 4.003629545374872, 4.882110340476635, 5.9192336449235565, 6.909488293592945, 7.902605646862013, 8.825516693326243, 9.87293105015358, 10.860531739215283, 11.86037493041517, 12.762792205487981, 12.70174096165136, 11.905199777209473, 10.89103947244336, 9.831440206062915, 8.778071891807281, 7.784898759592544, 6.828007646652868, 5.901770267904471, 4.926700830774868, 4.047172898764021, 5.029098554533127, 5.8442568773519294, 6.893073029631036, 7.8912439719334015, 8.96543095187526, 9.880540386389054, 10.810202145029951, 11.801690209674563, 12.729062367565149, 13.70772314938734, 13.633176643575467, 12.743281917925483, 11.80758665365175, 10.778975634903144, 9.73892742155888, 8.824873743976205, 7.780522606138206, 6.85095434735409, 5.936063526317178, 5.06166750879851, 5.958664383609937, 6.797059991637282, 7.824457621882735, 8.846401252237216, 9.812464795188156, 10.794190815622342, 11.747697868785455, 12.6945639090409, 13.730612108235153, 14.661356427689018, 14.617525397446844, 13.637939184079283, 12.655914881726714, 11.700021241414625, 10.678333612625934, 9.780968750070262, 8.733436015231218, 7.881977631700654, 6.942173676333398, 5.999446727430975, 6.95761193989093, 7.829024432792431, 8.773457439680916, 9.786037043508047, 10.735129682456305, 11.69839975752873, 12.70228426578284, 13.630402569059086, 14.573841277878827, 15.640664503463201, 15.572697678388655, 14.58389830712069, 13.584133316343573, 12.609407565744455, 11.620010245070867, 10.614792427672255, 9.689704476167556, 8.88054238388858, 7.886724792920356, 6.925829731865418, 7.958064144398663, 8.887599836550244, 9.720063983722014, 10.665145414323543, 11.625380309207435, 12.590594852309483, 13.620235487959599, 14.55542137393877, 15.507766824568545, 16.46176015257012, 16.45732208463883, 15.48471058349443, 14.501843781447418, 13.539408485417889, 12.570782237271121, 11.628321469930677, 10.692230865994686, 9.865704430344532, 8.851942059484957, 7.910797100045135, 8.917683598242208, 9.826934051740423, 10.700267817202205, 11.660123547446908, 12.551469719379574, 13.558422588374981, 14.58314953905295, 15.498438904780969, 16.442546598860893, 17.45129870698886, 17.37708188523896, 16.409911885013805, 15.431887959596931, 14.524300184941094, 13.57325136232279, 12.560920334678347, 11.703368964677075, 10.830862505423987, 9.843871565285717, 8.850819746222651, 9.805948312090255, 10.741439164128762, 11.661833111290349, 12.617060442459243, 13.577343982370948, 14.536555809597816, 15.490006691936719, 16.459302345147872, 17.401237966357336, 18.435056430100868, 18.408280631627957, 17.45909738757741, 16.444850241997624, 15.479382000694857, 14.590151522202733, 13.60832905681688, 12.67547600011502, 11.835339597366566, 10.821091237956626, 9.879025534416575, 10.003195775173213, 10.911613080697832, 11.784225356422011, 12.627971247455102, 13.603067456421712, 14.552309213054173, 15.487913406829223, 16.44084722806111, 17.433592202891944, 18.297128846840636, 18.444226524913027, 17.517156552402216, 16.484518048751433, 15.523428866622979, 14.49431655038958, 13.560180601211645, 12.647326290743564, 11.731550085277101, 10.757532740465287, 9.927483510633513, 8.980290015002428, 9.904141428647632, 10.768461854322176, 11.641872936729587, 12.581245301921113, 13.575560887187429, 14.538768243710072, 15.446869533958763, 16.43676350374991, 17.369869408113537, 17.4881757557324, 16.52253077851422, 15.556801545593942, 14.567981858074749, 13.562975298336733, 12.632682148806406, 11.65130115876744, 10.758475528210687, 9.79266605591363, 8.971025524423677, 8.034339942548566, 8.915330615915344, 9.770754722439731, 10.669985455066909, 11.611610956001096, 12.655259119052511, 13.544898442797026, 14.438261501084149, 15.499498428692375, 16.410556186064497, 16.56668544811974, 15.596370581756082, 14.569373973732294, 13.62149772963528, 12.569830514969713, 11.625633628921943, 10.651439315955514, 9.691890721434776, 8.735499195450817, 7.936406747687073, 7.043781588956754, 7.979251718812365, 8.780727699436406, 9.705393044825403, 10.712564657748114, 11.594785505988702, 12.509591026467582, 13.451647528625033, 14.451204919384697, 15.383402593976358, 15.682314119254237, 14.621078271720167, 13.674907682104308, 12.677344857442131, 11.767147533167753, 10.771926654018865, 9.78210365704902, 8.770779654043187, 7.778386006274414, 6.960941998352878, 6.031090985135778, 7.0580537000745185, 7.789699172693914, 8.676284961569301, 9.646487056887223, 10.591054735531308, 11.556717287730194, 12.571969646852853, 13.576318894654081, 14.580813676350363, 14.733895065814918, 13.766370986098153, 12.724991742676863, 11.71755421135634, 10.76820021568438, 9.802345091526599, 8.847511841613606, 7.874153999450125, 6.841004528745051, 6.023300582330392, 5.087845970983704, 6.093275423153997, 6.749034182295512, 7.676235095349386, 8.695463991262695, 9.651969531534657, 10.660328194477325, 11.624590244094536, 12.606633488829114, 13.66534502883846, 13.68773193642258, 12.711741689480178, 11.780674963480598, 10.790020022146507, 9.82978041560051, 8.800006015402408, 7.836127386920327, 6.8903042925945055, 5.897445555768872, 4.952396263995928, 4.040153649311223, 5.06586568968922, 5.807083090536245, 6.838793538806466, 7.753717013356146, 8.793439572119727, 9.758973198414235, 10.775262027390484, 11.842785356687159, 12.737400987185604, 12.687656496714427, 11.762316051781243, 10.811348725221169, 9.865394752707996, 8.85308100366178, 7.86840415981193, 6.887311676882882, 5.928127445665666, 4.955733554285577, 3.9753161182421293, 3.0009179769802907, 4.01161945131672, 4.875729044544198, 5.807323152801088, 6.77992615597902, 7.845323672608849, 8.79053390652231, 9.84721724316552, 10.848404727706892, 11.760951400374966, 11.736022725544908, 10.762435824946301, 9.82315063073346, 8.895545808714704, 7.912850146210389, 6.929034558146394, 5.962205871562465, 4.993064008209656, 3.977280642241783, 2.953328716404525, 2.0442205743251938, 2.9924065257793018, 3.940680732566764, 4.926318007244627, 5.926847671221746, 6.868798927608442, 7.856379775520133, 8.858988072737809, 9.845341832682548, 10.831896821778754, 10.911055279998607, 9.862113622325559, 8.900576341032158, 7.949967205343962, 7.005159395605001, 5.931475095902027, 4.965632522355729, 3.9961412724278373, 3.0491660413850923, 2.0267243635589702, 1.0477251124334186, 1.9737568393337468, 2.982654730391741, 3.926470435059767, 4.8662555629212045, 5.865841028851506, 6.875535499427803, 7.855280198463325, 8.890146235220307, 9.831316646413542, 9.98336964636443, 9.030001349531746, 8.019905592184273, 7.037787985212931, 6.101181552721068, 5.026887153115748, 4.057241630906207, 3.0308811760032595, 2.0359107506149523, 1.0062646642727684, 0.0, 1.0043311871776628, 1.9352524463054235, 2.9615186098913187, 3.9133172618995418, 4.916866669997239, 5.930483533459768, 6.947428682647174, 7.898621017798378, 8.966391685563265], [8.885798643493453, 7.907042749749624, 6.869181583707602, 5.914185034191302, 4.86478181251475, 3.8691374159565157, 2.914854529348584, 1.897785980273352, 0.9827942595504812, 1.9352033415729872, 2.978266289344918, 3.9912254588493603, 4.921205144070407, 5.9316667037124065, 6.87502292436264, 7.884345919396001, 8.936132252726363, 9.865336425597734, 10.883804797386142, 11.841744742844249, 9.790287340081182, 8.832993505711169, 7.876658194575309, 6.886666223333586, 5.887907111915446, 4.842966559526564, 3.8910565666379426, 2.8565489208724673, 1.9112476985282414, 2.871813026307365, 3.8042426073484923, 4.737060741161753, 5.789799419999758, 6.836574226732745, 7.883103133195945, 8.890449292068727, 9.954841794689996, 10.920920635160684, 11.933305662270438, 12.819400732746494, 10.766218041495195, 9.838067245198808, 8.908067504713655, 7.877576447123874, 6.822641495585391, 5.840984369505599, 4.8467950827441495, 3.8713665915177957, 2.893156321236795, 3.8896192512522076, 4.823987560703088, 5.702468355804852, 6.739591660251773, 7.7891762212418625, 8.78229357451093, 9.796572317039814, 10.843986673867152, 11.831587362928854, 12.831430554128742, 13.643786197819038, 11.697409774473696, 10.900868590031811, 9.909020491090963, 8.849421224710518, 7.796052910454885, 6.802879778240148, 5.845988665300472, 4.919751286552076, 3.944681849422473, 4.867530914092238, 5.849456569861344, 6.664614892680145, 7.713431044959251, 8.760099004727811, 9.834285984669672, 10.760328980637016, 11.69101436018362, 12.682502424828233, 13.609874582718819, 14.58853536454101, 12.628845456397803, 11.761262936573086, 10.825567672299353, 9.796956653550748, 8.756908440206486, 7.84285476262381, 6.798503624785811, 5.868935366001695, 4.954044544964783, 5.8820255241267265, 6.779022398938154, 7.617418006965497, 8.64481563721095, 9.675484549115874, 10.641548092066813, 11.623274112500999, 12.628510083939124, 13.57537612419457, 14.611424323388823, 15.542168642842688, 13.61319421026918, 12.655920202726886, 11.673895900374319, 10.71800226006223, 9.69631463127354, 8.798949768717867, 7.751417033878822, 6.899958650348259, 5.995207421968517, 6.8198047427591915, 7.777969955219147, 8.649382448120646, 9.593815455009132, 10.606395058836263, 11.555487697784521, 12.518757772856945, 13.522642281111054, 14.511214784212756, 15.454653493032497, 16.52147671861687, 14.568366491210991, 13.601879325768293, 12.602114334991176, 11.627388584392058, 10.63799126371847, 9.632773446319858, 8.70768549481516, 7.898523402536185, 6.939758538555475, 7.746187747193635, 8.77842215972688, 9.70795785187846, 10.54042199905023, 11.485503429651759, 12.44573832453565, 13.410952867637699, 14.440593503287815, 15.43623358909244, 16.388579039722213, 17.342572367723786, 15.486252623169227, 14.502691602142033, 13.519824800095021, 12.557389504065492, 11.588763255918725, 10.64630248857828, 9.71021188464229, 8.932477264254358, 7.945265142315756, 8.731155115373353, 9.738041613570426, 10.647292067068639, 11.52062583253042, 12.480481562775124, 13.37182773470779, 14.378780603703197, 15.403507554381166, 16.379251119934636, 17.32335881401456, 18.33211092214253, 16.406012423769358, 15.427892903661409, 14.449868978244535, 13.542281203588697, 12.591232380970393, 11.57890135332595, 10.721349983324679, 9.983117824474103, 9.007701525613708, 9.671177761550869, 10.626306327418472, 11.078446896845021, 11.816121774604136, 12.728446279156813, 13.6262192383887, 14.53818398295191, 15.491634865290813, 16.436658003346466, 17.393321803045584, 18.318705029157595, 17.426261650275556, 16.477078406225008, 15.462831260645226, 14.49736301934246, 13.608132540850336, 12.626310075464483, 11.693457018762624, 10.987594916416683, 9.990998379998253, 10.699383549744793, 10.884189767504266, 10.054247452850243, 10.813155894952411, 11.6569017859855, 12.63199799495211, 13.581239751584569, 14.51684394535962, 15.469777766591505, 16.46252274142234, 17.326059385371032, 18.323556006422464, 17.48964927588389, 16.535625768635192, 15.470035925555754, 14.543423086735316, 13.6275546391535, 12.75789090348705, 11.948362048773994, 10.951853273401255, 10.808477502964566, 9.86128400733348, 9.046775800800043, 9.797392392852576, 10.670803475259985, 11.610175840451511, 12.604491425717827, 13.567698782240468, 14.47580007248916, 15.465694042280306, 16.398799946643933, 18.369169748063456, 17.403524770845276, 16.437795537925, 15.448975850405805, 14.44396929066779, 13.513676141137463, 12.532295151098497, 11.639469520541743, 10.673660048244686, 9.85201951675473, 8.91533393487962, 8.057964988067756, 8.799685260970131, 9.698915993597307, 10.640541494531494, 11.684189657582909, 12.573828981327422, 13.467192039614545, 14.528428967222771, 15.439486724594891, 17.4476794404508, 16.47736457408714, 15.45036796606335, 14.502491721966337, 13.45082450730077, 12.506627621253, 11.53243330828657, 10.572884713765832, 9.616493187781874, 8.817400740018126, 7.924775581287807, 7.121886090964776, 7.809658237966806, 8.7343235833558, 9.741495196278512, 10.623716044519098, 11.538521564997978, 12.48057806715543, 13.480135457915093, 14.412333132506754, 16.563308111585293, 15.502072264051224, 14.555901674435365, 13.558338849773188, 12.648141525498808, 11.65292064634992, 10.663097649380076, 9.651773646374242, 8.65937999860547, 7.841935990683931, 6.912084977466831, 6.160593146879482, 6.818629711224313, 7.705215500099699, 8.67541759541762, 9.619985274061705, 10.58564782626059, 11.60090018538325, 12.605249433184479, 13.609744214880761, 15.614889058145975, 14.64736497842921, 13.60598573500792, 12.598548203687397, 11.649194208015434, 10.683339083857652, 9.72850583394466, 8.755147991781179, 7.721998521076106, 6.904294574661446, 5.968839963314758, 5.122205961684395, 5.777964720825911, 6.705165633879785, 7.724394529793093, 8.680900070065055, 9.689258733007723, 10.653520782624934, 11.635564027359512, 12.678283329245453, 14.568725928753636, 13.592735681811234, 12.661668955811654, 11.671014014477564, 10.710774407931567, 9.681000007733463, 8.717121379251381, 7.771298284925559, 6.778439548099926, 5.8333902563269815, 4.921147641642277, 4.094796228219618, 4.836013629066644, 5.867724077336865, 6.782647551886544, 7.822370110650125, 8.76912530950837, 9.785414138484619, 10.847824258009384, 11.73306980000794, 13.568650489045483, 12.6433100441123, 11.692342717552226, 10.746388745039052, 9.734074995992836, 8.749398152142986, 7.768305669213936, 6.80912143799672, 5.836727546616631, 4.856310110573183, 3.8819119693113446, 3.0405499898471176, 3.9046595830745967, 4.8362536913314855, 5.8088566945094176, 6.8554757837029845, 7.800686017616444, 8.857369354259655, 9.850279091472885, 10.756620213197301, 12.617016717875964, 11.643429817277358, 10.704144623064517, 9.776539801045761, 8.793844138541445, 7.8100285504774485, 6.84319986389352, 5.87405800054071, 4.858274634572837, 3.834322708735579, 2.9252145666562477, 2.0213370643096997, 2.969611271097162, 3.955248545775025, 4.922516484044083, 5.864467740430778, 6.85204858834247, 7.854656885560145, 8.841010645504884, 9.82756563460109, 11.863199604542126, 10.8059322839515, 9.8443950026581, 8.893785866969903, 7.948978057230943, 6.8752937575279685, 5.909451183981671, 4.939959934053779, 3.9421348785058954, 2.907718355890024, 1.9287191047644723, 1.0026873778641443, 1.9783235432140784, 2.922139247882104, 3.8619243757435417, 4.8615098416738425, 5.87120431225014, 6.850949011285662, 7.885815048042643, 8.826985459235878, 10.98770083354209, 10.034332536709407, 9.024236779361933, 8.042119172390592, 7.105512739898731, 6.03121834029341, 5.061572818083869, 4.035212363180922, 3.040241937792615, 2.0105958514504314, 1.0043311871776628, 0.0, 0.9309212591277607, 1.9571874227136556, 2.908986074721879, 3.9125354828195764, 4.926152346282105, 5.9430974954695115, 6.894289830620716, 7.962060498385602], [7.954877384365693, 6.976121490621863, 5.938260324579841, 4.983263775063541, 3.9338605533869893, 2.938216156828755, 1.9839332702208234, 0.9668647211455913, 1.913715518678242, 2.866124600700748, 3.9091875484726786, 4.922146717977121, 5.8521264031981675, 6.862587962840167, 7.805944183490401, 8.815267178523762, 9.867053511854124, 10.796257684725495, 11.814726056513903, 12.77266600197201, 8.859366080953421, 7.902072246583409, 6.945736935447548, 5.9557449642058256, 4.956985852787684, 3.912045300398804, 3.0263992887475046, 1.995990065532431, 2.842168957656002, 3.802734285435126, 4.7351638664762525, 5.667982000289514, 6.720720679127519, 7.767495485860506, 8.814024392323706, 9.821370551196487, 10.885763053817756, 11.851841894288444, 12.864226921398199, 13.750321991874255, 9.835296782367434, 8.907145986071047, 7.977146245585894, 6.946655187996114, 5.891720236457631, 4.9100631103778385, 3.9862362274041128, 3.0108077361777594, 3.8240775803645555, 4.820540510379969, 5.75490881983085, 6.633389614932613, 7.670512919379534, 8.720097480369624, 9.713214833638693, 10.727493576167575, 11.774907932994912, 12.762508622056615, 13.762351813256503, 14.574707456946797, 10.766488515345936, 9.96994733090405, 8.987071633453095, 7.954981111947074, 6.90161279769144, 5.908439665476703, 4.985429809960435, 4.05919243121204, 4.875603108550234, 5.798452173219999, 6.7803778289891055, 7.595536151807906, 8.644352304087011, 9.69102026385557, 10.76520724379743, 11.691250239764774, 12.621935619311378, 13.61342368395599, 14.540795841846576, 15.519456623668766, 11.697924197270043, 10.866822823809642, 9.93112755953591, 8.902516540787303, 7.86246832744304, 6.948414649860365, 5.9379447694457745, 5.008376510661659, 5.884965804092544, 6.812946783254488, 7.7099436580659155, 8.548339266093258, 9.57573689633871, 10.606405808243634, 11.572469351194574, 12.55419537162876, 13.559431343066882, 14.506297383322327, 15.54234558251658, 16.473089901970447, 12.68227295114142, 11.761480089963442, 10.779455787610873, 9.823562147298784, 8.801874518510093, 7.937491626248579, 6.890858178538786, 6.039399795008222, 6.926128681096277, 7.750726001886953, 8.708891214346908, 9.580303707248406, 10.524736714136893, 11.537316317964024, 12.486408956912282, 13.449679031984706, 14.453563540238815, 15.442136043340513, 16.385574752160252, 17.452397977744628, 13.63744523208323, 12.710502111136993, 11.710737120359877, 10.736011369760758, 9.74661404908717, 8.772214590979823, 7.847126639475124, 7.0379645471961485, 7.870679797683236, 8.677109006321396, 9.709343418854642, 10.63887911100622, 11.47134325817799, 12.41642468877952, 13.376659583663411, 14.34187412676546, 15.371514762415575, 16.367154848220196, 17.31950029884997, 18.273493626851543, 14.556475523935395, 13.611314387510733, 12.628447585463721, 11.666012289434192, 10.697386041287425, 9.785743633238246, 8.849653029302255, 8.071918408914321, 8.876186401443515, 9.662076374501114, 10.668962872698186, 11.5782133261964, 11.847909969458449, 12.755606074935317, 13.716620035180236, 14.628087799840467, 15.538949871067164, 16.474112431769942, 17.41822012584987, 18.400240164558916, 15.476235324535526, 14.536515689030109, 13.558491763613235, 12.650903988957397, 11.730673525630358, 10.718342497985915, 9.860791127984644, 9.122558969134067, 9.938622784741467, 10.60209902067863, 11.557227586546233, 11.780709082027325, 10.886344675370305, 11.798669179922982, 12.696442139154868, 13.608406883718079, 14.561857766056981, 15.506880904112636, 16.463544703811753, 17.388927929923764, 16.53488443564426, 15.58570119159371, 14.571454046013926, 13.60598580471116, 12.747573685510302, 11.765751220124448, 10.83289816342259, 10.127036061076646, 10.921919639126012, 11.630304808872554, 11.694430788735405, 10.756509638032547, 9.88337879571858, 10.727124686751669, 11.702220895718279, 12.651462652350737, 13.587066846125788, 14.540000667357674, 15.53274564218851, 16.3962822861372, 17.393778907188633, 16.598272061252594, 15.644248554003891, 14.578658710924454, 13.682864231395282, 12.766995783813465, 11.897332048147016, 11.171150740475802, 11.882774532529014, 11.703241255952527, 10.67152502856462, 9.749037985982348, 8.867615293618744, 9.741026376026154, 10.68039874121768, 11.674714326483995, 12.637921683006637, 13.546022973255328, 14.535916943046475, 15.469022847410102, 18.340912300553327, 17.55982354017859, 16.571965057161382, 15.626821561433882, 14.650611996607521, 13.694494236218704, 12.89335718012314, 12.144225297542217, 11.604581307372447, 10.746783269742691, 9.725574956110759, 8.76022717325006, 7.869908161736299, 8.769138894363476, 9.710764395297662, 10.754412558349077, 11.64405188209359, 12.537414940380714, 13.59865186798894, 14.50970962536106, 18.37860069957856, 17.4082858332149, 16.38128922519111, 15.433412981094097, 14.38174576642853, 13.43754888038076, 12.463354567414331, 11.503805972893593, 10.547414446909634, 9.712164493006087, 8.759618406002692, 7.824148276147081, 6.879881138732974, 7.804546484121969, 8.81171809704468, 9.693938945285266, 10.608744465764147, 11.550800967921598, 12.550358358681262, 13.482556033272923, 17.494229370713054, 16.432993523178983, 15.486822933563122, 14.489260108900945, 13.579062784626569, 12.58384190547768, 11.594018908507836, 10.582694905502002, 9.59030125773323, 8.752767514229413, 7.822916501012314, 6.881997410833712, 5.8888526119904805, 6.775438400865868, 7.745640496183789, 8.690208174827873, 9.655870727026759, 10.671123086149418, 11.675472333950648, 12.67996711564693, 16.545810317273734, 15.578286237556968, 14.536906994135679, 13.529469462815154, 12.580115467143195, 11.614260342985412, 10.65942709307242, 9.68606925090894, 8.652919780203867, 7.835215833789206, 6.87967148686024, 5.843610225638625, 4.8481876215920785, 5.775388534645953, 6.794617430559262, 7.751122970831224, 8.759481633773891, 9.723743683391103, 10.705786928125681, 11.747362070117692, 15.499647187881395, 14.523656940938993, 13.592590214939413, 12.60193527360532, 11.641695667059324, 10.611921266861222, 9.648042638379142, 8.702219544053321, 7.709360807227687, 6.764311515454742, 5.852068900770037, 4.8514052444127795, 3.906236529832811, 4.9379469781030325, 5.852870452652713, 6.892593011416293, 7.838204050380611, 8.85449287935686, 9.916902998881623, 10.802148540880179, 14.499571748173242, 13.574231303240058, 12.623263976679985, 11.677310004166811, 10.664996255120595, 9.680319411270744, 8.699226928341696, 7.740042697124481, 6.7676488057443915, 5.787231369700944, 4.812833228439105, 3.944640253992029, 2.9748824838407644, 3.9064765920976536, 4.879079595275586, 5.924554524575225, 6.869764758488685, 7.926448095131896, 8.919357832345124, 9.82569895406954, 13.547937977003723, 12.574351076405117, 11.635065882192276, 10.70746106017352, 9.724765397669204, 8.740949809605208, 7.77412112302128, 6.804979259668471, 5.789195893700597, 4.76524396786334, 3.8561358257840084, 2.9522583234374604, 2.0398341718633297, 3.0254714465411925, 3.9915952249163227, 4.9335464813030185, 5.92112732921471, 6.923735626432385, 7.910089386377124, 8.896644375473329, 12.794120863669887, 11.736853543079262, 10.77531626178586, 9.824707126097664, 8.879899316358703, 7.806215016655729, 6.84037244310943, 5.870881193181539, 4.873056137633656, 3.838639615017785, 2.859640363892233, 1.933608636991905, 1.0474022840863177, 1.9912179887543435, 2.931003116615781, 3.9305885825460822, 4.94028305312238, 5.920027752157902, 6.954893788914883, 7.8960642001081185, 11.918622092669853, 10.96525379583717, 9.955158038489696, 8.973040431518355, 8.036433999026492, 6.962139599421171, 5.99249407721163, 4.966133622308683, 3.971163196920376, 2.941517110578192, 1.9352524463054235, 0.9309212591277607, 0.0, 1.026266163585895, 1.978064815594118, 2.9816142236918153, 3.995231087154344, 5.01217623634175, 5.963368571492955, 7.031139239257842], [6.928611220779798, 5.949855327035968, 4.911994160993945, 3.9569976114776457, 2.9075943898010945, 1.9353554221669098, 1.0540736638582422, 1.9931308847314861, 2.9399816822641367, 3.8923907642866427, 4.935453712058573, 5.948412881563016, 6.878392566784062, 7.888854126426062, 8.832210347076295, 9.841533342109656, 10.893319675440019, 11.82252384831139, 12.840992220099798, 13.798932165557904, 7.833099917367527, 6.875806082997514, 5.919470771861652, 4.92947880061993, 3.9307196892017897, 2.909184565736959, 2.096539682384923, 3.0222562291183257, 3.868435121241897, 4.82900044902102, 5.761430030062147, 6.694248163875408, 7.746986842713413, 8.7937616494464, 9.8402905559096, 10.847636714782382, 11.912029217403651, 12.87810805787434, 13.890493084984094, 14.77658815546015, 8.826607828312103, 7.880879822485152, 6.97428551092405, 5.943794453334269, 4.888859501795786, 3.9072023757159937, 3.0916782418230877, 4.037073899763654, 4.85034374395045, 5.846806673965863, 6.781174983416744, 7.659655778518507, 8.69677908296543, 9.746363643955519, 10.739480997224588, 11.75375973975347, 12.801174096580807, 13.78877478564251, 14.788617976842398, 15.600973620532693, 9.759506205801014, 8.943681167318156, 7.9842108987912495, 6.95212037728523, 5.898752063029596, 4.905578930814858, 4.09087182437941, 5.0854585947979345, 5.901869272136128, 6.824718336805892, 7.806643992574999, 8.6218023153938, 9.670618467672906, 10.717286427441465, 11.791473407383325, 12.717516403350668, 13.648201782897273, 14.639689847541884, 15.56706200543247, 16.54572278725466, 10.69094188772512, 9.863962089147797, 8.928266824874065, 7.899655806125459, 6.859607592781195, 5.945553915198521, 5.057808932759564, 5.98737719154368, 6.911231967678439, 7.839212946840381, 8.73620982165181, 9.574605429679153, 10.602003059924606, 11.632671971829529, 12.598735514780468, 13.580461535214654, 14.585697506652776, 15.532563546908221, 16.568611746102473, 17.499356065556338, 11.675290641596497, 10.758619355301594, 9.776595052949027, 8.820701412636938, 7.799013783848248, 6.9346308915867345, 6.010722341852576, 6.986594474605108, 7.952394844682172, 8.776992165472846, 9.735157377932802, 10.606569870834301, 11.551002877722787, 12.563582481549918, 13.512675120498177, 14.4759451955706, 15.47982970382471, 16.468402206926406, 17.411840915746147, 18.478664141330523, 12.630462922538308, 11.707641376475147, 10.70787638569803, 9.733150635098912, 8.743753314425325, 7.87946005530557, 6.966990802788914, 7.933849403654697, 8.89694596126913, 9.70337516990729, 10.735609582440535, 11.665145274592115, 12.497609421763885, 13.258058155960907, 13.936226825216655, 14.874742745230124, 15.780691131484675, 16.6153737305802, 17.567719181209974, 18.521712509211547, 13.61501713655701, 12.608453652848887, 11.625586850801875, 10.663151554772346, 9.694525306625579, 8.905607796552037, 7.969517192616045, 8.945601181803156, 9.90245256502941, 10.688342538087007, 11.69522903628408, 12.604479489782294, 12.751296128874003, 12.228388516395473, 13.010137415044516, 13.906915009164626, 14.817777080391323, 15.672356199738001, 16.61646389381793, 17.572385539475373, 14.593667870458694, 13.533654954368263, 12.555631028951389, 11.648043254295551, 10.728856954197871, 9.838206661299706, 8.980655291298433, 9.950900412354061, 10.937891352492331, 11.628365184264522, 12.583493750132126, 12.684095241442877, 11.789730834785857, 11.271451621383138, 11.984263152053142, 12.887234093042238, 13.84068497538114, 14.705124672080695, 15.661788471779813, 16.56107330484022, 15.53202370098241, 14.582840456931864, 13.56859331135208, 12.603125070049314, 11.745757114077815, 10.885615383438239, 9.952762326736378, 10.95537750429664, 11.921188206876876, 12.656570972458447, 12.597816948150957, 11.6598957974481, 10.786764955134132, 10.199907128211825, 10.990041908616552, 11.930289861674897, 12.785310614093847, 13.738244435325733, 14.73098941015657, 15.568427661053656, 16.476160699342458, 15.595411326590746, 14.641387819342045, 13.575797976262608, 12.681047659962795, 11.886859947127256, 11.017196211460805, 11.985061964534765, 12.882043100279878, 12.606627415368079, 11.574911187980172, 10.6524241453979, 9.771001453034296, 9.21380881748631, 9.968219754115953, 10.953541535808153, 11.836165450974695, 12.744266741223386, 13.734160711014534, 14.64116822232656, 17.432211468523086, 16.556962805516743, 15.569104322499536, 14.623960826772038, 13.648795425175035, 12.814358399532495, 12.013221343436928, 12.95813652160118, 12.630847470958338, 11.650169429158243, 10.62896111552631, 9.663613332665612, 8.773294321151852, 8.241921335823632, 8.972321433906044, 9.959822188838144, 10.842295650061649, 11.735658708348772, 12.770797242905397, 13.681855000277517, 18.426367695988365, 17.48312300227488, 16.553079520493277, 15.605203276396262, 14.641940208542055, 13.821406919416958, 13.013083186248855, 12.530072136479484, 11.573680610495526, 10.61555065242164, 9.663004565418245, 8.727534435562633, 7.783267298148526, 7.277328925582125, 8.045583611925428, 8.892182713253325, 9.806988233732206, 10.749044735889656, 11.72250373359772, 12.65470140818938, 18.520495534298952, 17.45925968676488, 16.51308909714902, 15.515526272486843, 14.60532894821246, 13.610108069063571, 12.620285072093727, 11.608961069087893, 10.616567421319122, 9.656153673644965, 8.726302660427866, 7.785383570249264, 6.792238771406033, 6.248220842326024, 6.979506011064537, 7.888451942795933, 8.854114494994818, 9.833898510125197, 10.761784073948522, 11.676483469511389, 17.57207648085963, 16.604552401142865, 15.563173157721575, 14.555735626401052, 13.606381630729086, 12.640526506571305, 11.685693256658313, 10.712335414494833, 9.67918594378976, 8.847238731384993, 7.783057646275792, 6.746996385054177, 5.751573781007631, 5.248170976106109, 5.968189998346506, 6.924695538618468, 7.845793373771767, 8.810055423388977, 9.792098668123556, 10.740379760572772, 16.525913351467292, 15.54992310452489, 14.61885637852531, 13.628201437191219, 12.667961830645222, 11.638187430447118, 10.674308801965037, 9.728485707639214, 8.73562697081358, 7.790577679040637, 6.794476952661556, 5.754791403828332, 4.809622689248363, 4.1990173827831665, 5.026443020439957, 5.9579638448165495, 6.831221740835687, 7.847510569811937, 8.909920689336701, 9.795166231335257, 15.525837911759139, 14.600497466825955, 13.649530140265881, 12.703576167752708, 11.691262418706492, 10.706585574856641, 9.725493091927591, 8.766308860710375, 7.793914969330286, 6.813497533286839, 5.82718290165055, 4.848026413407581, 3.8782686432563165, 3.144407292357757, 4.05265216306283, 4.917572215030302, 5.862782448943761, 6.919465785586972, 7.912375522800201, 8.818716644524619, 14.57420414058962, 13.600617239991013, 12.661332045778172, 11.733727223759416, 10.7510315612551, 9.767215973191105, 8.800387286607176, 7.831245423254366, 6.815462057286492, 5.791510131449234, 4.870485498995453, 3.891494538066344, 2.943220331278882, 2.078860247562446, 2.9846129153714003, 3.9265641717580957, 4.914145019669787, 5.916753316887462, 6.903107076832201, 7.889662065928407, 13.820387027255782, 12.763119706665156, 11.801582425371755, 10.850973289683559, 9.906165479944598, 8.832481180241624, 7.866638606695325, 6.897147356767434, 5.89932230121955, 4.86490577860368, 3.8859065274781277, 2.9598748005777997, 1.9507884435018696, 1.0069727388338436, 1.9240208070708584, 2.9236062730011594, 3.9333007435774574, 4.9130454426129795, 5.94791147936996, 6.889081890563196, 12.944888256255748, 11.991519959423064, 10.98142420207559, 9.99930659510425, 9.062700162612387, 7.988405763007066, 7.0187602407975245, 5.992399785894578, 4.9974293605062705, 3.967783274164087, 2.9615186098913187, 1.9571874227136556, 1.026266163585895, 0.0, 0.9517986520082231, 1.9553480601059203, 2.968964923568449, 3.985910072755855, 4.9371024079070605, 6.004873075671947], [5.9768125687715745, 4.998056675027746, 3.9601955089857226, 3.005198959469423, 1.9557957377928714, 0.9835567701586866, 1.9378396567666183, 2.9449295367397093, 3.8917803342723603, 4.844189416294866, 5.887252364066796, 6.900211533571239, 7.830191218792286, 8.840652778434285, 9.784008999084518, 10.79333199411788, 11.845118327448242, 12.774322500319613, 13.792790872108021, 14.750730817566128, 6.881301265359304, 5.924007430989291, 4.96767211985343, 3.9776801486117073, 2.978921037193567, 1.9573859137287355, 2.9698193499705257, 3.9740548811265493, 4.82023377325012, 5.780799101029244, 6.713228682070371, 7.646046815883632, 8.698785494721637, 9.745560301454624, 10.792089207917824, 11.799435366790606, 12.863827869411875, 13.829906709882563, 14.842291736992317, 15.692319015630392, 7.874809176303881, 6.9290811704769295, 6.022486858915826, 4.991995801326045, 3.9370608497875623, 2.95540372370777, 3.96495790940869, 4.9403864006350435, 5.802142395958674, 6.798605325974086, 7.732973635424967, 8.61145443052673, 9.648577734973653, 10.698162295963742, 11.691279649232811, 12.705558391761695, 13.752972748589032, 14.740573437650735, 15.740416628850623, 16.516704480702934, 8.807707553792788, 7.991882515309933, 7.032412246783026, 6.000321725277006, 4.946953411021372, 3.9537802788066343, 4.910671391746311, 5.939705767385081, 6.853667924144352, 7.776516988814116, 8.758442644583223, 9.573600967402024, 10.62241711968113, 11.669085079449689, 12.743272059391549, 13.669315055358894, 14.600000434905498, 15.59148849955011, 16.518860657440694, 17.47647895341147, 9.739143235716895, 8.912163437139572, 7.97646817286584, 6.947857154117235, 5.907808940772972, 4.993755263190296, 5.877608500126465, 6.807176758910581, 7.817843236251439, 8.791011598848606, 9.688008473660034, 10.526404081687376, 11.553801711932831, 12.584470623837754, 13.550534166788694, 14.53226018722288, 15.537496158661002, 16.484362198916447, 17.5204103981107, 18.451154717564563, 10.723491989588272, 9.806820703293372, 8.824796400940803, 7.868902760628714, 6.8472151318400245, 5.98283223957851, 6.830521909219477, 7.806394041972009, 8.772981864740453, 9.715708813642877, 10.67811572826745, 11.558368522842525, 12.502801529731013, 13.515381133558144, 13.978297486459281, 14.877270049785878, 15.812769157033838, 16.588593883451658, 17.5320325922714, 18.558352475424506, 11.678664270530083, 10.755842724466923, 9.756077733689807, 8.781351983090689, 7.791954662417102, 6.927661403297345, 7.786790370155814, 8.753648971021597, 9.717532981327413, 10.64209181807732, 11.674326230610566, 12.60749299372719, 13.44940807377211, 13.944663068092323, 12.984428173208432, 13.922944093221899, 14.82889247947645, 15.663575078571975, 16.615920529201748, 17.56991385720332, 12.663218484548784, 11.656655000840665, 10.673788198793654, 9.711352902764125, 8.742726654617357, 7.990898463398658, 8.789316759982945, 9.765400749170055, 10.723039585087692, 11.627059186257037, 12.63394568445411, 13.54682720891737, 13.65633067296423, 12.948615463403849, 12.058338763036293, 12.9551163571564, 13.865978428383098, 14.720557547729777, 15.664665241809704, 16.620586887467148, 13.641869218450468, 12.581856302360041, 11.603832376943167, 10.69624460228733, 9.77705830218965, 8.923497328146327, 9.800454858665335, 10.770699979720963, 11.757690919859233, 12.567081832434553, 13.522210398302157, 13.589129785533107, 12.694765378876085, 11.991678568391514, 11.032464500044918, 11.935435441034013, 12.888886323372915, 13.753326020072471, 14.70998981977159, 15.609274652831997, 14.580225048974189, 13.631041804923642, 12.616794659343858, 11.651326418041092, 10.793958462069593, 9.97090605028486, 10.77256189410328, 11.775177071663542, 12.740987774243777, 13.595287620628477, 13.502851492241186, 12.564930341538329, 11.69179949922436, 10.9201340752202, 10.038243256608329, 10.978491209666672, 11.833511962085623, 12.78644578331751, 13.779190758148346, 14.616629009045434, 15.524362047334238, 14.643612674582524, 13.689589167333823, 12.623999324254386, 11.729249007954573, 10.972150613973877, 11.836995778827706, 12.804861531901667, 13.70184266764678, 13.511661959458309, 12.479945732070401, 11.55745868948813, 10.676035997124524, 9.934035764494686, 9.01642110210773, 10.00174288379993, 10.884366798966472, 11.792468089215163, 12.78236205900631, 13.689369570318338, 16.480412816514868, 15.605164153508522, 14.617305670491314, 13.672162174763816, 12.696996773166813, 11.899649066379116, 12.83302091080383, 13.777936088968081, 13.538661338420857, 12.555203973248473, 11.53399565961654, 10.568647876755842, 9.67832886524208, 8.962148282832008, 8.02052278189782, 9.00802353682992, 9.890496998053425, 10.783860056340549, 11.818998590897175, 12.730056348269295, 17.474569043980146, 16.531324350266658, 15.601280868485054, 14.65340462438804, 13.690141556533833, 12.90669758626358, 13.832882753615756, 13.437886003942003, 12.481494477958044, 11.520585196511869, 10.568039109508474, 9.632568979652863, 8.688301842238754, 8.027017537630336, 7.093784959917205, 7.940384061245101, 8.855189581723982, 9.797246083881433, 10.770705081589497, 11.702902756181158, 18.526771039010505, 17.500022187041214, 16.553851597425354, 15.628831141870878, 14.71324608498918, 13.845134264396632, 13.53601593226397, 12.524691929258136, 11.532298281489364, 10.561188217735195, 9.631337204518095, 8.690418114339494, 7.697273315496261, 6.997909454374234, 6.027707359056313, 6.936653290787709, 7.902315842986595, 8.882099858116973, 9.8099854219403, 10.724684817503164, 18.487807341029868, 17.520283261313104, 16.478904017891814, 15.471466486571291, 14.522112490899328, 13.556257366741548, 12.601424116828555, 11.628066274665075, 10.594916803960002, 9.752273275475222, 8.68809219036602, 7.652030929144406, 6.656608325097859, 6.073835266603694, 5.016391346338282, 5.972896886610244, 6.893994721763543, 7.858256771380755, 8.840300016115334, 9.788581108564546, 17.44164421163753, 16.46565396469513, 15.534587238695549, 14.543932297361458, 13.583692690815461, 12.553918290617357, 11.590039662135277, 10.644216567809456, 9.651357830983823, 8.706308539210879, 7.699511496751785, 6.65982594791856, 5.714657233338592, 5.033741520018909, 4.074644368431733, 5.006165192808326, 5.879423088827464, 6.895711917803713, 7.958122037328477, 8.843367579327033, 16.44156877192938, 15.516228326996194, 14.56526100043612, 13.619307027922947, 12.60699327887673, 11.62231643502688, 10.641223952097832, 9.682039720880615, 8.709645829500527, 7.72922839345708, 6.73221744574078, 5.7530609574978095, 4.7833031873465455, 4.049441836447986, 3.1008535110546065, 3.9657735630220783, 4.910983796935538, 5.967667133578749, 6.960576870791978, 7.866917992516394, 15.489935000759859, 14.516348100161252, 13.577062905948411, 12.649458083929655, 11.66676242142534, 10.682946833361344, 9.716118146777415, 8.746976283424607, 7.731192917456734, 6.707240991619476, 5.775520043085683, 4.796529082156574, 3.8482548753691113, 2.9838947916526752, 2.0328142633631767, 2.974765519749872, 3.9623463676615636, 4.964954664879239, 5.951308424823978, 6.937863413920184, 14.736117887426024, 13.678850566835399, 12.717313285541998, 11.766704149853801, 10.82189634011484, 9.748212040411866, 8.782369466865568, 7.812878216937676, 6.815053161389793, 5.780636638773921, 4.80163738764837, 3.875605660748042, 2.855822987592099, 1.912007282924073, 0.9722221550626353, 1.9718076209929363, 2.981502091569234, 3.9612467906047564, 4.996112827361737, 5.937283238554972, 13.89668690826397, 12.943318611431286, 11.933222854083812, 10.951105247112471, 10.014498814620609, 8.94020441501529, 7.970558892805748, 6.944198437902801, 5.949228012514494, 4.91958192617231, 3.9133172618995418, 2.908986074721879, 1.978064815594118, 0.9517986520082231, 0.0, 1.0035494080976972, 2.0171662715602263, 3.0341114207476325, 3.9853037558988373, 5.053074423663724], [4.973263160673877, 3.994507266930048, 2.956646100888025, 2.0016495513717256, 0.9522463296951741, 1.9871061782563837, 2.9413890648643157, 3.9484789448374067, 4.895329742370057, 5.847738824392564, 6.890801772164494, 7.903760941668936, 8.833740626889982, 9.844202186531982, 10.787558407182216, 11.796881402215577, 12.84866773554594, 13.77787190841731, 14.796340280205719, 15.754280225663825, 5.877751857261606, 4.920458022891593, 3.964122711755732, 2.97413074051401, 1.9753716290958696, 2.9609353218264327, 3.973368758068223, 4.977604289224247, 5.823783181347817, 6.784348509126941, 7.716778090168068, 8.649596223981328, 9.702334902819333, 10.74910970955232, 11.79563861601552, 12.802984774888303, 13.867377277509572, 14.83345611798026, 15.845841145090015, 16.69586842372809, 6.8712597682061825, 5.925531762379231, 5.030438636524385, 4.000094835854643, 2.9451598843161606, 3.9268170103959528, 4.95026866899342, 5.925697160219774, 6.805691804056371, 7.802154734071784, 8.736523043522665, 9.615003838624428, 10.65212714307135, 11.70171170406144, 12.694829057330509, 13.709107799859392, 14.75652215668673, 15.744122845748432, 16.74396603694832, 17.520253888800635, 7.811099169970466, 6.9883331072122346, 6.040364024391585, 5.014713659061598, 4.006733038599171, 4.925193565494817, 5.882084678434493, 6.911119054073263, 7.857217332242049, 8.780066396911813, 9.76199205268092, 10.577150375499722, 11.625966527778827, 12.672634487547386, 13.746821467489246, 14.672864463456591, 15.603549843003195, 16.595037907647807, 17.52241006553839, 18.48002836150917, 8.742534851894574, 7.926555370924164, 6.990860106650432, 5.962249087901827, 4.96758856835077, 5.96516854987848, 6.849021786814648, 7.778590045598763, 8.789256522939622, 9.794561006946303, 10.691557881757731, 11.529953489785074, 12.557351120030528, 13.588020031935452, 14.554083574886391, 15.045422602367617, 15.930119558176175, 16.604659150625984, 17.575094237923963, 18.505838557377828, 9.72688360576595, 8.866600330871169, 7.884576028518602, 6.9286823882065125, 5.906994759417823, 6.9318817925176415, 7.801935195907659, 8.777807328660192, 9.744395151428636, 10.68712210033106, 11.649529014955633, 12.561917930940222, 13.50635093782871, 14.518930541655841, 14.868914871383069, 13.972252608274566, 14.897367490034522, 15.6688204906078, 16.61225919942754, 17.638579082580648, 10.682055886707762, 9.815622352044722, 8.815857361267605, 7.841131610668487, 6.8517342899949005, 7.856952107393513, 8.758203656843996, 9.725062257709778, 10.688946268015595, 11.613505104765503, 12.645739517298749, 13.578906280415373, 14.452957481869808, 14.83528045301611, 13.87504555813222, 13.017926651710587, 13.913490812477134, 14.743801685728116, 15.69614713635789, 16.650140464359463, 11.666610100726462, 10.716434628418462, 9.73356782637145, 8.771132530341921, 7.8025062821951545, 8.785805512216776, 9.721896116152767, 10.697980105339877, 11.694452871775875, 12.59847247294522, 13.605358971142293, 14.518240495605552, 14.659880081061925, 13.839232848327637, 12.94895614796008, 12.050098915645089, 12.950576761383783, 13.800784154885918, 14.744891848965844, 15.645334703433871, 12.645260834628147, 11.641635929937838, 10.663612004520964, 9.756024229865126, 8.836837929767446, 9.718404376964445, 10.733034214835156, 11.703279335890784, 12.690270276029054, 13.538495119122736, 14.49362368499034, 14.592679193630802, 13.69831478697378, 12.882295953315301, 11.923081884968706, 11.030417999522701, 11.9734846563736, 12.833552627228611, 13.79021642692773, 14.63402246879872, 13.640004676551985, 12.690821432501439, 11.676574286921655, 10.71110604561889, 9.85373808964739, 10.765813099102978, 11.705141250273101, 12.707756427833363, 13.673567130413598, 14.56670090731666, 14.506400900338882, 13.568479749636024, 12.695348907322055, 11.810751460143988, 10.928860641532117, 10.07347376815536, 10.913738569241763, 11.86667239047365, 12.859417365304484, 13.641376825012157, 14.584141674912035, 13.70339230216032, 12.74936879491162, 11.683778951832183, 10.78902863553237, 11.723164584710306, 12.694048626038635, 13.661914379112595, 14.634422023816601, 14.515211367556004, 13.483495140168097, 12.561008097585825, 11.67958540522222, 10.824653149418474, 9.907038487031517, 9.096725442288616, 9.964593406122612, 10.872694696371301, 11.862588666162448, 12.71411738628506, 15.540192444092662, 14.664943781086318, 13.67708529806911, 12.731941802341613, 11.75677640074461, 12.650663037115544, 13.690073758014758, 14.63498893617901, 14.542210746518553, 13.558753381346168, 12.537545067714236, 11.572197284853537, 10.681878273339775, 9.852765667755795, 8.911140166821609, 8.103006095318607, 8.970723605209566, 9.864086663496687, 10.843746406863898, 11.754804164236019, 16.534348671557943, 15.591103977844456, 14.66106049606285, 13.713184251965837, 12.74992118411163, 13.657711557000006, 14.631905869966435, 14.441435412039699, 13.48504388605574, 12.524134604609564, 11.57158851760617, 10.636118387750559, 9.69185125033645, 8.975513706494503, 7.9844023448409915, 7.035366619733787, 7.935416188880121, 8.877472691037571, 9.79545289755622, 10.727650572147882, 17.586550666588302, 16.55980181461901, 15.61363122500315, 14.688610769448674, 13.773025712566977, 14.59614823513306, 14.539565340361667, 13.528241337355833, 12.535847689587062, 11.564737625832892, 10.634886612615793, 9.693967522437191, 8.700822723593957, 7.946405623238401, 6.97620352792048, 6.031635849276395, 6.982542450142734, 7.906847674083695, 8.834733237907022, 9.72807643368084, 18.540376553805906, 17.614693815718034, 16.62573251733613, 15.648401415534465, 14.774806518552428, 14.559806774839245, 13.604973524926253, 12.631615682762773, 11.5984662120577, 10.75582268357292, 9.691641598463718, 8.655580337242103, 7.660157733195556, 7.0289006511677155, 5.971456730902304, 5.06787944509893, 5.918742537730265, 6.883004587347476, 7.865047832082055, 8.791972724742223, 18.445193619735235, 17.469203372792833, 16.53813664679325, 15.547481705459159, 14.587242098913162, 13.557467698715058, 12.593589070232976, 11.647765975907154, 10.65490723908152, 9.709857947308576, 8.703060904849481, 7.663375356016257, 6.718206641436288, 5.988806904582931, 5.029709752995755, 4.030913008775047, 4.904170904794185, 5.920459733770435, 6.961513653506154, 7.84675919550471, 17.44511818002708, 16.519777735093896, 15.568810408533821, 14.622856436020648, 13.610542686974432, 12.625865843124581, 11.644773360195531, 10.685589128978314, 9.713195237598226, 8.732777801554779, 7.735766853838475, 6.756610365595506, 5.786852595444242, 5.02852189879656, 4.055918895618628, 2.990521378988799, 3.9357316129022593, 4.99241494954547, 5.963968486969655, 6.870309608694071, 16.49348440885756, 15.519897508258953, 14.580612314046112, 13.653007492027356, 12.67031182952304, 11.686496241459045, 10.719667554875116, 9.750525691522306, 8.734742325554432, 7.710790399717173, 6.7790694511833784, 5.80007849025427, 4.851804283466808, 3.9874441997503727, 3.033564162386611, 1.9995133357165928, 2.987094183628284, 3.98970248084596, 4.954700041001655, 5.94125503009786, 15.739667295523722, 14.682399974933096, 13.720862693639695, 12.770253557951499, 11.825445748212537, 10.751761448509564, 9.785918874963265, 8.816427625035374, 7.81860256948749, 6.784186046871619, 5.805186795746067, 4.879155068845739, 3.859372395689796, 2.91555669102177, 1.9757715631603325, 0.9965554369596568, 2.0062499075359543, 2.985994606571477, 3.999504443539414, 4.94067485473265, 14.900236316361667, 13.946868019528983, 12.93677226218151, 11.954654655210168, 11.018048222718306, 9.943753823112987, 8.974108300903445, 7.947747846000498, 6.952777420612191, 5.923131334270007, 4.916866669997239, 3.912535482819576, 2.9816142236918153, 1.9553480601059203, 1.0035494080976972, 0.0, 1.0136168634625289, 2.030562012649935, 2.98175434780114, 4.049525015566027], [3.959646297211348, 2.980890403467519, 1.9430292374254967, 0.988032687909197, 1.9658631931577029, 3.000723041718913, 3.9550059283268446, 4.962095808299936, 5.908946605832586, 6.8613556878550925, 7.904418635627023, 8.917377805131464, 9.84735749035251, 10.857819049994509, 11.801175270644743, 12.810498265678104, 13.862284599008467, 14.791488771879838, 15.809957143668246, 16.767897089126354, 4.864134993799077, 3.9068411594290637, 2.950505848293203, 1.960513877051481, 2.9889884925583985, 3.974552185288962, 4.986985621530752, 5.991221152686776, 6.837400044810346, 7.79796537258947, 8.730394953630597, 9.663213087443857, 10.715951766281862, 11.762726573014849, 12.809255479478049, 13.81660163835083, 14.8809941409721, 15.847072981442787, 16.85945800855254, 17.709485287190624, 5.857642904743654, 4.911914898916702, 4.0168217730618565, 2.9883355337337716, 3.9587767477786895, 4.940433873858482, 5.963885532455949, 6.939314023682303, 7.8193086675189, 8.815771597534312, 9.750139906985194, 10.628620702086957, 11.66574400653388, 12.715328567523969, 13.708445920793038, 14.72272466332192, 15.770139020149257, 16.75773970921096, 17.757582900410846, 18.533870752263162, 6.797482306507937, 5.974716243749706, 5.026747160929056, 4.002954356940727, 5.0203499020616995, 5.938810428957346, 6.895701541897022, 7.924735917535792, 8.870834195704578, 9.793683260374342, 10.77560891614345, 11.59076723896225, 12.639583391241356, 13.686251351009915, 14.760438330951775, 15.686481326919118, 15.89211474630696, 16.703321641015094, 17.612736479252693, 18.513630805399522, 7.728917988432044, 6.914796068803293, 5.979100804529561, 4.950489785780956, 5.981205431813299, 6.978785413341009, 7.862638650277177, 8.792206909061292, 9.802873386402151, 10.80817787040883, 11.70517474522026, 12.543570353247603, 13.570967983493055, 14.601636895397979, 15.567700438348918, 15.869554094890164, 14.954619022551457, 15.629158615001268, 16.599593702299245, 17.53033802175311, 8.713266742303421, 7.889667667055943, 6.907643364703375, 5.951749724391286, 6.920611622880352, 7.94549865598017, 8.815552059370189, 9.79142419212272, 10.758012014891165, 11.700738963793588, 12.663145878418161, 13.575534794402751, 14.519967801291237, 15.532547405118368, 15.751482778143416, 14.796384100797113, 13.921866954409804, 14.693319954983082, 15.636758663802823, 16.66307854695593, 9.668439023245233, 8.902608101850722, 7.902843111073606, 6.940754877707611, 7.865351153457429, 8.870568970856043, 9.771820520306527, 10.738679121172309, 11.702563131478124, 12.627121968228032, 13.659356380761277, 14.592523143877902, 15.466574345332335, 15.717848359776458, 14.757613464892566, 13.842058144233134, 12.937990276852416, 13.768301150103397, 14.720646600733172, 15.674639928734743, 10.652993237263933, 9.836084456340668, 8.853217654293656, 7.987392865281958, 8.816123145657684, 9.799422375679304, 10.735512979615295, 11.711596968802406, 12.708069735238404, 13.612089336407749, 14.618975834604822, 15.53185735906808, 15.633973017073892, 14.721800755087983, 13.831524054720427, 12.874230408167636, 11.975076225759064, 12.8252836192612, 13.769391313341126, 14.669834167809153, 11.631643971165618, 10.761285757860044, 9.78326183244317, 8.972284564805163, 9.850454793229977, 10.732021240426974, 11.746651078297685, 12.716896199353313, 13.703887139491583, 14.552111982585265, 15.507240548452868, 15.606296057093331, 14.672407722985746, 13.764863860075648, 12.805649791729053, 11.854549492045248, 10.997984120748882, 11.858052091603893, 12.814715891303011, 13.658521933174002, 12.700608668685808, 11.810471260423645, 10.796224114843861, 9.927366380558926, 10.86735495310992, 11.779429962565507, 12.71875811373563, 13.721373291295892, 14.687183993876127, 15.580317770779189, 15.52001776380141, 14.582096613098553, 13.66944184333402, 12.693319366904335, 11.811428548292463, 10.897605260677906, 9.938238033617045, 10.891171854848931, 11.883916829679768, 12.66587628938744, 13.644745667045857, 12.823042130082527, 11.869018622833826, 10.90003928677222, 11.8026454989949, 12.736781448172836, 13.707665489501165, 14.675531242575126, 15.64803888727913, 15.528828231018533, 14.497112003630626, 13.574624961048354, 12.672985349162808, 11.70722105617882, 10.789606393791864, 9.920856934811164, 8.989092870497894, 9.897194160746585, 10.887088130537732, 11.738616850660343, 14.600796436226485, 13.784593609008525, 12.796735125991317, 11.948202137281648, 12.77039326420714, 13.664279900578075, 14.70369062147729, 15.64860579964154, 15.555827609981081, 14.572370244808697, 13.551161931176765, 12.585814148316066, 11.695495136802304, 10.735333574516142, 9.793708073581955, 8.927137587841155, 7.995223069584848, 8.88858612787197, 9.86824587123918, 10.7793036286113, 15.594952663691764, 14.710753805766663, 13.784162697852965, 12.929444586905872, 13.76353804757416, 14.671328420462537, 15.645522733428965, 15.455052275502227, 14.498660749518269, 13.537751468072093, 12.585205381068699, 11.649735251213087, 10.705468113798979, 9.859234926443786, 8.86697025160134, 7.917934526494135, 6.959915653255404, 7.901972155412855, 8.819952361931502, 9.752150036523163, 16.647154658722123, 15.682904016409124, 14.736733426793265, 13.90487110438871, 14.786642576029507, 15.60976509859559, 15.553182203824194, 14.54185820081836, 13.549464553049589, 12.57835448929542, 11.64850347607832, 10.707584385899718, 9.714439587056486, 8.830126843187685, 7.859924747869764, 6.915357069225679, 6.007041914518017, 6.931347138458978, 7.859232702282304, 8.714459570218313, 17.600980545939727, 16.737796017508145, 15.748834719126242, 14.8646617504745, 15.788423382014958, 15.573423638301772, 14.61859038838878, 13.6452325462253, 12.612083075520227, 11.769439547035446, 10.705258461926245, 9.66919720070463, 8.673774596658085, 7.943820583369919, 6.886376663104508, 5.951600665048214, 4.943242002105547, 5.907504051722759, 6.889547296457337, 7.778355861279695, 18.555521587587293, 17.70221804720192, 16.693151498322507, 15.792195939684333, 15.600858962375689, 14.571084562177585, 13.607205933695504, 12.661382839369681, 11.668524102544048, 10.723474810771103, 9.71667776831201, 8.676992219478786, 7.731823504898817, 6.903726836785134, 5.944629685197959, 4.94583294097725, 3.928670369169468, 4.9449591981457175, 5.947896790043625, 6.833142332042181, 18.458735043489607, 17.533394598556423, 16.582427271996348, 15.636473299483175, 14.624159550436959, 13.639482706587108, 12.658390223658058, 11.699205992440842, 10.726812101060753, 9.746394665017306, 8.749383717301004, 7.770227229058035, 6.800469458906771, 5.943441830998764, 4.970838827820832, 3.9054413111910025, 2.9602310772775424, 4.016914413920753, 4.950351623507126, 5.856692745231542, 17.50710127232009, 16.53351437172148, 15.59422917750864, 14.666624355489883, 13.683928692985567, 12.700113104921572, 11.733284418337643, 10.764142554984833, 9.74835918901696, 8.724407263179701, 7.792686314645907, 6.813695353716799, 5.865421146929337, 5.001061063212902, 4.04718102584914, 3.0131301991791215, 2.001815034127074, 3.004423331344749, 3.941083177539126, 4.927638166635331, 16.753284158986254, 15.696016838395627, 14.734479557102226, 13.78387042141403, 12.839062611675068, 11.765378311972093, 10.799535738425794, 9.830044488497903, 8.83221943295002, 7.7978029103341475, 6.818803659208596, 5.892771932308268, 4.872989259152325, 3.929173554484299, 2.9893884266228614, 2.0101723004221856, 1.0209707580347442, 2.0007154570702665, 2.985887580076885, 3.9270579912701207, 15.913853179824194, 14.96048488299151, 13.950389125644037, 12.968271518672696, 12.031665086180833, 10.957370686575514, 9.987725164365973, 8.961364709463027, 7.9663942840747195, 6.936748197732536, 5.930483533459768, 4.926152346282105, 3.9952310871543446, 2.9689649235684494, 2.0171662715602263, 1.0136168634625289, 0.0, 1.0169451491874062, 1.968137484338611, 3.035908152103498], [2.942701148023942, 1.9639452542801128, 0.9394020594325745, 1.8943986089488742, 2.9639794142173925, 4.017668190906319, 4.971951077514251, 5.979040957487342, 6.925891755019992, 7.878300837042499, 8.92136378481443, 9.934322954318873, 10.864302639539918, 11.874764199181918, 12.818120419832152, 13.827443414865513, 14.879229748195876, 15.808433921067246, 16.826902292855653, 17.78484223831376, 3.8641094223284345, 2.9068155879584214, 1.9795677121133501, 2.8668797980911584, 3.9002181424817404, 4.973056382310634, 5.985489818552424, 7.008166301874182, 7.854345193997752, 8.814910521776875, 9.747340102818002, 10.680158236631263, 11.732896915469267, 12.779671722202254, 13.826200628665454, 14.83354678753824, 15.897939290159508, 16.864018130630196, 17.876403157739947, 18.726430436378024, 4.849345424342031, 3.91188932744606, 3.045883636882003, 3.894701454773449, 4.870006397702031, 5.8516635237818235, 6.87511518237929, 7.850543673605644, 8.834770756673338, 9.832696247449865, 10.767064556900745, 11.645565851274363, 12.682689155721285, 13.732273716711374, 14.725391069980443, 15.739669812509327, 16.787084169336662, 16.98104326834484, 17.81809575533116, 18.69087720643935, 5.7805371573205315, 4.974690672279063, 4.055809024749203, 4.909320277980404, 5.931579551985042, 6.850040078880688, 7.806931191820364, 8.835965567459134, 9.874258254054523, 10.810607910289896, 11.792533566059001, 12.607712388149656, 13.656528540428761, 14.70319650019732, 15.77738348013918, 16.703426476106525, 16.7533874738683, 15.94318873587118, 16.852603574108777, 17.650276433718233, 6.7119728392446385, 5.985681997115731, 5.087498335878136, 5.8568557068206335, 6.892435081736641, 7.89001506326435, 8.773868300200517, 9.703436558984633, 10.714103036325492, 11.767052421878633, 12.722099395135812, 13.560515502435008, 14.587913132680463, 15.618582044585386, 16.584645587536325, 16.869442978961462, 15.815891750112797, 14.869025709857352, 15.839460797155331, 16.66698365007182, 7.696321593116015, 6.989129559218206, 6.027246627658223, 6.8581156454309635, 7.831841272803694, 8.856728305903513, 9.72678170929353, 10.702653842046061, 11.669241664814505, 12.611968613716929, 13.574375528341502, 14.509273561986149, 15.536912950478644, 16.549492554305775, 16.761462769172844, 15.806364091826545, 14.931846945439233, 13.933187049839166, 14.876625758658907, 15.669541092394422, 8.651493874057827, 8.02221136480557, 7.022446374028454, 7.847120798747288, 8.77658080338077, 9.781798620779384, 10.683050170229867, 11.64990877109565, 12.613792781401465, 13.538351618151372, 14.570586030684618, 15.503752793801242, 16.483519494519744, 16.727828350805886, 15.767593455921997, 14.852038135262566, 13.947970267881846, 13.008168244959482, 13.960513695589256, 14.681102474173237, 9.636048088076528, 8.955687719295515, 7.972820917248504, 8.893758786321635, 9.727352795581025, 10.710652025602645, 11.646742629538636, 12.622826618725746, 13.619299385161744, 14.52331898633109, 15.530205484528162, 16.44308700899142, 16.64395300810332, 15.731780746117414, 14.841504045749858, 13.884210399197068, 12.985056216788495, 12.065150714117284, 12.973380778540585, 13.663032589484633, 10.614698821978212, 9.880889020814891, 8.902865095398017, 9.873515498192745, 10.761684443153317, 11.643250890350314, 12.657880728221025, 13.628125849276653, 14.615116789414923, 15.463341632508605, 16.41847019837621, 16.6164073364126, 15.682387714015176, 14.774843851105079, 13.815629782758483, 12.86452948307468, 12.007964111778312, 11.097919186459977, 12.014689411044142, 12.651720354849482, 11.683663519498403, 10.930074523378492, 9.915827377798708, 10.828597313946508, 11.778584603033261, 12.690659612488847, 13.62998776365897, 14.632602941219233, 15.598413643799468, 16.49154742070253, 16.536962912988816, 15.599041762285959, 14.67942183436345, 13.703299357933766, 12.821408539321894, 11.907585251707339, 10.948218024646476, 10.131038949705015, 10.952173994838008, 11.65907471106292, 12.627800517858452, 11.942645393037374, 10.988621885788673, 11.801270220159802, 12.713875148918241, 13.648011098096177, 14.618895139424506, 15.586760892498466, 16.55926853720247, 16.54577338020594, 15.514057152818031, 14.59157011023576, 13.682965340192238, 12.71720104720825, 11.799586384821295, 10.930836925840595, 9.999072861527324, 9.120112158545279, 9.955345295695972, 10.731815272335822, 13.58385128703908, 12.904196871963372, 11.916338388946164, 12.849433070669232, 13.68162291413048, 14.575509550501415, 15.61492027140063, 16.559835449564883, 16.572772759168487, 15.589315393996102, 14.56810708036417, 13.602759297503471, 12.71244028598971, 11.745313565545572, 10.803688064611386, 9.937117578870586, 9.005203060614278, 8.111504125670665, 8.880993272099094, 9.77250205028678, 14.578007514504359, 13.83035706872151, 12.903765960807812, 13.830675520293456, 14.6747676974975, 15.582558070385879, 16.556752383352308, 16.471997424689633, 15.515605898705674, 14.554696617259498, 13.602150530256104, 12.666680400400493, 11.722413262986384, 10.869214917473217, 9.87695024263077, 8.927914517523565, 7.9698956442848345, 7.124890153211548, 7.832699762791415, 8.745348458198643, 15.630209509534719, 14.80250727936397, 13.856336689748112, 14.806102037776293, 15.697872225952848, 16.52099474851893, 16.5701273530116, 15.558803350005768, 14.566409702236996, 13.595299638482826, 12.665448625265727, 11.724529535087125, 10.731384736243891, 9.840106834217115, 8.869904738899194, 7.925337060255109, 7.017021905547447, 6.13966948080955, 6.871980103142217, 7.697514421030907, 16.584035396752324, 15.857399280462992, 14.868437982081089, 15.765892683862084, 16.699653031938297, 16.59036878748918, 15.635535537576187, 14.662177695412707, 13.629028224707634, 12.786384696222854, 11.722203611113652, 10.686142349892037, 9.69071974584549, 8.953800574399349, 7.896356654133937, 6.961580656077644, 5.953221993134978, 5.115826394073331, 5.9022946973172505, 6.76141071209229, 17.63019852614466, 16.821821310156768, 15.812754761277354, 16.693426873071918, 16.617804111563096, 15.588029711364992, 14.62415108288291, 13.678327988557088, 12.685469251731455, 11.74041995995851, 10.733622917499416, 9.693937368666191, 8.748768654086224, 7.913706827814564, 6.954609676227388, 5.95581293200668, 4.938650360198898, 4.045419531385391, 4.930951640856219, 5.816197182854776, 18.6740097660693, 17.73304832609686, 16.782080999536785, 16.653418448670582, 15.641104699624366, 14.656427855774515, 13.675335372845465, 12.716151141628249, 11.74375725024816, 10.763339814204713, 9.766328866488411, 8.787172378245442, 7.817414608094177, 6.953421822028194, 5.980818818850262, 4.915421302220432, 3.970211068306972, 3.117374747160426, 3.93340647431972, 4.839747596044137, 18.524046421507496, 17.550459520908888, 16.611174326696048, 15.68356950467729, 14.700873842172975, 13.717058254108979, 12.75022956752505, 11.78108770417224, 10.765304338204366, 9.741352412367108, 8.809631463833314, 7.830640502904205, 6.882366296116743, 6.018006212400308, 5.064126175036545, 4.030075348366528, 3.0117950251565038, 2.0549139243031345, 2.92413802835172, 3.9106930174479255, 17.770229308173654, 16.71296198758303, 15.75142470628963, 14.800815570601433, 13.856007760862472, 12.782323461159498, 11.8164808876132, 10.846989637685308, 9.849164582137425, 8.814748059521554, 7.835748808396002, 6.909717081495674, 5.889934408339731, 4.946118703671705, 4.006333575810268, 3.027117449609592, 2.030950749064174, 1.0512060500286515, 1.9689424308894792, 2.9101128420827145, 16.930798329011605, 15.97743003217892, 14.967334274831448, 13.985216667860106, 13.048610235368244, 11.974315835762924, 11.004670313553383, 9.978309858650436, 8.983339433262127, 7.953693346919943, 6.947428682647175, 5.9430974954695115, 5.012176236341751, 3.9859100727558556, 3.0341114207476325, 2.030562012649935, 1.0169451491874062, 0.0, 0.9511923351512048, 2.0189630029160917], [1.9915088128727372, 1.012752919128908, 1.8905943945837793, 2.845590944100079, 3.9151717493685974, 4.968860526057523, 5.923143412665455, 6.930233292638547, 7.877084090171197, 8.829493172193702, 9.872556119965633, 10.885515289470076, 11.815494974691122, 12.825956534333121, 13.769312754983355, 14.778635750016717, 15.830422083347079, 16.75962625621845, 17.77809462800686, 18.736034573464966, 2.9129170871772296, 1.9556232528072168, 2.911958563943078, 3.8180721332423633, 4.851410477632945, 5.924248717461839, 6.936682153703629, 7.959358637025386, 8.805537529148957, 9.76610285692808, 10.698532437969208, 11.631350571782468, 12.684089250620472, 13.73086405735346, 14.77739296381666, 15.784739122689443, 16.84913162531071, 17.8152104657814, 17.998858414846595, 18.687921285605075, 3.898153089190827, 2.960696992294855, 3.9643431691709248, 4.845893789924654, 5.821198732853236, 6.802855858933028, 7.826307517530495, 8.801736008756848, 9.785963091824541, 10.783888582601069, 11.71825689205195, 12.596758186425568, 13.63388149087249, 14.68346605186258, 15.676583405131648, 16.690862147660532, 17.738276504487867, 17.737217933533167, 16.960190406899034, 17.739684871288148, 4.829344822169326, 4.023498337127858, 4.974268557038124, 5.8605126131316085, 6.882771887136246, 7.801232414031892, 8.758123526971568, 9.787157902610339, 10.825450589205728, 11.7618002454411, 12.743725901210206, 13.558904723300861, 14.607720875579966, 15.654388835348525, 16.728575815290384, 17.654618811257727, 17.509562139056623, 16.699363401059504, 15.99469822567665, 16.69908409856703, 5.760780504093433, 5.034489661964526, 5.970184926238257, 6.808048041971838, 7.843627416887846, 8.841207398415554, 9.725060635351722, 10.654628894135838, 11.665295371476697, 12.718244757029838, 13.673291730287017, 14.511707837586213, 15.539105467831668, 16.56977437973659, 17.535837922687527, 17.625617644149784, 16.57206641530112, 15.625200375045676, 14.981555448723205, 15.715791314920617, 6.74512925796481, 6.037937224067001, 6.909933218018344, 7.809307980582168, 8.783033607954899, 9.807920641054716, 10.677974044444735, 11.653846177197266, 12.62043399996571, 13.563160948868134, 14.525567863492707, 15.460465897137354, 16.48810528562985, 17.50068488945698, 17.60495522870855, 16.641745023819187, 15.68978648355921, 14.68936171502749, 14.01872041022678, 14.718348757243216, 7.700301538906622, 7.097127962871388, 7.905132964388575, 8.798313133898493, 9.727773138531976, 10.732990955930589, 11.634242505381073, 12.601101106246855, 13.56498511655267, 14.489543953302578, 15.521778365835823, 16.454945128952446, 17.43471182967095, 17.571320810341593, 16.611085915457704, 15.687419067255208, 14.76339566096299, 13.764342910147805, 13.029728983430678, 13.729910139022032, 8.684855752925323, 8.053765948638496, 8.855507507608625, 9.817942803638154, 10.67854513073223, 11.66184436075385, 12.597934964689841, 13.574018953876951, 14.57049172031295, 15.474511321482295, 16.48139781967937, 17.394279344142625, 17.49717868437581, 16.585006422389903, 15.684996505285564, 14.71959133118971, 13.800481609869639, 12.821325379305607, 12.02218844338938, 12.711840254333428, 9.663506486827007, 9.024445218629522, 9.785551685758138, 10.756202088552865, 11.712876778304523, 12.59444322550152, 13.60907306337223, 14.579318184427859, 15.566309124566128, 16.41453396765981, 17.369662533527414, 17.469633012685087, 16.535613390287665, 15.628069527377567, 14.65912224229419, 13.699910415067322, 12.823389504859456, 11.854093851648301, 11.063497075892936, 11.700528019698277, 10.732471184347197, 10.087489524225283, 10.79851396815883, 11.711283904306628, 12.729776938184466, 13.641851947640053, 14.581180098810176, 15.583795276370438, 16.549605978950673, 17.442739755853736, 17.488155248140025, 16.528854830190678, 15.53264751063594, 14.556525034206254, 13.674634215594383, 12.74296618369998, 11.774801815692086, 10.887213614893339, 10.000981659686802, 10.707882375911714, 11.676608182707247, 11.100060393884165, 11.871308476148794, 12.683956810519922, 13.665067484069446, 14.599203433247382, 15.570087474575711, 16.53795322764967, 17.510460872353676, 17.496965715357145, 16.46524948796924, 15.521383178140479, 14.536191016464727, 13.57042672348074, 12.652812061093783, 11.766217857833238, 10.825656652572935, 9.876286823733603, 9.004152960544767, 9.780622937184617, 12.632658951887874, 12.173925583794993, 12.799024979306285, 13.732119661029351, 14.632815249281686, 15.52670188565262, 16.566112606551833, 17.511027784716084, 17.523965094319696, 16.540507729147308, 15.519299415515375, 14.553951632654677, 13.663632621140914, 12.598539241818061, 11.656913740883875, 10.77249851086323, 9.840583992606922, 8.867678790858989, 7.929800936947888, 8.821309715135575, 13.626815179353153, 13.100085780553131, 13.786452551167933, 14.713362110653575, 15.625960032648706, 16.533750405537084, 17.507944718503513, 17.423189759840838, 16.46679823385688, 15.505888952410704, 14.55334286540731, 13.617872735551698, 12.67360559813759, 11.755915923507008, 10.730175918903258, 9.781140193796054, 8.823121320557323, 7.881064818399873, 6.8815074276402095, 7.794156123047438, 14.679017174383514, 14.156745137896491, 14.739023280108233, 15.688788628136413, 16.649064561104055, 17.472187083670136, 17.521319688162805, 16.509995685156973, 15.517602037388201, 14.546491973634032, 13.616640960416932, 12.67572187023833, 11.682577071395096, 10.784292497599973, 9.814090402282051, 8.869522723637967, 7.959714545281707, 6.944462186159047, 5.920787767991012, 6.746322085879702, 15.632843061601118, 15.211637138995513, 15.75112457244121, 16.648579274222204, 17.644941893455186, 17.541561122640385, 16.586727872727394, 15.613370030563912, 14.580220559858839, 13.737577031374059, 12.673395946264858, 11.637334685043243, 10.641912080996695, 9.904992909550554, 8.847548989285142, 7.9057663194605015, 6.897407656517835, 5.933145606900624, 4.951102362166045, 5.8102183769410845, 16.679006190993455, 16.266782709047927, 16.695441351637477, 17.576113463432037, 17.5689964467143, 16.539222046516198, 15.575343418034116, 14.629520323708293, 13.63666158688266, 12.691612295109715, 11.68481525265062, 10.645129703817396, 9.699960989237429, 8.864899162965768, 7.905802011378594, 6.907005267157885, 5.889842695350103, 4.911446407934853, 3.9797593057050142, 4.86500484770357, 17.722817430918095, 17.216208346746864, 17.664767589896908, 17.604610783821784, 16.59229703477557, 15.60762019092572, 14.62652770799667, 13.667343476779454, 12.694949585399366, 11.714532149355918, 10.717521201639615, 9.738364713396647, 8.768606943245382, 7.904614157179399, 6.932011154001467, 5.866613637371637, 4.921403403458177, 3.983401623709888, 2.9822141391685153, 3.888555260892932, 18.674451202087614, 18.243363593451793, 17.562366661847253, 16.634761839828496, 15.65206617732418, 14.668250589260184, 13.701421902676255, 12.732280039323445, 11.716496673355572, 10.692544747518314, 9.760823798984518, 8.78183283805541, 7.833558631267947, 6.969198547551512, 6.01531851018775, 4.981267683517733, 3.9629873603077086, 3.006106259454339, 1.9729456932005154, 2.9595006822967207, 18.72142164332486, 17.664154322734234, 16.702617041440835, 15.752007905752638, 14.807200096013677, 13.733515796310703, 12.767673222764405, 11.798181972836513, 10.80035691728863, 9.765940394672759, 8.786941143547207, 7.860909416646878, 6.8411267434909355, 5.8973110388229095, 4.957525910961472, 3.9783097847607967, 2.982143084215379, 2.0023983851798564, 1.0177500957382744, 1.9589205069315097, 17.881990664162803, 16.92862236733012, 15.91852660998265, 14.936409003011308, 13.999802570519446, 12.925508170914126, 11.955862648704585, 10.929502193801639, 9.934531768413331, 8.904885682071146, 7.898621017798378, 6.894289830620716, 5.963368571492955, 4.9371024079070605, 3.985303755898837, 2.98175434780114, 1.968137484338611, 0.9511923351512048, 0.0, 1.0677706677648868], [0.9753748803403247, 1.9541307740841538, 2.9583650623486664, 3.913361611864966, 4.982942417133485, 6.03663119382241, 6.9909140804303425, 7.998003960403433, 8.944854757936083, 9.897263839958589, 10.94032678773052, 11.953285957234963, 12.883265642456008, 13.893727202098008, 14.837083422748242, 15.846406417781603, 16.898192751111967, 17.82739692398334, 18.84586529577175, 18.91384248012773, 2.0470606376933476, 2.8970011077624624, 3.8533364188983237, 4.843328390140046, 5.8766667345306285, 6.949504974359522, 7.961938410601312, 8.996446056366787, 9.873308196913843, 10.833873524692967, 11.766303105734094, 12.699121239547354, 13.751859918385358, 14.798634725118346, 15.845163631581546, 16.85250979045433, 17.9169022930756, 18.88298113354629, 18.819712216662392, 17.854600603827944, 3.0528424249099935, 3.902074847250101, 4.905721024126171, 5.871150046822336, 6.846454989750919, 7.828112115830711, 8.851563774428179, 9.826992265654532, 10.811219348722226, 11.809144839498753, 12.743513148949635, 13.664528854190454, 14.701652158637376, 15.751236719627466, 16.744354072896535, 17.75863281542542, 18.806047172252754, 18.718656288411665, 17.78104420871483, 16.906364189511017, 3.996024140392197, 4.964876192083104, 5.915646411993371, 6.885768870029291, 7.9080281440339295, 8.826488670929576, 9.783379783869252, 10.812414159508023, 11.850706846103412, 12.787056502338784, 13.76898215810789, 14.626675391065747, 15.675491543344853, 16.722159503113414, 17.796346483055274, 18.722389479022617, 18.491000493935125, 17.680801755938006, 16.815552027492448, 15.8657634167899, 4.927459822316305, 5.897712844466094, 6.8334081087398255, 7.83330429886952, 8.868883673785529, 9.866463655313238, 10.750316892249407, 11.679885151033522, 12.690551628374381, 13.743501013927522, 14.698547987184702, 15.5794785053511, 16.606876135596554, 17.637545047501476, 18.603608590452417, 18.607055999028287, 17.55350477017962, 16.606638729924178, 15.802409250539, 14.882470633143488, 5.911808576187681, 6.90116040656857, 7.7731564005199125, 8.729050040832002, 9.750737669620692, 10.77562470272051, 11.703230301342419, 12.67910243409495, 13.645690256863395, 14.588417205765818, 15.550824120390391, 16.485722154035038, 17.554302713834954, 18.566882317662085, 18.590022407385202, 17.626812202495838, 16.671224838437713, 15.670800069905994, 14.839574212042576, 13.885028075466087, 6.866980857129493, 7.906615065047279, 8.768356146890143, 9.718055194148326, 10.69547720019777, 11.700695017596383, 12.625782969101081, 13.592641569966863, 14.587679820047327, 15.514800210200262, 16.547034622733506, 17.48020138585013, 18.500909257876053, 18.556387989018244, 17.596153094134355, 16.67248624593186, 15.744834015841493, 14.74578126502631, 13.850582785246473, 12.896589457244902, 7.851535071148193, 8.863253050814386, 9.718730690110194, 10.681165986139723, 11.646249192398024, 12.629548422419644, 13.565639026355635, 14.541723015542745, 15.55548538640232, 16.496630345842142, 17.503516844039215, 18.41953560104031, 18.482245863052462, 17.570073601066554, 16.670063683962216, 15.704658509866361, 14.781919964748141, 13.802763734184111, 12.859717169161126, 11.878519572556298, 8.830185805049878, 9.833932320805411, 10.648774868259707, 11.619425271054435, 12.657209458976494, 13.562147287167313, 14.576777125038024, 15.547022246093652, 16.534013186231924, 17.43665299201966, 18.391781557887263, 18.454700191361738, 17.520680568964316, 16.613136706054217, 15.644189420970841, 14.684977593743973, 13.804827859737959, 12.835532206526805, 11.901025801664682, 10.867207337921148, 9.899150502570068, 10.848333746620614, 11.661737150660398, 12.574507086808199, 13.623190183761729, 14.608604616278114, 15.54888416047597, 16.55149933803623, 17.51731004061647, 18.45937574415652, 18.477832168736462, 17.513922008867326, 16.51771468931259, 15.541592212882904, 14.659701394271032, 13.728033362376632, 12.759868994368736, 11.868651969771843, 10.85974345206052, 9.874561694134584, 10.843287500930117, 11.860904616279496, 12.734531658650363, 13.547179993021492, 14.558480729646709, 15.492616678824644, 16.46350072015297, 17.43136647322693, 18.42787524859967, 18.50916918999147, 17.454926408565676, 16.506450356817126, 15.521258195141376, 14.555493902157389, 13.637879239770433, 12.751285036509888, 11.810723831249584, 10.861354002410252, 9.988868635466694, 8.947302255407488, 11.799338270110745, 12.764983247328926, 13.662248161807854, 14.595342843530922, 15.526228494858948, 16.420115131229885, 17.459525852129094, 18.404441030293345, 18.591735762084582, 17.608278396912194, 16.587070083280263, 15.621722300419563, 14.656583137852575, 13.58360642049471, 12.641980919560524, 11.757565689539879, 10.825651171283571, 9.852745969535638, 8.914516611869816, 7.987989033358446, 12.793494497576024, 13.691143444087064, 14.649675733669502, 15.576585293155146, 16.51937327822597, 17.42716365111435, 18.401357964080777, 18.490960427605724, 17.534568901621768, 16.57365962017559, 15.621113533172196, 14.685643403316584, 13.741376265902476, 12.740983102183657, 11.715243097579908, 10.766207372472703, 9.808188499233973, 8.866131997076522, 7.866574606316858, 6.960835441270309, 13.845696492606384, 14.747802801430424, 15.602246462609802, 16.552011810637985, 17.54247780668132, 18.3656003292474, 18.589090355927695, 17.577766352921863, 16.58537270515309, 15.614262641398918, 14.684411628181818, 13.743492538003217, 12.750347739159983, 11.769359676276624, 10.799157580958703, 9.854589902314617, 8.944781723958355, 7.9295293648356955, 6.90585494666766, 5.913001404102572, 14.799522379823989, 15.802694802529446, 16.61434775494278, 17.511802456723778, 18.50816507595676, 18.60933179040527, 17.65449854049228, 16.6811406983288, 15.647991227623727, 14.805347699138945, 13.741166614029744, 12.705105352808129, 11.709682748761582, 10.904782958674526, 9.847339038409114, 8.890833498137152, 7.882474835194484, 6.918212785577273, 5.936169540842694, 4.976897695163955, 15.845685509216327, 16.82167575615873, 17.558664534139048, 18.43933664593361, 18.63676711447919, 17.606992714281088, 16.643114085799006, 15.697290991473182, 14.704432254647548, 13.759382962874604, 12.752585920415507, 11.712900371582283, 10.767731657002315, 9.900184088957815, 8.94108693737064, 7.9422901931499315, 6.923806313948679, 5.896513586611501, 4.964826484381662, 4.031684165926441, 16.889496749140967, 17.771101393857666, 18.52799077239848, 18.672381451586674, 17.66006770254046, 16.67539085869061, 15.694298375761559, 14.735114144544342, 13.762720253164254, 12.782302817120806, 11.785291869404503, 10.806135381161534, 9.836377611010269, 8.939899083171445, 7.967296079993513, 6.901898563363684, 5.956688329450224, 4.968468802386536, 3.967281317845164, 3.0552345791158024, 17.841130520310486, 18.798256640562595, 18.63013732961214, 17.702532507593382, 16.719836845089066, 15.73602125702507, 14.769192570441142, 13.800050707088333, 12.78426734112046, 11.760315415283202, 10.828594466749406, 9.849603505820298, 8.901329299032835, 8.036969215316399, 7.064131206210677, 6.030080379540659, 4.9982722862997555, 4.0189715999622075, 2.958012871877164, 2.126180000519591, 18.810801732032314, 18.731924990499124, 17.770387709205725, 16.819778573517528, 15.874970763778567, 14.801286464075591, 13.835443890529293, 12.865952640601401, 11.868127585053518, 10.833711062437647, 9.854711811312095, 8.928680084411766, 7.908897411255823, 6.965081706587797, 6.025296578726359, 5.027122480783723, 4.017428010207426, 3.0376833111719037, 2.002817274414923, 1.0616468632216878, 18.949761331927686, 17.996393035095004, 16.986297277747532, 16.004179670776193, 15.067573238284332, 13.993278838679013, 13.023633316469471, 11.997272861566525, 11.002302436178217, 9.972656349836033, 8.966391685563265, 7.962060498385602, 7.031139239257842, 6.004873075671947, 5.053074423663724, 4.049525015566027, 3.035908152103498, 2.0189630029160917, 1.0677706677648868, 0.0]]}],
                            {"plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "xaxis": {"constrain": "domain", "scaleanchor": "y"}, "yaxis": {"autorange": "reversed", "constrain": "domain"}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('6c240d93-5bf7-46a8-887c-bd096f60f7ca');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Compute the adjacency matrix of the grid points, with boundaries identified as in the Klein bottle
    from sklearn.utils.graph_shortest_path import graph_shortest_path
    
    # This functions prepares the grid matrix with boundary identification
    def make_matrix(rows, cols):
        n = rows*cols
        M = np.zeros((n,n))
        for r in range(rows):
            for c in range(cols):
                i = r*cols + c
                # Two inner diagonals
                if c > 0: M[i-1,i] = M[i,i-1] = 1 + 0.15*(np.random.rand(1)[0]-0.5)
                # Two outer diagonals
                if r > 0: M[i-cols,i] = M[i,i-cols] = 1 + 0.15*(np.random.rand(1)[0]-0.5)
                # vertical boundary identification
                if c == 0: M[i+cols-1,i] = M[i,i+cols-1] = 1 + 0.15*(np.random.rand(1)[0]-0.5)
                # horizontal twisted boundary identification
                if r == 0: M[n-i-1,i] = M[i,n-i-1] = 1 + 0.15*(np.random.rand(1)[0]-0.5)
                    
        return M
    
    M = make_matrix(20,20)
    
    # computing the distance matrix of the points over the Klein bottle
    
    klein = graph_shortest_path(M)
    
    # Plot of the distance matrix
    plot_heatmap(klein, colorscale='viridis')



.. raw:: html

    <div>
    
    
                <div id="f9235710-123c-475e-904f-1cf75d1b878e" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("f9235710-123c-475e-904f-1cf75d1b878e")) {
                        Plotly.newPlot(
                            'f9235710-123c-475e-904f-1cf75d1b878e',
                            [{"colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmap", "z": [[0.0, 0.9496445131195502, 1.942986848663539, 2.9027790022051105, 3.956245705819085, 4.960944020907935, 5.975225923829774, 7.029334562789777, 8.068872366529694, 9.13571676820537, 10.066734870535228, 9.040259280249076, 8.076316607608682, 7.086323708966579, 6.129724178112001, 5.158688350855338, 4.120187416444738, 3.1079954572958965, 2.0594482166840233, 1.0398117462902543, 0.9723996479974382, 1.9174837423506976, 2.895940949143879, 3.843177081193054, 4.778330485918354, 5.755543698869156, 6.816569587517229, 7.75179531907192, 8.738542325704381, 9.759658354899932, 10.713763612908712, 9.919369136369799, 8.880645118397073, 7.8993686420323215, 6.860847205337689, 5.854477324000177, 4.8915169528549445, 3.846535459797439, 2.859916142757338, 1.9129897542013183, 1.9901209112601328, 2.9181395641395103, 3.9307724118358087, 4.872070954346019, 5.787434247206875, 6.7438821453684605, 7.793095858886477, 8.801017796645398, 9.713966635864287, 10.666795582422354, 11.68893946566103, 10.856868582299118, 9.8016620485244, 8.853078052451693, 7.880078162584926, 6.905452948628387, 5.866406443415364, 4.815974514940525, 3.8519596402240897, 2.8507563050130087, 3.0231147578825497, 3.8795486389786573, 4.863765305797705, 5.813576470169778, 6.740384143271543, 7.767653571454401, 8.750532435473353, 9.749617234993128, 10.69529635914124, 11.620361933279947, 12.666235944161842, 11.732197896840697, 10.768566848177306, 9.87249844506744, 8.824384324097313, 7.780275637042718, 6.710784168112924, 5.772654546123373, 4.775118216908041, 3.8376103771728483, 3.968138058148054, 4.917723571237746, 5.813808012154352, 6.852449642151283, 7.800016845886007, 8.73366477459456, 9.722716419869581, 10.665452333492402, 11.64788381939168, 12.65435627158519, 13.60746342236293, 12.662289651328491, 11.744539467654148, 10.762099113670626, 9.69869022849534, 8.741859872547803, 7.690997589283911, 6.734119766873826, 5.769555071399552, 4.8289639181191655, 4.915180598748544, 5.870386600245275, 6.860506341096728, 7.851463012494969, 8.87111872967286, 9.667257085417463, 10.70751691226642, 11.590700974277649, 12.563613834713204, 13.54926568833321, 14.483855677191004, 13.684333227381419, 12.706428474631666, 11.73501727391751, 10.668687262502894, 9.621500068555752, 8.646726125760248, 7.640678994420964, 6.704113783923561, 5.8037573176203825, 5.908382686871907, 6.883968183053696, 7.892768935948816, 8.840666441483659, 9.816938693337733, 10.718055981017462, 11.713863716081205, 12.536794920993959, 13.494950985368646, 14.485045715294653, 15.432523034412704, 14.50185011195958, 13.571369573529115, 12.525531907447201, 11.51771512714755, 10.539005468643492, 9.579560155277493, 8.575298858067525, 7.668232099632724, 6.792799605538757, 6.8755890001700495, 7.866256583068806, 8.81386728197394, 9.825546799099424, 10.846303839627401, 11.703518656859469, 12.667431056905949, 13.483303703434059, 14.436766875596911, 15.403969345139451, 16.34834571037875, 15.392667241131765, 14.392153075309002, 13.326071266651088, 12.341796192258952, 11.3997026769626, 10.45237808706394, 9.520520406785415, 8.6079512646785, 7.801144910270686, 7.804189056274207, 8.800319881646512, 9.766821669090886, 10.783074239186275, 11.80981542721661, 12.68556171955911, 13.672065312101457, 14.551983934674643, 15.511740185285205, 16.367031395488805, 17.291334747942642, 16.25160855553562, 15.291945278040874, 14.228216896899195, 13.274608173909415, 12.336868768590632, 11.454994136659247, 10.522744458580746, 9.649322427907599, 8.761697122351384, 8.810681100984318, 9.753655052358205, 10.800307159717354, 11.752274246681, 12.735665332837034, 13.697357819905367, 14.605278860020213, 15.495156301199764, 16.464957993113064, 17.337133827512936, 18.1146111438168, 17.131762074033347, 16.11936876420022, 15.18581591943066, 14.263310169071069, 13.322800146774991, 12.488960840987188, 11.474438700243986, 10.597244851272228, 9.827161286941378, 9.777312526180754, 10.72747427556376, 11.708447137626532, 12.716233584098575, 13.65813206387181, 14.653296448250114, 15.543096063734453, 16.421425582298482, 17.44411774240778, 18.35996750217182, 18.336707621673842, 17.280713387541603, 16.349565389435337, 15.402596003659951, 14.477395560256486, 13.49655761554788, 12.682224637651181, 11.743742169668348, 10.891499634460887, 9.891050248849986, 9.898689218262469, 10.74074108349679, 11.670000773183206, 12.629683546478361, 13.562955807426775, 14.550509711153978, 15.519919837061096, 16.57733272917938, 17.64133976758184, 18.525774371134464, 17.529480154810482, 16.565153554986736, 15.496100508661334, 14.512831746354315, 13.503011391035164, 12.523783776348706, 11.711923391496288, 10.742933972985293, 9.876360922434374, 8.958588037269731, 8.891488428103752, 9.80492014081314, 10.734533963532819, 11.706247358157487, 12.657851134870661, 13.652587129146882, 14.626240982835895, 15.667689266344947, 16.685144006219442, 17.50913926948905, 16.52142719580925, 15.523135585656492, 14.521171897993089, 13.513705146624439, 12.520080283728284, 11.580285236375316, 10.660202665969715, 9.772609594694035, 8.80762352807781, 7.972299545857194, 7.880667315758489, 8.841897065319102, 9.815602653294182, 10.733323974938704, 11.722655451433605, 12.78706476679503, 13.823111556325722, 14.778626149354475, 15.732444543271676, 16.43832963755377, 15.485059707848656, 14.475502599078188, 13.528101174100827, 12.565275957153187, 11.581282287331087, 10.642758447015456, 9.694063474461881, 8.799664653347499, 7.799922747624187, 7.03370414186424, 6.934818048211218, 7.892851428751144, 8.888399719983076, 9.770624888121992, 10.830417290279401, 11.836343361585444, 12.873365947552347, 13.769062726613397, 14.799458938930469, 15.503227117932274, 14.525857068914663, 13.609331149631032, 12.653640666398333, 11.67941228073515, 10.629429899494074, 9.662177346099774, 8.71437722738023, 7.817014295039855, 6.830667134168601, 5.993036786471361, 5.90946956095341, 6.977171852642018, 7.959234423273073, 8.844854909157144, 9.895832577312278, 10.835178525308583, 11.824112198711175, 12.806733568132868, 13.774156248531792, 14.49572090717829, 13.570370786944574, 12.675749528937304, 11.722950061150659, 10.712408568697898, 9.767308633304438, 8.72458193121074, 7.69102033860849, 6.918585054629755, 5.877911820155942, 4.943771755909626, 4.980206821776146, 5.995278685965863, 7.001961356717567, 7.8869221017576665, 8.88668051121911, 9.885636990719936, 10.865331267443388, 11.847345214878304, 12.801766415794578, 13.585692846904893, 12.632718547932813, 11.67196261603567, 10.71443378846534, 9.681215565166804, 8.750660438208643, 7.732860054084115, 6.727996448769479, 5.899781354773685, 4.937696303123294, 4.012210526142842, 4.001742552680496, 4.948615838078632, 5.934647612080555, 6.954738003398651, 8.006957217609472, 8.962081259398216, 9.918382447267762, 10.934857694672756, 11.96051552721374, 12.55422728621814, 11.623068918416255, 10.602305105235404, 9.673735887772809, 8.733287531115616, 7.726914543949245, 6.7319537454260825, 5.767803717460262, 4.919764953349447, 4.031883803969653, 3.048000135177085, 3.0622980401989963, 4.110503100942126, 5.071679133671408, 6.004539829205559, 7.07302095255783, 8.145794693591153, 9.070175074496719, 10.025198806207833, 11.011343196183153, 11.75721177311271, 10.819880194406368, 9.881798408617321, 8.89932654522256, 7.894384875883164, 6.83394802907218, 5.796424881674193, 4.805561763873023, 3.9415921274648404, 2.9650002465218614, 2.0981086723102766, 2.0455425892912027, 3.091484110166623, 4.14145706972784, 5.071848117038361, 6.105429479155944, 7.107028404305814, 8.062548486494943, 9.09380491327488, 10.051835139981364, 10.91484454873751, 9.875297045529361, 8.91834278560451, 7.870918205949022, 6.879128078393862, 5.894106404343723, 4.831937544463486, 3.838917028915722, 2.9083142726333344, 1.8958234319764053, 1.074751924460486], [0.9496445131195502, 0.0, 0.9933423355439889, 1.9531344890855602, 3.0066011926995344, 4.011299507788385, 5.025581410710223, 6.079690049670226, 7.119227853410144, 8.186072255085818, 9.173638092023069, 9.989903793368622, 9.025961120728228, 8.035968222086126, 7.079368691231549, 6.108332863974887, 5.069831929564287, 4.057639970415446, 3.009092729803573, 1.9894562594098044, 1.9211199790334157, 0.9760358846801561, 1.9544930914733376, 2.893532568073504, 3.828685972798804, 4.805899185749606, 5.866925074397679, 6.802150805952371, 7.788897812584832, 8.810013841780382, 9.764119099789163, 10.693752109190427, 9.82936544943305, 8.848088973068299, 7.809567536373666, 6.803197655036154, 5.840237283890922, 4.795255790833417, 3.8086364737933156, 2.861710085237296, 2.9388412422961103, 1.9766917064689689, 2.9893245541652673, 3.922426441226469, 4.837789734087325, 5.794237632248911, 6.843451345766927, 7.85137328352585, 8.764322122744737, 9.717151069302805, 10.73929495254148, 11.631251555119746, 10.750382379560378, 9.80179838348767, 8.828798493620903, 7.854173279664364, 6.8151267744513415, 5.764694845976502, 4.800679971260067, 3.7994766360489862, 3.971835088918527, 2.938100781308116, 3.922317448127164, 4.872128612499237, 5.790739630151993, 6.818009058334852, 7.8008879223538035, 8.799972721873578, 9.74565184602169, 10.670717420160397, 11.716591431042293, 12.643615259598187, 11.717287179213283, 10.821218776103416, 9.77310465513329, 8.728995968078696, 7.659504499148901, 6.7213748771593504, 5.723838547944018, 4.786330708208825, 4.916858389184032, 3.9762757135672038, 4.87236015448381, 5.911001784480742, 6.850372332766457, 7.7840202614750105, 8.773071906750031, 9.715807820372852, 10.69823930627213, 11.70471175846564, 12.65781890924338, 13.573707014085981, 12.693259798690125, 11.710819444706605, 10.647410559531318, 9.690580203583782, 8.639717920319889, 7.6828400979098035, 6.718275402435529, 5.777684249155143, 5.863900929784522, 4.975785213619377, 5.919058483426186, 6.910015154824428, 7.921474216553311, 8.717612572297913, 9.757872399146871, 10.641056461158099, 11.613969321593654, 12.59962117521366, 13.534211164071454, 14.560657241893384, 13.655148805667645, 12.683737604953489, 11.617407593538873, 10.570220399591731, 9.595446456796227, 8.589399325456942, 7.652834114959538, 6.75247764865636, 6.857103017907885, 5.989525752491549, 6.951321078278274, 7.899218583813119, 8.875490835667192, 9.768411467897913, 10.764219202961655, 11.58715040787441, 12.545306472249097, 13.535401202175104, 14.482878521293154, 15.448659525080684, 14.520089904565094, 13.47425223848318, 12.466435458183529, 11.48772579967947, 10.528280486313472, 9.524019189103504, 8.616952430668702, 7.7415199365747345, 7.8243093312060275, 7.000587673129865, 7.942472078597601, 8.923311681365638, 9.931157464650047, 10.75387414373992, 11.7177865437864, 12.53365919031451, 13.487122362477361, 14.454324832019902, 15.513927041256919, 16.341387572167744, 15.340873406344981, 14.274791597687067, 13.290516523294931, 12.348423007998578, 11.401098418099918, 10.469240737821394, 9.556671595714477, 8.749865241306663, 8.752909387310185, 8.07352164205145, 8.895426465714547, 9.911679035809936, 10.93842022384027, 11.735917206439561, 12.722420798981908, 13.602339421555094, 14.562095672165656, 15.417386882369255, 16.413032887511662, 17.200328886571597, 16.240665609076853, 15.176937227935174, 14.223328504945394, 13.28558909962661, 12.403714467695226, 11.471464789616725, 10.598042758943576, 9.710417453387361, 9.759401432020297, 9.047711882557461, 9.930545700892889, 10.880879043304663, 11.864270129460696, 12.747713306785817, 13.655634346900664, 14.545511788080216, 15.515313479993514, 16.387489314393388, 17.34080690666114, 17.361430532517325, 16.427877492016453, 15.499350367512646, 14.479916073730982, 13.506616693150566, 12.779669303844553, 11.998678776781086, 11.115406937203918, 10.775881617977355, 10.726032857216733, 10.116620265580199, 10.988228673141919, 11.879081807655258, 12.808231124954094, 13.703651935130564, 14.593451550614903, 15.471781069178936, 16.49447322928823, 17.410322989052272, 17.38706310855429, 16.33106887442205, 15.399920876315786, 14.452951490540402, 13.527751047136936, 12.54691310242833, 11.76052435313739, 10.928064323274027, 10.085636999859652, 10.740577196215437, 10.74821616562792, 11.086115652396693, 11.926136004766553, 12.885818778061708, 13.819091039010122, 14.775429848201313, 15.613963799348308, 16.45197005129009, 17.51597708969255, 17.576129858014912, 16.57983564169093, 15.615509041867188, 14.546455995541784, 13.563187233234766, 12.553366877915614, 11.574139263229156, 10.762278878376737, 9.927256126590972, 9.060683076040053, 9.808114984635182, 9.741015375469205, 10.654447088178593, 11.584060910898272, 12.555774305522938, 13.507378082236112, 14.502114076512333, 15.475767930201346, 16.517216213710398, 17.401520905400854, 16.559494756369507, 15.5717826826897, 14.573491072536942, 13.571527384873539, 12.564060633504889, 11.570435770608734, 10.630640723255766, 9.710558152850163, 8.956931748299715, 7.9919456816834895, 8.821826493222645, 8.730194263123941, 9.691424012684555, 10.665129600659634, 11.582850922304155, 12.572182398799056, 13.636591714160481, 14.672638503691173, 15.628153096719927, 16.448821442453088, 15.488685124434225, 14.535415194729108, 13.525858085958639, 12.578456660981278, 11.615631444033637, 10.631637774211537, 9.693113933895907, 8.74441896134233, 7.983986806953177, 6.984244901229866, 7.883231089229691, 7.784344995576669, 8.742378376116596, 9.737926667348528, 10.620151835487443, 11.679944237644852, 12.685870308950895, 13.7228928949178, 14.61858967397885, 15.51583583811188, 14.553582604812727, 13.576212555795115, 12.659686636511482, 11.703996153278784, 10.7297677676156, 9.679785386374524, 8.712532832980225, 7.7647327142606795, 7.001336448645534, 6.01498928777428, 6.842563733836812, 6.758996508318861, 7.826698800007469, 8.808761370638523, 9.694381856522595, 10.74535952467773, 11.684705472674036, 12.673639146076628, 13.656260515498321, 14.490533147713203, 13.546076394058742, 12.620726273825026, 11.726105015817755, 10.773305548031109, 9.762764055578348, 8.817664120184888, 7.77493741809119, 6.74137582548894, 5.968940541510205, 5.0622339737616215, 5.793298703275077, 5.829733769141597, 6.844805633331314, 7.851488304083018, 8.736449049123118, 9.736207458584563, 10.735163938085389, 11.71485821480884, 12.696872162243757, 13.53643624609252, 12.636048333785345, 11.683074034813265, 10.72231810291612, 9.764789275345791, 8.731571052047254, 7.801015925089093, 6.783215540964565, 5.77835193564993, 4.9501368416541345, 4.047924503586284, 4.861737473508293, 4.851269500045947, 5.798142785444083, 6.784174559446006, 7.804264950764102, 8.870999768979141, 9.826123810767886, 10.782424998637431, 11.798900246042425, 12.59262558288174, 11.604582773098592, 10.673424405296707, 9.652660592115854, 8.72409137465326, 7.783643017996066, 6.777270030829695, 5.782309232306533, 4.818159204340712, 3.9701204402298966, 3.0822392908501026, 3.897527082542536, 3.9118249875644473, 4.985235394705006, 5.946411427434287, 6.883326607417738, 7.95759953056421, 9.030373271597535, 10.019819587616267, 10.97484331932738, 11.790594383485889, 10.807567259993162, 9.87023568128682, 8.932153895497773, 7.949682032103012, 6.944740362763614, 5.88430351595263, 4.846780368554644, 3.855917250753473, 2.99194761434529, 2.015355733402311, 2.9476356196757276, 2.9438161055227057, 3.9897576263981263, 5.039730585959344, 6.02149263015791, 7.055073992275494, 8.056672917425363, 9.012192999614491, 10.043449426394428, 11.00147965310091, 9.965200035617961, 8.925652532409813, 7.9686982724849615, 6.921273692829472, 5.929483565274312, 4.944461891224173, 3.882293031343936, 2.889272515796172, 1.9586697595137839, 0.946178918856855, 1.9242788718259365], [1.942986848663539, 0.9933423355439889, 0.0, 0.9597921535415713, 2.0132588571555456, 3.0179571722443965, 4.032239075166235, 5.086347714126238, 6.1258855178661555, 7.192729919541831, 8.180295756479081, 9.206771346765233, 10.019303456272217, 9.029310557630115, 8.072711026775538, 7.101675199518876, 6.063174265108276, 5.050982305959435, 4.002435065347562, 2.9827985949537936, 2.9144623145774045, 1.969378220224145, 1.0308063110088417, 1.900190232529515, 2.835343637254815, 3.812556850205617, 4.87358273885369, 5.8088084704083816, 6.795555477040843, 7.816671506236393, 8.770776764245173, 9.700409773646438, 10.739133791619164, 9.841431308612288, 8.802909871917654, 7.796539990580143, 6.833579619434911, 5.788598126377406, 4.801978809337305, 3.8550524207812846, 3.932183577840099, 2.9700340420129576, 2.0656377737007716, 2.92908410568248, 3.844447398543336, 4.800895296704922, 5.850109010222938, 6.85803094798186, 7.770979787200748, 8.723808733758815, 9.74595261699749, 10.637909219575757, 11.695345197803883, 10.795140719031659, 9.822140829164892, 8.847515615208353, 7.808469109995331, 6.758037181520491, 5.794022306804056, 4.7928189715929745, 4.9651774244625155, 3.9314431168521047, 3.114762936165091, 3.8915947296747673, 4.797397294608004, 5.824666722790862, 6.807545586809814, 7.806630386329589, 8.752309510477701, 9.677375084616408, 10.723249095498304, 11.650272924054198, 12.613903972717589, 11.814561111647405, 10.766446990677279, 9.722338303622683, 8.65284683469289, 7.714717212703339, 6.717180883488006, 5.779673043752814, 5.9102007247280195, 4.969618049111192, 4.064805642521738, 4.9304679016562725, 5.857029997222468, 6.790677925931021, 7.779729571206042, 8.722465484828863, 9.704896970728141, 10.711369422921651, 11.66447657369939, 12.580364678541992, 13.573332732919656, 12.70416178025059, 11.640752895075305, 10.683922539127769, 9.633060255863876, 8.676182433453793, 7.711617737979517, 6.771026584699131, 6.85724326532851, 5.969127549163366, 5.1115039714641135, 5.929481271999959, 6.928131881009322, 7.724270236753924, 8.764530063602882, 9.64771412561411, 10.620626986049665, 11.60627883966967, 12.540868828527465, 13.567314906349395, 14.574692366960095, 13.677079940497475, 12.61074992908286, 11.563562735135719, 10.588788792340214, 9.582741661000929, 8.646176450503527, 7.745819984200348, 7.850445353451873, 6.982868088035536, 6.143766566316201, 6.918684700988649, 7.894956952842722, 8.775069132353924, 9.770876867417666, 10.59380807233042, 11.551964136705108, 12.542058866631114, 13.489536185749165, 14.455317189536695, 15.38579772796716, 14.467594574027167, 13.459777793727516, 12.481068135223458, 11.52162282185746, 10.517361524647491, 9.61029476621269, 8.734862272118722, 8.817651666750015, 7.9939300086738525, 7.1349175666355285, 7.942777798541169, 8.950623581825578, 9.76053180819593, 10.72444420824241, 11.54031685477052, 12.493780026933372, 13.460982496475912, 14.52058470571293, 15.476263174959918, 16.317892063829145, 15.268133933231054, 14.283858858838919, 13.341765343542566, 12.394440753643906, 11.462583073365382, 10.550013931258464, 9.74320757685065, 9.746251722854172, 9.066656967849227, 8.087871953752474, 9.009932795921513, 9.982011415192476, 10.742574870895572, 11.729078463437919, 12.608997086011104, 13.568753336621667, 14.424044546825266, 15.419690551967673, 16.42743066383682, 16.44787138100217, 15.3905538640995, 14.436945141109721, 13.499205735790937, 12.84252967318119, 12.031767856423139, 11.591385094487563, 10.703759788931348, 10.752743767564283, 10.040847208355238, 9.122991188930817, 9.979132803416238, 10.962523889572271, 11.754370971241828, 12.662292011356675, 13.552169452536226, 14.521971144449525, 15.394146978849399, 16.34746457111715, 16.368088196973336, 15.434535156472466, 14.506008031968658, 13.486573738186994, 12.513274357606578, 11.786326968300568, 11.080073614759899, 11.990981901838918, 11.769223953521342, 11.719375192760719, 11.109755591377976, 10.180674161179846, 10.977335567766833, 11.90648488506567, 12.710309599586575, 13.600109215070914, 14.478438733634947, 15.501130893744241, 16.416980653508283, 16.3937207730103, 15.337726538878062, 14.406578540771799, 13.459609154996414, 12.534408711592949, 11.553570766884343, 10.767182017593402, 10.00945916125284, 10.961211964494652, 11.659859563780456, 11.722482123740527, 12.07925097819447, 11.11858149280448, 11.993430964816111, 12.926703225764527, 13.782087512657323, 14.62062146380432, 15.4586277157461, 16.522634754148562, 16.582787522470927, 15.586493306146945, 14.6221667063232, 13.553113659997797, 12.569844897690778, 11.560024542371627, 10.580796927685169, 9.76893654283275, 9.008650964569785, 9.936258040675051, 10.727397352200201, 10.71528133358181, 11.641694859872032, 12.054048302454868, 12.924728279018058, 13.902422331829094, 14.842879904177762, 15.628977753174954, 16.52833215687139, 16.408178569856865, 15.566152420825517, 14.578440347145712, 13.580148736992955, 12.578185049329552, 11.570718297960902, 10.577093435064747, 9.637298387711779, 8.717215817306176, 8.038326586278528, 8.867520646318487, 9.741108860787664, 9.717442034817381, 10.678671784377995, 11.652377372353076, 12.576193257848145, 13.565524734343045, 14.62993404970447, 15.665980839235162, 16.436506073789744, 15.455479106909097, 14.495342788890236, 13.542072859185119, 12.532515750414651, 11.58511432543729, 10.62228910848965, 9.63829543866755, 8.69977159835192, 7.751076625798342, 7.049876473410656, 7.859819865864864, 8.80251345679471, 8.77159276727011, 9.729626147810038, 10.72517443904197, 11.613494171031432, 12.673286573188841, 13.679212644494884, 14.71623523046179, 15.426942651048666, 14.52249350256789, 13.560240269268737, 12.582870220251126, 11.666344300967493, 10.710653817734794, 9.736425432071613, 8.686443050830537, 7.719190497436237, 6.771390378716691, 6.067226115103013, 6.890564252409278, 7.8298115055302535, 7.746244280012302, 8.81394657170091, 9.796009142331965, 10.687724192066584, 11.738701860221719, 12.678047808218025, 13.666981481620617, 14.464613492568137, 13.497190812169213, 12.552734058514753, 11.627383938281037, 10.732762680273765, 9.77996321248712, 8.769421720034359, 7.8243217846409, 6.781595082547201, 5.748033489944952, 4.995830905822469, 5.9378089383966195, 6.780546474968519, 6.818043113492931, 7.838147968875303, 8.844830639627007, 9.729791384667108, 10.729549794128552, 11.728506273629378, 12.70820055035283, 13.497515111464805, 12.543093910548532, 11.642705998241356, 10.689731699269275, 9.72897576737213, 8.771446939801802, 7.738228716503265, 6.807673589545104, 5.789873205420577, 4.7850096001059415, 3.977027205966399, 4.923499468221282, 5.848985245201734, 5.844611835589936, 6.791485120988072, 7.777516894989995, 8.797607286308091, 9.86434210452313, 10.819466146311875, 11.77576733418142, 12.624941079878734, 11.59928324733775, 10.611240437554603, 9.680082069752718, 8.659318256571865, 7.73074903910927, 6.790300682452076, 5.783927695285706, 4.788966896762544, 3.8248168687967232, 2.9970108045421613, 3.9578142554851006, 4.890869418086526, 4.9051673231084365, 5.978577730248995, 6.939753762978277, 7.876668942961727, 8.950941866108199, 10.023715607141522, 11.013161923160256, 11.78339643791722, 10.7972520479419, 9.814224924449173, 8.87689334574283, 7.938811559953784, 6.956339696559023, 5.951398027219625, 4.890961180408642, 3.853438033010655, 2.8625749152094837, 2.0188379786575545, 3.0086980689463, 3.940977955219717, 3.937158441066695, 4.9830999619421155, 6.033072921503333, 7.014834965701899, 8.048416327819483, 9.050015252969352, 10.00553533515848, 11.003176170914564, 10.044264621755696, 8.971857700073972, 7.932310196865824, 6.975355936940972, 5.927931357285483, 4.936141229730323, 3.951119555680184, 2.888950695799947, 1.8959301802521829, 0.9855601238260481, 1.939521254400844, 2.9176212073699257], [2.9027790022051105, 1.9531344890855602, 0.9597921535415713, 0.0, 1.0534667036139742, 2.058165018702825, 3.072446921624663, 4.126555560584666, 5.166093364324584, 6.2329377660002585, 7.220503602937508, 8.246979193223659, 9.210921865864053, 9.989102711171688, 9.03250318031711, 8.061467353060449, 7.022966418649848, 6.0107744595010075, 4.962227218889134, 3.942590748495365, 3.8742544681189757, 2.929170373765716, 1.9905984645504131, 0.9403980789879436, 1.8755514837132437, 2.8527646966640456, 3.9137905853121193, 4.849016316866811, 5.835763323499272, 6.856879352694822, 7.810984610703602, 8.740617620104866, 9.779341638077591, 10.760618114442343, 9.762702025459225, 8.756332144121714, 7.7933717729764815, 6.7483902799189766, 5.761770962878876, 4.814844574322856, 4.89197573138167, 3.9298261955545293, 2.9671573089988015, 1.9692919521409087, 2.8846552450017646, 3.841103143163351, 4.890316856681367, 5.89823879444029, 6.811187633659177, 7.764016580217245, 8.786160463455918, 9.678117066034185, 10.73555304426231, 11.684137040335019, 10.781932982706463, 9.807307768749924, 8.768261263536901, 7.717829335062062, 6.753814460345627, 5.752611125134546, 5.904238560022295, 4.865830407324317, 3.8816137405052693, 2.931802576133196, 3.837605141066433, 4.864874569249292, 5.8477534332682435, 6.846838232788018, 7.792517356936131, 8.717582931074837, 9.763456941956733, 10.690480770512625, 11.654111819176016, 12.69922038796153, 11.72623914421885, 10.682130457164254, 9.61263898823446, 8.67450936624491, 7.676973037029578, 6.739465197294385, 6.831183220210239, 5.799499020916243, 4.831656446861916, 3.9706757481147013, 4.897237843680897, 5.8308857723894505, 6.819937417664471, 7.762673331287291, 8.74510481718657, 9.75157726938008, 10.70468442015782, 11.62057252500042, 12.613540579378084, 13.62582872572007, 12.600545048616876, 11.64371469266934, 10.592852409405447, 9.635974586995363, 8.671409891521089, 7.7308187382407025, 7.754214522465147, 6.799008520968417, 5.878354775804292, 4.969689118458387, 5.968339727467751, 6.764478083212353, 7.804737910061311, 8.68792197207254, 9.660834832508094, 10.6464866861281, 11.581076674985894, 12.607522752807824, 13.614900213418522, 14.586311414132679, 13.570542082624431, 12.52335488867729, 11.548580945881785, 10.5425338145425, 9.605968604045097, 8.684842633176066, 8.74741661058851, 7.812749059840588, 6.91061737065638, 5.9588925474470775, 6.93516479930115, 7.815276978812353, 8.811084713876095, 9.63401591878885, 10.592171983163537, 11.582266713089544, 12.529744032207594, 13.495525035995124, 14.42600557442559, 15.427386727568738, 14.419569947269087, 13.440860288765029, 12.48141497539903, 11.477153678189062, 10.57008691975426, 9.67388492109444, 9.714622923886653, 8.823810980478905, 7.901768370975707, 6.982985644999597, 7.9908314282840065, 8.80073965465436, 9.76465205470084, 10.58052470122895, 11.533987873391801, 12.501190342934342, 13.560792552171359, 14.516471021418347, 15.358099910287576, 15.402948263565886, 14.41867318917375, 13.476579673877398, 12.885353569234926, 12.422375226906953, 11.509806084800035, 10.68223022582637, 10.64322297999081, 9.833507772189405, 8.854722758092652, 8.05014064237994, 9.022219261650903, 9.782782717354001, 10.769286309896348, 11.649204932469534, 12.608961183080096, 13.464252393283695, 14.459898398426102, 15.467638510295249, 15.488079227460597, 14.430761710557928, 13.477152987568148, 12.539413582249365, 11.882737519639619, 12.718629382520415, 12.551177248029134, 11.642782437907067, 11.649715024700921, 10.807698012695417, 9.889841993270995, 9.019340649874668, 10.0027317360307, 10.794578817700257, 11.702499857815104, 12.592377298994656, 13.562178990907954, 14.434354825307828, 15.387672417575581, 15.408296043431763, 14.474743002930893, 13.546215878427086, 12.526781584645422, 11.553482204065006, 10.826534814758997, 11.766935140857175, 12.721852058000298, 12.708246602497061, 12.616346449897357, 11.876606395718154, 10.947524965520024, 10.017543414225262, 10.946692731524099, 11.750517446045004, 12.640317061529343, 13.518646580093376, 14.54133874020267, 15.457188499966714, 15.433928619468729, 14.37793438533649, 13.446786387230226, 12.499817001454842, 11.574616558051376, 10.59377861334277, 9.807389864051832, 10.696320687350116, 11.693987800724368, 12.492546112249434, 12.555168672209504, 12.846101782534648, 11.885432297144659, 11.03363881127454, 11.966911072222956, 12.822295359115753, 13.660829310262748, 14.49883556220453, 15.562842600606992, 15.62299536892935, 14.62670115260537, 13.662374552781628, 12.593321506456224, 11.610052744149206, 10.600232388830054, 9.621004774143596, 8.809144389291179, 9.695512490667062, 10.719093262071073, 11.560083900669179, 11.547967882050788, 12.47438140834101, 12.820899106795046, 11.964936125476488, 12.942630178287523, 13.883087750636191, 14.669185599633384, 15.56854000332982, 15.44838641631529, 14.606360267283943, 13.61864819360414, 12.620356583451382, 11.618392895787979, 10.610926144419329, 9.617301281523174, 8.677506234170206, 7.757423663764605, 8.725188112375804, 9.690174178992029, 10.573795409256642, 10.550128583286359, 11.511358332846973, 12.485063920822054, 12.93785950869527, 13.87782586172458, 14.8442503921754, 15.718759236408765, 15.47671392024817, 14.495686953367523, 13.535550635348661, 12.582280705643548, 11.572723596873079, 10.625322171895718, 9.662496954948077, 8.678503285125977, 7.739979444810347, 6.791284472256771, 7.736737999507933, 8.692506414333842, 9.635200005263687, 9.604279315739088, 10.562312696279015, 11.557860987510947, 12.512965924230482, 13.572758326387891, 14.578684397693934, 15.511505109454793, 14.467150497507092, 13.562701349026316, 12.600448115727163, 11.623078066709551, 10.70655214742592, 9.750861664193222, 8.77663327853004, 7.726650897288964, 6.759398343894665, 5.8115982251751195, 6.75408764120029, 7.723250800878255, 8.662498053999231, 8.57893082848128, 9.646633120169888, 10.628695690800942, 11.587195945265634, 12.638173613420769, 13.577519561417075, 14.478517836625935, 13.504821339026563, 12.53739865862764, 11.592941904973179, 10.667591784739463, 9.772970526732193, 8.820171058945547, 7.809629566492786, 6.8645296310993285, 5.82180292900563, 4.78824133640338, 5.828517454291447, 6.770495486865597, 7.6132330234374965, 7.6507296619619085, 8.680232196404122, 9.71855413197661, 10.629263137866158, 11.629021547327602, 12.627978026828428, 13.519736905358148, 12.537722957923231, 11.583301757006957, 10.682913844699781, 9.729939545727701, 8.769183613830558, 7.811654786260229, 6.7784365629616925, 5.847881436003532, 4.830081051879005, 3.82521744656437, 4.809713754435377, 5.756186016690259, 6.681671793670712, 6.744083588788986, 7.690956874187122, 8.676988648189045, 9.697079039507141, 10.76381385772218, 11.718937899510925, 12.67523908738047, 11.66514892633716, 10.639491093796176, 9.651448284013028, 8.720289916211144, 7.699526103030292, 6.770956885567698, 5.830508528910505, 4.824135541744134, 3.829174743220972, 2.8650247152551516, 3.829697353011139, 4.790500803954078, 5.790341171285576, 5.864959476650007, 6.938369883790566, 7.899545916519847, 8.836461096503298, 9.91073401964977, 10.983507760683093, 11.778628016086763, 10.82360428437565, 9.837459894400329, 8.854432770907602, 7.917101192201261, 6.979019406412213, 5.996547543017452, 4.991605873678054, 3.93116902686707, 2.893645879469083, 1.9027827616679123, 2.9349952320453694, 3.968490222487871, 4.900770108761288, 4.896950594608266, 5.942892115483686, 6.992865075044904, 7.974627119243472, 9.008208481361056, 10.009807406510925, 10.965327488700053, 10.043384017372993, 9.084472468214125, 8.012065546532401, 6.9725180433242535, 6.015563783399402, 4.968139203743912, 3.976349076188752, 2.991327402138613, 1.9291585422583757, 0.9361380267106116, 1.9385516350772587, 2.899313407942415, 3.877413360911497], [3.9562457058190845, 3.0066011926995344, 2.0132588571555456, 1.0534667036139742, 0.0, 1.0046983150888507, 2.0189802180106886, 3.073088856970692, 4.1126266607106094, 5.179471062386284, 6.167036899323533, 7.1935124896096845, 8.157455162250079, 9.14744806089218, 10.085969883931083, 9.114934056674421, 8.076433122263822, 7.06424116311498, 6.015693922503107, 4.996057452109339, 4.904811302950527, 3.9597272085972683, 2.981270001804087, 1.9227321407074562, 0.9875787359821562, 1.964791948932958, 2.958873422088626, 3.8940991536433174, 4.8808461602757784, 5.901962189471329, 6.856067447480108, 7.785700456881372, 8.824424474854098, 9.80570095121885, 10.793258860290777, 9.786888978953266, 8.823928607808034, 7.778947114750529, 6.792327797710428, 5.845401409154408, 5.922532566213222, 4.960383030386081, 3.949491370718314, 2.9516260138604213, 1.9966824972706771, 2.9531303954322627, 3.982475093576376, 4.943321631216796, 5.856270470435684, 6.809099416993751, 7.831243300232424, 8.723199902810691, 9.780635881038817, 10.729219877111525, 11.702219766978292, 10.837864603581476, 9.798818098368454, 8.748386169893614, 7.784371295177179, 6.783167959966098, 6.886572621741806, 5.848164469043829, 4.863947802224781, 3.9141366378527085, 2.949632393335346, 3.9769018215182035, 4.939911670163252, 5.938996469683027, 6.837600193712637, 7.7626657678513435, 8.80853977873324, 9.735563607289132, 10.699194655952523, 11.744303224738037, 12.646525928490679, 11.712687291995806, 10.643195823066012, 9.705066201076463, 8.70752987186113, 7.7700220321259375, 7.813517281929751, 6.781833082635755, 5.813990508581428, 4.953009809834214, 4.00926509594981, 4.942913024658363, 5.931964669933384, 6.874700583556204, 7.857132069455483, 8.796660106156587, 9.749767256934327, 10.665655361776926, 11.65862341615459, 12.670911562496576, 13.631101883448428, 12.674271527500892, 11.623409244237, 10.666531421826916, 9.692009039238327, 8.75141788595794, 8.736548584184659, 7.7813425826879286, 6.860688837523804, 5.9520231801779, 5.080366979736664, 5.876505335481266, 6.916765162330224, 7.799949224341452, 8.772862084777007, 9.758513938397012, 10.693103927254807, 11.687698937829854, 12.659983050195029, 13.631394250909185, 14.601098917455984, 13.553911723508842, 12.579137780713337, 11.563132962259738, 10.626567751762336, 9.667176694895577, 9.729750672308022, 8.795083121560099, 7.892951432375892, 6.94122660916659, 6.072310082031999, 6.927304231081266, 7.923111966145008, 8.746043171057762, 9.70419923543245, 10.694293965358456, 11.641771284476507, 12.607552288264037, 13.538032826694502, 14.583870492776416, 14.585949737990852, 13.689586850937193, 13.511971810230582, 12.4977528259063, 11.590686067471498, 10.656218982813952, 10.696956985606164, 9.806145042198416, 8.884102432695219, 7.96531970671911, 7.127976711014855, 7.912766906923271, 8.876679306969752, 9.692551953497862, 10.646015125660714, 11.613217595203254, 12.672819804440271, 13.62849827368726, 14.470127162556489, 14.59997496984618, 13.615699895454044, 12.673606380157691, 13.620930970056351, 13.44297437462419, 12.530405232517273, 11.66456428754588, 11.625557041710321, 10.815841833908918, 9.837056819812165, 9.032474704099453, 8.159364544381752, 8.894809969622914, 9.88131356216526, 10.761232184738446, 11.720988435349009, 12.576279645552608, 13.571925650695015, 14.579665762564161, 14.685105933740891, 13.627788416838222, 12.674179693848442, 11.736440288529659, 12.74108881361718, 13.684519553761223, 13.571776395746372, 12.625116499626579, 12.632049086420434, 11.79003207441493, 10.872176054990508, 10.00167471159418, 9.210034823983332, 9.90660606996917, 10.814527110084017, 11.704404551263568, 12.674206243176867, 13.546382077576741, 14.499699669844494, 14.605322749712057, 13.671769709211187, 12.74324258470738, 11.723808290925716, 10.7505089103453, 11.793720366766326, 12.783672337549055, 13.738589254692178, 13.690580664216572, 13.59868051161687, 12.858940457437667, 11.929859027239537, 10.999877475944775, 10.15399581947673, 10.862544698313917, 11.752344313798256, 12.63067383236229, 13.653365992471583, 14.569215752235626, 14.630955325749023, 13.574961091616784, 12.64381309351052, 11.696843707735136, 10.77164326433167, 9.790805319623065, 10.774575416059163, 11.713057884041996, 12.710724997416248, 13.546012815863408, 13.608635375823479, 13.82843584425416, 12.867766358864172, 12.015972872994054, 11.196237189535054, 11.934322611384665, 12.772856562531661, 13.610862814473442, 14.674869852875904, 14.782768875871175, 13.786474659547196, 12.859401259061922, 11.790348212736518, 10.8070794504295, 9.797259095110348, 8.81803148042389, 9.77632994129851, 10.748979194281038, 11.77255996568505, 12.613550604283153, 12.601434585664762, 13.527848111954984, 13.80323316851456, 12.947270187196, 12.223581201404485, 12.995115002905104, 13.781212851902296, 14.680567255598733, 14.589692499058007, 13.74766635002666, 12.778421700545962, 11.817383289731676, 10.815419602068273, 9.807952850699623, 8.814327987803468, 7.8745329404505, 8.81089036737858, 9.77865481598978, 10.743640882606005, 11.627262112870616, 11.603595286900333, 12.564825036460947, 13.538530624436028, 13.920193570414783, 13.158776884841542, 13.956277644444313, 14.830786488677678, 14.618020002990887, 13.63699303611024, 12.67685671809138, 11.73622291800096, 10.769750303153373, 9.822348878176012, 8.859523661228371, 7.875529991406271, 6.937006151090641, 7.844751175870745, 8.790204703121908, 9.745973117947816, 10.688666708877662, 10.657746019353063, 11.61577939989299, 12.611327691124922, 13.566432627844454, 14.096216908849481, 14.991728624256933, 14.652811192197511, 13.60845658024981, 12.704007431769034, 11.74175419846988, 10.764384149452269, 9.855306642644445, 8.899616159411746, 7.953159427443253, 6.923677603569258, 5.956425050174959, 6.865064928789094, 7.807554344814265, 8.776717504492229, 9.715964757613206, 9.632397532095254, 10.700099823783862, 11.682162394414917, 12.640662648879607, 13.691640317034741, 14.590278799412966, 13.619823919368654, 12.64612742176928, 11.678704741370357, 10.734247987715896, 9.80889786748218, 8.921725021950717, 7.968925554164072, 6.95838406171131, 6.029786251020523, 5.018829635285924, 5.841708040017354, 6.881984157905421, 7.8239621904795715, 8.666699727051471, 8.704196365575882, 9.733698900018096, 10.772020835590585, 11.68272984148013, 12.682488250941574, 13.640737264824319, 12.661042988100867, 11.67902904066595, 10.724607839749677, 9.8242199274425, 8.871245628470419, 7.917938109049081, 6.9604092814787535, 5.927191058180217, 4.996635931222055, 4.027107758159299, 4.878684150178344, 5.863180458049351, 6.809652720304234, 7.735138497284686, 7.797550292402961, 8.744423577801095, 9.730455351803018, 10.750545743121114, 11.817280561336153, 12.659885116714726, 11.70358392884518, 10.80645500907988, 9.780797176538895, 8.792754366755748, 7.861595998953862, 6.848280598248817, 5.9197113807862225, 4.979263024129029, 3.972890036962658, 2.9779292384394958, 3.918491418869126, 4.883164056625113, 5.843967507568053, 6.84380787489955, 6.918426180263982, 7.99183658740454, 8.953012620133821, 9.88992780011727, 10.964200723263742, 11.80537415773733, 10.751040944925753, 9.79601721321464, 8.809872823239319, 7.826845699746593, 6.889514121040251, 5.951432335251203, 4.968960471856443, 3.9640188025170446, 2.9889719391651712, 2.042400374687607, 2.9562494652818865, 3.9884619356593434, 5.021956926101845, 5.954236812375262, 5.9504172982222405, 6.996358819097661, 8.046331778658878, 9.028093822857446, 10.06167518497503, 11.00257345518105, 10.047053372991922, 9.015796946211985, 8.056885397053115, 6.984478475371392, 5.9449309721632435, 4.987976712238392, 3.9405521325829027, 2.948762005027742, 1.9637403309776031, 1.013421582400521, 1.9896047303245858, 2.992018338691233, 3.9527801115563896, 4.930880064525471], [4.960944020907935, 4.011299507788385, 3.017957172244396, 2.058165018702825, 1.0046983150888507, 0.0, 1.014281902921838, 2.0683905418818416, 3.107928345621759, 4.174772747297434, 5.162338584234683, 6.188814174520834, 7.152756847161228, 8.14274974580333, 9.099349276657907, 10.07038510391457, 9.08113143735267, 8.06893947820383, 7.020392237591958, 6.000755767198189, 5.909509618039378, 4.964425523686119, 3.9859683168929374, 2.9274304557963067, 1.9922770510710068, 1.0459553064311, 1.954175106999775, 2.8894008385544665, 3.876147845186927, 4.897263874382477, 5.851369132391257, 6.781002141792521, 7.8197261597652465, 8.801002636129999, 9.839524072824632, 10.791587294042117, 9.828626922896884, 8.783645429839378, 7.797026112799278, 6.850099724243258, 6.927230881302073, 5.965081345474932, 4.954189685807164, 3.9563243289492718, 3.001380812359528, 2.034293752930405, 2.9777767784875246, 3.938623316127945, 4.851572155346832, 5.8044011019049, 6.826544985143573, 7.71850158772184, 8.775937565949965, 9.724521562022673, 10.69752145188944, 11.753793432462158, 10.803516413457304, 9.753084484982464, 8.78906961026603, 7.787866275054949, 7.891270936830656, 6.85286278413268, 5.868646117313632, 4.918834952941559, 3.9543307084241963, 3.058065179016346, 3.935213355074401, 4.934298154594176, 5.832901878623786, 6.757967452762492, 7.803841463644388, 8.730865292200281, 9.694496340863672, 10.739604909649186, 11.641827613401826, 12.716000819742526, 11.647894138154863, 10.709764516165313, 9.71222818694998, 8.774720347214789, 8.8182155970186, 7.786531397724605, 6.8186888236702785, 5.957708124923064, 4.995721433528525, 4.062073504819971, 4.945266028277387, 5.888001941900207, 6.854546329566067, 7.791961791067736, 8.745068941845474, 9.660957046688075, 10.65392510106574, 11.666213247407725, 12.711956488076169, 13.668786844023705, 12.62810755932585, 11.671229736915766, 10.696707354327176, 9.756116201046789, 9.74124689927351, 8.786040897776779, 7.865387152612654, 6.95672149526675, 5.933272875358069, 4.995665815642873, 6.007682509692707, 6.813250582685454, 7.7861634431210085, 8.769629115489735, 9.70421910434753, 10.683000622741003, 11.655284735106179, 12.626695935820335, 13.69302594723495, 14.558610038597692, 13.583836095802187, 12.567831277348587, 11.631266066851184, 10.671875009984428, 10.734448987396872, 9.79978143664895, 8.897649747464742, 7.901488229507477, 6.925215977653404, 6.046464711242873, 7.014029313507491, 7.759344529401765, 8.717500593776453, 9.70540914245118, 10.65288646156923, 11.61866746535676, 12.549148003787225, 13.59498566986914, 13.911313722761506, 14.668983247723894, 14.516670125319433, 13.502451140995149, 12.595384382560347, 11.660917297902802, 11.701655300695014, 10.810843357287267, 9.88880074778407, 8.925581327059996, 7.980882606636261, 7.031927387084878, 7.967596654332235, 8.705853311841866, 9.659316484004718, 10.626518953547258, 11.686121162784275, 12.641799632031264, 13.481242339649212, 13.873168893502179, 12.941063880224698, 13.653002776944392, 14.600327366843052, 14.44767268971304, 13.535103547606122, 12.669262602634731, 12.630255356799172, 11.820540148997768, 10.841755134901016, 9.99273632444034, 9.012270440003158, 8.013970449784521, 8.972230909527743, 9.77453354308245, 10.734289793693012, 11.589581003896612, 12.585227009039018, 13.592967120908165, 13.82643699213834, 12.87907070066489, 11.925461977675111, 12.71583668531636, 13.720485210403881, 14.663915950547924, 14.576474710835221, 13.629814814715429, 13.636747401509282, 12.79473038950378, 11.876874370079358, 10.961936331935068, 10.021952807075797, 9.025766550130777, 9.9054444574465, 10.71770590960757, 11.687507601520869, 12.559683435920745, 13.513001028188498, 13.746653808109507, 12.813100767608637, 11.956194276295122, 10.936759982513458, 11.729905307132, 12.773116763553027, 13.763068734335755, 14.717985651478878, 14.695278979305423, 14.603378826705718, 13.863638772526517, 12.915598728814471, 11.907812282342428, 10.965913802569194, 9.981705178475524, 10.843261661160739, 11.643975190706291, 12.666667350815585, 13.58251711057963, 13.757159867984527, 12.716292150014233, 11.78514415190797, 10.909795399322878, 9.984594955919412, 10.770201716409765, 11.753971812845863, 12.692454280828697, 13.690121394202949, 14.550711130952257, 14.613333690912327, 14.833134159343011, 13.853506060439106, 12.923907679391707, 12.008155172627518, 11.053483091546273, 11.863773909894144, 12.624164172817444, 13.688171211219906, 13.778070560782323, 12.781776344458343, 11.898682171255075, 10.830740793881642, 9.932358428067989, 8.968511625306713, 9.797427877210591, 10.75572633808521, 11.740273750319025, 12.763854521723037, 13.618248919372002, 13.606132900753611, 14.532546427043833, 14.788972870089493, 13.855204993593652, 13.035499184496949, 12.114275483066711, 12.87213019926478, 13.693868613942735, 13.584994183969158, 12.74296803493781, 11.773723385457112, 10.85666420192483, 9.855812183213397, 8.933231828338112, 7.939606965441957, 8.8539293372372, 9.800042314248696, 10.770288897595451, 11.735274964211676, 12.631960427959465, 12.608293601989182, 13.569523351549796, 14.543228939524877, 14.828128376812435, 13.970694867934006, 13.07543812460592, 13.921703836040159, 13.613321687902037, 12.63229472102139, 11.672158403002529, 10.73152460291211, 9.809031215346526, 8.862741459321136, 7.98480263886686, 7.00080896904476, 7.916402547877341, 8.849449490959596, 9.794903018210759, 10.750671433036665, 11.69336502396651, 11.662444334441911, 12.620477714981838, 13.61602600621377, 14.571130942933305, 14.908134891941945, 14.11088910441854, 13.64811287710866, 12.603758265160959, 11.699309116680183, 10.73705588338103, 9.759685834363419, 8.859430267810495, 7.903739784577796, 6.957283052609303, 6.048956581207747, 6.9358214469616595, 7.869763243877944, 8.812252659903116, 9.781415819581078, 10.720663072702054, 10.637095847184103, 11.704798138872711, 12.686860709503765, 13.645360963968457, 14.559686065854516, 13.585580484324115, 12.615125604279804, 11.64142910668043, 10.674006426281506, 9.729549672627046, 8.80419955239333, 7.925848647116767, 6.973049179330122, 5.962507686877361, 5.0339098761865735, 5.998226032072624, 6.846406355106205, 7.886682472994271, 8.82866050556842, 9.67139804214032, 9.708894680664732, 10.738397215106946, 11.776719150679437, 12.68742815656898, 13.634087881060234, 12.636038949735468, 11.656344673012017, 10.6743307255771, 9.719909524660826, 8.81952161235365, 7.866547313381568, 6.922061734215132, 5.964532906644804, 4.931314683346267, 4.000759556388106, 5.006504154946, 5.883382465267195, 6.867878773138201, 7.814351035393083, 8.739836812373536, 8.80224860749181, 9.749121892889946, 10.735153666891868, 11.755244058209964, 12.610310843414622, 11.655186801625877, 10.698885613756332, 9.80175669399103, 8.776098861450045, 7.7880560516668975, 6.856897683865012, 5.852404223414866, 4.923835005952272, 3.9833866492950785, 2.9770136621287078, 3.9573256352261965, 4.923189733957976, 5.887862371713963, 6.848665822656902, 7.848506189988399, 7.923124495352832, 8.99653490249339, 9.957710935222671, 10.894626115206123, 11.873449583681802, 10.800675842648479, 9.746342629836903, 8.79131889812579, 7.805174508150468, 6.822147384657742, 5.8848158059514, 4.946734020162353, 3.964262156767592, 2.959320487428194, 1.9842736240763208, 3.0217967714743077, 3.960947780370737, 4.993160250748193, 6.026655241190696, 6.9589351274641125, 6.955115613311091, 8.001057134186512, 9.05103009374773, 10.032792137946295, 11.024511264019438, 9.997875140092201, 9.042355057903073, 8.011098631123135, 7.052187081964266, 5.979780160282542, 4.940232657074393, 3.983278397149541, 2.9358538174940523, 1.9440636899388917, 0.9590420158887526, 2.0181198974893717, 2.9943030454134365, 3.9967166537800836, 4.95747842664524, 5.935578379614322], [5.9752259238297745, 5.025581410710224, 4.032239075166235, 3.072446921624663, 2.0189802180106886, 1.014281902921838, 0.0, 1.0541086389600036, 2.093646442699921, 3.160490844375596, 4.148056681312846, 5.174532271598997, 6.138474944239391, 7.128467842881494, 8.085067373736072, 9.056103200992734, 10.094604135403333, 9.08322138112567, 8.034674140513797, 7.015037670120028, 6.8953648726451835, 5.9502807782919245, 4.971823571498743, 3.9132857104021124, 2.9781323056768123, 2.0009190927260105, 0.9398932040779372, 1.8751189356326288, 2.8618659422650894, 3.8829819714606395, 4.83708722946942, 5.7667202388706835, 6.805444256843409, 7.786720733208162, 8.825242169902795, 9.831612051240306, 10.794572422385539, 9.769500684445184, 8.782881367405084, 7.835954978849064, 7.913086135907879, 6.9509366000807375, 5.94004494041297, 4.9421795835550775, 3.987236066965333, 2.9892575392253153, 1.963494875565687, 2.9243414132061076, 3.8372902524249946, 4.790119198983063, 5.812263082221736, 6.704219684800003, 7.761655663028129, 8.710239659100836, 9.683239548967602, 10.739511529540321, 11.776517839995282, 10.73893973958827, 9.774924864871835, 8.773721529660754, 8.877126191436462, 7.838718038738485, 6.854501371919437, 5.904690207547365, 4.940185963030002, 3.9045509552623403, 2.9209314521525633, 3.9200162516723376, 4.8186199757019486, 5.743685549840655, 6.789559560722551, 7.716583389278444, 8.680214437941835, 9.725323006727349, 10.627545710479989, 11.701718916820688, 12.633749392760668, 11.695619770771119, 10.698083441555786, 9.760575601820594, 9.804070851624406, 8.772386652330411, 7.804544078276084, 6.806414076237797, 5.842207209774519, 4.9085592810659655, 3.930984125355549, 4.8737200389783695, 5.84026442664423, 6.777679888145899, 7.730787038923637, 8.646675143766238, 9.639643198143903, 10.651931344485888, 11.697674585154331, 12.654504941101868, 13.613962813931655, 12.657084991521572, 11.682562608932981, 10.741971455652594, 10.727102153879315, 9.771896152382585, 8.833352648080158, 7.805427446581483, 6.779758651604064, 5.842151591888868, 4.9934006067708685, 5.798968679763616, 6.771881540199171, 7.755347212567897, 8.68993720142569, 9.668718719819166, 10.641002832184341, 11.612414032898497, 12.678744044313113, 13.613126369939094, 14.569691350407993, 13.553686531954392, 12.61712132145699, 11.657730264590233, 11.720304242002678, 10.785636691254755, 9.811670213820928, 8.747974005753472, 7.771701753899399, 6.892950487488868, 5.999747410585654, 6.745062626479927, 7.703218690854616, 8.691127239529342, 9.63860455864739, 10.60438556243492, 11.534866100865386, 12.5807037669473, 13.58852054724695, 14.56723020575101, 15.502525379925238, 14.488306395600954, 13.581239637166153, 12.646772552508608, 12.68751055530082, 11.73135731933661, 10.783746620431476, 9.772067103305991, 8.827368382882256, 7.878413163330873, 6.953314751410398, 7.691571408920028, 8.64503458108288, 9.61223705062542, 10.671839259862438, 11.627517729109426, 12.466960436727373, 13.091841307583836, 13.955345783146536, 14.66728467986623, 15.61460926976489, 15.433527944318845, 14.520958802211927, 13.655117857240537, 13.616110611404977, 12.715486021645175, 11.736701007548422, 10.839222100686335, 9.858756216249153, 8.860456226030516, 7.957949006605905, 8.760251640160613, 9.720007890771175, 10.575299100974775, 11.57094510611718, 12.578685217986328, 12.90966381227479, 12.097743114746548, 12.939743880596948, 13.730118588238197, 14.734767113325718, 15.678197853469761, 15.562329965441027, 14.615670069321235, 14.622602656115088, 13.689676262151186, 12.771820242726765, 11.808422108181063, 10.868438583321792, 9.872252326376772, 8.89116255452466, 9.703424006685733, 10.673225698599031, 11.545401532998907, 12.49871912526666, 12.829880628245956, 11.896327587745086, 11.140144092215083, 11.951041885435295, 12.744187210053838, 13.787398666474864, 14.777350637257593, 15.732267554400716, 15.681134233911228, 15.589234081311524, 14.743057367123239, 13.762084505060466, 12.754298058588423, 11.812399578815189, 10.77462438400277, 9.8289797582389, 10.629693287784454, 11.652385447893748, 12.568235207657793, 12.806428830815097, 11.799518970150682, 10.868370972044419, 10.093745215242839, 10.99887685884125, 11.784483619331603, 12.7682537157677, 13.706736183750534, 14.704403297124786, 15.564993033874098, 15.627615593834168, 15.712552753939732, 14.699411070850195, 13.73972829755504, 12.806456036606626, 11.818902132879423, 10.849492006972305, 11.609882269895607, 12.673889308298069, 12.827339523612894, 11.831045307288914, 10.981908991391526, 9.913967614018091, 9.112069157850595, 9.98279352822855, 10.811709780132428, 11.770008241007048, 12.754555653240862, 13.778136424644874, 14.632530822293843, 14.620414803675452, 15.546828329965674, 15.634877880500582, 14.671025611756985, 13.826238144308174, 12.831502150031953, 11.85784829634294, 12.679586711020898, 12.634263146799729, 11.79223699776838, 10.822992348287682, 9.93989102206128, 8.939039003349846, 8.112942558120718, 8.953888868363794, 9.868211240159038, 10.814324217170533, 11.784570800517288, 12.749556867133514, 13.646242330881305, 13.622575504911023, 14.583805254471637, 15.557510842446716, 15.643948994975768, 14.76143382774523, 13.792664791571163, 12.907421933118322, 12.662590650732607, 11.68156368385196, 10.7214273658331, 9.78079356574268, 8.892258035482977, 7.945968279457586, 7.070780080035771, 8.015090871966597, 8.930684450799179, 9.863731393881434, 10.809184921132596, 11.764953335958506, 12.707646926888351, 12.67672623736375, 13.634759617903677, 14.63030790913561, 15.542201509183572, 14.649401074784729, 13.665156877012654, 12.697381839939231, 11.65302722799153, 10.748578079510754, 9.7863248462116, 8.808954797193989, 7.942657087946945, 6.986966604714247, 6.040509872745754, 7.0632384841295845, 7.950103349883497, 8.884045146799782, 9.826534562824953, 10.795697722502918, 11.734944975623893, 11.651377750105942, 12.71908004179455, 13.701142612425604, 14.616431530218724, 13.608955028685086, 12.634849447154686, 11.664394567110374, 10.690698069511, 9.723275389112077, 8.778818635457617, 7.8534685152239, 7.007337019132102, 6.056275999466573, 5.045734507013812, 6.048191779108411, 7.012507934994461, 7.860688258028042, 8.900964375916109, 9.84294240849026, 10.685679945062159, 10.723176583586572, 11.752679118028786, 12.791001053601274, 13.658498722819248, 12.683356843890804, 11.685307912566039, 10.705613635842587, 9.72359968840767, 8.769178487491397, 7.86879057518422, 6.915816276212139, 6.003550106230467, 5.047759726781255, 4.014541503482718, 5.015041459309943, 6.020786057867836, 6.897664368189032, 7.882160676060039, 8.828632938314922, 9.754118715295375, 9.81653051041365, 10.763403795811785, 11.749435569813707, 12.726314624460231, 11.659579806245192, 10.704455764456448, 9.748154576586902, 8.8510256568216, 7.825367824280615, 6.837325014497468, 5.906166646695582, 4.932096849906876, 4.007061826088724, 3.0666134694315303, 3.9912955650505455, 4.971607538148033, 5.937471636879814, 6.902144274635801, 7.86294772557874, 8.862788092910238, 8.937406398274671, 10.01081680541523, 10.97199283814451, 11.90890801812796, 10.922718546512373, 9.84994480547905, 8.795611592667473, 7.840587860956359, 6.854443470981039, 5.871416347488313, 4.934084768781971, 3.996002982992923, 3.013531119598162, 2.0085894502587647, 2.9985555269981585, 4.036078674396145, 4.975229683292575, 6.007442153670032, 7.040937144112535, 7.9732170303859515, 7.96939751623293, 9.015339037108351, 10.06531199666957, 11.046264835996958, 10.013401555973845, 9.047144102922772, 8.091624020733644, 7.060367593953705, 6.101456044794836, 5.029049123113112, 3.9895016199049635, 3.0325473599801116, 1.9851227803246225, 0.993332652769462, 1.9733239188105904, 3.0324018004112094, 4.008584948335274, 5.010998556701921, 5.971760329567079, 6.949860282536161], [7.029334562789778, 6.079690049670227, 5.086347714126238, 4.126555560584666, 3.073088856970692, 2.0683905418818416, 1.0541086389600036, 0.0, 1.0395378037399172, 2.106382205415592, 3.0939480423528414, 4.1204236326389925, 5.084366305279387, 6.07435920392149, 7.030958734776068, 8.00199456203273, 9.04049549644333, 10.05268745559217, 9.088782779473801, 8.069146309080033, 7.891065667465078, 6.945981573111819, 5.967524366318638, 4.908986505222007, 3.973833100496707, 2.996619887545905, 1.9355939988978315, 1.00036826734314, 1.9871152739756006, 3.0082313031711507, 3.9623365611799306, 4.891969570581194, 5.93069358855392, 6.911970064918672, 7.950491501613305, 8.956861382950816, 9.919821754096048, 10.76520147926508, 9.778582162224978, 8.831655773668958, 8.908786930727773, 7.946637394900632, 6.935745735232865, 5.937880378374972, 4.982936861785228, 3.98495833404521, 2.959195670385581, 2.0495907449166184, 2.9625395841355058, 3.9153685306935735, 4.937512413932247, 5.829469016510513, 6.886904994738639, 7.8354889908113465, 8.808488880678114, 9.864760861250833, 10.901767171705792, 11.734640534408165, 10.77062565969173, 9.769422324480647, 9.872826986256358, 8.83441883355838, 7.850202166739332, 6.900391002367259, 5.935886757849897, 4.9002517500822345, 3.9166322469724575, 3.1065414074756426, 3.9438693074124593, 4.868934881551166, 5.9148088924330615, 6.841832720988955, 7.805463769652347, 8.85057233843786, 9.7527950421905, 10.826968248531198, 11.855433387971924, 12.691320565591012, 11.693784236375679, 10.756276396640487, 10.799771646444302, 9.768087447150306, 8.800244873095979, 7.802114871057691, 6.837908004594413, 5.90426007588586, 4.926684920175443, 4.137196297230917, 4.96551375835474, 5.90292921985641, 6.856036370634149, 7.771924475476749, 8.764892529854414, 9.7771806761964, 10.822923916864843, 11.77975427281238, 12.835646809142911, 13.652785786341465, 12.678263403752878, 11.73767225047249, 11.72280294869921, 10.76759694720248, 9.829053442900053, 8.801128241401377, 7.775459446423959, 6.837852386708763, 5.989101401590762, 5.062444938016164, 5.975732427256848, 6.880596544278408, 7.8151865331362025, 8.793968051529678, 9.766252163894853, 10.73766336460901, 11.803993376023623, 12.738375701649606, 13.71314964444511, 14.549387326774289, 13.612822116276886, 12.653431059410128, 12.716005036822573, 11.78133748607465, 10.807371008640823, 9.743674800573366, 8.767402548719293, 7.8886512823087624, 6.9954482054055465, 6.0085388847324745, 6.958583459310544, 7.816376571239852, 8.763853890357902, 9.729634894145432, 10.660115432575898, 11.705953098657812, 12.713769878957462, 13.692479537461521, 14.645983673962355, 15.48400719042085, 14.57694043198605, 13.642473347328503, 13.683211350120715, 12.727058114156504, 11.77944741525137, 10.767767898125886, 9.823069177702148, 8.874113958150769, 7.9466051136465135, 6.955047667172575, 7.900399349538809, 8.833024217086914, 9.801572432480118, 10.757250901727106, 11.592209768437884, 12.658291577095799, 13.642566651487934, 14.584660166784287, 15.531984756682947, 16.42922873913874, 15.516659597031824, 14.650818652060432, 14.611811406224872, 13.71118681646507, 12.732401802368317, 11.83492289550623, 10.854457011069046, 9.85615702085041, 8.951239368842021, 8.02372789841316, 8.975372659227103, 9.796086267436268, 10.791732272578674, 11.708418390604008, 11.96475184308732, 12.842567485858643, 13.736495853791498, 14.666291314118865, 15.670939839206387, 16.61437057935043, 16.558030760260923, 15.61137086414113, 15.618303450934985, 14.685377056971081, 13.76752103754666, 12.804122903000955, 11.864139378141687, 10.867953121196667, 9.884452916760777, 8.966900264938282, 9.929185626927426, 10.7661886994604, 11.719506291728154, 11.884968659058487, 10.951415618557617, 11.884968463327178, 12.747793858629844, 13.680359935934506, 14.723571392355534, 15.713523363138261, 16.668440280281384, 16.676835028731123, 16.58493487613142, 15.738758161943135, 14.757785299880362, 13.74999885340832, 12.808100373635085, 11.767914746238887, 10.822270120475016, 9.893169546037003, 10.908345376222142, 11.789022374119286, 11.79982535194678, 10.854607000963213, 9.92345900285695, 10.870428388632334, 11.7956288320358, 12.720656345212271, 13.70442644164837, 14.642908909631203, 15.640576023005455, 16.578696959726674, 16.641319519686743, 16.70825354875963, 15.692701433086311, 14.733018659791156, 13.799746398842743, 12.81219249511554, 11.842782369208422, 10.873358528148156, 11.937365566550618, 11.820736044744576, 10.824441828420596, 10.036997022204057, 8.969055644830622, 10.00517060503258, 10.894542156959131, 11.747882506013097, 12.706180966887716, 13.69072837912153, 14.714309150525542, 15.646234748146417, 15.634118729528026, 16.56053225581825, 16.6281682427367, 15.664315973993101, 14.819528506544291, 13.82479251226807, 12.851138658579057, 11.943062969273447, 11.627659667931407, 10.785633518900061, 9.816388869419365, 8.994979052873811, 7.994127034162377, 9.006044005302703, 9.865637497094376, 10.804383966039707, 11.750496943051202, 12.720743526397957, 13.685729593014182, 14.65994625673388, 14.636279430763597, 15.597509180324211, 16.42459260639864, 15.498297117131964, 14.580237619924347, 13.6850166697642, 12.648969880233508, 11.655987171864288, 10.674960204983641, 9.71482388696478, 8.774190086874363, 7.947346066295506, 7.001056310270116, 7.963881527217757, 8.926839500697179, 9.866857176679847, 10.877435319734008, 11.82288884698517, 12.77865726181108, 13.721350852740926, 13.690430163216327, 14.648463543756254, 15.497389673087536, 14.535598030315251, 13.642797595916408, 12.658553398144333, 11.690778361070912, 10.64642374912321, 9.741974600642434, 8.779721367343281, 7.8023513183256705, 6.997745118759476, 6.042054635526778, 6.939206585540531, 7.974987112860166, 8.912678996331595, 9.897749072652356, 10.840238488677528, 11.809401648355493, 12.74864890147647, 12.665081675958518, 13.732783967647126, 14.600838897742763, 13.609828051350403, 12.602351549816765, 11.628245968286365, 10.657791088242053, 9.684094590642681, 8.716671910243758, 7.772215156589297, 6.846865036355581, 6.000733540263782, 5.111364030279104, 5.944431219808589, 6.959940407838992, 7.97508358144256, 8.874392183880618, 9.914668301768685, 10.856646334342836, 11.699383870914735, 11.736880509439148, 12.766383043881362, 13.635682173482097, 12.651895243950927, 11.676753365022483, 10.678704433697717, 9.699010156974266, 8.71699620953935, 7.7625750086230765, 6.8621870963159, 5.9092127973438195, 4.996946627362147, 4.073450450422126, 4.913238216277496, 5.926790088040525, 6.983361704315935, 7.911368294041608, 8.895864601912615, 9.842336864167498, 10.767822641147951, 10.830234436266226, 11.777107721664361, 12.739801536910006, 11.71971114559191, 10.652976327376871, 9.697852285588127, 8.741551097718581, 7.844422177953279, 6.818764345412295, 5.830721535629148, 4.899563167827262, 3.9254933710385553, 3.024861825569115, 3.965310182226308, 4.971683169392679, 5.966643967915841, 6.951175562732391, 7.9158482004883775, 8.876651651431317, 9.876492018762814, 9.991515037234674, 11.064925444375232, 11.861763089187605, 10.924847909204153, 9.916115067644052, 8.843341326610728, 7.789008113799152, 6.833984382088038, 5.847839992112718, 4.864812868619992, 3.92748128991365, 2.989399504124602, 2.030028835359631, 3.0086674211305544, 4.003663905878959, 5.041187053276945, 6.000266408076693, 7.03247887845415, 8.074568632128438, 9.027325669345954, 9.023506155192933, 10.069447676068354, 10.98435176885459, 9.992156197036955, 8.95929291701384, 8.008262960969882, 7.060009061134541, 6.053764115085385, 5.094852565926516, 4.022445644244792, 2.982898141036643, 2.025943881111791, 1.0016204960860913, 1.9934106236412519, 2.978432297691391, 4.040601157571628, 5.033621673119392, 6.03603528148604, 7.0258689685270825, 8.003968921496163], [8.068872366529694, 7.119227853410145, 6.1258855178661555, 5.166093364324584, 4.1126266607106094, 3.107928345621759, 2.093646442699921, 1.0395378037399172, 0.0, 1.066844401675675, 2.054410238612925, 3.0808858288990764, 4.04482850153947, 5.034821400181573, 5.991420931036151, 6.962456758292813, 8.000957692703413, 9.013149651852252, 10.061696892464125, 9.10868411281995, 8.854363647182684, 7.909279552829424, 6.930822346036242, 5.872284484939612, 4.937131080214312, 3.95991786726351, 2.8988919786154366, 1.963666247060745, 0.9769192404282844, 1.9980352696238346, 2.952140527632615, 3.881773537033879, 4.920497555006605, 5.901774031371358, 6.918386323848887, 7.924756205186399, 8.887716576331632, 9.932698069389136, 10.741880141942584, 9.794953753386563, 9.872084910445379, 8.909935374618236, 7.899043714950469, 6.901178358092577, 5.946234841502832, 4.948256313762815, 3.9224936501031866, 2.922169866226761, 1.9523435505881896, 2.905172497146258, 3.927316380384931, 4.819272982963199, 5.876708961191325, 6.825292957264032, 7.798292847130799, 8.854564827703518, 9.869661993941376, 10.902976339964152, 11.733923639409335, 10.732720304198253, 10.836124965973962, 9.797716813275985, 8.813500146456937, 7.863688982084864, 6.8991847375675, 5.86354972979984, 4.879930226690063, 3.8898454651587118, 2.933673273865143, 3.85873884800385, 4.904612858885746, 5.83163668744164, 6.795267736105032, 7.840376304890546, 8.742599008643186, 9.816772214983885, 10.823328210207507, 11.761457832197056, 12.657082216093285, 11.719574376358093, 11.763069626161904, 10.73138542686791, 9.763542852813583, 8.75014270898366, 7.785935842520381, 6.852287913811828, 5.863236268536807, 4.920500354913987, 3.9553177248074243, 4.892733186309094, 5.845840337086832, 6.761728441929434, 7.754696496307099, 8.766984642649085, 9.812727883317528, 10.769558239265065, 11.803541631378494, 12.72292305294751, 13.64156138347048, 12.700970230190093, 12.686100928416813, 11.730894926920083, 10.777081280826021, 9.749156079327346, 8.723487284349925, 7.785880224634729, 6.879064142632863, 5.845748995699234, 4.965536393709533, 5.870400510731092, 6.804990499588887, 7.783772017982362, 8.756056130347538, 9.727467331061694, 10.79379734247631, 11.72817966810229, 12.702953610897795, 13.728858631047268, 14.576120095994488, 13.616729039127732, 13.679303016540176, 12.744635465792253, 11.75539884656679, 10.691702638499333, 9.71543038664526, 8.836679120234729, 7.807144263047501, 6.791842942415545, 5.9483874257632285, 6.806180537692536, 7.753657856810586, 8.719438860598116, 9.649919399028581, 10.695757065110495, 11.703573845410146, 12.682283503914205, 13.63578764041504, 14.66347849469383, 15.540238411703651, 14.605771327046106, 14.646509329838318, 13.664355775182432, 12.716745076277299, 11.705065559151814, 10.684308518623837, 9.716569229896864, 8.729909171329584, 7.7383517248556455, 6.890203315991493, 7.822828183539599, 8.791376398932801, 9.74705486817979, 10.582013734890568, 11.648095543548482, 12.632370617940618, 13.57446413323697, 14.52178872313563, 15.453646403414155, 16.47890192342252, 15.614116631778035, 15.575109385942476, 14.648484477490998, 13.669699463394245, 12.742437540021069, 11.715696351990735, 10.698612292596506, 9.734543426525093, 8.80703195609623, 7.965176625679787, 8.785890233888953, 9.78153623903136, 10.698222357056691, 11.524678373877961, 12.58840675501964, 13.54201547800942, 14.479754883328203, 15.484403408415725, 16.427834148559768, 17.46480308593171, 16.57466884385873, 16.565648669370898, 15.62267471799701, 14.704818698572588, 13.689985736043814, 12.706594649887782, 11.710408392942762, 10.667756974443849, 9.75020432262135, 8.91898959338011, 9.755992665913086, 10.709310258180839, 11.10373091979091, 11.741078577749734, 12.674631422519296, 13.537456817821962, 14.470022895126625, 15.513234351547652, 16.50318632233038, 17.458103239473502, 17.63679064946099, 17.498266065736225, 16.54810431635322, 15.567131454290449, 14.559345007818406, 13.617446528045171, 12.551218803921959, 11.605574178158088, 10.676473603720071, 9.898149342674825, 10.778826340571971, 10.760287548206861, 10.073369261695637, 10.713121962049067, 11.660091347824451, 12.585291791227917, 13.51031930440439, 14.494089400840489, 15.432571868823322, 16.430238982197576, 17.36835991891879, 17.430982478878864, 17.517599703169715, 16.47600549076938, 15.516322717474228, 14.583050456525815, 13.595496552798611, 12.626086426891494, 11.656662585831224, 10.940860394314997, 10.781198241004658, 9.784904024680678, 9.047868678490973, 9.75871860402274, 10.7948335642247, 11.68420511615125, 12.537545465205216, 13.495843926079836, 14.48039133831365, 15.503972109717662, 16.435897707338537, 16.423781688720148, 17.254125568650025, 16.324511745930344, 15.43168269661083, 14.475895499621487, 13.606641507563491, 12.659005713268972, 11.625274922444378, 10.588121864191493, 9.746095715160143, 8.776851065679445, 8.005850709160727, 8.783789993354494, 9.795706964494823, 10.655300456286495, 11.594046925231826, 12.540159902243321, 13.510406485590076, 14.475392552206301, 15.449609215926001, 15.425942389955718, 16.38717213951633, 15.385054802658725, 14.458759313392047, 13.54069981618443, 12.645478866024282, 11.60943207649359, 10.616449368124371, 9.635422401243725, 8.675286083224861, 7.7346522831344435, 6.9582177225824235, 7.790719269462234, 8.753544486409876, 9.716502459889298, 10.656520135871967, 11.667098278926126, 12.612551806177288, 13.568320221003201, 14.511013811933047, 14.480093122408446, 15.438126502948373, 14.45785186934762, 13.496060226575334, 12.603259792176491, 11.619015594404416, 10.651240557330995, 9.606885945383294, 8.702436796902518, 7.740183563603364, 6.762813514585752, 6.008616775046393, 6.831717594718896, 7.7288695447326505, 8.764650072052286, 9.702341955523712, 10.687412031844474, 11.629901447869646, 12.599064607547614, 13.538311860668589, 13.454744635150638, 14.522446926839246, 13.561301094002847, 12.570290247610487, 11.562813746076849, 10.588708164546448, 9.618253284502137, 8.644556786902765, 7.67713410650384, 6.732677352849379, 5.807327232615663, 4.961195736523864, 5.901026989471221, 6.734094179000708, 7.749603367031112, 8.764746540634677, 9.664055143072735, 10.704331260960803, 11.646309293534955, 12.489046830106854, 12.526543468631267, 13.556046003073481, 12.59614436974218, 11.61235744021101, 10.637215561282567, 9.639166629957801, 8.65947235323435, 7.677458405799432, 6.723037204883159, 5.822649292575982, 4.869674993603901, 3.957408823622229, 4.863113409614243, 5.702901175469615, 6.716453047232643, 7.773024663508053, 8.701031253233726, 9.685527561104733, 10.631999823359617, 11.55748560034007, 11.619897395458345, 12.56677068085648, 11.70026373317009, 10.680173341851994, 9.613438523636955, 8.65831448184821, 7.702013293978664, 6.804884374213361, 5.779226541672378, 4.79118373188923, 3.8600253640873445, 2.885955567298638, 3.8145247847612325, 4.754973141418426, 5.761346128584797, 6.756306927107959, 7.740838521924508, 8.705511159680496, 9.666314610623436, 10.666154977954934, 11.031052840974592, 11.783401318176967, 10.822225285447686, 9.885310105464235, 8.876577263904135, 7.803803522870811, 6.749470310059236, 5.794446578348121, 4.808302188372801, 3.825275064880074, 2.8879434861737328, 1.9498617003846848, 2.992280076535184, 4.0408775820718255, 5.035874066820231, 6.073397214218217, 7.032476569017964, 8.064689039395422, 9.10677879306971, 10.066863473085872, 10.063043958932852, 10.994786924675891, 9.944813965114673, 8.952618393297037, 7.919755113273924, 6.968725157229964, 6.020471257394624, 5.014226311345467, 4.0553147621865975, 2.982907840504874, 1.9433603372967254, 0.9864060773718736, 2.0338306570273628, 3.0256207845825234, 4.010642458632662, 5.072811318512899, 6.065831834060663, 7.06824544242731, 8.065406772267, 9.043506725236082], [9.135716768205368, 8.186072255085818, 7.19272991954183, 6.2329377660002585, 5.179471062386284, 4.174772747297434, 3.1604908443755955, 2.106382205415592, 1.066844401675675, 0.0, 0.9875658369372495, 2.0140414272234013, 2.977984099863795, 3.9679769985058977, 4.9245765293604755, 5.8956123566171375, 6.934113291027738, 7.946305250176579, 8.994852490788452, 10.01448896118222, 9.890714138865198, 8.945630044511939, 7.967172837718757, 6.9086349766221264, 5.973481571896826, 4.996268358946025, 3.935242470297951, 3.0000167387432595, 2.013269732110799, 0.9921537029152488, 1.946258960924029, 2.875891970325293, 3.914615988298019, 4.895892464662771, 5.851541922173212, 6.857911803510723, 7.820872174655956, 8.865853667713461, 9.852472984753561, 10.799399373309582, 10.908435402127893, 9.946285866300752, 8.935394206632985, 7.9375288497750915, 6.913708215911546, 5.9152385978875355, 4.866024884369519, 3.8479845396567907, 2.878158224018219, 1.9253292774601514, 2.921434813676345, 3.8133914162546123, 4.870827394482738, 5.819411390555445, 6.792411280422213, 7.848683260994932, 8.8028175922657, 9.836131938288476, 10.800146813004911, 11.737165924121271, 11.813558942873264, 10.775150790175287, 9.790934123356239, 8.841122958984165, 7.83262567215694, 6.763869189144847, 5.78024968603507, 4.781164886515295, 3.8249926952217264, 2.8788956283177436, 3.9247696391996394, 4.825755120733054, 5.789386169396446, 6.834494738181959, 7.736717441934599, 8.810890648275297, 9.756483808531833, 10.694613430521382, 11.692149759736715, 12.629657599471907, 12.68067160456787, 11.648987405273873, 10.681144831219546, 9.641462130340242, 8.677255263876964, 7.74360733516841, 6.754555689893389, 5.8118197762705694, 4.846637146164007, 3.9128899666229877, 4.865997117400726, 5.755846875220848, 6.748814929598512, 7.761103075940499, 8.806846316608942, 9.763676672556478, 10.73669722970282, 11.656078651271836, 12.633315555810148, 13.573906709090535, 13.603702906822777, 12.648496905326047, 11.668400702182604, 10.640475500683928, 9.614806705706508, 8.677199645991312, 7.770383563989446, 6.737068417055816, 5.856855815066115, 4.890557291044986, 5.82514727990278, 6.777890451273776, 7.750174563638952, 8.721585764353108, 9.787915775767722, 10.722298101393704, 11.692425766179158, 12.704139585703807, 13.567874268334156, 14.534331017533695, 14.59690499494614, 13.662237444198217, 12.64671826792337, 11.583022059855914, 10.606749808001842, 9.727998541591312, 8.698463684404084, 7.683162363772127, 6.839706847119811, 5.82633731800643, 6.773814637124479, 7.739595640912009, 8.670076179342475, 9.7153285996679, 10.723145379967551, 11.70185503847161, 12.625259795696403, 13.638759449350369, 14.53199258404332, 15.52337330545207, 15.546342779437772, 14.555675196539015, 13.608064497633881, 12.596384980508397, 11.57562793998042, 10.607888651253447, 9.621228592686167, 8.629671146212228, 7.781522737348076, 6.8429849638534925, 7.811533179246695, 8.767211648493683, 9.602170515204461, 10.668252323862376, 11.652527398254511, 12.594620913550864, 13.541945503449524, 14.473803183728048, 15.471711749089094, 16.46296806083254, 16.474942835541928, 15.53980389884758, 14.561018884750828, 13.633756961377651, 12.607015773347317, 11.589931713953089, 10.625862847881676, 9.698351377452813, 8.770750010990433, 7.806047014202846, 8.801693019345253, 9.718379137370585, 10.544835154191855, 11.608563535333534, 12.562172258323313, 13.499911663642097, 14.504560188729618, 15.447990928873661, 16.484959866245603, 17.423520272913237, 17.45696809072748, 16.513994139353592, 15.59613811992917, 14.581305157400397, 13.597914071244364, 12.601727814299345, 11.559076395800432, 10.641523743977935, 9.711544958470913, 8.77614944622698, 9.729467038494732, 10.712316108278182, 11.558171378721559, 12.49172422349112, 13.550874253484967, 14.485843041826456, 15.559815267359697, 16.399685170536902, 17.354602087680025, 18.34252132943598, 18.389585487092805, 17.439423737709802, 16.45845087564703, 15.450664429174989, 14.508765949401754, 13.442538225278541, 12.49689359951467, 11.567793025076655, 10.69070470776563, 9.798983120885865, 9.815524092573085, 10.855390956796665, 11.636730518645203, 12.583699904420588, 13.508900347824053, 14.454963557343202, 15.4387336537793, 16.377216121762135, 17.374883235136387, 18.33750498313472, 18.31472862756375, 17.245183055699897, 16.315215099946958, 15.418216555179, 14.55847605585714, 13.692008672912948, 12.72259854700583, 11.715179381803088, 10.651172343400626, 9.836434785370882, 8.840140569046902, 9.829890373592, 10.682327160618875, 11.718442120820834, 12.628849369090062, 13.482189718144028, 14.440488179018647, 15.425035591252461, 16.448616362656473, 17.405042771554466, 17.32228754733799, 16.30936211301625, 15.379748290296568, 14.486919240977054, 13.531132043987709, 12.661878051929715, 11.714242257635195, 10.680511466810598, 9.643358408557713, 8.801332259526367, 7.832087610045669, 8.814559387659314, 9.70739854995063, 10.719315521090957, 11.599944709225307, 12.538691178170637, 13.484804155182132, 14.455050738528888, 15.420036805145113, 16.41875428014193, 16.395087454171644, 15.477457685539349, 14.44029134702495, 13.513995857758271, 12.595936360550652, 11.700715410390506, 10.664668620859814, 9.671685912490593, 8.690658945609947, 7.730522627591085, 6.789888827500667, 7.766926401081009, 8.71432782605837, 9.67715304300601, 10.66114671282811, 11.601164388810778, 12.633655409436388, 13.581696870393216, 14.537465285219128, 15.480158876148973, 15.449238186624372, 14.508636704945776, 13.513088413713843, 12.551296770941558, 11.658496336542713, 10.674252138770639, 9.706477101697217, 8.662122489749516, 7.75767334126874, 6.795420107969587, 5.818050058951975, 6.817325453544979, 7.762221848231318, 8.698014608948577, 9.733795136268212, 10.671487019739638, 11.656557096060402, 12.599046512085573, 13.56820967176354, 14.507456924884515, 14.423889699366564, 13.598600209000125, 12.61653763836907, 11.62552679197671, 10.61805029044307, 9.64394470891267, 8.673489828868359, 7.699793331268987, 6.732370650870063, 5.787913897215602, 4.862563776981886, 5.7987716471216695, 6.831531242983644, 7.703239243216634, 8.718748431247038, 9.733891604850603, 10.633200207288663, 11.673476325176729, 12.615454357750881, 13.45819189432278, 13.495688532847193, 12.689702849680895, 11.651380914108405, 10.667593984577234, 9.69245210564879, 8.694403174324023, 7.7147088976005715, 6.732694950165655, 5.778273749249382, 4.877885836942205, 3.9249115379701247, 4.926553887838156, 5.83225847383017, 6.672046239685541, 7.685598111448569, 8.74216972772398, 9.670176317449654, 10.654672625320659, 11.601144887575543, 12.526630664555997, 12.589042459674271, 11.710735035454983, 10.734694028629693, 9.735409886218218, 8.668675068003179, 7.713551026214433, 6.757249838344887, 5.860120918579584, 4.834463086038601, 3.8464202762554534, 2.9152619084535676, 3.855100631514565, 4.783669848977159, 5.724118205634353, 6.730491192800724, 7.725451991323886, 8.709983586140435, 9.674656223896422, 10.635459674839362, 11.63530004217086, 11.789967323641848, 10.71655691650129, 9.755380883772009, 8.81846570378856, 7.820502185000134, 6.859040067237034, 5.804706854425459, 4.849683122714344, 3.863538732739024, 2.8805116092462972, 1.9431800305399558, 2.9190067646006117, 3.961425140751111, 5.010022646287753, 6.005019131036157, 7.042542278434143, 8.00162163323389, 9.033834103611348, 10.075923857285636, 11.051338048119039, 10.973884043875636, 9.927942523000215, 8.877969563438997, 7.885773991621361, 6.852910711598248, 5.901880755554289, 4.953626855718949, 3.984528836114557, 3.025617286955688, 2.021465113099306, 0.9985968816629487, 1.9555511415878006, 3.0029757212432897, 3.9947658487984503, 4.979787522848589, 6.041956382728826, 7.03497689827659, 8.037390506643238, 9.049881347300166, 10.027981300269248], [10.066734870535226, 9.173638092023069, 8.18029575647908, 7.220503602937509, 6.167036899323534, 5.162338584234684, 4.148056681312846, 3.0939480423528423, 2.054410238612925, 0.9875658369372495, 0.0, 1.0264755902861515, 1.9904182629265454, 2.980411161568648, 3.9370106924232258, 4.908046519679888, 5.946547454090489, 6.958739413239329, 8.007286653851203, 9.026923124244972, 10.752423642576211, 9.933195881449189, 8.954738674656006, 7.896200813559376, 6.961047408834076, 5.983834195883274, 4.922808307235201, 3.9875825756805092, 3.0008355690480486, 1.9797195398524985, 1.0381362709647575, 1.9677692803660216, 3.0064932983387473, 3.9323484420382524, 4.8639760852359615, 5.870345966573473, 6.833306337718706, 7.878287830776211, 8.86490714781631, 9.811833536372331, 11.733606725760158, 10.933851703238002, 9.922960043570235, 8.925094686712342, 7.9012740528487955, 6.902804434824785, 5.853590721306769, 4.83555037659404, 3.8657240609554684, 2.9128951143974007, 2.0133121237170735, 2.9052687262953407, 3.9627047045234667, 4.911288700596174, 5.883207042483199, 6.921321591201684, 7.81525175532845, 8.848566101351226, 9.812580976067661, 10.749600087184021, 12.706975942794227, 11.762716627112535, 10.778499960293487, 9.828688795921414, 8.820191509094188, 7.7514350260820954, 6.7678155229723185, 5.768730723452544, 4.812558532158976, 3.866461465254993, 3.0800758532548365, 3.917632430773782, 4.881263479437174, 5.926372048222688, 6.827513203995585, 7.901686410336283, 8.768917971594583, 9.707047593584132, 10.704583922799465, 11.642091762534656, 13.524241476181473, 12.636553242211122, 11.668710668156795, 10.62902796727749, 9.664821100814212, 8.73117317210566, 7.742121526830638, 6.799385613207818, 5.834202983101257, 4.900455803560237, 4.021303331455924, 4.847724185261576, 5.840692239639241, 6.852980385981227, 7.897642078669928, 8.854472434617465, 9.74913139276557, 10.668512814334585, 11.645749718872898, 12.586340872153285, 14.471284016781963, 13.636062742263295, 12.655966539119852, 11.628041337621177, 10.602372542643758, 9.664765482928562, 8.757949400926694, 7.724634253993065, 6.844421652003365, 5.878123127982235, 5.0798452395476685, 5.869767761314504, 6.842051873679679, 7.813463074393836, 8.879793085808451, 9.813093863454691, 10.704859929241907, 11.716573748766557, 12.580308431396906, 13.5611342716545, 15.464486104905326, 14.649803281135465, 13.63428410486062, 12.570587896793164, 11.594315644939092, 10.715564378528562, 9.686029521341332, 8.670728200709375, 7.827272684057061, 6.813903154943679, 6.028512596769367, 6.920323775772829, 7.850804314203295, 8.807205909708628, 9.815022690008279, 10.793732348512338, 11.637693958759153, 12.651193612413119, 13.544426747106069, 14.549780683499886, 16.43169241820347, 15.543241033476262, 14.595630334571128, 13.583950817445643, 12.563193776917666, 11.595454488190693, 10.608794429623414, 9.617236983149475, 8.769088574285325, 7.830550800790742, 7.066231138891583, 7.95212672377722, 8.782898650065281, 9.848980458723195, 10.785272532545086, 11.72736604784144, 12.601626276581571, 13.533483956860096, 14.484145912151844, 15.475402223895292, 17.360292474307624, 16.527369735784827, 15.548584721688075, 14.621322798314898, 13.594581610284564, 12.577497550890335, 11.613428684818922, 10.68591721439006, 9.758315847927681, 8.793612851140095, 8.118171637364332, 8.903294212654123, 9.725563289052673, 10.789291670194352, 11.742900393184131, 12.664532139469472, 13.604242326176879, 14.535708008655426, 15.525517075380943, 16.43595443597599, 18.366784519017735, 17.50155997629084, 16.58370395686642, 15.568870994337644, 14.585479908181611, 13.589293651236591, 12.546642232737678, 11.629089580915181, 10.699110795408162, 9.763715283164228, 9.097789266598381, 9.904710195410097, 10.738899513582377, 11.672452358351938, 12.731602388345785, 13.650463517653831, 14.660445031057499, 15.487402250318667, 16.44231916746179, 17.430238409217743, 18.260867031214126, 17.310705281831122, 16.349149270886322, 15.530338791543011, 14.803020216950825, 13.931753380387423, 12.986108754623553, 11.938366322798561, 10.936881353925118, 10.235527757914404, 10.047095724562995, 10.93507185350537, 11.766856129283044, 12.713825515058428, 13.639025958461893, 14.610167108376066, 15.665821447587502, 16.558016703825725, 17.472089104806056, 18.441886624609563, 17.41075546687848, 16.34120989501463, 15.411241939261688, 14.514243394493732, 13.760778846892501, 12.933960942678265, 11.965596505890147, 10.958177340687408, 9.894170302284946, 9.244607257198833, 9.827706405984149, 10.817456210529247, 11.669892997556126, 12.706007957758084, 13.616415206027312, 14.469755555081278, 15.428054015955897, 16.412601428189713, 17.436182199593727, 18.3787753508594, 16.418314386652717, 15.405388952330979, 14.4757751296113, 13.582946080291785, 12.73343483502307, 11.873168551157827, 10.957240216519512, 9.923509425694919, 8.886356367442033, 8.19112560984396, 8.819653446982917, 9.802125224596562, 10.69496438688788, 11.706881358028207, 12.587510546162557, 13.526257015107888, 14.472369992119383, 15.442616575466138, 16.407602642082363, 17.392486859446862, 15.508546192347705, 14.57348452485408, 13.536318186339681, 12.610022697073003, 11.798239151586014, 10.912005909618617, 9.90766657974413, 8.914683871374912, 7.933656904494265, 7.120315977908679, 7.777454664437916, 8.754492238018258, 9.70189366299562, 10.66471887994326, 11.64871254976536, 12.588730225748028, 13.621221246373638, 14.569262707330466, 15.525031122156378, 16.467724713086223, 14.562696924800434, 13.604663544260507, 12.609115253028575, 11.64732361025629, 10.860799127578074, 9.876554929806, 8.92504636874489, 7.905120448633834, 7.0006713001530585, 6.185213458287181, 6.8056158958892246, 7.804891290482228, 8.749787685168567, 9.685580445885828, 10.721360973205462, 11.65905285667689, 12.644122932997652, 13.586612349022824, 14.55577550870079, 15.495022761821765, 13.5792615605304, 12.694627048314857, 11.712564477683802, 10.721553631291442, 9.820353081478432, 8.846247499948031, 7.875792619903718, 6.9427912901533055, 5.975368609754382, 5.1777072475331956, 5.850129613919135, 6.786337484058919, 7.819097079920892, 8.690805080153885, 9.706314268184288, 10.721457441787855, 11.620766044225913, 12.66104216211398, 13.603020194688131, 14.44575773126003, 12.648506753011517, 11.769832046404964, 10.747407753423136, 9.763620823891966, 8.790649650760137, 7.896705965359383, 6.917011688635931, 5.947476942485358, 4.993055741569085, 4.178681514879512, 4.912477374907374, 5.914119724775405, 6.8198243107674195, 7.659612076622791, 8.67316394838582, 9.729735564661231, 10.657742154386904, 11.64223846225791, 12.588710724512794, 13.514196501493247, 11.670042483915868, 10.723169198517732, 9.747128191692443, 8.83143672553295, 7.7668726131145265, 6.882531778572449, 5.926230590702903, 5.074902910899287, 4.049245078358304, 3.1472159541927596, 3.902827745390817, 4.842666468451815, 5.771235685914409, 6.711684042571602, 7.718057029737973, 8.713017828261135, 9.697549423077685, 10.662222060833672, 11.623025511776612, 12.62286587910811, 10.802401486704598, 9.72899107956404, 8.767815046834759, 7.8308998668513095, 6.832936348062884, 5.9838050898761495, 4.973687606783475, 4.019678933204785, 3.033534543229465, 2.105363339857478, 2.9307458674772056, 3.9065726015378615, 4.948990977688361, 5.997588483225002, 6.992584967973407, 8.030108115371394, 8.98918747017114, 10.021399940548598, 11.063489694222886, 11.766590854593318, 9.986318206938385, 8.940376686062965, 7.890403726501748, 6.898208154684112, 5.865344874660999, 4.914314918617039, 3.966061018781699, 2.996962999177308, 2.038051450018439, 1.0338992761620562, 1.9861627186001982, 2.94311697852505, 3.9905415581805395, 4.9823316857357, 5.967353359785839, 7.029522219666076, 8.02254273521384, 9.024956343580486, 10.037447184237415, 11.005855440635155], [9.040259280249074, 9.989903793368624, 9.20677134676523, 8.246979193223659, 7.193512489609685, 6.188814174520835, 5.174532271598997, 4.120423632638993, 3.0808858288990764, 2.0140414272234013, 1.0264755902861515, 0.0, 0.963942672640394, 1.9539355712824966, 2.9105351021370742, 3.8815709293937366, 4.920071863804337, 5.9322638229531774, 6.980811063565051, 8.00044753395882, 9.72594805229006, 10.671032146643318, 9.801040297839606, 8.742502436742974, 7.807349032017675, 6.830135819066873, 5.7691099304188, 4.833884198864109, 3.8471371922316475, 2.8260211630360974, 1.8719159050273175, 0.9422828956260536, 1.9810069135987793, 2.905872851752101, 3.83750049494981, 4.843870376287321, 5.806830747432554, 6.851812240490059, 7.83843155753016, 8.78535794608618, 10.707131135474006, 11.671687968432131, 10.769261666753833, 9.77139630989594, 8.747575676032396, 7.749106058008384, 6.699892344490368, 5.681851999777639, 4.712025684139068, 3.759196737581, 2.8470917577796335, 1.8797823415553727, 2.9372183197834985, 3.885802315856206, 4.856731452197048, 5.894846000915532, 6.788776165042298, 7.822090511065074, 8.786105385781509, 9.723124496897869, 11.680500352508075, 12.609018250296135, 11.624801583477087, 10.674990419105013, 9.666493132277788, 8.597736649265695, 7.614117146155918, 6.615032346636143, 5.658860155342575, 4.712763088438592, 3.9138554873173965, 2.892146046033814, 3.8557770946972054, 4.900885663482719, 5.8010376137094335, 6.875210820050132, 7.74244238130843, 8.68057200329798, 9.678108332513313, 10.615616172248505, 12.497765885895321, 13.482854865394721, 12.515012291340394, 11.47532959046109, 10.511122723997811, 9.577474795289259, 8.588423150014238, 7.645687236391417, 6.680504606284856, 5.746757426743836, 4.799056268583338, 3.8222378005216076, 4.815205854899272, 5.827494001241258, 6.871166488383777, 7.827996844331313, 8.722655802479418, 9.642037224048433, 10.619274128586746, 11.559865281867133, 13.444808426495811, 14.400014427992541, 13.502268162303452, 12.474342960804776, 11.448674165827358, 10.511067106112161, 9.604251024110294, 8.570935877176664, 7.690723275186964, 6.724424751165834, 5.857598176675083, 4.844281376574536, 5.816565488939711, 6.787976689653867, 7.854306701068482, 8.78661827316854, 9.678384338955755, 10.690098158480405, 11.553832841110754, 12.534658681368349, 14.438010514619174, 15.413596010800964, 14.48058572804422, 13.416889519976763, 12.440617268122692, 11.561866001712161, 10.532331144524932, 9.517029823892974, 8.67357430724066, 7.660204778127278, 6.806265533896782, 5.89483739103286, 6.825317929463326, 7.781719524968659, 8.789536305268308, 9.768245963772367, 10.611218368473, 11.624718022126967, 12.517951156819917, 13.523305093213734, 15.405216827917316, 16.38954265665986, 15.441931957754727, 14.430252440629243, 13.409495400101266, 12.441756111374293, 11.455096052807013, 10.463538606333074, 9.615390197468924, 8.67685242397434, 7.843984076018998, 6.9266403390372515, 7.7574122653253115, 8.823494073983225, 9.759786147805116, 10.701879663101469, 11.57515068629542, 12.507008366573944, 13.457670321865692, 14.44892663360914, 16.333816884021473, 17.329947709393778, 16.394886344871672, 15.467624421498497, 14.440883233468163, 13.423799174073935, 12.459730308002522, 11.532218837573659, 10.60461747111128, 9.639914474323694, 8.895924574491747, 7.877807827914154, 8.700076904312704, 9.763805285454383, 10.717414008444162, 11.639045754729501, 12.577766735890727, 13.509232418369272, 14.499041485094791, 15.409478845689838, 17.340308928731584, 17.35313807456771, 16.380356652849198, 15.502065965607452, 14.720505622158072, 13.84815125796527, 12.773566221837978, 11.838160013611132, 10.889565512933684, 10.610016906347827, 9.862072880453578, 8.879223810670128, 9.713413128842408, 10.64696597361197, 11.706116003605816, 12.62497713291386, 13.633969440771349, 14.460926660032513, 15.415843577175636, 16.40376281893159, 17.234391440927975, 16.284229691544972, 15.32267368060017, 14.503863201256857, 13.776544626664673, 12.905277790101273, 11.959633164337403, 10.911890732512411, 9.910405763638968, 10.875640819632393, 10.811379338418192, 9.909585468765401, 10.741369744543075, 11.68833913031846, 12.613539573721924, 13.584680723636096, 14.640335062847532, 15.531541113539571, 16.445613514519902, 17.41541103432341, 16.384279876592327, 15.314734304728477, 14.384766348975536, 13.487767804207579, 12.73430325660635, 11.907485352392115, 10.939120915603997, 9.931701750401258, 8.867694711998796, 9.884720318916822, 10.796276685421425, 10.935086051970066, 11.695773102569403, 12.670015187710703, 13.629622904334624, 14.55745456283527, 15.51575302370989, 16.500300435943704, 17.4705674383395, 17.35229976057325, 15.391838796366565, 14.378913362044827, 13.449299539325148, 12.556470490005633, 11.706959244736918, 10.846692960871676, 9.930764626233362, 8.897033835408767, 7.859880777155882, 8.831238671561948, 9.788223726420192, 10.770695504033837, 11.663534666325155, 12.675451637465482, 13.556080825599832, 14.494827294545162, 15.440940271556657, 16.411186854903413, 17.356932704033856, 16.366011269160712, 14.482070602061555, 13.547008934567929, 12.509842596053529, 11.58354710678685, 10.771763561299862, 9.885530319332467, 8.88119098945798, 7.888208281088762, 6.907181314208115, 7.835958503498176, 8.74602494387519, 9.723062517455533, 10.670463942432894, 11.633289159380535, 12.617282829202635, 13.557300505185303, 14.589791525810913, 15.59573829761662, 16.34923192358023, 15.473453308208006, 13.536221334514282, 12.578187953974355, 11.582639662742423, 10.620848019970138, 9.834323537291922, 8.850079339519848, 7.898570778458738, 6.878644858347684, 5.974195709866908, 6.900855983876678, 7.7741861753264985, 8.773461569919503, 9.718357964605842, 10.71205603617198, 11.747836563491612, 12.68552844696304, 13.670598523283806, 14.613087939308977, 15.379976310124643, 14.542345962427405, 12.55278597024425, 11.668151458028705, 10.68608888739765, 9.69507804100529, 8.79387749119228, 7.819771909661879, 6.849317029617566, 5.916315699867155, 4.9488930194682315, 5.893349773122693, 6.818699893356409, 7.754907763496193, 8.787667359358167, 9.717280670440037, 10.732789858470438, 11.747933032074005, 12.647241634512067, 13.687517752400133, 14.427220996111986, 13.49308093186567, 11.622031162725367, 10.743356456118814, 9.720932163136984, 8.737145233605814, 7.7641740604739855, 6.870230375073231, 5.890536098349779, 4.921001352199207, 3.966580151282934, 5.004577802099769, 5.90914916257255, 6.940595315061557, 7.8462999010535714, 8.686087666908943, 9.69963953867197, 10.756211154947382, 11.684217744673058, 12.668714052544063, 13.48700547907934, 12.561519702098886, 10.643566893629718, 9.696693608231582, 8.720652601406293, 7.804961135246797, 6.7403970228283745, 5.856056188286297, 4.899755000416751, 4.048427320613136, 3.0227694880721523, 4.0108122978553, 4.899499533055993, 5.869142058737967, 6.797711276200561, 7.738159632857754, 8.744532620024126, 9.739493418547289, 10.724025013363839, 11.688697651119826, 12.597149678464627, 11.59730931113313, 9.775925896418448, 8.70251548927789, 7.741339456548608, 6.8044242765651575, 5.806460757776732, 4.9573294995899975, 3.947212016497323, 2.993203342918633, 2.007058952943313, 2.9900860764360395, 3.9274176551423814, 4.933048191824014, 5.975466567974513, 7.024064073511154, 8.019060558259559, 9.056583705657546, 10.015663060457292, 11.04787553083475, 11.77492992829433, 10.740115264307168, 8.959842616652233, 7.913901095776813, 6.863928136215596, 5.87173256439796, 4.838869284374847, 3.8878393283308874, 2.9395854284955476, 1.9704874088911561, 1.011575859732287, 2.0603748664482078, 3.01263830888635, 3.969592568811202, 5.0170171484666914, 6.008807276021852, 6.993828950071991, 8.055997809952228, 9.049018325499992, 10.051431933866638, 10.93608271222548, 9.979379850349002], [8.07631660760868, 9.02596112072823, 10.019303456272219, 9.210921865864055, 8.15745516225008, 7.152756847161229, 6.138474944239391, 5.084366305279388, 4.04482850153947, 2.9779840998637948, 1.9904182629265454, 0.963942672640394, 0.0, 0.9899928986421026, 1.9465924294966803, 2.9176282567533427, 3.956129191163943, 4.968321150312784, 6.016868390924657, 7.036504861318425, 8.762005379649667, 9.707089474002926, 10.685546680796108, 9.70644510938337, 8.77129170465807, 7.794078491707268, 6.733052603059194, 5.797826871504503, 4.811079864872042, 3.7899638356764918, 2.835858577667712, 1.9062255682664477, 1.065567200379984, 1.941930179111707, 2.873557822309416, 3.8799277036469277, 4.84288807479216, 5.887869567849665, 6.874488884889766, 7.821415273445786, 9.743188462833613, 10.707745295791739, 11.720378143488038, 10.735338982536335, 9.71151834867279, 8.71304873064878, 7.663835017130762, 6.645794672418034, 5.675968356779462, 4.723139410221394, 3.811034430420028, 2.843725014195767, 2.0871271160370175, 2.9640484265883735, 3.8927887795566534, 4.9309033282751376, 5.824833492401905, 6.8581478384246815, 7.822162713141116, 8.759181824257476, 10.71655767986768, 11.669154370630885, 12.588744256117481, 11.638933091745407, 10.630435804918182, 9.56167932190609, 8.578059818796312, 7.5789750192765375, 6.622802827982969, 5.676705761078987, 4.877798159957791, 3.856088718674208, 3.054031915689923, 4.010908635556018, 4.837094941069039, 5.9112681474097375, 6.778499708668036, 7.716629330657587, 8.714165659872918, 9.65167349960811, 11.533823213254928, 12.565507412548925, 13.478954963980788, 12.439272263101484, 11.475065396638206, 10.541417467929653, 9.552365822654632, 8.609629909031812, 7.6444472789252504, 6.710700099384231, 5.762998941223732, 4.786180473162002, 4.030004535166765, 4.937516973314557, 5.907223815743382, 6.864054171690919, 7.758713129839023, 8.67809455140804, 9.655331455946353, 10.59592260922674, 12.480865753855419, 13.436071755352149, 14.427478768955401, 13.43828563344517, 12.412616838467752, 11.475009778752556, 10.568193696750688, 9.534878549817059, 8.65466594782736, 7.688367423806229, 6.821540849315477, 5.80822404921493, 5.031364169207205, 5.978838492568644, 6.936681692531259, 7.822675600528145, 8.714441666315361, 9.726155485840012, 10.589890168470362, 11.570716008727956, 13.474067841978782, 14.449653338160571, 15.444528400684616, 14.38083219261716, 13.404559940763086, 12.525808674352556, 11.496273817165326, 10.480972496533369, 9.637516979881054, 8.624147450767673, 7.770208206537176, 6.8587800636732545, 6.076674815044383, 6.972581327883436, 7.980398108183087, 8.81477541007111, 9.647275695832606, 10.660775349486574, 11.554008484179525, 12.559362420573342, 14.441274155276924, 15.43194173817568, 16.379552437080815, 15.394195113269637, 14.37343807274166, 13.405698784014687, 12.419038725447408, 11.427481278973469, 10.579332870109319, 9.640795096614735, 8.807926748659392, 7.890583011677646, 7.008769150906368, 8.040741557463784, 8.950647950719894, 9.830755880850612, 10.611208013655025, 11.54306569393355, 12.493727649225299, 13.484983960968748, 15.369874211381081, 16.366005036753386, 16.45153321538715, 15.507323300461785, 14.807233229119255, 13.981548295466709, 12.957477511125106, 12.0810999263532, 11.568560143751675, 10.603857146964089, 9.859867247132142, 8.841750500554548, 7.951433789893761, 9.01516217103544, 9.966249853269481, 10.767921972478645, 11.613824063250332, 12.54528974572888, 13.535098812454398, 14.445536173049446, 16.376366256091192, 16.389195401927317, 15.416413980208807, 14.53812329296706, 13.756562949517676, 12.971259221167216, 12.02426396320635, 11.137927559828078, 11.853508185574077, 11.573959578988221, 10.826015553093972, 9.843166483310522, 8.964770014423465, 9.898322859193026, 10.954951848431135, 11.753853350663004, 12.670026768130953, 13.49698398739212, 14.451900904535243, 15.439820146291197, 16.270448768287583, 15.320287018904578, 14.358731007959777, 13.539920528616465, 12.812601954024279, 12.01532059282247, 11.08644675949211, 10.211658278729358, 10.87434843627936, 11.839583492272787, 11.775322011058586, 10.873528141405796, 9.992726630124132, 10.939696015899516, 11.864896459302981, 12.713556941385239, 13.689171718838118, 14.567598440899179, 15.48167084187951, 16.451468361683016, 15.420337203951936, 14.350791632088084, 13.420823676335143, 12.523825131567186, 11.770360583965955, 10.94354267975172, 10.065934510758705, 9.231469296618204, 9.831637384639189, 10.848662991557216, 11.760219358061818, 11.89902872461046, 10.94712998815046, 11.92137207329176, 12.880979789915681, 13.686330780584413, 14.644629241459032, 15.568406637582234, 16.506624765699108, 16.388357087932857, 14.427896123726173, 13.414970689404434, 12.485356866684755, 11.59252781736524, 10.743016572096524, 9.882750288231282, 9.05757822138807, 8.161764855492914, 8.823823449796276, 9.795181344202343, 10.752166399060586, 11.734638176674231, 11.922058598818705, 12.920498673021637, 13.909884449780437, 14.629829320557803, 15.575942297569298, 16.53873101587349, 16.392990031393463, 15.40206859652032, 13.518127929421162, 12.583066261927536, 11.545899923413137, 10.619604434146458, 9.807820888659467, 8.921587646692073, 8.00800458461269, 7.149790855313643, 7.8711239868485094, 8.79990117613857, 9.709967616515584, 10.687005190095928, 11.634406615073289, 12.59723183202093, 13.58122550184303, 14.521243177825697, 15.553734198451307, 16.385031156663146, 15.385289250939838, 14.509510635567613, 12.57227866187389, 11.614245281333963, 10.61869699010203, 9.656905347329745, 8.870380864651528, 7.886136666879454, 6.934628105818344, 6.140227432572566, 6.938138382507303, 7.864798656517072, 8.738128847966893, 9.737404242559897, 10.682300637246236, 11.67599870881237, 12.711779236132005, 13.649471119603433, 14.634541195924196, 15.402380798355505, 14.41603363748425, 13.578403289787012, 11.588843297603857, 10.704208785388312, 9.722146214757258, 8.731135368364898, 7.8299348185518856, 6.855829237021486, 5.885374356977173, 5.177898274092037, 5.912835692108626, 6.857292445763087, 7.782642565996803, 8.718850436136588, 9.751610031998561, 10.681223343080427, 11.69673253111083, 12.711875704714398, 13.611184307152458, 14.50397178510438, 13.463278323471593, 12.529138259225277, 10.658088490084975, 9.779413783478422, 8.75698949049659, 7.77320256096542, 6.800231387833593, 5.906287702432838, 4.9265934257093855, 4.115482335257596, 4.9305228239233285, 5.9685204747401635, 6.873091835212945, 7.90453798770195, 8.810242573693964, 9.650030339549334, 10.663582211312363, 11.720153827587774, 12.648160417313449, 13.48516808524831, 12.523062806438947, 11.597577029458494, 9.679624220989325, 8.73275093559119, 7.7567099287659, 6.841018462606405, 5.776454350187981, 4.892113515645903, 3.935812327776357, 3.145526750678768, 3.9867121607125466, 4.974754970495694, 5.863442205696387, 6.833084731378359, 7.761653948840953, 8.702102305498146, 9.708475292664517, 10.70343609118768, 11.68796768600423, 12.594010456767174, 11.633207005824234, 10.633366638492737, 8.811983223778055, 7.738572816637496, 6.777396783908214, 5.840481603924764, 4.842518085136339, 3.993386826949604, 2.983269343856929, 2.080504517820782, 2.9710016255837073, 3.954028749076434, 4.891360327782776, 5.8969908644644065, 6.939409240614905, 7.988006746151548, 8.983003230899952, 10.020526378297939, 10.979605733097687, 11.853077009328226, 10.810987255653938, 9.776172591666775, 7.99589994401184, 6.94995842313642, 5.899985463575202, 4.907789891757567, 3.8749266117344536, 2.923896655690494, 1.9756427558551537, 1.0446144447957488, 1.9755185323726812, 3.0243175390886017, 3.9765809815267437, 4.933535241451596, 5.980959821107085, 6.972749948662245, 7.957771622712384, 9.019940482592622, 10.012960998140386, 10.984630880242014, 9.972140039585085, 9.015437177708609], [7.086323708966578, 8.035968222086128, 9.029310557630117, 9.989102711171688, 9.14744806089218, 8.14274974580333, 7.128467842881493, 6.07435920392149, 5.034821400181572, 3.9679769985058977, 2.9804111615686484, 1.9539355712824966, 0.9899928986421026, 0.0, 0.9565995308545777, 1.9276353581112402, 2.9661362925218406, 3.9783282516706815, 5.026875492282555, 6.046511962676323, 7.772012481007564, 8.717096575360824, 9.695553782154006, 10.696438008025472, 9.761284603300172, 8.78407139034937, 7.7230455017012964, 6.787819770146605, 5.801072763514145, 4.779956734318595, 3.8258514763098144, 2.8962184669085502, 1.9332137568343564, 0.9519372804696042, 1.8835649236673135, 2.889934805004825, 3.852895176150058, 4.897876669207562, 5.884495986247663, 6.831422374803683, 8.75319556419151, 9.717752397149637, 10.730385244845936, 11.725331881178437, 10.701511247314892, 9.703041629290881, 8.653827915772865, 7.635787571060137, 6.665961255421565, 5.713132308863497, 4.801027329062131, 3.8337179128378693, 2.922639524018978, 1.9740555279462708, 2.9027958809145513, 3.940910429633035, 4.834840593759802, 5.868154939782578, 6.832169814499013, 7.769188925615373, 9.726564781225578, 10.679161471988785, 11.663378138807833, 12.613189303179906, 11.620428703560286, 10.551672220548193, 9.568052717438416, 8.568967917918641, 7.612795726625072, 6.6666986597210895, 5.867791058599893, 4.846081617316311, 3.889544323671884, 3.0209157369139152, 3.847102042426937, 4.9212752487676354, 5.788506810025933, 6.726636432015484, 7.724172761230816, 8.661680600966008, 10.543830314612824, 11.575514513906821, 12.543357087961148, 13.429265161743588, 12.46505829528031, 11.531410366571757, 10.542358721296736, 9.599622807673915, 8.634440177567352, 7.700692998026334, 6.752991839865835, 5.776173371804105, 4.865516943148726, 3.947524074672454, 4.91723091710128, 5.874061273048817, 6.76872023119692, 7.688101652765937, 8.66533855730425, 9.605929710584636, 11.490872855213315, 12.446078856710045, 13.437485870313298, 14.428278532087274, 13.402609737109856, 12.46500267739466, 11.558186595392792, 10.524871448459162, 9.644658846469461, 8.678360322448333, 7.81153374795758, 6.798216947857033, 5.866876577189165, 4.988845593926541, 5.946688793889157, 6.832682701886043, 7.724448767673258, 8.736162587197908, 9.599897269828258, 10.580723110085852, 12.484074943336678, 13.459660439518467, 14.469748465165386, 15.370825091259263, 14.39455283940519, 13.51580157299466, 12.48626671580743, 11.470965395175472, 10.627509878523156, 9.614140349409777, 8.760201105179279, 7.842667761456809, 6.9121872230263435, 5.982588429241333, 6.990405209540984, 7.8247825114290075, 8.657282797190504, 9.67078245084447, 10.56401558553742, 11.569369521931238, 13.45128125663482, 14.441948839533577, 15.38955953843871, 15.584485399200025, 14.848628163844053, 13.958778926245794, 12.972118867678514, 12.417474177615572, 11.56932576875142, 10.630787995256838, 9.797919647301494, 8.84479572471109, 7.844281558888329, 7.050748658821681, 7.96065505207779, 8.84076298220851, 9.621215115012923, 10.553072795291447, 11.503734750583195, 12.494991062326644, 14.379881312738977, 15.376012138111284, 15.461540316745046, 14.517330401819681, 13.817240330477155, 12.991555396824609, 11.967484612483005, 12.781204480017927, 12.558553042393779, 11.593850045606192, 10.786335667777491, 9.746609475370466, 8.786946197875722, 8.04484685165897, 8.976256954627377, 9.777929073836543, 10.62383116460823, 11.555296847086776, 12.545105913812295, 13.455543274407342, 15.386373357449088, 15.399202503285212, 14.426421081566703, 13.548130394324955, 12.766570050875576, 11.981266322525116, 11.03427106456425, 11.838032113492805, 12.78609800162114, 12.563952477630325, 11.73087452790989, 10.74802545812644, 9.800282422405425, 9.002445874190435, 9.96495894978903, 10.763860452020902, 11.680033869488852, 12.506991088750016, 13.46190800589314, 14.449827247649093, 15.280455869645479, 14.330294120262474, 13.368738109317674, 12.549927629974361, 11.822609055382177, 11.025327694180369, 10.09645386085001, 10.911762832394084, 11.806938252326423, 12.77217330831985, 12.680180985874504, 11.759387036212356, 10.828239038106092, 10.04884475116268, 10.917123976383076, 11.723564042743137, 12.699178820196018, 13.577605542257075, 14.491677943237406, 15.461475463040912, 14.430344305309832, 13.36079873344598, 12.43083077769304, 11.533832232925082, 10.780367685323853, 9.953549781109619, 9.075941612116605, 9.93157385028293, 10.764227200686252, 11.781252807604279, 12.692809174108877, 12.78488761941702, 11.78264239613242, 11.030520808554924, 11.933207306995776, 12.696337881942311, 13.65463634281693, 14.57841373894013, 15.516631867057004, 15.398364189290753, 13.437903225084069, 12.42497779076233, 11.495363968042652, 10.602534918723137, 9.753023673454422, 8.89275738958918, 8.06758532274597, 8.86186940915764, 9.756413265843339, 10.727771160249405, 11.684756215107646, 12.66722799272129, 12.757571006800665, 12.0296474082848, 12.962111966860531, 13.639836421915701, 14.585949398927196, 15.548738117231387, 15.402997132751358, 14.412075697878215, 12.528135030779058, 11.593073363285432, 10.555907024771033, 9.629611535504354, 8.817827990017365, 7.93159474804997, 7.018011685970588, 7.849895408978369, 8.80371380289557, 9.73249099218563, 10.642557432562644, 11.619595006142987, 12.566996431120348, 13.071809886369747, 13.900909963257728, 14.57736321127556, 15.55208859043503, 15.395038258021044, 14.395296352297734, 13.51951773692551, 11.582285763231786, 10.624252382691859, 9.628704091459927, 8.666912448687642, 7.880387966009426, 6.896143768237351, 5.944635207176241, 6.840331986237291, 7.870728198554364, 8.797388472564132, 9.670718664013952, 10.669994058606957, 11.614890453293295, 12.633835844155305, 13.683818225396381, 14.639464018245537, 15.354877315738573, 14.412387899713401, 13.426040738842147, 12.588410391144908, 10.598850398961753, 9.71421588674621, 8.732153316115156, 7.741142469722795, 6.839941919909783, 5.865836338379383, 4.89538145833507, 5.878002827756762, 6.845425508155686, 7.789882261810147, 8.715232382043864, 9.651440252183647, 10.68419984804562, 11.671216241722531, 12.686725429752935, 13.701868603356502, 14.491906817029285, 13.513978886462276, 12.47328542482949, 11.539145360583174, 9.66809559144287, 8.789420884836318, 7.766996591854489, 6.783209662323318, 5.810238489191489, 4.916294803790735, 3.9366005270672826, 4.918614474502199, 5.873035675418472, 6.911033326235307, 7.836534776530499, 8.894530886344054, 9.800235472336068, 10.640023238191437, 11.653575109954467, 12.710146726229878, 13.528882927190276, 12.495175186606206, 11.533069907796843, 10.60758413081639, 8.689631322347221, 7.742758036949087, 6.7667170301237975, 5.851025563964303, 4.786461451545878, 3.902120617003801, 2.9458194291342545, 3.9622946765392486, 4.9501551020301005, 5.938197911813248, 6.826885147013941, 7.823077630020463, 8.751646847483057, 9.69209520414025, 10.69846819130662, 11.693428989829783, 12.568690195881057, 11.60401755812507, 10.64321410718213, 9.643373739850633, 7.821990325135953, 6.748579917995394, 5.787403885266112, 4.850488705282662, 3.852525186494236, 3.003393928307501, 1.9932764452148266, 2.948300176925941, 3.934444566901261, 4.917471690393988, 5.85480326910033, 6.88698376310651, 7.929402139257009, 8.97799964479365, 9.972996129542054, 11.010519276940041, 11.8918854728396, 10.863084110686124, 9.820994357011836, 8.786179693024673, 7.005907045369738, 5.959965524494318, 4.9099925649331, 3.9177969931154646, 2.884933713092351, 1.933903757048391, 0.9856498572130512, 2.0169062839929888, 2.9655114310147836, 4.014310437730705, 4.966573880168847, 5.9235281400936985, 6.970952719749188, 7.962742847304348, 8.947764521354486, 10.009933381234724, 10.9252407378823, 9.994637981599912, 8.982147140942983, 8.025444279066507], [6.129724178111999, 7.07936869123155, 8.072711026775538, 9.032503180317109, 10.085969883931083, 9.09934927665791, 8.085067373736072, 7.0309587347760685, 5.991420931036151, 4.9245765293604755, 3.9370106924232258, 2.9105351021370742, 1.9465924294966803, 0.9565995308545777, 0.0, 0.9710358272566624, 2.009536761667263, 3.0217287208161037, 4.070275961427977, 5.0899124318217455, 6.815412950152987, 7.760497044506247, 8.738954251299429, 9.79749211239606, 10.71788413415475, 9.740670921203947, 8.679645032555873, 7.744419301001182, 6.757672294368722, 5.736556265173172, 4.782451007164392, 3.852817997763128, 2.8898132876889338, 1.9085368113241818, 0.9269653928127358, 1.9333352741502474, 2.8962956452954804, 3.9412771383529854, 4.927896455393086, 5.874822843949106, 7.796596033336933, 8.76115286629506, 9.773785713991359, 10.771651070849252, 11.658110778169469, 10.659641160145458, 9.610427446627442, 8.592387101914714, 7.622560786276142, 6.669731839718074, 5.757626859916708, 4.790317443692447, 3.867780235999448, 2.9191962399267406, 1.9461963500599735, 2.9843108987784577, 3.878241062905225, 4.911555408928001, 5.875570283644436, 6.8125893947607965, 8.769965250371001, 9.722561941134206, 10.706778607953254, 11.656589772325328, 12.577028234414861, 11.508271751402768, 10.524652248292991, 9.525567448773216, 8.569395257479648, 7.6232981905756665, 6.82439058945447, 5.798316084315745, 4.834685035652353, 3.9386166325424856, 2.8905025115723593, 3.9646757179130576, 4.831907279171356, 5.770036901160907, 6.7675732303762395, 7.705081070111432, 9.587230783758248, 10.618914983052242, 11.58675755710657, 12.626440257985873, 13.421657826134885, 12.488009897426332, 11.498958252151311, 10.55622233852849, 9.59103970842193, 8.65729252888091, 7.70522630686527, 6.728407838803539, 5.810657655129195, 4.865224970301025, 3.9606313862467024, 4.917461742194239, 5.812120700342343, 6.73150212191136, 7.708739026449672, 8.64933017973006, 10.534273324358738, 11.489479325855468, 12.48088633945872, 13.508811540957396, 14.359209267964431, 13.421602208249235, 12.514786126247367, 11.481470979313738, 10.601258377324038, 9.63495985330291, 8.763768214957015, 7.750451414856467, 6.812017289169635, 5.906546489555112, 4.99008926303458, 5.876083171031465, 6.767849236818681, 7.779563056343331, 8.643297738973681, 9.624123579231275, 11.5274754124821, 12.50306090866389, 13.51314893431081, 14.498014969946087, 14.977871690650277, 14.200024258635574, 13.442866246662005, 12.427564926030048, 11.584109409377733, 10.570739880264354, 9.712435572178714, 8.787808473437279, 7.857327935006813, 6.900289324869903, 6.0482254575589804, 6.86818298057443, 7.700683266335927, 8.714182919989893, 9.607416054682844, 10.61276999107666, 12.494681725780243, 13.485349308679, 14.432960007584134, 14.627885868345446, 13.922205061667421, 13.214561582793568, 13.919293318848403, 13.374073708470148, 12.525925299605998, 11.587387526111415, 10.74561490593855, 9.789936436691562, 8.7894222708688, 7.968449554450252, 7.018475300095787, 7.884163451353931, 8.664615584158346, 9.59647326443687, 10.547135219728618, 11.538391531472067, 13.4232817818844, 14.419412607256707, 14.504940785890467, 13.560730870965102, 12.890817228300524, 12.232518520093926, 12.914659063652895, 13.728378931187816, 13.515152573248356, 12.55044957646077, 11.731476379757963, 10.691750187350937, 9.732086909856193, 8.962547747287541, 8.034077202645374, 8.821329542981964, 9.667231633753653, 10.598697316232201, 11.588506382957718, 12.498943743552765, 14.429773826594513, 14.442602972430633, 13.469821550712124, 12.591530863470377, 11.840146948698944, 11.22072241974767, 11.981445515734139, 12.785206564662694, 13.733272452791029, 13.520552008484902, 12.676015239890361, 11.693166170106911, 10.745423134385897, 9.920146769819006, 9.022779197807028, 9.807260921166323, 10.723434338634274, 11.550391557895441, 12.505308475038564, 13.493227716794518, 14.3238563387909, 13.373694589407895, 12.412138578463095, 11.593328099119782, 10.896185953205546, 10.264783791402923, 11.0436283120199, 11.858937283563973, 12.754112703496313, 13.71934775948974, 13.625321697854975, 12.704527748192827, 11.773379750086564, 10.900144667804538, 9.974944224401073, 10.766964511888558, 11.742579289341439, 12.6210060114025, 13.53507841238283, 14.504875932186337, 13.473744774455254, 12.404199202591402, 11.47423124683846, 10.577232702070503, 9.853944583147221, 9.193005878332174, 10.023116063286494, 10.87874830145282, 11.711401651856141, 12.728427258774168, 13.63998362527877, 13.730028331397492, 12.727783108112892, 11.881820725196782, 10.991027555013773, 11.739738351087732, 12.698036811962352, 13.621814208085555, 14.560032336202429, 14.441764658436174, 12.48130369422949, 11.468378259907752, 10.538764437188073, 9.645935387868558, 8.82660057127779, 8.132213486811736, 9.01475977391586, 9.80904386032753, 10.703587717013228, 11.674945611419295, 12.631930666277537, 13.614402443891182, 13.702711718781137, 12.880947324926659, 12.019932214878528, 12.683236891061123, 13.629349868072618, 14.592138586376812, 14.446397601896782, 13.455476167023637, 11.57153549992448, 10.636473832430854, 9.599307493916454, 8.673012004649776, 7.891404887840733, 7.171050845272527, 7.9651861371404795, 8.797069860148259, 9.750888254065462, 10.679665443355521, 11.589731883732535, 12.566769457312878, 13.514170882290239, 13.923109803011606, 12.958730211275725, 13.620763680420982, 14.595489059580451, 14.438438727166469, 13.438696821443159, 12.56291820607093, 10.625686232377207, 9.66765285183728, 8.672104560605348, 7.710312917833063, 6.953964863832794, 6.135599865459908, 6.891809658346133, 7.787506437407182, 8.817902649724255, 9.744562923734023, 10.617893115183843, 11.617168509776848, 12.562064904463186, 13.581010295325196, 13.910582599112738, 14.601344781336664, 14.398277784883998, 13.455788368858826, 12.469441207987572, 11.631810860290331, 9.642250868107176, 8.757616355891631, 7.775553785260576, 6.784542938868216, 5.91351881773315, 5.10529243560194, 5.842555909504961, 6.825177278926653, 7.792599959325577, 8.737056712980038, 9.662406833213755, 10.598614703353539, 11.631374299215512, 12.62781577257711, 13.643324960607513, 14.568868878776959, 13.535307286174708, 12.557379355607699, 11.516685893974913, 10.582545829728597, 8.711496060588294, 7.83282135398174, 6.81039706099991, 5.8266101314687395, 4.853638958336912, 4.155750901013292, 4.883774978237174, 5.86578892567209, 6.820210126588363, 7.858207777405198, 8.78370922770039, 9.848676943987071, 10.756835003190647, 11.596622769046016, 12.610174640809046, 13.577147001650335, 12.572283396335699, 11.538575655751629, 10.576470376942266, 9.650984599961813, 7.733031791492644, 6.786158506094509, 5.81011749926922, 4.894426033109724, 3.8298619206913003, 3.1040620428280796, 3.8929938803041457, 4.90946912770914, 5.897329553199992, 6.885372362983139, 7.7740595981838325, 8.77967716087504, 9.708246378337636, 10.648694734994828, 11.6550677221612, 12.59662225984303, 11.61209066502648, 10.647418027270493, 9.686614576327553, 8.686774208996056, 6.8653907942813746, 5.791980387140816, 4.830804354411534, 3.893889174428084, 2.895925655639658, 2.0467943974529232, 2.940450896384718, 3.8954746280958323, 4.881619018071152, 5.864646141563879, 6.801977720270221, 7.843583293961087, 8.886001670111586, 9.934599175648229, 10.929595660396632, 11.926149059786193, 10.935285941985022, 9.906484579831545, 8.864394826157257, 7.829580162170094, 6.04930751451516, 5.00336599363974, 3.953393034078522, 2.9611974622608868, 1.9283341822377733, 0.9773042261938134, 1.9328243083829424, 2.96408073516288, 3.922110961869361, 4.970909968585282, 5.923173411023424, 6.880127670948276, 7.927552250603766, 8.919342378158927, 9.904364052209065, 10.961661722575485, 9.968641207027721, 9.038038450745333, 8.025547610088404, 7.068844748211929], [5.158688350855337, 6.108332863974888, 7.101675199518877, 8.061467353060449, 9.114934056674423, 10.070385103914571, 9.056103200992734, 8.00199456203273, 6.962456758292813, 5.8956123566171375, 4.908046519679888, 3.8815709293937366, 2.9176282567533427, 1.9276353581112402, 0.9710358272566624, 0.0, 1.0385009344106004, 2.0506928935594413, 3.0992401341713145, 4.1188766045650835, 5.868575496184757, 6.813659590538016, 7.7921167973311976, 8.850654658427828, 9.785808063153128, 10.711706748460609, 9.650680859812535, 8.715455128257844, 7.728708121625384, 6.707592092429834, 5.753486834421054, 4.82385382501979, 3.8608491149455966, 2.8795726385808447, 1.898001220069398, 1.0655737587724465, 2.0285341299176793, 2.9944396843847554, 3.9810590014248564, 4.9279853899808765, 6.849758579368704, 7.814315412326829, 8.826948260023126, 9.82481361688102, 10.79491182444165, 11.63067698740212, 10.581463273884104, 9.563422929171375, 8.593596613532805, 7.640767666974736, 6.72866268717337, 5.761353270949109, 4.83881606325611, 3.8902320671834025, 2.9172321773166354, 2.116549383400657, 3.010479547527424, 3.964717954959771, 4.928732829676207, 5.865751940792567, 7.882752425991121, 8.775724487165977, 9.759941153985025, 10.709752318357099, 11.718249605184324, 12.479307578659432, 11.495688075549655, 10.49660327602988, 9.540431084736312, 8.59433401783233, 7.795426416711132, 6.769351911572407, 5.805720862909015, 4.9096524597991476, 3.861538338829021, 3.1315522021061173, 3.9641457637935553, 4.902275385783105, 5.899811714998438, 6.8373195547336305, 8.719469268380445, 9.751153467674442, 10.709983860341671, 11.748625490338604, 12.712832356801883, 13.459045724682996, 12.469994079407975, 11.527258165785154, 10.562075535678593, 9.628328356137573, 8.67626213412193, 7.699443666060201, 6.781693482385857, 5.836260797557687, 4.931667213503364, 4.093136437611203, 4.944359184964543, 5.863740606533558, 6.840977511071871, 7.781568664352257, 9.666511808980935, 10.621717810477666, 11.613124824080918, 12.641050025579593, 13.669825237058102, 14.392638035505898, 13.485821953504031, 12.452506806570401, 11.572294204580702, 10.605995680559571, 9.734804042213675, 8.72148724211313, 7.783053116426297, 6.877582316811774, 5.961125090291242, 5.051757866448429, 5.9000877214408805, 6.911801540965529, 7.77553622359588, 8.756362063853473, 10.659713897104298, 11.635299393286088, 12.645387418933007, 13.630253454568283, 14.006835863393613, 14.844599217275205, 14.413902073918669, 13.398600753286711, 12.555145236634397, 11.541775707521015, 10.683471399435374, 9.75884430069394, 8.828363762263475, 7.871325152126565, 7.019261284815642, 6.043857675991394, 6.832921750958127, 7.846421404612091, 8.739654539305043, 9.74500847569886, 11.62692021040244, 12.617587793301198, 13.565198492206331, 13.656850041088786, 12.951169234410758, 13.859136541433198, 14.720288977828597, 14.345109535726811, 13.496961126862661, 12.558423353368077, 11.716650733195213, 10.760972263948224, 9.760458098125461, 8.939485381706914, 7.989511127352449, 7.059838146770895, 7.796854068780545, 8.72871174905907, 9.679373704350818, 10.670630016094266, 12.555520266506598, 13.551651091878904, 13.533904958633805, 12.589695043708442, 11.91978140104386, 12.877093478733556, 13.715654722633088, 14.605636373976598, 14.486188400505018, 13.521485403717431, 12.702512207014623, 11.662786014607597, 10.703122737112853, 9.88835236670749, 8.934743643717711, 7.997004238398927, 8.799470118375853, 9.7309358008544, 10.720744867579917, 11.631182228174964, 13.562012311216709, 13.471567145173971, 12.498785723455462, 11.620495036213716, 10.86911112144228, 11.8652973783873, 12.782441174714332, 13.662464007451478, 14.61052989557981, 14.491587835741564, 13.647051067147022, 12.664201997363572, 11.716458961642557, 10.845951389238955, 9.923445638879365, 8.982935616583287, 9.855672823256473, 10.68263004251764, 11.637546959660764, 12.625466201416717, 13.352820511534238, 12.402658762151233, 11.441102751206433, 10.622292271863122, 9.925150125948882, 10.942240572688512, 11.844623971000093, 12.736194726352757, 13.631370146285095, 14.596605202278521, 14.596357525111635, 13.675563575449488, 12.744415577343224, 11.800811108876875, 10.87561066547341, 9.942639207305522, 10.874817773963638, 11.7532444960247, 12.66731689700503, 13.637114416808537, 12.502708947198592, 11.43316337533474, 10.503195419581798, 9.606196874813843, 8.882908755890558, 9.870462659617761, 10.824111722266688, 11.756005744241603, 12.588659094644923, 13.60568470156295, 14.517241068067552, 14.701064158654152, 13.698818935369552, 12.782487166269119, 11.89169399608611, 10.915413046504696, 11.873063248724291, 12.754052692707754, 13.692270820824628, 13.470728831179512, 11.510267866972828, 10.49734243265109, 9.567728609931411, 8.674899560611896, 7.855564744021127, 8.84210157920704, 9.815755432896053, 10.686301303116313, 11.58084515980201, 12.552203054208077, 13.509188109066319, 14.491659886679964, 14.673747546037797, 13.781613765998996, 12.882829824404105, 11.858911586478087, 12.805024563489582, 13.724377070999012, 13.475361774640119, 12.484440339766975, 10.600499672667816, 9.665438005174192, 8.628271666659792, 7.701976177393114, 6.92036906058407, 7.880938937667829, 8.842443579929261, 9.674327302937042, 10.628145696854244, 11.556922886144303, 12.466989326521317, 13.44402690010166, 14.391428325079021, 14.720449721642714, 13.736456051820614, 12.796438375837946, 13.771163754997415, 13.467402899909805, 12.467660994186495, 11.591882378814267, 9.654650405120545, 8.696617024580618, 7.701068733348686, 6.739277090576401, 5.982929036576131, 6.845487957855211, 7.769067101134915, 8.664763880195965, 9.695160092513037, 10.621820366522805, 11.495150557972625, 12.49442595256563, 13.439322347251968, 14.458267738113978, 14.688308439657627, 13.777019476753628, 13.427241957627334, 12.484752541602163, 11.498405380730908, 10.660775033033667, 8.671215040850514, 7.786580528634969, 6.804517958003914, 5.813507111611554, 4.9424829904764875, 5.815180527997242, 6.719813352293744, 7.702434721715436, 8.66985740211436, 9.61431415576882, 10.539664276002537, 11.47587214614232, 12.508631742004294, 13.519173234457055, 14.58202095396966, 13.597833051520295, 12.564271458918045, 11.586343528351035, 10.545650066718249, 9.611510002471933, 7.740460233331631, 6.861785526725077, 5.839361233743248, 4.855574304212078, 3.8826031310802493, 4.865638993408594, 5.7610324210259565, 6.743046368460873, 7.697467569377146, 8.73546522019398, 9.741235210140497, 10.806202926427178, 11.727870830447308, 12.567658596302678, 13.581210468065706, 12.606111174393671, 11.601247569079035, 10.567539828494965, 9.605434549685603, 8.67994877270515, 6.7619959642359815, 5.815122678837846, 4.839081672012557, 3.923390205853062, 2.858826093434638, 3.8139501352233824, 4.770251323092928, 5.7867265704979225, 6.812384403038906, 7.800427212822053, 8.731585580623939, 9.750712988131703, 10.679282205594298, 11.61973056225149, 12.62054723110953, 11.625586432586367, 10.641054837769817, 9.67638220001383, 8.71557874907089, 7.715738381739392, 5.894354967024713, 4.820944559884153, 3.859768527154872, 2.9228533471714218, 1.9248898283829958, 2.9976635694163196, 3.91148672364138, 4.866510455352494, 5.852654845327814, 6.835681968820541, 7.773013547526883, 8.81461912121775, 9.857037497368248, 10.90563500290489, 11.900631487653296, 10.955113232529532, 9.964250114728362, 8.935448752574883, 7.893358998900595, 6.858544334913432, 5.078271687258497, 4.032330166383077, 2.9823572068218596, 1.9901616350042244, 0.9572983549811108, 1.9483400534504758, 2.9038601356396048, 3.9351165624195423, 4.893146789126024, 5.941945795841944, 6.894209238280086, 7.851163498204938, 8.898588077860428, 9.890378205415589, 10.875399879465729, 9.990625895318825, 8.997605379771061, 8.067002623488673, 7.054511782831743, 6.097808920955266], [4.120187416444738, 5.069831929564288, 6.063174265108278, 7.022966418649849, 8.076433122263824, 9.081131437352674, 10.094604135403333, 9.040495496443329, 8.000957692703413, 6.934113291027738, 5.946547454090489, 4.9200718638043375, 3.956129191163943, 2.9661362925218406, 2.009536761667263, 1.0385009344106004, 0.0, 1.0121919591488409, 2.060739199760714, 3.080375670154483, 4.830074561774156, 5.775158656127415, 6.753615862920596, 7.812153724017227, 8.747307128742527, 9.72452034169333, 10.689181794223137, 9.753956062668445, 8.767209056035984, 7.746093026840435, 6.791987768831655, 5.862354759430391, 4.8993500493561974, 3.918073572991445, 2.9365021544799985, 2.0350739698112013, 1.0721135986659684, 1.955938749974155, 2.942558067014256, 3.8894844555702757, 5.811257644958102, 6.775814477916228, 7.788447325612526, 8.786312682470419, 9.756410890031049, 10.712858788192635, 11.619964208294704, 10.601923863581975, 9.632097547943404, 8.679268601385337, 7.767163621583971, 6.79985420535971, 5.87731699766671, 4.9287330015940025, 3.955733111727236, 3.0860495944394115, 2.054059016275713, 2.9262170205491707, 3.890231895265606, 4.827251006381966, 6.844251491580519, 7.737223552755375, 8.721440219574424, 9.671251383946498, 10.679748670773723, 11.736630214278577, 12.534189009960254, 11.53510421044048, 10.578932019146912, 9.632834952242929, 8.833927351121734, 7.807852845983007, 6.844221797319615, 5.948153394209748, 4.900039273239622, 4.077216701471638, 3.007725232541844, 3.9458548545313947, 4.942179754491032, 5.814105078541805, 7.74335922351631, 8.775043422810306, 9.67148292593107, 10.710124555928003, 11.674331422391282, 12.607979351099834, 13.508495013818575, 12.565759100195754, 11.600576470089193, 10.666829290548172, 9.71476306853253, 8.7379446004708, 7.820194416796457, 6.874761731968287, 5.970168147913965, 5.038800936976724, 3.987938653712831, 4.907320075281848, 5.88455697982016, 6.805458619488122, 8.690401764116801, 9.645607765613532, 10.637014779216784, 11.66493998071546, 12.69371519219397, 13.541571661922736, 14.52432288791463, 13.491007740981, 12.610795138991302, 11.644496614970171, 10.773304976624274, 9.759988176523729, 8.821554050836896, 7.916083251222374, 6.9656283269318156, 5.918441132984674, 4.943667190189169, 5.955381009713818, 6.81911569234417, 7.780252018989339, 9.683603852240164, 10.659189348421954, 11.669277374068873, 12.654143409704151, 13.630415661558224, 14.592370557522736, 15.452403008329268, 14.43710168769731, 13.593646171044997, 12.580276641931615, 11.721972333845974, 10.79734523510454, 9.866864696674075, 8.82247297187612, 7.81465619157647, 6.835946533072412, 5.876501219706414, 6.89000087336038, 7.783234008053332, 8.769294306907714, 10.650810165538307, 11.641477748437064, 12.589088447342197, 12.618349106678187, 13.551708925687633, 14.459676232710073, 15.354109486547888, 15.38361047013741, 14.535462061273261, 13.596924287778677, 12.736401160843647, 11.780722691596658, 10.780208525773896, 9.714126717115981, 8.729851642723846, 7.787758127427493, 6.840433537528833, 7.772291217807357, 8.722953173099107, 9.714209484842556, 11.579410221642464, 12.57554104701477, 12.495404024223205, 11.551194109297843, 12.520321092320735, 13.477633170010431, 14.349475231352379, 15.294840258185591, 15.524689334915617, 14.55998633812803, 13.679390198407537, 12.639664006000512, 11.680000728505767, 10.616272347364088, 9.662663624374309, 8.724924219055525, 7.84304958712414, 8.774515269602688, 9.764324336328206, 10.674761696923253, 12.585902266352576, 12.433066210763371, 11.460284789044863, 10.581994101803117, 11.469650812719156, 12.465837069664175, 13.416261683433623, 14.351667891660469, 15.321469583573768, 15.455984186549442, 14.502666594281688, 13.519817524498238, 12.507424214665114, 11.573871369895553, 10.651365619535962, 9.710855597239885, 8.89925229200476, 9.726209511265928, 10.681126428409051, 11.669045670165005, 12.314319577123639, 11.364157827740634, 10.402601816795833, 9.583791337452523, 10.525689817225757, 11.560300018149611, 12.478444479719384, 13.495534105215414, 14.532453680049782, 15.509282103496423, 15.451973052246302, 14.40684847341512, 13.475700475308857, 12.528731089533473, 11.603530646130007, 10.67055918796212, 9.918397242711926, 10.796823964772987, 11.710896365753317, 12.680693885556824, 11.464208012787992, 10.39466244092414, 9.464694485171199, 8.567695940403244, 9.500968201351657, 10.48852210507886, 11.457932230985978, 12.515345123104261, 13.579352161506723, 14.633628409293049, 15.545184775797647, 15.432349056619785, 14.430103833335185, 13.510407146925717, 12.619613976742707, 11.643333027161294, 10.916642717472579, 11.797632161456042, 12.735850289572916, 12.432227896768913, 10.471766932562229, 9.45884149824049, 8.529227675520811, 7.636398626201298, 8.588002402914471, 9.582738397190692, 10.556392250879705, 11.597840534388757, 12.608788867532109, 13.580146761938176, 14.537131816796416, 15.51960359441006, 15.40503244400343, 14.509533746655594, 13.610749805060703, 12.586831567134684, 11.968363442999152, 12.7679565397473, 12.436860840229519, 11.445939405356375, 9.561998738257216, 8.62693707076359, 7.589770732249192, 6.663475242982514, 7.6528067194774145, 8.717216034838838, 9.75326282436953, 10.70227101066714, 11.65608940458434, 12.5848665938744, 13.494933034251414, 14.471970607831757, 15.419372032809118, 15.448369702299312, 14.464376032477212, 13.524358356494544, 12.934502634506986, 12.428901965499206, 11.429160059775896, 10.553381444403668, 8.616149470709944, 7.658116090170018, 6.6625677989380865, 5.7007761561658015, 6.760568558323211, 7.766494629629253, 8.797010808865013, 9.692707587926062, 10.723103800243134, 11.649764074252902, 12.523094265702722, 13.522369660295727, 14.467266054982066, 15.41869799327001, 14.368715612028934, 13.401463058634635, 12.388741023216735, 11.446251607191563, 10.459904446320309, 9.622274098623068, 7.632714106439915, 6.74807959422437, 5.766017023593315, 4.775006177200955, 5.825983845356089, 6.765329793352396, 7.747757060023841, 8.730378429445533, 9.697801109844457, 10.642257863498918, 11.567607983732634, 12.503815853872418, 13.536575449734391, 14.547116942187152, 13.602058819203394, 12.559332117109696, 11.525770524507445, 10.547842593940434, 9.50714913230765, 8.573009068061333, 6.7019592989210315, 5.823284592314478, 4.800860299332648, 3.8170733698014776, 4.816831779262921, 5.815788258763748, 6.788976128756054, 7.77099007619097, 8.725411277107243, 9.763408927924079, 10.769178917870594, 11.834146634157275, 12.757450943850493, 13.536347317916489, 12.60579219095833, 11.567610239983072, 10.562746634668436, 9.529038894084364, 8.566933615275001, 7.641447838294549, 5.723495029825382, 4.7766217444272465, 3.800580737601957, 2.8848892714424617, 3.8867698011647343, 4.841893842953479, 5.798195030823026, 6.81467027822802, 7.840328110769003, 8.828370920552151, 9.759529288354036, 10.780293101534888, 11.708862318997483, 12.588419283865301, 11.58204629669893, 10.587085498175767, 9.602553903359217, 8.63788126560323, 7.67707781466029, 6.6772374473287925, 4.855854032614112, 3.782443625473553, 2.8212675927442716, 1.8843524127608213, 2.952833536113092, 4.025607277146416, 4.949987658051981, 5.905011389763096, 6.8911557797384155, 7.874182903231143, 8.811514481937484, 9.85312005562835, 10.89553843177885, 11.944135937315492, 10.95413544551692, 9.916612298118933, 8.925749180317762, 7.896947818164284, 6.854858064489995, 5.820043400502832, 4.039770752847897, 2.9938292319724766, 1.9438562724112591, 0.9516607005936238, 1.9852420627112073, 2.9868409878610764, 3.9423610700502056, 4.973617496830143, 5.931647723536624, 6.980446730252545, 7.932710172690687, 8.88966443261554, 9.937089012271029, 10.92887913982619, 10.014293820788463, 8.952124960908225, 7.959104445360461, 7.028501689078072, 6.016010848421144, 5.059307986544666], [3.1079954572958965, 4.057639970415447, 5.050982305959436, 6.0107744595010075, 7.064241163114982, 8.068939478203832, 9.08322138112567, 10.05268745559217, 9.013149651852254, 7.94630525017658, 6.95873941323933, 5.932263822953178, 4.968321150312784, 3.9783282516706815, 3.0217287208161037, 2.0506928935594413, 1.0121919591488409, 0.0, 1.0485472406118732, 2.0681837110056422, 3.817882602625315, 4.762966696978575, 5.741423903771756, 6.799961764868387, 7.735115169593687, 8.71232838254449, 9.773354271192563, 10.708580002747254, 9.779401015184826, 8.758284985989276, 7.804179727980496, 6.874546718579232, 5.911542008505038, 4.930265532140286, 3.9486941136288394, 2.951688655028052, 1.988728283882819, 0.943746790825314, 1.930366107865415, 2.877292496421435, 4.7990656858092615, 5.763622518767388, 6.776255366463686, 7.7741207233215786, 8.744218930882209, 9.700666829043795, 10.749880542561812, 11.614115822730817, 10.644289507092246, 9.691460560534178, 8.779355580732812, 7.812046164508551, 6.889508956815551, 5.940924960742844, 4.967925070876077, 4.002664279656262, 2.964456989875169, 1.9140250614003298, 2.8780399361167652, 3.815059047233125, 5.832059532431678, 6.725031593606535, 7.709248260425583, 8.659059424797656, 9.667556711624881, 10.724438255129737, 11.707317119148687, 12.547296169589321, 11.591123978295753, 10.64502691139177, 9.846119310270575, 8.820044805131849, 7.856413756468457, 6.960345353358589, 5.9122312323884625, 4.976515573654705, 3.9070241047249112, 2.9688944827353607, 3.929987795342191, 4.801913119392965, 6.73116726436747, 7.762851463661466, 8.65929096678223, 9.697932596779161, 10.66213946324244, 11.595787391950992, 12.584839037226013, 13.527574950848834, 12.612768429238034, 11.679021249697014, 10.726955027681374, 9.750136559619643, 8.8323863759453, 7.886953691117128, 6.894930165107327, 5.938099809159791, 4.887237525895898, 3.9303597034858138, 4.907596608024126, 5.793266660339282, 7.678209804967961, 8.633415806464692, 9.624822820067944, 10.65274802156662, 11.68152323304513, 12.529379702773895, 13.569639529622853, 14.45282359163408, 13.622987098140143, 12.656688574119013, 11.785496935773118, 10.77218013567257, 9.833746009985738, 8.928275210371215, 7.864927199114883, 6.817740005167741, 5.842966062372236, 4.978420637917784, 5.842155320548136, 6.768060059840499, 8.671411893091324, 9.646997389273114, 10.657085414920033, 11.641951450555311, 12.618223702409384, 13.580178598373895, 14.575986333437637, 15.398917538350391, 14.605838130193838, 13.592468601080457, 12.663871052359097, 11.698090048571567, 10.767609510141101, 9.721771844059187, 8.713955063759537, 7.735245405255479, 6.775800091889481, 5.913040501564346, 6.806273636257298, 7.757102347758874, 9.638618206389467, 10.629285789288224, 11.576896488193357, 12.588576005318842, 13.60933304584682, 14.565641274215901, 15.529553674262381, 16.34542632079049, 15.547654020422103, 14.609116246927519, 13.635700033026714, 12.680021563779725, 11.679507397956963, 10.613425589299048, 9.629150514906913, 8.68705699961056, 7.7397324097119, 6.858262050282236, 7.745992801303073, 8.737249113046522, 10.567218262493624, 11.56334908786593, 12.084474404046388, 12.563386068446682, 13.532513051469575, 14.489825129159271, 15.361667190501219, 16.30703221733443, 16.536881294064457, 15.572178297276873, 14.578689070590604, 13.538962878183579, 12.579299600688834, 11.515571219547155, 10.561962496557376, 9.624223091238592, 8.742348459307207, 7.860486102077566, 8.787363964532172, 9.69780132512722, 11.573710307203736, 12.022136590586554, 11.049355168868045, 11.594186060951957, 12.481842771867996, 13.478029028813015, 14.428453642582463, 15.363859850809309, 16.33366154272261, 16.355283058732507, 15.401965466464755, 14.419116396681305, 13.406723086848181, 12.47317024207862, 11.55066449171903, 10.610154469422952, 9.798551164187828, 8.812180343740806, 9.735286387896801, 10.723205629652757, 11.852257827411734, 10.953228207563816, 9.991672196619016, 10.595983296601363, 11.537881776374597, 12.572491977298451, 13.490636438868224, 14.507726064364254, 15.544645639198622, 16.521474062645265, 16.35127192442937, 15.306147345598188, 14.374999347491924, 13.42802996171654, 12.502829518313074, 11.569858060145187, 10.817696114894993, 9.882794797247865, 10.765056325241067, 11.734853845044576, 10.897684733060274, 9.983732820747322, 9.053764864994381, 9.579887899552084, 10.513160160500497, 11.5007140642277, 12.470124190134818, 13.527537082253101, 14.591544120655563, 15.645820368441889, 16.55737673494649, 16.33164792880285, 15.329402705518252, 14.409706019108784, 13.518912848925774, 12.54263189934436, 11.815941589655646, 10.88360299393092, 11.790010249060668, 11.795929432108238, 9.89048394290156, 9.047911878063672, 8.118298055343994, 8.648590585350137, 9.600194362063311, 10.594930356339532, 11.568584210028545, 12.610032493537597, 13.620980826680949, 14.592338721087016, 15.549323775945258, 16.531795553558904, 16.304331316186495, 15.40883261883866, 14.51004867724377, 13.486130439317751, 12.824173955568932, 11.853927372222177, 11.71261180954082, 10.8096409406957, 8.879662830556295, 8.15932963504473, 7.178841112072374, 7.675667202131354, 8.664998678626255, 9.729407993987678, 10.76545478351837, 11.714462969815981, 12.668281363733183, 13.597058553023242, 14.507124993400256, 15.484162566980599, 16.431563991957958, 15.580312638999347, 14.596318969177247, 13.657795128861617, 12.644178239609687, 11.704652934810506, 10.704911029087196, 9.871045536702747, 7.933813563009023, 7.122653419075502, 6.251638178761269, 6.712968115314641, 7.772760517472051, 8.778686588778093, 9.809202768013854, 10.704899547074904, 11.735295759391976, 12.661956033401744, 13.535286224851564, 14.534561619444569, 15.479458014130907, 14.69444896258131, 13.644466581340234, 12.677214027945935, 11.664491992528035, 10.722002576502863, 9.735655415631609, 8.898025067934368, 6.908465075751215, 6.164486433729432, 5.187155437364939, 5.787198136349795, 6.838175804504929, 7.777521752501236, 8.759949019172682, 9.742570388594375, 10.709993068993299, 11.65444982264776, 12.579799942881476, 13.51600781302126, 14.548767408883233, 13.820404025993795, 12.875304090600336, 11.832577388506637, 10.799015795904388, 9.823593563251734, 8.78290010161895, 7.848760037372633, 5.9777102682323315, 5.099035561625778, 4.1436454515502685, 4.829265328950318, 5.829023738411761, 6.827980217912588, 7.801168087904895, 8.783182035339811, 9.737603236256085, 10.775600887072919, 11.781370877019434, 12.846338593306115, 13.769642902999333, 12.789211022462702, 11.85865589550454, 10.840855511380013, 9.835991906065379, 8.804789863395664, 7.842684584586301, 6.917198807605849, 4.999245999136682, 4.052372713738547, 3.076331706913257, 3.8970812305913025, 4.8989617603135756, 5.85408580210232, 6.8103869899718665, 7.826862237376861, 8.852520069917844, 9.840562879700991, 10.771721247502876, 11.792485060683727, 12.721054278146323, 11.841282988411514, 10.834910001245143, 9.83994920272198, 8.87579917475616, 7.913632234914529, 6.95282878397159, 5.952988416640093, 4.101667548681442, 3.0581945947848532, 2.0970185620555717, 2.896544371909662, 3.965025495261933, 5.037799236295257, 5.962179617200822, 6.9172033489119364, 7.903347738887256, 8.886374862379983, 9.823706441086324, 10.86531201477719, 11.90773039092769, 11.002380333179063, 9.941943486368078, 8.904420338970091, 7.9135572211689205, 7.0495875847607365, 6.0729957038177576, 5.065856916570161, 3.073914554006591, 2.106519465148366, 1.0651274587683726, 1.9638526597424648, 2.997434021860048, 3.9990329470099173, 4.9545530291990465, 5.985809455978984, 6.943839682685465, 7.992638689401387, 8.944902131839529, 9.90185639176438, 10.949280971419869, 9.987123535689761, 9.002101861639622, 7.939933001759384, 6.94691248621162, 6.0163097299292305, 5.003818889272302, 4.09345178770336], [2.0594482166840233, 3.0090927298035735, 4.002435065347562, 4.962227218889134, 6.015693922503108, 7.020392237591959, 8.034674140513797, 9.088782779473801, 10.061696892464129, 8.994852490788453, 8.007286653851203, 6.980811063565052, 6.016868390924658, 5.026875492282555, 4.070275961427977, 3.0992401341713145, 2.060739199760714, 1.0485472406118732, 0.0, 1.0196364703937688, 2.820312626282567, 3.7653967206358265, 4.743853927429008, 5.802391788525639, 6.737545193250939, 7.7147584062017405, 8.775784294849814, 9.711010026404505, 10.697757033036966, 9.80683222660115, 8.85272696859237, 7.923093959191106, 6.953525107162403, 5.972248630797651, 4.933727194103017, 3.9273573127655057, 2.9643969416202727, 1.9194154485627677, 0.9327961315226668, 1.8797225200786867, 3.801495709466513, 4.76605254242464, 5.778685390120938, 6.77655074697883, 7.7466489545394595, 8.703096852701046, 9.752310566219062, 10.760232503977983, 11.673181343196871, 10.740007801146053, 9.827902821344686, 8.860593405120426, 7.8745420372897295, 6.925958041217022, 5.952958151350255, 4.978332937393716, 3.939286432180693, 2.8888545037058537, 1.9248396289894183, 2.817489070890377, 4.83448955608893, 5.727461617263787, 6.711678284082835, 7.661489448454907, 8.669986735282134, 9.726868278786988, 10.709747142805938, 11.708831942325713, 12.639671218907628, 11.693574152003645, 10.858762109510524, 9.805077885606027, 8.841446836942636, 7.945378433832767, 6.8972643128626405, 5.951345015960229, 4.881853547030435, 3.943723925040884, 2.9767874882148435, 3.8043431430502164, 5.733597288024722, 6.765281487318718, 7.661720990439481, 8.700362620436412, 9.66456948689969, 10.598217415608243, 11.587269060883264, 12.530004974506085, 13.512436460405363, 12.727568490308888, 11.711988108155552, 10.73516964009382, 9.817419456419477, 8.871986771591306, 7.869759607412851, 6.9129292514653145, 5.862066968201422, 4.905189145791337, 3.996772447091453, 4.795696683996534, 6.680639828625212, 7.6358458301219425, 8.627252843725195, 9.65517804522387, 10.683953256702381, 11.531809726431145, 12.572069553280103, 13.455253615291332, 14.428166475726886, 13.70512000510509, 12.770530016247296, 11.757213216146749, 10.818779090459916, 9.906086652835022, 8.839756641420406, 7.792569447473264, 6.817795504677759, 5.867896370112865, 4.931331159615462, 5.770490083497751, 7.673841916748575, 8.649427412930365, 9.659515438577284, 10.644381474212562, 11.620653726066635, 12.582608622031145, 13.578416357094888, 14.401347562007642, 15.35950362638233, 14.640900032066535, 13.638700494664622, 12.672919490877092, 11.742438952446626, 10.696601286364713, 9.688784506065062, 8.710074847561003, 7.750629534195005, 6.802516233759427, 5.895449475324625, 6.7595323714161255, 8.641048230046717, 9.631715812945474, 10.579326511850608, 11.591006028976093, 12.61176306950407, 13.568071297873152, 14.531983697919632, 15.347856344447742, 16.301319516610594, 15.63516529530767, 14.575563086070654, 13.619884616823665, 12.619370451000902, 11.553288642342988, 10.569013567950853, 9.6269200526545, 8.67959546275584, 7.747737782477317, 6.8351686403704, 7.767877676148054, 9.569648286150874, 10.565779111523181, 11.532280898967555, 12.548533469062944, 13.575274657093278, 14.550114360572794, 15.53661795311514, 16.416536575688326, 17.376292826298886, 16.51419812877695, 15.518552123634544, 14.478825931227519, 13.519162653732774, 12.455434272591095, 11.501825549601316, 10.564086144282532, 9.682211512351147, 8.749961834272646, 7.876539803599499, 8.728429888228751, 10.576140330860987, 11.11537404358879, 11.934715320941352, 12.642733301563828, 13.530390012479867, 14.526576269424886, 15.477000883194334, 16.41240709142118, 17.38220878333448, 17.295146111776447, 16.341828519508695, 15.358979449725245, 14.346586139892121, 13.41303329512256, 12.49052754476297, 11.550017522466892, 10.716178216679088, 9.701656075935887, 8.824462226964128, 9.793894052818745, 10.871054447938874, 10.046465660566053, 10.877032348692323, 11.644530537213234, 12.586429016986468, 13.621039217910322, 14.539183679480095, 15.556273304976125, 16.59319287981049, 17.570021303257132, 17.29113497747331, 16.246010398642127, 15.314862400535864, 14.36789301476048, 13.442692571357014, 12.509721113189126, 11.710752997425779, 10.772270529442945, 9.854232164308394, 10.805542268210564, 9.916481353587415, 9.07697027374956, 9.939125017067688, 10.628435140163955, 11.561707401112368, 12.549261304839572, 13.51867143074669, 14.576084322864972, 15.640091361267434, 16.694367609053764, 17.605923975558362, 17.27151098184679, 16.26926575856219, 15.349569072152724, 14.458775901969714, 13.4824949523883, 12.708998472186432, 11.773078726126, 10.879186088127994, 10.814726052635379, 8.9092805634287, 8.14114933106591, 9.0036582074173, 9.69713782596201, 10.648741602675184, 11.643477596951405, 12.617131450640418, 13.65857973414947, 14.669528067292823, 15.64088596169889, 16.59787101655713, 17.552384989687656, 16.55042130202425, 15.542954550655603, 14.549329687759448, 13.57064313031402, 12.624530153302524, 11.691810598342048, 10.726824531725823, 9.828437561222842, 7.898459451083437, 7.178126255571872, 8.064201264145682, 8.724214442743227, 9.713545919238127, 10.777955234599553, 11.814002024130245, 12.763010210427854, 13.716828604345055, 14.645605793635115, 15.555672234012128, 16.504752003109353, 15.557350578131992, 14.59452536118435, 13.610531691362251, 12.67200785104662, 11.65839096179469, 10.71886565699551, 9.7191237512722, 8.889842157229888, 6.952610183536166, 6.141450039602645, 7.136998330834576, 7.761515355926514, 8.821307758083924, 9.827233829389966, 10.857750008625727, 11.753446787686777, 12.783843000003849, 13.710503274013616, 14.583833465463437, 15.583108860056441, 14.713088883082357, 13.708661684766314, 12.658679303525238, 11.691426750130939, 10.678704714713039, 9.736215298687867, 8.749868137816613, 7.912237790119372, 5.927261696278357, 5.183283054256575, 6.128304123350645, 6.835745376961667, 7.886723045116802, 8.826068993113108, 9.808496259784555, 10.791117629206248, 11.758540309605172, 12.702997063259632, 13.628347183493348, 14.564555053633132, 13.782398277834682, 12.771856785381921, 11.826756849988461, 10.784030147894763, 9.750468555292512, 8.837806285436738, 7.797112823803953, 6.862972759557637, 4.996506888759474, 4.11783218215292, 5.084794137535975, 5.877812569562191, 6.877570979023634, 7.8765274585244605, 8.849715328516767, 9.831729275951684, 10.786150476867958, 11.824148127684794, 12.829918117631307, 13.731410832719693, 12.773882005149364, 11.740663781850827, 10.810108654892666, 9.792308270768139, 8.787444665453503, 7.819002585580668, 6.856897306771305, 5.931411529790853, 4.018042619663825, 3.071169334265689, 4.017480392898963, 4.945628471203175, 5.947509000925448, 6.902633042714193, 7.858934230583739, 8.875409477988732, 9.901067310529717, 10.889110120312864, 11.820268488114749, 12.661753321919427, 11.733184104456832, 10.79273574779964, 9.786362760633269, 8.791401962110106, 7.827251934144285, 6.927844957099533, 5.967041506156594, 4.9672011388250965, 3.053120308069568, 2.0769912153119963, 3.038167248041278, 3.9450916125215354, 5.013572735873806, 6.08634647690713, 7.010726857812695, 7.965750589523809, 8.95189497949913, 9.934922102991857, 10.872253681698199, 11.913859255389065, 10.958774761906586, 9.953833092567187, 8.893396245756204, 7.855873098358217, 6.865009980557046, 6.001040344148863, 5.024448463205884, 4.017309675958288, 2.0253673133947174, 1.0579722245364929, 2.1079451840977104, 3.012399900354338, 4.045981262471921, 5.04758018762179, 6.003100269810919, 7.034356696590857, 7.992386923297339, 9.04118593001326, 9.993449372451401, 10.950403632376254, 9.930366422633046, 8.938576295077885, 7.953554621027746, 6.891385761147509, 5.898365245599745, 4.967762489317357, 3.9552716486604282, 3.0449045470914866], [1.0398117462902543, 1.9894562594098044, 2.982798594953793, 3.9425907484953644, 4.996057452109339, 6.000755767198189, 7.015037670120027, 8.06914630908003, 9.108684112819947, 10.014488961182224, 9.026923124244973, 8.000447533958821, 7.036504861318427, 6.046511962676324, 5.089912431821746, 4.1188766045650835, 3.080375670154483, 2.0681837110056422, 1.0196364703937688, 0.0, 1.8692844099967636, 2.814368504350023, 3.7928257111432044, 4.851363572239835, 5.786516976965135, 6.763730189915937, 7.82475607856401, 8.759981810118703, 9.746728816751164, 10.767844845946714, 9.864706695362628, 8.935073685961363, 7.8963496679886385, 6.915073191623886, 5.876551754929253, 4.870181873591742, 3.907221502446509, 2.862240009389004, 1.8756206923489032, 0.9286943037928834, 2.8504674931807106, 3.815024326138836, 4.827657173835134, 5.825522530693027, 6.795620738253656, 7.752068636415242, 8.801282349933258, 9.80920428769218, 10.722153126911069, 11.674982073469137, 10.839882548114945, 9.872573131890682, 8.817366598115965, 7.868782602043257, 6.895782712176491, 5.9211574982199515, 4.882110993006929, 3.83167906453209, 2.8676641898156547, 1.8664608546045738, 3.8834613398031275, 4.776433400977983, 5.760650067797031, 6.710461232169104, 7.718958518996329, 8.775840062501183, 9.758718926520135, 10.75780372603991, 11.703482850188022, 12.628548424326729, 11.801586670336759, 10.747902446432262, 9.78427139776887, 8.888202994659004, 7.8400888736888765, 6.795980186634282, 5.7264887177044885, 4.788359095714938, 3.7908227664996055, 2.8533149267644133, 4.782569071738919, 5.814253271032915, 6.710692774153678, 7.749334404150609, 8.713541270613888, 9.64718919932244, 10.636240844597461, 11.578976758220282, 12.56140824411956, 13.592908215720627, 12.654812668981787, 11.677994200920056, 10.760244017245713, 9.77780366326219, 8.714394778086906, 7.757564422139368, 6.7067021388754755, 5.749824316465391, 4.785259620991117, 3.8446684677107306, 5.72961161233941, 6.68481761383614, 7.6762246274393915, 8.704149828938068, 9.732925040416578, 10.580781510145343, 11.6210413369943, 12.504225399005529, 13.477138259441084, 14.46279011306109, 13.713354577073531, 12.700037776972984, 11.722133024223231, 10.750721823509075, 9.68439181209446, 8.637204618147319, 7.662430675351813, 6.656383544012529, 5.719818333515127, 4.819461867211947, 6.722813700462773, 7.698399196644562, 8.70848722229148, 9.69335325792676, 10.669625509780833, 11.631580405745343, 12.627388140809085, 13.450319345721839, 14.408475410096527, 15.398570140022533, 14.483335665338677, 13.517554661551147, 12.587074123120681, 11.541236457038767, 10.533419676739117, 9.554710018235058, 8.59526470486906, 7.591003407659091, 6.6839366492242895, 5.808504155130322, 7.690020013760915, 8.680687596659672, 9.628298295564806, 10.63997781269029, 11.660734853218267, 12.617043081587349, 13.58095548163383, 14.396828128161939, 15.350291300324791, 16.317493769867333, 15.36405025997032, 14.408371790723331, 13.407857624900569, 12.341775816242654, 11.357500741850519, 10.415407226554166, 9.468082636655506, 8.536224956376982, 7.623655814270064, 6.816849459862251, 8.618620069865072, 9.614750895237378, 10.581252682681752, 11.597505252777141, 12.624246440807475, 13.599086144286991, 14.585589736829338, 15.465508359402524, 16.425264610013084, 17.280555820216687, 16.30703929753421, 15.267313105127185, 14.30764982763244, 13.243921446490761, 12.290312723500982, 11.352573318182198, 10.470698686250813, 9.53844900817231, 8.665026977499164, 7.777401671942949, 9.625112114575185, 10.568086065949071, 11.61473817330822, 12.566705260271867, 13.5500963464279, 14.54628260337292, 15.518803284748094, 16.408680725927645, 17.378482417840946, 18.083633285676115, 17.130315693408363, 16.14746662362491, 15.135073313791787, 14.201520469022226, 13.279014718662635, 12.338504696366558, 11.504665390578753, 10.490143249835551, 9.612949400863792, 8.842865836532942, 9.930098875156407, 10.787073032855762, 11.68474466735032, 12.664167007607004, 13.606065487380238, 14.640675688304093, 15.558820149873865, 16.575909775369894, 17.61282935020426, 18.589657773650902, 18.079622151372977, 17.034497572541795, 16.10334957443553, 15.156380188660146, 14.23117974525668, 13.298208287088793, 12.499240171325443, 11.56075770334261, 10.642719338208058, 9.854514051924761, 8.975525780804947, 9.817577646039268, 10.746837335725685, 11.648071610557725, 12.581343871506139, 13.568897775233342, 14.53830790114046, 15.595720793258742, 16.659727831661204, 17.714004079447527, 18.539093088447878, 17.57476648862413, 16.505713442298728, 15.494460608766516, 14.473732814580098, 13.49450519989364, 12.62704591847335, 11.642498506239535, 10.775925455688617, 9.858152570523972, 7.968324990646231, 8.881756703355618, 9.811370526075297, 10.716774296355778, 11.668378073068952, 12.663114067345173, 13.636767921034187, 14.678216204543238, 15.68916453768659, 16.660522432092655, 17.531040129446644, 16.532748519293886, 15.530784831630482, 14.523318080261832, 13.529693217365677, 12.55100665992025, 11.604893682908754, 10.672174127948278, 9.707188061332053, 8.871864079111434, 6.957503878300967, 7.918733627861581, 8.892439215836658, 9.743850913136995, 10.733182389631896, 11.79759170499332, 12.833638494524012, 13.782646680821623, 14.736465074738824, 15.665242264028883, 16.49467264148605, 15.485115532715582, 14.537714107738221, 13.57488889079058, 12.59089522096848, 11.65237138065285, 10.63875449140092, 9.69922918660174, 8.69948728087843, 7.93326867511848, 6.011654610753696, 6.969687991293622, 7.965236282525553, 8.781151826320283, 9.840944228477692, 10.846870299783735, 11.877386479019496, 12.773083258080545, 13.803479470397617, 14.730139744407385, 15.565668815204917, 14.649142895921287, 13.693452412688588, 12.689025214372544, 11.639042833131468, 10.671790279737168, 9.659068244319268, 8.716578828294097, 7.730231667422842, 6.8926013197256015, 4.986306123495887, 6.054008415184495, 7.036070985815551, 7.855381847355436, 8.906359515510571, 9.845705463506876, 10.828132730178323, 11.810754099600016, 12.77817677999894, 13.7226335336534, 14.610182533234829, 13.715561275227559, 12.762761807440913, 11.752220314988152, 10.807120379594691, 9.764393677500992, 8.730832084898744, 7.818169815042968, 6.777476353410184, 5.843336289163868, 4.055551315977004, 5.07062318016672, 6.077305850918425, 6.897449039955959, 7.897207449417403, 8.896163928918229, 9.869351798910536, 10.851365746345452, 11.805786947261726, 12.84378459807856, 13.672530294223067, 12.711774362325924, 11.754245534755595, 10.721027311457059, 9.790472184498899, 8.772671800374368, 7.767808195059734, 6.799366115186898, 5.837260836377536, 4.911775059397083, 3.077087046881354, 4.023960332279489, 5.009992106281413, 5.965264941596944, 6.967145471319217, 7.9222695131079615, 8.878570700977507, 9.895045948382501, 10.920703780923485, 11.908746590706633, 12.66288066470651, 11.642116851525659, 10.713547634063064, 9.773099277405871, 8.7667262902395, 7.771765491716337, 6.807615463750516, 5.908208486705763, 4.947405035762824, 3.947564668431327, 2.033483837675799, 3.0706913546518724, 4.031867387381154, 4.964728082915304, 6.033209206267575, 7.105982947300898, 8.030363328206464, 8.985387059917578, 9.971531449892899, 10.954558573385626, 11.859691940696626, 10.921610154907578, 9.939138291512817, 8.934196622173419, 7.873759775362434, 6.836236627964448, 5.845373510163277, 4.981403873755094, 4.004811992812115, 2.9976732055645186, 1.0057308430009486, 2.051672363876369, 3.1016453234375865, 4.032036370748107, 5.0656177328656895, 6.0672166580155595, 7.022736740204689, 8.053993166984625, 9.01202339369111, 10.06082240040703, 10.91510879181962, 9.958154531894767, 8.910729952239278, 7.9189398246841165, 6.9339181506339775, 5.8717492907537405, 4.8787287752059765, 3.9481260189235883, 2.9356351782666597, 2.025268076697718], [0.9723996479974382, 1.9211199790334157, 2.9144623145774045, 3.8742544681189757, 4.904811302950528, 5.909509618039379, 6.895364872645184, 7.891065667465078, 8.854363647182684, 9.8907141388652, 10.752423642576213, 9.725948052290061, 8.762005379649667, 7.772012481007565, 6.815412950152987, 5.868575496184756, 4.830074561774156, 3.8178826026253154, 2.820312626282567, 1.8692844099967636, 0.0, 0.9450840943532595, 1.9235413011464408, 2.982079162243072, 3.917232566968372, 4.894445779919174, 5.955471668567247, 6.8906974001219385, 7.8774444067544, 8.89856043594995, 9.85266569395873, 8.94696948837236, 7.908245470399636, 6.926968994034883, 5.888447557340251, 4.882077676002739, 3.9191173048575063, 2.8741358118000013, 1.8875164947599001, 0.9405901062038803, 1.0177212632626946, 1.9457399161420723, 2.9583727638383706, 3.9562381206962636, 4.926336328256893, 5.882784226418479, 6.931997939936495, 7.939919877695417, 8.852868716914305, 9.805697663472372, 10.827841546711047, 9.88446893430168, 8.829262400526963, 7.880678404454255, 6.907678514587488, 5.933053300630949, 4.894006795417926, 3.843574866943087, 2.8795599922266515, 1.8783566570155705, 2.0507151098851115, 2.907148990981219, 3.891365657800267, 4.84117682217234, 5.849674108999565, 6.906555652504419, 7.889434516523371, 8.888519316043146, 9.834198440191258, 10.759264014329965, 11.80513802521186, 10.759798248843259, 9.796167200179868, 8.900098797070001, 7.851984676099874, 6.80787598904528, 5.738384520115486, 4.800254898125935, 3.8027185689106022, 2.86521072917541, 2.995738410150616, 3.945323923240307, 4.841408364156914, 5.880049994153845, 6.844256860617123, 7.777904789325676, 8.766956434600697, 9.709692348223518, 10.692123834122796, 11.723623805723864, 12.666708471392784, 11.689890003331053, 10.77213981965671, 9.789699465673188, 8.726290580497903, 7.7694602245503654, 6.718597941286473, 5.761720118876388, 4.797155423402113, 3.8565642701217273, 3.9427809507511062, 4.8979869522478365, 5.88810669309929, 6.879063364497531, 7.907838575976041, 8.711497100148579, 9.751756926997537, 10.634940989008765, 11.60785384944432, 12.593505703064325, 13.52809569192212, 12.711933579383981, 11.734028826634228, 10.762617625920072, 9.696287614505458, 8.649100420558316, 7.67432647776281, 6.6682793464235255, 5.731714135926123, 4.831357669622944, 4.935983038874469, 5.911568535056258, 6.920369287951377, 7.868266793486222, 8.844539045340294, 9.762295995748579, 10.758103730812321, 11.581034935725075, 12.539191000099763, 13.52928573002577, 14.47676304914382, 13.529450463962144, 12.598969925531678, 11.553132259449765, 10.545315479150114, 9.566605820646055, 8.607160507280057, 7.602899210070087, 6.695832451635286, 5.820399957541319, 5.903189352172611, 6.893856935071367, 7.8414676339765, 8.853147151101984, 9.873904191629961, 10.747758671590585, 11.711671071637065, 12.527543718165175, 13.481006890328027, 14.448209359870567, 15.375946062381315, 14.420267593134326, 13.419753427311564, 12.35367161865365, 11.369396544261514, 10.427303028965161, 9.479978439066501, 8.548120758787977, 7.63555161668106, 6.828745262273248, 6.8317894082767685, 7.827920233649075, 8.794422021093446, 9.810674591188835, 10.83741577921917, 11.729801734290227, 12.716305326832574, 13.59622394940576, 14.555980200016322, 15.411271410219921, 16.318935099945207, 15.27920890753818, 14.319545630043436, 13.255817248901756, 12.302208525911977, 11.364469120593194, 10.482594488661809, 9.550344810583308, 8.67692277991016, 7.789297474353946, 7.83828145298688, 8.781255404360767, 9.827907511719916, 10.779874598683563, 11.763265684839595, 12.741597834636483, 13.64951887475133, 14.53939631593088, 15.509198007844178, 16.381373842244052, 17.14221149581936, 16.15936242603591, 15.146969116202783, 14.213416271433221, 13.29091052107363, 12.350400498777553, 11.51656119298975, 10.502039052246548, 9.62484520327479, 8.85476163894394, 8.804912878183316, 9.755074627566321, 10.736047489629094, 11.743833936101137, 12.685732415874371, 13.69753646298123, 14.587336078465569, 15.4656655970296, 16.488357757138893, 17.404207516902936, 18.091517953783974, 17.046393374952792, 16.115245376846527, 15.168275991071141, 14.243075547667676, 13.310104089499788, 12.51113597373644, 11.572653505753607, 10.654615140619056, 9.829801084751264, 9.759485972534776, 10.724570014382815, 11.673954821253728, 12.633637594548883, 13.566909855497297, 14.5544637592245, 15.523873885131618, 16.445854579140754, 17.509861617543216, 18.395128017618507, 18.500955620724348, 17.5366290209006, 16.467575974575198, 15.48430721226818, 14.474486856949028, 13.49525924226257, 12.68339885741015, 11.715333620982731, 10.848760570431812, 9.93098768526717, 9.837609400642995, 10.751041113352382, 11.680654936072061, 12.466473187975453, 13.418076964688627, 14.412812958964848, 15.386466812653861, 16.427915096162913, 17.438863429306263, 18.410221323712328, 17.492902661723114, 16.494611051570356, 15.492647363906952, 14.485180612538302, 13.491555749642147, 12.55176070228918, 11.631678131883577, 10.745009242691474, 9.780023176075249, 8.944699193854632, 8.826788288297731, 9.788018037858345, 10.761723625833424, 11.49354980475667, 12.48288128125157, 13.547290596612996, 14.583337386143688, 15.532345572441296, 16.486163966358497, 17.40980510346764, 16.45653517376252, 15.446978064992052, 14.499576640014691, 13.53675142306705, 12.55275775324495, 11.61423391292932, 10.665538940375743, 9.772064301344935, 8.772322395621625, 8.006103789861678, 7.880939020750459, 8.838972401290386, 9.834520692522318, 10.530850717939957, 11.590643120097367, 12.59656919140341, 13.627085370639168, 14.522782149700218, 15.55317836201729, 16.474702583846142, 15.497332534828528, 14.580806615544898, 13.625116132312199, 12.650887746649014, 11.600905365407938, 10.633652812013638, 9.685852693294093, 8.789413943037292, 7.803066782166039, 6.965436434468799, 6.85559053349265, 7.923292825181258, 8.905355395812313, 9.60508073897511, 10.656058407130244, 11.59540435512655, 12.577831621797996, 13.56045299121969, 14.527875671618613, 15.467196373092156, 14.54184625285844, 13.64722499485117, 12.694425527064524, 11.683884034611763, 10.738784099218302, 9.696057397124603, 8.662495804522354, 7.89006052054362, 6.8503114681533805, 5.9161714039070645, 5.924835725973767, 6.938144808435487, 7.905106763818542, 8.647147931575633, 9.646906341037077, 10.645862820537904, 11.619050690530209, 12.601064637965125, 13.555485838881399, 14.557168312818758, 13.604194013846678, 12.643438081949535, 11.685909254379206, 10.65269103108067, 9.72213590412251, 8.70433551999798, 7.699471914683345, 6.87125682068755, 5.9100959511207325, 4.98461017414028, 4.946371456878118, 5.891481960548256, 6.83779301918153, 7.714963833216617, 8.71684436293889, 9.671968404727634, 10.62826959259718, 11.644744840002174, 12.670402672543158, 13.525702752132005, 12.59454438433012, 11.57378057114927, 10.645211353686674, 9.704762997029482, 8.698390009863111, 7.703429211339948, 6.739279183374127, 5.891240419263312, 5.003359269883518, 4.020399783174524, 3.9027682476725625, 4.897303841594563, 5.858479874323844, 6.714426974534977, 7.782908097887248, 8.855681838920571, 9.755863846537704, 10.710887578248817, 11.697031968224138, 12.679638712062756, 11.742307133356414, 10.804225347567368, 9.870802011136428, 8.86586034179703, 7.805423494986045, 6.767900347588059, 5.777037229786888, 4.913067593378705, 3.936475712435726, 3.070508320307715, 2.875015252997712, 3.87828485081906, 4.883010061393688, 5.781735262367779, 6.815316624485362, 7.7927171763468, 8.748237258535928, 9.779493685315867, 10.737523912022349, 11.78632291873827, 10.797723984479408, 9.840769724554557, 8.842393671862888, 7.850603544307727, 6.865581870257588, 5.803413010377351, 4.810392494829587, 3.879789738547199, 2.8672988978902705, 2.047151572457924], [1.9174837423506976, 0.9760358846801561, 1.969378220224145, 2.929170373765716, 3.959727208597269, 4.96442552368612, 5.950280778291925, 6.945981573111819, 7.909279552829425, 8.94563004451194, 9.93319588144919, 10.67103214664332, 9.707089474002926, 8.717096575360824, 7.760497044506246, 6.813659590538015, 5.775158656127415, 4.762966696978574, 3.765396720635826, 2.814368504350023, 0.9450840943532595, 0.0, 0.9784572067931815, 2.0369950678898125, 2.9721484726151126, 3.9493616855659144, 5.010387574213988, 5.9456133057686795, 6.932360312401141, 7.953476341596691, 8.907581599605471, 9.837214609006736, 8.853329564752894, 7.872053088388142, 6.83353165169351, 5.827161770355998, 4.864201399210765, 3.8192199061532603, 2.8326005891131594, 1.8856742005571396, 1.962805357615954, 1.0006558217888128, 2.013288669485111, 3.0111540263430037, 3.981252233903634, 4.93770013206522, 5.986913845583236, 6.994835783342158, 7.907784622561046, 8.860613569119113, 9.882757452357788, 10.774714054936055, 9.774346494880222, 8.825762498807514, 7.852762608940747, 6.878137394984208, 5.839090889771185, 4.788658961296346, 3.824644086579911, 2.82344075136883, 2.995799204238371, 1.96206489662796, 2.946281563447008, 3.896092727819081, 4.904590014646306, 5.96147155815116, 6.944350422170112, 7.943435221689887, 8.889114345838, 9.814179919976706, 10.860053930858601, 11.704882343196518, 10.741251294533127, 9.84518289142326, 8.797068770453134, 7.752960083398539, 6.683468614468745, 5.745338992479194, 4.747802663263862, 3.8102948235286695, 3.9408225045038754, 3.0002398288870475, 3.896324269803655, 4.934965899800586, 5.899172766263864, 6.832820694972417, 7.821872340247438, 8.764608253870259, 9.747039739769537, 10.778539711370605, 11.801281409059689, 12.634974097684312, 11.717223914009969, 10.734783560026447, 9.67137467485116, 8.714544318903624, 7.663682035639732, 6.706804213229647, 5.742239517755373, 4.801648364474987, 4.887865045104366, 3.999749328939221, 4.943022598746031, 5.933979270144272, 6.962754481622782, 7.76641300579532, 8.806672832644278, 9.689856894655506, 10.66276975509106, 11.648421608711066, 12.583011597568861, 13.60945767539079, 12.679112920987487, 11.707701720273331, 10.641371708858715, 9.594184514911573, 8.619410572116069, 7.613363440776785, 6.676798230279383, 5.776441763976204, 5.881067133227729, 5.013489867811392, 5.975285193598118, 6.923182699132963, 7.899454950987035, 8.81721190139532, 9.813019636459062, 10.635950841371816, 11.594106905746504, 12.58420163567251, 13.53167895479056, 14.474534558315401, 13.544054019884936, 12.498216353803022, 11.490399573503371, 10.511689914999312, 9.552244601633314, 8.547983304423347, 7.640916545988546, 6.765484051894579, 6.848273446525871, 6.024551788449709, 6.9664361939174455, 7.947275796685482, 8.95512157996989, 9.802674577237326, 10.766586977283806, 11.582459623811916, 12.535922795974768, 13.503125265517308, 14.562727474754325, 15.365351687487587, 14.364837521664825, 13.29875571300691, 12.314480638614775, 11.372387123318422, 10.425062533419762, 9.493204853141238, 8.58063571103432, 7.773829356626508, 7.776873502630028, 7.097485757371294, 7.919390581034392, 8.935643151129781, 9.962384339160115, 10.784717639936968, 11.771221232479315, 12.6511398550525, 13.610896105663063, 14.466187315866662, 15.461833321009069, 16.224293001891443, 15.264629724396697, 14.200901343255017, 13.247292620265238, 12.309553214946455, 11.42767858301507, 10.495428904936567, 9.62200687426342, 8.734381568707205, 8.78336554734014, 8.071675997877307, 8.954509816212735, 9.904843158624509, 10.888234244780541, 11.796513740283224, 12.70443478039807, 13.59431222157762, 14.56411391349092, 15.436289747890795, 16.38960734015855, 17.10444652038917, 16.092053210556045, 15.158500365786482, 14.235994615426891, 13.295484593130814, 12.461645287343009, 11.447123146599807, 10.569929297628049, 9.799845733297198, 9.749996972536575, 9.140584380900044, 10.012192788461764, 10.903045922975103, 11.83219524027394, 12.75245236862797, 13.64225198411231, 14.520581502676341, 15.543273662785635, 16.45912342254968, 17.338913798123162, 17.30710475910221, 16.375956760995944, 15.428987375220558, 14.503786931817093, 13.522948987108487, 12.736560237817548, 11.904100207954183, 11.06167288453981, 10.774885179104523, 10.704570066888035, 10.110079767716538, 10.950100120086399, 11.909782893381553, 12.843055154329967, 13.824230281698721, 14.662764232845715, 15.500770484787495, 16.564777523189957, 17.450043923265252, 17.55587152637109, 16.591544926547343, 15.52249188022194, 14.539223117914922, 13.52940276259577, 12.550175147909313, 11.738314763056895, 10.903292011271128, 10.03671896072021, 10.784150869315338, 10.71705126014936, 11.045900710400188, 11.885566929736786, 12.841080207583499, 13.818774260394534, 14.813510254670755, 15.67112052221635, 16.570474925912784, 17.57259145803287, 17.535530641049657, 16.547818567369855, 15.549526957217099, 14.547563269553695, 13.540096518185045, 12.54647165528889, 11.606676607935922, 10.686594037530321, 9.93296763297987, 8.967981566363646, 9.797862377902801, 9.706230147804096, 10.66745989736471, 11.64116548533979, 12.438633899109929, 13.42796537560483, 14.492374690966255, 15.528421480496947, 16.477429666794553, 17.42485732713324, 16.464721009114378, 15.511451079409262, 14.501893970638795, 13.554492545661434, 12.591667328713793, 11.607673658891693, 10.669149818576063, 9.720454846022488, 8.960022691633334, 7.960280785910022, 8.859266973909847, 8.760380880256825, 9.718414260796752, 10.713962552028685, 11.475934812293216, 12.535727214450626, 13.541653285756668, 14.572169464992427, 15.467866244053477, 16.491871722792034, 15.529618489492881, 14.55224844047527, 13.635722521191637, 12.680032037958938, 11.705803652295756, 10.65582127105468, 9.688568717660381, 8.740768598940836, 7.9773723333256905, 6.991025172454436, 7.818599618516968, 7.735032392999017, 8.802734684687625, 9.78479725531868, 10.550164833328369, 11.601142501483503, 12.54048844947981, 13.522915716151255, 14.505537085572948, 15.466569032393357, 14.522112278738897, 13.59676215850518, 12.70214090049791, 11.749341432711264, 10.738799940258502, 9.793700004865045, 8.750973302771346, 7.717411710169096, 6.944976426190361, 6.038269858441778, 6.769334587955234, 6.805769653821753, 7.82084151801147, 8.827524188763174, 9.592232025928892, 10.591990435390336, 11.590946914891163, 12.564134784883468, 13.546148732318384, 14.500569933234658, 13.6120842184655, 12.65910991949342, 11.698353987596274, 10.740825160025945, 9.707606936727409, 8.777051809769247, 7.759251425644721, 6.754387820330086, 5.926172726334291, 5.02396038826644, 5.837773358188449, 5.827305384726103, 6.774178670124239, 7.760210444126162, 8.660047927569876, 9.661928457292149, 10.617052499080893, 11.573353686950439, 12.589828934355433, 13.568661467561894, 12.580618657778746, 11.649460289976862, 10.628696476796009, 9.700127259333414, 8.759678902676221, 7.753305915509849, 6.758345116986687, 5.794195089020867, 4.946156324910053, 4.058275175530259, 4.873562967222693, 4.847852342025822, 5.842387935947823, 6.803563968677104, 7.659511068888236, 8.727992192240507, 9.80076593327383, 10.700947940890963, 11.655971672602076, 12.642116062577397, 11.734554617709497, 10.797223039003155, 9.859141253214109, 8.925717916783167, 7.92077624744377, 6.860339400632785, 5.822816253234799, 4.831953135433628, 3.967983499025446, 2.991391618082467, 3.923671504355884, 3.820099347350972, 4.823368945172319, 5.828094155746946, 6.726819356721038, 7.760400718838621, 8.737801270700059, 9.693321352889187, 10.724577779669126, 11.682608006375608, 10.892187393334297, 9.852639890126149, 8.895685630201298, 7.8973095775096285, 6.905519449954468, 5.920497775904329, 4.858328916024092, 3.865308400476328, 2.93470564419394, 1.922214803537011, 2.9003147565060927], [2.895940949143879, 1.9544930914733376, 1.0308063110088417, 1.9905984645504131, 2.981270001804087, 3.9859683168929374, 4.971823571498744, 5.967524366318639, 6.930822346036242, 7.967172837718757, 8.954738674656006, 9.801040297839606, 10.685546680796106, 9.695553782154004, 8.738954251299427, 7.792116797331197, 6.753615862920596, 5.741423903771755, 4.743853927429008, 3.7928257111432044, 1.9235413011464408, 0.9784572067931815, 0.0, 1.058537861096631, 1.993691265821931, 2.970904478772733, 4.031930367420807, 4.967156098975498, 5.953903105607958, 6.975019134803508, 7.929124392812288, 8.858757402213552, 9.831786771546076, 8.850510295181325, 7.811988858486691, 6.805618977149179, 5.842658606003947, 4.797677112946442, 3.8110577959063408, 2.864131407350321, 2.9412625644091355, 1.9791130285819944, 1.0348314626919297, 2.0326968195498223, 3.002795027110452, 3.9592429252720382, 5.008456638790054, 6.016378576548977, 6.9293274157678635, 7.882156362325931, 8.904300245564604, 9.796256848142871, 10.752803701673404, 9.804219705600696, 8.83121981573393, 7.85659460177739, 6.8175480965643676, 5.767116168089528, 4.803101293373093, 3.8018979581620114, 3.9742564110315524, 2.9405221034211415, 2.083956625156249, 2.9952074435421094, 3.9557449231751205, 4.983014351357979, 5.965893215376931, 6.9649780148967055, 7.910657139044817, 8.835722713183523, 9.88159672406542, 10.808620552621312, 11.71970850132631, 10.823640098216442, 9.775525977246316, 8.73141729019172, 7.661925821261926, 6.723796199272376, 5.726259870057043, 4.7887520303218505, 4.919279711297056, 3.9786970356802294, 3.033999331512896, 4.034080615523615, 4.9982874819868925, 5.931935410695446, 6.920987055970467, 7.863722969593287, 8.846154455492565, 9.869717051488767, 10.822824202266506, 11.738712307109106, 12.695681120803151, 11.713240766819627, 10.649831881644342, 9.693001525696806, 8.642139242432913, 7.685261420022829, 6.720696724548554, 5.780105571268168, 5.866322251897547, 4.978206535732403, 4.080697660455272, 5.033093985867301, 6.0618691973458105, 6.8655277215183474, 7.9057875483673055, 8.788971610378534, 9.761884470814088, 10.747536324434094, 11.682126313291889, 12.708572391113819, 13.657570127780668, 12.686158927066511, 11.619828915651897, 10.572641721704755, 9.59786777890925, 8.591820647569966, 7.655255437072563, 6.754898970769385, 6.85952434002091, 5.991947074604573, 5.112960255307359, 6.022297414855991, 6.998569666710064, 7.916326617118347, 8.91213435218209, 9.735065557094844, 10.693221621469531, 11.683316351395538, 12.630793670513588, 13.596574674301118, 14.522511226678118, 13.476673560596204, 12.468856780296553, 11.490147121792495, 10.530701808426496, 9.526440511216528, 8.619373752781726, 7.74394125868776, 7.826730653319052, 7.003008995242889, 6.1041112556266865, 7.046390512408511, 8.05423629569292, 8.901789292960354, 9.865701693006834, 10.681574339534944, 11.635037511697796, 12.602239981240336, 13.661842190477353, 14.617520659724342, 15.343294728458005, 14.27721291980009, 13.292937845407955, 12.350844330111602, 11.403519740212943, 10.471662059934419, 9.5590929178275, 8.75228656341969, 8.755330709423209, 8.035850656840385, 7.057065642743633, 8.073318212839022, 9.085624129059818, 9.883832355659996, 10.870335948202342, 11.750254570775528, 12.71001082138609, 13.56530203158969, 14.560948036732096, 15.568688148601243, 16.24308693118988, 15.179358550048198, 14.225749827058419, 13.288010421739635, 12.40613578980825, 11.473886111729747, 10.6004640810566, 9.712838775500387, 9.76182275413332, 9.010040897346396, 8.092184877921976, 9.042518220333747, 10.02590930648978, 10.895628456006252, 11.803549496121098, 12.69342693730065, 13.663228629213949, 14.535404463613823, 15.488722055881576, 16.471571125665026, 16.465341467481306, 15.536814342977499, 14.517380049195834, 13.544080668615418, 12.817133279309406, 12.11087992576874, 11.548386504421229, 10.77830294009038, 10.728454179329756, 10.078949280369134, 9.149867850171006, 10.040720984684341, 10.969870301983178, 11.851567084350998, 12.741366699835337, 13.61969621839937, 14.642388378508665, 15.558238138272708, 16.43802851384619, 16.368532849886904, 15.437384851780639, 14.490415466005254, 13.56521502260179, 12.584377077893183, 11.797988328602242, 11.040265472261682, 11.992018275503494, 11.753342385897703, 11.683027273681216, 11.048444667185628, 10.08777518179564, 11.047457955090795, 11.980730216039209, 12.923344997421747, 13.761878948568743, 14.599885200510524, 15.663892238912986, 16.54915863898828, 16.617299617155783, 15.652973017332041, 14.583919971006637, 13.600651208699619, 12.590830853380467, 11.61160323869401, 10.79974285384159, 10.039457275578627, 10.967064351683893, 11.758203663209043, 11.69550846694254, 11.952855814165707, 11.023241991446028, 11.97875526929274, 12.956449322103776, 13.951185316379997, 14.770235237939378, 15.669589641635815, 16.6717061737559, 16.59695873183436, 15.609246658154552, 14.610955048001795, 13.608991360338392, 12.601524608969742, 11.607899746073587, 10.668104698720619, 9.748022128315016, 9.06913289728737, 9.89832695732733, 10.771915171796506, 10.684687354597276, 11.64591710415789, 11.962698934717647, 12.904438396157284, 13.891645005540832, 14.912347957919206, 15.81980887471476, 16.681563641815085, 16.48628541791794, 15.526149099899078, 14.57287917019396, 13.563322061423492, 12.61592063644613, 11.65309541949849, 10.66910174967639, 9.73057790936076, 8.781882936807182, 8.080682784419498, 8.890626176873706, 9.833319767803552, 9.738838087050006, 10.696871467589933, 11.692419758821865, 12.454392019086399, 13.514184421243808, 14.52011049254985, 15.55062667178561, 16.44632345084666, 15.553299813576732, 14.59104658027758, 13.613676531259967, 12.697150611976335, 11.741460128743636, 10.767231743080453, 9.717249361839377, 8.749996808445077, 7.802196689725532, 7.098032426111854, 7.921370563418119, 8.797056825310149, 8.713489599792197, 9.781191891480805, 10.76325446211186, 11.528622040121551, 12.579599708276685, 13.518945656272992, 14.501372922944437, 15.48399429236613, 14.527997123178055, 13.583540369523595, 12.658190249289879, 11.763568991282607, 10.810769523495962, 9.8002280310432, 8.855128095649741, 7.812401393556042, 6.778839800953793, 6.02663721683131, 6.9686152494054605, 7.747791794748414, 7.784226860614933, 8.79929872480465, 9.805981395556355, 10.570689232722074, 11.570447642183519, 12.569404121684345, 13.54259199167665, 14.524605939111566, 13.573900221557373, 12.673512309250198, 11.720538010278117, 10.759782078380972, 9.802253250810644, 8.769035027512107, 7.838479900553946, 6.820679516429418, 5.8158159111147825, 5.00783351697524, 5.954305779230123, 6.8162305649816295, 6.805762591519284, 7.752635876917419, 8.738667650919343, 9.638505134363058, 10.640385664085331, 11.595509705874075, 12.551810893743621, 13.568286141148615, 12.630089558346592, 11.642046748563445, 10.71088838076156, 9.690124567580707, 8.761555350118112, 7.821106993460918, 6.814734006294548, 5.8197732077713855, 4.855623179805565, 4.027817115551002, 4.988620566493942, 5.852020174015873, 5.826309548819004, 6.820845142741004, 7.782021175470286, 8.637968275681418, 9.706449399033689, 10.779223140067012, 11.679405147684145, 12.634428879395259, 11.739124534409044, 10.756097410916317, 9.818765832209975, 8.880684046420928, 7.950230473660529, 6.945288804321132, 5.921767491417483, 4.884244344019496, 3.8933812262183256, 3.0496442896663956, 3.9698488248756485, 4.902128711149065, 4.798556554144153, 5.801826151965501, 6.806551362540128, 7.70527656351422, 8.738857925631804, 9.716258477493241, 10.67177855968237, 11.703034986462306, 10.812616157571894, 9.913730186541116, 8.874182683332968, 7.917228423408116, 6.921822134386989, 5.930032006831829, 4.94501033278169, 3.919757006808789, 2.9267364912610248, 2.0163664348348895, 2.900672010330193, 3.8787719632992745], [3.843177081193054, 2.893532568073504, 1.900190232529515, 0.9403980789879436, 1.9227321407074562, 2.9274304557963067, 3.9132857104021124, 4.908986505222007, 5.872284484939611, 6.908634976622126, 7.896200813559375, 8.742502436742974, 9.706445109383369, 10.69643800802547, 9.797492112396059, 8.850654658427828, 7.812153724017228, 6.799961764868387, 5.8023917885256395, 4.851363572239835, 2.982079162243072, 2.0369950678898125, 1.058537861096631, 0.0, 0.9351534047253001, 1.9123666176761018, 2.973392506324175, 3.9086182378788665, 4.895365244511327, 5.916481273706877, 6.870586531715657, 7.80021954111692, 8.838943559089646, 9.820220035454398, 8.870526719583323, 7.864156838245811, 6.901196467100578, 5.856214974043073, 4.869595657002972, 3.922669268446952, 3.9998004255057666, 3.037650889678625, 2.0267592300108577, 1.028893873152965, 1.944257166013821, 2.9007050641754066, 3.949918777693423, 4.957840715452345, 5.870789554671232, 6.8236185012293, 7.845762384467973, 8.73771898704624, 9.795154965274365, 10.743738961347074, 9.88975767683056, 8.915132462874022, 7.876085957660999, 6.825654029186159, 5.861639154469724, 4.860435819258642, 4.9638404810343495, 3.925432328336373, 2.941215661517325, 1.9914044971452523, 2.8972070620784898, 3.9244764902613474, 4.907355354280299, 5.906440153800074, 6.852119277948185, 7.777184852086892, 8.823058862968788, 9.75008269152468, 10.713713740188071, 11.758822308973585, 10.834063838342948, 9.78995515128835, 8.720463682358556, 7.782334060369006, 6.784797731153674, 5.847289891418481, 5.8907851412222945, 4.859100941928299, 3.891258367873972, 3.0302776691267574, 3.956839764692954, 4.890487693401507, 5.879539338676528, 6.822275252299348, 7.804706738198627, 8.811179190392135, 9.764286341169875, 10.680174446012474, 11.673142500390139, 12.685430646732124, 11.708369742740972, 10.751539386793436, 9.700677103529543, 8.74379928111946, 7.769276898530869, 6.828685745250483, 6.813816443477203, 5.858610441980472, 4.9379566968163475, 4.0292910394704435, 5.027941648479808, 5.82408000422441, 6.864339831073368, 7.747523893084596, 8.72043675352015, 9.706088607140156, 10.64067859599795, 11.667124673819881, 12.674502134430577, 13.645913335144733, 12.678366776748527, 11.631179582801385, 10.65640564000588, 9.64040082155228, 8.703835611054878, 7.744444554188121, 7.807018531600566, 6.872350980852643, 5.970219291668435, 5.018494468459134, 5.994766720313207, 6.8748788998244095, 7.870686634888152, 8.693617839800906, 9.651773904175593, 10.6418686341016, 11.58934595321965, 12.55512695700718, 13.485607495437646, 14.53144516151956, 13.527394641393183, 12.548684982889124, 11.589239669523126, 10.575020685198842, 9.66795392676404, 8.733486842106496, 8.774224844898708, 7.883412901490959, 6.9613702919877625, 6.042587566011654, 7.050433349296063, 7.860341575666415, 8.824253975712896, 9.640126622241006, 10.593589794403858, 11.560792263946398, 12.620394473183415, 13.576072942430404, 14.417701831299633, 15.325793093782405, 14.34151801939027, 13.399424504093917, 12.452099914195257, 11.520242233916733, 10.607673091809815, 9.741832146838425, 9.702824901002865, 8.893109693201461, 7.914324679104709, 7.109742563391998, 8.08182118266296, 8.842384638366058, 9.828888230908404, 10.70880685348159, 11.668563104092152, 12.523854314295752, 13.519500319438158, 14.527240431307305, 15.360366470287026, 15.371159789545871, 14.417551066556092, 13.479811661237308, 12.823135598627562, 12.522466285712063, 11.649044255038914, 10.702384358919122, 10.709316945712978, 9.867299933707473, 8.949443914283052, 8.078942570886724, 9.062333657042757, 9.854180738712314, 10.76210177882716, 11.651979220006712, 12.62178091192001, 13.493956746319885, 14.447274338587638, 15.430123408371088, 15.415141081918836, 14.48661395741503, 13.467179663633365, 12.493880283052949, 11.76693289374694, 12.70733321984512, 12.596966678403543, 11.767848523509116, 11.675948370909413, 10.93620831673021, 10.007126886532081, 9.077145335237319, 10.006294652536155, 10.81011936705706, 11.6999189825414, 12.578248501105433, 13.600940661214727, 14.51679042097877, 15.396580796552252, 15.318332464324433, 14.38718446621817, 13.440215080442785, 12.51501463703932, 11.534176692330714, 10.747787943039775, 11.636718766338062, 12.634385879712314, 12.70083657747736, 12.630521465260873, 11.905703703546704, 10.945034218156716, 10.093240732286597, 11.026512993235013, 11.88189728012781, 12.720431231274805, 13.558437483216586, 14.622444521619048, 15.507710921694342, 15.567099231593314, 14.602772631769572, 13.533719585444167, 12.55045082313715, 11.540630467817998, 10.56140285313154, 9.749542468279122, 10.635910569655007, 11.659491341059018, 12.500481979657122, 12.488365961038731, 12.810114850526782, 11.880501027807103, 11.024538046488544, 12.00223209929958, 12.942689671648248, 13.72878752064544, 14.628141924341877, 15.630258456461961, 15.54675834627189, 14.559046272592083, 13.560754662439326, 12.558790974775922, 11.551324223407272, 10.557699360511117, 9.61790431315815, 8.697821742752549, 9.665586191363749, 10.630572257979974, 11.514193488244585, 11.490526662274302, 12.451756411834916, 12.819957971078722, 11.997461429707327, 12.937427782736636, 13.903852313187457, 14.778361157420822, 15.640115924521147, 15.43608503235547, 14.475948714336608, 13.522678784631491, 12.513121675861022, 11.565720250883661, 10.60289503393602, 9.61890136411392, 8.68037752379829, 7.731682551244714, 8.677136078495877, 9.632904493321785, 10.57559808425163, 10.544677394727032, 11.502710775266959, 12.49825906649889, 12.96016051652404, 13.874867806744575, 14.880793878050618, 15.851737636215168, 15.407548576495039, 14.503099428014263, 13.54084619471511, 12.563476145697498, 11.646950226413866, 10.691259743181167, 9.717031357517984, 8.667048976276908, 7.699796422882608, 6.751996304163063, 7.694485720188234, 8.663648879866198, 9.602896132987174, 9.519328907469223, 10.587031199157831, 11.569093769788886, 12.527594024253576, 13.57857169240871, 14.517917640405017, 15.418915915613882, 14.44521941801451, 13.477796737615586, 12.533339983961126, 11.60798986372741, 10.713368605720138, 9.760569137933492, 8.750027645480731, 7.804927710087272, 6.762201007993573, 5.728639415391323, 6.76891553327939, 7.7108935658535405, 8.55363110242544, 8.591127740949851, 9.620630275392065, 10.658952210964554, 11.569661216854099, 12.569419626315543, 13.56837610581637, 14.460134984346094, 13.478121036911178, 12.523699835994904, 11.623311923687728, 10.670337624715648, 9.709581692818503, 8.752052865248174, 7.718834641949638, 6.788279514991476, 5.770479130866948, 4.765615525552313, 5.75011183342332, 6.696584095678203, 7.622069872658655, 7.68448166777693, 8.631354953175064, 9.617386727176987, 10.637477118495083, 11.698923525181963, 12.654047566970707, 13.574297778918275, 12.605547005325107, 11.579889172784123, 10.591846363000975, 9.66068799519909, 8.639924182018238, 7.7113549645556425, 6.770906607898449, 5.764533620732078, 4.769572822208916, 3.8054227942430954, 4.770095431999082, 5.7308988829420215, 6.730739250273519, 6.805357555637951, 7.878767962778509, 8.83994399550779, 9.69650613677805, 10.76498726013032, 11.837761001163644, 12.621754794998846, 11.666731063287733, 10.680586673312412, 9.697559549819685, 8.760227971113343, 7.822146185324296, 6.891692612563898, 5.8867509432245, 4.871567105855013, 3.834043958457027, 2.843180840655856, 3.8753933110333127, 4.908888301475814, 5.841168187749231, 5.8373486735962095, 6.860364013062132, 7.86508922363676, 8.763814424610851, 9.797395786728435, 10.774796338589873, 11.682087865238522, 10.71298984563413, 9.754078296475262, 8.855192325444484, 7.815644822236337, 6.858690562311485, 5.8632842732903585, 4.871494145735198, 3.8864724716850594, 2.8695566212463195, 1.8765361056985552, 2.878949714065202, 3.8397114869303586, 4.81781143989944], [4.778330485918354, 3.828685972798804, 2.835343637254815, 1.8755514837132437, 0.9875787359821562, 1.9922770510710068, 2.9781323056768128, 3.973833100496707, 4.937131080214312, 5.973481571896826, 6.961047408834076, 7.807349032017675, 8.771291704658069, 9.76128460330017, 10.717884134154747, 9.785808063153127, 8.747307128742527, 7.735115169593687, 6.73754519325094, 5.786516976965136, 3.917232566968372, 2.9721484726151126, 1.993691265821931, 0.9351534047253001, 0.0, 0.9772132129508019, 2.0382391015988754, 2.973464833153567, 3.9602118397860275, 4.981327868981578, 5.9354331269903575, 6.865066136391621, 7.903790154364347, 8.8850666307291, 9.805680124308623, 8.799310242971112, 7.836349871825878, 6.791368378768373, 5.804749061728272, 4.857822673172253, 4.934953830231066, 3.9728042944039252, 2.9619126347361577, 1.9640472778782652, 1.009103761288521, 1.965551659450107, 3.0147653729681236, 4.022687310727045, 4.935636149945933, 5.888465096504, 6.9106089797426735, 7.80256558232094, 8.860001560549065, 9.808585556621773, 10.78158544648854, 9.850285867599322, 8.8112393623863, 7.760807433911459, 6.7967925591950245, 5.795589223983943, 5.89899388575965, 4.860585733061673, 3.876369066242625, 2.9265579018705523, 1.9620536573531895, 2.989323085536048, 3.972201949555, 4.971286749074775, 5.916965873222886, 6.842031447361593, 7.887905458243488, 8.814929286799382, 9.778560335462773, 10.823668904248287, 11.725891608000927, 10.725108556013652, 9.655617087083858, 8.717487465094308, 7.719951135878975, 6.782443296143782, 6.8259385459475945, 5.794254346653599, 4.826411772599272, 3.9654310738520575, 3.021686359967654, 3.9553342886762066, 4.944385933951228, 5.887121847574048, 6.869553333473327, 7.876025785666837, 8.829132936444575, 9.745021041287176, 10.73798909566484, 11.750277242006826, 12.643523147466274, 11.686692791518738, 10.635830508254845, 9.678952685844761, 8.704430303256169, 7.763839149975783, 7.748969848202503, 6.793763846705772, 5.873110101541648, 4.964444444195744, 4.092788243754508, 4.888926599499109, 5.929186426348068, 6.812370488359296, 7.7852833487948505, 8.770935202414856, 9.70552519127265, 10.73197126909458, 11.739348729705279, 12.710759930419435, 13.61352018147383, 12.566332987526687, 11.591559044731182, 10.57555422627758, 9.638989015780178, 8.679597958913421, 8.742171936325866, 7.807504385577943, 6.905372696393735, 5.953647873184434, 5.084731346049843, 5.939725495099108, 6.935533230162852, 7.758464435075607, 8.716620499450295, 9.7067152293763, 10.65419254849435, 11.61997355228188, 12.550454090712346, 13.59629175679426, 14.462548046118485, 13.483838387614426, 12.524393074248428, 11.510174089924142, 10.60310733148934, 9.668640246831796, 9.709378249624008, 8.81856630621626, 7.8965236967130625, 6.977740970736954, 6.140397975032699, 6.925188170941113, 7.889100570987596, 8.704973217515708, 9.65843638967856, 10.6256388592211, 11.685241068458117, 12.640919537705106, 13.482548426574333, 14.548630235232247, 14.6032786314362, 13.661185116139848, 13.387253318920557, 12.455395638642033, 11.542826496535115, 10.676985551563725, 10.637978305728165, 9.828263097926762, 8.84947808383001, 8.044895968117297, 7.171785808399597, 7.907231233640755, 8.893734826183104, 9.773653448756292, 10.733409699366854, 11.588700909570454, 12.58434691471286, 13.592087026582007, 14.425213065561724, 14.615367152820378, 13.661758429830599, 12.724019024511815, 13.728667549599336, 13.457619690437362, 12.584197659764214, 11.637537763644422, 11.644470350438276, 10.802453338432773, 9.884597319008352, 9.014095975612022, 8.222456088001177, 8.91902733398701, 9.82694837410186, 10.716825815281414, 11.686627507194713, 12.558803341594587, 13.51212093386234, 14.49497000364579, 14.659348445193343, 13.730821320689536, 12.711387026907872, 11.738087646327456, 12.702086298472238, 13.64248662457042, 13.532120083128843, 12.703001928234416, 12.611101775634712, 11.87136172145551, 10.942280291257381, 10.012298739962617, 9.166417083494576, 9.874965962331757, 10.7647655778161, 11.643095096380135, 12.665787256489429, 13.581637016253472, 14.461427391826954, 14.56253982759894, 13.631391829492676, 12.684422443717292, 11.759222000313827, 10.77838405560522, 11.682941347765075, 12.571872171063362, 13.569539284437614, 13.63598998220266, 13.565674869986172, 12.840857108272004, 11.880187622882016, 11.028394137011896, 10.2086584535529, 10.946743875402507, 11.785277826549505, 12.623284078491288, 13.68729111689375, 14.572557516969043, 14.722035104894989, 13.846979995044078, 12.777926948718674, 11.794658186411656, 10.784837831092505, 9.805610216406047, 10.684695873004422, 11.571063974380307, 12.594644745784318, 13.435635384382424, 13.423519365764033, 13.745268255252082, 12.815654432532403, 11.959691451213843, 11.236002465422331, 12.007536266922946, 12.79363411592014, 13.692988519616579, 14.695105051736663, 14.683226795374456, 13.713982145893757, 12.804962025713833, 11.802998338050429, 10.79553158668178, 9.801906723785624, 8.862111676432656, 9.632975147477849, 10.60073959608905, 11.565725662705274, 12.449346892969887, 12.425680066999604, 13.386909816560218, 13.755111375804022, 12.932614834432625, 12.171198148859387, 12.968698908462155, 13.84320775269552, 14.70496251979585, 14.572553481458035, 13.612417163439174, 12.671783363348755, 11.757329039135529, 10.809927614158168, 9.847102397210527, 8.863108727388427, 7.924584887072797, 8.666835955970015, 9.612289483221177, 10.568057898047087, 11.510751488976933, 11.479830799452332, 12.437864179992259, 13.433412471224191, 13.895313921249338, 13.108638172867327, 14.004149888274775, 14.916584231489866, 14.544017025597604, 13.639567877116828, 12.677314643817676, 11.699944594800064, 10.842885378626601, 9.887194895393902, 8.94073816342541, 7.911256339551414, 6.944003786157115, 7.687149708888363, 8.629639124913535, 9.5988022845915, 10.538049537712475, 10.454482312194523, 11.522184603883131, 12.504247174514186, 13.462747428978878, 14.14908421896697, 15.034457318132743, 14.555384364716447, 13.581687867117076, 12.614265186718152, 11.669808433063691, 10.744458312829975, 9.898326816738175, 8.956504290146228, 7.945962797693467, 7.017364987002681, 6.00640837126808, 6.663792820116623, 7.70406893800469, 8.64604697057884, 9.48878450715074, 9.526281145675153, 10.555783680117367, 11.594105615689855, 12.504814621579401, 13.504573031040845, 14.503529510541671, 13.59660343344866, 12.614589486013744, 11.66016828509747, 10.759780372790294, 9.806806073818214, 8.89453990383654, 7.94798801746091, 6.914769794162373, 5.9842146672042125, 5.014686494141455, 5.700768930277613, 6.68526523814862, 7.631737500403503, 8.557223277383956, 8.61963507250223, 9.566508357900366, 10.552540131902289, 11.572630523220385, 12.634076929907263, 13.589200971696007, 12.639144374192977, 11.742015454427673, 10.716357621886688, 9.728314812103541, 8.797156444301656, 7.823086647512949, 6.907290116768379, 5.966841760111185, 4.9604687729448145, 3.965507974421652, 4.740576198968395, 5.705248836724382, 6.666052287667322, 7.665892654998819, 7.740510960363251, 8.81392136750381, 9.77509740023309, 10.63165954150335, 11.70014066485562, 12.740934603085124, 11.686601390273548, 10.731577658562435, 9.745433268587114, 8.762406145094387, 7.825074566388045, 6.886992780598996, 5.956539207838598, 4.9515975384992, 3.9765506751473274, 3.029979110669763, 3.7783342453811564, 4.810546715758614, 5.844041706201114, 6.776321592474531, 6.7725020783215095, 7.7955174177874325, 8.80024262836206, 9.698967829336151, 10.732549191453735, 11.695188360348562, 10.746934460513222, 9.777836440908832, 8.818924891749962, 7.920038920719186, 6.880491417511037, 5.9235371575861855, 4.928130868565058, 3.9363407410098983, 2.9513190669597593, 2.001000318382677, 2.8116895104238555, 3.8141031187905026, 4.774864891655659, 5.75296484462474], [5.755543698869156, 4.805899185749605, 3.8125568502056164, 2.852764696664045, 1.964791948932958, 1.0459553064311, 2.0009190927260105, 2.996619887545905, 3.9599178672635102, 4.996268358946025, 5.983834195883274, 6.830135819066873, 7.794078491707268, 8.78407139034937, 9.740670921203947, 10.711706748460609, 9.724520341693331, 8.71232838254449, 7.714758406201741, 6.763730189915938, 4.894445779919174, 3.949361685565914, 2.9709044787727326, 1.9123666176761018, 0.9772132129508019, 0.0, 1.0610258886480735, 1.996251620202765, 2.9829986268352258, 4.004114656030776, 4.958219914039556, 5.8878529234408195, 6.926576941413545, 7.9078534177782975, 8.94637485447293, 9.776523455921913, 8.81356308477668, 7.768581591719175, 6.781962274679074, 5.8350358861230545, 5.912167043181869, 4.950017507354727, 3.9391258476869595, 2.941260490829067, 1.986316974239323, 0.988338446499305, 2.0375521600173214, 3.0454740977762436, 3.958422936995131, 4.911251883553199, 5.933395766791872, 6.825352369370139, 7.8827883475982645, 8.831372343670973, 9.80437223353774, 10.827499080550123, 9.7884525753371, 8.73802064686226, 7.774005772145825, 6.772802436934745, 6.876207098710452, 5.837798946012475, 4.853582279193427, 3.903771114821354, 2.9392668703039915, 2.012109872585246, 2.994988736604198, 3.994073536123972, 4.9397526602720845, 5.864818234410791, 6.910692245292687, 7.83771607384858, 8.801347122511972, 9.846455691297486, 10.748678395050126, 11.702321768964453, 10.632830300034659, 9.694700678045109, 8.697164348829777, 7.759656509094584, 7.803151758898396, 6.7714675596044005, 5.803624985550074, 4.913972993560702, 3.9497661270974245, 3.0161181983888716, 4.005041409807184, 4.947777323430004, 5.930208809329283, 6.898812572716035, 7.851919723493774, 8.767807828336373, 9.760775882714038, 10.773064029056025, 11.818807269724468, 12.663906004469538, 11.613043721205646, 10.656165898795562, 9.681643516206972, 8.741052362926585, 8.726183061153305, 7.770977059656574, 6.850323314492449, 5.9129863639043885, 4.88731756892697, 3.9497105092117737, 4.989970336060733, 5.873025964215252, 6.845938824650807, 7.831590678270812, 8.766180667128607, 9.789851404389301, 10.762135516754476, 11.733546717468633, 12.799876728883248, 13.543546200477488, 12.568772257681983, 11.552767439228383, 10.61620222873098, 9.656811171864224, 9.719385149276668, 8.784717598528745, 7.882585909344537, 6.855532923076377, 5.879260671222305, 5.000509404811773, 5.996317139875517, 6.819119910931563, 7.777275975306251, 8.767370705232256, 9.714848024350307, 10.680629028137837, 11.611109566568302, 12.656947232650216, 13.664764012949867, 14.461051600565227, 13.501606287199229, 12.487387302874945, 11.580320544440143, 10.645853459782598, 10.68659146257481, 9.795779519167063, 8.873736909663865, 7.879626020628897, 6.934927300205161, 5.985972080653778, 6.949884480700261, 7.765628693371664, 8.719091865534516, 9.686294335077056, 10.745896544314073, 11.701575013561062, 12.543203902430289, 13.609285711088203, 13.987019186655798, 14.63839832909065, 14.36446653187136, 13.432608851592835, 12.520039709485918, 11.654198764514527, 11.615191518678968, 10.805476310877564, 9.826691296780812, 8.94678101800924, 7.966315133572059, 6.96801514335342, 7.9545187358957685, 8.834308924612248, 9.79406517522281, 10.64935638542641, 11.645002390568816, 12.652742502437963, 13.48586854141768, 13.92502600709599, 12.971417284106211, 13.701232237462618, 14.705880762550139, 14.434832903388166, 13.561410872715017, 12.614750976595225, 12.62168356338908, 11.779666551383576, 10.861810531959154, 9.915981025503967, 8.975997500644695, 7.979811243699675, 8.887732283814524, 9.77748129113737, 10.747282983050669, 11.619458817450543, 12.572776409718296, 13.555625479501746, 13.859056074039735, 13.002149582726222, 11.982715288944558, 12.715300859278258, 13.67929951142304, 14.619699837521221, 14.509333296079646, 13.680215141185219, 13.588314988585516, 12.848574934406313, 11.869643422383371, 10.861856975911328, 9.919958496138094, 8.935749872044422, 9.825549487528763, 10.70375057223609, 11.726442732345385, 12.642292492109428, 13.52208286768291, 13.762247456445332, 12.831099458339068, 11.955750705753978, 11.030550262350513, 11.755597268556023, 12.660154560715876, 13.549085384014163, 14.546752497388415, 14.613203195153464, 14.542888082936976, 13.818070321222807, 12.807550754008005, 11.877952372960607, 10.962199866196418, 10.007527785115172, 10.846061736262168, 11.683939554347244, 12.747946592749706, 13.633212992825, 13.744821891944188, 12.944637477686173, 11.87669610031274, 10.978313734499089, 10.014466931737813, 10.78282342935685, 11.661909085955223, 12.548277187331108, 13.57185795873512, 14.412848597333225, 14.400732578714834, 14.672631386378072, 13.743017563658393, 12.809249687162552, 11.989543878065849, 11.068320176635611, 11.854418025632803, 12.753643995472535, 13.755760527592619, 13.706013582423653, 12.736768932942955, 11.902619508355928, 10.901767489644495, 9.979187134769212, 8.985562271873057, 9.839324889383459, 10.61018836042865, 11.57795280903985, 12.542938875656075, 13.426560105920688, 13.402893279950405, 14.364123029511019, 14.682474506930012, 13.782173070381335, 12.924739561502905, 12.02948281817482, 12.903991662408185, 13.765617995651805, 13.595340268507233, 12.635203950488371, 11.694570150397952, 10.854986521777624, 9.908696765752234, 9.03075794529796, 8.04676427547586, 8.9017981000236, 9.644049168920816, 10.589502696171978, 11.545271110997888, 12.487964701927734, 12.457044012403133, 13.41507739294306, 14.410625684174992, 14.744872157198047, 13.862179585510845, 13.06493379798744, 13.97736814120253, 13.566803812646802, 12.662354664166026, 11.700101430866873, 10.722731381849261, 9.905385574241594, 8.949695091008895, 8.003238359040402, 7.0949118876388475, 7.9212169991079175, 8.664362921839164, 9.606852337864336, 10.5760154975423, 11.515262750663275, 11.431695525145324, 12.499397816833932, 13.481460387464987, 14.439960641929678, 14.902625631610487, 14.095241227845408, 13.578171151765646, 12.604474654166273, 11.637051973767349, 10.692595220112889, 9.767245099879172, 8.921113603787374, 8.01900448576122, 7.008462993308459, 6.079865182617674, 6.983621584218882, 7.641006033067424, 8.681282150955491, 9.623260183529641, 10.46599772010154, 10.503494358625954, 11.532996893068168, 12.571318828640656, 13.482027834530202, 14.481786243991646, 13.59908449722131, 12.61939022049786, 11.637376273062943, 10.682955072146669, 9.782567159839493, 8.829592860867411, 7.917326690885739, 7.010488213075902, 5.977269989777366, 5.046714862819205, 5.991899707092257, 6.677982143228414, 7.662478451099421, 8.608950713354304, 9.534436490334757, 9.596848285453031, 10.543721570851167, 11.52975334485309, 12.549843736171185, 13.570532841895247, 12.618232349111718, 11.661931161242173, 10.764802241476872, 9.739144408935887, 8.75110159915274, 7.819943231350854, 6.845873434562148, 5.969790312383371, 5.029341955726178, 4.022968968559807, 4.942721187372454, 5.717789411919196, 6.682462049675183, 7.6432655006181225, 8.64310586794962, 8.717724173314053, 9.791134580454612, 10.752310613183893, 11.608872754454154, 12.636596576843605, 11.763721390134322, 10.709388177322746, 9.754364445611632, 8.768220055636311, 7.785192932143585, 6.847861353437243, 5.9097795676481955, 5.010217463198692, 4.005275793859294, 3.0302289305074206, 4.007192323620565, 4.755547458331957, 5.787759928709415, 6.821254919151916, 7.753534805425333, 7.749715291272311, 8.772730630738234, 9.777455841312863, 10.676181042286956, 11.66900510344172, 10.71797514739776, 9.76972124756242, 8.80062322795803, 7.84171167879916, 6.942825707768384, 5.903278204560236, 4.946323944635384, 3.981809123925152, 2.9900189963699915, 2.0049973223198525, 2.9782135313334788, 3.788902723374657, 4.791316331741304, 5.75207810460646, 6.730178057575542], [6.816569587517231, 5.86692507439768, 4.873582738853691, 3.9137905853121193, 2.958873422088626, 1.954175106999775, 0.9398932040779372, 1.9355939988978315, 2.8988919786154366, 3.935242470297951, 4.922808307235201, 5.7691099304188, 6.733052603059194, 7.723045501701297, 8.679645032555875, 9.650680859812537, 10.689181794223138, 9.773354271192561, 8.775784294849814, 7.824756078564011, 5.955471668567247, 5.010387574213988, 4.031930367420807, 2.9733925063241755, 2.0382391015988754, 1.0610258886480735, 0.0, 0.9352257315546915, 1.921972738187152, 2.943088767382702, 3.8971940253914825, 4.826827034792746, 5.865551052765472, 6.846827529130224, 7.885348965824857, 8.891718847162368, 9.8546792183076, 8.829607480367248, 7.842988163327147, 6.896061774771128, 6.973192931829942, 6.011043396002801, 5.000151736335034, 4.002286379477141, 3.0473428628873966, 2.0493643351473785, 1.0236016714877498, 1.98444820912817, 2.8973970483470572, 3.8502259949051254, 4.8723698781437985, 5.764326480722065, 6.821762458950191, 7.7703464550228984, 8.743346344889666, 9.799618325462385, 10.836624635917344, 9.799046535510334, 8.835031660793899, 7.833828325582818, 7.9372329873585254, 6.898824834660549, 5.914608167841501, 4.964797003469428, 4.000292758952066, 2.964657751184403, 1.9810382480746263, 2.9801230475944007, 3.878726771624011, 4.803792345762718, 5.849666356644613, 6.776690185200507, 7.740321233863899, 8.785429802649412, 9.687652506402053, 10.761825712742752, 11.693856188682732, 10.755726566693182, 9.75819023747785, 8.820682397742658, 8.86417764754647, 7.832493448252475, 6.864650874198148, 5.866520872159859, 4.9023140056965815, 3.9686660769880286, 2.9910909212776122, 3.9338268349004326, 4.900371222566292, 5.837786684067962, 6.790893834845701, 7.706781939688301, 8.699749994065966, 9.712038140407952, 10.757781381076395, 11.714611737023931, 12.674069609853719, 11.717191787443635, 10.742669404855045, 9.802078251574658, 9.787208949801379, 8.832002948304648, 7.893459444002222, 6.8655342425035455, 5.839865447526127, 4.902258387810931, 4.053507402692931, 4.85907547568568, 5.831988336121235, 6.81545400848996, 7.750043997347754, 8.72882551574123, 9.701109628106405, 10.672520828820561, 11.738850840235177, 12.673233165861157, 13.629798146330057, 12.613793327876456, 11.677228117379054, 10.717837060512297, 10.780411037924742, 9.845743487176819, 8.87177700974299, 7.808080801675534, 6.831808549821462, 5.95305728341093, 5.0598542065077154, 5.805169422401991, 6.763325486776679, 7.751234035451404, 8.698711354569454, 9.664492358356984, 10.59497289678745, 11.640810562869364, 12.648627343169014, 13.627337001673073, 14.562632175847302, 13.548413191523018, 12.641346433088216, 11.706879348430672, 11.747617351222884, 10.791464115258671, 9.843853416353538, 8.832173899228053, 7.887475178804318, 6.938519959252935, 6.0134215473324595, 6.751678204842092, 7.705141377004944, 8.672343846547484, 9.731946055784501, 10.68762452503149, 11.527067232649436, 12.59314904130735, 13.577424115699486, 14.51951763099584, 15.425492420519433, 14.493634740240909, 13.581065598133991, 12.7152246531626, 12.67621740732704, 11.775592817567237, 10.796807803470484, 9.899328896608397, 8.918863012171215, 7.920563021952577, 7.018055802527967, 7.8203584360826754, 8.780114686693238, 9.635405896896838, 10.631051902039244, 11.638792013908391, 12.469731871636828, 13.037636318824484, 13.879637084674886, 14.670011792316135, 15.674660317403657, 15.495858792036238, 14.62243676136309, 13.675776865243298, 13.682709452037152, 12.749783058073248, 11.831927038648827, 10.868528904103123, 9.928545379243852, 8.932359122298832, 7.951269350446723, 8.763530802607796, 9.733332494521095, 10.60550832892097, 11.558825921188724, 12.541674990972174, 12.836220791823024, 12.08003729629302, 12.890935089513233, 13.684080414131776, 14.727291870552804, 15.680725726169294, 15.57035918472772, 14.741241029833292, 14.649340877233588, 13.803164163045299, 12.822191300982526, 11.814404854510483, 10.872506374737249, 9.834731179924832, 8.889086554160961, 9.689800083706517, 10.712492243815811, 11.628342003579856, 12.508132379153338, 12.73941217422862, 11.808264176122357, 11.033638419320775, 11.938770062919188, 12.724376823409541, 13.708146919845639, 14.610111272662236, 15.607778386036488, 15.674229083801535, 15.603913971585047, 14.772659549861793, 13.759517866772255, 12.7998350934771, 11.866562832528686, 10.879008928801483, 9.909598802894367, 10.66998906581767, 11.733996104220132, 12.619262504295428, 12.683796003296113, 11.921802195469462, 10.85386081809603, 10.051962361928531, 10.922686732306488, 11.751602984210367, 12.709901445084986, 13.60930307597918, 14.632883847383193, 15.4738744859813, 15.461758467362909, 15.624598499142321, 14.694984676422642, 13.731132407679045, 12.886344940230236, 11.891608945954015, 10.917955092265002, 11.739693506942961, 12.741810039063045, 12.64498769377558, 11.675743044294881, 10.879784226139217, 9.878932207427784, 9.052835762198654, 9.893782072441732, 10.808104444236976, 11.671214249076721, 12.638978697687923, 13.603964764304148, 14.487585994568763, 14.46391916859848, 15.425148918159094, 15.634441619694261, 14.704055790897828, 13.821540623667293, 12.852771587493224, 11.967528729040382, 12.751667507122232, 12.53431437985916, 11.574178061840298, 10.63354426174988, 9.832151239560913, 8.885861483535523, 8.010673284113707, 8.954984076044536, 9.870577654877117, 10.705075057568887, 11.650528584820051, 12.606296999645963, 13.548990590575809, 13.518069901051208, 14.476103281591135, 15.471651572823067, 15.66675487771454, 14.758980647675232, 13.888222567305842, 13.040905207834728, 12.505777923998728, 11.601328775517953, 10.6390755422188, 9.661705493201188, 8.882550292024883, 7.926859808792184, 6.98040307682369, 8.003131688207523, 8.889996553961435, 9.725388810487237, 10.667878226512409, 11.637041386190376, 12.57628863931135, 12.492721413793399, 13.560423705482007, 14.542486276113062, 15.464187971424094, 14.461705724692285, 13.487600143161885, 12.517145263117573, 11.5434487655182, 10.576026085119276, 9.631569331464815, 8.7062192112311, 7.8600877151393, 6.996169203544509, 5.985627711091748, 6.988084983186349, 7.952401139072399, 8.702031921715498, 9.742308039603566, 10.684286072177716, 11.527023608749616, 11.564520247274029, 12.594022781716243, 13.632344717288731, 14.506255164024617, 13.533283990892787, 12.538058608573238, 11.558364331849786, 10.57635038441487, 9.621929183498596, 8.72154127119142, 7.768566972219338, 6.856300802237665, 5.987652930859191, 4.9544347075606545, 5.95493466338788, 6.960679261945774, 7.739008031876489, 8.723504339747496, 9.669976602002379, 10.595462378982832, 10.657874174101106, 11.604747459499242, 12.590779233501165, 13.574071065665601, 12.509506953247175, 11.557206460463647, 10.600905272594101, 9.703776352828799, 8.678118520287814, 7.690075710504667, 6.758917342702781, 5.784847545914074, 4.94695503016666, 4.006506673509467, 4.931188769128482, 5.9115007422259715, 6.778815300567271, 7.743487938323258, 8.704291389266197, 9.704131756597695, 9.778750061962128, 10.852160469102687, 11.813336501831968, 12.573534206983961, 11.575570688195533, 10.702695501486248, 9.648362288674672, 8.693338556963559, 7.707194166988238, 6.724167043495512, 5.78683546478917, 4.848753679000121, 3.9534243236760993, 2.9484826543367015, 3.938448731076096, 4.975971878474082, 5.816573346980032, 6.84878581735749, 7.882280807799991, 8.814560694073409, 8.810741179920386, 9.833756519386306, 10.838481729960934, 11.640842494816763, 10.607979214793648, 9.65694925874969, 8.708695358914348, 7.739597339309956, 6.780685790151087, 5.881799819120311, 4.842252315912162, 3.88529805598731, 2.9250159844025596, 1.9332258568473992, 2.9132171228885277, 3.9722950044891467, 4.849928612022731, 5.852342220389378, 6.813103993254535, 7.791203946223617], [7.751795319071922, 6.802150805952372, 5.808808470408382, 4.849016316866811, 3.8940991536433174, 2.889400838554467, 1.8751189356326288, 1.00036826734314, 1.963666247060745, 3.0000167387432595, 3.9875825756805092, 4.833884198864109, 5.797826871504503, 6.787819770146606, 7.744419301001184, 8.715455128257846, 9.753956062668447, 10.708580002747253, 9.711010026404505, 8.759981810118703, 6.8906974001219385, 5.9456133057686795, 4.967156098975498, 3.908618237878867, 2.973464833153567, 1.996251620202765, 0.9352257315546915, 0.0, 0.9867470066324606, 2.0078630358280107, 2.961968293836791, 3.891601303238055, 4.9303253212107805, 5.911601797575533, 6.9501232342701655, 7.956493115607677, 8.91945348675291, 9.764833211921939, 8.778213894881839, 7.831287506325819, 7.908418663384634, 6.946269127557493, 5.935377467889725, 4.9375121110318325, 3.982568594442088, 2.98459006670207, 1.9588274030424413, 1.0492224775734786, 1.9621713167923658, 2.915000263350434, 3.937144146589107, 4.829100749167374, 5.8865367273955, 6.835120723468207, 7.8081206133349745, 8.864392593907693, 9.901398904362654, 10.734272267065025, 9.77025739234859, 8.76905405713751, 8.872458718913217, 7.83405056621524, 6.8498338993961925, 5.90002273502412, 4.935518490506757, 3.899883482739095, 2.916263979629318, 2.106173140132503, 2.9435010400693193, 3.868566614208026, 4.914440625089922, 5.841464453645815, 6.805095502309207, 7.850204071094721, 8.752426774847361, 9.82659998118806, 10.855065120628787, 11.690952298247874, 10.693415969032541, 9.75590812929735, 9.799403379101161, 8.767719179807166, 7.799876605752839, 6.801746603714552, 5.837539737251274, 4.9038918085427206, 3.9263166528323037, 3.1368280298877775, 3.9651454910116004, 4.90256095251327, 5.855668103291009, 6.771556208133609, 7.764524262511274, 8.77681240885326, 9.822555649521703, 10.77938600546924, 11.835278541799774, 12.652417518998327, 11.677895136409736, 10.73730398312935, 10.72243468135607, 9.76722867985934, 8.828685175556913, 7.800759974058238, 6.775091179080819, 5.837484119365623, 4.988733134247623, 4.062076670673025, 4.975364159913709, 5.880228276935268, 6.814818265793063, 7.793599784186537, 8.765883896551713, 9.73729509726587, 10.803625108680485, 11.738007434306466, 12.71278137710197, 13.549019059431147, 12.612453848933745, 11.653062792066988, 11.715636769479433, 10.78096921873151, 9.807002741297683, 8.743306533230227, 7.767034281376154, 6.888283014965623, 5.995079938062407, 5.008170617389336, 5.958215191967405, 6.816008303896712, 7.763485623014762, 8.729266626802293, 9.659747165232758, 10.705584831314672, 11.713401611614323, 12.692111270118382, 13.645615406619216, 14.48363892307771, 13.576572164642908, 12.642105079985363, 12.682843082777575, 11.726689846813365, 10.77907914790823, 9.767399630782746, 8.82270091035901, 7.873745690807628, 6.946236846303374, 5.954679399829436, 6.900031082195669, 7.832655949743775, 8.801204165136978, 9.756882634383967, 10.591841501094745, 11.65792330975266, 12.642198384144795, 13.584291899441148, 14.531616489339807, 15.4288604717956, 14.516291329688682, 13.650450384717292, 13.611443138881732, 12.71081854912193, 11.732033535025177, 10.83455462816309, 9.854088743725908, 8.855788753507271, 7.9508711014988815, 7.0233596310700195, 7.975004391883963, 8.795718000093128, 9.791364005235534, 10.708050123260868, 11.534506140082136, 12.598234521223816, 13.551843244213595, 14.489582649532379, 15.4942311746199, 16.43108452359093, 15.557662492917782, 14.61100259679799, 14.617935183591843, 13.685008789627942, 12.76715277020352, 11.803754635657818, 10.863771110798547, 9.867584853853527, 8.884084649417638, 7.9665319975951405, 8.928817359584286, 9.76582043211726, 10.719138024385014, 11.701987094168464, 11.95178388590076, 12.885336730670321, 13.748162125972987, 14.619306145686465, 15.662517602107492, 16.615951457723984, 16.50558491628241, 15.676466761387983, 15.584566608788279, 14.738389894599994, 13.757417032537221, 12.749630586065178, 11.807732106291944, 10.767546478895747, 9.821901853131877, 8.892801278693861, 9.907977108879003, 10.788654106776146, 11.668444482349628, 11.854975268306356, 10.923827270200093, 11.870796655975477, 12.795997099378942, 13.65960255496423, 14.643372651400329, 15.545337004216927, 16.54300411759118, 16.609454815356226, 16.53913970313974, 15.707885281416488, 14.69233316574317, 13.732650392448015, 12.799378131499601, 11.811824227772398, 10.842414101865282, 9.872990260805015, 10.936997299207476, 11.779574607491718, 11.748570271741421, 11.011534925551718, 9.969423912173765, 10.987188093483224, 11.857912463861181, 12.686828715765056, 13.645127176639676, 14.544528807533872, 15.568109578937884, 16.40910021753599, 16.3969841989176, 16.557413798113238, 15.627799975393557, 14.66394770664996, 13.819160239201151, 12.82442424492493, 11.850770391235917, 10.942694701930305, 11.94481123405039, 11.709761962220888, 10.74051731274019, 9.969516956221472, 8.99449530150552, 9.988061493753348, 10.829007803996426, 11.743330175791666, 12.606439980631412, 13.574204429242615, 14.53919049585884, 15.422811726123454, 15.399144900153171, 16.360374649713783, 16.567256918665176, 15.636871089868743, 14.754355922638208, 13.78558688646414, 12.900344028011297, 11.954668702109576, 11.599088648304468, 10.638952330285607, 9.698318530195188, 8.921883969643169, 8.001424577613259, 8.9458990156684, 9.890209807599229, 10.805803386431807, 11.640300789123579, 12.585754316374743, 13.541522731200654, 14.4842163221305, 14.4532956326059, 15.411329013145828, 16.40687730437776, 15.45473221883425, 14.566926039237236, 13.582681841465162, 12.614906804391739, 11.570552192444037, 10.666103043963261, 9.703849810664108, 8.726479761646496, 7.972283022107138, 7.0424229028699195, 7.915628808378384, 8.938357419762216, 9.825222285516125, 10.660614542041928, 11.6031039580671, 12.572267117745067, 13.511514370866044, 13.427947145348092, 14.4956494370367, 15.477712007667755, 14.528962239869402, 13.526479993137594, 12.552374411607193, 11.581919531562882, 10.608223033963508, 9.640800353564584, 8.696343599910124, 7.770993479676408, 6.924861983584608, 6.111732297622245, 6.920853442646441, 7.923310714741042, 8.88762687062709, 9.63725765327019, 10.677533771158258, 11.61951180373241, 12.462249340304309, 12.499745978828722, 13.529248513270936, 14.554816362001096, 13.571029432469926, 12.598058259338096, 11.602832877018546, 10.623138600295094, 9.641124652860178, 8.686703451943904, 7.7863155396367265, 6.833341240664646, 5.921075070682973, 5.073818717765266, 5.889660439115348, 6.890160394942574, 7.895904993500466, 8.67423376343118, 9.658730071302188, 10.605202333557072, 11.530688110537525, 11.5930999056558, 12.539973191053935, 13.526004965055858, 12.63884533411091, 11.574281221692484, 10.621980728908955, 9.66567954103941, 8.768550621274105, 7.742892788733122, 6.7548499789499745, 5.823691611148089, 4.8496218143593826, 4.025230092912255, 4.941732405064159, 5.866414500683176, 6.846726473780663, 7.714041032121963, 8.67871366987795, 9.63951712082089, 10.639357488152388, 10.713975793516818, 11.787386200657377, 12.57522365541272, 11.63830847542927, 10.640344956640842, 9.767469769931557, 8.71313655711998, 7.758112825408866, 6.771968435433546, 5.788941311940819, 4.851609733234477, 3.91352794744543, 3.030397102702771, 3.8837083858913934, 4.873674462630788, 5.911197610028775, 6.751799078534724, 7.784011548912181, 8.817506539354683, 9.749786425628098, 9.745966911475076, 10.768982250940997, 11.697812335079707, 10.705616763262071, 9.672753483238957, 8.721723527194998, 7.773469627359657, 6.8043716077552645, 5.845460058596395, 4.946574087565619, 3.9070265843574705, 2.9500723244326186, 2.0019887634292313, 2.868451588402091, 3.8484428544432197, 4.907520736043838, 5.785154343577423, 6.7875679519440695, 7.748329724809227, 8.726429677778308], [8.738542325704381, 7.788897812584832, 6.795555477040843, 5.835763323499271, 4.880846160275778, 3.876147845186927, 2.8618659422650894, 1.9871152739756006, 0.9769192404282844, 2.013269732110799, 3.000835569048048, 3.8471371922316475, 4.811079864872042, 5.801072763514145, 6.757672294368723, 7.728708121625385, 8.767209056035984, 9.779401015184824, 10.697757033036966, 9.746728816751162, 7.8774444067544, 6.93236031240114, 5.953903105607958, 4.895365244511328, 3.9602118397860275, 2.9829986268352258, 1.921972738187152, 0.9867470066324606, 0.0, 1.0211160291955501, 1.9752212872043302, 2.904854296605594, 3.94357831457832, 4.924854790943072, 5.9633762276377045, 6.969746108975216, 7.932706480120449, 8.977687973177954, 9.7649609015143, 8.81803451295828, 8.895165670017095, 7.933016134189953, 6.922124474522185, 5.924259117664293, 4.969315601074548, 3.9713370733345306, 2.9455744096749017, 1.9452506257984765, 0.9754243101599052, 1.928253256717973, 2.9503971399566464, 3.8423537425349132, 4.899789720763039, 5.848373716835746, 6.8213736067025135, 7.877645587275232, 8.914651897730193, 9.947966243752969, 10.757004398981051, 9.755801063769969, 9.859205725545678, 8.8207975728477, 7.836580906028653, 6.88676974165658, 5.922265497139216, 4.886630489371555, 3.903010986261778, 2.9129262247304273, 1.9567540334368587, 2.8818196075755655, 3.9276936184574613, 4.854717447013354, 5.818348495676746, 6.86345706446226, 7.765679768214899, 8.839852974555598, 9.868318113996324, 10.806447735985873, 11.680162975665, 10.742655135929809, 10.78615038573362, 9.754466186439625, 8.786623612385299, 7.773223468555374, 6.809016602092096, 5.875368673383543, 4.886317028108522, 3.943581114485702, 2.97839848437914, 3.915813945880809, 4.868921096658548, 5.784809201501148, 6.777777255878813, 7.790065402220799, 8.835808642889242, 9.792638998836779, 10.84853153516731, 11.767912956736327, 12.664642143042196, 11.724050989761809, 11.70918168798853, 10.753975686491799, 9.800162040397735, 8.77223683889906, 7.746568043921641, 6.808960984206445, 5.902144902204579, 4.86882975527095, 3.9886171532812478, 4.893481270302807, 5.828071259160602, 6.806852777554076, 7.779136889919252, 8.750548090633409, 9.816878102048022, 10.751260427674005, 11.72603437046951, 12.751939390618983, 13.599200855566204, 12.639809798699448, 12.702383776111892, 11.76771622536397, 10.778479606138506, 9.714783398071049, 8.738511146216975, 7.859759879806445, 6.830225022619217, 5.814923701987261, 4.971468185334944, 5.829261297264251, 6.776738616382301, 7.742519620169831, 8.673000158600297, 9.718837824682211, 10.726654604981862, 11.70536426348592, 12.658868399986755, 13.686559254265545, 14.563319171275367, 13.628852086617822, 13.669590089410034, 12.687436534754147, 11.739825835849013, 10.728146318723528, 9.707389278195551, 8.739649989468578, 7.7529899309012995, 6.7614324844273614, 5.913284075563208, 6.845908943111314, 7.814457158504517, 8.770135627751506, 9.605094494462284, 10.671176303120198, 11.655451377512334, 12.597544892808687, 13.544869482707346, 14.47672716298587, 15.501982682994237, 14.637197391349751, 14.598190145514192, 13.671565237062712, 12.69278022296596, 11.765518299592783, 10.738777111562449, 9.72169305216822, 8.757624186096807, 7.830112715667945, 6.988257385251502, 7.808970993460667, 8.804616998603073, 9.721303116628407, 10.547759133449677, 11.611487514591357, 12.565096237581136, 13.50283564289992, 14.50748416798744, 15.450914908131484, 16.487883845503426, 15.597749603430449, 15.58872942894261, 14.645755477568724, 13.727899458144302, 12.713066495615529, 11.729675409459496, 10.733489152514476, 9.690837734015563, 8.773285082193066, 7.942070352951825, 8.7790734254848, 9.732391017752553, 10.715240087536003, 11.561095357979381, 12.494648202748943, 13.553798232742789, 14.488767021084278, 15.56273924661752, 16.402609149794724, 17.357526066937847, 16.659871409032704, 16.52134682530794, 15.571185075924936, 14.590212213862163, 13.58242576739012, 12.640527287616885, 11.574299563493673, 10.628654937729802, 9.699554363291787, 8.921230102246541, 9.801907100143685, 10.681697475717167, 11.050288502123921, 11.690041202477353, 12.637010588252737, 13.562211031656203, 14.487238544832675, 15.471008641268773, 16.409491109251608, 17.40715822262586, 17.546235031875888, 17.4759199196594, 16.540680462741427, 15.499086250341096, 14.53940347704594, 13.606131216097527, 12.618577312370324, 11.649167186463208, 10.67974334540294, 9.963941153886713, 10.792827600859257, 10.761823265108962, 10.024787918919257, 10.735637844451025, 11.771752804652984, 12.661124356579535, 13.5144647056335, 14.47276316650812, 15.457310578741934, 16.480891350145946, 17.395847224168453, 17.38373120555006, 17.36416688271116, 16.434553059991483, 15.470700791247886, 14.625913323799077, 13.631177329522856, 12.657523475833843, 11.749447786528231, 10.971755088729626, 10.723014955588427, 9.75377030610773, 8.982769949589011, 9.76070923378278, 10.772626204923107, 11.63221969671478, 12.57096616566011, 13.517079142671605, 14.48732572601836, 15.452311792634585, 16.409558732755915, 16.38589190678563, 17.347121656346243, 16.356979788285177, 15.4306842990185, 14.517619056612714, 13.622398106452566, 12.586351316921874, 11.593368608552653, 10.612341641672007, 9.652205323653146, 8.711571523562728, 7.935136963010708, 8.767638509890519, 9.73046372683816, 10.693421700317582, 11.63343937630025, 12.627047795756042, 13.572501323007204, 14.528269737833114, 15.47096332876296, 15.44004263923836, 16.398076019778287, 15.429776854974072, 14.467985212201787, 13.580179032604775, 12.5959348348327, 11.628159797759277, 10.583805185811576, 9.6793560373308, 8.717102804031647, 7.739732755014036, 6.985536015474677, 7.80863683514718, 8.705788785160935, 9.74156931248057, 10.679261195951996, 11.64736154867439, 12.589850964699561, 13.559014124377526, 14.498261377498503, 14.414694151980552, 15.48239644366916, 14.5332260796293, 13.54221523323694, 12.539732986505133, 11.565627404974732, 10.59517252493042, 9.621476027331047, 8.654053346932123, 7.709596593277663, 6.784246473043947, 5.938114976952148, 6.877946229899505, 7.711013419428992, 8.726522607459396, 9.741665781062961, 10.624004659902651, 11.664280777790717, 12.606258810364869, 13.448996346936768, 13.486492985461181, 14.515995519903395, 13.568069355368634, 12.584282425837463, 11.611311252705635, 10.616085870386085, 9.636391593662633, 8.654377646227717, 7.699956445311443, 6.799568533004266, 5.846594234032185, 4.934328064050513, 5.840032650042527, 6.679820415897899, 7.693372287660927, 8.749943903936337, 9.660980770063642, 10.645477077934647, 11.591949340189531, 12.517435117169985, 12.579846912288259, 13.526720197686394, 12.567789793637942, 11.652098327478447, 10.587534215060023, 9.635233722276492, 8.678932534406947, 7.781803614641645, 6.756145782100662, 5.768102972317514, 4.836944604515629, 3.8628748077269224, 4.7914440251895165, 5.73189238184671, 6.738265369013081, 7.733226167536243, 8.700788038754423, 9.66546067651041, 10.62626412745335, 11.626104494784848, 11.70072280014928, 12.549652681509539, 11.588476648780258, 10.651561468796807, 9.65359795000838, 8.780722763299096, 7.72638955048752, 6.771365818776405, 5.785221428801085, 4.802194305308359, 3.8648627266020172, 2.9267809408129692, 3.9691993169634685, 4.870455392523854, 5.8604214692632475, 6.897944616661234, 7.738546085167183, 8.77075855554464, 9.804253545987143, 10.73653343226056, 10.732713918107539, 11.75572925757346, 10.711065328447244, 9.718869756629609, 8.686006476606495, 7.734976520562536, 6.786722620727196, 5.817624601122803, 4.858713051963934, 3.9598270809331586, 2.92027957772501, 1.963325317800158, 2.988735770061692, 3.8551985950345515, 4.83518986107568, 5.894267742676298, 6.771901350209882, 7.774314958576529, 8.735076731441687, 9.713176684410769], [9.759658354899932, 8.810013841780382, 7.816671506236393, 6.856879352694821, 5.901962189471328, 4.897263874382477, 3.8829819714606395, 3.0082313031711507, 1.9980352696238346, 0.9921537029152488, 1.9797195398524985, 2.8260211630360974, 3.7899638356764913, 4.779956734318594, 5.736556265173172, 6.7075920924298345, 7.746093026840435, 8.758284985989276, 9.806832226601149, 10.767844845946712, 8.89856043594995, 7.95347634159669, 6.975019134803508, 5.916481273706878, 4.981327868981578, 4.004114656030776, 2.943088767382702, 2.0078630358280107, 1.0211160291955501, 0.0, 0.9541052580087801, 1.883738267410044, 2.9224622853827698, 3.9037387617475217, 4.942260198442154, 5.948630079779666, 6.911590450924899, 7.956571943982404, 8.943191261022506, 9.83915054215383, 9.916281699212645, 8.954132163385502, 7.943240503717735, 6.945375146859843, 5.921554512996297, 4.923084894972287, 3.8738711814542706, 2.855830836741542, 1.8860045211029703, 0.9331755745449024, 1.9292811107610963, 2.821237713339363, 3.8786736915674886, 4.827257687640196, 5.800257577506963, 6.856529558079682, 7.893535868534643, 8.926850214557419, 9.890865089273854, 10.776917092965519, 10.821405239958015, 9.782997087260037, 8.79878042044099, 7.848969256068916, 6.84047196924169, 5.771715486229597, 4.78809598311982, 3.789011183600046, 2.8328389923064776, 1.8867419254024949, 2.9326159362843907, 3.833601417817804, 4.797232466481196, 5.84234103526671, 6.744563739019349, 7.8187369453600475, 8.847202084800774, 9.785331706790323, 10.782868036005656, 11.720375875740848, 11.68851790165262, 10.656833702358623, 9.688991128304297, 8.649308427424993, 7.685101560961715, 6.7514536322531615, 5.762401986978141, 4.819666073355321, 3.8544834432487587, 2.920736263707739, 3.8738434144854774, 4.763693172305598, 5.756661226683263, 6.768949373025249, 7.814692613693692, 8.771522969641229, 9.82741550597176, 10.746796927540776, 11.724033832079089, 12.626418505680808, 12.611549203907527, 11.656343202410797, 10.676246999267354, 9.648321797768679, 8.62265300279126, 7.685045943076064, 6.778229861074198, 5.7449147141405685, 4.864702112150867, 3.898403588129737, 4.832993576987532, 5.785736748358526, 6.758020860723702, 7.729432061437858, 8.795762072852472, 9.730144398478455, 10.70491834127396, 11.730823361423433, 12.658592544603097, 13.542177314618446, 13.60475129203089, 12.670083741282967, 11.654564565008124, 10.590868356940668, 9.614596105086594, 8.735844838676064, 7.706309981488836, 6.6910086608568795, 5.8475531442045625, 4.834183615091181, 5.78166093420923, 6.7474419379967605, 7.677922476427226, 8.723174896752651, 9.730991677052302, 10.70970133555636, 11.637752370791205, 12.665443225069994, 13.62271086031226, 14.53121960253682, 14.554189076522524, 13.563521493623767, 12.615910794718634, 11.604231277593149, 10.583474237065172, 9.615734948338199, 8.62907488977092, 7.63751744329698, 6.789369034432827, 5.850831260938244, 6.819379476331447, 7.7750579455784345, 8.610016812289212, 9.676098620947126, 10.660373695339262, 11.602467210635615, 12.549791800534274, 13.481649480812798, 14.506905000821165, 15.498161312564614, 15.482789132626682, 14.547650195932333, 13.56886518183558, 12.641603258462403, 11.61486207043207, 10.59777801103784, 9.633709144966428, 8.706197674537565, 7.7785963080751825, 6.813893311287597, 7.809539316430003, 8.726225434455337, 9.552681451276605, 10.616409832418285, 11.570018555408064, 12.507757960726847, 13.512406485814369, 14.455837225958412, 15.492806163330354, 16.45871352464531, 16.464814387812233, 15.521840436438344, 14.603984417013923, 13.58915145448515, 12.605760368329117, 11.609574111384097, 10.566922692885184, 9.649370041062685, 8.719391255555664, 7.7839957433117295, 8.737313335579483, 9.720162405362933, 10.56601767580631, 11.49957052057587, 12.558720550569717, 13.493689338911206, 14.567661564444448, 15.407531467621652, 16.362448384764775, 17.35036762652073, 17.39743178417756, 16.447270034794556, 15.466297172731784, 14.45851072625974, 13.516612246486506, 12.450384522363294, 11.504739896599423, 10.575639322161406, 9.69855100485038, 8.806829417970615, 9.686619793544097, 10.742614027676336, 11.593974291506976, 12.54094367728236, 13.466144120685826, 14.446982065394431, 15.502636404605868, 16.441118872588703, 17.39221832210904, 18.362015841912548, 18.35200487852902, 17.41676542161105, 16.375171209210716, 15.415488435915563, 14.48221617496715, 13.494662271239946, 12.525252145332828, 11.55582830427256, 10.741262056490552, 9.797749918686186, 9.832294271962148, 10.822044076507247, 11.674480863534125, 12.710595823736083, 13.621003072005312, 14.474343421059277, 15.432641881933897, 16.417189294167713, 17.440770065571726, 18.397196474469716, 18.21785995940267, 17.20493452508093, 16.27532070236125, 15.382491653041733, 14.523285746902959, 13.654031754844965, 12.706395960550445, 11.672665169725848, 10.635512111472963, 9.793485962441615, 8.824241312960917, 9.806713090574561, 10.69955225286588, 11.711469224006207, 12.592098412140556, 13.530844881085887, 14.476957858097382, 15.447204441444137, 16.412190508060363, 17.41090798305718, 17.30809176509765, 16.373030097604026, 15.335863759089628, 14.40956826982295, 13.588090063465902, 12.692869113305756, 11.656822323775064, 10.663839615405843, 9.682812648525196, 8.722676330506333, 7.782042530415915, 8.759080103996258, 9.706481528973619, 10.66930674592126, 11.65330041574336, 12.593318091726028, 13.625809112351638, 14.573850573308466, 15.529618988134377, 16.472312579064223, 16.36224249755038, 15.404209117010454, 14.408660825778522, 13.446869183006237, 12.650650039457963, 11.666405841685888, 10.698630804612467, 9.654276192664765, 8.74982704418399, 7.787573810884836, 6.810203761867224, 7.8094791564602275, 8.754375551146566, 9.690168311863827, 10.725948839183461, 11.66364072265489, 12.648710798975651, 13.591200215000823, 14.56036337467879, 15.499610627799765, 15.378807133280349, 14.494172621064804, 13.51211005043375, 12.52109920404139, 11.61020399335832, 10.63609841182792, 9.665643531783608, 8.691947034184237, 7.724524353785312, 6.780067600130851, 5.854717479897134, 6.790925350036918, 7.823684945898892, 8.695392946131884, 9.710902134162287, 10.726045307765855, 11.625353910203913, 12.665630028091979, 13.60760806066613, 14.45034559723803, 14.448052325761466, 13.569377619154913, 12.546953326173083, 11.563166396641913, 10.590195223510085, 9.686556877239273, 8.706862600515821, 7.724848653080904, 6.770427452164631, 5.870039539857454, 4.917065240885373, 5.918707590753405, 6.824412176745419, 7.66419994260079, 8.67775181436382, 9.73432343063923, 10.662330020364903, 11.646826328235909, 12.593298590490793, 13.518784367471246, 13.469588056665817, 12.522714771267681, 11.546673764442392, 10.630982298282897, 9.566418185864473, 8.682077351322395, 7.725776163452848, 6.852274621494833, 5.826616788953849, 4.838573979170702, 3.9074156113688163, 4.847254334429814, 5.775823551892408, 6.716271908549602, 7.722644895715972, 8.717605694239134, 9.702137289055685, 10.666809926811672, 11.627613377754612, 12.62745374508611, 12.601947059454547, 11.528536652313988, 10.567360619584708, 9.630445439601257, 8.63248192081283, 7.783350662626095, 6.77323317953342, 5.81922450595473, 4.83308011597941, 3.872665312161547, 2.935333733455205, 3.911160467515861, 4.95357884366636, 5.891571421719403, 6.881537498458798, 7.919060645856784, 8.759662114362733, 9.79187458474019, 10.825369575182693, 11.75764946145611, 11.753829947303089, 10.739922258812912, 9.689949299251694, 8.697753727434058, 7.664890447410945, 6.713860491366985, 5.765606591531645, 4.796508571927253, 3.837597022768384, 3.0136188160145547, 1.9907505845781976, 2.9477048445030496, 3.995129424158539, 4.876314624230101, 5.85630589027123, 6.9153837718718485, 7.793017379405432, 8.795430987772079, 9.756192760637237, 10.734292713606319], [10.71376361290871, 9.764119099789161, 8.770776764245172, 7.810984610703601, 6.856067447480108, 5.851369132391258, 4.83708722946942, 3.962336561179931, 2.9521405276326145, 1.946258960924029, 1.0381362709647575, 1.8719159050273175, 2.8358585776677114, 3.825851476309814, 4.782451007164392, 5.753486834421054, 6.791987768831654, 7.804179727980495, 8.852726968592368, 9.864706695362628, 9.852665693958729, 8.90758159960547, 7.929124392812288, 6.870586531715658, 5.9354331269903575, 4.958219914039556, 3.8971940253914825, 2.961968293836791, 1.9752212872043302, 0.9541052580087801, 0.0, 0.929633009401264, 1.9683570273739899, 2.949633503738742, 3.988154940433375, 4.994524821770886, 5.957485192916119, 7.002466685973624, 7.989086003013725, 8.936012391569745, 10.857785580957572, 9.908237421394283, 8.897345761726516, 7.899480404868623, 6.875659771005077, 5.877190152981067, 4.82797643946305, 3.809936094750322, 2.84010977911175, 1.8872808325536825, 0.9751758527523161, 1.8671324553305833, 2.9245684335587088, 3.8731524296314164, 4.8461523194981835, 5.902424300070903, 6.939430610525863, 7.97274495654864, 8.936759831265075, 9.873778942381435, 11.775510497966795, 10.737102345268818, 9.75288567844977, 8.803074514077696, 7.794577227250471, 6.725820744238378, 5.742201241128601, 4.7431164416088265, 3.7869442503152575, 2.8408471834112747, 2.041939582290079, 2.8794961598090243, 3.843127208472416, 4.88823577725793, 5.790458481010569, 6.864631687351268, 7.893096826791995, 8.831226448781544, 9.828762777996877, 10.766270617732069, 12.642623159661401, 11.610938960367404, 10.643096386313077, 9.603413685433773, 8.639206818970495, 7.705558890261941, 6.7165072449869205, 5.773771331364101, 4.808588701257539, 3.874841521716519, 2.9831670604911658, 3.8095879142968183, 4.802555968674483, 5.814844115016469, 6.860587355684912, 7.817417711632449, 8.873310247962982, 9.792691669531997, 10.76992857407031, 11.710519727350697, 13.565654461916308, 12.610448460419578, 11.630352257276135, 10.60242705577746, 9.57675826080004, 8.639151201084843, 7.732335119082977, 6.6990199721493475, 5.8188073701596466, 4.852508846138517, 4.041708968582911, 4.831631490349746, 5.8039156027149215, 6.775326803429078, 7.8416568148436925, 8.776039140469676, 9.75081308326518, 10.776718103414654, 11.704487286594318, 12.685313126851913, 14.558856550039671, 13.624188999291748, 12.608669823016902, 11.544973614949445, 10.568701363095373, 9.689950096684843, 8.660415239497615, 7.6451139188656585, 6.801658402213342, 5.788288873099961, 4.990376325804609, 5.882187504808071, 6.812668043238537, 7.769069638743869, 8.77688641904352, 9.755596077547578, 10.683647112782426, 11.711337967061215, 12.668605602303481, 13.673959538697298, 15.508294334531303, 14.517626751632546, 13.570016052727413, 12.558336535601928, 11.53757949507395, 10.569840206346978, 9.583180147779698, 8.59162270130576, 7.743474292441607, 6.804936518947024, 6.028094867926825, 6.913990452812462, 7.744762379100522, 8.810844187758436, 9.747136261580327, 10.68922977687668, 11.63655436677534, 12.568412047053863, 13.59366756706223, 14.584923878805679, 16.43689439063546, 15.501755453941112, 14.522970439844359, 13.595708516471182, 12.568967328440849, 11.55188326904662, 10.587814402975207, 9.660302932546344, 8.732701566083964, 7.7679985692963776, 7.080035366399574, 7.865157941689365, 8.687427018087915, 9.751155399229594, 10.704764122219373, 11.626395868504712, 12.631044393592234, 13.570636098849192, 14.607605036221134, 15.545476090886376, 17.41891964582101, 16.475945694447123, 15.558089675022702, 14.543256712493928, 13.559865626337896, 12.563679369392876, 11.521027950893963, 10.603475299071466, 9.673496513564444, 8.73810100132051, 8.059652995633623, 8.866573924445339, 9.700763242617619, 10.63431608738718, 11.693466117381027, 12.612327246689071, 13.686299472222313, 14.522330340512433, 15.477247257655556, 16.46516649941151, 18.351537042186337, 17.401375292803333, 16.420402430740562, 15.41261598426852, 14.470717504495285, 13.404489780372073, 12.458845154608202, 11.529744580170187, 10.65265626285916, 9.760934675979396, 9.008959453598237, 9.896935582540612, 10.728719858318286, 11.67568924409367, 12.600889687497135, 13.572030837411306, 14.627685176622743, 15.566167644605576, 16.507017194999822, 17.47681471480333, 18.256195781619645, 17.186650209755793, 16.256682254002854, 15.359683709234897, 14.606219161633666, 13.77940125741943, 12.811036820631315, 11.803617655428573, 10.739610617026111, 10.282743528163591, 9.98434297712442, 10.922436165745276, 11.683123216344613, 12.657365301485914, 13.616973018109835, 14.54480467661048, 15.5031031374851, 16.487650549718914, 17.511231321122928, 18.409276926383583, 17.263754701393886, 16.250829267072145, 15.321215444352466, 14.428386395032952, 13.578875149764235, 12.718608865898991, 11.80268053126068, 10.768949740436083, 9.731796682183198, 9.229261880808718, 9.778346570969699, 10.760818348583342, 11.65365751087466, 12.665574482014987, 13.546203670149337, 14.484950139094668, 15.431063116106163, 16.401309699452916, 17.36629576606914, 18.23792717418803, 16.353986507088873, 15.418924839595247, 14.381758501080848, 13.45546301181417, 12.643679466327178, 11.757446224359782, 10.753106894485299, 9.760124186116078, 8.779097219235432, 8.158452248873436, 8.736147788424697, 9.713185362005039, 10.6605867869824, 11.62341200393004, 12.60740567375214, 13.547423349734808, 14.579914370360418, 15.527955831317247, 16.483724246143158, 17.345369213235323, 15.4081372395416, 14.450103859001674, 13.454555567769741, 12.492763924997456, 11.706239442319239, 10.721995244547164, 9.770486683486057, 8.750560763375, 7.846111614894225, 7.223349729251938, 7.764309019876005, 8.763584414469008, 9.708480809155347, 10.644273569872606, 11.680054097192238, 12.617745980663667, 13.602816056984432, 14.545305473009604, 15.51446863268757, 16.414261867454723, 14.424701875271568, 13.540067363056023, 12.558004792424969, 11.566993946032609, 10.665793396219597, 9.691687814689196, 8.721232934644885, 7.788231604894472, 6.820808924495548, 6.215843518497953, 6.808822737905915, 7.745030608045699, 8.777790203907673, 9.649498204140663, 10.665007392171065, 11.680150565774632, 12.579459168212693, 13.61973528610076, 14.561713318674911, 15.364996836892988, 13.493947067752686, 12.615272361146133, 11.592848068164303, 10.609061138633132, 9.636089965501304, 8.742146280100549, 7.7624520033770965, 6.792917257226525, 5.838496056310252, 5.216817785844269, 5.871170498894154, 6.872812848762184, 7.778517434754198, 8.61830520060957, 9.631857072372597, 10.688428688648008, 11.616435278373684, 12.60093158624469, 13.547403848499574, 14.433435607126205, 12.515482798657036, 11.5686095132589, 10.592568506433611, 9.676877040274116, 8.612312927855692, 7.727972093313615, 6.7716709054440685, 5.920343225640454, 4.89468539309947, 4.185352225157517, 4.861520869377596, 5.801359592438593, 6.729928809901187, 7.670377166558381, 8.676750153724752, 9.671710952247915, 10.656242547064465, 11.620915184820452, 12.581718635763393, 13.469225216160448, 11.647841801445766, 10.574431394305208, 9.613255361575927, 8.676340181592476, 7.67837666280405, 6.829245404617315, 5.8191279215246405, 4.865119247945951, 3.8789748579706305, 3.1434996108222353, 3.889438991463985, 4.86526572552464, 5.907684101675139, 6.845676679728184, 7.835642756467578, 8.873165903865566, 9.713767372371514, 10.745979842748971, 11.779474833191472, 12.612031169334486, 10.831758521679552, 9.785817000804132, 8.735844041242913, 7.743648469425278, 6.710785189402165, 5.759755233358205, 4.811501333522865, 3.8424033139184735, 2.8834917647596043, 2.0720355471268137, 2.9448558425869775, 3.9018101025118295, 4.949234682167319, 5.830419882238882, 6.810411148280011, 7.869489029880629, 8.747122637414213, 9.74953624578086, 10.710298018646016, 11.688397971615098], [9.919369136369799, 10.693752109190426, 9.700409773646436, 8.740617620104866, 7.785700456881372, 6.781002141792522, 5.7667202388706835, 4.891969570581194, 3.8817735370338786, 2.8758919703252928, 1.9677692803660216, 0.9422828956260536, 1.9062255682664477, 2.8962184669085502, 3.852817997763128, 4.823853825019791, 5.862354759430391, 6.874546718579232, 7.923093959191105, 8.935073685961363, 8.94696948837236, 9.837214609006734, 8.858757402213552, 7.800219541116921, 6.865066136391621, 5.8878529234408195, 4.826827034792746, 3.8916013032380548, 2.904854296605594, 1.883738267410044, 0.929633009401264, 0.0, 1.0387240179727257, 2.0200004943374776, 3.058521931032111, 4.0648918123696225, 5.027852183514855, 6.07283367657236, 7.059452993612461, 8.00637938216848, 9.928152571556307, 10.837870430795547, 9.82697877112778, 8.829113414269887, 7.805292780406341, 6.80682316238233, 5.757609448864314, 4.7395691041515855, 3.769742788513014, 2.816913841954946, 1.9048088621535801, 0.9374994459293191, 1.9949354241574448, 2.9435194202301522, 3.9165193100969193, 4.9727912906696385, 6.0097976011246, 7.043111947147375, 8.00712682186381, 8.94414593298017, 10.901521788590376, 11.666735354670081, 10.682518687851033, 9.73270752347896, 8.724210236651734, 7.655453753639641, 6.671834250529864, 5.672749451010089, 4.716577259716521, 3.7704801928125384, 2.971572591691343, 1.9498631504077604, 2.913494199071152, 3.9586027678566653, 4.860825471609306, 5.934998677950004, 6.963463817390731, 7.901593439380282, 8.899129768595614, 9.836637608330806, 11.718787321977622, 12.540571969768667, 11.57272939571434, 10.533046694835036, 9.568839828371758, 8.635191899663205, 7.646140254388183, 6.703404340765363, 5.738221710658802, 4.8044745311177826, 3.8567733729572846, 2.879954904895554, 3.872922959273219, 4.8852111056152046, 5.930954346283649, 6.887784702231185, 7.943677238561718, 8.863058660130735, 9.840295564669047, 10.780886717949434, 12.665829862578112, 13.54008146982084, 12.559985266677398, 11.532060065178722, 10.506391270201304, 9.568784210486108, 8.66196812848424, 7.62865298155061, 6.74844037956091, 5.7821418555397806, 4.915315281049029, 3.9019984809484827, 4.874282593313659, 5.845693794027815, 6.91202380544243, 7.846406131068411, 8.821180073863916, 9.847085094013389, 10.774854277193056, 11.75568011745065, 13.659031950701475, 14.553822008693011, 13.538302832418166, 12.47460662435071, 11.498334372496638, 10.619583106086107, 9.590048248898878, 8.57474692826692, 7.731291411614606, 6.717921882501225, 5.863982638270728, 4.952554495406807, 5.883035033837273, 6.8394366293426065, 7.847253409642257, 8.825963068146315, 9.754014103381161, 10.78170495765995, 11.738972592902218, 12.744326529296035, 14.626238263999618, 15.447259761033807, 14.499649062128674, 13.487969545003189, 12.467212504475212, 11.499473215748239, 10.51281315718096, 9.52125571070702, 8.67310730184287, 7.734569528348287, 6.901701180392944, 5.984357443411199, 6.8151293696992585, 7.881211178357172, 8.817503252179064, 9.759596767475417, 10.706921357374076, 11.6387790376526, 12.664034557660967, 13.655290869404416, 15.554838320103775, 16.431388463342373, 15.45260344924562, 14.525341525872443, 13.49860033784211, 12.48151627844788, 11.517447412376468, 10.589935941947605, 9.662334575485227, 8.69763157869764, 7.953641678865694, 6.935524932288101, 7.757794008686651, 8.821522389828331, 9.77513111281811, 10.69676285910345, 11.70141138419097, 12.641003089447931, 13.677972026819873, 14.615843081485114, 16.561330364813887, 17.405578703848384, 16.487722684423964, 15.47288972189519, 14.489498635739157, 13.493312378794137, 12.450660960295224, 11.533108308472727, 10.603129522965707, 9.667734010721773, 8.919789984827524, 7.936940915044074, 8.771130233216354, 9.704683077985916, 10.763833107979764, 11.682694237287809, 12.75666646282105, 13.592697331111172, 14.547614248254295, 15.535533490010248, 17.527961790010323, 17.226512587171026, 16.264956576226226, 15.446146096882915, 14.718827522290727, 13.847560685727327, 12.901916059963456, 11.854173628138465, 10.852688659265022, 10.690567685380659, 9.869096442792138, 8.967302573139348, 9.799086848917021, 10.746056234692405, 11.67125667809587, 12.642397828010044, 13.69805216722148, 14.636534635204313, 15.57738418559856, 16.547181705402068, 17.326562772218384, 16.257017200354532, 15.327049244601591, 14.430050699833636, 13.676586152232403, 12.849768248018169, 11.88140381123005, 10.873984646027312, 9.80997760762485, 10.827003214542877, 10.844479966318321, 9.992803156344012, 10.753490206943349, 11.72773229208465, 12.68734000870857, 13.615171667209218, 14.573470128083837, 15.558017540317651, 16.581598311721663, 17.479643916982322, 16.33412169199262, 15.321196257670882, 14.391582434951204, 13.498753385631689, 12.649242140362972, 11.78897585649773, 10.873047521859416, 9.839316731034822, 8.802163672781937, 9.773521567188004, 10.70797958037096, 11.034821125674258, 11.728418817611594, 12.726858891814526, 13.716244668573326, 14.558670207182608, 15.504783184194103, 16.475029767540857, 17.44001583415708, 17.308294164786766, 15.424353497687608, 14.489291830193984, 13.452125491679585, 12.525830002412906, 11.714046456925916, 10.827813214958521, 9.823473885084034, 8.830491176714816, 7.849464209834169, 8.77824139912423, 9.665780797825958, 10.642818371406301, 11.590219796383662, 12.553045013331303, 13.537038683153403, 14.477056359136071, 15.509547379761681, 16.457588840718508, 17.291514819206284, 16.415736203834058, 14.478504230140338, 13.520470849600411, 12.524922558368479, 11.563130915596194, 10.776606432917976, 9.792362235145902, 8.840853674084793, 7.820927753973738, 6.916478605492962, 7.843138879502732, 8.693942029277267, 9.693217423870271, 10.63811381855661, 11.573906579273869, 12.609687106593503, 13.547378990064932, 14.532449066385695, 15.474938482410867, 16.322259205750697, 15.484628858053458, 13.495068865870303, 12.61043435365476, 11.628371783023706, 10.637360936631346, 9.736160386818334, 8.762054805287933, 7.79159992524362, 6.858598595493209, 5.891175915094285, 6.8356326687487465, 7.738455747307178, 8.674663617446962, 9.707423213308935, 10.579131213541926, 11.59464040157233, 12.609783575175896, 13.509092177613956, 14.549368295502022, 15.36950389173804, 14.435363827491724, 12.564314058351421, 11.685639351744868, 10.66321505876304, 9.67942812923187, 8.706456956100041, 7.812513270699285, 6.832818993975833, 5.863284247825261, 4.908863046908988, 5.946860697725823, 6.800803508295417, 7.802445858163448, 8.708150444155462, 9.547938210010832, 10.561490081773862, 11.618061698049273, 12.546068287774947, 13.530564595645952, 14.429288374705393, 13.50380259772494, 11.585849789255771, 10.638976503857636, 9.662935497032347, 8.747244030872853, 7.682679918454429, 6.798339083912351, 5.842037896042805, 4.99071021623919, 3.965052383698206, 4.953095193481354, 5.79115387877886, 6.730992601839858, 7.659561819302452, 8.600010175959644, 9.606383163126015, 10.601343961649178, 11.585875556465728, 12.550548194221715, 13.511351645164655, 12.539592206759183, 10.718208792044502, 9.644798384903943, 8.683622352174662, 7.746707172191212, 6.748743653402787, 5.899612395216051, 4.889494912123377, 3.9354862385446867, 2.9493418485693668, 3.9323689720620933, 4.819072000865249, 5.794898734925905, 6.837317111076404, 7.775309689129449, 8.765275765868843, 9.80279891326683, 10.643400381772778, 11.675612852150236, 12.709107842592736, 11.682398159933221, 9.902125512278289, 8.856183991402869, 7.80621103184165, 6.814015460024015, 5.781152180000902, 4.830122223956941, 3.8818683241216014, 2.9127703045172098, 1.9538587553583406, 3.001668556528078, 3.8744888519882412, 4.831443111913093, 5.8788676915685825, 6.760052891640146, 7.740044157681274, 8.799122039281894, 9.676755646815478, 10.679169255182124, 11.63993102804728, 10.921662745975059], [8.880645118397073, 9.829365449433052, 10.73913379161916, 9.77934163807759, 8.824424474854098, 7.819726159765247, 6.805444256843409, 5.93069358855392, 4.920497555006604, 3.914615988298019, 3.0064932983387473, 1.9810069135987793, 1.065567200379984, 1.9332137568343564, 2.889813287688934, 3.8608491149455966, 4.8993500493561974, 5.911542008505038, 6.9535251071624025, 7.8963496679886385, 7.908245470399636, 8.853329564752896, 9.831786771546078, 8.838943559089646, 7.903790154364347, 6.926576941413545, 5.865551052765472, 4.9303253212107805, 3.9435783145783203, 2.92246228538277, 1.9683570273739899, 1.0387240179727257, 0.0, 0.981276476364752, 2.019797913059385, 3.0261677943968968, 3.98912816554213, 5.034109658599634, 6.020728975639735, 6.967655364195755, 8.889428553583581, 9.853985386541709, 10.865702789100505, 9.867837432242611, 8.844016798379068, 7.845547180355057, 6.796333466837041, 5.778293122124312, 4.8084668064857405, 3.855637859927673, 2.943532880126306, 1.9762234639020448, 1.0215599156570334, 1.9701439117297408, 2.943143801596508, 3.999415782169227, 4.971073583151874, 6.00438792917465, 6.968402803891085, 7.905421915007445, 9.86279777061765, 10.815394461380855, 11.72124270582376, 10.771431541451687, 9.762934254624462, 8.694177771612368, 7.7105582685025915, 6.711473468982817, 5.755301277689248, 4.809204210785265, 4.005779987877827, 2.9520957639733307, 1.9884647153099388, 3.0170041206973854, 3.887449963108894, 4.9616231694495925, 5.924739799418005, 6.862869421407556, 7.860405750622888, 8.79791359035808, 10.680063304004896, 11.711747503298891, 12.611453413687068, 11.571770712807764, 10.607563846344485, 9.673915917635933, 8.684864272360912, 7.742128358738091, 6.776945728631529, 5.843198549090509, 4.859005986522855, 3.8821875184611248, 2.9644373347867807, 3.9436124584559242, 4.957578837783237, 5.914409193730774, 6.904953220588992, 7.824334642158009, 8.801571546696321, 9.742162699976708, 11.627105844605387, 12.582311846102117, 13.57371885970537, 12.57078408315145, 11.545115288174031, 10.607508228458835, 9.700692146456968, 8.667376999523338, 7.787164397533637, 6.820865873512507, 5.9175478946146, 4.904231094514053, 3.96579696882722, 4.937208169541376, 5.987036714571115, 6.873030622568, 7.8478045653635045, 8.87239557658998, 9.73613025922033, 10.716956099477924, 12.62030793272875, 13.59589342891054, 14.577026850390896, 13.513330642323439, 12.537058390469365, 11.658307124058835, 10.628772266871605, 9.613470946239648, 8.770015429587332, 7.756645900473951, 6.866215251836299, 5.941588153094864, 5.0111076146643985, 5.930951004856167, 6.938767785155818, 7.8651304321109645, 8.78063859488075, 9.807015440236542, 10.700248574929493, 11.70560251132331, 13.587514246026892, 14.578181828925649, 15.525792527830783, 14.526693562975916, 13.50593652244794, 12.538197233720966, 11.551537175153687, 10.559979728679748, 9.711831319815596, 8.773293546321014, 7.899394585596133, 6.943716116349146, 5.943201950526384, 6.999111234436516, 7.9090176276926245, 8.851111142988978, 9.74457091270317, 10.676428592981694, 11.639967739975267, 12.631224051718716, 14.516114302131049, 15.512245127503355, 16.478746914947727, 15.564065543845171, 14.537324355814837, 13.520240296420608, 12.556171430349195, 11.628659959920332, 10.701058593457955, 9.736355596670368, 8.885256059415546, 7.845529867008521, 6.8858665895137765, 7.949594970655456, 8.903203693645235, 9.788277234617011, 10.747186962298477, 11.678652644777024, 12.681338903204367, 13.591776263799414, 15.522606346841162, 16.46558029821505, 16.35963483840106, 15.481344151159314, 14.699783807709931, 13.914480079359471, 12.967484821398605, 12.203494760208063, 11.641853540938435, 10.7064580286945, 9.829794919547945, 8.846945849764495, 7.8992028140434805, 8.832755658813042, 9.891905688806888, 10.77420861280137, 11.803389667179097, 12.630346886440265, 13.585263803583388, 14.573183045339341, 16.489237772037598, 16.26350787709683, 15.30195186615203, 14.48314138680872, 13.755822812216532, 12.958541451014725, 12.029667617684366, 11.277225479109342, 11.891412677237744, 11.729291703353386, 10.779101377512559, 9.858307427850411, 8.927159429744147, 9.874128815519532, 10.799329258922997, 11.733912203523605, 12.789566542735042, 13.700961339947323, 14.615033740927654, 15.58483126073116, 16.36355806214419, 15.294012490280338, 14.364044534527396, 13.467045989759441, 12.713581442158208, 11.886763537943974, 11.00915536895096, 10.297036496998189, 10.848701625597572, 11.8657272325156, 11.754484901038742, 10.883808011055075, 9.881562787770475, 10.855804872911776, 11.815412589535697, 12.70668604272278, 13.664984503597399, 14.649531915831213, 15.639987664747252, 16.517293472311415, 15.371116981918426, 14.358191547596688, 13.428577724877009, 12.535748675557494, 11.686237430288777, 10.825971146423536, 10.000799079580325, 9.227332055872898, 9.84088769075466, 10.812245585160726, 11.746703598343688, 11.909685896418665, 10.85649139843872, 11.854931472641653, 12.844317249400452, 13.65018458269617, 14.596297559707665, 15.56654414305442, 16.531530209670645, 16.34528945471257, 14.461348787613414, 13.52628712011979, 12.48912078160539, 11.562825292338712, 10.75104174685172, 9.864808504884326, 8.951225442804944, 8.215358055693628, 8.888188227806893, 9.816965417096954, 10.704504815798686, 11.681542389379029, 11.849562122330981, 12.812387339278622, 13.78311524579765, 14.58771137205603, 15.562436751215499, 16.554994255922292, 16.328510109132093, 15.452731493759865, 13.515499520066143, 12.557466139526216, 11.561917848294284, 10.600126205521999, 9.813601722843782, 8.829357525071709, 7.877848964010598, 7.20579463295255, 7.955202623465686, 8.881862897475456, 9.732666047249994, 10.731941441842999, 11.676837836529337, 12.612630597246595, 13.648411124566229, 14.586103008037657, 15.57117308435842, 16.34560165654776, 15.359254495676506, 14.521624147979265, 12.53206415579611, 11.647429643580566, 10.665367072949511, 9.674356226557151, 8.773155676744139, 7.799050095213739, 6.828595215169426, 6.243465474472021, 6.929899933067009, 7.8743566867214705, 8.777179765279906, 9.71338763541969, 10.746147231281663, 11.617855231514651, 12.633364419545055, 13.648507593148622, 14.547816195586682, 15.447192643296633, 14.406499181663847, 13.47235911741753, 11.601309348277228, 10.722634641670673, 9.700210348688845, 8.716423419157675, 7.743452246025846, 6.849508560625091, 5.869814283901639, 5.18104953563758, 5.947587064881713, 6.985584715698548, 7.839527526268144, 8.841169876136174, 9.746874462128188, 10.586662227983558, 11.600214099746587, 12.656785716021998, 13.584792305747673, 14.428388943440563, 13.4662836646312, 12.540797887650747, 10.622845079181578, 9.675971793783443, 8.699930786958154, 7.784239320798658, 6.7196752083802345, 5.835334373838157, 4.879033185968611, 4.211093951058752, 5.003776401670931, 5.991819211454079, 6.8298778967515865, 7.769716619812583, 8.698285837275177, 9.63873419393237, 10.64510718109874, 11.640067979621904, 12.624599574438454, 13.537231314959428, 12.576427864016487, 11.57658749668499, 9.755204081970309, 8.68179367482975, 7.720617642100469, 6.783702462117018, 5.785738943328592, 4.936607685141857, 3.926490202049183, 3.1460717182007665, 3.9880658665420925, 4.971092990034819, 5.857796018837975, 6.833622752898631, 7.8760411290491295, 8.814033707102174, 9.803999783841567, 10.841522931239554, 11.682124399745502, 12.71433687012296, 11.754208113846191, 10.719393449859028, 8.902080510989586, 7.893179281328674, 6.843206321767457, 5.851010749949821, 4.818147469926707, 3.8671175138827474, 2.9188636140474076, 2.110181645175733, 2.9925827733310664, 4.040392574500803, 4.913212869960968, 5.87016712988582, 6.917591709541309, 7.798776909612871, 8.778768175654, 9.83784605725462, 10.715479664788202, 11.717893273154848, 10.775544368289907, 9.921617744686355], [7.899368642032322, 8.8480889730683, 9.84143130861229, 10.760618114442343, 9.80570095121885, 8.801002636129999, 7.786720733208161, 6.9119700649186715, 5.901774031371356, 4.89589246466277, 3.9323484420382524, 2.905872851752101, 1.941930179111707, 0.9519372804696042, 1.9085368113241818, 2.8795726385808442, 3.9180735729914447, 4.930265532140286, 5.972248630797651, 6.915073191623887, 6.926968994034884, 7.872053088388144, 8.850510295181326, 9.8202200354544, 8.8850666307291, 7.907853417778297, 6.846827529130223, 5.911601797575532, 4.924854790943072, 3.9037387617475217, 2.949633503738742, 2.0200004943374776, 0.981276476364752, 0.0, 1.0385214366946331, 2.0448913180321444, 3.0078516891773774, 4.052833182234883, 5.039452499274984, 5.986378887831004, 7.908152077218831, 8.872708910176957, 9.885341757873256, 10.849113908607364, 9.825293274743819, 8.826823656719808, 7.777609943201792, 6.759569598489064, 5.789743282850492, 4.836914336292424, 3.9248093564910578, 2.9574999402667967, 1.9707022435493742, 1.0221182474766666, 1.9951181373434337, 3.051390117916153, 3.989797106787122, 5.023111452809898, 5.987126327526333, 6.924145438642694, 8.881521294252899, 9.834117985016103, 10.818334651835151, 11.752708017816438, 10.744210730989213, 9.67545424797712, 8.691834744867343, 7.692749945347568, 6.736577754053999, 5.7904806871500165, 4.954922315770168, 3.9012380918656717, 2.93760704320228, 2.068978456444311, 2.93942429885582, 4.013597505196518, 4.943463323053253, 5.8815929450428035, 6.879129274258136, 7.816637113993329, 9.698786827640143, 10.73047102693414, 11.698313600988467, 12.553047189172515, 11.588840322709236, 10.655192394000684, 9.666140748725663, 8.723404835102842, 7.75822220499628, 6.824475025455261, 5.808148314415196, 4.831329846353466, 3.9135796626791217, 2.99558679420285, 4.009553173530163, 4.9663835294776995, 5.92367674422424, 6.8430581657932565, 7.820295070331569, 8.760886223611955, 10.645829368240634, 11.601035369737364, 12.592442383340616, 13.552060559516201, 12.526391764538783, 11.588784704823587, 10.681968622821719, 9.64865347588809, 8.768440873898388, 7.801280211364736, 6.866690222506941, 5.853373422406394, 4.914939296719561, 4.036908313456937, 5.03901105031804, 5.925004958314926, 6.879405280700578, 7.891119100225227, 8.754853782855578, 9.735679623113171, 11.639031456363996, 12.614616952545786, 13.624704978192705, 14.49460711868819, 13.518334866834117, 12.639583600423586, 11.610048743236357, 10.5947474226044, 9.750749114577664, 8.73706023832618, 7.81535757972864, 6.890730480987205, 5.9602499425567395, 5.030651148771729, 6.03846792907138, 6.91710476785789, 7.812239310217823, 8.825738963871789, 9.718972098564741, 10.724326034958558, 12.606237769662139, 13.596905352560896, 14.54451605146603, 15.507970039340668, 14.48721299881269, 13.519473710085718, 12.532813651518438, 11.5412562050445, 10.692565004805928, 9.753707884173242, 8.848536913488475, 7.892858444241487, 6.892344278418725, 6.098811378352077, 7.008717771608186, 7.933085238637393, 8.776171628040242, 9.708029308318766, 10.658691263610516, 11.649947575353965, 13.534837825766296, 14.530968651138602, 15.497470438582976, 15.469267682289289, 14.769177610946759, 13.943492677294213, 12.91942189295261, 12.609936436285084, 11.681472931310182, 10.716769934522596, 9.834398387307887, 8.794672194900862, 7.8350089174061175, 7.092909571189367, 8.024319674157773, 8.870251330265425, 9.778787677635549, 10.710253360114095, 11.700062426839615, 12.610499787434662, 14.541329870476407, 15.484303821850293, 15.378358362036309, 14.500067674794563, 13.71850733134518, 12.93320360299472, 11.986208345033853, 12.789969393962407, 12.622267878790662, 11.686872366546728, 10.778937247440286, 9.796088177656836, 8.848345141935821, 8.050508593720831, 9.013021669319427, 9.856182708449785, 10.834990382516171, 11.661947601777335, 12.616864518920458, 13.604783760676412, 15.507961295672843, 15.28223140073208, 14.32067538978728, 13.501864910443969, 12.774546335851781, 11.977264974649973, 11.048391141319614, 11.863700112863686, 12.758875532796027, 12.709706041205614, 11.7282437054049, 10.807449755742752, 9.876301757636488, 9.096907470693075, 9.965186695913472, 10.81588629917202, 11.854135333223336, 12.732562055284394, 13.646634456264724, 14.616431976068231, 15.382281585779438, 14.312736013915586, 13.382768058162645, 12.48576951339469, 11.732304965793457, 10.905487061579223, 10.027878892586209, 10.883511130752533, 11.716164481155856, 12.733190088073883, 12.703627228931083, 11.832950338947416, 10.830705115662816, 10.07858352808532, 10.981270026526172, 11.788660138371194, 12.746958599245813, 13.731506011479627, 14.671588380084323, 15.548894187648486, 14.389840505553675, 13.376915071231936, 12.447301248512257, 11.554472199192743, 10.704960953924026, 9.844694670058784, 9.019522603215574, 9.813806689627242, 10.708350546312943, 11.67970844071901, 12.63669349557725, 12.858828224311006, 11.805633726331061, 11.077710127815196, 12.010174686390927, 12.732158678344584, 13.67827165535608, 14.648518238702835, 15.61350430531906, 15.364012978347821, 13.480072311248662, 12.545010643755038, 11.507844305240639, 10.58154881597396, 9.76976527048697, 8.883532028519575, 7.969948966440192, 8.801832689447972, 9.755651083365175, 10.684428272655234, 11.594494713032248, 12.571532286612591, 12.798704450223322, 12.119872605900143, 12.948972682788124, 13.669685467704443, 14.644410846863913, 15.636968351570706, 15.347233632767342, 14.471455017395114, 12.534223043701392, 11.576189663161465, 10.580641371929532, 9.618849729157247, 8.83232524647903, 7.848081048706955, 6.896572487645845, 7.792269266706895, 8.822665479023968, 9.749325753033736, 10.622655944483556, 11.62193133907656, 12.5668277337629, 13.15014281319016, 13.900825070625137, 14.650266568620125, 15.624097093945565, 15.364325180183009, 14.377978019311755, 13.540347671614514, 11.550787679431359, 10.666153167215814, 9.68409059658476, 8.6930797501924, 7.791879200379387, 6.817773618848987, 5.847318738804674, 6.829940108226366, 7.79736278862529, 8.741819542279751, 9.667169662513468, 10.603377532653251, 11.636137128515225, 12.599131707879405, 13.614640895909806, 14.629784069513374, 15.443844097498891, 14.465916166931882, 13.425222705299095, 12.49108264105278, 10.620032871912477, 9.741358165305922, 8.718933872324092, 7.735146942792922, 6.762175769661093, 5.868232084260339, 4.888537807536887, 5.870551754971803, 6.824972955888076, 7.862970606704911, 8.788472057000103, 9.822446352500927, 10.728150938492941, 11.567938704348311, 12.581490576111339, 13.63806219238675, 14.480820207659882, 13.447112467075812, 12.485007188266449, 11.559521411285996, 9.641568602816827, 8.694695317418692, 7.718654310593402, 6.802962844433907, 5.738398732015482, 4.854057897473405, 3.8977567096038586, 4.914231957008853, 5.9020923824997045, 6.890135192282852, 7.778822427483545, 8.750993096177336, 9.67956231363993, 10.620010670297123, 11.626383657463494, 12.621344455986657, 13.520627476350663, 12.555954838594676, 11.595151387651736, 10.595311020320239, 8.773927605605557, 7.700517198464998, 6.739341165735716, 5.802425985752266, 4.80446246696384, 3.955331208777105, 2.9452137256844306, 3.900237457395545, 4.886381847370865, 5.869408970863592, 6.806740549569934, 7.814899229263382, 8.857317605413881, 9.795310183466924, 10.785276260206318, 11.822799407604306, 12.663400876110256, 11.815021391155728, 10.77293163748144, 9.738116973494277, 7.920804034624836, 6.911902804963922, 5.861929845402704, 4.869734273585069, 3.836870993561955, 2.885841037517995, 1.9375871376826554, 2.968843564462593, 3.917448711484388, 4.966247718200309, 5.894489346325719, 6.851443606250571, 7.8988681859060605, 8.780053385977622, 9.76004465201875, 10.819122533619371, 11.696756141152955, 10.806758732582084, 9.794267891925156, 8.940341268321605], [6.860847205337689, 7.809567536373667, 8.802909871917656, 9.762702025459227, 10.793258860290779, 9.83952407282463, 8.825242169902793, 7.950491501613305, 6.918386323848885, 5.851541922173211, 4.8639760852359615, 3.83750049494981, 2.873557822309416, 1.8835649236673135, 0.9269653928127358, 1.898001220069398, 2.9365021544799985, 3.9486941136288394, 4.933727194103017, 5.876551754929253, 5.888447557340251, 6.8335316516935105, 7.811988858486692, 8.870526719583323, 9.805680124308623, 8.94637485447293, 7.885348965824857, 6.9501232342701655, 5.963376227637705, 4.942260198442155, 3.988154940433375, 3.058521931032111, 2.019797913059385, 1.0385214366946331, 0.0, 1.0063698813375115, 1.9693302524827443, 3.0143117455402493, 4.00093106258035, 4.94785745113637, 6.869630640524197, 7.834187473482324, 8.846820321178622, 9.844685678036516, 10.814783885597144, 9.865345093414442, 8.816131379896426, 7.798091035183697, 6.828264719545126, 5.875435772987058, 4.963330793185691, 3.99602137696143, 2.940814843186712, 1.9922308471140047, 1.0192309572472376, 2.0573455059657215, 2.951275670092489, 3.984590016115265, 4.9486048908317, 5.88562400194806, 7.842999857558266, 8.79559654832147, 9.779813215140518, 10.729624379512591, 11.738121666339817, 10.713975684671754, 9.730356181561977, 8.731271382042202, 7.775099190748633, 6.82900212384465, 5.9250349154075055, 4.871350691503009, 3.9077196428396177, 3.0116512397297504, 1.9635371187596236, 3.037710325100322, 3.9049418863586203, 4.843071508348171, 5.840607837563503, 6.778115677298696, 8.660265390945511, 9.691949590239506, 10.659792164293833, 11.699474865173137, 12.62736175940387, 11.693713830695318, 10.704662185420297, 9.761926271797476, 8.796743641690913, 7.845602960250677, 6.778260914052534, 5.801442445990803, 4.88369226231646, 3.938259577488289, 3.0336659934339663, 3.9904963493815027, 4.885155307529607, 5.804536729098624, 6.781773633636936, 7.722364786917322, 9.607307931546002, 10.562513933042732, 11.553920946645984, 12.58184614814466, 13.564913201233416, 12.62730614151822, 11.720490059516353, 10.687174912582723, 9.757044664622079, 8.771392811002073, 7.8368028221442785, 6.823486022043731, 5.885051896356899, 4.979581096742376, 4.063123870221844, 4.949117778218729, 5.840883844005945, 6.852597663530595, 7.716332346160946, 8.69715818641854, 10.600510019669365, 11.576095515851154, 12.586183541498073, 13.571049577133351, 14.547321828987425, 13.67810503711822, 12.64857017993099, 11.633268859299033, 10.720861714215001, 9.707172837963517, 8.785470179365978, 7.860843080624543, 6.930362542194077, 5.973323932057168, 5.121260064746244, 5.9412175877616935, 6.773717873523191, 7.787217527177157, 8.68045066187011, 9.685804598263926, 11.567716332967507, 12.558383915866264, 13.505994614771398, 14.517674131896882, 14.849170454480154, 14.141526975606304, 13.571335088213072, 12.579777641739133, 11.662677604443266, 10.723820483810579, 9.818649513125813, 8.862971043878824, 7.862456878056062, 7.041484161637516, 6.091509907283051, 6.957198058541195, 7.73765019134561, 8.669507871624134, 9.620169826915884, 10.611426138659333, 12.496316389071664, 13.49244721444397, 14.458949001888344, 14.487696263777838, 13.817782621113256, 13.159483912906662, 13.841624456465631, 13.648457872979717, 12.65158553094752, 11.686882534159933, 10.804510986945225, 9.7647847945382, 8.805121517043455, 8.035582354474805, 7.107111809832637, 7.894364150169227, 8.740266240940917, 9.671731923419465, 10.661540990144983, 11.57197835074003, 13.502808433781777, 14.445782385155663, 14.39678694352486, 13.518496256283113, 12.767112341511677, 12.147687812560406, 12.908410908546875, 13.712171957475432, 13.592380478428, 12.656984966184066, 11.749049847077623, 10.766200777294173, 9.818457741573159, 8.99318137700627, 8.095813804994291, 8.880295528353585, 9.796468945821537, 10.623426165082705, 11.578343082225828, 12.566262323981782, 14.469439858978212, 14.300659982220632, 13.339103971275831, 12.520293491932518, 11.82315134601828, 11.19174918421566, 11.970593704832636, 12.785902676376711, 13.681078096309049, 13.679818640842951, 12.698356305042237, 11.77756235538009, 10.846414357273826, 9.973179274991802, 9.047978831588336, 9.83999911907582, 10.815613896528703, 11.694040618589764, 12.608113019570094, 13.577910539373601, 14.40071016726799, 13.331164595404138, 12.401196639651197, 11.50419809488324, 10.780909975959956, 10.11997127114491, 10.95008145609923, 11.805713694265558, 12.638367044668877, 13.655392651586904, 13.67373982856842, 12.803062938584754, 11.800817715300154, 10.954855332384046, 10.064062162201036, 10.812772958274994, 11.771071419149614, 12.694848815272818, 13.633066943389693, 14.510372750953856, 13.408269087042227, 12.395343652720488, 11.465729830000809, 10.572900780681294, 9.753565964090525, 9.059178879624472, 9.941725166728595, 10.736009253140267, 11.630553109825964, 12.601911004232031, 13.558896059090273, 13.828940823948344, 12.775746325968399, 11.953981932113923, 11.092966822065792, 11.756271498248385, 12.70238447525988, 13.665173193564076, 14.630159260180301, 14.382441559836373, 12.498500892737216, 11.56343922524359, 10.52627288672919, 9.599977397462512, 8.818370280653468, 8.098016238085263, 8.892151529953216, 9.724035252960997, 10.677853646878198, 11.606630836168257, 12.51669727654527, 13.493734850125614, 13.76881704986066, 12.99614441019887, 12.031764818462989, 12.693798287608244, 13.668523666767713, 14.653623306431948, 14.365662214255895, 13.489883598883667, 11.552651625189943, 10.594618244650016, 9.599069953418084, 8.637278310645799, 7.88093025664553, 7.062565258272644, 7.818775051158869, 8.71447183021992, 9.744868042536991, 10.671528316546759, 11.54485850799658, 12.544133902589584, 13.489030297275923, 14.026414617488886, 12.983617206300002, 13.674379388523926, 14.648209913849364, 14.382753761671562, 13.396406600800308, 12.558776253103067, 10.569216260919912, 9.684581748704367, 8.702519178073313, 7.711508331680952, 6.8404842105458865, 6.032257828414676, 6.769521302317697, 7.7521426717393895, 8.719565352138314, 9.664022105792775, 10.58937222602649, 11.525580096166275, 12.558339692028248, 13.554781165389846, 13.998663911321175, 14.611974803412961, 14.462272678987445, 13.484344748420435, 12.443651286787649, 11.509511222541333, 9.63846145340103, 8.759786746794475, 7.737362453812646, 6.753575524281476, 5.780604351149648, 5.082716293826028, 5.81074037104991, 6.7927543184848265, 7.747175519401099, 8.785173170217934, 9.710674620513126, 10.775642336799807, 11.683800396003383, 12.523588161858752, 13.537140033621782, 14.504112394463071, 13.499248789148435, 12.465541048564365, 11.503435769755002, 10.577949992774549, 8.65999718430538, 7.713123898907245, 6.737082892081956, 5.82139142592246, 4.756827313504036, 4.031027435640816, 4.819959273116882, 5.836434520521876, 6.824294946012728, 7.812337755795875, 8.701024990996569, 9.706642553687777, 10.635211771150372, 11.575660127807565, 12.582033114973935, 13.523587652655767, 12.539056057839217, 11.57438342008323, 10.61357996914029, 9.613739601808792, 7.792356187094111, 6.718945779953552, 5.757769747224271, 4.82085456724082, 3.822891048452394, 2.9737597902656594, 3.867416289197454, 4.8224400209085685, 5.808584410883888, 6.7916115343766155, 7.728943113082957, 8.770548686773823, 9.812967062924322, 10.833831620161558, 11.82379769690095, 12.65634790492831, 11.66548478712714, 10.801515150718958, 9.791360218969993, 8.75654555498283, 6.882282597930202, 5.930331386452475, 4.880358426891258, 3.8881628550736225, 2.855299575050509, 1.9042696190065493, 2.8597897011956785, 3.891046127975616, 4.849076354682097, 5.897875361398018, 6.85013880383616, 7.807093063761012, 8.8545176434165, 9.818574822672256, 10.798566088713383, 11.691860567717603, 10.698840052169839, 9.76823729588745, 8.755746455230522, 7.901819831626971], [5.854477324000177, 6.803197655036154, 7.796539990580143, 8.756332144121714, 9.786888978953266, 10.791587294042117, 9.831612051240304, 8.956861382950816, 7.924756205186398, 6.857911803510723, 5.870345966573474, 4.843870376287322, 3.8799277036469277, 2.8899348050048252, 1.9333352741502474, 1.0655737587724465, 2.0350739698112013, 2.951688655028052, 3.9273573127655057, 4.870181873591742, 4.882077676002739, 5.827161770355998, 6.805618977149179, 7.86415683824581, 8.79931024297111, 9.776523455921913, 8.891718847162368, 7.956493115607676, 6.969746108975215, 5.948630079779665, 4.994524821770885, 4.064891812369622, 3.0261677943968963, 2.0448913180321444, 1.0063698813375115, 0.0, 0.9629603711452329, 2.007941864202738, 2.994561181242839, 3.9414875697988587, 5.863260759186685, 6.827817592144811, 7.840450439841109, 8.838315796699002, 9.808414004259632, 10.764861902421218, 9.822501261233935, 8.804460916521206, 7.8346346008826355, 6.881805654324568, 5.969700674523201, 5.002391258298941, 3.9471847245242238, 2.998600728451516, 2.025600838584749, 1.0509756246282103, 1.9449057887549774, 2.9782201347777537, 3.942235009494189, 4.879254120610549, 6.836629976220754, 7.789226666983958, 8.773443333803007, 9.72325449817508, 10.731751785002306, 11.720345566009263, 10.736726062899486, 9.737641263379711, 8.781469072086143, 7.83537200518216, 6.931404796745017, 5.877720572840521, 4.914089524177129, 4.018021121067261, 2.969907000097135, 2.0659784433336705, 2.8985720050211086, 3.836701627010659, 4.834237956225992, 5.771745795961184, 7.653895509607999, 8.685579708901994, 9.65342228295632, 10.693104983835624, 11.657311850298903, 12.590959779007456, 11.711032066757806, 10.768296153134985, 9.803113523028424, 8.85197284158819, 7.784630795390045, 6.807812327328315, 5.890062143653971, 4.9446294588258, 3.984393034786293, 3.0275626788387564, 3.8787854261920955, 4.798166847761112, 5.775403752299424, 6.7159949055798105, 8.60093805020849, 9.55614405170522, 10.547551065308472, 11.575476266807147, 12.604251478285658, 13.524552089830358, 12.726859940853862, 11.693544793920232, 10.76341454595959, 9.777762692339584, 8.84317270348179, 7.829855903381243, 6.89142177769441, 5.985950978079887, 5.0138509115741705, 3.9861841076759825, 4.834513962668433, 5.846227782193083, 6.709962464823434, 7.6907883050810275, 9.594140138331852, 10.569725634513642, 11.57981366016056, 12.564679695795839, 13.540951947649912, 14.55694178030002, 13.6549400612685, 12.639638740636542, 11.727231595552512, 10.713542719301028, 9.791840060703489, 8.867212961962053, 7.936732423531588, 6.964810356022656, 5.956993575723005, 4.978283917218947, 5.7673479921856785, 6.7808476458396445, 7.674080780532597, 8.679434716926414, 10.561346451629994, 11.552014034528751, 12.499624733433885, 13.51130425055937, 14.016742993183202, 14.924710300205643, 14.577704969550581, 13.586147523076642, 12.669047485780776, 11.73019036514809, 10.825019394463325, 9.869340925216337, 8.868826759393574, 7.911518492651947, 6.9272434182598115, 5.994264387998449, 6.731280310008097, 7.6631379902866215, 8.613799945578371, 9.60505625732182, 11.489946507734151, 12.486077333106458, 13.452579120550832, 13.586268079109043, 12.985355159816304, 13.942667237506, 14.781228481405535, 14.654827754317227, 13.65795541228503, 12.693252415497444, 11.810880868282736, 10.77115467587571, 9.811491398380966, 8.822778607935044, 7.869169884945265, 6.9314304796264805, 7.7338963596034045, 8.665362042081952, 9.65517110880747, 10.565608469402518, 12.496438552444264, 13.43941250381815, 13.495358758856064, 12.617068071614318, 11.934684880214725, 12.930871137159745, 13.848014933486779, 14.718541838812943, 14.597885959364332, 13.662490447120398, 12.709172854852644, 11.726323785069194, 10.71393047523607, 9.780377630466509, 8.857871880106918, 7.91736185781084, 8.790099064484025, 9.617056283745193, 10.571973200888316, 11.55989244264427, 13.4630699776407, 13.399231797551835, 12.437675786607034, 11.618865307263723, 10.990723884721328, 12.007814331460956, 12.91019772977254, 13.792272557714222, 14.687447977646562, 14.685324121779283, 13.658479312817258, 12.613354733986077, 11.682206735879813, 10.735237350104429, 9.810036906700963, 8.877065448533076, 9.80924401519119, 10.687670737252251, 11.601743138232582, 12.571540658036088, 13.499281982599193, 12.429736410735341, 11.4997684549824, 10.602769910214445, 9.948482514663004, 10.936036418390207, 11.889685481039134, 12.812083575603069, 13.64473692600639, 14.661762532924417, 14.62860512173584, 13.63885531719074, 12.63661009390614, 11.716913407496673, 10.826120237313663, 9.84983928773225, 10.807489489951843, 11.688478933935306, 12.62669706205218, 13.504002869616343, 12.50684090237343, 11.493915468051691, 10.564301645332012, 9.671472596012498, 8.921138502793573, 9.907675337979486, 10.881329191668499, 11.742379134477778, 12.636922991163477, 13.608280885569544, 14.565265940427784, 14.66473320255433, 13.611538704574386, 12.71604000722655, 11.817256065631659, 10.79333782770564, 11.739450804717135, 12.658803312226564, 13.623789378842789, 13.481013375167576, 11.597072708068417, 10.662011040574793, 9.624844702060393, 8.698549212793715, 7.9859428193565165, 8.946512696440276, 9.898521411290726, 10.730405134298508, 11.684223528215709, 12.613000717505768, 13.523067157882782, 14.500104731463125, 14.604609428466647, 13.654875962870268, 12.670882293048168, 11.7308646170655, 12.705589996224969, 13.647253425094435, 13.464234029587097, 12.588455414214868, 10.651223440521147, 9.69319005998122, 8.697641768749287, 7.735850125977002, 7.048502795348577, 7.911061716627658, 8.82514493249638, 9.72084171155743, 10.751237923874502, 11.67789819788427, 12.55122838933409, 13.550503783927095, 14.495400178613433, 14.672717062126257, 13.62273468088518, 12.711445717981182, 13.685276243306621, 13.481325577002764, 12.49497841613151, 11.657348068434269, 9.667788076251115, 8.78315356403557, 7.801090993404515, 6.8100801470121555, 6.008056749248934, 6.880754286769689, 7.775891183655209, 8.758512553076901, 9.725935233475825, 10.670391987130285, 11.595742107364002, 12.531949977503785, 13.564709573365759, 14.561151046727359, 14.637781385906354, 13.649041132870217, 13.544573480525095, 12.582916563751636, 11.54222310211885, 10.608083037872534, 8.737033268732233, 7.858358562125678, 6.835934269143849, 5.852147339612679, 4.948176889852696, 5.931212752181041, 6.817110252387422, 7.799124199822338, 8.753545400738611, 9.791543051555447, 10.717044501850637, 11.782012218137318, 12.690170277340895, 13.529958043196265, 14.543509914959294, 13.58641319600072, 12.581549590686086, 11.564112863895566, 10.602007585086204, 9.67652180810575, 7.758568999636583, 6.811695714238447, 5.835654707413158, 4.919963241253663, 3.924399852207084, 4.879523893995829, 5.826329154454394, 6.842804401859388, 7.8306648273502395, 8.818707637133388, 9.70739487233408, 10.71301243502529, 11.641581652487885, 12.582030009145077, 13.58046768586585, 12.585506887342687, 11.621356859376867, 10.672955235414431, 9.71215178447149, 8.712311417139993, 6.890928002425314, 5.817517595284754, 4.856341562555473, 3.9194263825720226, 2.990463587155442, 3.980129671603171, 4.873786170534966, 5.82880990224608, 6.8149542922214, 7.797981415714126, 8.735312994420468, 9.776918568111336, 10.819336944261835, 11.840201501499068, 12.687501170988785, 11.649978023590798, 10.659114905789627, 9.795145269381445, 8.818553388438465, 7.855117370314034, 5.8759127165926905, 4.985329537301999, 3.9789302422224604, 2.986734670404825, 2.0228721137535572, 2.910639500344061, 3.8661595825331903, 4.897416009313128, 5.855446236019609, 6.904245242735531, 7.856508685173672, 8.813462945098525, 9.860887524754014, 10.824944704009766, 11.747659546260328, 10.68549068638009, 9.692470170832326, 8.761867414549938, 7.749376573893009, 6.89544995028946], [4.8915169528549445, 5.840237283890922, 6.833579619434911, 7.793371772976482, 8.823928607808034, 9.828626922896884, 10.794572422385537, 9.919821754096048, 8.88771657633163, 7.820872174655956, 6.833306337718707, 5.806830747432555, 4.84288807479216, 3.852895176150058, 2.89629564529548, 2.0285341299176793, 1.0721135986659684, 1.988728283882819, 2.9643969416202727, 3.907221502446509, 3.919117304857506, 4.864201399210765, 5.842658606003947, 6.901196467100577, 7.8363498718258775, 8.81356308477668, 9.8546792183076, 8.919453486752909, 7.932706480120449, 6.911590450924899, 5.957485192916119, 5.027852183514855, 3.9891281655421293, 3.0078516891773774, 1.9693302524827443, 0.9629603711452329, 0.0, 1.044981493057505, 2.031600810097606, 2.9785271986536257, 4.900300388041453, 5.864857220999578, 6.877490068695876, 7.875355425553769, 8.8454536331144, 9.801901531275986, 10.78546163237917, 9.76742128766644, 8.79759497202787, 7.844766025469801, 6.932661045668435, 5.965351629444174, 4.910145095669456, 3.9615610995967487, 2.9885612097299816, 2.0139359957734433, 0.9819454176097445, 2.0152597636325207, 2.979274638348956, 3.916293749465316, 5.873669605075522, 6.8262662958387255, 7.810482962657773, 8.760294127029846, 9.768791413857072, 10.825672957361927, 11.69968643404472, 10.700601634524945, 9.744429443231377, 8.798332376327394, 7.89436516789025, 6.840680943985753, 5.8770498953223616, 4.980981492212494, 3.9328673712423674, 3.00510310280567, 1.935611633875876, 2.8737412558654265, 3.871277585080759, 4.808785424815952, 6.690935138462766, 7.722619337756762, 8.690461911811088, 9.730144612690392, 10.69435147915367, 11.627999407862223, 12.617051053137244, 11.73125652428022, 10.766073894173658, 9.814933212733422, 8.747591166535278, 7.7707726984735475, 6.853022514799203, 5.907589829971033, 4.923517694258292, 3.9666873383107557, 2.915825055046863, 3.8352064766158795, 4.812443381154192, 5.753034534434578, 7.6379776790632565, 8.593183680559987, 9.58459069416324, 10.612515895661915, 11.641291107140425, 12.561591718685126, 13.601851545534084, 12.656505165065466, 11.726374917104822, 10.740723063484817, 9.806133074627022, 8.792816274526476, 7.854382148839642, 6.94891134922512, 5.893514728265847, 4.846327534318705, 3.8715535915232, 4.88326741104785, 5.747002093678201, 6.727827933935795, 8.63117976718662, 9.606765263368409, 10.616853289015328, 11.601719324650606, 12.57799157650468, 13.593981409154788, 14.608198349348868, 13.602599111781776, 12.690191966697745, 11.67650309044626, 10.692458581510062, 9.726677577722532, 8.796197039292066, 7.750359373210152, 6.742542592910501, 5.763832934406444, 4.804387621040446, 5.817887274694412, 6.711120409387364, 7.716474345781181, 9.598386080484762, 10.589053663383519, 11.536664362288652, 12.548343879414137, 13.569100919942114, 14.536840208669087, 15.523500267236367, 14.549107894221876, 13.632007856926009, 12.693150736293322, 11.664287562177678, 10.70860909293069, 9.708094927107927, 8.642013118450013, 7.6577380440578775, 6.7156445287615245, 5.768319938862865, 6.700177619141389, 7.650839574433139, 8.642095886176588, 10.526986136588919, 11.523116961961225, 12.489618749405599, 12.62330770796381, 13.592434690986703, 14.5497467686764, 15.421588830018347, 15.593297934039404, 14.567625601671562, 13.602922604883975, 12.607276599741569, 11.567550407334544, 10.6078871298398, 9.54415874869812, 8.59055002570834, 7.652810620389556, 6.770935988458172, 7.702401670936719, 8.692210737662238, 9.602648098257285, 11.533478181299031, 12.476452132672918, 12.53239838771083, 11.654107700469085, 12.541764411385124, 13.537950668330144, 14.488375282099591, 15.423781490326437, 15.319266100127408, 14.383870587883473, 13.43055299561572, 12.44770392583227, 11.435310615999146, 10.501757771229585, 9.579252020869994, 8.638741998573916, 7.827138693338793, 8.654095912599958, 9.609012829743081, 10.596932071499037, 12.500109606495467, 12.4362714264066, 11.4747154154618, 10.65590493611849, 11.597803415891725, 12.63241361681558, 13.550558078385352, 14.567647703881383, 15.60456727871575, 15.406704262542359, 14.379859453580334, 13.334734874749152, 12.403586876642889, 11.456617490867504, 10.53141704746404, 9.598445589296151, 8.846283644045958, 9.724710366107017, 10.638782767087347, 11.608580286890856, 12.536321611453959, 11.466776039590107, 10.536808083837165, 9.639809539069212, 10.573081800017626, 11.560635703744829, 12.530045829651947, 13.58745872177023, 14.607697297151622, 15.62472290406965, 15.349985262498915, 14.360235457953817, 13.357990234669217, 12.438293548259749, 11.54750037807674, 10.571219428495326, 9.84452911880661, 10.725518562790072, 11.663736690906948, 12.54104249847111, 11.543880531228195, 10.530955096906457, 9.601341274186778, 8.708512224867265, 9.66011600158044, 10.65485199585666, 11.628505849545673, 12.669954133054725, 13.59988336230871, 14.571241256714776, 15.528226311573018, 15.386113343317406, 14.332918845337462, 13.437420147989625, 12.538636206394735, 11.514717968468716, 10.896249844333184, 11.69584294108133, 12.660829007697554, 12.518053004022342, 10.634112336923184, 9.699050669429559, 8.661884330915159, 7.7355888416484815, 8.724920318143383, 9.789329633504806, 10.825376423035499, 11.693365505443742, 12.647183899360943, 13.575961088651002, 14.486027529028016, 15.46306510260836, 15.325989569229723, 14.376256103633343, 13.392262433811243, 12.452244757828575, 11.862389035841018, 12.684293053949201, 12.50127365844186, 11.625495043069636, 9.688263069375912, 8.730229688835985, 7.734681397604054, 6.772889754831769, 7.832682156989178, 8.83860822829522, 9.788105303641615, 10.683802082702664, 11.714198295019736, 12.640858569029504, 13.514188760479325, 14.51346415507233, 15.458360549758668, 15.394097202889332, 14.344114821648256, 13.432825858744257, 12.842075282922668, 12.518365205857528, 11.532018044986273, 10.694387697289034, 8.704827705105881, 7.820193192890337, 6.838130622259282, 5.847119775866922, 6.898097444022056, 7.837443392018363, 8.738851554800442, 9.721472924222136, 10.68889560462106, 11.63335235827552, 12.558702478509236, 13.49491034864902, 14.527669944510993, 15.524111417872591, 14.65790140407581, 13.615174701982111, 12.581613109379862, 11.619956192606402, 10.579262730973616, 9.6451226667273, 7.774072897586999, 6.895398190980445, 5.872973897998616, 4.889186968467445, 5.888945377928889, 6.887901857429715, 7.780070623532654, 8.762084570967572, 9.716505771883845, 10.75450342270068, 11.68000487299587, 12.74497258928255, 13.653130648486128, 14.492918414341498, 13.641253208980014, 12.623452824855487, 11.618589219540853, 10.601152492750332, 9.63904721394097, 8.713561436960516, 6.795608628491349, 5.848735343093214, 4.872694336267925, 3.95700287010843, 4.887360223352317, 5.842484265141062, 6.789289525599626, 7.80576477300462, 8.793625198495473, 9.78166800827862, 10.670355243479312, 11.675972806170522, 12.604542023633117, 13.54499038029031, 12.617507314720617, 11.622546516197454, 10.658396488231634, 9.709994864269197, 8.749191413326256, 7.74935104599476, 5.9279676312800795, 4.854557224139521, 3.89338119141024, 2.9564660114267896, 3.953423958300675, 4.943090042748404, 5.836746541680198, 6.791770273391313, 7.777914663366633, 8.760941786859359, 9.6982733655657, 10.739878939256569, 11.782297315407067, 12.784977646654538, 11.724540799843552, 10.687017652445565, 9.696154534644394, 8.832184898236212, 7.8555930172932324, 6.892156999168799, 4.912952345447458, 4.022369166156766, 3.0159698710772274, 2.023774299259592, 2.9858324848987903, 3.8735998714892936, 4.829119953678423, 5.86037638045836, 6.8184066071648415, 7.867205613880763, 8.819469056318905, 9.776423316243758, 10.823847895899247, 11.769720849165235, 10.784699175115096, 9.722530315234858, 8.729509799687094, 7.798907043404705, 6.786416202747777, 5.932489579144227], [3.846535459797439, 4.795255790833417, 5.788598126377406, 6.748390279918977, 7.778947114750529, 8.78364542983938, 9.769500684445184, 10.765201479265079, 9.932698069389136, 8.865853667713461, 7.878287830776211, 6.85181224049006, 5.887869567849665, 4.897876669207562, 3.941277138352985, 2.9944396843847554, 1.955938749974155, 0.943746790825314, 1.9194154485627677, 2.862240009389004, 2.874135811800001, 3.8192199061532603, 4.797677112946442, 5.8562149740430725, 6.7913683787683725, 7.768581591719174, 8.829607480367248, 9.764833211921939, 8.977687973177954, 7.9565719439824045, 7.002466685973625, 6.072833676572361, 5.034109658599635, 4.052833182234883, 3.0143117455402493, 2.007941864202738, 1.044981493057505, 0.0, 0.986619317040101, 1.9335457055961207, 3.855318894983948, 4.819875727942073, 5.832508575638371, 6.830373932496264, 7.800472140056893, 8.75692003821848, 9.806133751736496, 10.812402780723945, 9.842576465085374, 8.889747518527306, 7.977642538725941, 7.01033312250168, 5.955126588726961, 5.006542592654254, 4.033542702787487, 3.0589174888309483, 2.020710199049855, 0.9702782705750157, 1.9342931452914511, 2.871312256407811, 4.888312741606365, 5.7812848027812205, 6.765501469600268, 7.715312633972341, 8.723809920799567, 9.780691464304422, 10.763570328323372, 11.74558312758245, 10.789410936288881, 9.843313869384898, 8.939346660947756, 7.885662437043258, 6.9220313883798665, 6.025962985269999, 4.977848864299872, 4.0327687828293906, 2.9632773138995967, 2.025147691910046, 2.9862410045168764, 3.8581663285676506, 5.787420473542157, 6.819104672836152, 7.715544175956915, 8.754185805953846, 9.718392672417124, 10.652040601125677, 11.641092246400698, 12.583828160023518, 11.811055387231162, 10.859914705790926, 9.792572659592782, 8.815754191531052, 7.898004007856708, 6.952571323028538, 5.951183374282013, 4.994353018334476, 3.9434907350705837, 2.986612912660499, 3.9638498171988115, 4.849519869513968, 6.734463014142647, 7.689669015639377, 8.681076029242629, 9.709001230741304, 10.737776442219815, 11.58563291194858, 12.625892738797537, 13.509076800808765, 12.771356410162326, 11.78570455654232, 10.851114567684526, 9.83779776758398, 8.899363641897148, 7.987510419704183, 6.921180408289568, 5.873993214342426, 4.899219271546921, 4.034673847092471, 4.898408529722821, 5.824313269015185, 7.72766510226601, 8.703250598447799, 9.713338624094717, 10.698204659729996, 11.674476911584069, 12.636431807548579, 13.632239542612322, 14.455170747525075, 13.735173459755249, 12.721484583503765, 11.720124261533783, 10.754343257746253, 9.823862719315787, 8.778025053233874, 7.770208272934223, 6.791498614430165, 5.8320533010641675, 4.9692937107390325, 5.862526845431984, 6.81335555693356, 8.694871415564151, 9.685538998462908, 10.633149697368042, 11.644829214493527, 12.665586255021504, 13.621894483390586, 14.585806883437066, 15.401679529965175, 14.676989349983513, 13.738132229350827, 12.6919532422014, 11.736274772954411, 10.735760607131649, 9.669678798473734, 8.685403724081599, 7.743310208785246, 6.795985618886586, 5.914515259456922, 6.8022460104777585, 7.793502322221206, 9.623471471668308, 10.619602297040615, 11.586104084484989, 12.602356654580378, 13.629097842610712, 14.603937546090227, 15.590441138632574, 16.47035976120576, 15.595291281695284, 14.630588284907697, 13.63494227976529, 12.595216087358265, 11.63555280986352, 10.571824428721841, 9.618215705732062, 8.680476300413279, 7.7986016684818935, 6.916739311252252, 7.843617173706858, 8.754054534301904, 10.629963516378421, 11.572937467752308, 11.993101959693359, 12.537932851777269, 13.425589562693307, 14.421775819638327, 15.372200433407775, 16.30760664163462, 16.34693178015113, 15.411536267907195, 14.458218675639442, 13.475369605855992, 12.462976296022868, 11.529423451253306, 10.606917700893716, 9.666407678597638, 8.854804373362516, 7.8684335529154925, 8.791539597071486, 9.779458838827441, 11.596594941574857, 11.89697499838913, 10.93541898744433, 11.539730087426674, 12.481628567199909, 13.516238768123763, 14.434383229693536, 15.451472855189566, 16.488392430023932, 16.43436994256608, 15.407525133604056, 14.362400554772874, 13.43125255666661, 12.484283170891226, 11.55908272748776, 10.626111269319873, 9.873949324069681, 8.939048006422551, 9.821309534415752, 10.79110705421926, 11.835896802150181, 10.927479611572636, 9.997511655819695, 10.523634690377396, 11.45690695132581, 12.444460855053013, 13.41387098096013, 14.471283873078413, 15.535290911480875, 16.589567159267204, 16.377650942522635, 15.387901137977538, 14.385655914692938, 13.46595922828347, 12.57516605810046, 11.598885108519047, 10.872194798830334, 9.939856203105606, 10.846263458235352, 11.723569265799515, 10.828696011991466, 9.991658668888986, 9.062044846169307, 9.59233737617545, 10.543941152888625, 11.538677147164845, 12.512331000853859, 13.55377928436291, 14.564727617506264, 15.536085511912331, 16.49307056677057, 16.413779023341128, 15.360584525361183, 14.465085828013347, 13.566301886418456, 12.542383648492438, 11.880427164743619, 10.910180581396864, 11.875166648013089, 11.73410408850044, 9.817874899646203, 9.097541704134638, 8.122587902897688, 8.619413992956668, 9.608745469451568, 10.673154784812994, 11.709201574343686, 12.658209760641295, 13.612028154558496, 14.540805343848556, 15.45087178422557, 16.427909357805913, 16.353655249253443, 15.403921783657065, 14.419928113834965, 13.479910437852297, 12.846566356251452, 11.898630694264735, 11.561727290267434, 10.795508684507485, 8.872025632098932, 8.060865488165412, 7.195384969586583, 7.656714906139955, 8.716507308297365, 9.722433379603407, 10.752949558839168, 11.648646337900217, 12.67904255021729, 13.605702824227057, 14.479033015676878, 15.478308410269882, 16.42320480495622, 15.52502355844902, 14.475041177207943, 13.507788623813644, 12.521308253708273, 11.578818837683102, 10.592471676811847, 9.754841329114607, 7.8466771448411246, 7.102698502819342, 6.130902228190253, 6.730944927175108, 7.781922595330243, 8.721268543326548, 9.703695809997996, 10.686317179419689, 11.653739859818613, 12.598196613473073, 13.52354673370679, 14.459754603846573, 15.492514199708546, 14.558019846411765, 13.612919911018308, 12.570193208924609, 11.536631616322358, 10.680409824431973, 9.639716362799188, 8.705576298552872, 6.915922337322241, 6.0372476307156875, 5.087392242375583, 5.773012119775632, 6.772770529237075, 7.771727008737901, 8.744914878730208, 9.726928826165125, 10.681350027081399, 11.719347677898234, 12.724986366053376, 13.789954082340056, 14.560045066179208, 13.526826842880672, 12.596271715922512, 11.578471331797985, 10.573607726483349, 9.661606124575902, 8.69950084576654, 7.774015068786087, 5.937458068226592, 4.990584782828456, 4.020078497738571, 4.840828021416616, 5.842708551138889, 6.797832592927634, 7.75413378079718, 8.770609028202173, 9.796266860743158, 10.784309670526305, 11.715336736536818, 12.720954299228024, 13.519347165486677, 12.578898808829484, 11.572525821663113, 10.57756502313995, 9.61341499517413, 8.765376231063312, 7.809645045151829, 6.809804677820331, 4.8957238470648035, 3.9964066638747635, 3.040765352880886, 3.8402911627349763, 4.908772286087247, 5.9815460271205705, 6.881728034737703, 7.836751766448818, 8.822896156424138, 9.805923279916865, 10.743254858623207, 11.78486043231407, 12.74493782293643, 11.739996153597032, 10.679559306786048, 9.642036159388061, 8.65117304158689, 7.7872034051787065, 6.8106115242357275, 5.859913214953523, 3.867970852389953, 2.9773876730992606, 2.0088742495936867, 2.907599450567779, 3.9411808126853622, 4.918581364546799, 5.874101446735928, 6.905357873515865, 7.8633881002223465, 8.912187106938267, 9.864450549376409, 10.82140480930126, 11.71652948366289, 10.72473935610773, 9.739717682057591, 8.677548822177354, 7.6845283066295895, 6.7539255503472, 5.741434709690272, 4.887508086086722], [2.8599161427573385, 3.8086364737933156, 4.801978809337305, 5.7617709628788765, 6.792327797710428, 7.797026112799278, 8.782881367405084, 9.778582162224977, 10.741880141942582, 9.852472984753563, 8.864907147816313, 7.8384315575301615, 6.874488884889767, 5.884495986247664, 4.927896455393086, 3.9810590014248564, 2.942558067014256, 1.930366107865415, 0.9327961315226668, 1.8756206923489032, 1.8875164947599001, 2.8326005891131594, 3.8110577959063408, 4.8695956570029715, 5.8047490617282715, 6.781962274679073, 7.8429881633271465, 8.778213894881837, 9.764960901514298, 8.943191261022506, 7.989086003013725, 7.059452993612461, 6.020728975639735, 5.039452499274983, 4.00093106258035, 2.994561181242839, 2.031600810097606, 0.986619317040101, 0.0, 0.9469263885560198, 2.868699577943847, 3.8332564109019724, 4.8458892585982705, 5.843754615456163, 6.813852823016792, 7.770300721178378, 8.819514434696394, 9.827436372455315, 10.740385211674203, 9.876366835567408, 8.964261855766042, 7.99695243954178, 6.941745905767061, 5.993161909694354, 5.020162019827588, 4.045536805871049, 3.0064903006580264, 1.956058372183187, 0.9920434974667516, 1.88469293936771, 3.901693424566264, 4.7946654857411195, 5.7788821525601675, 6.72869331693224, 7.7371906037594655, 8.79407214726432, 9.77695101128327, 10.776035810803045, 11.721714934951157, 10.829933186425, 9.925965977987856, 8.872281754083359, 7.908650705419967, 7.0125823023101, 5.964468181339973, 5.018548884437562, 3.9490574155077685, 3.010927793518218, 2.0439913566921772, 2.8715470115275497, 4.800801156502056, 5.832485355796051, 6.728924858916814, 7.7675664889137455, 8.731773355377024, 9.665421284085577, 10.654472929360598, 11.597208842983418, 12.579640328882697, 11.846534022831028, 10.779191976632884, 9.802373508571153, 8.88462332489681, 7.939190640068639, 6.936963475890185, 5.980133119942648, 4.929270836678755, 3.972393014268671, 3.063976315568787, 3.862900552473867, 5.747843697102546, 6.703049698599276, 7.694456712202528, 8.722381913701204, 9.751157125179713, 10.59901359490848, 11.639273421757437, 12.522457483768665, 13.49537034420422, 12.772323873582422, 11.837733884724628, 10.82441708462408, 9.885982958937248, 8.973290521312354, 7.90696050989774, 6.859773315950598, 5.884999373155093, 4.935100238590199, 3.9985350280927965, 4.8376939519750835, 6.741045785225909, 7.7166312814076985, 8.726719307054616, 9.711585342689894, 10.687857594543967, 11.649812490508479, 12.645620225572221, 13.468551430484975, 14.426707494859663, 13.708103900543867, 12.705904363141954, 11.740123359354424, 10.809642820923958, 9.763805154842045, 8.755988374542394, 7.777278716038336, 6.817833402672338, 5.869720102236761, 4.96265334380196, 5.826736239893458, 7.708252098524051, 8.698919681422808, 9.646530380327942, 10.658209897453427, 11.678966937981404, 12.635275166350485, 13.599187566396965, 14.415060212925075, 15.368523385087927, 14.702369163785006, 13.642766954547989, 12.687088485301, 11.686574319478238, 10.620492510820323, 9.636217436428188, 8.694123921131835, 7.746799331233175, 6.814941650954651, 5.902372508847734, 6.835081544625387, 8.636852154628208, 9.632982980000515, 10.599484767444888, 11.615737337540278, 12.642478525570612, 13.617318229050127, 14.603821821592474, 15.48374044416566, 16.443496694776222, 15.581401997254286, 14.58575599211188, 13.546029799704854, 12.58636652221011, 11.52263814106843, 10.569029418078651, 9.631290012759868, 8.749415380828482, 7.817165702749981, 6.943743672076834, 7.795633756706085, 9.643344199338319, 10.586318150712206, 11.632970258071355, 12.584937345035005, 13.568328431191038, 14.564514688136057, 15.53703536951123, 16.42691281069078, 17.297745492497718, 16.362349980253782, 15.40903238798603, 14.42618331820258, 13.413790008369457, 12.480237163599895, 11.557731413240305, 10.617221390944227, 9.783382085156422, 8.76885994441322, 7.891666095441462, 8.861097921296079, 10.609975624534755, 10.97926179208872, 11.809828480214989, 12.526349404466776, 13.46824788424001, 14.502858085163865, 15.421002546733638, 16.438092172229666, 17.475011747064034, 17.385183654912666, 16.358338845950644, 15.313214267119463, 14.3820662690132, 13.435096883237815, 12.50989643983435, 11.576924981666462, 10.777956865903112, 9.839474397920279, 8.921436032785728, 9.872746136687898, 10.849277485110083, 10.009766405272225, 10.871921148590355, 11.510254007417497, 12.443526268365911, 13.431080172093115, 14.400490298000232, 15.457903190118515, 16.521910228520976, 17.576186476307303, 17.328464654869226, 16.338714850324127, 15.336469627039527, 14.416772940630059, 13.52597977044705, 12.549698820865636, 11.776202340663765, 10.840282594603334, 9.946389956605326, 10.805208348268152, 9.842076694951368, 9.073945462588576, 9.936454338939967, 10.578956693215552, 11.530560469928727, 12.525296464204947, 13.49895031789396, 14.540398601403012, 15.551346934546366, 16.52270482895243, 17.47968988381067, 17.364592735687715, 16.31139823770777, 15.415899540359936, 14.517115598765045, 13.493197360839027, 12.780853556241347, 11.810606972894591, 11.01512735096189, 10.74748477146034, 8.831255582606104, 8.110922387094538, 8.996997395668348, 9.60603330999677, 10.59536478649167, 11.659774101853095, 12.695820891383788, 13.644829077681397, 14.598647471598598, 15.527424660888657, 16.43749110126567, 17.334494559751956, 16.387093134774595, 15.424267917826954, 14.440274248004854, 13.501750407689224, 12.514375183749824, 11.574849878950642, 10.575107973227333, 9.808889367467385, 7.885406315058832, 7.074246171125311, 8.069794462357242, 8.643334223180057, 9.703126625337466, 10.709052696643509, 11.73956887587927, 12.63526565494032, 13.665661867257391, 14.592322141267159, 15.46565233271698, 16.464927727309984, 15.5126326270721, 14.538404241408918, 13.488421860167842, 12.521169306773542, 11.534688936668172, 10.592199520643, 9.605852359771745, 8.768222012074506, 6.860057827801024, 6.116079185779241, 7.0611002548733115, 7.71756424421521, 8.768541912370345, 9.70788786036665, 10.690315127038097, 11.67293649645979, 12.640359176858714, 13.584815930513175, 14.510166050746891, 15.446373920886675, 14.581942021824425, 13.571400529371664, 12.626300593978206, 11.583573891884507, 10.550012299282256, 9.693790507391872, 8.653097045759088, 7.718956981512772, 5.92930302028214, 5.0506283136755865, 6.017590269058641, 6.7596314368157335, 7.759389846277177, 8.758346325778003, 9.73153419577031, 10.713548143205227, 11.6679693441215, 12.705966994938336, 13.711605683093477, 14.530954576709435, 13.573425749139107, 12.54020752584057, 11.60965239888241, 10.591852014757883, 9.586988409443247, 8.674986807535802, 7.71288152872644, 6.787395751745987, 4.950838751186491, 4.003965465788355, 4.950276524421629, 5.827447338456718, 6.829327868178991, 7.784451909967736, 8.740753097837281, 9.757228345242275, 10.78288617778326, 11.770928987566407, 12.70195605357692, 13.46129706590917, 12.532727848446575, 11.592279491789382, 10.585906504623011, 9.590945706099848, 8.626795678134028, 7.778756914023212, 6.823025728111729, 5.823185360780231, 3.9091045300247025, 3.0097873468346625, 3.970963379563944, 4.826910479775077, 5.895391603127349, 6.968165344160672, 7.868347351777804, 8.823371083488919, 9.80951547346424, 10.792542596956967, 11.729874175663308, 12.691741842327266, 11.758318505896328, 10.75337683655693, 9.692939989745947, 8.65541684234796, 7.6645537245467885, 6.8005840881386055, 5.8239922071956265, 4.873293897913422, 2.881351535349852, 1.9907683560591596, 2.9954935666337876, 3.89421876760788, 4.927800129725464, 5.9052006815869, 6.860720763776029, 7.891977190555966, 8.850007417262448, 9.89880642397837, 10.85106986641651, 11.728286219314455, 10.729910166622789, 9.738120039067628, 8.75309836501749, 7.690929505137252, 6.697908989589488, 5.7673062333070995, 4.754815392650171, 3.900888769046621], [1.9129897542013183, 2.861710085237296, 3.8550524207812846, 4.814844574322856, 5.845401409154408, 6.850099724243258, 7.835954978849064, 8.831655773668958, 9.794953753386563, 10.799399373309583, 9.811833536372333, 8.785357946086181, 7.821415273445787, 6.831422374803684, 5.874822843949106, 4.927985389980876, 3.8894844555702757, 2.877292496421435, 1.8797225200786867, 0.9286943037928834, 0.9405901062038803, 1.8856742005571396, 2.864131407350321, 3.9226692684469517, 4.857822673172252, 5.835035886123054, 6.896061774771127, 7.831287506325818, 8.81803451295828, 9.83915054215383, 8.936012391569747, 8.006379382168483, 6.967655364195756, 5.986378887831004, 4.94785745113637, 3.9414875697988587, 2.9785271986536257, 1.9335457055961207, 0.9469263885560198, 0.0, 1.9217731893878267, 2.8863300223459527, 3.8989628700422507, 4.896828226900143, 5.8669264344607726, 6.823374332622358, 7.8725880461403746, 8.880509983899296, 9.793458823118184, 10.746287769676252, 9.911188244322064, 8.943878828097802, 7.888672294323082, 6.940088298250375, 5.967088408383607, 4.992463194427069, 3.953416689214046, 2.9029847607392067, 1.9389698860227713, 0.9377665508116902, 2.9547670360102436, 3.8477390971850998, 4.831955764004148, 5.7817669283762205, 6.790264215203446, 7.847145758708299, 8.830024622727251, 9.829109422247026, 10.774788546395138, 11.699854120533844, 10.872892366543876, 9.81920814263938, 8.855577093975988, 7.9595086908661195, 6.911394569895993, 5.867285882841399, 4.797794413911605, 3.8596647919220546, 2.862128462706722, 1.9246206229715297, 3.8538747679460355, 4.885558967240032, 5.7819984703607945, 6.820640100357726, 7.784846966821004, 8.718494895529556, 9.707546540804577, 10.650282454427398, 11.632713940326676, 12.664213911927742, 11.726118365188903, 10.749299897127173, 9.83154971345283, 8.849109359469306, 7.785700474294021, 6.828870118346485, 5.778007835082592, 4.821130012672508, 3.8565653171982337, 2.915974163917847, 4.800917308546526, 5.7561233100432565, 6.747530323646508, 7.775455525145183, 8.804230736623694, 9.652087206352459, 10.692347033201417, 11.575531095212645, 12.5484439556482, 13.534095809268205, 12.784660273280647, 11.771343473180101, 10.793438720430347, 9.82202751971619, 8.755697508301576, 7.7085103143544345, 6.73373637155893, 5.727689240219646, 4.791124029722243, 3.890767563419064, 5.794119396669889, 6.769704892851678, 7.779792918498596, 8.764658954133875, 9.740931205987948, 10.702886101952458, 11.6986938370162, 12.521625041928955, 13.479781106303642, 14.46987583622965, 13.554641361545793, 12.588860357758263, 11.658379819327797, 10.612542153245883, 9.604725372946232, 8.626015714442174, 7.666570401076175, 6.662309103866208, 5.755242345431406, 4.8798098513374395, 6.761325709968031, 7.751993292866787, 8.699603991771921, 9.711283508897406, 10.732040549425383, 11.688348777794465, 12.652261177840945, 13.468133824369055, 14.421596996531907, 15.388799466074447, 14.435355956177435, 13.479677486930447, 12.479163321107684, 11.41308151244977, 10.428806438057634, 9.486712922761281, 8.539388332862622, 7.6075306525840976, 6.694961510477181, 5.888155156069368, 7.6899257660721885, 8.686056591444494, 9.652558378888868, 10.668810948984257, 11.695552137014591, 12.670391840494107, 13.656895433036453, 14.53681405560964, 15.496570306220201, 16.3518615164238, 15.378344993741326, 14.3386188013343, 13.378955523839556, 12.315227142697877, 11.361618419708098, 10.423879014389314, 9.542004382457929, 8.609754704379426, 7.73633267370628, 6.848707368150066, 8.6964178107823, 9.639391762156187, 10.686043869515336, 11.638010956478983, 12.621402042635015, 13.617588299580035, 14.59010898095521, 15.479986422134761, 16.44978811404806, 17.15493898188323, 16.20162138961548, 15.218772319832027, 14.206379009998903, 13.272826165229342, 12.350320414869751, 11.409810392573673, 10.575971086785868, 9.561448946042667, 8.684255097070908, 7.91417153274006, 9.663049235978736, 10.613210985361741, 11.594183847424514, 12.601970293896557, 13.543868773669791, 14.573526927924782, 15.519171553688652, 16.40625570323348, 17.428947863342778, 18.177772656542114, 17.150927847580093, 16.10580326874891, 15.174655270642646, 14.227685884867261, 13.302485441463796, 12.369513983295908, 11.570545867532559, 10.632063399549725, 9.714025034415174, 8.925819748131879, 9.904220084597828, 10.74627194983215, 11.675531639518567, 12.45718039597352, 13.390452656921934, 14.378006560649137, 15.347416686556254, 16.404829578674537, 17.468836617077, 18.52311286486332, 18.121053656498674, 17.131303851953575, 16.12905862866897, 15.209361942259505, 14.318568772076496, 13.342287822495082, 12.568791342293212, 11.63287159623278, 10.738978958234775, 9.858281959712134, 8.897019294439113, 9.810451007148501, 10.74006482986818, 11.525883081771573, 12.477486858484747, 13.472222852760968, 14.445876706449981, 15.487324989959033, 16.498273323102385, 17.46963121750845, 18.426616272366694, 17.435201157774237, 16.433237470110832, 15.425770718742184, 14.432145855846029, 13.479700963713134, 12.533587986701638, 11.600868431741162, 10.635882365124937, 9.800558382904319, 7.88619818209385, 8.847427931654464, 9.821133519629543, 10.55295969855279, 11.54229117504769, 12.606700490409114, 13.642747279939806, 14.591755466237416, 15.545573860154617, 16.474351049444675, 17.384417489821693, 16.387568171195934, 15.440166746218573, 14.477341529270932, 13.493347859448832, 12.554824019133202, 11.567448795193805, 10.627923490394624, 9.628181584671314, 8.861962978911365, 6.940348914546578, 7.898382295086504, 8.893930586318437, 9.590260611736078, 10.650053013893487, 11.65597908519953, 12.686495264435289, 13.582192043496338, 14.61258825581341, 15.539248529823178, 16.412578721273, 15.521396721748777, 14.565706238516078, 13.591477852852895, 12.54149547161182, 11.57424291821752, 10.587762548112153, 9.645273132086981, 8.658925971215726, 7.821295623518486, 5.91500042728877, 6.982702718977378, 7.964765289608433, 8.66449063277123, 9.715468300926364, 10.65481424892267, 11.637241515594116, 12.61986288501581, 13.587285565414733, 14.531742319069194, 15.45709243930291, 14.58781510105505, 13.635015633268404, 12.624474140815643, 11.679374205422183, 10.636647503328485, 9.603085910726234, 8.746864118835852, 7.706170657203067, 6.772030592956751, 4.984245619769887, 5.997554702231607, 6.964516657614662, 7.706557825371752, 8.706316234833196, 9.705272714334022, 10.678460584326329, 11.660474531761245, 12.61489573267752, 13.652893383494355, 14.54478412005056, 13.584028188153415, 12.626499360583086, 11.59328113728455, 10.662726010326388, 9.64492562620186, 8.640062020887225, 7.728060418979782, 6.765955140170419, 5.840469363189967, 4.005781350674237, 4.950891854344376, 5.89720291297765, 6.774373727012737, 7.77625425673501, 8.731378298523754, 9.6876794863933, 10.704154733798294, 11.729812566339278, 12.717855376122426, 13.535134490534002, 12.51437067735315, 11.585801459890554, 10.645353103233361, 9.63898011606699, 8.644019317543828, 7.679869289578007, 6.8318305254671925, 5.876099339555708, 4.8762589722242105, 2.9621781414686823, 3.956713735390683, 4.917889768119965, 5.773836868331097, 6.842317991683368, 7.915091732716691, 8.815273740333824, 9.770297472044938, 10.756441862020258, 11.739468985512985, 12.676800564219327, 11.744815453771247, 10.811392117340308, 9.80645044800091, 8.746013601189926, 7.7084904537919385, 6.717627335990768, 5.853657699582586, 4.877065818639607, 3.926367509357402, 1.934425146793832, 2.9376947446151798, 3.9424199551898074, 4.8411451561639, 5.8747265182814825, 6.852127070142919, 7.8076471523320485, 8.838903579111985, 9.796933805818469, 10.84573281253439, 11.73831409068329, 10.781359830758436, 9.782983778066768, 8.791193650511607, 7.806171976461468, 6.744003116581231, 5.750982601033467, 4.82037984475108, 3.807889004094151, 2.9539623804906014], [1.9901209112601328, 2.9388412422961103, 3.932183577840099, 4.89197573138167, 5.922532566213222, 6.927230881302073, 7.913086135907879, 8.908786930727773, 9.872084910445377, 10.908435402127893, 11.73360672576016, 10.707131135474008, 9.743188462833613, 8.753195564191511, 7.796596033336933, 6.849758579368703, 5.811257644958102, 4.7990656858092615, 3.801495709466513, 2.85046749318071, 1.0177212632626946, 1.962805357615954, 2.9412625644091355, 3.999800425505766, 4.934953830231066, 5.912167043181868, 6.973192931829941, 7.908418663384633, 8.895165670017093, 9.916281699212643, 10.857785580957572, 9.928152571556307, 8.889428553583581, 7.90815207721883, 6.869630640524197, 5.863260759186685, 4.900300388041453, 3.8553188949839474, 2.8686995779438464, 1.9217731893878267, 0.0, 1.0407066143735566, 2.076535897612031, 3.074401254469924, 4.138630187876073, 5.137099805900084, 6.1863135194181, 7.2043538641308285, 8.1741801797694, 9.127009126327467, 10.134455843815562, 9.155047437695172, 8.097611459467046, 7.149027463394338, 6.176027573527572, 5.119755592954853, 4.0618718078873925, 3.0114398794125536, 2.047425004696118, 0.9840066385761366, 1.032993846622417, 2.0021156892127037, 2.9863323560317516, 3.9361435204038244, 4.94464080723105, 6.013397290243143, 6.99701679335292, 7.996101592872694, 8.952273784166263, 9.898370851070245, 10.944244861952141, 10.028147307783343, 9.064516259119952, 8.03581329791667, 6.987699176946543, 5.9135259706058445, 4.844034501676051, 3.9059048796865006, 2.908368550471168, 1.970860710735976, 1.9780171468879213, 3.009701346181917, 3.9363750623883984, 4.97501669238533, 5.9392235588486075, 6.872871487557161, 7.861923132832182, 8.804659046455003, 9.78709053235428, 10.818590503955349, 11.885472340153228, 10.913141928762398, 9.920173874384734, 8.895349447233752, 7.831940562058467, 6.87511020611093, 5.824247922847038, 4.833745808734808, 3.856508904196496, 2.9159177509161096, 2.925059687488412, 3.8802656889851423, 4.871672702588394, 5.89959790408707, 6.92837311556558, 7.806463798380063, 8.846723625229021, 9.72990768724025, 10.702820547675804, 11.68847240129581, 12.623062390153605, 11.883770649949144, 10.8132401962388, 9.841828995524644, 8.775498984110028, 7.728311790162886, 6.753537847367381, 5.727632827217908, 4.791067616720506, 3.8556877981993303, 3.9182617756117755, 4.893847271793565, 5.903935297440482, 6.888801333075761, 7.865073584929833, 8.857262693980063, 9.853070429043806, 10.67600163395656, 11.634157698331247, 12.624252428257254, 13.571729747375304, 12.608661833566714, 11.678181295136248, 10.632343629054334, 9.624526848754684, 8.645817190250625, 7.6863718768846265, 6.66225269086447, 5.755185932429669, 4.844730086117705, 4.885468088909917, 5.876135671808673, 6.823746370713806, 7.835425887839291, 8.856182928367268, 9.82392221709424, 10.80663776986855, 11.62251041639666, 12.575973588559512, 13.543176058102052, 14.435299543175697, 13.479621073928708, 12.479106908105946, 11.413025099448031, 10.428750025055896, 9.486656509759543, 8.539331919860883, 7.60747423958236, 6.694905097475443, 5.853075390849634, 5.814068145014074, 6.810198970386381, 7.776700757830753, 8.792953327926142, 9.819694515956476, 10.805965279793883, 11.811272025064058, 12.691190647637244, 13.650946898247806, 14.506238108451406, 15.378288580739587, 14.338562388332562, 13.378899110837818, 12.315170729696138, 11.36156200670636, 10.423822601387576, 9.54194796945619, 8.60969829137769, 7.7362762607045426, 6.813627602930332, 6.820560189724186, 7.763534141098073, 8.81018624845722, 9.76215333542087, 10.745544421576902, 11.741730678521922, 12.744485572982814, 13.634363014162364, 14.604164706075663, 15.476340540475539, 16.20156497661374, 15.218715906830289, 14.206322596997165, 13.272769752227603, 12.350264001868013, 11.409753979571935, 10.575914673784132, 9.56139253304093, 8.684198684069171, 7.879091767520325, 7.787191614920623, 8.737353364303628, 9.7183262263664, 10.726112672838443, 11.668011152611678, 12.697669306866668, 13.643313932630539, 14.560632295261085, 15.583324455370379, 16.499174215134424, 17.150871434578352, 16.10574685574717, 15.174598857640907, 14.227629471865523, 13.302429028462058, 12.36945757029417, 11.570489454530822, 10.632006986547989, 9.713968621413438, 8.81207982148857, 8.741764709272083, 9.706848751120122, 10.656233557991035, 11.61591633128619, 12.549188592234604, 13.536742495961807, 14.506152621868925, 15.540821277372238, 16.6048283157747, 17.490094715849995, 18.120997243496934, 17.131247438951835, 16.129002215667235, 15.209305529257767, 14.318512359074758, 13.342231409493344, 12.568734929291475, 11.632815183231044, 10.738922545233038, 9.744542033068825, 9.748965499430799, 10.642669693803771, 11.57228351652345, 12.547213645488135, 13.52490769829917, 14.519643692575391, 15.493297546264404, 16.534745829773456, 17.57189888802634, 18.543256782432405, 18.51062392498581, 17.512332314833053, 16.510368627169647, 15.502901875801, 14.509277012904844, 13.569481965551876, 12.649399395146274, 11.76273050595417, 10.797744439337945, 9.962420457117327, 9.807971371481678, 10.769201121042292, 11.74290670901737, 12.474732887940617, 13.464064364435517, 14.528473679796942, 15.564520469327634, 16.51352865562524, 17.467347049542447, 18.396124238832503, 17.47425643702522, 16.46469932825475, 15.517297903277388, 14.554472686329747, 13.570479016507647, 12.631955176192017, 11.68326020363844, 10.789785564607632, 9.790043658884322, 9.023825053124373, 8.862122103934405, 9.820155484474332, 10.815703775706265, 11.512033801123904, 12.571826203281313, 13.577752274587356, 14.608268453823115, 15.503965232884164, 16.534361445201238, 17.461021719211004, 16.515053798091227, 15.598527878807593, 14.642837395574894, 13.66860900991171, 12.618626628670635, 11.651374075276335, 10.703573956556788, 9.80713520629999, 8.820788045428735, 7.983157697731494, 7.836773616676597, 8.904475908365205, 9.88653847899626, 10.586263822159056, 11.63724149031419, 12.576587438310497, 13.559014704981943, 14.541636074403636, 15.50905875480256, 16.45351550845702, 15.559567516121136, 14.664946258113865, 13.71214679032722, 12.701605297874458, 11.756505362480999, 10.7137786603873, 9.68021706778505, 8.907781783806314, 7.868032731416076, 6.93389266716976, 6.906018809157714, 7.919327891619433, 8.886289847002487, 9.62833101475958, 10.628089424221024, 11.62704590372185, 12.600233773714155, 13.582247721149072, 14.536668922065346, 15.57466657288218, 14.621915277109375, 13.66115934521223, 12.703630517641901, 11.670412294343365, 10.739857167385203, 9.722056783260676, 8.71719317794604, 7.888978083950245, 6.927817214383428, 6.002331437402975, 5.927554540062064, 6.872665043732202, 7.818976102365476, 8.696146916400563, 9.698027446122836, 10.65315148791158, 11.609452675781126, 12.62592792318612, 13.651585755727105, 14.543424015394702, 13.612265647592817, 12.591501834411964, 11.66293261694937, 10.722484260292177, 9.716111273125806, 8.721150474602643, 7.757000446636822, 6.908961682526007, 6.021080533146213, 5.038121046437219, 4.883951330856509, 5.878486924778509, 6.839662957507791, 7.695610057718923, 8.764091181071194, 9.836864922104517, 10.73704692972165, 11.692070661432764, 12.678215051408085, 13.661242174900812, 12.760028396619107, 11.82194661083006, 10.888523274399123, 9.883581605059724, 8.823144758248741, 7.785621610850754, 6.794758493049583, 5.9307888566414, 4.954196975698421, 4.08822958357041, 3.8561983361816585, 4.859467934003006, 5.864193144577634, 6.762918345551726, 7.796499707669309, 8.773900259530746, 9.729420341719875, 10.760676768499813, 11.718706995206295, 12.767506001922216, 11.815445247742101, 10.85849098781725, 9.860114935125583, 8.868324807570422, 7.8833031335202834, 6.821134273640046, 5.828113758092282, 4.897511001809894, 3.8850201611529656, 3.0648728357206187], [2.9181395641395103, 1.9766917064689689, 2.9700340420129576, 3.929826195554529, 4.960383030386081, 5.965081345474932, 6.9509366000807375, 7.946637394900632, 8.909935374618236, 9.946285866300752, 10.933851703238002, 11.671687968432131, 10.707745295791737, 9.717752397149635, 8.761152866295058, 7.814315412326828, 6.775814477916228, 5.763622518767387, 4.76605254242464, 3.815024326138836, 1.9457399161420723, 1.0006558217888128, 1.9791130285819944, 3.037650889678625, 3.9728042944039252, 4.950017507354727, 6.0110433960028, 6.946269127557492, 7.933016134189952, 8.954132163385502, 9.908237421394283, 10.837870430795547, 9.853985386541707, 8.872708910176955, 7.834187473482323, 6.827817592144811, 5.864857220999578, 4.819875727942073, 3.8332564109019724, 2.8863300223459527, 1.0407066143735566, 0.0, 1.0358292832384746, 2.0336946400963676, 3.0979235735025163, 4.096393191526527, 5.145606905044543, 6.163647249757272, 7.133473565395843, 8.086302511953912, 9.127047652729027, 10.106456058849417, 9.138318073840605, 8.189734077767897, 7.21673418790113, 6.160462207328411, 5.102578422260951, 4.052146493786111, 3.0881316190696753, 2.0247132529496934, 1.999817227537124, 0.9614090748391471, 1.945625741658195, 2.895436906030268, 3.903934192857493, 4.972690675869586, 5.956310178979363, 6.955394978499138, 7.911567169792706, 8.857664236696689, 9.903538247578584, 10.957222471483082, 10.10522287349351, 9.076519912290227, 8.0284057913201, 6.954232584979402, 5.884741116049608, 4.946611494060058, 3.949075164844725, 3.011567325109533, 2.9448405278026284, 1.999584007098235, 2.895668448014842, 3.934310078011773, 4.898516944475051, 5.832164873183604, 6.821216518458625, 7.763952432081445, 8.746383917980724, 9.77788388958179, 10.844765725779672, 11.821584193841403, 10.940316443787001, 9.91549201663602, 8.852083131460734, 7.895252775513198, 6.827555043939947, 5.800569189649515, 4.823332285111203, 3.8827411318308167, 3.8918830684031187, 2.9990935071504086, 3.9423667769572175, 4.933323448355459, 5.962098659833969, 6.765757184006507, 7.806017010855465, 8.689201072866693, 9.662113933302248, 10.647765786922253, 11.582355775780048, 12.608801853601978, 11.780063577153507, 10.808652376439351, 9.742322365024735, 8.695135171077593, 7.720361228282088, 6.694456208132615, 5.757890997635212, 4.822511179114037, 4.885085156526482, 4.012834046022579, 4.974629371809305, 5.92252687734415, 6.898799129198222, 7.816556079606507, 8.812363814670249, 9.635295019583003, 10.59345108395769, 11.583545813883697, 12.531023133001748, 13.496804136789278, 12.645004676050956, 11.599167009969042, 10.591350229669391, 9.612640571165333, 8.653195257799334, 7.629076071779177, 6.722009313344375, 5.811553467032412, 5.852291469824624, 5.023895966660896, 5.965780372128632, 6.946619974896669, 7.954465758181079, 8.802018755448513, 9.765931155494993, 10.581803802023103, 11.535266974185955, 12.502469443728495, 13.562071652965512, 14.446444454843416, 13.445930289020653, 12.379848480362739, 11.395573405970604, 10.45347989067425, 9.50615530077559, 8.574297620497067, 7.66172847839015, 6.819898771764341, 6.780891525928781, 6.096829935582481, 6.918734759245579, 7.934987329340968, 8.961728517371302, 9.784061818148155, 10.770565410690502, 11.650484033263687, 12.61024028387425, 13.46553149407785, 14.461177499220256, 15.30538576924727, 14.345722491752525, 13.281994110610846, 12.328385387621067, 11.390645982302283, 10.508771350370898, 9.576521672292397, 8.70309964161925, 7.780450983845038, 7.787383570638893, 7.071020176088493, 7.953853994423922, 8.904187336835694, 9.887578422991727, 10.795857918494411, 11.703778958609258, 12.59365639978881, 13.563458091702108, 14.435633926101982, 15.388951518369735, 16.185539287744998, 15.173145977911872, 14.23959313314231, 13.31708738278272, 12.376577360486642, 11.54273805469884, 10.528215913955638, 9.651022064983879, 8.845915148435031, 8.754014995835329, 8.139928559111231, 9.011536966672951, 9.902390101186288, 10.831539418485125, 11.751796546839158, 12.641596162323497, 13.51992568088753, 14.542617840996824, 15.458467600760867, 16.33825797633435, 17.072570236661882, 16.141422238555617, 15.19445285278023, 14.269252409376765, 13.336280951208877, 12.53731283544553, 11.598830367462696, 10.680792002328145, 9.778903202403276, 9.708588090186788, 9.109423945927725, 9.949444298297585, 10.90912707159274, 11.842399332541156, 12.823574459909906, 13.662108411056902, 14.500114662998683, 15.564121701401145, 16.44938810147644, 17.313641499860534, 17.592200748336158, 16.523147702010753, 15.539878939703735, 14.530058584384584, 13.550830969698126, 12.738970584845706, 11.903947833059942, 11.037374782509023, 10.71136541398353, 10.715788880345503, 10.045244888611375, 10.884911107947973, 11.840424385794687, 12.818118438605723, 13.812854432881943, 14.670464700427537, 15.569819104123974, 16.57193563624406, 17.502869748831312, 17.54847438915867, 16.55018277900591, 15.548219091342508, 14.540752339973858, 13.547127477077703, 12.607332429724735, 11.687249859319133, 10.933623454768684, 9.968637388152459, 10.798518199691612, 10.706885969592907, 11.008267964105412, 11.824368051219592, 12.766107512659229, 13.753314122042779, 14.774017074421153, 15.720038337202919, 16.581793104303244, 17.524635099191826, 17.465376830903192, 16.512106901198077, 15.502549792427608, 14.555148367450247, 13.592323150502606, 12.608329480680506, 11.669805640364876, 10.721110667811299, 9.960678513422145, 8.960936607698835, 9.859922795698658, 9.761036702045637, 10.719070082585564, 11.714618373817496, 12.47659063408203, 13.536383036239439, 14.542309107545481, 15.57282528678124, 16.46852206584229, 17.49252754458085, 16.530274311281694, 15.55290426226408, 14.63637834298045, 13.680687859747751, 12.70645947408457, 11.656477092843494, 10.689224539449194, 9.741424420729647, 8.978028155114503, 7.991680994243248, 8.81925544030578, 8.735688214787828, 9.803390506476436, 10.78545307710749, 11.550820655117182, 12.601798323272316, 13.541144271268623, 14.523571537940068, 15.506192907361761, 16.46722485418217, 15.522768100527708, 14.597417980293992, 13.702796722286722, 12.749997254500077, 11.739455762047315, 10.794355826653858, 9.751629124560159, 8.718067531957908, 7.945632247979173, 7.03892568023059, 7.769990409744045, 7.806425475610564, 8.821497339800281, 9.828180010551986, 10.592887847717705, 11.59264625717915, 12.591602736679976, 13.56479060667228, 14.546804554107197, 15.501225755023471, 14.61274004025431, 13.65976574128223, 12.699009809385087, 11.741480981814759, 10.708262758516222, 9.777707631558062, 8.759907247433535, 7.755043642118899, 6.926828548123103, 6.024616210055252, 6.83842917997726, 6.827961206514915, 7.77483449191305, 8.760866265914974, 9.660703749358689, 10.662584279080962, 11.617708320869706, 12.574009508739252, 13.590484756144246, 14.569317289350705, 13.581274479567558, 12.650116111765673, 11.629352298584822, 10.700783081122227, 9.760334724465034, 8.753961737298663, 7.7590009387755, 6.79485091080968, 5.946812146698865, 5.058930997319071, 5.874218789011504, 5.8485081638146355, 6.843043757736636, 7.804219790465917, 8.660166890677049, 9.72864801402932, 10.801421755062643, 11.701603762679776, 12.65662749439089, 13.64277188436621, 12.735210439498308, 11.797878860791966, 10.85979707500292, 9.92637373857198, 8.921432069232583, 7.860995222421598, 6.823472075023612, 5.832608957222441, 4.968639320814258, 3.9920474398712793, 4.924327326144696, 4.820755169139785, 5.8240247669611325, 6.828749977535759, 7.727475178509851, 8.761056540627434, 9.738457092488872, 10.693977174678, 11.725233601457937, 12.683263828164419, 11.892843215123108, 10.85329571191496, 9.896341451990109, 8.89796539929844, 7.9061752717432805, 6.9211535976931415, 5.8589847378129045, 4.8659642222651405, 3.9353614659827523, 2.9228706253258236, 3.9009705782949053], [3.9307724118358087, 2.9893245541652673, 2.0656377737007716, 2.967157308998801, 3.949491370718314, 4.954189685807164, 5.94004494041297, 6.935745735232864, 7.899043714950469, 8.935394206632985, 9.922960043570235, 10.769261666753835, 11.720378143488036, 10.730385244845934, 9.773785713991357, 8.826948260023126, 7.788447325612526, 6.776255366463685, 5.778685390120938, 4.827657173835134, 2.9583727638383706, 2.013288669485111, 1.0348314626919297, 2.0267592300108577, 2.9619126347361577, 3.9391258476869595, 5.000151736335033, 5.935377467889724, 6.922124474522185, 7.943240503717735, 8.897345761726516, 9.82697877112778, 10.865702789100506, 9.885341757873254, 8.84682032117862, 7.840450439841109, 6.877490068695876, 5.832508575638371, 4.8458892585982705, 3.8989628700422507, 2.076535897612031, 1.0358292832384746, 0.0, 0.9978653568578928, 2.062094290264042, 3.060563908288053, 4.109777621806069, 5.127817966518798, 6.097644282157369, 7.050473228715437, 8.091218369490552, 9.070626775610942, 10.128062753839068, 9.22556336100637, 8.252563471139604, 7.196291490566885, 6.138407705499425, 5.087975777024585, 4.123960902308149, 3.0605425361881675, 3.0356465107755985, 1.9972383580776216, 1.0491251624643192, 1.9603759808501802, 2.9688732676774054, 4.037629750689499, 5.021249253799276, 6.020334053319051, 6.976506244612619, 7.9226033115166015, 8.968477322398497, 10.022161546302994, 10.985792594966385, 10.1123491955287, 9.064235074558574, 7.990061868217876, 6.920570399288082, 5.982440777298532, 4.984904448083199, 4.047396608348007, 3.980669811041103, 2.967010442875292, 1.9991678688209658, 2.9992491528316854, 3.9634560192949637, 4.897103948003517, 5.886155593278538, 6.828891506901358, 7.811322992800637, 8.842822964401705, 9.909704800599584, 10.886523268661314, 11.879491323038978, 10.951321299874493, 9.887912414699208, 8.931082058751672, 7.863384327178421, 6.83639847288799, 5.859161568349678, 4.918570415069292, 4.921725944424196, 3.966519942927466, 3.0458661977633414, 3.9982625231753715, 5.027037734653881, 5.8306962588264195, 6.8709560856753775, 7.754140147686606, 8.72705300812216, 9.712704861742166, 10.64729485059996, 11.67374092842189, 12.744271382132233, 11.844481659677825, 10.77815164826321, 9.730964454316068, 8.756190511520563, 7.73028549137109, 6.793720280873687, 5.852354055135114, 5.914928032547559, 4.980260481799636, 4.07812879261543, 4.987465952164062, 5.963738204018134, 6.881495154426419, 7.877302889490162, 8.700234094402916, 9.658390158777603, 10.64848488870361, 11.59596220782166, 12.56174321160919, 13.492223750039656, 12.634996293207516, 11.627179512907865, 10.648469854403807, 9.689024541037808, 8.664905355017652, 7.75783859658285, 6.841396343053489, 6.882134345845701, 5.9913224024379526, 5.069279792934757, 6.011559049716581, 7.019404833000991, 7.866957830268425, 8.830870230314906, 9.646742876843016, 10.600206049005868, 11.567408518548408, 12.627010727785425, 13.582689197032414, 14.424318085901643, 13.415677763601215, 12.43140268920908, 11.489309173912726, 10.541984584014067, 9.610126903735543, 8.697557761628625, 7.849741647785418, 7.810734401949858, 7.001019194148456, 6.022234180051703, 7.038486750147093, 8.050792666367888, 8.849000892968068, 9.835504485510414, 10.7154231080836, 11.675179358694162, 12.530470568897762, 13.526116574040168, 14.533856685909315, 15.366982724889034, 14.317823393849322, 13.364214670859543, 12.426475265540759, 11.544600633609374, 10.612350955530871, 9.738928924857724, 8.810293859866116, 8.81722644665997, 7.9752094346544675, 7.057353415230047, 8.00768675764182, 8.991077843797852, 9.860796993314324, 10.76871803342917, 11.65859547460872, 12.628397166522019, 13.500573000921895, 14.453890593189648, 15.436739662973098, 16.20897526115035, 15.275422416380787, 14.352916666021196, 13.412406643725118, 12.578567337937313, 11.564045197194112, 10.686851348222353, 9.87575802445611, 9.783857871856405, 9.044117817677206, 8.115036387479076, 9.005889521992414, 9.935038839291249, 10.81673562165907, 11.70653523714341, 12.584864755707441, 13.607556915816735, 14.52340667558078, 15.403197051154262, 16.4591912852865, 16.413943696229026, 15.466974310453642, 14.541773867050177, 13.56093592234157, 12.77454717305063, 12.075096934953612, 11.71662128556662, 10.808746078424353, 10.738430966207865, 10.0136132044937, 9.05294371910371, 10.012626492398866, 10.94589875334728, 11.888513534729821, 12.727047485876815, 13.565053737818594, 14.629060776221056, 15.514327176296351, 16.378580574680445, 16.62953186178043, 15.560478815455024, 14.577210053148006, 13.567389697828855, 12.588162083142397, 11.776301698289977, 11.074288738270557, 12.001895814375823, 11.741208290004607, 11.745631756366581, 10.918024351473777, 9.988410528754098, 10.94392380660081, 11.921617859411846, 12.916353853688067, 13.73540377524745, 14.634758178943885, 15.63687471106397, 16.567808823651223, 16.58580550260294, 15.587513892450183, 14.585550204786779, 13.57808345341813, 12.584458590521974, 11.644663543169006, 10.724580972763404, 10.1039643599793, 10.933158420019259, 11.806746634488436, 11.719518817289206, 11.881047426967815, 10.927867472025717, 11.869606933465354, 12.856813542848903, 13.877516495227276, 14.78497741202283, 15.646732179123156, 16.589574174011737, 16.502707944347463, 15.549438014642348, 14.539880905871879, 13.592479480894518, 12.629654263946877, 11.645660594124777, 10.707136753809147, 9.75844178125557, 9.115514247111427, 9.925457639565636, 10.868151230495481, 10.773669549741935, 11.731702930281863, 11.855070405336823, 12.816862048109108, 13.794253566856842, 14.800179638162884, 15.853043242332548, 16.656295601864233, 16.52985865802512, 15.567605424725967, 14.590235375708355, 13.673709456424723, 12.718018973192024, 11.74379058752884, 10.693808206287764, 9.726555652893465, 8.77875553417392, 8.132863888803785, 8.956202026110049, 9.831888288002078, 9.748321062484127, 10.816023354172735, 11.79808592480379, 12.56345350281348, 13.614431170968615, 14.553777118964922, 15.536204385636367, 16.471978648025367, 15.504555967626443, 14.560099213971982, 13.634749093738266, 12.740127835730995, 11.78732836794435, 10.776786875491588, 9.831686940098129, 8.78896023800443, 7.75539864540218, 7.061468679523241, 8.003446712097391, 8.782623257440344, 8.819058323306864, 9.83413018749658, 10.840812858248283, 11.605520695414004, 12.605279104875448, 13.604235584376275, 14.57742345436858, 15.504880266922035, 14.550459066005761, 13.650071153698585, 12.697096854726505, 11.73634092282936, 10.778812095259031, 9.745593871960494, 8.815038745002333, 7.797238360877805, 6.79237475556317, 6.042664979667171, 6.989137241922053, 7.851062027673559, 7.840594054211214, 8.787467339609348, 9.77349911361127, 10.673336597054988, 11.67521712677726, 12.630341168566005, 13.58664235643555, 14.603117603840545, 13.60664840279498, 12.618605593011832, 11.687447225209947, 10.666683412029094, 9.7381141945665, 8.797665837909307, 7.791292850742935, 6.796332052219773, 5.832182024253952, 5.062648578242933, 6.023452029185872, 6.886851636707803, 6.8611410115109335, 7.855676605432934, 8.816852638162215, 9.672799738373348, 10.741280861725619, 11.814054602758942, 12.714236610376075, 13.669260342087188, 12.707345903323269, 11.724318779830542, 10.7869872011242, 9.848905415335153, 8.918451842574756, 7.913510173235359, 6.89832633586587, 5.860803188467884, 4.869940070666713, 4.084475752358326, 5.004680287567578, 5.936960173840995, 5.833388016836083, 6.8366576146574305, 7.841382825232058, 8.74010802620615, 9.773689388323733, 10.751089940185171, 11.7066100223743, 12.737866449154236, 11.780837526486122, 10.881951555455341, 9.842404052247193, 8.885449792322342, 7.890043503301216, 6.898253375746056, 5.913231701695917, 4.896315851257176, 3.9032953357094127, 3.0511978975268197, 3.9355034730221226, 4.913603425991204], [4.872070954346019, 3.922426441226469, 2.92908410568248, 1.9692919521409087, 2.9516260138604213, 3.9563243289492718, 4.9421795835550775, 5.937880378374972, 6.901178358092576, 7.937528849775091, 8.92509468671234, 9.77139630989594, 10.735338982536334, 11.725331881178436, 10.771651070849249, 9.82481361688102, 8.786312682470419, 7.774120723321578, 6.77655074697883, 5.825522530693027, 3.956238120696263, 3.0111540263430037, 2.0326968195498223, 1.028893873152965, 1.9640472778782652, 2.941260490829067, 4.00228637947714, 4.937512111031832, 5.924259117664292, 6.945375146859842, 7.899480404868622, 8.829113414269885, 9.867837432242611, 10.849113908607363, 9.844685678036512, 8.838315796699002, 7.875355425553769, 6.830373932496264, 5.843754615456163, 4.896828226900143, 3.074401254469924, 2.0336946400963676, 0.9978653568578928, 0.0, 1.064228933406149, 2.06269855143016, 3.1119122649481765, 4.129952609660905, 5.099778925299477, 6.0526078718575445, 7.09335301263266, 8.07276141875305, 9.130197396981176, 10.078781393053884, 9.250428827997498, 8.194156847424779, 7.1362730623573185, 6.085841133882479, 5.121826259166043, 4.058407893046061, 3.9349466078813853, 2.8965384551834084, 1.9123217883643604, 0.9625106239922873, 1.9710079108195124, 3.039764393831606, 4.023383896941382, 5.022468696461157, 5.978640887754725, 6.924737954658708, 7.970611965540604, 9.024296189445101, 9.987927238108492, 11.033035806894006, 10.016669254351523, 8.942496048010824, 7.873004579081031, 6.9348749570914805, 5.937338627876148, 4.999830788140955, 4.8618912680693285, 3.830207068775333, 2.8623644947210067, 2.0013837959737923, 2.9655906624370703, 3.899238591145623, 4.888290236420644, 5.831026150043464, 6.8134576359427435, 7.844957607543811, 8.911839443741691, 9.88865791180342, 10.881625966181085, 11.832542756902718, 10.769133871727433, 9.812303515779897, 8.744605784206646, 7.717619929916215, 6.740383025377903, 5.799791872097517, 5.784922570324237, 4.829716568827506, 3.9090628236633824, 3.0003971663174784, 4.029172377795988, 4.832830901968525, 5.873090728817484, 6.756274790828712, 7.729187651264267, 8.714839504884273, 9.649429493742067, 10.675875571563996, 11.74640602527434, 12.717817225988496, 11.659373105291435, 10.612185911344293, 9.637411968548788, 8.611506948399315, 7.6749417379019125, 6.715550681035155, 6.7781246584476, 5.8434571076996775, 4.94132541851547, 3.989600595306169, 4.965872847160242, 5.883629797568524, 6.879437532632268, 7.702368737545023, 8.660524801919712, 9.650619531845717, 10.598096850963767, 11.563877854751297, 12.494358393181763, 13.516217750235741, 12.50840096993609, 11.529691311432032, 10.570245998066033, 9.546126812045877, 8.639060053611075, 7.70459296895353, 7.745330971745742, 6.854519028337994, 5.932476418834797, 5.013693692858689, 6.021539476143098, 6.86909247341053, 7.833004873457012, 8.648877519985124, 9.602340692147976, 10.569543161690516, 11.629145370927533, 12.584823840174522, 13.42645272904375, 14.29689922062944, 13.312624146237305, 12.370530630940952, 11.423206041042292, 10.491348360763768, 9.57877921865685, 8.71293827368546, 8.673931027849898, 7.864215820048496, 6.885430805951744, 6.080848690239033, 7.052927309509996, 7.851135536110172, 8.83763912865252, 9.717557751225709, 10.67731400183627, 11.53260521203987, 12.528251217182277, 13.535991329051424, 14.36911736803114, 15.199044850877547, 14.245436127887768, 13.307696722568984, 12.425822090637599, 11.493572412559097, 10.62015038188595, 9.673490485766157, 9.68042307256001, 8.838406060554508, 7.920550041130087, 7.050048697733759, 8.033439783889792, 8.862931636456427, 9.770852676571277, 10.66073011775083, 11.630531809664129, 12.502707644064003, 13.456025236331756, 14.438874306115206, 15.382453592560845, 15.515507830567994, 14.49607353678633, 13.522774156205914, 12.795826766899904, 12.445266654222337, 11.568072805250578, 10.73895465035615, 10.647054497756447, 9.907314443577246, 8.978233013379116, 8.048251462084353, 8.977400779383188, 9.818870264801173, 10.708669880285516, 11.586999398849551, 12.609691558958845, 13.525541318722889, 14.40533169429637, 15.461325928428609, 15.416078339371134, 14.46910895359575, 13.543908510192285, 12.56307056548368, 11.77668181619274, 12.665612639491027, 12.597842742594844, 11.671942704324394, 11.601627592107906, 10.87680983039374, 9.91614034500375, 9.064346859133632, 9.997619120082046, 10.890648177871924, 11.729182129018922, 12.567188380960705, 13.631195419363166, 14.51646181943846, 15.380715217822553, 15.631666504922537, 14.562613458597133, 13.579344696290114, 12.569524340970963, 11.590296726284505, 10.778436341432087, 11.664804442807972, 12.688385214211984, 12.604404915904649, 12.608828382266623, 11.781220977373817, 10.851607154654138, 9.995644173335577, 10.973338226146613, 11.951440569392362, 12.737538418389557, 13.636892822085995, 14.63900935420608, 15.569943466793333, 15.587940145745048, 14.589648535592291, 13.587684847928887, 12.580218096560237, 11.586593233664082, 10.646798186311115, 9.726715615905514, 10.694480064516714, 11.65946613113294, 12.543087361397552, 12.519420535427269, 12.744244052867854, 11.791064097925757, 10.96856755655436, 11.908533909583669, 12.912603210931572, 13.787112055164936, 14.648866822265266, 15.591708817153847, 15.504842587489572, 14.551572657784455, 13.542015549013987, 12.594614124036626, 11.631788907088985, 10.647795237266886, 9.709271396951255, 8.76057642439768, 9.706029951648842, 10.661798366474752, 11.604491957404598, 11.573571267879997, 12.531604648419924, 12.718267031236863, 11.931266643371073, 12.845973933591608, 13.85190000489765, 14.860488533959282, 15.658430245006343, 15.531993301167226, 14.569740067868073, 13.592370018850461, 12.675844099566831, 11.720153616334132, 10.745925230670949, 9.695942849429873, 8.728690296035573, 7.780890177316028, 8.7233795933412, 9.692542753019165, 10.63179000614014, 10.548222780622188, 11.615925072310796, 12.59798764294185, 12.85703662233592, 13.88641997969125, 14.860525561221651, 15.909099131508816, 15.474113291167473, 14.50669061076855, 13.562233857114089, 12.636883736880373, 11.742262478873103, 10.789463011086458, 9.778921518633696, 8.833821583240237, 7.791094881146538, 6.7575332885442885, 7.797809406432355, 8.739787439006506, 9.582524975578405, 9.620021614102818, 10.649524148545032, 11.68784608411752, 12.598555090007066, 13.59831349946851, 14.597269978969337, 15.489028857499058, 14.507014910064141, 13.552593709147867, 12.652205796840692, 11.699231497868611, 10.738475565971468, 9.78094673840114, 8.747728515102603, 7.817173388144441, 6.799373004019913, 5.794509398705278, 6.779005706576285, 7.725477968831168, 8.650963745811621, 8.713375540929896, 9.660248826328031, 10.646280600329954, 11.66637099164805, 12.673082483635154, 13.628206525423899, 14.584507713293444, 13.63444087847807, 12.608783045937086, 11.620740236153939, 10.689581868352054, 9.668818055171203, 8.740248837708608, 7.799800481051414, 6.793427493885043, 5.798466695361881, 4.8343166673960605, 5.798989305152047, 6.759792756094987, 7.759633123426484, 7.834251428790916, 8.853541962290826, 9.814717995020107, 10.670665095231241, 11.739146218583512, 12.811919959616835, 13.650648668151812, 12.695624936440698, 11.709480546465377, 10.72645342297265, 9.789121844266308, 8.851040058477261, 7.920586485716863, 6.9156448163774655, 5.9004609790079785, 4.862937831609992, 3.8720747138088214, 4.904287184186279, 5.937782174628779, 6.870062060902196, 6.831253373693976, 7.834522971515323, 8.83924818208995, 9.737973383064043, 10.771554745181627, 11.748955297043063, 12.704475379232191, 11.741883718787097, 10.782972169628227, 9.884086198597451, 8.844538695389302, 7.88758443546445, 6.892178146443324, 5.900388018888163, 4.9153663448380245, 3.8984504943992846, 2.9054299788515205, 3.9078435872181676, 4.868605360083324, 5.846705313052405], [5.787434247206876, 4.837789734087325, 3.844447398543336, 2.8846552450017646, 1.9966824972706771, 3.001380812359528, 3.987236066965334, 4.9829368617852285, 5.946234841502832, 6.913708215911546, 7.9012740528487955, 8.747575676032394, 9.711518348672788, 10.70151124731489, 11.658110778169467, 10.794911824441648, 9.756410890031049, 8.744218930882209, 7.74664895453946, 6.795620738253657, 4.926336328256893, 3.9812522339036334, 3.002795027110452, 1.944257166013821, 1.009103761288521, 1.986316974239323, 3.0473428628873966, 3.982568594442088, 4.969315601074548, 5.921554512996297, 6.875659771005077, 7.805292780406341, 8.844016798379066, 9.825293274743817, 10.814783885597143, 9.808414004259632, 8.8454536331144, 7.800472140056894, 6.813852823016793, 5.866926434460773, 4.138630187876073, 3.0979235735025163, 2.062094290264042, 1.064228933406149, 0.0, 0.9984696180240109, 2.0476833315420273, 3.065723676254756, 4.035549991893327, 4.988378938451395, 6.029124079226509, 7.008532485346899, 8.065968463575025, 9.014552459647733, 9.9875523495145, 9.258385780830928, 8.200501995763467, 7.1500700672886275, 6.186055192572192, 5.12263682645221, 4.933883166780992, 3.895475014083015, 2.911258347263967, 1.9614471828918938, 0.9529498960646685, 2.021706379076762, 3.0051199081289037, 4.004204707648678, 4.960376898942247, 5.90647396584623, 6.9523479767281255, 8.006032200632623, 8.969663249296014, 10.014771818081527, 10.931858511026887, 9.941432606910432, 8.871941137980638, 7.933811515991088, 6.936275186775755, 5.9987673470405625, 5.8608278269689364, 4.829143627674941, 3.861301053620614, 2.976789465142411, 2.0125825986791326, 2.9462305273876854, 3.9352821726627063, 4.878018086285526, 5.860449572184805, 6.891949543785873, 7.893575454929213, 8.870393922990942, 9.863361977368607, 10.888186404519589, 11.768070430627043, 10.811240074679507, 9.743542343106256, 8.716556488815824, 7.739319584277511, 6.798728430997125, 6.783859129223845, 5.828653127727114, 4.9079993825629895, 3.975802835486097, 3.083684482465986, 3.8798228382105875, 4.920082665059546, 5.803266727070774, 6.776179587506329, 7.7618314411263345, 8.69642142998413, 9.722867507806058, 10.793397961516401, 11.764809162230558, 12.658309664191043, 11.6111224702439, 10.636348527448396, 9.610443507298923, 8.67387829680152, 7.714487239934763, 7.777061217347208, 6.8423936665992855, 5.940261977415077, 4.965006264474788, 4.075627584761321, 4.930621733810587, 5.92642946887433, 6.749360673787085, 7.7075167381617735, 8.697611468087779, 9.645088787205829, 10.610869790993359, 11.541350329423825, 12.587187995505738, 13.507337528835698, 12.52862787033164, 11.569182556965641, 10.545063370945485, 9.637996612510683, 8.703529527853139, 8.744267530645349, 7.853455587237602, 6.9314129777344045, 5.989099362027307, 5.1312942137441775, 5.916084409652592, 6.879996809699074, 7.695869456227186, 8.649332628390038, 9.616535097932578, 10.676137307169595, 11.631815776416584, 12.473444665285811, 13.539526473943726, 14.311560705136912, 13.36946718984056, 12.4221425999419, 11.490284919663376, 10.577715777556458, 9.711874832585067, 9.672867586749506, 8.863152378948104, 7.884367364851351, 7.056254359407651, 6.162682047111075, 6.898127472352234, 7.884631064894582, 8.76454968746777, 9.724305938078333, 10.579597148281932, 11.575243153424339, 12.582983265293485, 13.416109304273203, 14.479837685414882, 14.67086219111912, 13.733122785800337, 13.424758649537207, 12.492508971458705, 11.619086940785557, 10.672427044665765, 10.679359631459619, 9.837342619454116, 8.919486600029694, 8.025454366902377, 7.213352326712656, 7.90992357269849, 8.817844612813337, 9.707722053992892, 10.677523745906191, 11.549699580306065, 12.503017172573818, 13.485866242357268, 14.429445528802907, 14.739925081978058, 13.720490788196393, 12.747191407615977, 13.71119005976076, 13.444203213121945, 12.567009364150186, 11.737891209255759, 11.645991056656054, 10.906251002476854, 9.977169572278724, 9.023657131252971, 8.157313322206054, 8.865862201043237, 9.755661816527576, 10.633991335091613, 11.656683495200907, 12.57253325496495, 13.452323630538432, 14.508317864670671, 14.640495590781198, 13.693526205005814, 12.768325761602348, 11.787487816893742, 12.692045109053597, 13.580975932351883, 13.596779301494452, 12.670879263224002, 12.600564151007514, 11.875746389293347, 10.915076903903358, 10.03975252830225, 9.199554692264378, 9.937640114113986, 10.776174065260982, 11.614180317202766, 12.678187355605228, 13.563453755680522, 14.427707154064615, 14.8560837563326, 13.787030710007196, 12.803761947700178, 11.793941592381026, 10.814713977694568, 11.693799634292944, 12.580167735668828, 13.60374850707284, 13.603341474804257, 13.60776494116623, 12.780157536273425, 11.850543713553746, 10.971049842504197, 10.22689870413381, 10.998432505634424, 11.784530354631617, 12.683884758328057, 13.686001290448141, 14.616935403035395, 14.723085907182277, 13.814065787002354, 12.81210209933895, 11.8046353479703, 10.811010485074146, 9.871215437721178, 10.64207890876637, 11.60984335737757, 12.574829423993796, 13.458450654258408, 13.434783828288126, 13.743180611767462, 12.790000656825365, 11.94397322572298, 11.162094387570866, 11.959595147173633, 12.834103991406998, 13.695858758507327, 14.63870075339591, 14.621520924727694, 13.680887124637275, 12.76643280042405, 11.81903137544669, 10.856206158499049, 9.872212488676949, 8.933688648361318, 9.675939717258537, 10.621393244509699, 11.577161659335609, 12.519855250265454, 12.488934560740853, 13.44696794128078, 13.71720359013647, 12.906672312539692, 12.099534411578805, 12.995046126986253, 13.907480470201344, 14.705422181248405, 14.648671638405348, 13.686418405106195, 12.709048356088584, 11.851989139915123, 10.896298656682424, 9.949841924713931, 8.920360100839936, 7.9531075474456365, 8.696253470176885, 9.638742886202056, 10.607906045880021, 11.547153299000996, 11.463586073483045, 12.531288365171653, 13.513350935802707, 13.83244229150454, 13.139980457678448, 14.025353556844221, 14.956734219042517, 14.590791628405595, 13.623368948006672, 12.678912194352211, 11.753562074118495, 10.907430578026698, 9.96560805143475, 8.955066558981988, 8.026468748291201, 7.0155121325566006, 7.672896581405145, 8.71317269929321, 9.655150731867362, 10.497888268439262, 10.535384906963674, 11.564887441405888, 12.603209376978377, 13.51391838286792, 14.199860317074686, 14.974895091432868, 14.60570719473718, 13.623693247302263, 12.66927204638599, 11.768884134078814, 10.815909835106734, 9.903643665125063, 8.957091778749431, 7.923873555450895, 6.993318428492733, 6.023790255429976, 6.709872691566135, 7.694368999437141, 8.640841261692024, 9.566327038672478, 9.62873883379075, 10.575612119188886, 11.561643893190809, 12.581734284508904, 13.643180691195784, 14.598304732984529, 13.647330676449144, 12.751119215716193, 11.725461383175208, 10.73741857339206, 9.806260205590176, 8.832190408801472, 7.916393878056899, 6.975945521399706, 5.969572534233335, 4.974611735710173, 5.749679960256916, 6.714352598012903, 7.675156048955842, 8.674996416287339, 8.749614721651772, 9.823025128792331, 10.784201161521612, 11.640763302791871, 12.709244426144142, 13.704905175622391, 12.694787692529717, 11.740681419850954, 10.754537029875634, 9.771509906382907, 8.834178327676565, 7.896096541887518, 6.96564296912712, 5.960701299787722, 4.985654436435849, 4.039082871958284, 4.787438006669677, 5.819650477047134, 6.853145467489636, 7.785425353763053, 7.781605839610031, 8.804621179075953, 9.809346389650582, 10.708071590624673, 11.741652952742257, 12.635415004363281, 11.687161104527942, 10.71806308492355, 9.759151535764682, 8.929142682007708, 7.889595178799558, 6.932640918874706, 5.93723462985358, 4.94544450229842, 3.9604228282482805, 3.010104079671198, 3.8207932717123763, 4.823206880079024, 5.78396865294418, 6.762068605913262], [6.743882145368462, 5.794237632248912, 4.8008952967049225, 3.841103143163351, 2.953130395432263, 2.034293752930405, 2.989257539225316, 3.98495833404521, 4.948256313762815, 5.9152385978875355, 6.902804434824785, 7.749106058008384, 8.713048730648778, 9.70304162929088, 10.659641160145457, 11.630676987402119, 10.712858788192637, 9.700666829043795, 8.703096852701046, 7.752068636415244, 5.8827842264184795, 4.93770013206522, 3.9592429252720382, 2.900705064175407, 1.965551659450107, 0.988338446499305, 2.0493643351473785, 2.98459006670207, 3.9713370733345306, 4.923084894972287, 5.877190152981067, 6.80682316238233, 7.845547180355056, 8.826823656719808, 9.865345093414442, 10.76486190242122, 9.801901531275988, 8.756920038218482, 7.77030072117838, 6.82337433262236, 5.137099805900084, 4.096393191526527, 3.060563908288053, 2.06269855143016, 0.9984696180240109, 0.0, 1.0492137135180164, 2.067254058230745, 3.0370803738693164, 3.989909320427384, 5.030654461202499, 6.010062867322889, 7.067498845551015, 8.016082841623723, 8.98908273149049, 10.045354712063208, 9.198971613787478, 8.148539685312638, 7.184524810596202, 6.12110644447622, 5.932352784805003, 4.893944632107026, 3.9097279652879777, 2.959916800915905, 1.9514195140886794, 1.023771426085941, 2.0066502901048926, 3.0057350896246673, 3.961907280918236, 4.908004347822218, 5.953878358704114, 7.00756258260861, 7.971193631272002, 9.016302200057515, 9.933388893002876, 10.939902224934443, 9.870410756004649, 8.9322811340151, 7.934744804799766, 6.997236965064573, 6.859297444992947, 5.827613245698951, 4.8597706716446245, 3.9256345470613976, 2.9614276805981192, 2.0277797518895664, 3.0167029633078783, 3.9594388769306987, 4.941870362829977, 5.941998686127462, 6.8951058369052, 7.871924304966931, 8.864892359344596, 9.889716786495578, 10.953125671670865, 11.809709692703517, 10.742011961130267, 9.715026106839835, 8.737789202301522, 7.7971980490211354, 7.782328747247855, 6.827122745751125, 5.906469000587, 4.924647917405084, 3.898979122427664, 2.9613720627124684, 4.001631889561427, 4.884687517715946, 5.857600378151501, 6.8432522317715065, 7.777842220629301, 8.80428829845123, 9.866251993385035, 10.837663194099191, 11.903993205513807, 12.609592088267911, 11.634818145472407, 10.608913125322934, 9.672347914825531, 8.712956857958774, 8.77553083537122, 7.840863284623296, 6.930890684644528, 5.867194476577072, 4.890922224722999, 4.012170958312468, 5.007978693376211, 5.830781464432257, 6.788937528806946, 7.779032258732951, 8.726509577851001, 9.692290581638531, 10.622771120068997, 11.66860878615091, 12.676425566450561, 13.52709748835565, 12.567652174989652, 11.543532988969496, 10.636466230534694, 9.70199914587715, 9.742737148669361, 8.850577790160209, 7.902967091255076, 6.891287574129591, 5.9465888537058555, 4.997633634154473, 5.961546034200955, 6.777290246872358, 7.73075341903521, 8.69795588857775, 9.757558097814767, 10.713236567061756, 11.554865455930983, 12.620947264588898, 13.605222338981033, 14.36793680786457, 13.42061221796591, 12.488754537687386, 11.576185395580469, 10.710344450609078, 10.671337204773518, 9.834706492468774, 8.855921478372021, 7.958442571509935, 6.977976687072753, 5.979676696854115, 6.966180289396463, 7.845970478112942, 8.805726728723505, 9.661017938927104, 10.65666394406951, 11.664404055938657, 12.497530094918375, 13.561258476060054, 13.959755730605517, 14.689570683961923, 14.423228267561218, 13.490978589482715, 12.617556558809568, 11.670896662689776, 11.67782924948363, 10.808896732974786, 9.891040713550364, 8.927642579004662, 7.987659054145391, 6.9914727972003705, 7.899393837315219, 8.789142844638063, 9.758944536551361, 10.631120370951237, 11.58443796321899, 12.56728703300244, 13.510866319448079, 13.990488029225528, 12.971053735443864, 13.703639305777564, 14.667637957922341, 14.442672831145956, 13.565478982174197, 12.73636082727977, 12.644460674680065, 11.862277837946838, 10.881304975884065, 9.873518529412022, 8.931620049638788, 7.947411425545118, 8.837211041029457, 9.715412125736783, 10.738104285846077, 11.653954045610122, 12.533744421183604, 13.589738655315843, 13.819437904838374, 12.944089152253284, 12.018888708849818, 12.74393571505533, 13.648493007215178, 14.537423830513466, 14.595248919518463, 13.669348881248013, 13.599033769031525, 12.831773224763332, 11.8192123075087, 10.889613926461301, 9.973861419697112, 9.019189338615867, 9.857723289762863, 10.695601107847937, 11.759608146250399, 12.644874546325694, 13.509127944709787, 13.93297592418548, 12.865034546812046, 11.966652180998395, 11.002805378237118, 11.771161875856155, 12.650247532454525, 13.536615633830412, 14.560196405234423, 14.601811092828267, 14.606234559190241, 13.684292939878766, 12.754679117159087, 11.820911240663246, 11.001205431566543, 10.079981730136305, 10.866079579133498, 11.765305548973227, 12.767422081093311, 13.698356193680567, 13.72510737944226, 12.890957954855233, 11.8901059361438, 10.967525581268518, 9.973900718372363, 10.827663335882765, 11.598526806927952, 12.566291255539154, 13.531277322155379, 14.414898552419993, 14.39123172644971, 14.647316015372803, 13.694136060430706, 12.793834623882029, 11.9364011150036, 11.041144371675514, 11.915653215908879, 12.777279549152498, 13.720121544041078, 13.623542396987677, 12.682908596897258, 11.84332496827693, 10.89703521225154, 10.019096391797266, 9.035102721975166, 9.890136546522905, 10.632387615420118, 11.577841142671282, 12.533609557497194, 13.47630314842704, 13.445382458902438, 14.403415839442365, 14.621338993741812, 13.756533710698742, 12.873841139011539, 12.076595351488134, 12.989029694703225, 13.786842971893575, 13.650693110665332, 12.688439877366179, 11.711069828348567, 10.8937240207409, 9.9380335375082, 8.991576805539708, 8.083250334138153, 8.909555445607223, 9.652701368338468, 10.59519078436364, 11.564353944041606, 12.503601197162581, 12.42003397164463, 13.487736263333238, 14.469798833964292, 14.68230368966359, 13.914287185111181, 13.106902781346102, 14.038283443544397, 13.592813100665579, 12.625390420266655, 11.680933666612194, 10.755583546378478, 9.909452050286678, 9.007342932260526, 7.996801439807765, 7.068203629116979, 7.971960030718187, 8.62934447956673, 9.669620597454797, 10.611598630028947, 11.454336166600847, 11.49183280512526, 12.521335339567473, 13.559657275139962, 14.470366281029508, 14.97416704450742, 14.05644431593475, 13.607728666997163, 12.625714719562247, 11.671293518645973, 10.770905606338797, 9.817931307366717, 8.905665137385043, 7.998826659575208, 6.965608436276671, 6.035053309318511, 6.9802381535915625, 7.66632058972772, 8.650816897598727, 9.59728915985361, 10.522774936834063, 10.585186731952337, 11.532060017350473, 12.518091791352395, 13.538182182670491, 14.489503080836757, 13.605162246294679, 12.648861058425133, 11.753140687976176, 10.727482855435191, 9.739440045652044, 8.80828167785016, 7.834211881061452, 6.958128758882677, 6.0176804022254835, 5.011307415059113, 5.93105963387176, 6.706127858418502, 7.670800496174489, 8.631603947117428, 9.631444314448926, 9.706062619813359, 10.779473026953918, 11.740649059683198, 12.59721120095346, 13.555566815785115, 12.70643555759838, 11.696318074505706, 10.742309400927018, 9.756165010951698, 8.77353137864289, 7.836199799936548, 6.898118014147499, 5.998555909697997, 4.9936142403586, 4.018567377006725, 4.995530770119871, 5.743885904831263, 6.77609837520872, 7.809593365651223, 8.74187325192464, 8.738053737771619, 9.76106907723754, 10.765794287812168, 11.664519488786262, 12.58797534238323, 11.63694538633927, 10.68869148650393, 9.71959346689954, 8.760681917740671, 7.931164154267689, 6.8916166510595405, 5.9346623911346885, 4.970147570424457, 3.9783574428692967, 2.9933357688191577, 3.9665519778327845, 4.777241169873962, 5.779654778240609, 6.740416551105767, 7.718516504074849], [7.7930958588864785, 6.843451345766928, 5.850109010222939, 4.890316856681367, 3.982475093576375, 2.9777767784875246, 1.963494875565687, 2.959195670385581, 3.922493650103186, 4.866024884369519, 5.853590721306769, 6.699892344490368, 7.663835017130762, 8.653827915772865, 9.610427446627442, 10.581463273884104, 11.619964208294704, 10.74988054256181, 9.752310566219062, 8.80128234993326, 6.931997939936496, 5.986913845583236, 5.008456638790054, 3.9499187776934233, 3.014765372968123, 2.0375521600173214, 1.0236016714877498, 1.9588274030424413, 2.9455744096749017, 3.8738711814542706, 4.82797643946305, 5.757609448864314, 6.79633346683704, 7.777609943201792, 8.816131379896426, 9.822501261233937, 10.78546163237917, 9.806133751736496, 8.819514434696396, 7.872588046140376, 6.1863135194181, 5.145606905044543, 4.109777621806069, 3.1119122649481765, 2.0476833315420273, 1.0492137135180164, 0.0, 1.0180403447127286, 1.9878666603513, 2.940695606909368, 3.981440747684483, 4.960849153804873, 6.018285132032999, 6.9668691281057065, 7.939869017972473, 8.996140998545192, 10.054024783612652, 9.197753398830653, 8.233738524114218, 7.170320157994237, 6.981566498323019, 5.943158345625042, 4.958941678805994, 4.009130514433921, 3.000633227606696, 1.9410560796966534, 0.9574365765868764, 1.956521376106651, 2.9126935674002192, 3.858790634304202, 4.904664645186098, 5.958348869090594, 6.921979917753986, 7.9670884865395, 8.88417517948486, 9.958348385825559, 10.919624469522663, 9.981494847533114, 8.983958518317781, 8.04645067858259, 7.882128674899737, 6.850444475605741, 5.882601901551414, 4.84291920067211, 3.878712334208832, 2.945064405500279, 1.9674892497898622, 2.9102251634126826, 3.892656649311961, 4.892784972609446, 5.845892123387184, 6.822710591448915, 7.815678645826579, 8.840503072977562, 9.903911958152847, 10.860742314100383, 11.764843191037057, 10.737857336746625, 9.760620432208313, 8.820029278927926, 8.805159977154645, 7.849953975657915, 6.869857772514472, 5.841932571015796, 4.816263776038377, 3.878656716323181, 3.0299057312051816, 3.83547380419793, 4.808386664633485, 5.79403851825349, 6.728628507111285, 7.755074584933214, 8.817038279867019, 9.788449480581175, 10.854779491995789, 11.81936374293761, 12.657649375379197, 11.631744355229724, 10.695179144732322, 9.735788087865563, 9.798362065278008, 8.863694514530085, 7.848175338255241, 6.784479130187784, 5.808206878333712, 4.9294556119231805, 4.036252535019966, 4.781567750914241, 5.739723815288929, 6.729818545214934, 7.677295864332984, 8.643076868120513, 9.573557406550979, 10.619395072632893, 11.627211852932543, 12.605921511436602, 13.5653668248026, 12.566364218876286, 11.659297460441485, 10.724830375783938, 10.758530026669678, 9.767862443770921, 8.820251744865788, 7.808572227740304, 6.863873507316568, 5.914918287765186, 4.989819875844709, 5.728076533354342, 6.681539705517194, 7.648742175059735, 8.708344384296753, 9.664022853543742, 10.505651742412965, 11.57173355107088, 12.556008625463015, 13.498102140759368, 14.443443447872701, 13.511585767594177, 12.599016625487259, 11.733175680515867, 11.687130082773836, 10.751991146079487, 9.773206131982734, 8.875727225120647, 7.895261340683466, 6.896961350464828, 5.994454131040217, 6.796756764594925, 7.7565130152054875, 8.611804225409088, 9.607450230551494, 10.615190342420643, 11.448316381400357, 12.512044762542036, 13.465653485531815, 14.403392890850599, 15.40804141593812, 14.513809819389508, 13.640387788716358, 12.693727892596565, 12.669155337959385, 11.726181386585498, 10.808325367161077, 9.844927232615373, 8.904943707756104, 7.908757450811083, 6.927667678958973, 7.739929131120046, 8.709730823033345, 9.58190665743322, 10.535224249700974, 11.518073319484424, 12.46165260593006, 13.10363896778077, 13.914536761000983, 14.707682085619522, 15.71685167144036, 15.465504061052748, 14.588310212080987, 13.740297318049478, 13.63578676315582, 12.779562491557552, 11.79858962949478, 10.790803183022737, 9.848904703249502, 8.811129508437082, 7.865484882673211, 8.666198412218767, 9.688890572328061, 10.604740332092106, 11.484530707665588, 12.540524941797827, 12.831865847610107, 12.057240090808525, 12.962371734406938, 13.747978494897287, 14.697706720733196, 15.586637544031483, 15.618080149425253, 14.660674969723768, 14.59035985750728, 13.749057878374046, 12.735916195284505, 11.77623342198935, 10.842961161040936, 9.855407257313733, 8.885997131406617, 9.64638739432992, 10.710394432732382, 11.595660832807678, 12.459914231191771, 12.945403866957212, 11.87746248958378, 11.075564033416281, 11.946288403794238, 12.775204655698113, 13.699461245972543, 14.585829347348428, 15.60941011875244, 15.593137181304023, 15.597560647665997, 14.600996827654571, 13.671383004934892, 12.707530736191295, 11.862743268742486, 10.868007274466265, 9.894353420777252, 10.716091835455211, 11.718208367575295, 12.649142480162551, 12.698112494415188, 11.903385897626967, 10.902533878915534, 10.076437433686404, 10.917383743929483, 11.831706115724723, 12.64774052044597, 13.61550496905717, 14.580491035673395, 15.464112265938011, 15.440445439967728, 15.564019903148608, 14.610839948206511, 13.680454119410077, 12.797938952179543, 11.829169916005474, 10.943927057552632, 11.728065835634482, 12.670907830523063, 12.596547511960605, 11.655913711870186, 10.855752911048663, 9.909463155023273, 9.034274955601457, 9.978585747532286, 10.894179326364863, 11.681601328938136, 12.627054856189298, 13.582823271015211, 14.525516861945057, 14.494596172420456, 15.452629552960383, 15.538042881517617, 14.64315320622679, 13.735378976187482, 12.864620895818092, 12.017303536346978, 12.73762925837556, 12.62369822563826, 11.661444992339106, 10.684074943321495, 9.906151963512633, 8.950461480279934, 8.004004748311441, 9.026733359695273, 9.913598225449181, 10.701915081856484, 11.644404497881656, 12.613567657559624, 13.552814910680599, 13.469247685162648, 14.536949976851256, 15.51901254748231, 15.568923185191638, 14.775825022287124, 13.89492832567606, 13.06655728518815, 12.565818215638506, 11.598395535239582, 10.653938781585122, 9.728588661351406, 8.883689386627049, 8.01977087503226, 7.009229382579498, 8.011686654674099, 8.976002810560146, 9.678558193084745, 10.718834310972813, 11.660812343546965, 12.503549880118864, 12.541046518643277, 13.570549053085491, 14.60887098865798, 15.437037578096183, 14.464066404964354, 13.560428058693542, 12.58073378197009, 11.598719834535174, 10.6442986336189, 9.743910721311725, 8.790936422339644, 7.879902473725414, 7.011254602346941, 5.978036379048405, 6.97853633487563, 7.9842809334335225, 8.715534303245736, 9.700030611116743, 10.646502873371627, 11.57198865035208, 11.634400445470355, 12.58127373086849, 13.567305504870413, 14.504853479737166, 13.440289367318742, 12.555948532776664, 11.599647344907119, 10.726145802949103, 9.700487970408119, 8.712445160624972, 7.781286792823087, 6.808449217401823, 5.97055670165441, 5.030108344997217, 5.954790440616232, 6.93510241371372, 7.755341571936518, 8.720014209692506, 9.680817660635446, 10.680658027966944, 10.755276333331375, 11.828686740471934, 12.789862773201214, 13.504316621055526, 12.5063531022671, 11.657221844080366, 10.647104360987692, 9.693095687409002, 8.706951297433681, 7.746536493615817, 6.8092049149094755, 5.8723553504878705, 4.977025995163849, 3.9720843258244516, 4.962050402563845, 5.9995735499618315, 6.793099618349279, 7.8253120887267364, 8.858807079169239, 9.791086965442656, 9.787267451289633, 10.810282790755554, 11.815008001330183, 12.571624908888328, 11.538761628865215, 10.587731672821256, 9.639477772985916, 8.670379753381525, 7.711468204222655, 6.887489997468824, 5.864621766032468, 4.90889972747506, 3.9486176558903097, 2.956827528335149, 3.9368187943762774, 4.995896675976896, 5.826454883391978, 6.828868491758625, 7.789630264623783, 8.767730217592865], [8.8010177966454, 7.85137328352585, 6.85803094798186, 5.898238794440289, 4.943321631216795, 3.938623316127945, 2.924341413206107, 2.0495907449166184, 2.922169866226761, 3.8479845396567907, 4.83555037659404, 5.681851999777639, 6.645794672418034, 7.635787571060137, 8.592387101914714, 9.563422929171375, 10.601923863581977, 11.614115822730817, 10.760232503977983, 9.809204287692179, 7.9399198776954165, 6.9948357833421575, 6.016378576548976, 4.957840715452345, 4.022687310727045, 3.0454740977762436, 1.98444820912817, 1.0492224775734786, 1.9452506257984765, 2.855830836741542, 3.809936094750322, 4.7395691041515855, 5.778293122124311, 6.759569598489064, 7.798091035183697, 8.804460916521208, 9.76742128766644, 10.812402780723946, 9.827436372455317, 8.880509983899296, 7.2043538641308285, 6.163647249757272, 5.127817966518797, 4.129952609660904, 3.0657236762547555, 2.067254058230745, 1.0180403447127286, 0.0, 0.9698263156385714, 1.9226552621966393, 2.963400402971754, 3.9428088090921443, 5.00024478732027, 5.948828783392977, 6.9218286732597445, 7.978100653832463, 9.035984438899924, 10.086416367374763, 9.251778868826946, 8.188360502706965, 7.999606843035746, 6.96119869033777, 5.976982023518722, 5.027170859146649, 4.018673572319424, 2.959096424409382, 1.975476921299605, 1.0569506625590244, 1.9511560389155251, 2.8762216130542315, 3.9220956239361273, 4.955172513570585, 5.918803562233977, 6.963912131019491, 7.86613483477213, 8.940308041112829, 9.989650655166056, 10.927780277155605, 10.001998863030508, 9.064491023295316, 8.900169019612466, 7.86848482031847, 6.900642246264143, 5.860959545384839, 4.896752678921561, 3.9631047502130077, 2.985529594502591, 2.087605552314299, 2.972800489857806, 3.9102159513594756, 4.863323102137214, 5.840141570198944, 6.8331096245766085, 7.857934051727591, 8.921342936902878, 9.878173292850414, 10.945871024423665, 11.755897681459354, 10.778660776921042, 9.838069623640655, 9.823200321867374, 8.867994320370643, 7.8878981172272, 6.859972915728525, 5.834304120751106, 4.89669706103591, 4.046169340033177, 3.0128541930995465, 3.983019158759914, 4.887883275781474, 5.822473264639268, 6.848919342461198, 7.834469258617048, 8.805880459331204, 9.87221047074582, 10.83679472168764, 11.811568664483145, 12.649784699942453, 11.71321948944505, 10.753828432578292, 10.816402409990737, 9.881734859242814, 8.86621568296797, 7.802519474900514, 6.826247223046441, 5.94749595663591, 4.974249460447814, 3.958948139815857, 4.9171042041905455, 5.823663302742918, 6.771140621860967, 7.736921625648497, 8.667402164078963, 9.713239830160877, 10.721056610460527, 11.699766268964586, 12.659211582330585, 13.584404563589015, 12.677337805154213, 11.742870720496667, 11.776570371382409, 10.785902788483652, 9.838292089578518, 8.826612572453033, 7.851413716024148, 6.8836744272971755, 5.897014368729896, 4.905456922255958, 5.85892009441881, 6.826122563961351, 7.808859163983183, 8.764537633230171, 9.59949649994095, 10.665578308598864, 11.649853382991, 12.591946898287352, 13.539271488186012, 14.471129168464536, 13.617056970199988, 12.751216025228596, 12.705170427486566, 11.770031490792217, 10.791246476695465, 9.893767569833377, 8.882801549391047, 7.865717489996817, 6.901648623925404, 5.9741371534965415, 6.933893404107104, 7.789184614310704, 8.78483061945311, 9.715705122107073, 10.542161138928343, 11.605889520070022, 12.559498243059801, 13.497237648378585, 14.501886173466106, 15.44531691361015, 14.658428133429087, 13.711768237309293, 13.687195682672115, 12.744221731298229, 11.826365711873807, 10.857090933444125, 9.873699847288092, 8.877513590343073, 7.83486217184416, 6.9173095200216625, 7.887111211934962, 8.759287046334837, 9.71260463860259, 10.69545370838604, 11.555497363458047, 12.489050208227608, 13.548200238221455, 14.483169026562944, 15.557141252096185, 16.39701115527339, 15.606350556793716, 14.758337662762209, 14.653827107868551, 13.715209513753532, 12.73423665169076, 11.726450205218717, 10.784551725445482, 9.71832400132227, 8.772679375558399, 7.843578801120383, 8.866270961229677, 9.782120720993722, 10.661911096567204, 11.717905330699443, 11.97304974777357, 12.920019133548955, 13.84521957695242, 14.708825032537709, 15.692595128973807, 16.594559481790405, 16.636120494137984, 15.678715314436499, 15.608400202220011, 14.684704900570026, 13.643110688169694, 12.683427914874539, 11.750155653926125, 10.762601750198922, 9.793191624291804, 8.823767783231537, 9.887774821633998, 10.773041221709294, 11.637294620093387, 11.970038544717733, 11.018646389747243, 12.036410571056702, 12.90713494143466, 13.736051193338534, 14.694349654213154, 15.593751285107352, 16.617332056511366, 16.611177526016753, 16.5211167548615, 15.50819132053976, 14.578577497820081, 13.614725229076484, 12.769937761627673, 11.775201767351453, 10.80154791366244, 9.893472224356827, 10.895588756476911, 11.826522869064167, 11.68007214970246, 10.928020575387487, 10.043717779078998, 11.037283971326826, 11.878230281569904, 12.792552653365144, 13.655662458204892, 14.623426906816094, 15.58841297343232, 16.472034203696936, 16.44836737772665, 16.471214396033798, 15.5180344410917, 14.587648612295267, 13.70513344506473, 12.736364408890662, 11.85112155043782, 10.905446224536098, 11.848288219424678, 11.578507167247876, 10.637873367157457, 9.880387588809183, 9.050647055186737, 9.995121493241879, 10.939432285172707, 11.855025864005285, 12.689523266697059, 13.634976793948223, 14.590745208774134, 15.53343879970398, 15.502518110179379, 16.460551490719304, 16.445237374402804, 15.55034769911198, 14.64257346907267, 13.771815388703281, 12.924498029232167, 11.915009647277175, 11.60565788092553, 10.643404647626378, 9.666034598608766, 8.930786641273153, 8.091645380443397, 8.964851285951863, 9.987579897335694, 10.874444763089603, 11.709837019615408, 12.65232643564058, 13.621489595318547, 14.560736848439522, 14.47716962292157, 15.544871914610178, 16.367940887175294, 15.376930040782932, 14.466034830099863, 13.491929248569463, 12.521474368525151, 11.547777870925778, 10.580355190526854, 9.635898436872393, 8.710548316638677, 7.883365602750624, 7.160954775195723, 7.970075920219919, 8.97253319231452, 9.936849348200568, 10.68648013084367, 11.726756248731736, 12.668734281305888, 13.511471817877787, 13.5489684564022, 14.578470990844414, 15.402784162914626, 14.418997233383456, 13.446026060251626, 12.542387713980816, 11.562693437257364, 10.580679489822447, 9.626258288906174, 8.725870376598996, 7.772896077626916, 6.879578689848989, 6.123041195338744, 6.938882916688826, 7.939382872516052, 8.945127471073944, 9.72345624100466, 10.707952548875665, 11.65442481113055, 12.579910588111003, 12.642322383229278, 13.589195668627413, 14.402504601183935, 13.48681313502444, 12.422249022606014, 11.537908188063938, 10.581607000194392, 9.708105458236377, 8.682447625695392, 7.694404815912244, 6.763246448110358, 5.808125433525398, 5.074452570485733, 5.990954882637637, 6.915636978256654, 7.895948951354141, 8.763263509695442, 9.727936147451429, 10.688739598394369, 11.688579965725866, 11.763198271090296, 12.836608678230855, 13.42319145632625, 12.4862762763428, 11.488312757554372, 10.639181499367638, 9.629064016274963, 8.675055342696272, 7.688910952720952, 6.728496148903089, 5.791164570196747, 4.8720315666114455, 4.079619580276249, 4.932930863464872, 5.922896940204266, 6.960420087602253, 7.801021556108202, 8.833234026485659, 9.86672901692816, 10.799008903201576, 10.795189389048556, 11.818204728514477, 12.545780135993237, 11.553584564175601, 10.520721284152486, 9.569691328108528, 8.621437428273188, 7.652339408668795, 6.693427859509926, 5.869449652756096, 4.84658142131974, 3.9085759435986343, 3.0512112410027097, 3.9176740659755693, 4.897665332016698, 5.956743213617316, 6.834376821150901, 7.8367904295175475, 8.797552202382704, 9.775652155351786], [9.713966635864287, 8.764322122744737, 7.770979787200748, 6.811187633659176, 5.856270470435683, 4.851572155346832, 3.8372902524249946, 2.9625395841355058, 1.9523435505881896, 2.878158224018219, 3.8657240609554684, 4.712025684139068, 5.675968356779462, 6.665961255421565, 7.622560786276143, 8.593596613532805, 9.632097547943406, 10.644289507092246, 11.673181343196871, 10.722153126911067, 8.852868716914305, 7.907784622561045, 6.9293274157678635, 5.870789554671233, 4.935636149945933, 3.958422936995131, 2.8973970483470572, 1.9621713167923658, 0.9754243101599052, 1.8860045211029703, 2.84010977911175, 3.7697427885130144, 4.80846680648574, 5.789743282850492, 6.828264719545125, 7.834634600882636, 8.79759497202787, 9.842576465085376, 10.740385211674205, 9.793458823118184, 8.1741801797694, 7.1334735653958425, 6.097644282157368, 5.099778925299476, 4.035549991893327, 3.0370803738693164, 1.9878666603513, 0.9698263156385714, 0.0, 0.9528289465580679, 1.9935740873331829, 2.972982493453573, 4.030418471681699, 4.979002467754406, 5.952002357621174, 7.008274338193893, 8.066158123261353, 9.116590051736193, 10.080604926452628, 9.158186818345536, 8.969433158674319, 7.931025005976342, 6.946808339157294, 5.996997174785221, 4.988499887957996, 3.9202062172000733, 2.9365867140902964, 1.9375019145705221, 0.9813297232769537, 1.9063952974156604, 2.952269308297556, 3.9853461979320146, 4.9489772465954065, 5.99408581538092, 6.89630851913356, 7.970481725474258, 9.019824339527485, 9.957953961517035, 10.955490290732367, 10.034317338933889, 9.837008632623096, 8.8053244333291, 7.8374818592747735, 6.7977991583954696, 5.833592291932192, 4.899944363223638, 3.910892717948617, 2.9681568043257966, 2.0029741742192346, 2.940389635720904, 3.893496786498643, 4.870315254560373, 5.863283308938038, 6.888107736089021, 7.9515166212643065, 8.908346977211844, 9.976044708785095, 10.919419182267488, 11.715500389931671, 10.774909236651284, 10.760039934878003, 9.804833933381273, 8.824737730237832, 7.796812528739156, 6.771143733761736, 5.83353667404654, 4.926720592044674, 3.893405445111044, 3.0131928431213426, 3.918056960142902, 4.852646949000697, 5.879093026822626, 6.864642942978477, 7.836054143692634, 8.90238415510725, 9.86696840604907, 10.841742348844575, 11.867647368994048, 12.65005910245568, 11.690668045588922, 11.753242023001366, 10.818574472253443, 9.8030552959786, 8.739359087911144, 7.763086836057071, 6.88433556964654, 5.854800712459312, 4.839499391827355, 3.9960438751750385, 4.853836987104346, 5.8013143062223955, 6.767095310009926, 7.697575848440391, 8.743413514522304, 9.751230294821955, 10.729939953326014, 11.689385266692012, 12.7628495929525, 13.614177418164843, 12.679710333507296, 12.702679807492997, 11.71201222459424, 10.764401525689106, 9.752722008563621, 8.731964968035644, 7.764225679308672, 6.777565620741393, 5.7860081742674545, 4.937859765403303, 5.870484632951409, 6.839032848344612, 7.7947113175916, 8.629670184302377, 9.695751992960291, 10.680027067352427, 11.62212058264878, 12.56944517254744, 13.501302852825964, 14.52655837283433, 13.688055638239225, 13.631279863597154, 12.696140926902805, 11.717355912806052, 10.790093989432876, 9.763352801402542, 8.746268742008315, 7.7821998759369, 6.854688405508038, 6.012833075091597, 6.833546683300762, 7.829192688443168, 8.745878806468502, 9.572334823289768, 10.636063204431448, 11.589671927421227, 12.52741133274001, 13.532059857827532, 14.475490597971575, 15.512459535343517, 14.648607850319923, 14.613305118782703, 13.670331167408817, 12.752475147984395, 11.737642185455623, 10.75425109929959, 9.758064842354571, 8.715413423855656, 7.797860772033159, 6.96664604279192, 7.803649115324895, 8.756966707592648, 9.739815777376098, 10.585671047819472, 11.519223892589034, 12.57837392258288, 13.51334271092437, 14.587314936457611, 15.427184839634815, 16.38210175677794, 15.684447098872797, 15.545922515148034, 14.595760765765029, 13.614787903702256, 12.607001457230213, 11.665102977456979, 10.598875253333766, 9.653230627569895, 8.72413005313188, 7.945805792086635, 8.82648278998378, 9.706273165557262, 10.7622673996895, 11.61362766352014, 12.560597049295524, 13.485797492698989, 14.466635437407595, 15.522289776619031, 16.460772244601866, 17.411871694122205, 16.57081072171598, 16.50049560949949, 15.565256152581522, 14.52366194018119, 13.563979166886035, 12.630706905937622, 11.643153002210418, 10.6737428763033, 9.704319035243033, 8.988516843726806, 9.817403290699351, 10.681656689083445, 11.000212229079162, 11.71106215461093, 12.747177114812889, 13.63654866673944, 14.489889015793405, 15.448187476668025, 16.43273488890184, 17.456315660305854, 17.503272933296234, 17.401668006873, 16.38874257255126, 15.459128749831578, 14.49527648108798, 13.65048901363917, 12.65575301936295, 11.682099165673936, 10.774023476368324, 9.99633077856972, 10.870884938054225, 10.710245834063887, 9.958194259748916, 10.736133543942685, 11.748050515083012, 12.607644006874684, 13.546390475820015, 14.49250345283151, 15.462750036178265, 16.42773610279449, 17.38498304291582, 17.361316216945536, 17.351765648045298, 16.398585693103197, 15.468199864306763, 14.585684697076227, 13.616915660902158, 12.731672802449317, 11.785997476547594, 10.949030241517487, 10.608680851609304, 9.668047051518885, 8.910561273170613, 9.743062820050424, 10.705888036998065, 11.668846010477488, 12.608863686460156, 13.602472105915947, 14.54792563316711, 15.503694047993019, 16.446387638922864, 16.415466949398265, 17.290213638113425, 16.294665346881494, 15.33287370410921, 14.536654560560933, 13.552410362788859, 12.584635325715436, 11.540280713767734, 10.635831565286958, 9.673578331987805, 8.696208282970193, 7.9609603256345824, 8.784061145307085, 9.68121309532084, 10.716993622640475, 11.654685506111903, 12.622785858834295, 13.565275274859466, 14.534438434537432, 15.473685687658408, 15.390118462140457, 16.380177142167778, 15.398114571536722, 14.407103725144362, 13.49620851446129, 12.52210293293089, 11.551648052886579, 10.577951555287205, 9.610528874888281, 8.666072121233821, 7.740722001000105, 6.913539287112053, 7.8533705400594105, 8.686437729588897, 9.701946917619301, 10.717090091222868, 11.599428970062556, 12.639705087950622, 13.581683120524774, 14.424420657096674, 14.461917295621086, 15.455382140257885, 14.432957847276056, 13.449170917744885, 12.476199744613055, 11.572561398342243, 10.592867121618792, 9.610853174183875, 8.656431973267601, 7.756044060960424, 6.803069761988343, 5.909752374210418, 6.815456960202432, 7.655244726057804, 8.668796597820833, 9.725368214096244, 10.636405080223547, 11.620901388094552, 12.567373650349436, 13.49285942732989, 13.555271222448164, 14.408719292370654, 13.432678285545364, 12.516986819385869, 11.452422706967443, 10.568081872425367, 9.611780684555821, 8.738279142597804, 7.71262131005682, 6.724578500273672, 5.793420132471787, 4.8382991178868275, 5.766868335349422, 6.707316692006615, 7.713689679172986, 8.708650477696148, 9.676212348914328, 10.640884986670315, 11.601688437613255, 12.601528804944753, 12.676147110309184, 13.41454117341696, 12.45336514068768, 11.516449960704229, 10.518486441915801, 9.669355183729067, 8.659237700636393, 7.7052290270577, 6.71908463708238, 5.758669833264517, 4.821338254558175, 3.9022052509728744, 4.944623627123374, 5.845879702683758, 6.835845779423153, 7.873368926821139, 8.713970395327088, 9.746182865704546, 10.779677856147048, 11.711957742420465, 11.708138228267444, 12.625926779915885, 11.575953820354666, 10.58375824853703, 9.550894968513916, 8.599865012469957, 7.651611112634616, 6.682513093030224, 5.723601543871355, 4.899623337117525, 3.876755105681168, 2.938749627960063, 3.964160080221597, 4.830622905194456, 5.810614171235585, 6.8696920528362035, 7.747325660369787, 8.749739268736434, 9.710501041601592, 10.688600994570674], [10.666795582422354, 9.717151069302805, 8.723808733758815, 7.764016580217244, 6.809099416993751, 5.804401101904901, 4.790119198983063, 3.915368530693574, 2.9051724971462574, 1.9253292774601514, 2.9128951143974007, 3.759196737581, 4.723139410221394, 5.713132308863497, 6.669731839718075, 7.640767666974737, 8.679268601385338, 9.691460560534178, 10.740007801146051, 11.674982073469135, 9.805697663472372, 8.860613569119113, 7.882156362325931, 6.8236185012293005, 5.888465096504, 4.911251883553199, 3.8502259949051254, 2.915000263350434, 1.928253256717973, 0.9331755745449024, 1.8872808325536825, 2.8169138419549467, 3.8556378599276724, 4.836914336292424, 5.875435772987057, 6.881805654324569, 7.844766025469801, 8.889747518527306, 9.876366835567406, 10.746287769676252, 9.127009126327467, 8.08630251195391, 7.050473228715436, 6.052607871857544, 4.988378938451395, 3.989909320427384, 2.940695606909368, 1.9226552621966393, 0.9528289465580679, 0.0, 1.040745140775115, 2.020153546895505, 3.0775895251236305, 4.026173521196338, 4.999173411063104, 6.055445391635823, 7.113329176703283, 8.163761105178123, 9.127775979894558, 10.111015764903604, 9.888229665413112, 8.849821512715135, 7.865604845896086, 6.915793681524013, 5.907296394696788, 4.838539911684695, 3.854920408574918, 2.8558356090551436, 1.899663417761575, 0.9535663508575924, 1.9994403617394882, 3.032517251373946, 3.996148300037338, 5.041256868822852, 5.94347957257549, 7.017652778916188, 8.066995392969414, 9.005125014958963, 10.002661344174296, 10.940169183909488, 10.755342327107716, 9.72365812781372, 8.755815553759394, 7.71613285288009, 6.751925986416812, 5.818278057708259, 4.829226412433238, 3.886490498810418, 2.921307868703856, 1.9875606891628363, 2.9406678399405752, 3.9174863080023057, 4.91045436237997, 5.935278789530953, 6.998687674706239, 7.955518030653775, 9.023215762227027, 9.966590235709416, 10.943827140247729, 11.693242931135904, 11.678373629362625, 10.723167627865895, 9.743071424722451, 8.715146223223776, 7.689477428246358, 6.751870368531161, 5.845054286529296, 4.811739139595666, 3.931526537605964, 2.9652280135848343, 3.899818002442629, 4.926264080264558, 5.91181399642041, 6.883225197134566, 7.949555208549181, 8.914139459491002, 9.888913402286507, 10.91481842243598, 11.851383632933382, 12.609001740073543, 12.671575717485988, 11.736908166738065, 10.72138899046322, 9.657692782395763, 8.681420530541692, 7.802669264131161, 6.773134406943933, 5.757833086311977, 4.91437756965966, 3.9010080405462784, 4.848485359664328, 5.814266363451858, 6.744746901882324, 7.7905845679642365, 8.798401348263887, 9.777111006767946, 10.736556320133944, 11.810020646394433, 12.775481280828025, 13.598044027991918, 13.621013501977622, 12.630345919078865, 11.682735220173731, 10.671055703048246, 9.65029866252027, 8.682559373793296, 7.695899315226016, 6.704341868752078, 5.856193459887924, 4.917655686393341, 5.886203901786544, 6.841882371033532, 7.676841237744309, 8.742923046402224, 9.727198120794359, 10.669291636090712, 11.616616225989372, 12.548473906267896, 13.573729426276262, 14.564985738019711, 14.549613558081779, 13.61447462138743, 12.635689607290677, 11.7084276839175, 10.681686495887167, 9.664602436492938, 8.700533570421523, 7.773022099992661, 6.84542073353028, 5.880717736742694, 6.8763637418851005, 7.793049859910434, 8.6195058767317, 9.68323425787338, 10.63684298086316, 11.574582386181943, 12.579230911269464, 13.522661651413507, 14.55963058878545, 15.525537950100409, 15.531638813267328, 14.588664861893442, 13.67080884246902, 12.655975879940247, 11.672584793784214, 10.676398536839194, 9.63374711834028, 8.716194466517782, 7.786215681010761, 6.850820168766827, 7.80413776103458, 8.78698683081803, 9.632842101261405, 10.566394946030966, 11.625544976024813, 12.560513764366302, 13.634485989899543, 14.474355893076748, 15.42927281021987, 16.417192051975825, 16.464256209632655, 15.514094460249652, 14.533121598186879, 13.525335151714836, 12.583436671941602, 11.51720894781839, 10.571564322054519, 9.642463747616503, 8.765375430305477, 7.873653843425712, 8.753444218999194, 9.809438453131433, 10.660798716962072, 11.607768102737456, 12.532968546140921, 13.513806490849527, 14.569460830060963, 15.507943298043797, 16.459042747564137, 17.428840267367644, 17.418829303984115, 16.483589847066145, 15.441995634665814, 14.482312861370659, 13.549040600422245, 12.561486696695042, 11.592076570787924, 10.622652729727657, 9.808086481945649, 8.864574344141284, 9.728827742525377, 10.718577547070476, 11.6152020749884, 12.5894441601297, 13.549051876753621, 14.486580330048701, 15.44487879092332, 16.429426203157135, 17.45300697456115, 18.3613024789479, 18.320001701357622, 17.30707626703588, 16.3774624443162, 15.413610175572604, 14.568822708123793, 13.574086713847572, 12.60043286015856, 11.692357170852947, 10.815900416788562, 9.918055991496157, 9.757416887505821, 10.739888665119464, 11.632727827410783, 12.64464479855111, 13.525273986685459, 14.46402045563079, 15.410133432642285, 16.38038001598904, 17.345366082605263, 18.337811989473888, 18.241267339642555, 17.30620567214893, 16.26903933363453, 15.342743844367854, 14.521265638010805, 13.626044687850657, 12.589997898319965, 11.597015189950744, 10.615988223070097, 9.655851905051236, 8.715218104960819, 9.69225567854116, 10.639657103518521, 11.602482320466162, 12.586475990288262, 13.52649366627093, 14.555301052474015, 15.500754579725177, 16.456522994551086, 17.399216585480932, 17.295418072095284, 16.337384691555357, 15.341836400323427, 14.380044757551142, 13.583825614002865, 12.59958141623079, 11.631806379157368, 10.587451767209666, 9.68300261872889, 8.720749385429738, 7.743379336412127, 8.74265473100513, 9.687551125691469, 10.62334388640873, 11.659124413728362, 12.59681629719979, 13.575614805392362, 14.518104221417534, 15.4872673810955, 16.426514634216474, 16.311982707825255, 15.427348195609708, 14.445285624978654, 13.454274778586294, 12.543379567903223, 11.569273986372822, 10.598819106328511, 9.625122608729137, 8.657699928330214, 7.713243174675753, 6.787893054442037, 7.724100924581821, 8.756860520443794, 9.628568520676787, 10.644077708707188, 11.659220882310755, 12.552257916620624, 13.59253403450869, 14.534512067082842, 15.377249603654741, 15.38122790030637, 14.502553193699818, 13.480128900717988, 12.496341971186817, 11.523370798054987, 10.619732451784175, 9.640038175060724, 8.658024227625807, 7.7036030267095335, 6.803215114402357, 5.850240815430276, 6.851883165298307, 7.7575877512903215, 8.597375517145693, 9.61092738890872, 10.667499005184132, 11.589234026781615, 12.57373033465262, 13.520202596907504, 14.445688373887958, 14.402763631210721, 13.455890345812586, 12.479849338987297, 11.564157872827801, 10.499593760409375, 9.615252925867297, 8.658951737997752, 7.7854501960397355, 6.759792363498752, 5.771749553715605, 4.840591185913719, 5.780429908974717, 6.708999126437311, 7.649447483094504, 8.655820470260876, 9.650781268784039, 10.629041295472396, 11.593713933228383, 12.554517384171323, 13.55435775150282, 13.535122633999451, 12.461712226858893, 11.500536194129612, 10.563621014146161, 9.565657495357733, 8.716526237170998, 7.706408754078324, 6.7524000804996325, 5.7662556905243125, 4.8058408867064495, 3.8685093080001076, 4.844336042060764, 5.886754418211263, 6.798708649241828, 7.788674725981222, 8.82619787337921, 9.666799341885156, 10.699011812262613, 11.732506802705116, 12.664786688978532, 12.660967174825512, 11.673097833357817, 10.623124873796598, 9.630929301978963, 8.598066021955848, 7.647036065911888, 6.6987821660765485, 5.729684146472156, 4.770772597313287, 3.946794390559457, 2.9239261591231003, 3.8808804190479522, 4.916989026779666, 5.783451851752525, 6.763443117793654, 7.822520999394272, 8.700154606927855, 9.702568215294502, 10.66332998815966, 11.641429941128742], [11.688939465661027, 10.739294952541478, 9.745952616997489, 8.786160463455918, 7.831243300232424, 6.826544985143574, 5.812263082221736, 4.937512413932247, 3.927316380384931, 2.921434813676345, 2.0133121237170735, 2.8470917577796335, 3.8110344304200274, 4.80102732906213, 5.757626859916708, 6.728662687173371, 7.767163621583971, 8.779355580732812, 9.827902821344685, 10.839882548114943, 10.827841546711046, 9.882757452357787, 8.904300245564604, 7.845762384467974, 6.9106089797426735, 5.933395766791872, 4.8723698781437985, 3.937144146589107, 2.9503971399566464, 1.9292811107610963, 0.9751758527523161, 1.9048088621535801, 2.943532880126306, 3.9248093564910578, 4.9633307931856905, 5.969700674523202, 6.932661045668435, 7.97764253872594, 8.96426185576604, 9.91118824432206, 10.134455843815562, 9.127047652729026, 8.091218369490552, 7.093353012632659, 6.02912407922651, 5.0306544612024995, 3.981440747684483, 2.963400402971754, 1.9935740873331829, 1.040745140775115, 0.0, 0.9794084061203902, 2.036844384348516, 2.9854283804212236, 3.9584282702879907, 5.0147002508607095, 6.07258403592817, 7.1230159644030095, 8.087030839119445, 9.150449205239426, 10.928974806188227, 9.89056665349025, 8.906349986671202, 7.9565388222991285, 6.948041535471903, 5.87928505245981, 4.895665549350033, 3.8965807498302585, 2.94040855853669, 1.9943114916327074, 1.066763729537763, 1.9917721105988315, 2.9554031592622234, 4.000511728047737, 4.9027344318003765, 5.976907638141075, 7.026250252194301, 7.964379874183852, 8.961916203399184, 9.899424043134376, 11.781573756781192, 10.764403268588836, 9.79656069453451, 8.756877993655205, 7.792671127191927, 6.859023198483373, 5.8699715532083525, 4.927235639585533, 3.962053009478971, 3.0283058299379513, 2.0079912077388498, 2.9218638650866255, 3.9148319194642904, 4.927120065806276, 5.97286330647472, 6.929693662422256, 7.997391393995507, 8.925845094934305, 9.903081999472617, 10.843673152753004, 12.71911877013774, 11.76391276864101, 10.783816565497567, 9.755891363998892, 8.730222569021471, 7.792615509306275, 6.885799427304409, 5.8524842803707795, 4.972271678381079, 4.001123104688389, 3.0665331158305946, 3.9439074411395536, 4.91619155350473, 5.887602754218886, 6.953932765633501, 7.888315091259482, 8.863089034054987, 9.88899405420446, 10.825559264701862, 11.81846655225422, 13.712320858261103, 12.77765330751318, 11.762134131238335, 10.698437923170879, 9.722165671316805, 8.843414404906275, 7.813879547719047, 6.7985782270870905, 5.950592007901317, 4.936903131649833, 4.015200473052293, 4.9809814768398235, 5.911462015270289, 6.8813455895336775, 7.889162369833328, 8.867872028337386, 9.795923063572232, 10.823613917851022, 11.789074552284614, 12.794428488678431, 14.661758642752735, 13.671091059853978, 12.723480360948844, 11.71180084382336, 10.691043803295383, 9.72330451456841, 8.73664445600113, 7.745087009527191, 6.892407898129582, 5.953550777496896, 5.05291901517451, 6.0085974844214975, 6.843556351132275, 7.909638159790188, 8.859412212370135, 9.801505727666488, 10.748830317565147, 11.680687997843672, 12.705943517852038, 13.697199829595487, 15.590358698856893, 14.655219762162544, 13.676434748065791, 12.749172824692614, 11.72243163666228, 10.705347577268052, 9.741278711196639, 8.813767240767776, 7.881315824633835, 6.916612827846249, 6.104859513647259, 6.9597649732984, 7.786220990119667, 8.849949371261348, 9.803558094251127, 10.73867181929452, 11.743320344382042, 12.682912049639, 13.719880987010942, 14.657752041676185, 16.572383954042444, 15.629410002668555, 14.711553983244134, 13.69672102071536, 12.713329934559328, 11.717143677614308, 10.674492259115395, 9.756939607292896, 8.822110772114316, 7.886715259870382, 7.084477142881309, 7.961180956054373, 8.79955721464937, 9.733110059418932, 10.79226008941278, 11.72460319747888, 12.798575423012121, 13.63460629130224, 14.589523208445364, 15.577442450201318, 17.50500135040777, 16.554839601024767, 15.573866738961994, 14.566080292489952, 13.624181812716717, 12.557954088593505, 11.612309462829634, 10.683208888391617, 9.801270521409032, 8.909548934529267, 8.033783600845924, 8.991542614149646, 9.827513830350037, 10.774483216125422, 11.699683659528887, 12.680521604237493, 13.736175943448929, 14.674658411431762, 15.61929314578963, 16.589090665593137, 18.45957444475923, 17.52433498784126, 16.482740775440927, 15.523058002145774, 14.58978574119736, 13.602231837470157, 12.63282171156304, 11.66339787050277, 10.843981573049204, 9.900469435244839, 9.009167124372107, 9.998916928917206, 10.781917188376365, 11.756159273517666, 12.715766990141587, 13.653295443436667, 14.611593904311286, 15.5961413165451, 16.619722087949114, 17.52155287717339, 18.238930554146204, 17.226005119824464, 16.296391297104783, 15.403562247785269, 14.55405100251655, 13.693784718651306, 12.777856384012996, 11.744125593188398, 10.706972534935513, 10.204437733561033, 10.017220083373338, 11.015511693526095, 11.75684579904461, 12.755285873247542, 13.744671650006342, 14.596793983410057, 15.542906960421552, 16.513153543768308, 17.47813961038453, 18.50784136858593, 17.329162359841188, 16.394100692347564, 15.356934353833164, 14.430638864566486, 13.618855319079493, 12.732622077112097, 11.728282747237614, 10.735300038868393, 9.754273071987747, 9.133628101625751, 9.71132364117701, 10.688361214757354, 11.635762639734715, 12.598587856682355, 13.582581526504455, 14.522599202487124, 15.555090223112733, 16.50313168406956, 17.458900098895473, 18.320545065987638, 16.383313092293918, 15.42527971175399, 14.429731420522058, 13.467939777749773, 12.681415295071554, 11.69717109729948, 10.745662536238372, 9.725736616127316, 8.82128746764654, 8.198525582004253, 8.739484872628319, 9.738760267221323, 10.683656661907662, 11.619449422624921, 12.655229949944554, 13.592921833415982, 14.577991909736747, 15.520481325761919, 16.489644485439886, 17.389437720207038, 15.399877728023883, 14.51524321580834, 13.533180645177286, 12.542169798784926, 11.640969248971912, 10.666863667441511, 9.6964087873972, 8.763407457646787, 7.795984777247863, 7.191019371250269, 7.78399859065823, 8.720206460798014, 9.752966056659988, 10.624674056892978, 11.64018324492338, 12.655326418526947, 13.554635020965009, 14.594911138853075, 15.536889171427227, 16.340172689645303, 14.469122920505, 13.590448213898448, 12.56802392091662, 11.584236991385449, 10.61126581825362, 9.717322132852864, 8.737627856129413, 7.76809310997884, 6.813671909062567, 6.191993638596585, 6.846346351646469, 7.847988701514501, 8.753693287506515, 9.593481053361884, 10.607032925124912, 11.663604541400323, 12.591611131126, 13.576107438997004, 14.522579701251889, 15.40861145987852, 13.490658651409351, 12.543785366011216, 11.567744359185927, 10.652052893026433, 9.587488780608009, 8.703147946065931, 7.7468467581963845, 6.895519078392769, 5.869861245851785, 5.160528077909833, 5.836696722129912, 6.77653544519091, 7.705104662653504, 8.645553019310697, 9.651926006477067, 10.64688680500023, 11.63141839981678, 12.596091037572767, 13.556894488515708, 14.444401068912763, 12.623017654198081, 11.549607247057523, 10.588431214328242, 9.651516034344793, 8.653552515556367, 7.804421257369631, 6.7943037742769565, 5.840295100698266, 4.854150710722946, 4.118675463574551, 4.864614844216301, 5.840441578276957, 6.882859954427456, 7.820852532480501, 8.810818609219895, 9.848341756617883, 10.68894322512383, 11.721155695501288, 12.754650685943789, 13.587207022086801, 11.806934374431869, 10.760992853556449, 9.71101989399523, 8.718824322177595, 7.6859610421544815, 6.734931086110521, 5.786677186275181, 4.8175791666707894, 3.8586676175119203, 3.0472113998791297, 3.9200316953392935, 4.8769859552641455, 5.924410534919635, 6.805595734991198, 7.785587001032327, 8.844664882632946, 9.72229849016653, 10.724712098533177, 11.685473871398333, 12.663573824367415], [10.856868582299118, 11.631251555119743, 10.637909219575754, 9.678117066034183, 8.723199902810691, 7.718501587721841, 6.704219684800003, 5.829469016510513, 4.819272982963198, 3.8133914162546123, 2.9052687262953407, 1.8797823415553727, 2.843725014195767, 3.8337179128378693, 4.790317443692447, 5.76135327094911, 6.79985420535971, 7.812046164508551, 8.860593405120424, 9.872573131890682, 9.88446893430168, 10.774714054936053, 9.796256848142871, 8.73771898704624, 7.80256558232094, 6.825352369370139, 5.764326480722065, 4.829100749167374, 3.8423537425349137, 2.8212377133393636, 1.8671324553305833, 0.9374994459293191, 1.9762234639020448, 2.9574999402667967, 3.99602137696143, 5.002391258298942, 5.965351629444174, 7.010333122501679, 7.99695243954178, 8.9438788280978, 9.155047437695172, 10.106456058849417, 9.070626775610943, 8.07276141875305, 7.0085324853469, 6.0100628673228895, 4.960849153804873, 3.9428088090921447, 2.972982493453573, 2.020153546895505, 0.9794084061203902, 0.0, 1.0574359782281257, 2.006019974300833, 2.9790198641676002, 4.035291844740319, 5.09317562980778, 6.1436075582826195, 7.1076224329990545, 8.171040799119035, 9.984899817273556, 10.86997505961064, 9.885758392791592, 8.935947228419518, 7.927449941592293, 6.8586934585802, 5.875073955470423, 4.8759891559506485, 3.9198169646570804, 2.9737198977530976, 2.046172135658153, 1.0123637044784413, 1.975994753141833, 3.021103321927346, 3.9233260256799865, 4.997499232020685, 6.046841846073911, 6.984971468063462, 7.982507797278794, 8.920015637013986, 10.802165350660802, 11.743811674709226, 10.7759691006549, 9.736286399775596, 8.772079533312317, 7.838431604603763, 6.8493799593287426, 5.906644045705923, 4.9414614155993615, 3.986615973226109, 2.9192739270279655, 1.942455458966235, 2.9354235133439, 3.947711659685885, 4.99345490035433, 5.950285256301866, 7.017982987875117, 7.946436688813915, 8.923673593352227, 9.864264746632614, 11.749207891261293, 12.704413892758023, 11.763224971617957, 10.735299770119282, 9.709630975141861, 8.772023915426665, 7.865207833424799, 6.8318926864911695, 5.89805767759751, 4.912405823977505, 3.97781583511971, 2.9644990350191636, 3.936783147384339, 4.908194348098495, 5.97452435951311, 6.908906685139092, 7.883680627934597, 8.90958564808407, 9.846150858581472, 10.83905814613383, 12.742409979384655, 13.717995475566445, 12.741542537358724, 11.677846329291267, 10.701574077437195, 9.822822811026665, 8.793287953839437, 7.7779866332074805, 6.861874727190433, 5.848185850938949, 4.926483192341409, 4.015055049477488, 4.945535587907954, 5.9019371834132865, 6.909753963712937, 7.888463622216995, 8.816514657451842, 9.844205511730632, 10.809666146164226, 11.815020082558043, 13.709616292682798, 14.650499465974368, 13.702888767069235, 12.69120924994375, 11.670452209415773, 10.7027129206888, 9.71605286212152, 8.724495415647581, 7.803690617418697, 6.864833496786011, 5.964201734463625, 5.0468579974818795, 5.877629923769939, 6.943711732427853, 7.880003806249744, 8.822097321546098, 9.769421911444757, 10.701279591723281, 11.726535111731648, 12.717791423475097, 14.638216348786955, 15.634347174159261, 14.655843154186181, 13.728581230813004, 12.70184004278267, 11.684755983388442, 10.720687117317029, 9.793175646888166, 8.792598543922951, 7.827895547135364, 7.0161422329363745, 5.998025486358782, 6.820294562757332, 7.884022943899012, 8.837631666888791, 9.75926341317413, 10.763911938261652, 11.703503643518612, 12.740472580890554, 13.678343635555795, 15.644708393497066, 16.587682344870952, 15.690962389364524, 14.67612942683575, 13.692738340679718, 12.696552083734698, 11.638601391543576, 10.70319518331673, 9.733393491403431, 8.797997979159497, 7.982290538898205, 6.999441469114755, 7.833630787287035, 8.767183632056597, 9.826333662050445, 10.74519479135849, 11.81916701689173, 12.655197885181853, 13.610114802324976, 14.59803404408093, 16.6113398186935, 17.518948733452948, 16.537975871390177, 15.530189424918133, 14.588290945144898, 13.522063221021686, 12.576418595257815, 11.62946446441545, 10.712553240698147, 9.820831653818383, 8.931596996862819, 8.029803127210029, 8.861587402987702, 9.808556788763086, 10.733757232166552, 11.704898382080724, 12.76055272129216, 13.699035189274994, 14.639884739669242, 15.609682259472748, 17.56591291304496, 17.19451664628385, 16.264548690530912, 15.367550145762955, 14.61408559816172, 13.787267693947484, 12.81890325715937, 11.811484091956627, 10.747477053554165, 10.811752154533954, 9.906980520389002, 9.055303710414693, 9.81599076101403, 10.79023284615533, 11.749840562779251, 12.677672221279899, 13.635970682154518, 14.620518094388332, 15.644098865792344, 16.542144471053003, 17.271621137921944, 16.258695703600203, 15.329081880880523, 14.436252831561008, 13.58674158629229, 12.726475302427046, 11.810546967788735, 10.776816176964138, 9.739663118711253, 10.71102101311732, 10.915033479390235, 10.097321679744939, 10.790919371682275, 11.789359445885207, 12.778745222644007, 13.621170761253289, 14.567283738264784, 15.53753032161154, 16.502516388227765, 17.52843296246554, 16.361852943616928, 15.426791276123303, 14.389624937608904, 13.463329448342225, 12.651545902855233, 11.765312660887837, 10.760973331013354, 9.767990622644133, 8.786963655763486, 9.715740845053547, 10.603280243755279, 11.144954666323242, 11.783990095574536, 12.746815312522177, 13.717543219041204, 14.558697550613148, 15.533422929772618, 16.52598043447941, 17.51021716868139, 17.353235649763377, 15.416003676069657, 14.45797029552973, 13.462422004297798, 12.500630361525513, 11.714105878847294, 10.729861681075219, 9.778353120014112, 8.758427199903055, 7.8539780514222794, 8.780638325432049, 9.631441475206588, 10.630716869799592, 11.57561326448593, 12.511406025203188, 13.547186552522822, 14.48487843599425, 15.469948512315014, 16.412437928340186, 17.25975865168002, 16.422128303982777, 14.432568311799622, 13.54793379958408, 12.565871228953025, 11.574860382560665, 10.673659832747651, 9.69955425121725, 8.72909937117294, 7.7960980414225265, 6.828675361023603, 7.773132114678064, 8.675955193236499, 9.612163063376283, 10.644922659238256, 11.516630659471245, 12.532139847501648, 13.547283021105216, 14.446591623543275, 15.486867741431341, 16.30700333766736, 15.372863273421043, 13.50181350428074, 12.623138797674187, 11.600714504692359, 10.616927575161188, 9.64395640202936, 8.750012716628603, 7.770318439905152, 6.800783693754579, 5.846362492838306, 6.884360143655141, 7.7383029542247375, 8.739945304092767, 9.645649890084782, 10.485437655940151, 11.49898952770318, 12.555561143978592, 13.483567733704266, 14.468064041575271, 15.366787820634713, 14.44130204365426, 12.52334923518509, 11.576475949786955, 10.600434942961666, 9.684743476802172, 8.620179364383748, 7.73583852984167, 6.779537341972124, 5.928209662168508, 4.902551829627525, 5.890594639410672, 6.72865332470818, 7.668492047769177, 8.59706126523177, 9.537509621888963, 10.543882609055334, 11.538843407578497, 12.523375002395047, 13.488047640151034, 14.448851091093974, 13.477091652688502, 11.65570823797382, 10.582297830833262, 9.621121798103982, 8.684206618120532, 7.686243099332106, 6.83711184114537, 5.826994358052696, 4.872985684474006, 3.886841294498686, 4.8698684179914125, 5.756571446794569, 6.732398180855224, 7.774816557005723, 8.712809135058768, 9.70277521179816, 10.740298359196148, 11.580899827702096, 12.613112298079553, 13.646607288522054, 12.61989760586254, 10.839624958207608, 9.793683437332188, 8.74371047777097, 7.751514905953334, 6.718651625930221, 5.76762166988626, 4.8193677700509205, 3.850269750446529, 2.8913582012876597, 3.939168002457397, 4.811988297917561, 5.768942557842413, 6.8163671374979025, 7.697552337569465, 8.677543603610593, 9.736621485211213, 10.614255092744795, 11.616668701111442, 12.577430473976598, 11.859162191904378], [9.8016620485244, 10.750382379560378, 11.695345197803881, 10.73555304426231, 9.780635881038817, 8.775937565949967, 7.761655663028129, 6.886904994738639, 5.876708961191323, 4.870827394482737, 3.9627047045234662, 2.9372183197834985, 2.0871271160370175, 2.9226395240189786, 3.8677802359994478, 4.83881606325611, 5.877316997666711, 6.889508956815551, 7.8745420372897295, 8.817366598115965, 8.829262400526963, 9.774346494880222, 10.752803701673404, 9.795154965274367, 8.860001560549067, 7.8827883475982645, 6.821762458950191, 5.8865367273955, 4.899789720763039, 3.8786736915674886, 2.9245684335587088, 1.9949354241574448, 1.0215599156570334, 1.9707022435493742, 2.940814843186712, 3.9471847245242238, 4.910145095669456, 5.955126588726961, 6.941745905767062, 7.888672294323082, 8.097611459467046, 9.138318073840603, 10.12806275383907, 9.130197396981176, 8.065968463575027, 7.0674988455510155, 6.018285132032999, 5.000244787320271, 4.030418471681699, 3.077589525123631, 2.036844384348516, 1.0574359782281257, 0.0, 0.9485839960727075, 1.9215838859394747, 2.977855866512194, 4.035739651579655, 5.0861715800544935, 6.0501864547709285, 7.11360482089091, 8.927463839045432, 9.965871991743409, 10.942132578141184, 9.99232141376911, 8.983824126941885, 7.915067643929792, 6.931448140820015, 5.93236334130024, 4.976191150006672, 4.030094083102689, 2.9842200722207934, 1.930535848316297, 0.9669047996529055, 1.9954442050403518, 2.8658900474518605, 3.940063253792559, 4.989405867845786, 5.9275354898353365, 6.925071819050669, 7.862579658785862, 9.744729372432676, 10.776413571726671, 11.744256145780998, 10.748361928633985, 9.784155062170706, 8.850507133462154, 7.861455488187132, 6.918719574564312, 5.936288088665033, 4.904788117063966, 3.8374460708658216, 2.860627602804091, 1.9428774191297475, 2.9220525427988906, 3.9360189221262036, 4.89284927807374, 5.960547009646991, 6.8890007105857896, 7.866237615124102, 8.806828768404488, 10.691771913033167, 11.646977914529897, 12.63838492813315, 11.747375298977671, 10.721706504000252, 9.784099444285056, 8.82245782880455, 7.789142681870921, 6.816229821435367, 5.830577967815361, 4.895987978957566, 3.882671178857019, 2.9442370531701867, 3.915648253884343, 4.9654767989140804, 5.851470706910966, 6.826244649706471, 7.852149669855944, 8.788714880353346, 9.781622167905704, 11.68497400115653, 12.660559497338319, 13.670647522985238, 12.68992185814966, 11.713649606295586, 10.822952872277597, 9.750537949219188, 8.73523662858723, 7.780046871028289, 6.766357994776805, 5.844655336179265, 4.920028237437831, 3.989547699007365, 4.909391089199135, 5.917207869498785, 6.843570516453931, 7.759078679223716, 8.786769533502506, 9.752230167936098, 10.757584104329915, 12.652180314454672, 13.642847897353429, 14.590458596258562, 13.6484592453235, 12.627702204795522, 11.65996291606855, 10.67330285750127, 9.68174541102733, 8.721862761256553, 7.783005640623868, 6.877834669939101, 5.922156200692113, 4.92164203486935, 5.977551318779483, 6.887457712035592, 7.829551227331945, 8.723010997046135, 9.654868677324659, 10.680124197333026, 11.671380509076474, 13.580780370558829, 14.576911195931135, 15.543412983375509, 14.685831226192754, 13.65909003816242, 12.642005978768191, 11.677937112696778, 10.73644302012865, 9.710770687760808, 8.746067690973222, 7.863696143758514, 6.823969951351488, 5.864306673856743, 6.928035054998423, 7.881643777988201, 8.766717318959977, 9.725627046641442, 10.657092729119988, 11.69406166649193, 12.631932721157172, 14.587272415268941, 15.530246366642828, 16.57689847400198, 15.610935914609778, 14.627544828453745, 13.631358571508725, 12.556773535381433, 11.621367327154587, 10.651565635241289, 9.716170122997354, 8.808235003890912, 7.825385934107461, 6.877642898386446, 7.8111957431560075, 8.870345773149856, 9.752648697144336, 10.781829751522064, 11.608786970783228, 12.563703887926351, 13.551623129682305, 15.553903840465377, 16.50406558984838, 16.279918814462544, 15.461108335119233, 14.745248579401155, 13.947967218199345, 13.019093384868986, 12.298785394766375, 11.630725384536005, 10.73900379765624, 9.757541461855526, 8.836747512193377, 7.905599514087113, 8.852568899862497, 9.777769343265962, 10.71235228786657, 11.768006627078007, 12.679401424290287, 13.593473825270618, 14.563271345074124, 16.508476934816837, 16.27197943859085, 15.34201148283791, 14.445012938069954, 13.70300720934283, 12.876189305128594, 11.99858113613558, 11.318596412655221, 11.804913031782293, 11.729219201705689, 10.73292498538171, 9.86224809539804, 8.86000287211344, 9.834244957254741, 10.793852673878662, 11.685126127065745, 12.643424587940364, 13.627972000174179, 14.618427749090216, 15.495733556654379, 16.34908393022894, 15.3361584959072, 14.406544673187522, 13.513715623868007, 12.6756631974734, 11.815396913608156, 10.990224846764946, 10.24889197152993, 10.79709909693938, 11.768456991345447, 11.74097794438294, 10.88812598076163, 9.834931482781686, 10.833371556984618, 11.822757333743418, 12.628624667039135, 13.57473764405063, 14.544984227397386, 15.50997029401361, 16.482022048066916, 15.439315735923927, 14.504254068430303, 13.467087729915903, 12.540792240649225, 11.740467514036343, 10.854234272068947, 9.940651209989566, 9.23691797135066, 9.844399633991612, 10.773176823281672, 11.660716221983403, 11.775403631651308, 10.828002206673947, 11.790827423621588, 12.761555330140615, 13.566151456398995, 14.540876835558464, 15.533434340265257, 16.517671074467234, 16.430698442070376, 14.493466468376656, 13.53543308783673, 12.539884796604797, 11.578093153832512, 10.803027490028404, 9.81878329225633, 8.86727473119522, 8.227354548609583, 8.911414029650405, 9.838074303660173, 10.688877453434712, 11.688152848027716, 11.787003881417286, 12.805949272279296, 13.713407717977628, 14.546732557314677, 15.520563082640116, 16.463052498665288, 16.337221443987016, 15.499591096289777, 13.510031104106622, 12.625396591891079, 11.643334021260024, 10.652323174867664, 9.762581443928761, 8.78847586239836, 7.8180209823540485, 7.265025390129054, 7.886111339251729, 8.830568092906189, 9.733391171464623, 10.669599041604407, 11.70235863746638, 12.574066637699373, 13.589575825729776, 14.604718999333343, 15.504027601771403, 16.425159591607144, 15.384466129974358, 14.450326065728042, 12.57927629658774, 11.700601589981186, 10.678177296999358, 9.694390367468188, 8.72141919433636, 7.838934327809714, 6.859240051086261, 6.202609451294613, 6.903798471066432, 7.941796121883267, 8.795738932452862, 9.797381282320895, 10.70308586831291, 11.542873634168279, 12.556425505931308, 13.61299712220672, 14.541003711932394, 15.406355891751074, 14.444250612941712, 13.518764835961258, 11.60081202749209, 10.653938742093954, 9.677897735268665, 8.762206269109171, 7.6976421566907485, 6.82476014102278, 5.868458953153233, 5.2326538667157845, 5.959987807855651, 6.948030617638798, 7.786089302936305, 8.725928025997304, 9.654497243459899, 10.594945600117091, 11.601318587283462, 12.596279385806625, 13.580810980623175, 14.515198263269939, 13.554394812326999, 12.554554444995501, 10.73317103028082, 9.659760623140262, 8.69858459041098, 7.7616694104275314, 6.763705891639106, 5.914574633452371, 4.915915969233805, 4.167631633857799, 4.944277272726811, 5.927304396219538, 6.814007425022694, 7.78983415908335, 8.832252535233849, 9.770245113286892, 10.760211190026286, 11.797734337424274, 12.638335805930224, 13.67054827630768, 12.732175062156703, 11.69736039816954, 9.823097441116914, 8.871146229639187, 7.82117327007797, 6.828977698260334, 5.796114418237221, 4.845084462193261, 3.90828938123203, 3.1317415608327663, 3.9487941795157857, 4.9966039806855225, 5.869424276145686, 6.826378536070538, 7.8738031157260275, 8.75498831579759, 9.734979581838719, 10.794057463439339, 11.671691070972923, 12.67410467933957, 11.696561298417233, 10.842634674813684], [8.853078052451693, 9.801798383487672, 10.79514071903166, 11.684137040335019, 10.729219877111523, 9.724521562022673, 8.710239659100836, 7.835488990811347, 6.825292957264031, 5.819411390555445, 4.911288700596174, 3.885802315856206, 2.9640484265883735, 1.9740555279462708, 2.9191962399267406, 3.890232067183403, 4.928733001594003, 5.940924960742844, 6.925958041217022, 7.868782602043258, 7.8806784044542555, 8.825762498807515, 9.804219705600698, 10.743738961347075, 9.808585556621775, 8.831372343670973, 7.770346455022899, 6.835120723468208, 5.848373716835747, 4.827257687640197, 3.8731524296314164, 2.9435194202301522, 1.9701439117297408, 1.0221182474766666, 1.9922308471140047, 2.998600728451516, 3.961561099596749, 5.006542592654254, 5.993161909694355, 6.940088298250375, 7.149027463394339, 8.189734077767895, 9.225563361006369, 10.078781393053882, 9.014552459647733, 8.016082841623723, 6.966869128105706, 5.948828783392977, 4.979002467754405, 4.026173521196338, 2.985428380421223, 2.006019974300833, 0.9485839960727075, 0.0, 0.9729998898667671, 2.0292718704394863, 3.0871556555069466, 4.1375875839817855, 5.1016024586982205, 6.165020824818202, 7.978879842972724, 9.017287995670701, 10.001504662489749, 10.940905409841818, 9.932408123014593, 8.8636516400025, 7.880032136892723, 6.880947337372948, 5.92477514607938, 4.978678079175397, 3.9328040682935015, 2.8791198443890047, 1.915488795725613, 1.0468602089676444, 1.917306051379153, 2.9914792577198517, 4.040821871773078, 4.9789514937626285, 5.976487822977961, 6.913995662713154, 8.796145376359968, 9.827829575653965, 10.795672149708292, 11.696945924706691, 10.732739058243412, 9.79909112953486, 8.810039484259839, 7.867303570637018, 6.884872084737739, 5.853372113136672, 4.786030066938529, 3.8092115988767983, 2.891461415202455, 1.9734685467261834, 2.987434926053496, 3.944265282001033, 5.0119630135742845, 5.9404167145130815, 6.917653619051394, 7.85824477233178, 9.743187916960458, 10.698393918457189, 11.689800932060441, 12.695959295050377, 11.670290500072959, 10.732683440357762, 9.771041824877258, 8.737726677943629, 7.764813817508074, 6.779161963888068, 5.844571975030274, 4.831255174929726, 3.8928210492428943, 3.0147900659802707, 4.016892802841373, 4.902886710838259, 5.877660653633764, 6.903565673783237, 7.840130884280639, 8.833038171832996, 10.736390005083821, 11.711975501265611, 12.72206352691253, 13.638505854222366, 12.662233602368293, 11.771536868350305, 10.699121945291896, 9.683820624659939, 8.728630867100996, 7.714941990849512, 6.793239332251972, 5.868612233510538, 4.938131695080072, 4.008532901295062, 5.016349681594713, 5.894986520381224, 6.81049468315101, 7.838185537429799, 8.803646171863392, 9.809000108257209, 11.703596318381964, 12.69426390128072, 13.641874600185854, 14.597043241396207, 13.57628620086823, 12.608546912141257, 11.621886853573978, 10.630329407100039, 9.67044675732926, 8.731589636696574, 7.826418666011807, 6.870740196764819, 5.8702260309420575, 5.076693130875411, 5.9865995241315195, 6.910966991160725, 7.774427000973429, 8.706284681251953, 9.73154020126032, 10.722796513003768, 12.63219637448612, 13.628327199858427, 14.594828987302801, 15.61108155739819, 14.607674034235128, 13.5905899748409, 12.626521108769486, 11.685027016201357, 10.659354683833515, 9.694651687045928, 8.81228013983122, 7.7725539474241945, 6.81289066992945, 6.0707913237127, 7.002201426681106, 7.848133082788757, 8.777043050568736, 9.708508733047282, 10.745477670419223, 11.683348725084466, 13.638688419196232, 14.581662370570118, 15.628314477929267, 15.510727103397121, 14.740625578821845, 13.955321850471385, 13.00832659251052, 12.569951323227293, 11.600149631313995, 10.66475411907006, 9.756818999963619, 8.773969930180169, 7.826226894459154, 7.028390346244165, 7.990903421842759, 8.834064460973117, 9.833245755449358, 10.660202974710522, 11.615119891853645, 12.603039133609599, 14.605319844392668, 15.555481593775673, 15.331334818389838, 14.512524339046527, 13.796664583328447, 12.999383222126639, 12.07050938879628, 12.885818360340354, 12.579309380608711, 11.687587793728946, 10.706125457928232, 9.785331508266085, 8.854183510159821, 8.07478922321641, 8.943068448436804, 9.793768051695352, 10.849422390906788, 11.73081742821758, 12.644889829197911, 13.614687349001418, 15.559892938744127, 15.323395442518144, 14.393427486765203, 13.496428941997248, 12.754423213270123, 11.927605309055888, 11.049997140062874, 11.9056293782292, 12.738282728632521, 12.677803197778395, 11.681508981454416, 10.810832091470749, 9.808586868186149, 9.056465280608654, 9.959151779049504, 10.766541890894526, 11.724840351769146, 12.70938776400296, 13.66984375301751, 14.547149560581673, 15.400499934156233, 14.387574499834495, 13.457960677114816, 12.565131627795301, 11.727079201400691, 10.86681291753545, 10.04164085069224, 10.83592493710391, 11.730468793789608, 12.701826688195675, 12.689561940455647, 11.836709976834339, 10.783515478854394, 10.05559188033853, 10.98805643891426, 11.710040430867917, 12.656153407879412, 13.626399991226167, 14.591386057842392, 15.53343805199421, 14.49073173985122, 13.555670072357596, 12.518503733843197, 11.592208244576518, 10.791883517963635, 9.90565027599624, 8.992067213916858, 9.82395093692464, 10.77776933084184, 11.7065465201319, 12.609300218056113, 12.723987627724016, 11.776586202746655, 11.097754358423478, 11.926854435311457, 12.647567220227776, 13.622292599387245, 14.614850104094039, 15.599086838296016, 15.482114445997672, 13.54488247230395, 12.586849091764023, 11.59130080053209, 10.629509157759806, 9.854443493955696, 8.870199296183623, 7.918690735122512, 8.814387514183561, 9.844783726500633, 10.771444000510401, 11.637461449507422, 12.636736844100426, 12.735587877489994, 12.128024565713494, 12.87870682314847, 13.628148321143458, 14.601978846468896, 15.544468262494068, 15.38863744791431, 14.55100710021707, 12.561447108033915, 11.676812595818372, 10.694750025187318, 9.703739178794958, 8.813997447856053, 7.839891866325654, 6.8694369862813405, 7.852058355703033, 8.819481036101957, 9.763937789756417, 10.681975167537333, 11.618183037677117, 12.65094263353909, 13.122799931445437, 13.893753528169643, 14.565743736032493, 15.625335735240634, 15.476575595534438, 14.435882133901652, 13.501742069655336, 11.630692300515033, 10.75201759390848, 9.729593300926652, 8.745806371395481, 7.772835198263653, 6.890350331737006, 5.910656055013553, 6.89267000244847, 7.847091203364743, 8.885088854181578, 9.744322928525571, 10.745965278393603, 11.651669864385617, 12.491457630240987, 13.505009502004015, 14.561581118279426, 15.489587708005102, 14.457771895678368, 13.495666616869006, 12.570180839888552, 10.652228031419384, 9.705354746021248, 8.729313739195959, 7.813622273036465, 6.749058160618041, 5.876176144950072, 4.919874957080525, 5.936350204485519, 6.908571803928358, 7.896614613711505, 8.734673299009014, 9.674512022070012, 10.603081239532607, 11.5435295961898, 12.54990258335617, 13.544863381879333, 14.529394976695883, 13.566614267197233, 12.605810816254293, 11.605970448922795, 9.784587034208114, 8.711176627067555, 7.750000594338275, 6.813085414354824, 5.815121895566399, 4.965990637379664, 3.967331973161097, 4.922355704872212, 5.8928612687995185, 6.875888392292245, 7.762591421095402, 8.738418155156058, 9.780836531306557, 10.7188291093596, 11.708795186098993, 12.74631833349698, 13.586919802002932, 12.793745997832962, 11.783591066083996, 10.748776402096833, 8.874513445044206, 7.92256223356648, 6.8725892740052625, 5.880393702187627, 4.847530422164514, 3.8965004661205542, 2.959705385159322, 3.9909618119392594, 4.897378175588493, 5.9451879767582305, 6.818008272218394, 7.774962532143246, 8.822387111798735, 9.703572311870298, 10.683563577911425, 11.742641459512045, 12.62027506704563, 11.760468143001455, 10.747977302344527, 9.894050678740975], [7.880078162584927, 8.828798493620905, 9.822140829164894, 10.781932982706465, 11.70221976697829, 10.69752145188944, 9.683239548967602, 8.808488880678114, 7.7982928471307975, 6.792411280422212, 5.8832070424832, 4.856731452197048, 3.892788779556654, 2.9027958809145513, 1.9461963500599735, 2.917232177316636, 3.9557331117272363, 4.967925070876078, 5.952958151350256, 6.895782712176492, 6.907678514587489, 7.852762608940749, 8.831219815733931, 9.889757676830563, 10.781585446488542, 9.80437223353774, 8.743346344889666, 7.8081206133349745, 6.8213736067025135, 5.800257577506963, 4.8461523194981835, 3.91651931009692, 2.9431438015965083, 1.9951181373434337, 1.0192309572472376, 2.025600838584749, 2.988561209729982, 4.0335427027874875, 5.0201620198275885, 5.967088408383608, 6.176027573527573, 7.21673418790113, 8.252563471139604, 9.250428827997498, 9.987552349514502, 8.989082731490491, 7.939869017972474, 6.921828673259745, 5.952002357621174, 4.999173411063106, 3.9584282702879907, 2.9790198641676007, 1.9215838859394747, 0.9729998898667671, 0.0, 1.0562719805727192, 2.11415576564018, 3.1645876941150193, 4.128602568831455, 5.192020934951437, 7.005879953105957, 8.044288105803934, 9.028504772622982, 9.978315936995056, 10.90540801288136, 9.836651529869266, 8.85303202675949, 7.853947227239715, 6.897775035946147, 5.951677969042164, 4.905803958160268, 3.852119734255772, 2.8884886855923804, 1.9924202824825126, 0.944306161512386, 2.018479367853084, 3.0678219819063113, 4.005951603895862, 5.003487933111194, 5.940995772846387, 7.8231454864932015, 8.854829685787198, 9.822672259841525, 10.862354960720829, 11.70573894811018, 10.772091019401628, 9.783039374126608, 8.840303460503787, 7.857871974604508, 6.82637200300344, 5.759029956805296, 4.782211488743566, 3.8644613050692227, 2.9190286202410514, 2.014435036186729, 2.9712653921342653, 4.038963123707516, 4.967416824646315, 5.944653729184627, 6.885244882465013, 8.770188027093692, 9.725394028590422, 10.716801042193675, 11.74472624369235, 12.643290389939727, 11.705683330224531, 10.744041714744025, 9.710726567810395, 8.73781370737484, 7.752161853754836, 6.817571864897041, 5.804255064796494, 4.865820939109662, 3.960350139495138, 3.043892912974606, 3.9298868209714914, 4.904660763766996, 5.930565783916469, 6.867130994413872, 7.86003828196623, 9.763390115217055, 10.738975611398844, 11.749063637045763, 12.73392967268104, 13.635233492235061, 12.744536758217071, 11.672121835158663, 10.656820514526705, 9.701630756967765, 8.68794188071628, 7.76623922211874, 6.841612123377306, 5.91113158494684, 4.95409297480993, 4.102029107499006, 4.921986630514456, 5.837494793284241, 6.865185647563031, 7.830646281996624, 8.836000218390442, 10.730596428515197, 11.721264011413954, 12.668874710319088, 13.680554227444572, 14.549286090734997, 13.581546802008024, 12.594886743440744, 11.603329296966805, 10.64344664719603, 9.704589526563343, 8.799418555878576, 7.843740086631588, 6.843225920808826, 6.022253204390278, 5.0722789500358125, 5.9379671012939585, 6.80142711110666, 7.733284791385184, 8.758540311393551, 9.749796623137, 11.659196484619354, 12.65532730999166, 13.621829097436034, 14.638081667531424, 14.837013578360494, 14.1787148701539, 13.599520998636253, 12.658026906068125, 11.632354573700283, 10.667651576912696, 9.785280029697988, 8.745553837290963, 7.7858905597962185, 7.0163513972275675, 6.087880852585399, 6.87513319292199, 7.804043160701967, 8.735508843180515, 9.772477780552457, 10.710348835217697, 12.665688529329465, 13.608662480703352, 14.6553145880625, 14.537727213530355, 13.786343298758915, 13.166918769807644, 13.927641865794113, 13.542951213094062, 12.573149521180763, 11.63775400893683, 10.729818889830387, 9.746969820046937, 8.799226784325922, 7.973950419759032, 7.076582847747053, 7.86106457110635, 8.860245865582588, 9.687203084843755, 10.642120001986878, 11.630039243742832, 13.6323199545259, 14.582481703908906, 14.358334928523071, 13.53952444917976, 12.842382303265516, 12.210980141462898, 12.989824662079874, 13.805133633623948, 13.55230927047548, 12.660587683595715, 11.679125347795, 10.758331398132853, 9.82718340002659, 8.953948317744564, 8.028747874341098, 8.820768161828585, 9.876422501040022, 10.757817538350814, 11.671889939331145, 12.641687459134651, 14.58689304887736, 14.350395552651378, 13.420427596898437, 12.523429052130481, 11.800140933207192, 11.139202228392147, 11.969312413346469, 12.824944651512794, 13.657598001916115, 13.650803087645164, 12.654508871321184, 11.783831981337517, 10.781586758052917, 9.935624375136808, 9.044831204953798, 9.79354200102776, 10.751840461902379, 11.736387874136193, 12.696843863150743, 13.574149670714906, 14.427500044289467, 13.414574609967728, 12.484960787248049, 11.592131737928534, 10.772796921337761, 10.078409836871709, 10.960956123975834, 11.755240210387504, 12.649784067073202, 13.62114196147927, 13.662561830322417, 12.809709866701107, 11.756515368721162, 10.934750974866684, 10.073735864818554, 10.73704054100115, 11.683153518012645, 12.6534001013594, 13.618386167975626, 14.560438162127443, 13.517731849984454, 12.58267018249083, 11.54550384397643, 10.619208354709752, 9.837601237900705, 9.1172471953325, 9.911382487200452, 10.743266210208233, 11.697084604125434, 12.625861793415494, 13.535928233792507, 13.696987517590784, 12.749586092613423, 11.976913452951631, 11.01253386121575, 11.67456733036101, 12.649292709520479, 13.641850214227272, 14.626086948429249, 14.509114556130905, 12.571882582437183, 11.613849201897256, 10.618300910665324, 9.656509267893039, 8.900161213892765, 8.081796215519882, 8.838006008406106, 9.733702787467156, 10.764098999784228, 11.690759273793995, 12.564089465243816, 13.56336485983682, 13.708587767356763, 13.007183660241648, 11.964386249052763, 12.655148431276691, 13.628978956602129, 14.5714683726273, 14.415637558047546, 13.578007210350306, 11.58844721816715, 10.703812705951606, 9.721750135320551, 8.730739288928191, 7.859715167793123, 7.051488785661913, 7.7887522595649346, 8.771373628986627, 9.73879630938555, 10.683253063040011, 11.608603183273727, 12.544811053413511, 13.577570649275485, 14.00195902597359, 12.979432954073937, 13.592743846165726, 14.652335845373868, 14.503575705667673, 13.462882244034887, 12.528742179788571, 10.657692410648268, 9.779017704041713, 8.756593411059884, 7.772806481528714, 6.799835308396885, 6.101947251073265, 6.829971328297147, 7.811985275732064, 8.766406476648337, 9.804404127465173, 10.717322818392336, 11.718965168260368, 12.624669754252382, 13.464457520107752, 14.012583273872405, 14.58446572329235, 14.518479746395673, 13.484772005811603, 12.52266672700224, 11.597180950021787, 9.679228141552619, 8.732354856154483, 7.756313849329193, 6.840622383169698, 5.776058270751274, 5.050258392888053, 5.839190230364119, 6.855665477769113, 7.843525903259965, 8.831568713043113, 9.707673188875779, 10.647511911936776, 11.576081129399372, 12.516529486056564, 13.522902473222935, 14.517863271746098, 13.558287015086455, 12.593614377330468, 11.632810926387528, 10.63297055905603, 8.811587144341349, 7.7381767372007895, 6.777000704471508, 5.840085524488058, 4.842122005699632, 3.9929907475128967, 4.886647246444691, 5.841670978155806, 6.827815368131126, 7.810842491623852, 8.735591310962167, 9.711418045022823, 10.753836421173322, 11.691828999226367, 12.68179507596576, 13.675578862175549, 12.684715744374378, 11.820746107966196, 10.810591176217232, 9.775776512230069, 7.9015135551774405, 6.949562343699713, 5.899589384138496, 4.90739381232086, 3.874530532297747, 2.9235005762537867, 3.879020658442916, 4.910277085222853, 5.8683073119293345, 6.917106318645256, 7.791008162085161, 8.747962422010012, 9.795387001665501, 10.676572201737065, 11.656563467778192, 12.711091524964841, 11.718071009417077, 10.787468253134689, 9.77497741247776, 8.92105078887421], [6.905452948628388, 7.854173279664366, 8.847515615208355, 9.807307768749926, 10.837864603581478, 11.753793432462158, 10.739511529540321, 9.864760861250833, 8.854564827703516, 7.848683260994931, 6.921321591201684, 5.894846000915532, 4.9309033282751376, 3.940910429633035, 2.9843108987784572, 2.116549383400657, 3.0860495944394115, 4.002664279656262, 4.978332937393716, 5.921157498219952, 5.93305330063095, 6.8781373949842095, 7.856594601777391, 8.915132462874022, 9.850285867599322, 10.827499080550124, 9.799618325462385, 8.864392593907693, 7.877645587275232, 6.856529558079682, 5.902424300070902, 4.9727912906696385, 3.999415782169227, 3.051390117916153, 2.0573455059657215, 1.0509756246282103, 2.0139359957734433, 3.0589174888309483, 4.045536805871049, 4.992463194427069, 5.119755592954854, 6.16046220732841, 7.196291490566885, 8.194156847424779, 9.258385780830928, 10.04535471206321, 8.996140998545194, 7.978100653832464, 7.008274338193893, 6.055445391635825, 5.0147002508607095, 4.035291844740319, 2.977855866512194, 2.0292718704394863, 1.0562719805727192, 0.0, 1.0578837850674605, 2.1083157135423, 3.0723305882587355, 4.135748954378717, 5.949607972533237, 6.988016125231214, 7.972232792050262, 8.922043956422335, 9.93054124324956, 10.892923510441987, 9.90930400733221, 8.910219207812435, 7.954047016518866, 7.007949949614884, 5.962075938732988, 4.9083917148284915, 3.9447606661650996, 3.0486922630552318, 2.0005781420851054, 1.0150028187054603, 2.0115500013335916, 2.949679623323142, 3.9472159525384747, 4.884723792273667, 6.766873505920482, 7.798557705214478, 8.766400279268804, 9.806082980148108, 10.770289846611387, 11.70393777531994, 10.839311354699326, 9.896575441076505, 8.914143955177227, 7.882643983576159, 6.815301937378016, 5.8384834693162855, 4.9207332856419415, 3.9753006008137706, 2.9334174101580825, 1.976587054210546, 2.9917634225045786, 3.911144844073595, 4.888381748611907, 5.828972901892294, 7.713916046520972, 8.669122048017703, 9.660529061620956, 10.688454263119631, 11.717229474598142, 12.637530086142842, 11.800313695316746, 10.766998548383116, 9.794085687947561, 8.808433834327555, 7.873843845469761, 6.8605270453692135, 5.922092919682381, 5.016622120067858, 3.96287528694596, 2.9352084830477723, 3.9099824258432774, 4.93588744599275, 5.822940461135917, 6.803766301393511, 8.707118134644336, 9.682703630826126, 10.692791656473045, 11.677657692108323, 12.653929943962396, 13.669919776612504, 12.728393815731383, 11.713092495099426, 10.757902737540483, 9.744213861289, 8.82251120269146, 7.8901529359068245, 6.959672397476359, 5.913834731394446, 4.906017951094795, 3.927308292590737, 4.8428164553605235, 5.870507309639312, 6.78705877684508, 7.792412713238897, 9.674324447942478, 10.664992030841235, 11.612602729746369, 12.624282246871854, 13.64503928739983, 14.612778576126804, 13.651158724013465, 12.659601277539526, 11.699718627768748, 10.760861507136061, 9.847959368408095, 8.892280899161106, 7.891766733338344, 6.860542868023737, 5.876267793631602, 4.943288763370239, 5.806748773182942, 6.7386064534614665, 7.726777941890854, 8.718034253634302, 10.602924504046635, 11.599055329418942, 12.565557116863316, 13.581809686958705, 14.036330784444516, 14.993642862134212, 14.655792979208973, 13.714298886640844, 12.688626554273002, 11.723923557485415, 10.833820842227507, 9.794094649820481, 8.834431372325737, 7.771802983306833, 6.818194260317055, 5.880454854998271, 6.8093648227782495, 7.740830505256796, 8.768149105119955, 9.678586465715, 11.609416548756748, 12.552390500130635, 13.599042607489784, 13.668043696242526, 12.985660504842937, 13.981846761787956, 14.89899055811499, 14.51671202664942, 13.546910334736122, 12.611514822492188, 11.658197230224435, 10.675348160440985, 9.66295485060786, 8.729402005838299, 7.8068962554787085, 6.86638623318263, 7.865567527658871, 8.692524746920036, 9.647441664063159, 10.635360905819113, 12.576047973953184, 13.526209723336189, 13.488651411235244, 12.669840931891931, 12.041699509349538, 13.058789956089168, 13.961173354400751, 14.843248182342434, 14.526070084030838, 13.634348497151073, 12.607503688189048, 11.562379109357867, 10.631231111251603, 9.684261725476219, 8.759061282072754, 7.826089823904866, 8.881744163116302, 9.763139200427094, 10.677211601407425, 11.647009121210932, 13.530621068304644, 13.48071203536355, 12.55074407961061, 11.653745534842653, 10.999458139291214, 11.987012043018417, 12.940661105667346, 13.86305920023128, 14.695712550634601, 14.57392371343161, 13.57762949710763, 12.587879692562531, 11.585634469277931, 10.665937782868463, 9.775144612685454, 8.79886366310404, 9.75716212397866, 10.741709536212474, 11.702165525227024, 12.579471332791186, 13.55781652700164, 12.5448910926799, 11.615277269960222, 10.722448220640707, 9.972114127421783, 10.958650962607697, 11.93230481629671, 12.79335475910599, 13.687898615791688, 14.659256510197755, 14.585682456108863, 13.61375757792612, 12.560563079946176, 11.66506438259834, 10.766280441003449, 9.74236220307743, 10.688475180088925, 11.65872176343568, 12.623707830051906, 13.565759824203724, 12.648048332696629, 11.712986665203003, 10.675820326688603, 9.749524837421925, 9.036918443984726, 9.997488321068488, 10.949497035918938, 11.78138075892672, 12.73519915284392, 13.66397634213398, 14.574042782510993, 14.501035228815798, 13.553633803838437, 12.603900338242058, 11.619906668419958, 10.67988899243729, 11.65461437159676, 12.647171876303553, 13.63140861050553, 13.63943103884308, 11.702199065149356, 10.74416568460943, 9.748617393377497, 8.786825750605212, 8.099478419976787, 8.962037341255868, 9.876120557124592, 10.771817336185642, 11.802213548502714, 12.728873822512481, 13.602204013962302, 14.601479408555306, 14.512635478581776, 13.621741437498047, 12.57175905625697, 11.660470093352972, 12.63430061867841, 13.576790034703581, 13.545954040759717, 12.708323693062479, 10.718763700879324, 9.83412918866378, 8.852066618032726, 7.861055771640365, 7.0590323738771446, 7.9317299113979, 8.82686680828342, 9.809488177705113, 10.776910858104037, 11.721367611758497, 12.646717731992213, 13.582925602131997, 14.61568519799397, 14.61651680322999, 13.586805761278145, 12.598065508242007, 13.657657507450148, 13.633892188379846, 12.59319872674706, 11.659058662500744, 9.788008893360441, 8.909334186753888, 7.886909893772059, 6.903122964240889, 5.999152514480906, 6.982188376809252, 7.8680858770156314, 8.850099824450549, 9.804521025366823, 10.842518676183658, 11.768020126478847, 12.775237148833089, 13.680941734825103, 14.520729500680472, 14.619956081076612, 13.58978738536863, 13.632525215314297, 12.615088488523776, 11.652983209714414, 10.72749743273396, 8.809544624264792, 7.862671338866657, 6.886630332041368, 5.970938865881873, 4.975375476835295, 5.93049951862404, 6.877304779082603, 7.8937800264875975, 8.881640451978448, 9.869683261761596, 10.75837049696229, 11.703783892509497, 12.632353109972092, 13.572801466629285, 14.579174453795655, 13.636482511970899, 12.672332484005079, 11.72393086004264, 10.7631274090997, 9.763287041768203, 7.941903627053524, 6.868493219912964, 5.907317187183683, 4.970402007200232, 4.041439211783653, 5.031105296231381, 5.9247617951631755, 6.87978552687429, 7.86592991684961, 8.848957040342336, 9.786288619048678, 10.767690025595543, 11.810108401746042, 12.748100979799085, 13.738067056538478, 12.70095364821901, 11.710090530417839, 10.846120894009657, 9.869529013066677, 8.906092994942243, 6.926888341220901, 6.036305161930209, 5.029905866850671, 4.037710295033035, 3.073847738381768, 3.961615124972271, 4.9171352071614, 5.948391633941338, 6.906421860647819, 7.955220867363741, 8.84728014265788, 9.804234402582733, 10.851658982238222, 11.732844182309783, 12.71283544835091, 11.736466311008302, 10.743445795460538, 9.81284303917815, 8.800352198521221, 7.94642557491767], [5.866406443415364, 6.8151267744513415, 7.808469109995331, 8.768261263536901, 9.798818098368454, 10.803516413457304, 11.776517839995282, 10.901767171705794, 9.869661993941376, 8.8028175922657, 7.81525175532845, 6.788776165042299, 5.824833492401905, 4.834840593759802, 3.8782410629052246, 3.010479547527424, 2.054059016275713, 2.964456989875169, 3.939286432180693, 4.882110993006929, 4.894006795417926, 5.839090889771185, 6.817548096564367, 7.876085957660997, 8.811239362386297, 9.7884525753371, 10.836624635917346, 9.901398904362654, 8.914651897730193, 7.893535868534643, 6.939430610525863, 6.0097976011246, 4.971073583151874, 3.989797106787122, 2.951275670092489, 1.9449057887549774, 0.9819454176097445, 2.020710199049855, 3.0064903006580264, 3.953416689214046, 4.061871807887393, 5.10257842226095, 6.138407705499425, 7.136273062357318, 8.200501995763467, 9.198971613787478, 10.054024783612652, 9.035984438899924, 8.066158123261353, 7.113329176703285, 6.072584035928171, 5.093175629807781, 4.035739651579655, 3.087155655506947, 2.11415576564018, 1.0578837850674605, 0.0, 1.0504319284748393, 2.014446803191275, 3.0778651693112566, 4.891724187465776, 5.930132340163754, 6.9143490069828015, 7.864160171354874, 8.8726574581821, 9.941413941194194, 10.92503344430397, 9.968102992879894, 9.011930801586326, 8.065833734682343, 7.019959723800448, 5.966275499895952, 5.00264445123256, 4.106576048122692, 3.0584619271525657, 2.023157685195925, 0.9536662162661314, 1.8917958382556819, 2.8893321674710144, 3.8268400072062065, 5.708989720853022, 6.740673920147017, 7.708516494201344, 8.748199195080648, 9.712406061543927, 10.64605399025248, 11.6351056355275, 10.954459226143966, 9.972027740244688, 8.94052776864362, 7.873185722445476, 6.896367254383746, 5.978617070709402, 5.004981161823833, 3.9415722766485475, 2.984741920701011, 1.9338796374371185, 2.853261059006135, 3.830497963544447, 4.771089116824833, 6.656032261453512, 7.611238262950242, 8.602645276553494, 9.630570478052169, 10.659345689530678, 11.579646301075382, 12.61990612792434, 11.824882333450576, 10.851969473015021, 9.866317619395016, 8.931727630537221, 7.918410830436674, 6.949310522784874, 5.9778993220707175, 4.911569310656103, 3.8643821167089607, 2.889608173913456, 3.901321993438106, 4.765056676068457, 5.74588251632605, 7.649234349576875, 8.624819845758664, 9.634907871405582, 10.619773907040859, 11.596046158894932, 12.61203599154504, 13.626252931739124, 12.688143294711313, 11.729987230336626, 10.716298354085142, 9.710513163900318, 8.744732160112788, 7.814251621682322, 6.768413955600408, 5.760597175300758, 4.7818875167967, 3.8224422034307017, 4.835941857084667, 5.72917499177762, 6.734528928171437, 8.616440662875016, 9.607108245773773, 10.554718944678907, 11.566398461804392, 12.587155502332369, 13.554894791059342, 14.541554849626621, 13.634652077151413, 12.67180312056489, 11.732945999932204, 10.682342144567935, 9.726663675320946, 8.726149509498184, 7.660067700840269, 6.675792626448134, 5.733699111151781, 4.786374521253121, 5.718232201531645, 6.668894156823394, 7.660150468566842, 9.545040718979173, 10.54117154435148, 11.507673331795853, 12.523925901891243, 13.550667089921577, 14.536937853758984, 15.54618910482213, 14.61135251642966, 13.585680184061818, 12.620977187274232, 11.625331182131825, 10.5856049897248, 9.625941712230055, 8.562213331088376, 7.608604608098597, 6.6708652027798125, 5.788990570848428, 6.720456253326975, 7.7102653200524935, 8.62070268064754, 10.551532763689284, 11.49450671506317, 12.54115882242232, 12.636053118078829, 13.523709828994868, 14.519896085939887, 15.470320699709335, 15.307122374430962, 14.337320682517664, 13.40192517027373, 12.448607578005976, 11.465758508222526, 10.453365198389402, 9.519812353619841, 8.59730660326025, 7.656796580964172, 6.8451932757290495, 7.672150494990215, 8.627067412133337, 9.614986653889293, 11.51816418888572, 12.468325938268725, 12.456660833071545, 11.637850353728235, 12.579748833501469, 13.614359034425323, 14.532503495995096, 15.549593121491126, 15.31648043181238, 14.424758844932615, 13.39791403597059, 12.352789457139409, 11.421641459033145, 10.47467207325776, 9.549471629854295, 8.616500171686408, 7.864338226436214, 8.742764948497273, 9.656837349477604, 10.626634869281112, 12.47273728323718, 12.448721457199852, 11.518753501446911, 10.621754956678956, 11.55502721762737, 12.542581121354573, 13.51199124726169, 14.569404139379973, 15.589642714761366, 15.364334061213151, 14.368039844889172, 13.378290040344073, 12.376044817059473, 11.456348130650005, 10.565554960466995, 9.589274010885582, 8.862583701196867, 9.743573145180328, 10.681791273297204, 11.559097080861367, 12.52582594883794, 11.512900514516202, 10.583286691796523, 9.690457642477009, 10.642061419190183, 11.636797413466404, 12.610451267155417, 13.651899550664469, 14.581828779918453, 15.55318667432452, 15.376092803890405, 14.404167925707663, 13.350973427727718, 12.455474730379882, 11.55669078878499, 10.532772550858972, 9.91430442672344, 10.713897523471585, 11.67888359008781, 12.545385572273904, 11.616057754532928, 10.680996087039304, 9.643829748524904, 8.717534259258226, 9.706865735753127, 10.77127505111455, 11.807321840645242, 12.675310923053486, 13.629129316970687, 14.557906506260746, 15.46797294663776, 15.29144557659734, 14.344044151619979, 13.3943106860236, 12.4103170162015, 11.470299340218832, 10.880443618231274, 11.702347636339457, 12.686584370541434, 12.60744046067938, 10.670208486985658, 9.71217510644573, 8.716626815213798, 7.754835172441513, 8.814627574598923, 9.820553645904965, 10.770050721251359, 11.665747500312408, 12.69614371262948, 13.622803986639248, 14.496134178089068, 15.495409572682073, 15.303045826363318, 14.412151785279589, 13.362169404038513, 12.450880441134514, 11.860129865312924, 12.6849979946471, 12.51396346259602, 11.67633311489878, 9.686773122715627, 8.802138610500082, 7.8200760398690266, 6.829065193476667, 7.880042861631801, 8.819388809628107, 9.720796972410186, 10.70341834183188, 11.670841022230803, 12.615297775885264, 13.54064789611898, 14.476855766258764, 15.509615362120737, 15.406927151011532, 14.377216109059686, 13.388475856023549, 12.883486754084663, 12.601901610216148, 11.561208148583361, 10.627068084337045, 8.756018315196744, 7.87734360859019, 6.8549193156083605, 5.87113238607719, 6.870890795538633, 7.86984727503946, 8.762016041142399, 9.744029988577315, 10.69845118949359, 11.736448840310423, 12.661950290605615, 13.726918006892296, 14.635076066095872, 15.474863831951241, 14.616142699540436, 13.598342315415909, 12.593478710101273, 11.583097910360078, 10.620992631550715, 9.695506854570262, 7.777554046101094, 6.8306807607029585, 5.854639753877669, 4.9389482877181745, 5.869305640962062, 6.824429682750806, 7.771234943209371, 8.787710190614364, 9.775570616105217, 10.763613425888364, 11.652300661089058, 12.657918223780266, 13.586487441242861, 14.526935797900054, 13.592396805281037, 12.597436006757874, 11.633285978792054, 10.691940281878942, 9.731136830936002, 8.731296463604505, 6.909913048889825, 5.836502641749266, 4.875326609019984, 3.938411429036534, 4.93536937591042, 5.925035460358148, 6.818691959289943, 7.773715691001057, 8.759860080976377, 9.742887204469104, 10.680218783175446, 11.721824356866312, 12.764242733016811, 13.759867137214956, 12.699430290403972, 11.661907143005985, 10.671044025204814, 9.807074388796632, 8.830482507853652, 7.874102416778545, 5.887841836007878, 4.997258656717186, 3.997915288686972, 3.005719716869337, 3.967777902508535, 4.855545289099038, 5.8110653712881675, 6.842321798068105, 7.800352024774586, 8.849151031490507, 9.801414473928649, 10.758368733853501, 11.80579331350899, 12.744610339725654, 11.759588665675516, 10.697419805795278, 9.704399290247514, 8.773796533965125, 7.761305693308197, 6.907379069704647], [4.815974514940525, 5.764694845976503, 6.758037181520492, 7.7178293350620635, 8.748386169893614, 9.753084484982464, 10.73893973958827, 11.734640534408165, 10.902976339964153, 9.836131938288478, 8.848566101351228, 7.822090511065077, 6.858147838424682, 5.868154939782579, 4.911555408928002, 3.964717954959771, 2.9262170205491707, 1.9140250614003298, 2.8888545037058537, 3.83167906453209, 3.843574866943087, 4.788658961296346, 5.767116168089528, 6.8256540291861585, 7.7608074339114586, 8.73802064686226, 9.799046535510334, 10.734272267065025, 9.94796624375297, 8.92685021455742, 7.97274495654864, 7.043111947147376, 6.0043879291746505, 5.023111452809898, 3.9845900161152654, 2.9782201347777537, 2.0152597636325207, 0.9702782705750157, 1.956058372183187, 2.9029847607392067, 3.0114398794125536, 4.05214649378611, 5.087975777024585, 6.085841133882478, 7.150070067288627, 8.148539685312638, 9.197753398830654, 10.086416367374763, 9.116590051736193, 8.163761105178125, 7.1230159644030095, 6.1436075582826195, 5.0861715800544935, 4.137587583981786, 3.1645876941150193, 2.1083157135423, 1.0504319284748393, 0.0, 0.9640148747164354, 2.027433240836417, 4.018354753936624, 5.013555568625257, 5.997772235444305, 6.947583399816378, 7.956080686643603, 9.024837169655697, 10.008456672765474, 11.007541472285249, 10.062362730061166, 9.116265663157183, 8.070391652275287, 7.016707428370791, 6.053076379707399, 5.157007976597532, 4.1088938556274055, 3.062490512254375, 1.992999043324581, 1.0548694213350307, 2.015962733941861, 2.9534705736770532, 4.8720633039323715, 5.903747503226367, 6.871590077280694, 7.911272778159998, 8.875479644623276, 9.809127573331828, 10.79817921860685, 11.74091513222967, 11.022459668719527, 9.990959697118459, 8.923617650920315, 7.946799182858585, 7.029048999184241, 6.0443139888822826, 4.980905103706997, 4.02407474775946, 2.9732124644955684, 2.016334642085484, 2.993571546623796, 3.9341626999041828, 5.819105844532862, 6.774311846029592, 7.765718859632844, 8.79364406113152, 9.82241927261003, 10.742719884154731, 11.782979711003689, 12.666163773014917, 11.90240140148986, 10.916749547869854, 9.982159559012059, 8.968842758911514, 7.988643349843324, 7.017232149129168, 5.950902137714553, 4.903714943767411, 3.9289410009719057, 3.064395576517455, 3.928130259147806, 4.908956099405399, 6.812307932656225, 7.787893428838014, 8.797981454484932, 9.782847490120211, 10.759119741974285, 11.775109574624393, 12.789326514818473, 13.612257719731227, 12.769320057395074, 11.75563118114359, 10.749845990958766, 9.784064987171236, 8.85358444874077, 7.807746782658858, 6.799930002359207, 5.821220343855149, 4.861775030489151, 3.9990154401640163, 4.892248574856969, 5.897602511250786, 7.779514245954367, 8.770181828853124, 9.717792527758258, 10.729472044883742, 11.75022908541172, 12.717968374138692, 13.704628432705972, 14.558766502171327, 13.711135947623339, 12.772278826990652, 11.721674971626385, 10.765996502379396, 9.765482336556634, 8.69940052789872, 7.715125453506583, 6.77303193821023, 5.82570734831157, 4.944236988881906, 5.831967739902743, 6.823224051646191, 8.708114302058524, 9.70424512743083, 10.670746914875204, 11.686999484970594, 12.713740673000927, 13.700011436838334, 14.70926268790148, 15.627446733411912, 14.625013011120267, 13.66031001433268, 12.664664009190274, 11.624937816783248, 10.665274539288504, 9.601546158146824, 8.647937435157045, 7.710198029838262, 6.828323397906877, 5.946461040677236, 6.873338903131843, 7.783776263726889, 9.714606346768637, 10.657580298142523, 11.704232405501672, 12.65619949246532, 13.639590578621352, 14.635776835566372, 15.642476235820236, 16.346455201489412, 15.376653509576112, 14.441257997332178, 13.487940405064425, 12.505091335280975, 11.49269802544785, 10.55914518067829, 9.636639430318699, 8.696129408022621, 7.884526102787499, 6.898155282340476, 7.8212613264964705, 8.809180568252426, 10.681237771965073, 11.631399521348078, 11.905697258019346, 12.510008358001693, 13.451906837774928, 14.486517038698782, 15.404661500268555, 16.421751125764583, 16.35581325887083, 15.464091671991063, 14.437246863029038, 13.392122284197857, 12.460974286091593, 11.514004900316209, 10.588804456912744, 9.655832998744856, 8.903671053494662, 7.968769735847534, 8.851031263840737, 9.820828783644245, 11.635810866316532, 11.897757882147653, 10.967789926394712, 11.493912960952414, 12.427185221900828, 13.414739125628032, 14.384149251535149, 15.441562143653432, 16.505569182055893, 16.4036668882716, 15.40737267194762, 14.417622867402521, 13.415377644117921, 12.495680957708453, 11.604887787525444, 10.62860683794403, 9.901916528255315, 8.969577932530589, 9.875985187660337, 10.7532909952245, 11.798135067134554, 10.961936939464003, 10.032323116744324, 10.562615646750467, 11.514219423463642, 12.508955417739863, 13.482609271428876, 14.524057554937928, 15.53500588808128, 16.506363782487345, 16.415425630948853, 15.443500752766111, 14.390306254786166, 13.49480755743833, 12.596023615843439, 11.57210537791742, 10.910148894168602, 9.939902310821846, 10.904888377438072, 11.739579486637037, 10.78731395478929, 10.066980759277724, 9.092866173472705, 9.589692263531685, 10.579023740026585, 11.643433055388009, 12.679479844918701, 13.628488031216312, 14.582306425133513, 15.511083614423573, 16.421150054800588, 16.33077840365579, 15.383376978678427, 14.433643513082048, 13.449649843259948, 12.50963216727728, 11.876288085676435, 10.928352423689718, 11.912589157891695, 11.764947739650571, 9.841464687242018, 9.030304543308498, 8.1656632401616, 8.626993176714972, 9.686785578872382, 10.692711650178424, 11.723227829414185, 12.618924608475234, 13.649320820792306, 14.575981094802074, 15.449311286251895, 16.448586680844898, 16.342378653421765, 15.451484612338037, 14.401502231096961, 13.490213268192962, 12.853492198022533, 11.911002781997361, 11.561910731954931, 10.724280384257693, 8.81611619998421, 8.072137557962428, 7.1011804987652685, 7.701223197750125, 8.75220086590526, 9.691546813901565, 10.673974080573013, 11.656595449994706, 12.62401813039363, 13.56847488404809, 14.493825004281806, 15.43003287442159, 16.462792470283564, 15.527458901554851, 14.582358966161392, 13.539632264067693, 12.506070671465444, 11.64984887957506, 10.609155417942274, 9.675015353695958, 7.885361392465327, 7.0066866858587735, 6.057670512950598, 6.743290390350649, 7.743048799812092, 8.742005279312918, 9.715193149305225, 10.697207096740142, 11.651628297656416, 12.68962594847325, 13.695264636628393, 14.760232352915073, 15.529484121322294, 14.496265898023758, 13.565710771065596, 12.54791038694107, 11.543046781626435, 10.63104517971899, 9.668939900909628, 8.743454123929174, 6.906897123369678, 5.9600238379715424, 4.990356768313586, 5.811106291991633, 6.812986821713905, 7.76811086350265, 8.724412051372196, 9.74088729877719, 10.766545131318175, 11.754587941101322, 12.685615007111835, 13.691232569803043, 14.488786220629763, 13.54833786397257, 12.5419648768062, 11.547004078283036, 10.582854050317216, 9.734815286206398, 8.779084100294915, 7.779243732963417, 5.8651629022078895, 4.9658457190178495, 4.011043623455901, 4.810569433309992, 5.879050556662263, 6.9518242976955875, 7.852006305312719, 8.807030037023834, 9.793174426999155, 10.776201550491882, 11.713533129198224, 12.75513870288909, 13.714376878079518, 12.70943520874012, 11.648998361929134, 10.611475214531147, 9.620612096729976, 8.756642460321792, 7.7800505793788135, 6.829352270096609, 4.837409907533039, 3.9468267282423466, 2.9791525201687024, 3.8778777211427946, 4.911459083260378, 5.888859635121815, 6.844379717310944, 7.8756361440908815, 8.833666370797363, 9.882465377513284, 10.834728819951426, 11.791683079876279, 12.685968538805978, 11.694178411250817, 10.709156737200678, 9.64698787732044, 8.653967361772676, 7.7233646054902865, 6.710873764833358, 5.856947141229808], [3.8519596402240897, 4.800679971260067, 5.794022306804056, 6.753814460345628, 7.78437129517718, 8.789069610266031, 9.774924864871835, 10.77062565969173, 11.733923639409335, 10.800146813004913, 9.812580976067663, 8.78610538578151, 7.822162713141117, 6.832169814499014, 5.875570283644437, 4.928732829676207, 3.890231895265606, 2.8780399361167652, 1.9248396289894183, 2.8676641898156547, 2.8795599922266515, 3.824644086579911, 4.803101293373093, 5.8616391544697235, 6.796792559195024, 7.774005772145825, 8.835031660793899, 9.77025739234859, 10.757004398981051, 9.890865089273856, 8.936759831265075, 8.00712682186381, 6.9684028038910855, 5.987126327526333, 4.9486048908317, 3.942235009494189, 2.979274638348956, 1.9342931452914511, 0.9920434974667516, 1.9389698860227713, 2.047425004696118, 3.088131619069675, 4.123960902308149, 5.121826259166042, 6.186055192572191, 7.184524810596201, 8.233738524114218, 9.251778868826946, 10.080604926452628, 9.12777597989456, 8.087030839119445, 7.107622432999054, 6.050186454770928, 5.1016024586982205, 4.128602568831454, 3.072330588258735, 2.014446803191275, 0.9640148747164354, 0.0, 1.0634183661199816, 3.054339879220188, 4.049540693908822, 5.03375736072787, 5.983568525099943, 6.992065811927168, 8.060822294939262, 9.04444179804904, 10.043526597568814, 10.999698788862382, 10.080280537873618, 9.034406526991722, 7.980722303087225, 7.017091254423833, 6.121022851313966, 5.07290873034384, 4.02650538697081, 2.9570139180410164, 2.018884296051466, 1.0519478592254254, 1.9894556989606178, 3.9187098439351233, 4.950394043229119, 5.918236617283446, 6.95791931816275, 7.922126184626028, 8.855774113334581, 9.844825758609602, 10.787561672232423, 11.769993158131701, 10.954974571834894, 9.88763252563675, 8.910814057575019, 7.993063873900675, 7.008328863598718, 5.944919978423433, 4.988089622475896, 3.9372273392120034, 2.980349516801919, 2.0719328181020353, 2.980809239906935, 4.865752384535614, 5.820958386032344, 6.8123653996355955, 7.840290601134271, 8.869065812612781, 9.789366424157484, 10.829626251006442, 11.71281031301767, 12.685723173453225, 11.880764422586289, 10.946174433728494, 9.932857633627947, 8.952658224559759, 7.981247023845603, 6.914917012430988, 5.867729818483846, 4.892955875688341, 3.9430567411234474, 3.006491530626045, 3.955602639408152, 5.858954472658977, 6.834539968840765, 7.844627994487683, 8.829494030122962, 9.805766281977036, 10.821756114627144, 11.835973054821226, 12.65890425973398, 13.617060324108667, 12.719646055860027, 11.713860865675203, 10.748079861887673, 9.817599323457207, 8.771761657375293, 7.763944877075643, 6.785235218571585, 5.825789905205587, 4.877676604770009, 3.9706098463352077, 4.944644927326527, 6.826160785957119, 7.816828368855875, 8.764439067761009, 9.776118584886493, 10.79687562541447, 11.764614914141443, 12.751274972708723, 13.60541304217408, 14.558876214336932, 13.710325666318255, 12.650723457081238, 11.69504498783425, 10.694530822011487, 9.628449013353572, 8.644173938961437, 7.702080423665083, 6.754755833766423, 5.822898153487899, 4.910329011380982, 5.90158532312443, 7.754760842061276, 8.750891667433581, 9.717393454877955, 10.733646024973345, 11.760387213003678, 12.746657976841085, 13.755909227904231, 14.674093273414664, 15.55406149657512, 14.589358499787533, 13.593712494645127, 12.553986302238101, 11.594323024743357, 10.530594643601678, 9.576985920611898, 8.639246515293115, 7.7573718833617304, 6.825122205283229, 5.951700174610082, 6.862137535205128, 8.761252886771388, 9.704226838145274, 10.750878945504423, 11.70284603246807, 12.686237118624103, 13.682423375569122, 14.689122775822987, 15.617265639939784, 16.305701995030965, 15.370306482787031, 14.416988890519278, 13.434139820735828, 12.421746510902704, 11.488193666133142, 10.565687915773552, 9.625177893477474, 8.79133858768967, 7.776816446946469, 6.899622597974711, 7.887541839730665, 9.727884311967824, 10.678046061350829, 11.659018923413601, 12.666805369885644, 13.608703849658879, 14.638362003913869, 15.58400662967774, 16.543534921038503, 17.28486174432568, 16.393140157445917, 15.366295348483892, 14.32117076965271, 13.390022771546446, 12.443053385771062, 11.517852942367597, 10.584881484199709, 9.785913368436361, 8.847430900453528, 7.929392535318978, 8.899190055122485, 10.682457406319283, 11.001809902738977, 11.863964646057108, 12.457927835668851, 13.391200096617265, 14.378754000344468, 15.348164126251586, 16.40557701836987, 17.46958405677233, 17.332715373726455, 16.336421157402473, 15.346671352857374, 14.344426129572774, 13.424729443163306, 12.533936272980297, 11.557655323398883, 10.784158843197014, 9.848239097136583, 8.954346459138577, 9.83165226670274, 10.834120192418117, 10.065988960055327, 10.92849783640672, 11.526630521466904, 12.478234298180078, 13.4729702924563, 14.446624146145313, 15.488072429654364, 16.499020762797716, 17.47037865720378, 17.344474116403706, 16.372549238220966, 15.31935474024102, 14.423856042893183, 13.525072101298292, 12.501153863372274, 11.788810058774596, 10.81856347542784, 10.023083853495141, 10.817940758115277, 9.823299080072854, 9.10296588456129, 9.989040893135101, 10.553707138248122, 11.543038614743022, 12.607447930104446, 13.643494719635138, 14.592502905932747, 15.546321299849948, 16.475098489140006, 17.385164929517025, 17.25982688911064, 16.31242546413328, 15.362691998536901, 14.378698328714801, 13.438680652732133, 12.75494925028243, 11.807013588295712, 11.030784633948764, 10.800932864934136, 8.877449812525583, 8.066289668592063, 9.061837959823995, 9.591008051431409, 10.650800453588818, 11.65672652489486, 12.68724270413062, 13.58293948319167, 14.613335695508741, 15.53999596951851, 16.41332616096833, 17.412601555561334, 16.50467612453885, 15.530447738875667, 14.480465357634591, 13.513212804240291, 12.526732434134924, 11.584243018109753, 10.597895857238498, 9.760265509541258, 7.852101325267776, 7.108122683245993, 8.053143752340064, 8.665238072466561, 9.716215740621696, 10.655561688618, 11.637988955289448, 12.62061032471114, 13.588033005110065, 14.532489758764525, 15.457839878998241, 16.394047749138025, 15.573985519291176, 14.563444026838415, 13.618344091444955, 12.575617389351256, 11.542055796749008, 10.685834004858624, 9.645140543225839, 8.711000478979523, 6.921346517748892, 6.0426718111423385, 7.009633766525393, 7.707305265067084, 8.707063674528527, 9.706020154029353, 10.67920802402166, 11.661221971456577, 12.61564317237285, 13.653640823189686, 14.659279511344826, 15.522998074176186, 14.565469246605858, 13.532251023307321, 12.60169589634916, 11.583895512224633, 10.579031906909998, 9.667030305002553, 8.704925026193191, 7.779439249212738, 5.942882248653243, 4.9960089632551075, 5.942320021888381, 6.775121166708068, 7.777001696430341, 8.732125738219086, 9.688426926088631, 10.704902173493625, 11.73056000603461, 12.718602815817757, 13.649629881828268, 14.45334056337592, 13.524771345913326, 12.584322989256133, 11.577950002089763, 10.5829892035666, 9.61883917560078, 8.770800411489963, 7.81506922557848, 6.815228858246982, 4.901148027491454, 4.001830844301415, 4.963006877030696, 5.774584308026427, 6.843065431378699, 7.9158391724120225, 8.816021180029153, 9.771044911740267, 10.757189301715588, 11.740216425208315, 12.677548003914657, 13.683785339794019, 12.750362003363081, 11.745420334023683, 10.684983487212698, 9.64746033981471, 8.65659722201354, 7.792627585605357, 6.816035704662378, 5.865337395380173, 3.873395032816603, 2.982811853525911, 3.943167394885138, 4.84189259585923, 5.875473957976814, 6.85287450983825, 7.808394592027379, 8.839651018807317, 9.797681245513798, 10.84648025222972, 11.798743694667861, 12.720329716781208, 11.721953664089542, 10.73016353653438, 9.74514186248424, 8.682973002604003, 7.689952487056239, 6.759349730773851, 5.746858890116922, 4.892932266513372], [2.8507563050130087, 3.7994766360489862, 4.792818971592975, 5.752611125134547, 6.783167959966098, 7.787866275054949, 8.773721529660754, 9.769422324480649, 10.732720304198255, 11.737165924121273, 10.749600087184023, 9.72312449689787, 8.759181824257476, 7.769188925615374, 6.8125893947607965, 5.865751940792566, 4.827251006381966, 3.815059047233125, 2.817489070890377, 1.8664608546045738, 1.8783566570155705, 2.82344075136883, 3.8018979581620114, 4.860435819258642, 5.795589223983942, 6.772802436934744, 7.833828325582817, 8.76905405713751, 9.75580106376997, 10.77691709296552, 9.873778942381435, 8.94414593298017, 7.905421915007445, 6.924145438642693, 5.88562400194806, 4.879254120610549, 3.916293749465316, 2.871312256407811, 1.88469293936771, 0.9377665508116902, 0.9840066385761366, 2.0247132529496934, 3.060542536188168, 4.058407893046061, 5.12263682645221, 6.12110644447622, 7.170320157994237, 8.188360502706965, 9.158186818345536, 10.111015764903604, 9.150449205239426, 8.171040799119035, 7.11360482089091, 6.165020824818203, 5.192020934951437, 4.135748954378717, 3.077865169311256, 2.027433240836417, 1.0634183661199816, 0.0, 2.0170004851985537, 2.9861223277888405, 3.9703389946078884, 4.920150158979961, 5.9286474458071865, 6.9974039288192795, 7.9810234319290565, 8.980108231448831, 9.9362804227424, 10.882377489646382, 10.097824893111705, 9.044140669207207, 8.080509620543816, 7.051806659340533, 6.003692538370407, 4.929519332029709, 3.8600278630999147, 2.9218982411103642, 1.9243619118950317, 0.9868540721598394, 2.916108217134345, 3.947792416428341, 4.915634990482667, 5.955317691361971, 6.919524557825249, 7.853172486533802, 8.842224131808823, 9.784960045431644, 10.767391531330922, 11.79889150293199, 10.905953758247993, 9.929135290186263, 8.936167235808599, 7.911342808657617, 6.847933923482331, 5.8911035675347945, 4.840241284270902, 3.8833634618608173, 2.9187987663865433, 1.9782076131061568, 3.863150757734836, 4.818356759231566, 5.809763772834818, 6.837688974333494, 7.866464185812004, 8.786764797356705, 9.827024624205663, 10.710208686216891, 11.683121546652446, 12.668773400272451, 11.952648701150931, 10.926202623329, 9.855672169618657, 8.884260968904501, 7.817930957489886, 6.770743763542744, 5.795969820747239, 4.789922689407955, 3.853357478910553, 2.953001012607374, 4.856352845858199, 5.831938342039988, 6.8420263676869055, 7.8268924033221845, 8.803164655176257, 9.819154487826365, 10.833371428020447, 11.656302632933201, 12.614458697307889, 13.604553427233895, 12.616874810734101, 11.651093806946571, 10.720613268516106, 9.674775602434192, 8.666958822134541, 7.688249163630483, 6.728803850264486, 5.724542553054517, 4.817475794619716, 3.9420433005257487, 5.823559159156341, 6.814226742055097, 7.76183744096023, 8.773516958085715, 9.794273998613692, 10.762013287340665, 11.748673345907944, 12.602811415373301, 13.556274587536153, 14.523477057078694, 13.497589405365744, 12.541910936118756, 11.541396770295993, 10.475314961638079, 9.491039887245943, 8.54894637194959, 7.601621782050931, 6.669764101772407, 5.75719495966549, 4.950388605257678, 6.752159215260498, 7.748290040632805, 8.714791828077177, 9.731044398172566, 10.7577855862029, 11.744056350040307, 12.753307601103453, 13.671491646613886, 14.631247897224448, 15.436224448072041, 14.440578442929635, 13.40085225052261, 12.441188973027865, 11.377460591886186, 10.423851868896406, 9.486112463577623, 8.604237831646238, 7.671988153567737, 6.79856612289459, 5.910940817338376, 7.75865125997061, 8.701625211344497, 9.748277318703646, 10.700244405667291, 11.683635491823324, 12.679821748768344, 13.686521149022209, 14.614664013139006, 15.584465705052304, 16.21717243107154, 15.263854838803786, 14.281005769020336, 13.268612459187212, 12.33505961441765, 11.41255386405806, 10.472043841761982, 9.638204535974179, 8.623682395230977, 7.746488546259219, 6.976404981928369, 8.725282685167047, 9.675444434550052, 10.656417296612824, 11.664203743084867, 12.606102222858102, 13.63576037711309, 14.581405002876961, 15.540933294237727, 16.56362545434702, 17.240006105730423, 16.2131612967684, 15.168036717937218, 14.236888719830954, 13.28991933405557, 12.364718890652105, 11.431747432484217, 10.63277931672087, 9.694296848738036, 8.776258483603485, 7.988053197320189, 9.679855779518507, 10.644939821366545, 11.594324628237459, 12.554007401532614, 13.48727966248103, 14.474833566208233, 15.44424369211535, 16.501656584233633, 17.565663622636094, 18.17958132201096, 17.18328710568698, 16.19353730114188, 15.191292077857282, 14.271595391447814, 13.380802221264805, 12.404521271683391, 11.631024791481522, 10.69510504542109, 9.801212407423083, 8.920515408900444, 9.834785845250805, 10.748217557960192, 11.677831380679871, 12.463649632583262, 13.415253409296437, 14.409989403572657, 15.38364325726167, 16.425091540770723, 17.436039873914073, 18.407397768320138, 18.191340064688212, 17.219415186505472, 16.166220688525527, 15.270721991177691, 14.3719380495828, 13.348019811656782, 12.635676007059104, 11.665429423712348, 10.869949801779647, 9.906803900312982, 8.82396473290554, 9.785194482466155, 10.758900070441234, 11.49072624936448, 12.48005772585938, 13.544467041220805, 14.580513830751498, 15.529522017049105, 16.483340410966306, 17.412117600256366, 18.32218404063338, 17.325334722007625, 16.377933297030264, 15.415108080082623, 14.431114410260523, 13.492590569944893, 12.505215346005496, 11.565690041206315, 10.565948135483005, 9.799729529723056, 7.8781154653582695, 8.836148845898196, 9.831697137130128, 10.528027162547767, 11.587819564705176, 12.593745636011219, 13.624261815246978, 14.519958594308028, 15.5503548066251, 16.477015080634867, 17.350345272084688, 16.459163272560467, 15.50347278932777, 14.529244403664586, 13.47926202242351, 12.512009469029211, 11.525529098923844, 10.583039682898672, 9.596692522027418, 8.759062174330177, 6.852766978100461, 7.920469269789069, 8.902531840420124, 9.60225718358292, 10.653234851738054, 11.59258079973436, 12.575008066405806, 13.557629435827499, 14.525052116226423, 15.469508869880883, 16.3948589901146, 15.52558165186674, 14.572782184080095, 13.562240691627334, 12.617140756233875, 11.574414054140176, 10.540852461537927, 9.684630669647543, 8.643937208014759, 7.7097971437684425, 5.922012170581578, 6.935321253043297, 7.9022832084263515, 8.644324376183443, 9.644082785644887, 10.643039265145713, 11.616227135138018, 12.598241082572935, 13.552662283489209, 14.590659934306043, 15.482550670862251, 14.521794738965106, 13.564265911394777, 12.53104768809624, 11.60049256113808, 10.582692177013552, 9.577828571698918, 8.665826969791473, 7.7037216909821105, 6.778235914001658, 4.943547901485928, 5.8886584051560655, 6.8349694637893394, 7.712140277824426, 8.7140208075467, 9.669144849335444, 10.62544603720499, 11.641921284609984, 12.667579117150968, 13.655621926934115, 14.472901041345693, 13.45213722816484, 12.523568010702245, 11.583119654045053, 10.576746666878682, 9.581785868355519, 8.617635840389699, 7.769597076278883, 6.813865890367399, 5.814025523035902, 3.899944692280373, 4.894480286202373, 5.855656318931654, 6.7116034191427865, 7.780084542495057, 8.85285828352838, 9.753040291145513, 10.708064022856627, 11.694208412831948, 12.677235536324675, 13.614567115031017, 12.682582004582938, 11.749158668152, 10.744216998812602, 9.683780152001617, 8.64625700460363, 7.655393886802459, 6.791424250394276, 5.814832369451297, 4.864134060169093, 2.8721916976055226, 3.8754612954268697, 4.880186506001498, 5.778911706975589, 6.812493069093172, 7.78989362095461, 8.745413703143738, 9.776670129923676, 10.734700356630158, 11.78349936334608, 12.67608064149498, 11.719126381570128, 10.720750328878461, 9.7289602013233, 8.74393852727316, 7.681769667392922, 6.688749151845158, 5.75814639556277, 4.7456555549058415, 3.891728931302292], [3.0231147578825497, 3.971835088918527, 4.965177424462516, 5.904238560022294, 6.886572621741807, 7.891270936830657, 8.877126191436462, 9.872826986256356, 10.836124965973962, 11.813558942873264, 12.706975942794227, 11.680500352508075, 10.71655767986768, 9.726564781225578, 8.769965250371001, 7.88275242599112, 6.844251491580519, 5.832059532431678, 4.834489556088931, 3.8834613398031275, 2.0507151098851115, 2.995799204238371, 3.9742564110315524, 4.96384048103435, 5.8989938857596504, 6.876207098710452, 7.9372329873585254, 8.872458718913217, 9.859205725545678, 10.821405239958015, 11.775510497966795, 10.901521788590376, 9.86279777061765, 8.881521294252899, 7.842999857558265, 6.836629976220753, 5.873669605075521, 4.888312741606365, 3.901693424566264, 2.954767036010244, 1.032993846622417, 1.999817227537124, 3.0356465107755985, 3.9349466078813853, 4.933883166780992, 5.932352784805003, 6.981566498323019, 7.999606843035748, 8.969433158674319, 9.888229665413112, 10.928974806188227, 9.984899817273556, 8.92746383904543, 7.978879842972722, 7.005879953105955, 5.9496079725332365, 4.891724187465776, 4.018354753936624, 3.054339879220188, 2.0170004851985537, 0.0, 1.038408152697977, 2.022624819517025, 2.972435983889098, 3.9809332707163234, 5.049689753728417, 6.033309256838194, 7.032394056357969, 7.988566247651537, 8.93466331455552, 9.980537325437416, 9.138576384889168, 8.174945336225777, 7.129836767440264, 6.081722646470138, 5.00754944012944, 3.9380579711996453, 2.9999283492100948, 2.0023920199947622, 1.06488418025957, 0.9450233002655044, 1.9767074995595002, 2.9445500736138266, 3.9842327744931305, 4.948439640956408, 5.882087569664962, 6.871139214939983, 7.8138751285628025, 8.79630661446208, 9.827806586063147, 10.895148632261291, 9.933467270627544, 8.94049921624988, 7.9156747890988965, 6.852265903923611, 5.895435547976074, 4.8277378164028235, 3.8007519621123915, 2.8235150575740793, 1.8829239042936927, 1.892065840865995, 2.8472718423627255, 3.838678855965977, 4.866604057464652, 5.895379268943162, 6.815679880487863, 7.855939707336821, 8.73912376934805, 9.712036629783604, 10.69768848340361, 11.632278472261405, 10.850776803326726, 9.780246349616382, 8.808835148902226, 7.742505137487611, 6.695317943540469, 5.720544000744964, 4.694638980595491, 3.758073770098089, 2.8226939515769134, 2.885267928989358, 3.8608534251711473, 4.870941450818065, 5.855807486453343, 6.832079738307415, 7.848069570957524, 8.862286511151606, 9.68521771606436, 10.643373780439047, 11.633468510365054, 12.541448990731826, 11.575667986944296, 10.64518744851383, 9.599349782431917, 8.591533002132266, 7.612823343628208, 6.6533780302622105, 5.629258844242053, 4.722192085807252, 3.8117362394952883, 3.8524742422875002, 4.843141825186256, 5.790752524091389, 6.802432041216874, 7.823189081744851, 8.790928370471823, 9.777588429039103, 10.63172649850446, 11.585189670667312, 12.552392140209852, 13.402305696553281, 12.446627227306292, 11.44611306148353, 10.380031252825615, 9.39575617843348, 8.453662663137127, 7.506338073238467, 6.574480392959943, 5.661911250853026, 4.820081544227217, 4.781074298391657, 5.777205123763964, 6.743706911208336, 7.759959481303725, 8.78670066933406, 9.772971433171465, 10.782222684234611, 11.700406729745044, 12.660162980355606, 13.515454190559206, 14.345294734117171, 13.305568541710146, 12.345905264215402, 11.282176883073722, 10.328568160083943, 9.39082875476516, 8.508954122833774, 7.576704444755273, 6.703282414082126, 5.780633756307915, 5.787566343101769, 6.730540294475656, 7.777192401834805, 8.729159488798452, 9.712550574954484, 10.708736831899504, 11.715436232153367, 12.643579096270166, 13.613380788183465, 14.485556622583339, 15.168571129991323, 14.185722060207873, 13.173328750374749, 12.239775905605187, 11.317270155245597, 10.376760132949519, 9.542920827161714, 8.528398686418512, 7.651204837446754, 6.8460979208979085, 6.754197768298206, 7.70435951768121, 8.685332379743983, 9.693118826216025, 10.63501730598926, 11.66467546024425, 12.610320086008121, 13.569848377368887, 14.59254053747818, 15.508390297242224, 16.117877587955938, 15.072753009124755, 14.141605011018491, 13.194635625243107, 12.269435181839642, 11.336463723671754, 10.537495607908404, 9.599013139925571, 8.68097477479102, 7.7790859748661525, 7.708770862649666, 8.673854904497704, 9.623239711368617, 10.582922484663772, 11.516194745612186, 12.50374864933939, 13.473158775246507, 14.53057166736479, 15.594578705767251, 16.499310797957797, 17.088003396874516, 16.098253592329417, 15.096008369044819, 14.176311682635351, 13.285518512452342, 12.309237562870928, 11.535741082669057, 10.599821336608626, 9.70592869861062, 8.711548186446407, 8.715971652808381, 9.609675847181354, 10.539289669901033, 11.514219798865717, 12.491913851676753, 13.486649845952973, 14.460303699641987, 15.501751983151038, 16.538905041403922, 17.510262935809987, 18.09605635587575, 17.12413147769301, 16.070936979713064, 15.175438282365228, 14.276654340770337, 13.252736102844318, 12.540392298246639, 11.570145714899883, 10.732532202354355, 9.690144125602528, 9.726792765153645, 10.572698922675391, 11.478746613172651, 12.420486074612288, 13.409817551107189, 14.447812487492182, 15.483859277022875, 16.476841985392095, 17.491604504351688, 18.46873330393375, 18.48651926566584, 17.47696215689537, 16.52956073191801, 15.56673551497037, 14.58274184514827, 13.64421800483264, 12.695523032279063, 11.822779411230046, 10.823037505506736, 10.056818899746789, 9.895115950556823, 10.85314933109675, 11.848697622328682, 12.545027647746322, 13.604820049903731, 14.610746121209774, 15.641262300445533, 16.536959079506584, 17.567355291823656, 18.494015565833422, 17.527316626731846, 16.610790707448214, 15.655100224215516, 14.680871838552333, 13.630889457311257, 12.663636903916958, 11.715836785197412, 10.840129052922403, 9.853781892051149, 9.01615154435391, 8.869767463299015, 9.937469754987623, 10.919532325618677, 11.619257668781474, 12.670235336936608, 13.609581284932915, 14.59200855160436, 15.574629921026053, 16.542052601424977, 17.486509355079438, 16.571830344761757, 15.677209086754488, 14.724409618967842, 13.71386812651508, 12.768768191121621, 11.726041489027923, 10.692479896425674, 9.940775630428732, 8.901026578038492, 7.966886513792176, 7.9390126557801315, 8.952321738241851, 9.919283693624905, 10.661324861381997, 11.661083270843442, 12.660039750344268, 13.633227620336573, 14.61524156777149, 15.569662768687763, 16.587152404722076, 15.634178105749998, 14.673422173852853, 13.715893346282524, 12.682675122983987, 11.752119996025826, 10.734319611901299, 9.729456006586664, 8.921971930572662, 7.960811061005844, 7.035325284025391, 6.960548386684482, 7.90565889035462, 8.851969948987893, 9.729140763022981, 10.731021292745254, 11.686145334533999, 12.642446522403544, 13.658921769808538, 14.667294803570993, 15.555686844035325, 14.62452847623344, 13.603764663052587, 12.675195445589992, 11.7347470889328, 10.728374101766429, 9.733413303243266, 8.769263275277446, 7.941955529148424, 7.05407437976863, 6.071114893059635, 5.916945177478927, 6.911480771400927, 7.872656804130209, 8.728603904341341, 9.797085027693612, 10.816759647823925, 11.710416146755719, 12.665439878466833, 13.651584268442154, 14.63461139193488, 13.724068452147693, 12.785986666358646, 11.855533093598249, 10.85059142425885, 9.835407586889364, 8.797884439491376, 7.807021321690206, 6.963782703263817, 5.987190822320838, 5.121223430192826, 4.889192182804076, 5.892461780625424, 6.897186991200051, 7.795912192174143, 8.829493554291727, 9.747269476564815, 10.702789558753944, 11.734045985533882, 12.692076212240362, 13.740875218956283, 12.779485303270686, 11.822531043345835, 10.827124754324709, 9.835334626769548, 8.85031295271941, 7.833397102280669, 6.840376586732905, 5.930504848432311, 4.9180140077753824, 4.097866682343035], [3.8795486389786573, 2.938100781308116, 3.9314431168521047, 4.865830407324317, 5.84816446904383, 6.852862784132681, 7.838718038738486, 8.83441883355838, 9.797716813275985, 10.775150790175287, 11.762716627112537, 12.609018250296137, 11.669154370630885, 10.679161471988783, 9.722561941134206, 8.775724487165975, 7.737223552755375, 6.725031593606534, 5.727461617263787, 4.776433400977982, 2.907148990981219, 1.96206489662796, 2.9405221034211415, 3.9254323283363735, 4.860585733061674, 5.837798946012476, 6.898824834660549, 7.83405056621524, 8.8207975728477, 9.782997087260037, 10.737102345268818, 11.666735354670083, 10.815394461380855, 9.834117985016103, 8.79559654832147, 7.789226666983958, 6.8262662958387255, 5.7812848027812205, 4.7946654857411195, 3.8477390971850993, 2.0021156892127037, 0.9614090748391471, 1.9972383580776216, 2.8965384551834084, 3.895475014083015, 4.893944632107026, 5.943158345625042, 6.9611986903377705, 7.931025005976342, 8.849821512715135, 9.89056665349025, 10.86997505961064, 9.965871991743407, 9.0172879956707, 8.044288105803933, 6.988016125231214, 5.930132340163754, 5.013555568625257, 4.049540693908822, 2.9861223277888405, 1.038408152697977, 0.0, 0.9842166668190481, 1.9340278311911212, 2.9425251180183465, 4.01128160103044, 4.994901104140217, 5.993985903659992, 6.95015809495356, 7.8962551618575425, 8.942129172739438, 9.995813396643936, 9.213353488923754, 8.16824492013824, 7.120130799168114, 6.045957592827416, 4.976466123897622, 4.038336501908072, 3.040800172692739, 2.103292332957547, 1.9834314529634813, 1.0381749322590879, 1.9342593731756947, 2.9729010031726264, 3.9371078696359048, 4.870755798344458, 5.859807443619479, 6.802543357242299, 7.784974843141578, 8.816474814742644, 9.883356650940526, 10.860175119002257, 9.978907368947855, 8.954082941796873, 7.890674056621588, 6.933843700674052, 5.866145969100801, 4.839160114810369, 3.861923210272056, 2.9213320569916696, 2.9304739935639716, 2.0376844323112615, 2.9809577021180704, 3.9719143735163125, 5.000689584994822, 5.8043481091673605, 6.844607936016319, 7.727791998027547, 8.700704858463101, 9.686356712083107, 10.620946700940902, 11.647392778762832, 10.818654502314358, 9.847243301600201, 8.780913290185588, 7.7337260962384455, 6.758952153442941, 5.733047133293468, 4.796481922796065, 3.86110210427489, 3.923676081687335, 3.0514249711834323, 4.013220296970158, 4.961117802505003, 5.937390054359075, 6.85514700476736, 7.850954739831103, 8.673885944743857, 9.632042009118544, 10.622136739044551, 11.569614058162601, 12.535395061950132, 11.683595601211808, 10.637757935129894, 9.629941154830243, 8.651231496326185, 7.691786182960186, 6.66766699694003, 5.760600238505228, 4.850144392193265, 4.890882394985477, 4.062486891821749, 5.004371297289485, 5.985210900057522, 6.993056683341932, 7.840609680609366, 8.804522080655847, 9.620394727183957, 10.573857899346809, 11.54106036888935, 12.600662578126366, 13.485035380004268, 12.484521214181505, 11.418439405523591, 10.434164331131456, 9.492070815835103, 8.544746225936443, 7.61288854565792, 6.700319403551003, 5.858489696925194, 5.819482451089634, 5.135420860743334, 5.957325684406432, 6.973578254501821, 8.000319442532156, 8.822652743309009, 9.809156335851355, 10.689074958424541, 11.648831209035103, 12.504122419238703, 13.49976842438111, 14.343976694408122, 13.384313416913377, 12.320585035771698, 11.366976312781919, 10.429236907463135, 9.54736227553175, 8.61511259745325, 7.741690566780102, 6.819041909005891, 6.825974495799746, 6.109611101249346, 6.992444919584775, 7.942778261996548, 8.92616934815258, 9.834448843655265, 10.742369883770111, 11.632247324949663, 12.602049016862962, 13.474224851262836, 14.427542443530589, 15.224130212905848, 14.211736903072724, 13.278184058303163, 12.355678307943572, 11.415168285647495, 10.581328979859691, 9.56680683911649, 8.689612990144731, 7.884506073595885, 7.792605920996182, 7.178519484272083, 8.050127891833805, 8.940981026347142, 9.870130343645979, 10.790387472000011, 11.68018708748435, 12.558516606048384, 13.581208766157678, 14.497058525921721, 15.376848901495203, 16.111161161822732, 15.180013163716467, 14.233043777941083, 13.307843334537617, 12.37487187636973, 11.575903760606382, 10.637421292623548, 9.719382927488997, 8.81749412756413, 8.747179015347642, 8.148014871088577, 8.98803522345844, 9.947717996753594, 10.88099025770201, 11.86216538507076, 12.700699336217756, 13.538705588159537, 14.602712626561999, 15.487979026637293, 16.352232425021384, 17.136661745027396, 16.134416521742793, 15.214719835333327, 14.323926665150317, 13.347645715568904, 12.574149235367035, 11.638229489306603, 10.744336851308596, 9.749956339144385, 9.754379805506357, 9.083835813772227, 9.923502033108827, 10.879015310955541, 11.856709363766576, 12.851445358042797, 13.709055625588391, 14.608410029284828, 15.610526561404912, 16.541460673992166, 17.360285384022617, 17.4861869907757, 16.484223303112294, 15.476756551743646, 14.483131688847491, 13.543336641494523, 12.62325407108892, 11.895032529607832, 10.930046462991607, 10.728552278300503, 10.76520091785162, 10.046858889266264, 10.862958976380446, 11.804698437820083, 12.791905047203633, 13.812607999582006, 14.758629262363772, 15.620384029464098, 16.56322602435268, 17.54035482393474, 17.448111112967865, 16.438554004197396, 15.491152579220035, 14.528327362272394, 13.544333692450294, 12.605809852134664, 11.657114879581087, 10.922087588261293, 9.922345682537983, 10.821331870537806, 10.722445776884785, 11.083535105235491, 11.790161909691552, 12.751953552463837, 13.729345071211572, 14.735271142517615, 15.788134746687279, 16.629947452205176, 17.496211628693885, 17.466278523051482, 16.488908474033874, 15.57238255475024, 14.61669207151754, 13.642463685854358, 12.592481304613282, 11.625228751218982, 10.677428632499435, 9.93943722995365, 8.953090069082396, 9.780664515144927, 9.697097289626976, 10.764799581315584, 11.746862151946639, 12.51222972995633, 13.563207398111464, 14.50255334610777, 15.484980612779216, 16.467601982200907, 17.403229065951958, 16.458772312297498, 15.533422192063783, 14.638800934056512, 13.686001466269866, 12.675459973817105, 11.730360038423646, 10.687633336329947, 9.654071743727696, 8.90704132281832, 8.000334755069737, 8.731399484583193, 8.767834550449713, 9.782906414639427, 10.789589085391132, 11.554296922556853, 12.554055332018297, 13.553011811519124, 14.526199681511429, 15.508213628946345, 16.449132164331278, 15.548744252024102, 14.595769953052022, 13.635014021154877, 12.677485193584548, 11.644266970286012, 10.71371184332785, 9.695911459203323, 8.691047853888687, 7.88823762296225, 6.986025284894399, 7.799838254816408, 7.789370281354063, 8.736243566752197, 9.72227534075412, 10.622112824197837, 11.62399335392011, 12.579117395708854, 13.5354185835784, 14.551893830983394, 15.505321501120497, 14.51727869133735, 13.586120323535464, 12.565356510354611, 11.636787292892016, 10.696338936234824, 9.689965949068453, 8.69500515054529, 7.730855122579469, 6.908221221538012, 6.020340072158218, 6.835627863850652, 6.809917238653782, 7.804452832575783, 8.765628865305064, 9.621575965516197, 10.690057088868468, 11.762830829901791, 12.663012837518924, 13.618036569230037, 14.604180959205358, 13.622991878156059, 12.685660299449717, 11.747578513660669, 10.817124940900273, 9.812183271560874, 8.796999434191388, 7.759476286793401, 6.76861316899223, 5.930048395653405, 4.953456514710426, 5.885736400983843, 5.782164243978931, 6.7854338418002795, 7.790159052374907, 8.688884253348998, 9.722465615466582, 10.69986616732802, 11.655386249517148, 12.686642676297087, 13.620594110028424, 12.780624653780858, 11.74107715057271, 10.784122890647858, 9.788716601626733, 8.796926474071572, 7.811904800021433, 6.794988949582693, 5.801968434034929, 4.896770540821899, 3.8842797001649707, 4.862379653134052], [4.863765305797706, 3.9223174481271643, 3.114762936165091, 3.8816137405052693, 4.863947802224782, 5.868646117313633, 6.854501371919438, 7.850202166739333, 8.813500146456937, 9.790934123356239, 10.77849996029349, 11.624801583477089, 12.588744256117483, 11.66337813880783, 10.706778607953254, 9.759941153985022, 8.721440219574422, 7.709248260425582, 6.711678284082835, 5.760650067797031, 3.8913656578002676, 2.946281563447008, 2.083956625156249, 2.9412156615173255, 3.8763690662426256, 4.853582279193428, 5.914608167841501, 6.8498338993961925, 7.836580906028653, 8.79878042044099, 9.75288567844977, 10.682518687851035, 11.72124270582376, 10.818334651835151, 9.779813215140518, 8.773443333803007, 7.810482962657773, 6.765501469600268, 5.7788821525601675, 4.831955764004148, 2.9863323560317516, 1.945625741658195, 1.0491251624643192, 1.9123217883643604, 2.911258347263967, 3.9097279652879777, 4.958941678805994, 5.9769820235187225, 6.946808339157294, 7.865604845896087, 8.906349986671202, 9.885758392791592, 10.942132578141184, 10.001504662489747, 9.02850477262298, 7.972232792050262, 6.9143490069828015, 5.997772235444305, 5.03375736072787, 3.9703389946078884, 2.022624819517025, 0.9842166668190481, 0.0, 0.949811164372073, 1.9583084511992983, 3.027064934211392, 4.010684437321169, 5.009769236840944, 5.965941428134512, 6.9120384950384945, 7.95791250592039, 9.011596729824888, 9.975227778488279, 9.152461586957289, 8.104347465987162, 7.030174259646464, 5.96068279071667, 5.02255316872712, 4.025016839511787, 3.087508999776595, 2.949569479704969, 1.9178852804109732, 0.9500427063566466, 1.9886843363535782, 2.9528912028168564, 3.886539131525409, 4.87559077680043, 5.81832669042325, 6.800758176322529, 7.832258147923596, 8.899139984121478, 9.875958452183209, 10.868926506560873, 9.92022096853836, 8.856812083363074, 7.899981727415538, 6.832283995842287, 5.805298141551856, 4.828061237013544, 3.8874700837331573, 3.8726007819598776, 2.917394780463147, 1.9967410352990222, 2.987697706697264, 4.016472918175774, 4.820131442348311, 5.860391269197269, 6.743575331208497, 7.716488191644052, 8.702140045264057, 9.636730034121852, 10.66317611194378, 11.733706565654124, 10.813381328341691, 9.747051316927076, 8.699864122979934, 7.725090180184429, 6.699185160034956, 5.762619949537553, 4.803228892670796, 4.8658028700832405, 3.9311353193353176, 3.0290036301511103, 3.9769011356859547, 4.953173387540027, 5.870930337948311, 6.866738073012053, 7.689669277924808, 8.647825342299496, 9.637920072225501, 10.585397391343552, 11.551178395131082, 12.481658933561548, 11.603895961871382, 10.596079181571731, 9.617369523067673, 8.657924209701674, 7.633805023681518, 6.726738265246716, 5.792271180589171, 5.833009183381383, 4.942197239973634, 4.020154630470437, 5.000994233238474, 6.008840016522884, 6.856393013790316, 7.820305413836797, 8.636178060364909, 9.589641232527761, 10.556843702070301, 11.616445911307318, 12.572124380554307, 13.413753269423534, 12.38457743226508, 11.400302357872945, 10.458208842576592, 9.510884252677933, 8.579026572399409, 7.666457430292491, 6.8006164853210995, 6.76160923948554, 5.951894031684136, 4.973109017587384, 5.989361587682773, 7.016102775713108, 7.838436076489958, 8.824939669032306, 9.704858291605493, 10.664614542216055, 11.519905752419655, 12.515551757562061, 13.523291869431208, 14.350451443654867, 13.286723062513188, 12.333114339523409, 11.395374934204625, 10.51350030227324, 9.581250624194737, 8.70782859352159, 7.761168697401797, 7.768101284195652, 6.926084272190148, 6.008228252765727, 6.9585615951775, 7.941952681333533, 8.850232176836213, 9.758153216951062, 10.648030658130615, 11.617832350043914, 12.490008184443788, 13.443325776711541, 14.426174846494991, 15.177874929814214, 14.244322085044653, 13.321816334685062, 12.381306312388984, 11.54746700660118, 10.532944865857978, 9.655751016886219, 8.82663286199179, 8.734732709392087, 7.9949926552128865, 7.065911225014757, 7.956764359528094, 8.885913676826931, 9.80617080518096, 10.6959704206653, 11.574299939229336, 12.59699209933863, 13.512841859102673, 14.392632234676155, 15.448626468808394, 16.146151190457957, 15.199181804682572, 14.273981361279107, 13.34100990311122, 12.54204178734787, 11.603559319365036, 10.685520954230485, 9.759620915960035, 9.689305803743547, 8.96448804202938, 8.003818556639391, 8.963501329934546, 9.896773590882962, 10.877948718251709, 11.716482669398706, 12.55448892134049, 13.618495959742951, 14.503762359818245, 15.368015758202338, 16.357765562747435, 16.474935246961493, 15.491666484654475, 14.481846129335324, 13.502618514648866, 12.690758129796446, 12.123413900734874, 11.710474878050086, 10.69208312754029, 10.696506593902264, 9.868899189009458, 8.939285366289779, 9.894798644136493, 10.872492696947528, 11.86722869122375, 12.724838958769341, 13.62419336246578, 14.626309894585864, 15.557244007173118, 16.37606871720357, 16.50197032395665, 15.500006636293248, 14.492539884924598, 13.498915022028443, 12.559119974675475, 11.639037404269873, 11.153089522443617, 11.914263129810655, 11.67067906669641, 11.707327706247527, 10.831922264503495, 9.878742309561398, 10.820481771001035, 11.807688380384585, 12.828391332762958, 13.774412595544721, 14.63616736264505, 15.579009357533632, 16.556138157115694, 16.463894446148817, 15.454337337378348, 14.506935912400987, 13.544110695453346, 12.560117025631246, 11.621593185315616, 10.672898212762039, 10.164639409575745, 10.906562349357031, 11.805548537356854, 11.706662443703832, 11.801493534104436, 10.805945242872504, 11.767736885644789, 12.745128404392524, 13.751054475698567, 14.80391807986823, 15.645730785386128, 16.51199496187484, 16.482061856232438, 15.504691807214824, 14.588165887931192, 13.632475404698493, 12.65824701903531, 11.608264637794234, 10.641012084399934, 9.693211965680387, 9.181989051268102, 9.937306735901444, 10.764881181963975, 10.681313956446024, 11.749016248134632, 11.870427984268833, 12.693506864609637, 13.744484532764771, 14.718590114295171, 15.767163684582336, 16.608059943866657, 16.419012399132914, 15.474555645478452, 14.549205525244735, 13.654584267237464, 12.701784799450818, 11.691243306998057, 10.746143371604598, 9.703416669510899, 8.669855076908648, 8.110593841987559, 8.984551421888785, 9.71561615140224, 9.752051217268761, 10.767123081458479, 11.773805752210182, 12.538513589375901, 13.538271998837345, 14.537228478338172, 15.510416348330477, 16.419336698428502, 15.46491549751223, 14.564527585205054, 13.611553286232974, 12.650797354335829, 11.6932685267655, 10.660050303466964, 9.729495176508802, 8.711694792384275, 7.706831187069639, 7.091790142131489, 7.970241951713448, 8.784054921635457, 8.773586948173111, 9.720460233571247, 10.70649200757317, 11.606329491016885, 12.608210020739158, 13.563334062527902, 14.519635250397448, 15.536110497802442, 14.521104834301449, 13.533062024518301, 12.601903656716416, 11.581139843535563, 10.652570626072968, 9.712122269415776, 8.705749282249405, 7.710788483726242, 6.746638455760421, 6.111773740707251, 7.004556738977267, 7.8198445306697, 7.7941339054728305, 8.78866949939483, 9.74984553212411, 10.605792632335245, 11.674273755687516, 12.747047496720839, 13.647229504337972, 14.602253236049085, 13.621802334829738, 12.63877521133701, 11.701443632630669, 10.76336184684162, 9.832908274081225, 8.827966604741826, 7.812782767372339, 6.775259619974353, 5.784396502173182, 5.133600914822645, 5.937673181529475, 6.869953067802892, 6.76638091079798, 7.7696505086193275, 8.774375719193955, 9.673100920168046, 10.70668228228563, 11.684082834147068, 12.639602916336196, 13.595288992368246, 12.636377443209376, 11.79640798696181, 10.756860483753663, 9.79990622382881, 8.804499934807685, 7.812709807252524, 6.827688133202385, 5.810772282763645, 4.817751767215881, 4.100323059991139, 4.8684963669840196, 5.846596319953101], [5.813576470169778, 4.872128612499237, 3.891594729674767, 2.9318025761331956, 3.9141366378527085, 4.918834952941559, 5.904690207547365, 6.900391002367259, 7.863688982084863, 8.841122958984165, 9.828688795921416, 10.674990419105015, 11.63893309174541, 12.613189303179903, 11.656589772325326, 10.709752318357097, 9.671251383946498, 8.659059424797656, 7.661489448454907, 6.710461232169104, 4.84117682217234, 3.896092727819081, 2.99520744354211, 1.9914044971452523, 2.9265579018705523, 3.903771114821354, 4.964797003469427, 5.900022735024119, 6.886769741656579, 7.848969256068916, 8.803074514077696, 9.732707523478961, 10.771431541451687, 11.752708017816438, 10.72962437951259, 9.723254498175079, 8.760294127029846, 7.715312633972341, 6.72869331693224, 5.7817669283762205, 3.936143520403825, 2.8954369060302683, 1.9603759808501802, 0.9625106239922873, 1.9614471828918938, 2.959916800915905, 4.009130514433921, 5.02717085914665, 5.996997174785221, 6.915793681524013, 7.9565388222991285, 8.935947228419518, 9.99232141376911, 10.940905409841818, 9.978315936995054, 8.922043956422335, 7.864160171354875, 6.947583399816379, 5.983568525099943, 4.920150158979961, 2.972435983889098, 1.9340278311911212, 0.949811164372073, 0.0, 1.0084972868272253, 2.0772537698393188, 3.0608732729490957, 4.05995807246887, 5.016130263762438, 5.962227330666421, 7.008101341548317, 8.061785565452814, 9.025416614116205, 10.070525182901719, 9.054158630359236, 7.979985424018538, 6.910493955088744, 5.972364333099193, 4.974828003883861, 4.037320164148668, 3.8993806440770418, 2.867696444783046, 1.8998538707287196, 1.0388731719815052, 2.003080038444783, 2.936727967153336, 3.9257796124283573, 4.868515526051177, 5.850947011950456, 6.882446983551524, 7.949328819749404, 8.926147287811133, 9.919115342188798, 10.870032132910435, 9.806623247735148, 8.849792891787612, 7.782095160214361, 6.755109305923929, 5.777872401385617, 4.8372812481052305, 4.82241194633195, 3.8672059448352196, 2.9465521996710953, 2.0378865423251913, 3.066661753803701, 3.870320277976238, 4.910580104825197, 5.793764166836425, 6.76667702727198, 7.7523288808919855, 8.68691886974978, 9.713364947571709, 10.783895401282052, 11.755306601996208, 10.69686248129915, 9.649675287352007, 8.674901344556503, 7.648996324407029, 6.712431113909626, 5.753040057042869, 5.815614034455313, 4.88094648370739, 3.978814794523183, 3.027089971313882, 4.003362223167954, 4.921119173576237, 5.916926908639981, 6.739858113552736, 7.6980141779274245, 8.68810890785343, 9.63558622697148, 10.60136723075901, 11.531847769189476, 12.553707126243456, 11.545890345943805, 10.567180687439746, 9.607735374073748, 8.58361618805359, 7.676549429618789, 6.7420823449612435, 6.782820347753455, 5.892008404345707, 4.96996579484251, 4.0511830688664014, 5.059028852150811, 5.9065818494182425, 6.870494249464725, 7.686366895992837, 8.639830068155689, 9.60703253769823, 10.666634746935246, 11.622313216182235, 12.463942105051462, 13.334388596637153, 12.350113522245017, 11.408020006948664, 10.460695417050005, 9.52883773677148, 8.616268594664565, 7.750427649693172, 7.711420403857613, 6.901705196056209, 5.922920181959457, 5.1183380662467455, 6.090416685517709, 6.888624912117884, 7.875128504660233, 8.755047127233421, 9.714803377843984, 10.570094588047583, 11.56574059318999, 12.573480705059136, 13.406606744038854, 14.23653422688526, 13.28292550389548, 12.345186098576697, 11.463311466645312, 10.53106178856681, 9.657639757893664, 8.71097986177387, 8.717912448567724, 7.875895436562221, 6.9580394171378, 6.087538073741472, 7.0709291598975055, 7.90042101246414, 8.808342052578988, 9.698219493758543, 10.668021185671842, 11.540197020071716, 12.49351461233947, 13.47636368212292, 14.419942968568558, 15.194133249416724, 14.271627499057134, 13.331117476761056, 12.497278170973251, 11.48275603023005, 10.605562181258293, 9.776444026363864, 9.68454387376416, 8.944803819584958, 8.015722389386829, 7.085740838092066, 8.014890155390903, 8.856359640808886, 9.746159256293227, 10.624488774857264, 11.647180934966558, 12.563030694730601, 13.442821070304083, 14.498815304436322, 15.429963302542586, 15.431619577588037, 14.506419134184572, 13.525581189475966, 12.739192440185027, 12.553370483737108, 11.635332118602559, 10.709432080332107, 10.63911696811562, 9.914299206401452, 8.953629721011463, 8.101836235141345, 9.035108496089759, 9.928137553879637, 10.766671505026633, 11.604677756968417, 12.66868479537088, 13.553951195446173, 14.418204593830266, 15.407954398375365, 15.52512408258942, 14.541855320282401, 13.53203496496325, 12.552807350276792, 11.740946965424374, 12.627315066800259, 12.660286042422157, 11.641894291912362, 11.646317758274336, 10.81871035338153, 9.88909653066185, 9.03313354934329, 10.010827602154325, 10.988929945400075, 11.775027794397268, 12.674382198093708, 13.676498730213792, 14.607432842801046, 15.426257552831498, 15.552159159584578, 14.550195471921175, 13.542728720552525, 12.54910385765637, 11.609308810303402, 10.6892262398978, 11.656990688509001, 12.621976755125226, 12.620490231068482, 12.6571388706196, 11.781733428875567, 10.82855347393347, 10.006056932562073, 10.946023285591382, 11.950092586939284, 12.824601431172649, 13.686356198272978, 14.62919819316156, 15.60632699274362, 15.514083281776742, 14.504526173006274, 13.557124748028913, 12.594299531081273, 11.610305861259173, 10.671782020943542, 9.723087048389967, 10.66854057564113, 11.62430899046704, 12.567002581396885, 12.536081891872284, 12.751304698476508, 11.755756407244576, 10.968756019378786, 11.883463309599321, 12.889389380905364, 13.897977909966995, 14.695919621014056, 15.562183797502767, 15.53225069186036, 14.554880642842749, 13.638354723559116, 12.682664240326417, 11.708435854663236, 10.65845347342216, 9.69120092002786, 8.743400801308315, 9.685890217333487, 10.655053377011452, 11.594300630132427, 11.510733404614475, 12.578435696303083, 12.820239148640905, 11.894525998343633, 12.923909355698964, 13.898014937229364, 14.946588507516529, 15.658248779494585, 15.469201234760837, 14.524744481106376, 13.59939436087266, 12.704773102865389, 11.751973635078743, 10.741432142625982, 9.796332207232524, 8.753605505138825, 7.720043912536576, 8.76032003042464, 9.702298062998793, 10.545035599570692, 10.582532238095105, 11.612034772537319, 12.650356708109808, 12.85245880574311, 13.852217215204554, 14.847556471818011, 15.827250748541463, 15.469525534056428, 14.515104333140155, 13.614716420832979, 12.661742121860899, 11.700986189963754, 10.743457362393425, 9.710239139094888, 8.779684012136727, 7.7618836280122006, 6.757020022697565, 7.7415163305685715, 8.687988592823455, 9.613474369803908, 9.675886164922181, 10.622759450320316, 11.608791224322239, 12.55614065538896, 13.558021185111233, 14.513145226899978, 15.469446414769523, 14.596951502470358, 13.571293669929373, 12.583250860146226, 11.652092492344341, 10.631328679163488, 9.702759461700893, 8.7623111050437, 7.755938117877329, 6.760977319354167, 5.796827291388347, 6.761499929144334, 7.722303380087273, 8.72214374741877, 8.743945069844903, 9.738480663766904, 10.699656696496184, 11.55560379670732, 12.624084920059591, 13.696858661092914, 14.597040668710044, 13.658135560432983, 12.671991170457662, 11.688964046964935, 10.751632468258594, 9.813550682469547, 8.883097109709151, 7.878155440369753, 6.862971603000265, 5.825448455602278, 4.834585337801108, 5.866797808178564, 6.887484345901548, 7.819764232174965, 7.716192075170053, 8.7194616729914, 9.724186883566029, 10.622912084540122, 11.656493446657706, 12.63389399851914, 13.589414080708268, 12.64547782799617, 11.686566278837303, 10.846596822589735, 9.807049319381587, 8.850095059456736, 7.854688770435611, 6.862898642880451, 5.877876968830312, 4.860961118391572, 3.8679406028438073, 4.870354211210454, 5.818307531356092, 6.796407484325174], [6.740384143271545, 5.790739630151994, 4.797397294608005, 3.837605141066433, 2.949632393335346, 3.9543307084241963, 4.940185963030002, 5.935886757849897, 6.8991847375675, 7.832625672156939, 8.820191509094188, 9.666493132277788, 10.630435804918182, 11.620428703560284, 12.577028234414861, 11.718249605184322, 10.679748670773723, 9.667556711624881, 8.669986735282132, 7.718958518996329, 5.849674108999565, 4.904590014646306, 3.9557449231751205, 2.8972070620784898, 1.9620536573531895, 2.9392668703039915, 4.000292758952065, 4.935518490506756, 5.922265497139216, 6.84047196924169, 7.79457722725047, 8.724210236651734, 9.76293425462446, 10.744210730989211, 11.738121666339817, 10.731751785002306, 9.768791413857073, 8.723809920799567, 7.7371906037594655, 6.790264215203446, 4.94464080723105, 3.9039341928574935, 2.968873267677405, 1.9710079108195124, 0.9529498960646685, 1.9514195140886794, 3.000633227606696, 4.0186735723194245, 4.988499887957996, 5.907296394696788, 6.948041535471903, 7.927449941592293, 8.983824126941885, 9.932408123014593, 10.90540801288136, 9.93054124324956, 8.8726574581821, 7.956080686643604, 6.992065811927168, 5.9286474458071865, 3.9809332707163234, 2.9425251180183465, 1.9583084511992983, 1.0084972868272253, 0.0, 1.0687564830120935, 2.0523759861218704, 3.0514607856416447, 4.007632976935213, 4.953730043839196, 5.999604054721091, 7.053288278625588, 8.01691932728898, 9.062027896074493, 10.062655917186461, 8.988482710845762, 7.918991241915969, 6.980861619926419, 5.983325290711086, 5.0458174509758935, 4.907877930904267, 3.8761937316102713, 2.908351157555945, 2.023839569077742, 1.059632702614464, 1.993280631323017, 2.9823322765980382, 3.9250681902208586, 4.907499676120137, 5.938999647721205, 6.940831532922179, 7.917650000983909, 8.910618055361574, 9.935442482512556, 10.815120534562372, 9.858290178614835, 8.790592447041584, 7.763606592751153, 6.786369688212841, 5.845778534932455, 5.830909233159175, 4.8757032316624445, 3.9550494864983206, 3.022852939421428, 2.130734586401318, 2.926872942145919, 3.9671327689948774, 4.850316831006106, 5.823229691441661, 6.808881545061666, 7.743471533919461, 8.769917611741391, 9.840448065451735, 10.811859266165891, 11.705359768126373, 10.65817257417923, 9.683398631383726, 8.657493611234253, 7.720928400736851, 6.761537343870093, 6.824111321282538, 5.889443770534616, 4.987312081350408, 4.012056368410119, 3.122677688696653, 3.9776718377459184, 4.973479572809662, 5.796410777722417, 6.7545668420971055, 7.7446615720231105, 8.69213889114116, 9.65791989492869, 10.588400433359157, 11.63423809944107, 12.554387632771029, 11.57567797426697, 10.616232660900971, 9.592113474880815, 8.685046716446013, 7.750579631788468, 7.79131763458068, 6.900505691172932, 5.9784630816697355, 5.036149465962638, 4.178344317679509, 4.963134513587924, 5.927046913634406, 6.742919560162518, 7.69638273232537, 8.66358520186791, 9.723187411104927, 10.678865880351916, 11.520494769221143, 12.586576577879057, 13.358610809072243, 12.41651729377589, 11.46919270387723, 10.537335023598706, 9.624765881491788, 8.758924936520398, 8.719917690684836, 7.9102024828834345, 6.931417468786682, 6.103304463342982, 5.209732151046407, 5.945177576287566, 6.931681168829914, 7.8115997914031015, 8.771356042013664, 9.626647252217264, 10.62229325735967, 11.630033369228817, 12.463159408208536, 13.526887789350216, 14.291422790722706, 13.353683385403922, 12.471808753472537, 11.539559075394035, 10.666137044720887, 9.719477148601095, 9.726409735394949, 8.884392723389446, 7.9665367039650254, 7.072504470837709, 6.2604024306479875, 6.9569736766338215, 7.86489471674867, 8.754772157928222, 9.724573849841521, 10.596749684241397, 11.55006727650915, 12.5329163462926, 13.47649563273824, 14.410048477507802, 14.673440684261061, 13.700141303680645, 13.505775457800477, 12.491253317057275, 11.614059468085516, 10.784941313191089, 10.693041160591385, 9.953301106412184, 9.024219676214054, 8.070707235188303, 7.204363426141385, 7.912912304978569, 8.802711920462908, 9.681041439026943, 10.703733599136237, 11.619583358900282, 12.499373734473764, 13.555367968606003, 14.486515966712266, 14.646476101070482, 13.721275657667016, 12.74043771295841, 13.644995005118263, 13.561867770564334, 12.643829405429782, 11.717929367159332, 11.647614254942845, 10.922796493228677, 9.962127007838689, 9.086802632237582, 8.246604796199708, 8.98469021804932, 9.823224169196314, 10.661230421138097, 11.725237459540558, 12.610503859615854, 13.474757257999947, 14.464507062545046, 14.739980606071864, 13.756711843764846, 12.746891488445694, 11.767663873759236, 12.64674953035761, 13.533117631733495, 13.668783329249383, 12.650391578739587, 12.65481504510156, 11.827207640208755, 10.897593817489076, 10.018099946439527, 9.27394880806914, 10.045482609569758, 10.831580458566949, 11.730934862263387, 12.733051394383471, 13.663985506970727, 14.48281021700118, 14.767015683067022, 13.765051995403619, 12.757585244034969, 11.763960381138814, 10.824165333785846, 11.595028804831037, 12.562793253442237, 13.527779320058462, 13.628987517895707, 13.665636157446825, 12.790230715702792, 11.837050760760695, 10.99102332965831, 10.209144491506196, 11.006645251108967, 11.881154095342328, 12.742908862442658, 13.68575085733124, 14.662879656913299, 14.622514499657605, 13.719382696488719, 12.771981271511358, 11.809156054563717, 10.825162384741617, 9.886638544425987, 10.628889613323203, 11.574343140574365, 12.530111555400275, 13.47280514633012, 13.441884456805521, 13.759801985303733, 12.764253694071801, 11.953722416475022, 11.146584515514135, 12.042096230921587, 12.954530574136674, 13.752472285183735, 14.618736461672446, 14.628045780126525, 13.650675731108914, 12.80493903597979, 11.849248552747092, 10.9027918207786, 9.873309996904604, 8.906057443510305, 9.64920336624155, 10.591692782266723, 11.560855941944688, 12.500103195065664, 12.416535969547713, 13.484238261236321, 13.82873643546813, 12.87949239543987, 12.187030561613778, 13.072403660779555, 14.003784322977847, 14.714801443664264, 14.564996323027001, 13.620539569372541, 12.695189449138825, 11.860380474091366, 10.918557947499417, 9.908016455046656, 8.979418644355869, 7.968462028621269, 8.625846477469812, 9.66612259535788, 10.60810062793203, 11.45083816450393, 11.488334803028343, 12.517837337470556, 13.556159273043047, 13.837425202839347, 13.246910421010016, 14.021945195368202, 14.962565254245634, 14.565320622322593, 13.61089942140632, 12.710511509099144, 11.757537210127063, 10.856593561189731, 9.9100416748141, 8.876823451515563, 7.946268324557401, 6.976740151494644, 7.662822587630803, 8.64731889550181, 9.593791157756693, 10.519276934737146, 10.58168872985542, 11.528562015253556, 12.514593789255478, 13.534684180573574, 14.270687458655628, 15.073634053553414, 14.56624813269454, 13.692746590736522, 12.667088758195538, 11.67904594841239, 10.747887580610506, 9.78514030486614, 8.869343774121567, 7.928895417464374, 6.922522430298003, 5.927561631774841, 6.702629856321585, 7.667302494077572, 8.628105945020511, 9.627946312352009, 9.702564617716442, 10.746977950594129, 11.70815398332341, 12.564101083534545, 13.632582206886816, 14.623822631867785, 13.61370514877511, 12.659696475196423, 11.673552085221102, 10.713137281403236, 9.775805702696895, 8.849046437952186, 7.918592865191788, 6.91365119585239, 5.938604332500518, 4.992032768022953, 5.740387902734346, 6.772600373111803, 7.806095363554305, 8.738375249827723, 8.724689361997278, 9.727958959818626, 10.732684170393254, 11.631409371367347, 12.664990733484931, 13.554332460608675, 12.606078560773335, 11.636980541168946, 10.678068992010076, 9.854090785256245, 8.831222553819888, 7.885590814939374, 6.890184525918248, 5.898394398363088, 4.913372724312949, 3.9630539757358667, 4.773743167777045, 5.776156776143692, 6.736918549008849, 7.715018501977931], [7.767653571454403, 6.8180090583348525, 5.824666722790863, 4.864874569249292, 3.976901821518204, 3.058065179016346, 3.9045509552623408, 4.900251750082235, 5.863549729799839, 6.763869189144846, 7.7514350260820954, 8.597736649265695, 9.56167932190609, 10.551672220548191, 11.508271751402768, 12.47930757865943, 11.736630214278577, 10.724438255129735, 9.726868278786986, 8.775840062501183, 6.906555652504419, 5.96147155815116, 4.983014351357979, 3.924476490261348, 2.9893230855360478, 2.012109872585246, 2.9646577511844034, 3.899883482739095, 4.886630489371555, 5.771715486229597, 6.725820744238377, 7.655453753639641, 8.694177771612367, 9.675454247977118, 10.713975684671752, 11.720345566009263, 10.825672957361927, 9.780691464304422, 8.79407214726432, 7.8471457587083, 6.013397290243144, 4.972690675869587, 4.037629750689499, 3.039764393831606, 2.021706379076762, 1.023771426085941, 1.9410560796966534, 2.959096424409382, 3.9202062172000733, 4.838539911684695, 5.87928505245981, 6.8586934585802, 7.915067643929792, 8.8636516400025, 9.836651529869266, 10.892923510441985, 9.941413941194195, 9.024837169655697, 8.060822294939262, 6.99740392881928, 5.049689753728417, 4.01128160103044, 3.027064934211392, 2.0772537698393188, 1.0687564830120935, 0.0, 0.9836195031097769, 1.9827043026295512, 2.93887649392312, 3.8849735608271025, 4.930847571708998, 5.984531795613495, 6.948162844276887, 7.9932714130624, 9.041385534032527, 10.057239193857857, 8.987747724928063, 8.049618102938513, 7.05208177372318, 6.114573933987987, 5.941072595203083, 4.909388395909088, 3.9415458218547608, 2.901863120975457, 1.9376562545121785, 1.0040083258036256, 1.9930599710786467, 2.935795884701467, 3.9182273706007456, 4.918967899132347, 5.8720750499100856, 6.848893517971816, 7.8418615723494804, 8.866685999500463, 9.93009488467575, 10.886925240623286, 9.823787111340403, 8.796801257049971, 7.819564352511658, 6.878973199231272, 6.8641038974579915, 5.908897895961261, 4.928801692817819, 3.900876491319143, 2.8752076963417235, 1.9376006366265277, 2.977860463475486, 3.8610445254867143, 4.833957385922268, 5.819609239542274, 6.7541992284000685, 7.780645306221998, 8.84322120638992, 9.814632407104076, 10.880962418518692, 11.691367238478048, 10.716593295682543, 9.69068827553307, 8.754123065035667, 7.79473200816891, 7.8573059855813545, 6.922638434833432, 5.907119258558588, 4.843423050491131, 3.8671507986370584, 2.988399532226527, 3.984207267290271, 4.807138472203025, 5.765294536577714, 6.755389266503718, 7.702866585621767, 8.668647589409296, 9.599128127839762, 10.644965793921676, 11.652782574221327, 12.608872638565787, 11.649427325199788, 10.625308139179632, 9.71824138074483, 8.783774296087284, 8.817473946973024, 7.826806364074268, 6.879195665169135, 5.86751614804365, 4.922817427619915, 3.973862208068533, 4.9377746081150145, 5.753647254643125, 6.707110426805978, 7.674312896348519, 8.733915105585536, 9.689593574832525, 10.531222463701749, 11.597304272359663, 12.581579346751798, 13.449711958074706, 12.502387368176047, 11.570529687897523, 10.657960545790605, 9.792119600819213, 9.746074003077181, 8.810935066382834, 7.832150052286082, 6.934671145423994, 5.954205260986813, 4.955905270768175, 5.942408863310522, 6.822327485883709, 7.782083736494272, 8.637374946697873, 9.63302095184028, 10.640761063709427, 11.47388710268914, 12.53761548383082, 13.491224206820599, 14.386878049702739, 13.505003417771354, 12.572753739692853, 11.699331709019704, 10.75267181289991, 10.728099258262732, 9.785125306888846, 8.867269287464424, 7.903871152918721, 6.963887628059451, 5.967701371114431, 6.875622411229278, 7.76549985240883, 8.735301544322128, 9.607477378722006, 10.56079497098976, 11.54364404077321, 12.487223327218844, 13.420776171988406, 13.994825161529805, 14.727410731863502, 14.538970122099295, 13.524447981356094, 12.647254132384333, 11.799241238352826, 11.694730683459168, 10.8385064118609, 9.857533549798127, 8.849747103326084, 7.907848623552849, 6.923639999459178, 7.813439614943517, 8.69176913350755, 9.714461293616845, 10.630311053380892, 11.510101428954373, 12.566095663086612, 13.497243661192876, 13.967860578339225, 13.04266013493576, 13.767707141141267, 14.672264433301121, 14.595062434863152, 13.6770240697286, 12.719618890027116, 12.649303777810628, 11.808001798677394, 10.795440881422762, 9.865842500375363, 8.950089993611172, 7.995417912529928, 8.833951863676923, 9.671958115618704, 10.735965154021166, 11.621231554096463, 12.485484952480556, 13.475234757025655, 13.818518569280434, 12.990423607084336, 12.02657680432306, 12.794933301942093, 13.674018958540469, 14.560387059916353, 14.701977993548198, 13.65208110160737, 13.656504567969343, 12.660521513792828, 11.73090769107315, 10.79713981457731, 9.977434005480603, 9.056210304050367, 9.842308153047558, 10.741662556743995, 11.743779088864079, 12.674713201451336, 13.493537911481788, 13.844441977323621, 12.843589958612188, 11.99129700735446, 10.997672144458305, 11.851434761968703, 12.622298233013895, 13.590062681625096, 14.55504874824132, 14.630677040763489, 14.58477433884748, 13.623544589286865, 12.670364634344768, 11.770063197796093, 10.91262968891766, 10.017372945589576, 10.89188178982294, 11.753636556923265, 12.696478551811847, 13.673607351393906, 13.553758016645512, 12.796808990745317, 11.850519234719927, 10.975331035298112, 10.058874148061108, 10.913907972608843, 11.656159041506061, 12.601612568757224, 13.557380983583137, 14.500074574512983, 14.469153884988382, 14.593115858887806, 13.597567567655874, 12.732762284612805, 11.850069712925599, 11.052823925402194, 11.965258268617285, 12.763199979664343, 13.629464156153054, 13.559289297114432, 12.58191924809682, 11.847208043209287, 10.891517559976588, 9.945060828008096, 9.107021760224095, 9.933326871693161, 10.67647279442441, 11.618962210449581, 12.58812537012755, 13.527372623248525, 13.443805397730573, 14.511507689419181, 14.649543109970013, 13.658532263577653, 12.890515759025241, 12.083131355260162, 13.014512017458458, 13.725529138144871, 13.496239840014908, 12.551783086360448, 11.626432966126732, 10.824745466323705, 9.960826954728914, 8.950285462276153, 8.091975055202921, 8.995731456804126, 9.65311590565267, 10.693392023540738, 11.63537005611489, 12.47810759268679, 12.515604231211203, 13.545106765653417, 14.583428701225905, 14.61646507097713, 13.95039561842148, 13.03267288984881, 13.973292948726245, 13.4965641393105, 12.542142938394226, 11.64175502608705, 10.68878072711497, 9.82095855342207, 8.952310682043596, 7.919092458745059, 7.058824735404452, 8.004009579677502, 8.690092015813661, 9.674588323684668, 10.621060585939553, 11.546546362920006, 11.60895815803828, 12.555831443436416, 13.541863217438339, 14.561953608756435, 14.974172656067092, 14.084361748034022, 13.497491649682445, 12.62399010772443, 11.598332275183445, 10.610289465400298, 9.679131097598413, 8.749505297098478, 7.911612781351064, 6.97116442469387, 6.035078841145054, 6.9548310599577, 7.729899284504444, 8.694571922260431, 9.655375373203372, 10.655215740534869, 10.729834045899299, 11.803244453039857, 12.764420485769138, 13.6209826270394, 14.404197407042426, 13.555066148855692, 12.544948665763018, 11.59093999218433, 10.604795602209009, 9.644380798391143, 8.707049219684801, 7.813411430184525, 6.918082074860503, 5.913140405521105, 5.042338803092667, 6.019302196205811, 6.767657330917205, 7.799869801294662, 8.833364791737164, 9.76564467801058, 9.761825163857559, 10.78484050332348, 11.789565713898108, 12.688290914872201, 13.436605933640541, 12.485575977596582, 11.537322077761242, 10.56822405815685, 9.609312508997983, 8.785334302244152, 7.762466070807795, 6.849955807171713, 5.889673735586963, 4.897883608031803, 4.0171071949050985, 4.990323403918725, 5.801012595959904, 6.80342620432655, 7.764187977191708, 8.742287930160789], [8.750532435473353, 7.8008879223538035, 6.807545586809814, 5.847753433268243, 4.9399116701632515, 3.935213355074401, 2.9209314521525633, 3.916632246972458, 4.879930226690063, 5.780249686035069, 6.7678155229723185, 7.614117146155918, 8.578059818796312, 9.568052717438414, 10.524652248292991, 11.495688075549653, 12.534189009960254, 11.707317119148685, 10.709747142805938, 9.758718926520135, 7.889434516523371, 6.944350422170111, 5.96589321537693, 4.907355354280299, 3.972201949554999, 2.9949887366041974, 1.9810382480746263, 2.916263979629318, 3.9030109862617786, 4.78809598311982, 5.7422012411286, 6.671834250529864, 7.71055826850259, 8.691834744867341, 9.730356181561975, 10.736726062899486, 11.699686434044718, 10.763570328323372, 9.776951011283272, 8.830024622727251, 6.997016793352921, 5.956310178979364, 5.021249253799276, 4.023383896941383, 3.0051199081289033, 2.0066502901048926, 0.9574365765868764, 1.975476921299605, 2.936586714090297, 3.854920408574918, 4.895665549350033, 5.875073955470423, 6.931448140820015, 7.880032136892722, 8.85303202675949, 9.909304007332208, 10.92503344430397, 10.008456672765474, 9.04444179804904, 7.981023431929057, 6.033309256838194, 4.994901104140217, 4.010684437321169, 3.0608732729490957, 2.0523759861218704, 0.9836195031097769, 0.0, 0.9990847995197745, 1.955256990813343, 2.9013540577173256, 3.9472280685992214, 5.000912292503718, 5.96454334116711, 7.009651909952623, 8.05776603092275, 9.131939237263449, 9.971367228037838, 9.033237606048289, 8.035701276832956, 7.098193437097764, 6.92469209831286, 5.893007899018865, 4.925165324964538, 3.885482624085234, 2.9212757576219555, 1.9876278289134026, 1.0100526732029858, 1.9527885868258061, 2.935220072725085, 3.9353483960225697, 4.888455546800309, 5.865274014862039, 6.8582420692397035, 7.883066496390686, 8.946475381565971, 9.903305737513508, 10.80740661445018, 9.780420760159748, 8.803183855621436, 7.862592702341049, 7.8477234005677685, 6.892517399071038, 5.912421195927596, 4.88449599442892, 3.8588271994515004, 2.9212201397363047, 2.072469154618305, 2.8780372276110535, 3.850950088046608, 4.836601941666613, 5.771191930524408, 6.797638008346337, 7.859601703280143, 8.8310129039943, 9.897342915408913, 10.861927166350734, 11.70021279879232, 10.674307778642847, 9.737742568145444, 8.778351511278688, 8.840925488691132, 7.906257937943209, 6.890738761668365, 5.827042553600908, 4.850770301746835, 3.972019035336304, 3.07881595843309, 3.824131174327364, 4.782287238702052, 5.772381968628057, 6.7198592877461065, 7.685640291533637, 8.616120829964103, 9.661958496046017, 10.669775276345668, 11.648484934849726, 12.607930248215725, 11.608927642289409, 10.701860883854607, 9.767393799197063, 9.801093450082803, 8.810425867184046, 7.862815168278912, 6.851135651153427, 5.906436930729692, 4.95748171117831, 4.032383299257834, 4.770639956767464, 5.724103128930317, 6.691305598472858, 7.750907807709876, 8.706586276956864, 9.54821516582609, 10.614296974484004, 11.59857204887614, 12.540665564172492, 13.486006871285824, 12.5541491910073, 11.641580048900382, 10.775739103928991, 10.72969350618696, 9.794554569492611, 8.815769555395859, 7.918290648533771, 6.9378247640965895, 5.9395247738779515, 5.0370175544533415, 5.839320188008048, 6.79907643861861, 7.654367648822211, 8.650013653964617, 9.657753765833766, 10.490879804813481, 11.55460818595516, 12.50821690894494, 13.445956314263723, 14.450604839351245, 13.556373242802628, 12.682951212129481, 11.73629131600969, 11.71171876137251, 10.768744809998623, 9.850888790574201, 8.887490656028497, 7.9475071311692265, 6.951320874224207, 5.9702311023720975, 6.782492554533169, 7.752294246446469, 8.624470080846343, 9.577787673114097, 10.560636742897547, 11.504216029343185, 12.437768874112747, 13.496918904106593, 14.431887692448083, 15.505859917981324, 14.508067484465869, 13.63087363549411, 12.782860741462603, 12.678350186568945, 11.822125914970673, 10.8411530529079, 9.833366606435858, 8.891468126662623, 7.853692931850206, 6.908048306086336, 7.70876183563189, 8.731453995741184, 9.647303755505229, 10.52709413107871, 11.58308836521095, 12.514236363317213, 13.014676667395403, 13.919808310993815, 14.705415071484165, 15.655143297320071, 15.578681937972927, 14.660643572838376, 13.703238393136893, 13.632923280920405, 12.791621301787167, 11.778479618697629, 10.818796845402474, 9.88552458445406, 8.897970680726857, 7.928560554819741, 8.688950817743043, 9.752957856145505, 10.6382242562208, 11.502477654604894, 12.492227459149992, 12.834899066170657, 12.033000610003159, 12.903724980381115, 13.73264123228499, 14.656897822559419, 15.543265923935305, 15.685597496657977, 14.635700604717147, 14.640124071079121, 13.643560251067695, 12.713946428348017, 11.75009415960442, 10.90530669215561, 9.91057069787939, 8.936916844190376, 9.758655258868334, 10.760771790988418, 11.691705903575674, 12.510530613606125, 12.860822474213844, 11.859970455502411, 11.033874010273282, 11.87482032051636, 12.7891426923116, 13.605177097032845, 14.572941545644047, 15.537927612260273, 15.614296543873268, 15.567813076122347, 14.606583326561733, 13.653403371619635, 12.723017542823202, 11.840502375592667, 10.871733339418599, 9.986490480965756, 10.770629259047604, 11.713471253936184, 12.690600053518244, 12.570138513535737, 11.81318948763554, 10.86689973161015, 9.991711532188335, 10.936022324119163, 11.85161590295174, 12.639037905525011, 13.584491432776176, 14.540259847602087, 15.482953438531933, 15.452032749007332, 15.576154596162674, 14.580606304930742, 13.685716629639915, 12.777942399600606, 11.907184319231217, 11.059866959760102, 11.780192681788682, 12.646456858277391, 12.575669794004657, 11.598299744987045, 10.86358854009951, 9.907898056866811, 8.961441324898319, 9.98416993628215, 10.871034802036059, 11.659351658443361, 12.601841074468533, 13.5710042341465, 14.510251487267475, 14.426684261749523, 15.494386553438131, 15.602497454997122, 14.611486608604762, 13.818388445700249, 12.937491749089185, 12.109120708601274, 12.74252184026921, 12.512620336905133, 11.568163583250673, 10.642813463016957, 9.841125963213926, 8.977207451619137, 7.9666659591663755, 8.969123231260976, 9.933439387147024, 10.635994769671623, 11.676270887559689, 12.61824892013384, 13.46098645670574, 13.498483095230153, 14.527985629672367, 15.566307565244855, 15.569419416004239, 14.878268305096487, 13.887033283677832, 13.067901639869062, 12.512944636200725, 11.558523435284451, 10.658135522977275, 9.705161224005195, 8.837339050312291, 7.968691178933819, 6.935472955635282, 7.935972911462508, 8.9417175100204, 9.672970879832613, 10.657467187703618, 11.603939449958503, 12.529425226938956, 12.59183702205723, 13.538710307455366, 14.524742081457289, 15.419078281402717, 14.354514168984291, 13.470173334442215, 12.51387214657267, 11.640370604614654, 10.61471277207367, 9.626669962290523, 8.695511594488638, 7.7658857939887005, 6.927993278241287, 5.987544921584093, 6.91222701720311, 7.892538990300597, 8.712778148523395, 9.677450786279381, 10.638254237222322, 11.63809460455382, 11.71271290991825, 12.78612331705881, 13.74729934978809, 14.418541422721077, 13.42057790393265, 12.571446645745915, 11.56132916265324, 10.607320489074553, 9.621176099099232, 8.660761295281366, 7.723429716575025, 6.829791927074748, 5.934462571750726, 4.929520902411328, 5.919486979150722, 6.957010126548709, 7.750536194936155, 8.782748665313612, 9.816243655756114, 10.748523542029531, 10.744704027876509, 11.76771936734243, 12.772444577917058, 13.485849710553879, 12.452986430530764, 11.501956474486805, 10.553702574651465, 9.584604555047076, 8.625693005888206, 7.801714799134375, 6.778846567698018, 5.866336304061937, 4.906054232477186, 3.9142641049220255, 4.894255370963154, 5.953333252563772, 6.783891459978854, 7.7863050683455, 8.747066841210659, 9.72516679417974], [9.749617234993128, 8.799972721873578, 7.806630386329589, 6.846838232788017, 5.938996469683026, 4.934298154594176, 3.920016251672338, 3.106541407475643, 3.8898454651587118, 4.781164886515295, 5.768730723452545, 6.615032346636144, 7.578975019276538, 8.568967917918641, 9.525567448773218, 10.49660327602988, 11.53510421044048, 12.54729616958932, 11.708831942325713, 10.75780372603991, 8.888519316043146, 7.943435221689886, 6.964978014896705, 5.906440153800074, 4.971286749074774, 3.994073536123972, 2.9801230475944007, 2.106173140132503, 2.9129262247304273, 3.7890111836000466, 4.7431164416088265, 5.67274945101009, 6.711473468982816, 7.692749945347568, 8.731271382042202, 9.737641263379713, 10.700601634524945, 11.74558312758245, 10.776035810803046, 9.829109422247026, 7.996101592872694, 6.955394978499138, 6.02033405331905, 5.022468696461157, 4.004204707648678, 3.0057350896246673, 1.956521376106651, 1.0569506625590244, 1.9375019145705221, 2.855835609055144, 3.896580749830259, 4.875989155950649, 5.932363341300241, 6.880947337372948, 7.853947227239715, 8.910219207812434, 9.968102992879894, 11.007541472285247, 10.043526597568812, 8.980108231448831, 7.032394056357967, 5.993985903659991, 5.009769236840943, 4.05995807246887, 3.0514607856416447, 1.9827043026295512, 0.9990847995197745, 0.0, 0.9561721912935686, 1.9022692581975513, 2.948143269079447, 4.001827492983944, 4.965458541647336, 6.0105671104328495, 7.058681231402976, 8.132854437743674, 9.202345906673468, 10.032322405568062, 9.034786076352729, 8.097278236617537, 7.8995067180525735, 6.867822518758578, 5.899979944704251, 4.860297243824947, 3.8960903773616686, 2.962442448653116, 1.973390803378095, 1.0306548897552745, 1.9778166422358496, 2.936263596502795, 3.889370747280534, 4.866189215342264, 5.859157269719929, 6.8839816968709115, 7.947390582046197, 8.904220937993735, 9.971918669566985, 10.755235379899462, 9.77799847536115, 8.837407322080763, 8.822538020307482, 7.867332018810751, 6.887235815667308, 5.859310614168633, 4.833641819191214, 3.896034759476018, 2.9892186774741516, 1.955903530540522, 2.9288163909760763, 3.913930920924793, 4.848520909782588, 5.874966987604517, 6.860516903760368, 7.831928104474525, 8.898258115889139, 9.86284236683096, 10.837616309626465, 11.649122398382561, 10.712557187885158, 9.7531661310184, 9.815740108430845, 8.881072557682922, 7.865553381408078, 6.801857173340621, 5.8255849214865485, 4.946833655076017, 3.9172987978887894, 2.9019974772568324, 3.8601535416315205, 4.849710947886237, 5.7971882670042865, 6.7629692707918165, 7.693449809222282, 8.739287475304195, 9.747104255603846, 10.725813914107905, 11.685259227473903, 12.583742262029123, 11.676675503594321, 10.742208418936775, 10.765177892922475, 9.774510310023718, 8.826899611118584, 7.8152200939931005, 6.794463053465123, 5.8267237647381505, 4.840063706170871, 3.848506259696933, 4.801969431859785, 5.769171901402326, 6.828774110639344, 7.784452579886332, 8.625544145084268, 9.691625953742182, 10.675901028134318, 11.61799454343067, 12.56531913332933, 13.497176813607854, 12.616394668640096, 11.750553723668704, 11.693777949026632, 10.758639012332283, 9.77985399823553, 8.852592074862356, 7.825850886832021, 6.808766827437792, 5.8446979613663785, 4.9171864909375165, 5.876942741548079, 6.732233951751679, 7.7278799568940855, 8.735620068763234, 9.568208784071661, 10.63193716521334, 11.58554588820312, 12.523285293521903, 13.527933818609425, 14.471364558753468, 13.657765831869195, 12.711105935749401, 12.675803204212182, 11.732829252838295, 10.814973233413873, 9.8001402708851, 8.816749184729067, 7.820562927784048, 6.7779115092851345, 5.8603588574626375, 6.830160549375937, 7.702336383775812, 8.655653976043565, 9.638503045827015, 10.581545008601365, 11.515097853370927, 12.574247883364773, 13.509216671706263, 14.583188897239504, 15.423058800416708, 14.605688255233824, 13.746945184302275, 13.608420600577512, 12.658258851194507, 11.677285989131734, 10.669499542659691, 9.727601062886457, 8.661373338763244, 7.715728712999374, 6.786628138561358, 7.809320298670652, 8.725170058434697, 9.604960434008179, 10.660954668140418, 11.592102666246682, 12.539072052022066, 13.464272495425531, 14.445110440134137, 15.500764779345573, 16.439247247328407, 15.63375819275636, 14.63330880714546, 14.562993694928972, 13.627754238011, 12.586160025610669, 11.626477252315514, 10.6932049913671, 9.705651087639897, 8.73624096173278, 7.766817120672511, 8.830824159074972, 9.716090559150269, 10.580343957534362, 11.57009376207946, 12.075597052306268, 13.032085409522933, 13.902809779900888, 14.731726031804765, 15.655982622079193, 16.54235072345508, 16.61574990273411, 15.565771018725714, 15.464166092302474, 14.451240657980735, 13.521626835261056, 12.557774566517459, 11.712987099068648, 10.718251104792428, 9.744597251103414, 8.8365215617978, 9.838638093917885, 10.769572206505142, 11.588396916535594, 11.895696174319438, 11.100668441638023, 12.032958809793056, 12.873905120036133, 13.788227491831375, 14.60426189655262, 15.572026345163822, 16.537012411780047, 16.43833856509662, 16.375493483035385, 15.414263733474773, 14.461083778532675, 13.530697949736242, 12.648182782505705, 11.679413746331637, 10.794170887878796, 9.84849556197707, 10.791337556865653, 11.768466356447712, 11.571053714015962, 10.848063187741134, 10.107597717745762, 10.99079633170811, 11.935107123638936, 12.850700702471515, 13.638122705044786, 14.58357623229595, 15.539344647121862, 16.482038238051707, 16.451117548527108, 16.383835003075713, 15.388286711843781, 14.493397036552954, 13.585622806513644, 12.714864726144256, 11.867547366673142, 10.858058984718149, 11.72432316120686, 11.576584994484882, 10.59921494546727, 9.898462240205104, 9.148596043002422, 9.960526124418093, 10.983254735801923, 11.870119601555833, 12.658436457963136, 13.600925873988308, 14.570089033666275, 15.50933628678725, 15.425769061269298, 16.493471352957904, 16.410177861910164, 15.419167015517802, 14.626068852613287, 13.745172156002225, 12.80300951262037, 11.820388143198677, 11.513535537385359, 10.569078783730898, 9.643728663497182, 8.851041201682575, 8.217905437754748, 8.96575075868615, 9.96820803078075, 10.932524186666798, 11.635079569191397, 12.675355687079463, 13.617333719653615, 14.460071256225515, 14.497567894749928, 15.527070429192142, 16.335964509773127, 15.352177580241959, 14.37920640711013, 13.475568060839318, 12.495873784115867, 11.51385983668095, 10.559438635764677, 9.6590507234575, 8.70607642448542, 7.84725428878094, 7.179991857897769, 7.934557755155057, 8.935057710982282, 9.940802309540175, 10.672055679352388, 11.656551987223393, 12.603024249478278, 13.528510026458731, 13.590921821577005, 14.53779510697514, 15.335684948042438, 14.419993481882942, 13.355429369464519, 12.47108853492244, 11.514787347052895, 10.64128580509488, 9.615627972553895, 8.627585162770748, 7.696426794968863, 6.775801032457349, 6.131403233044758, 6.986629721103868, 7.911311816722884, 8.891623789820372, 9.71186294804317, 10.676535585799156, 11.637339036742096, 12.637179404073594, 12.711797709438025, 13.785208116578584, 14.356371803184754, 13.419456623201302, 12.421493104412876, 11.572361846226142, 10.562244363133468, 9.608235689554778, 8.622091299579457, 7.6616764957615935, 6.724344917055252, 5.8397071655433965, 5.136570242835274, 5.928605701931103, 6.918571778670497, 7.9560949260684835, 8.74962099445593, 9.781833464833387, 10.815328455275889, 11.747608341549306, 11.743788827396283, 12.766804166862205, 13.47896048285174, 12.486764911034104, 11.453901631010991, 10.502871674967032, 9.554617775131693, 8.5855197555273, 7.626608206368431, 6.8026299996146005, 5.779761768178244, 4.876251542530586, 4.108161903561735, 4.9133489044418, 5.8933401704829285, 6.952418052083547, 7.7829762594986285, 8.785389867865275, 9.746151640730433, 10.724251593699515], [10.69529635914124, 9.74565184602169, 8.752309510477701, 7.79251735693613, 6.837600193712636, 5.832901878623786, 4.818619975701948, 3.9438693074124593, 2.933673273865143, 3.8249926952217264, 4.812558532158976, 5.658860155342575, 6.622802827982969, 7.612795726625072, 8.56939525747965, 9.540431084736312, 10.578932019146912, 11.591123978295752, 12.639671218907624, 11.70348285018802, 9.834198440191258, 8.889114345838, 7.910657139044817, 6.852119277948186, 5.916965873222886, 4.9397526602720845, 3.878726771624011, 2.9435010400693193, 1.9567540334368587, 2.8328389923064776, 3.7869442503152575, 4.716577259716521, 5.755301277689247, 6.736577754053999, 7.775099190748632, 8.781469072086143, 9.744429443231375, 10.789410936288881, 11.721714934951159, 10.774788546395138, 8.952273784166263, 7.911567169792706, 6.976506244612618, 5.978640887754725, 4.960376898942246, 3.9619072809182354, 2.9126935674002192, 1.9511560389155251, 0.9813297232769537, 1.899663417761575, 2.94040855853669, 3.91981696465708, 4.976191150006672, 5.924775146079379, 6.897775035946147, 7.9540470165188655, 9.011930801586326, 10.062362730061166, 10.99969878886238, 9.9362804227424, 7.988566247651535, 6.950158094953559, 5.965941428134511, 5.016130263762438, 4.007632976935213, 2.93887649392312, 1.955256990813343, 0.9561721912935686, 0.0, 0.9460970669039827, 1.9919710777858786, 3.045655301690375, 4.009286350353767, 5.0543949191392805, 6.102509040109407, 7.176682246450105, 8.2461737153799, 9.18430333736945, 9.990958267646297, 9.053450427911105, 8.855678909346143, 7.823994710052147, 6.85615213599782, 5.816469435118516, 4.852262568655238, 3.918614639946685, 2.9295629946716635, 1.986827081048843, 1.021644450942281, 1.9800914052092264, 2.9331985559869653, 3.9100170240486958, 4.902985078426361, 5.927809505577343, 6.991218390752629, 7.948048746700166, 9.015746478273417, 10.04273233256385, 10.734170666654718, 9.79357951337433, 9.77871021160105, 8.82350421010432, 7.843408006960878, 6.815482805462202, 5.789814010484783, 4.852206950769586, 3.9453908687677206, 2.9120757218340905, 2.031863119844389, 2.957758729631225, 3.8923487184890195, 4.918794796310949, 5.9043447124668, 6.8757559131809565, 7.942085924595571, 8.906670175537393, 9.881444118332897, 10.90734913848237, 11.668729379178727, 10.709338322311968, 10.771912299724413, 9.83724474897649, 8.821725572701647, 7.75802936463419, 6.7817571127801175, 5.903005846369586, 4.873470989182358, 3.858169668550401, 3.014714151898085, 3.893538756592669, 4.841016075710718, 5.806797079498248, 6.737277617928714, 7.783115284010627, 8.790932064310278, 9.769641722814336, 10.729087036180335, 11.802551362440823, 12.63284769488789, 11.698380610230343, 11.721350084216043, 10.730682501317286, 9.783071802412152, 8.771392285286668, 7.7506352447586915, 6.782895956031719, 5.796235897464439, 4.804678450990501, 3.9565300421263494, 4.910186402439732, 5.878734617832935, 6.8344130870799225, 7.6693719537907, 8.735453762448614, 9.71972883684075, 10.661822352137102, 11.609146942035762, 12.541004622314286, 13.566260142322653, 12.706725914962272, 12.6499501403202, 11.714811203625851, 10.736026189529099, 9.808764266155924, 8.78202307812559, 7.7649390187313605, 6.800870152659947, 5.873358682231085, 5.031503351814643, 5.873248452789085, 6.868894457931491, 7.785580575956825, 8.612036592778093, 9.675764973919772, 10.629373696909552, 11.567113102228335, 12.571761627315857, 13.5151923674599, 14.552161304831841, 13.66727812704297, 13.63197539550575, 12.689001444131863, 11.771145424707441, 10.756312462178668, 9.772921376022635, 8.776735119077616, 7.734083700578703, 6.816531048756206, 5.985316319514967, 6.843350884813217, 7.796668477080971, 8.77951754686442, 9.625372817307797, 10.558925662077359, 11.618075692071205, 12.553044480412694, 13.627016705945936, 14.46688660912314, 15.421803526266263, 14.703117375595843, 14.56459279187108, 13.614431042488075, 12.633458180425302, 11.62567173395326, 10.683773254180025, 9.617545530056812, 8.671900904292942, 7.742800329854926, 6.964476068809682, 7.866184559472103, 8.745974935045584, 9.801969169177823, 10.653329433008464, 11.600298818783848, 12.525499262187314, 13.50633720689592, 14.561991546107356, 15.500474014090189, 16.45157346361053, 15.589480998439027, 15.51916588622254, 14.583926429304569, 13.542332216904237, 12.582649443609082, 11.649377182660668, 10.661823278933465, 9.692413153026347, 8.72298931196608, 8.007187120449853, 8.857105060187674, 9.721358458571768, 10.711108263116866, 11.607732791034792, 12.581974876176092, 13.541582592800014, 14.479111046095094, 15.437409506969713, 16.421956919203527, 17.44553769060754, 16.521943210019284, 16.420338283596042, 15.407412849274303, 14.477799026554624, 13.513946757811027, 12.669159290362217, 11.674423296085996, 10.700769442396982, 9.79269375309137, 9.015001055292766, 9.910586707542548, 10.729411417573, 10.93952398302587, 11.717463267219639, 12.729380238359965, 13.588973730151638, 14.527720199096969, 15.473833176108464, 16.444079759455217, 17.40906582607144, 17.394510756390186, 17.331665674328953, 16.37043592476834, 15.417255969826243, 14.48687014102981, 13.604354973799273, 12.635585937625205, 11.750343079172364, 10.80466775327064, 9.967700518240534, 10.944829317822593, 10.614881522722392, 9.891890996447566, 10.724392543327378, 11.687217760275018, 12.650175733754441, 13.59019340973711, 14.5838018291929, 15.529255356444063, 16.485023771269972, 17.427717362199818, 17.39679667267522, 17.340007194369278, 16.344458903137348, 15.449569227846522, 14.541794997807212, 13.671036917437824, 12.82371955796671, 11.814231176011718, 10.90068612258174, 10.620412803191313, 9.6430427541737, 8.942290048911536, 9.765390868584038, 10.662542818597794, 11.698323345917428, 12.636015229388857, 13.604115582111248, 14.54660499813642, 15.515768157814385, 16.45501541093536, 16.37144818541741, 17.32701161337128, 16.344949042740225, 15.353938196347867, 14.443042985664798, 13.468937404134397, 12.498482524090086, 11.524786026490712, 10.557363346091789, 9.612906592437328, 8.687556472203612, 7.894869010389007, 8.834700263336364, 9.667767452865851, 10.683276640896255, 11.698419814499822, 12.58075869333951, 13.621034811227576, 14.563012843801728, 15.405750380373627, 15.44324701889804, 16.40221661146139, 15.379792318479561, 14.39600538894839, 13.423034215816562, 12.51939586954575, 11.539701592822299, 10.557687645387382, 9.603266444471108, 8.702878532163933, 7.749904233191851, 6.891082097487372, 7.796786683479386, 8.636574449334757, 9.650126321097787, 10.706697937373198, 11.6177348035005, 12.602231111371506, 13.54870337362639, 14.474189150606843, 14.536600945725118, 15.355553763574159, 14.37951275674887, 13.463821290589374, 12.39925717817095, 11.514916343628872, 10.558615155759327, 9.685113613801311, 8.659455781260327, 7.67141297147718, 6.740254603675294, 5.819628841163781, 6.748198058626375, 7.688646415283569, 8.69501940244994, 9.689980200973103, 10.657542072191282, 11.622214709947269, 12.583018160890209, 13.582858528221706, 13.657476833586138, 14.361375644620466, 13.400199611891185, 12.463284431907734, 11.465320913119308, 10.616189654932574, 9.6060721718399, 8.652063498261208, 7.6659191082858875, 6.7055043044680245, 5.768172725761683, 4.883534974249828, 5.925953350400327, 6.827209425960712, 7.817175502700106, 8.854698650098094, 9.695300118604042, 10.727512588981499, 11.761007579424001, 12.693287465697418, 12.689467951544398, 13.57276125111939, 12.522788291558172, 11.530592719740536, 10.497729439717423, 9.546699483673464, 8.598445583838124, 7.629347564233731, 6.670436015074862, 5.846457808321032, 4.823589576884675, 3.9200793512370167, 4.945489803498551, 5.81195262847141, 6.7919438945125385, 7.851021776113157, 8.72865538364674, 9.731068992013387, 10.691830764878546, 11.669930717847627], [11.620361933279947, 10.670717420160397, 9.677375084616408, 8.717582931074837, 7.7626657678513435, 6.757967452762493, 5.743685549840655, 4.868934881551166, 3.85873884800385, 2.8788956283177436, 3.866461465254993, 4.712763088438592, 5.676705761078987, 6.6666986597210895, 7.623298190575667, 8.59433401783233, 9.63283495224293, 10.64502691139177, 11.693574152003643, 12.628548424326727, 10.759264014329965, 9.814179919976706, 8.835722713183523, 7.777184852086893, 6.842031447361593, 5.864818234410791, 4.803792345762718, 3.868566614208026, 2.8818196075755655, 1.8867419254024949, 2.8408471834112747, 3.770480192812539, 4.809204210785264, 5.7904806871500165, 6.829002123844649, 7.835372005182161, 8.798332376327394, 9.8433138693849, 10.829933186425002, 11.699854120533844, 9.898370851070245, 8.857664236696689, 7.922603311516601, 6.924737954658708, 5.906473965846229, 4.908004347822218, 3.858790634304202, 2.8762216130542315, 1.9063952974156604, 0.9535663508575924, 1.9943114916327074, 2.9737198977530976, 4.030094083102689, 4.978678079175396, 5.951677969042164, 7.007949949614883, 8.065833734682343, 9.116265663157183, 10.080280537873618, 10.882377489646382, 8.934663314555518, 7.896255161857542, 6.912038495038494, 5.962227330666421, 4.953730043839196, 3.8849735608271025, 2.9013540577173256, 1.9022692581975513, 0.9460970669039827, 0.0, 1.0458740108818958, 2.099558234786392, 3.063189283449784, 4.108297852235298, 5.156411973205424, 6.2305851795461225, 7.300076648475916, 8.238206270465467, 9.2357425996808, 9.999547494815088, 9.801775976250124, 8.770091776956129, 7.802249202901803, 6.762566502022499, 5.798359635559221, 4.864711706850668, 3.8756600615756462, 2.932924147952826, 1.9677415178462638, 1.033994338305244, 1.9871014890829826, 2.963919957144713, 3.956888011522378, 4.981712438673361, 6.0451213238486465, 7.001951679796183, 8.069649411369435, 9.096635265659867, 10.073872170198179, 10.739676580278312, 10.724807278505033, 9.769601277008302, 8.789505073864861, 7.761579872366185, 6.735911077388765, 5.798304017673569, 4.891487935671703, 3.8581727887380732, 2.977960186748372, 2.011661662727242, 2.9462516515850368, 3.972697729406966, 4.9582476455628175, 5.929658846276974, 6.9959888576915885, 7.960573108633409, 8.935347051428915, 9.961252071578388, 10.89781728207579, 11.65543538921595, 11.718009366628396, 10.783341815880473, 9.76782263960563, 8.704126431538173, 7.7278541796841, 6.849102913273569, 5.819568056086341, 4.804266735454384, 3.9608112188020677, 2.947441689688686, 3.894919008806736, 4.8607000125942665, 5.791180551024732, 6.837018217106646, 7.844834997406297, 8.823544655910355, 9.782989969276354, 10.856454295536842, 11.821914929970436, 12.644477677134326, 12.667447151120026, 11.676779568221269, 10.729168869316135, 9.71748935219065, 8.696732311662673, 7.728993022935701, 6.742332964368422, 5.750775517894484, 4.902627109030332, 3.964089335535749, 4.932637550928952, 5.88831602017594, 6.723274886886718, 7.789356695544631, 8.773631769936767, 9.71572528523312, 10.66304987513178, 11.594907555410304, 12.62016307541867, 13.611419387162119, 13.596047207224183, 12.660908270529834, 11.682123256433082, 10.754861333059905, 9.728120145029571, 8.711036085635344, 7.746967219563929, 6.819455749135067, 5.891854382672688, 4.927151385885102, 5.922797391027508, 6.839483509052842, 7.66593952587411, 8.72966790701579, 9.683276630005569, 10.621016035324352, 11.625664560411874, 12.569095300555919, 13.60606423792786, 14.571971599242817, 14.578072462409732, 13.635098511035846, 12.717242491611424, 11.702409529082653, 10.71901844292662, 9.7228321859816, 8.680180767482685, 7.762628115660188, 6.832649330153169, 5.897253817909235, 6.850571410176988, 7.833420479960438, 8.679275750403814, 9.612828595173376, 10.671978625167222, 11.606947413508712, 12.680919639041953, 13.520789542219159, 14.475706459362282, 15.463625701118236, 15.510689858775063, 14.560528109392058, 13.579555247329285, 12.571768800857242, 11.629870321084008, 10.563642596960795, 9.617997971196925, 8.68889739675891, 7.811809079447884, 6.92008749256812, 7.7998778681416026, 8.855872102273842, 9.707232366104481, 10.654201751879866, 11.57940219528333, 12.560240139991937, 13.615894479203373, 14.554376947186206, 15.505476396706548, 16.475273916510055, 16.465262953126523, 15.530023496208551, 14.488429283808218, 13.528746510513063, 12.59547424956465, 11.607920345837446, 10.63851021993033, 9.669086378870063, 8.854520131088055, 7.911007993283691, 8.775261391667787, 9.765011196212885, 10.661635724130809, 11.63587780927211, 12.59548552589603, 13.53301397919111, 14.49131244006573, 15.475859852299545, 16.499440623703556, 17.40773612809031, 17.366435350500023, 16.353509916178282, 15.423896093458605, 14.460043824715008, 13.6152563572662, 12.620520362989978, 11.646866509300965, 10.738790819995353, 9.862334065930968, 8.964489640638565, 9.78331435066902, 10.781605960821777, 11.636564334799054, 12.635004409001986, 13.624390185760786, 14.476512519164501, 15.422625496175996, 16.39287207952275, 17.357858146138973, 18.340607823294167, 18.277762741232934, 17.31653299167232, 16.363353036730224, 15.43296720793379, 14.550452040703256, 13.581683004529188, 12.696440146076345, 11.750764820174624, 10.815033528878736, 10.035299272573846, 9.66878445581841, 10.645822029398753, 11.593223454376114, 12.556048671323754, 13.540042341145854, 14.480060017128523, 15.508867403331607, 16.45432093058277, 17.410089345408682, 18.352782936338528, 18.248984422952876, 17.29095104241295, 16.29540275118102, 15.333611108408734, 14.537391964860458, 13.553147767088383, 12.58537273001496, 11.541018118067258, 10.636568969586483, 9.67431573628733, 8.696945687269718, 9.696221081862722, 10.641117476549061, 11.57691023726632, 12.612690764585954, 13.550382648057383, 14.529181156249956, 15.471670572275128, 16.440833731953095, 17.38008098507407, 17.265549058682847, 16.380914546467302, 15.398851975836246, 14.407841129443886, 13.496945918760815, 12.522840337230415, 11.552385457186103, 10.57868895958673, 9.611266279187806, 8.666809525533345, 7.741459405299629, 8.677667275439413, 9.710426871301387, 10.582134871534377, 11.59764405956478, 12.612787233168348, 13.505824267478218, 14.546100385366284, 15.488078417940436, 16.330815954512335, 16.334794251163963, 15.45611954455741, 14.43369525157558, 13.44990832204441, 12.47693714891258, 11.573298802641768, 10.593604525918316, 9.6115905784834, 8.657169377567126, 7.756781465259949, 6.803807166287868, 7.8054495161559, 8.711154102147914, 9.550941868003283, 10.564493739766313, 11.621065356041724, 12.542800377639209, 13.527296685510214, 14.473768947765098, 15.399254724745552, 15.356329982068313, 14.409456696670178, 13.433415689844889, 12.517724223685393, 11.453160111266968, 10.568819276724891, 9.612518088855346, 8.739016546897329, 7.713358714356344, 6.725315904573197, 5.794157536771311, 6.733996259832309, 7.662565477294903, 8.603013833952096, 9.609386821118466, 10.60434761964163, 11.58260764632999, 12.547280284085977, 13.508083735028917, 14.507924102360414, 14.488688984857044, 13.415278577716485, 12.454102544987204, 11.517187365003753, 10.519223846215326, 9.670092588028592, 8.659975104935917, 7.705966431357225, 6.719822041381905, 5.759407237564042, 4.8220756588577, 5.797902392918356, 6.840320769068855, 7.75227500009942, 8.742241076838814, 9.779764224236802, 10.62036569274275, 11.652578163120207, 12.686073153562708, 13.618353039836125, 13.614533525683104, 12.626664184215409, 11.57669122465419, 10.584495652836555, 9.55163237281344, 8.600602416769481, 7.652348516934141, 6.683250497329748, 5.724338948170879, 4.90036074141705, 3.8774925099806925, 4.8344467699055444, 5.870555377637257, 6.737018202610117, 7.717009468651246, 8.776087350251865, 9.653720957785449, 10.656134566152096, 11.616896339017252, 12.594996291986334], [12.666235944161842, 11.716591431042293, 10.723249095498304, 9.763456941956733, 8.80853977873324, 7.803841463644389, 6.789559560722551, 5.9148088924330615, 4.904612858885746, 3.9247696391996394, 3.0800758532548365, 3.913855487317397, 4.877798159957791, 5.867791058599894, 6.824390589454472, 7.795426416711134, 8.833927351121734, 9.846119310270574, 10.858762109510524, 11.80158667033676, 11.805138025211862, 10.860053930858603, 9.881596724065421, 8.82305886296879, 7.887905458243488, 6.910692245292687, 5.849666356644613, 4.914440625089922, 3.9276936184574613, 2.9326159362843907, 2.041939582290079, 2.971572591691343, 4.005779987877827, 4.954922315770168, 5.9250349154075055, 6.931404796745017, 7.89436516789025, 8.939346660947756, 9.925965977987858, 10.872892366543878, 10.944244861952141, 9.903538247578584, 8.968477322398497, 7.970611965540604, 6.952347976728125, 5.953878358704114, 4.904664645186098, 3.9220956239361273, 2.952269308297556, 1.9994403617394882, 1.066763729537763, 2.046172135658153, 2.984220072220794, 3.9328040682935015, 4.905803958160268, 5.962075938732987, 7.019959723800447, 8.070391652275287, 9.034406526991722, 10.097824893111703, 9.980537325437416, 8.942129172739438, 7.9579125059203895, 7.008101341548317, 5.999604054721091, 4.930847571708998, 3.9472280685992214, 2.948143269079447, 1.9919710777858786, 1.0458740108818958, 0.0, 1.0536842239044966, 2.0173152725678882, 3.062423841353402, 4.110537962323528, 5.184711168664227, 6.2542026375940205, 7.192332259583571, 8.189868588798904, 9.127376428534095, 10.84764998713202, 9.815965787838024, 8.848123213783698, 7.808440512904394, 6.844233646441116, 5.9105857177325625, 4.921534072457542, 3.9787981588347217, 3.0136155287281596, 2.0085695243992303, 0.9412274782010868, 1.9180459462628172, 2.911014000640482, 3.935838427791465, 4.999247312966751, 5.956077668914287, 7.023775400487539, 8.05076125477797, 9.027998159316283, 9.96858931259667, 11.770681289386928, 10.815475287890198, 9.835379084746755, 8.80745388324808, 7.781785088270661, 6.844178028555465, 5.926239236139816, 4.892924089206186, 3.9200112287706315, 2.934359375150626, 1.9997693862928314, 2.9400895223157457, 3.9123736346809213, 4.883784835395077, 5.950114846809692, 6.914699097751513, 7.889473040547018, 8.91537806069649, 9.851943271193893, 10.903392916468455, 12.752766827126495, 11.829215826762368, 10.813696650487524, 9.750000442420067, 8.773728190565995, 7.894976924155465, 6.854319356554454, 5.839018035922497, 4.883828278363554, 3.87013940211207, 2.9484367435145304, 3.9142177473020605, 4.844698285732527, 5.877527670709869, 6.885344451009519, 7.864054109513577, 8.822307070064264, 9.849997924343052, 10.815458558776644, 11.820812495170461, 13.702198451588142, 12.711530868689385, 11.763920169784251, 10.752240652658767, 9.73148361213079, 8.763744323403817, 7.777084264836536, 6.785526818362598, 5.825644168591818, 4.886787047959133, 3.9861552856367464, 4.941833754883734, 5.776792621594512, 6.842874430252426, 7.827149504644561, 8.769243019940914, 9.716567609839574, 10.648425290118098, 11.673680810126465, 12.664937121869913, 14.6307985076923, 13.69565957099795, 12.716874556901198, 11.789612633528021, 10.762871445497687, 9.745787386103459, 8.781718520032044, 7.840224427463913, 6.814552095096071, 5.849849098308486, 5.038095784109496, 5.8930012437606365, 6.719457260581905, 7.783185641723584, 8.736794364713363, 9.674533770032147, 10.679182295119668, 11.622613035263711, 12.659581972635653, 13.625489333950611, 15.588285415916122, 14.669849811503962, 13.75199379207954, 12.714717321945042, 11.731326235789009, 10.73513997884399, 9.660554942716697, 8.725148734489851, 7.7553470425765525, 6.819951530332618, 6.017713413343546, 6.89441722651661, 7.732793485111609, 8.66634632988117, 9.725496359875017, 10.660465148216506, 11.734437373749747, 12.574307276926952, 13.529224194070075, 14.517143435826029, 16.491064034009074, 15.54090228462607, 14.559929422563297, 13.552142976091254, 12.61024449631802, 11.544016772194807, 10.598372146430936, 9.651418015588572, 8.734506791871269, 7.842785204991504, 6.96701987130816, 7.924778884611882, 8.760750100812276, 9.70771948658766, 10.632919929991125, 11.613757874699731, 12.669412213911167, 13.607894681894, 14.558994131414341, 15.528791651217848, 17.445637128360534, 16.51039767144256, 15.46880345904223, 14.509120685747074, 13.57584842479866, 12.588294521071457, 11.618884395164342, 10.631606997699725, 9.77721784351144, 8.833705705707075, 7.9424033948343435, 8.932153199379442, 9.715153458838603, 10.689395543979904, 11.649003260603825, 12.586531713898905, 13.544830174773525, 14.529377587007339, 15.55295835841135, 16.461253862798102, 18.346809525734034, 17.333884091412294, 16.404270268692617, 15.44041799994902, 14.595630532500211, 13.60089453822399, 12.627240684534977, 11.701311438825016, 10.785031778354353, 9.887187353061949, 8.950456353835577, 9.948747963988334, 10.690082069506849, 11.68852214370978, 12.67790792046858, 13.530030253872296, 14.47614323088379, 15.446389814230546, 16.41137588084677, 17.44754235421064, 18.39592608937895, 17.460864421885326, 16.423698083370926, 15.49740259410425, 14.685619048617259, 13.799385806649862, 12.795046476775376, 11.802063768406157, 10.82103680152551, 10.200391831163515, 9.992655136380579, 10.996380950566637, 11.68315279339911, 12.64597801034675, 13.616705916865778, 14.467557043232155, 15.442282422391624, 16.434839927098416, 17.419076661300394, 18.36177025223024, 17.45007682183168, 16.492043441291752, 15.496495150059822, 14.534703507287537, 13.74817902460932, 12.763934826837245, 11.812426265776137, 10.79250034566508, 9.888051197184303, 9.265289311542016, 9.742819698151614, 10.742095092744618, 11.686991487430957, 12.622784248148216, 13.65856477546785, 14.596256658939279, 15.575055167131852, 16.517544583157022, 17.48670774283499, 18.425954995955966, 16.46664145756165, 15.582006945346103, 14.599944374715049, 13.608933528322689, 12.707732978509677, 11.733627396979276, 10.763172516934965, 9.83017118718455, 8.862748506785627, 8.257783100788032, 8.787333416181525, 9.723541286321309, 10.756300882183282, 11.628008882416273, 12.643518070446676, 13.658661244050244, 14.551698278360114, 15.59197439624818, 16.53395242882233, 17.37668996539423, 15.535886650042766, 14.657211943436213, 13.634787650454383, 12.651000720923212, 11.678029547791384, 10.78408586239063, 9.804391585667178, 8.834856839516604, 7.88043563860033, 7.258757368134348, 7.849681177169764, 8.851323527037795, 9.75702811302981, 10.59681587888518, 11.610367750648209, 12.66693936692362, 13.588674388521104, 14.57317069639211, 15.519642958646994, 16.445128735627446, 14.557422380947116, 13.610549095548981, 12.634508088723692, 11.718816622564196, 10.654252510145772, 9.769911675603694, 8.813610487734149, 7.962282807930532, 6.936624975389549, 6.227291807447596, 6.840031547653207, 7.779870270714205, 8.708439488176799, 9.648887844833991, 10.655260832000362, 11.650221630523525, 12.628481657211886, 13.593154294967873, 14.553957745910813, 15.511164798450528, 13.689781383735847, 12.616370976595288, 11.655194943866007, 10.718279763882556, 9.72031624509413, 8.871184986907394, 7.861067503814721, 6.907058830236029, 5.9209144402607095, 5.185439193112314, 5.867949669739596, 6.843776403800252, 7.886194779950751, 8.798149010981316, 9.788115087720708, 10.825638235118696, 11.666239703624646, 12.698452174002103, 13.731947164444604, 14.653970751624566, 12.80731751333771, 11.827756583094212, 10.777783623532994, 9.785588051715358, 8.752724771692245, 7.801694815648285, 6.8534409158129455, 5.884342896208553, 4.925431347049684, 4.113975129416893, 4.923366520862588, 5.88032078078744, 6.916429388519153, 7.782892213492013, 8.76288347953314, 9.821961361133761, 10.699594968667345, 11.702008577033991, 12.662770349899148, 13.64087030286823], [11.732197896840699, 12.643615259598185, 11.650272924054196, 10.690480770512625, 9.735563607289132, 8.730865292200281, 7.716583389278443, 6.841832720988954, 5.831636687441638, 4.825755120733053, 3.9176324307737818, 2.892146046033814, 3.856088718674208, 4.846081617316311, 5.798316084315745, 6.769351911572407, 7.807852845983008, 8.820044805131849, 9.805077885606027, 10.747902446432263, 10.75979824884326, 11.70488234319652, 10.808620552621313, 9.750082691524682, 8.814929286799382, 7.837716073848579, 6.776690185200506, 5.8414644536458145, 4.854717447013354, 3.833601417817804, 2.8794961598090243, 1.9498631504077604, 2.9520957639733307, 3.9012380918656713, 4.871350691503009, 5.877720572840521, 6.840680943985753, 7.885662437043258, 8.87228175408336, 9.819208142639381, 10.028147307783344, 10.957222471483082, 10.022161546302994, 9.024296189445101, 8.006032200632623, 7.007562582608611, 5.958348869090595, 4.955172513570586, 3.9853461979320146, 3.0325172513739465, 1.9917721105988315, 1.0123637044784413, 1.930535848316297, 2.8791198443890047, 3.852119734255772, 4.9083917148284915, 5.966275499895952, 7.0167074283707915, 7.9807223030872265, 9.044140669207207, 9.13857638488917, 9.995813396643936, 9.011596729824888, 8.061785565452814, 7.053288278625589, 5.984531795613496, 5.000912292503719, 4.001827492983944, 3.045655301690375, 2.099558234786392, 1.0536842239044966, 0.0, 0.9636310486633917, 2.008739617448905, 3.056853738419032, 4.13102694475973, 5.200518413689524, 6.138648035679075, 7.136184364894407, 8.0736922046296, 9.905999444040837, 10.825351355251318, 9.85750878119699, 8.817826080317687, 7.853619213854408, 6.919971285145855, 5.930919639870834, 4.988183726248014, 4.005752240348735, 2.9742522687476676, 1.9069102225495242, 0.9300917544877938, 1.9230598088654585, 2.935347955207444, 3.99875684038273, 4.955587196330266, 6.023284927903518, 7.05027078219395, 8.027507686732262, 8.96809884001265, 10.833530554595354, 11.788736556092084, 10.844764652160048, 9.816839450661373, 8.791170655683953, 7.853563595968756, 6.891921980488252, 5.858606833554623, 4.885693973119069, 3.9000421194990635, 2.965452130641269, 1.952135330540722, 2.9244194429058976, 3.8958306436200534, 4.962160655034668, 5.914208625167492, 6.888982567962997, 7.91488758811247, 8.851452798609873, 9.902902443884436, 11.752276354542476, 12.727861850724265, 11.823082217900817, 10.75938600983336, 9.783113757979287, 8.892417023961299, 7.82000210090289, 6.804700780270934, 5.849511022711992, 4.835822146460508, 3.914119487862968, 3.0026913449990467, 3.9331718834295124, 4.889573478934845, 5.897390259234496, 6.876099917738554, 7.821816597480243, 8.849507451759031, 9.814968086192625, 10.820322022586442, 12.719482667840618, 13.677213613037821, 12.729602914132688, 11.717923397007203, 10.697166356479226, 9.729427067752253, 8.742767009184973, 7.7512095627110345, 6.7913269129402565, 5.852469792307571, 4.9518380299851845, 4.034494293003438, 4.865266219291498, 5.9313480279494115, 6.867640101771302, 7.809733617067655, 8.757058206966315, 9.688915887244839, 10.714171407253206, 11.705427718996654, 13.648082723944775, 14.644213549317081, 13.682557301249634, 12.755295377876458, 11.728554189846124, 10.711470130451895, 9.747401264380482, 8.805907171812352, 7.7802348394445096, 6.815531842656924, 6.003778528457934, 4.98566178188034, 5.80793085827889, 6.87165923942057, 7.825267962410348, 8.746899708695688, 9.75154823378321, 10.69113993904017, 11.728108876412112, 12.665979931077352, 14.654574768654886, 15.597548720028772, 14.717676536427977, 13.68040006629348, 12.697008980137447, 11.700822723192427, 10.626237687065135, 9.69083147883829, 8.72102978692499, 7.7856342746810565, 6.9699268344197645, 5.987077764636314, 6.821267082808594, 7.754819927578156, 8.813969957572002, 9.732831086880047, 10.806803312413289, 11.64283418070341, 12.597751097846533, 13.585670339602487, 15.621206193851322, 16.506585028974506, 15.525612166911735, 14.517825720439692, 13.575927240666458, 12.509699516543245, 11.564054890779374, 10.61710075993701, 9.700189536219707, 8.808467949339942, 7.919233292384379, 7.017439422731586, 7.849223698509261, 8.796193084284646, 9.721393527688111, 10.692534677602282, 11.748189016813718, 12.686671484796552, 13.6275210351908, 14.597318554994306, 16.564092919637556, 17.476080415791, 16.434486203390666, 15.474803430095513, 14.541531169147099, 13.553977265419896, 12.58456713951278, 11.597289742048163, 10.742900587859879, 9.799388450055513, 8.894616815910563, 8.04294000593625, 8.80362705653559, 9.77786914167689, 10.737476858300811, 11.665308516801456, 12.623606977676076, 13.60815438990989, 14.631735161313902, 15.52978076657456, 17.490241730781243, 17.266694344223502, 16.33708052150382, 15.444251472184305, 14.599105290770732, 13.738839006905488, 12.822910672267177, 11.78917988144258, 10.752026823189695, 10.852870097410387, 9.902669774911796, 9.084957975266496, 9.778555667203834, 10.776995741406767, 11.766381518165566, 12.608807056774847, 13.554920033786342, 14.525166617133097, 15.490152683749322, 16.5160692579871, 17.369851584240223, 16.4347899167466, 15.397623578232201, 14.471328088965523, 13.663909607333675, 12.777676365366279, 11.773337035491796, 10.780354327122575, 9.799327360241929, 10.728104549531988, 10.944868557456799, 10.1325909618448, 10.771626391096095, 11.734451608043736, 12.705179514562763, 13.546333846134706, 14.521059225294175, 15.513616730000969, 16.497853464202947, 17.440547055132793, 16.424002316692953, 15.465968936153027, 14.470420644921095, 13.50862900214881, 12.726469583325736, 11.742225385553661, 10.790716824492554, 9.770790904381498, 8.866341755900722, 9.79300202991049, 10.643805179685028, 11.08219190938083, 11.730628065839435, 12.749573456701444, 13.657031902399776, 14.526914947050388, 15.500745472375826, 16.443234888400998, 17.429582049272252, 17.430126944606076, 15.440566952422921, 14.555932440207377, 13.573869869576322, 12.582859023183962, 11.686023537226093, 10.711917955695693, 9.741463075651382, 8.808461745900969, 7.841039065502045, 8.785495819156505, 9.68831889771494, 10.624526767854723, 11.657286363716697, 12.528994363949687, 13.54450355198009, 14.559646725583658, 15.458955328021718, 16.499231445909782, 17.31500197829066, 16.380861914044342, 14.50981214490404, 13.631137438297486, 12.608713145315656, 11.624926215784486, 10.651955042652657, 9.762376421107046, 8.782682144383594, 7.813147398233021, 6.858726197316748, 7.896723848133583, 8.750666658703178, 9.75230900857121, 10.658013594563224, 11.497801360418594, 12.511353232181623, 13.567924848457034, 14.495931438182708, 15.480427746053714, 16.37478646125801, 15.449300684277558, 13.53134787580839, 12.584474590410254, 11.608433583584965, 10.69274211742547, 9.628178005007046, 8.748202234320111, 7.791901046450565, 6.94057336664695, 5.914915534105966, 6.902958343889114, 7.7410170291866205, 8.680855752247618, 9.609424969710213, 10.549873326367406, 11.556246313533777, 12.55120711205694, 13.53573870687349, 14.500411344629477, 15.461214795572417, 14.485090293311801, 12.66370687859712, 11.590296471456561, 10.62912043872728, 9.69220525874383, 8.694241739955404, 7.8451104817686685, 6.839358062531137, 5.885349388952447, 4.899204998977127, 5.882232122469853, 6.768935151273009, 7.744761885333665, 8.787180261484163, 9.725172839537207, 10.7151389162766, 11.752662063674588, 12.593263532180538, 13.625476002557996, 14.658970993000496, 13.62789624648584, 11.753633289433212, 10.801682077955485, 9.751709118394267, 8.759513546576631, 7.726650266553518, 6.7756203105095585, 5.831731474529362, 4.86263345492497, 3.9037219057661012, 4.951531706935838, 5.824352002396002, 6.781306262320854, 7.828730841976343, 8.709916042047904, 9.689907308089033, 10.748985189689654, 11.626618797223237, 12.629032405589884, 13.58979417845504, 12.77317052312998], [10.768566848177306, 11.717287179213283, 12.613903972717589, 11.654111819176018, 10.699194655952523, 9.694496340863672, 8.680214437941835, 7.805463769652347, 6.79526773610503, 5.789386169396445, 4.881263479437173, 3.8557770946972054, 3.054031915689923, 3.889544323671884, 4.834685035652353, 5.805720862909016, 6.844221797319617, 7.8564137564684575, 8.841446836942634, 9.784271397768872, 9.796167200179868, 10.741251294533127, 11.71970850132631, 10.713713740188075, 9.778560335462775, 8.801347122511972, 7.740321233863899, 6.805095502309207, 5.818348495676746, 4.797232466481196, 3.843127208472416, 2.913494199071152, 1.9884647153099388, 2.93760704320228, 3.9077196428396173, 4.914089524177129, 5.8770498953223616, 6.9220313883798665, 7.9086507054199675, 8.855577093975988, 9.064516259119952, 10.105222873493508, 10.985792594966385, 9.987927238108492, 8.969663249296014, 7.971193631272002, 6.921979917753986, 5.918803562233977, 4.948977246595406, 3.996148300037338, 2.955403159262223, 1.975994753141833, 0.9669047996529055, 1.915488795725613, 2.88848868559238, 3.944760666165099, 5.00264445123256, 6.053076379707399, 7.017091254423834, 8.080509620543815, 8.174945336225779, 9.213353488923756, 9.975227778488279, 9.025416614116205, 8.01691932728898, 6.948162844276887, 5.96454334116711, 4.965458541647335, 4.009286350353767, 3.063189283449784, 2.0173152725678882, 0.9636310486633917, 0.0, 1.0451085687855135, 2.09322268975564, 3.1673958960963384, 4.236887365026132, 5.175016987015683, 6.172553316231015, 7.110061155966208, 8.942368395377446, 9.974052594671441, 10.821139829860382, 9.781457128981078, 8.817250262517799, 7.883602333809247, 6.894550688534226, 5.951814774911406, 4.969383289012127, 3.9378833174110595, 2.870541271212916, 1.8937228031511855, 0.9759726194768421, 1.9717169065440525, 3.0351257917193384, 3.9919561476668752, 5.059653879240127, 6.086639733530559, 7.063876638068871, 8.004467791349258, 9.869899505931963, 10.825105507428693, 11.80839570082344, 10.780470499324764, 9.754801704347345, 8.81719464463215, 7.855553029151645, 6.822237882218015, 5.849325021782461, 4.863673168162455, 3.9290831793046603, 2.915766379204114, 1.9773322535172813, 2.9487434542314372, 4.0150734656460525, 4.950577576504101, 5.925351519299606, 6.951256539449079, 7.8878217499464816, 8.939271395221045, 10.788645305879085, 11.764230802060874, 12.786713266564208, 11.723017058496751, 10.74674480664268, 9.856048072624692, 8.783633149566283, 7.768331828934326, 6.813142071375383, 5.799453195123899, 4.877750536526359, 3.9531234377849254, 3.0226428993544596, 3.9424862895462294, 4.95030306984588, 5.929012728349938, 6.858185548816852, 7.885876403095641, 8.851337037529234, 9.856690973923051, 11.755851619177227, 12.746519202075984, 13.69323396279608, 12.681554445670596, 11.660797405142619, 10.693058116415646, 9.706398057848366, 8.714840611374427, 7.7549579616036475, 6.816100840970962, 5.910929870286195, 4.955251401039208, 3.954737235216445, 5.010646519126578, 5.9205529123826866, 6.8626464276790395, 7.809971017577699, 8.741828697856223, 9.76708421786459, 10.758340529608038, 12.684451675281384, 13.68058250065369, 14.646188349913027, 13.71892642653985, 12.692185238509516, 11.675101179115288, 10.711032313043875, 9.769538220475743, 8.743865888107901, 7.779162891320315, 6.896791344105608, 5.857065151698583, 4.897401874203838, 5.961130255345518, 6.914738978335296, 7.799812519307071, 8.804461044394593, 9.744052749651551, 10.781021687023493, 11.718892741688736, 13.690943719991495, 14.633917671365381, 15.68056977872453, 14.64403111495687, 13.660640028800838, 12.664453771855818, 11.589868735728526, 10.65446252750168, 9.684660835588382, 8.749265323344448, 7.841330204238007, 6.858481134454556, 5.910738098733541, 6.844290943503102, 7.90344097349695, 8.78574389749143, 9.859716123024672, 10.695746991314792, 11.650663908457915, 12.638583150213869, 14.65757514518793, 15.607736894570936, 16.489243215575126, 15.481456769103083, 14.539558289329849, 13.473330565206636, 12.527685939442765, 11.580731808600401, 10.663820584883098, 9.772098998003333, 8.79063666220262, 7.869842712540471, 6.938694714434208, 7.885664100209592, 8.810864543613057, 9.745447488213665, 10.801101827425102, 11.739584295407935, 12.680433845802181, 13.650231365605688, 15.61214823953939, 16.57723228138743, 16.308916282490816, 15.41191773772286, 14.669912008995736, 13.8430941047815, 12.96548593578849, 12.285501212308128, 11.70653163652327, 10.762314402052784, 9.766020185728804, 8.895343295745135, 7.8930980724605355, 8.867340157601836, 9.826947874225757, 10.71822132741284, 11.67651978828746, 12.661067200521273, 13.684647971925285, 14.582693577185943, 16.543154541392624, 16.303063295560108, 15.373449472840429, 14.480620423520914, 13.642567997126305, 12.782301713261061, 11.957129646417854, 11.215796771182838, 11.715657871853086, 11.815796049407657, 10.774073144730036, 9.921221181108725, 8.86802668312878, 9.866466757331713, 10.855852534090513, 11.66171986738623, 12.607832844397725, 13.57807942774448, 14.543065494360706, 15.56898206859848, 16.406220535576836, 15.47115886808321, 14.43399252956881, 13.507697040302132, 12.707372313689248, 11.821139071721852, 10.907556009642473, 10.203822771003567, 10.76295840890532, 11.691735598195379, 11.816271927275038, 10.808498831998403, 9.861097407021042, 10.823922623968683, 11.79465053048771, 12.59924665674609, 13.573972035905559, 14.566529540612352, 15.550766274814329, 16.493459865744175, 15.460371268029563, 14.502337887489636, 13.506789596257704, 12.544997953485419, 11.769932289681309, 10.785688091909234, 9.834179530848127, 9.19425934826249, 9.829972804564113, 10.75663307857388, 11.607436228348421, 11.758099779534433, 10.820099081764381, 11.83904447262639, 12.746502918324722, 13.579827757661771, 14.553658282987211, 15.496147699012383, 16.482494859883637, 16.466495895942685, 14.47693590375953, 13.592301391543986, 12.610238820912931, 11.619227974520571, 10.729486243581666, 9.755380662051266, 8.784925782006955, 8.231930189781961, 8.804670114165436, 9.749126867819896, 10.651949946378332, 11.588157816518116, 11.750789687012055, 12.761331179464817, 13.761549623345896, 14.517423172550806, 15.57701517175895, 16.56754290829293, 16.35137092962727, 15.417230865380951, 13.546181096240648, 12.667506389634095, 11.645082096652265, 10.661295167121095, 9.688323993989266, 8.805839127462619, 7.826144850739166, 7.16951425094752, 7.822357245980139, 8.860354896796974, 9.71429770736657, 10.715940057234603, 11.621644643226617, 12.461432409081986, 13.474984280845014, 14.531555897120425, 15.459562486846101, 16.37326069140398, 15.41115541259462, 14.485669635614167, 12.567716827144999, 11.620843541746863, 10.644802534921574, 9.729111068762078, 8.664546956343655, 7.791664940675685, 6.835363752806138, 6.1995586663686915, 6.878546582769357, 7.866589392552505, 8.704648077850013, 9.644486800911011, 10.573056018373606, 11.513504375030799, 12.51987736219717, 13.514838160720332, 14.499369755536883, 15.46404239329287, 14.521299611979908, 13.52145924464841, 11.700075829933729, 10.62666542279317, 9.66548939006389, 8.728574210080438, 7.7306106912920125, 6.881479433105277, 5.8828207688867105, 5.134536433510705, 5.862836047640518, 6.845863171133244, 7.732566199936401, 8.708392933997057, 9.750811310147556, 10.6888038882006, 11.678769964939992, 12.71629311233798, 13.556894580843931, 14.589107051221388, 13.699079861809611, 12.664265197822449, 10.790002240769821, 9.838051029292094, 8.788078069730876, 7.79588249791324, 6.763019217890127, 5.811989261846167, 4.875194180884935, 4.098646360485672, 4.867352954429492, 5.91516275559923, 6.787983051059394, 7.744937310984246, 8.792361890639734, 9.673547090711297, 10.653538356752424, 11.712616238353045, 12.59024984588663, 13.592663454253277, 12.663466098070138, 11.80953947446659], [9.87249844506744, 10.821218776103416, 11.814561111647405, 12.69922038796153, 11.744303224738035, 10.739604909649184, 9.725323006727347, 8.850572338437859, 7.840376304890543, 6.834494738181958, 5.926372048222687, 4.900885663482719, 4.010908635556018, 3.0209157369139152, 3.938616632542486, 4.909652459799148, 5.948153394209749, 6.96034535335859, 7.945378433832768, 8.888202994659004, 8.900098797070001, 9.84518289142326, 10.823640098216442, 11.758822308973587, 10.823668904248287, 9.846455691297484, 8.78542980264941, 7.850204071094719, 6.863457064462259, 5.842341035266709, 4.888235777257929, 3.9586027678566653, 3.0170041206973854, 2.068978456444311, 3.0116512397297504, 4.018021121067262, 4.980981492212495, 6.02596298527, 7.012582302310101, 7.95950869086612, 8.03581329791667, 9.076519912290227, 10.1123491955287, 11.033035806894006, 10.014771818081527, 9.016302200057517, 7.9670884865395, 6.96391213101949, 5.9940858153809184, 5.041256868822851, 4.000511728047736, 3.021103321927346, 1.9954442050403518, 1.0468602089676444, 1.9924202824825126, 3.0486922630552318, 4.106576048122692, 5.157007976597532, 6.121022851313967, 7.051806659340533, 7.129836767440264, 8.16824492013824, 9.152461586957289, 10.070525182901719, 9.062027896074493, 7.9932714130624, 7.009651909952623, 6.010567110432849, 5.0543949191392805, 4.108297852235298, 3.062423841353402, 2.008739617448905, 1.0451085687855135, 0.0, 1.0481141209701266, 2.1222873273108247, 3.1917787962406186, 4.129908418230169, 5.127444747445502, 6.064952587180694, 7.897259826591932, 8.928944025885928, 9.896786599940254, 10.826565697766592, 9.862358831303313, 8.92871090259476, 7.939659257319739, 6.996923343696919, 6.01449185779764, 4.982991886196572, 3.915649839998429, 2.9388313719366987, 1.9514327649095216, 0.9266083377585389, 1.9900172229338247, 2.9468475788813615, 4.014545310454613, 5.041531164745045, 6.018768069283357, 6.9593592225637435, 8.82479093714645, 9.77999693864318, 10.771403952246432, 11.799329153745107, 10.79991027313286, 9.862303213417663, 8.900661597937159, 7.867346451003529, 6.894433590567974, 5.908781736947969, 4.974191748090174, 3.960874947989627, 2.9393410577267822, 1.967929857012626, 3.019475099721702, 3.9054690077185876, 4.880242950514092, 5.906147970663565, 6.842713181160968, 7.894162826435531, 9.74353673709357, 10.71912223327536, 11.782686573171475, 12.768125627282267, 11.791853375428193, 10.901156641410205, 9.828741718351797, 8.81344039771984, 7.858250640160897, 6.844561763909413, 5.880913245781956, 4.915132241994426, 3.9846517035639604, 2.961672692327418, 3.9694894726270684, 4.897568817261552, 5.813076980031338, 6.840767834310127, 7.80622846874372, 8.811582405137537, 10.710743050391713, 11.70141063329047, 12.649021332195604, 13.660700849321088, 12.70590597392813, 11.738166685201158, 10.751506626633878, 9.75994918015994, 8.800066530389161, 7.8612094097564755, 6.872938674495695, 5.9172602052487075, 4.916746039425946, 4.029832921907767, 4.939739315163875, 5.881832830460228, 6.777009297853757, 7.708866978132281, 8.734122498140648, 9.725378809884097, 11.63934310649587, 12.635473931868177, 13.60197571931255, 14.61822828940794, 13.737293807295028, 12.7202097479008, 11.756140881829387, 10.814646789261257, 9.788974456893415, 8.824271460105829, 7.858800148315108, 6.819073955908083, 5.859410678413338, 5.023931114745056, 5.955341217713461, 6.81899892208826, 7.779625347449064, 8.711091029927612, 9.748059967299554, 10.685931021964794, 12.645835151205983, 13.58880910257987, 14.635461209939018, 15.587428296902665, 14.66803130617165, 13.671845049226631, 12.597260013099339, 11.661853804872493, 10.692052112959194, 9.75665660071526, 8.803339008447507, 7.820489938664056, 6.872746902943042, 5.981530137276521, 6.9440432128751155, 7.804930300272619, 8.835828052329685, 9.662785271590852, 10.617702188733976, 11.60562143048993, 13.612466576402419, 14.562628325785424, 15.543601187848196, 15.53194473166227, 14.83480258574803, 14.046243431094283, 13.117369597763924, 12.588123085971214, 11.67121186225391, 10.779490275374146, 9.75264546641212, 8.831851516749973, 7.900703518643709, 7.027929014248765, 7.89620823946916, 8.764633890994855, 9.820288230206291, 10.733399725097911, 11.647472126078242, 12.617269645881748, 14.567039670753879, 15.532123712601917, 15.412847879380948, 14.51584933461299, 13.792561215689705, 12.974465518023532, 12.096857349030518, 12.952489587196846, 12.713922913894082, 11.724323206262284, 10.728028989938304, 9.857352099954637, 8.855106876670037, 8.00960507164101, 8.91229157008186, 9.737407730194029, 10.695706191068648, 11.680253603302463, 12.67242604989784, 13.549731857462003, 15.510192821668687, 15.40699489245024, 14.47738106973056, 13.584552020411046, 12.765217203820274, 11.913673126503094, 11.088501059659883, 11.882785146071555, 12.760766440638601, 12.777804853617157, 11.736081948939535, 10.883229985318227, 9.830035487338282, 9.008731671370887, 9.941196229946616, 10.68090627016742, 11.627019247178914, 12.59726583052567, 13.562251897141895, 14.53602034887454, 15.510152132466967, 14.575090464973341, 13.537924126458941, 12.611628637192263, 11.830021520383218, 10.952510484963884, 10.038927422884504, 10.870811145892285, 11.808066977690833, 12.736844166980893, 12.778280731484537, 11.770507636207904, 10.823106211230543, 10.050894149455834, 10.879994226343813, 11.618433059527279, 12.593158438686748, 13.585715943393541, 14.569952677595518, 15.474615752867495, 14.564302864919695, 13.606269484379768, 12.610721193147835, 11.64892955037555, 10.892581496375279, 9.917059505151267, 8.965550944090158, 9.861247723151207, 10.875081373349627, 11.801741647359394, 12.652544797133933, 12.720108583743935, 11.782107885973883, 11.08116435674585, 11.831846614180826, 12.59901416044296, 13.572844685768398, 14.51533410179357, 15.501681262664825, 15.570427492832817, 13.580867500649662, 12.696232988434117, 11.714170417803063, 10.723159571410703, 9.852135450275636, 8.886752075293298, 7.916297195248985, 8.898918564670678, 9.84977868295095, 10.79423543660541, 11.697058515163844, 12.633266385303628, 12.712798491221557, 12.075939722477793, 12.846893319202, 13.536609575331996, 14.596201574540137, 15.586729311074114, 15.455302526517398, 14.521162462271082, 12.65011269313078, 11.771437986524226, 10.749013693542397, 9.765226764011226, 8.792255590879398, 7.93721054070465, 6.957516263981198, 7.939530211416114, 8.867465814765653, 9.90546346558249, 10.759406276152083, 11.761048626020115, 12.666753212012129, 13.107132726008887, 13.880043639000467, 14.52833145245862, 15.533195057773256, 15.477192288294114, 14.515087009484752, 13.589601232504299, 11.67164842403513, 10.724775138636994, 9.748734131811705, 8.83304266565221, 7.768478553233787, 6.923036353917716, 5.96673516604817, 6.983210413453164, 7.923655151554871, 8.91169796133802, 9.749756646635525, 10.689595369696523, 11.618164587159118, 12.55861294381631, 13.564985930982681, 14.559946729505844, 15.544478324322395, 14.586034659812979, 13.625231208870039, 12.625390841538541, 10.80400742682386, 9.730597019683302, 8.769420986954021, 7.83250580697057, 6.834542288182145, 5.98541102999541, 5.014192182128742, 5.969215913839856, 6.907944616426032, 7.890971739918758, 8.777674768721914, 9.75350150278257, 10.795919878933068, 11.733912456986111, 12.723878533725504, 13.761401681123491, 14.602003149629443, 13.813166390448707, 12.803011458699743, 11.76819679471258, 9.893933837659953, 8.941982626182226, 7.892009666621008, 6.899814094803372, 5.866950814780259, 4.9159208587363, 4.0065655941269664, 5.037822020906904, 5.912461523215006, 6.960271324384744, 7.8330916198449065, 8.790045879769758, 9.837470459425248, 10.71865565949681, 11.698646925537936, 12.757724807138556, 13.635358414672142, 12.7798885356172, 11.767397694960271, 10.913471071356721], [8.824384324097313, 9.77310465513329, 10.766446990677279, 11.72623914421885, 12.646525928490675, 11.641827613401825, 10.627545710479987, 9.752795042190499, 8.742599008643184, 7.736717441934598, 6.827513203995586, 5.801037613709434, 4.83709494106904, 3.847102042426937, 2.8905025115723593, 3.8615383388290216, 4.9000392732396225, 5.912231232388463, 6.8972643128626405, 7.8400888736888765, 7.851984676099874, 8.797068770453134, 9.775525977246316, 10.834063838342948, 11.725891608000927, 10.748678395050124, 9.687652506402051, 8.75242677484736, 7.765679768214899, 6.744563739019349, 5.790458481010569, 4.860825471609306, 3.887449963108894, 2.93942429885582, 1.9635371187596236, 2.969907000097135, 3.932867371242368, 4.977848864299872, 5.964468181339973, 6.911394569895993, 6.987699176946544, 8.0284057913201, 9.064235074558574, 10.016669254351523, 10.931858511026887, 9.933388893002876, 8.88417517948486, 7.86613483477213, 6.896308519133559, 5.943479572575491, 4.9027344318003765, 3.9233260256799865, 2.8658900474518605, 1.917306051379153, 0.944306161512386, 2.0005781420851054, 3.0584619271525657, 4.1088938556274055, 5.0729087303438405, 6.003692538370407, 6.081722646470138, 7.120130799168114, 8.104347465987162, 9.054158630359236, 10.062655917186461, 9.041385534032527, 8.05776603092275, 7.058681231402975, 6.102509040109407, 5.156411973205424, 4.110537962323528, 3.056853738419032, 2.09322268975564, 1.0481141209701266, 0.0, 1.0741732063406983, 2.143664675270492, 3.0817942972600427, 4.079330626475375, 5.016838466210568, 6.898988179857382, 7.930672379151378, 8.898514953205705, 9.938197654085009, 10.902404520548288, 9.976825023564889, 8.987773378289868, 8.045037464667047, 7.062605978767768, 6.0311060071667, 4.963763960968556, 3.986945492906826, 2.9995468858796484, 1.9747224587286656, 1.070128874674343, 2.0269592306218795, 3.0946569621951308, 4.043259518010496, 5.020496422548808, 5.961087575829194, 7.846030720457873, 8.801236721954604, 9.792643735557856, 10.820568937056532, 11.848024394102987, 10.910417334387791, 9.948775718907285, 8.915460571973655, 7.942547711538102, 6.956895857918096, 6.022305869060301, 5.008989068959754, 3.9874551786969086, 3.0160439779827524, 2.09958675146222, 2.9855806594591057, 3.9603546022546103, 4.986259622404083, 5.922824832901486, 6.935880975330411, 8.823648388834089, 9.799233885015878, 10.824906330409945, 11.809772366045223, 12.786044617899297, 11.949270762380332, 10.876855839321923, 9.861554518689966, 8.906364761131023, 7.89267588487954, 6.9290273667520825, 5.9632463629645525, 5.032765824534087, 4.009786813297544, 3.1577229459866203, 3.9776804690020704, 4.8931886317718565, 5.920879486050645, 6.886340120484238, 7.891694056878055, 9.790854702132231, 10.781522285030988, 11.729132983936122, 12.740812501061606, 13.754020094898257, 12.786280806171284, 11.799620747604004, 10.808063301130066, 9.848180651359288, 8.909323530726603, 7.921052795465822, 6.965374326218834, 5.964860160396072, 5.077947042877892, 4.127972788523427, 4.993660939781572, 5.857120949594275, 6.788978629872799, 7.814234149881165, 8.805490461624613, 10.719454758236388, 11.715585583608695, 12.682087371053068, 13.698339941148458, 14.725081129178792, 13.768323868870926, 12.804255002799513, 11.862760910231385, 10.837088577863543, 9.872385581075957, 8.906914269285235, 7.867188076878209, 6.907524799383465, 6.072045235715182, 5.143574691073013, 5.930827031409604, 6.8597369991895825, 7.791202681668129, 8.82817161904007, 9.76604267370531, 11.725946802946499, 12.668920754320386, 13.715572861679535, 14.667539948643185, 14.730649460271302, 14.11122493132003, 13.645374134069465, 12.70996792584262, 11.74016623392932, 10.804770721685387, 9.851453129417633, 8.868604059634183, 7.920861023913169, 7.0296442582466465, 6.1322766862346665, 6.916758409593963, 7.915939704070204, 8.742896923331369, 9.697813840474492, 10.685733082230445, 12.692578228142935, 13.64273997752594, 14.623712839588713, 14.483830610692143, 13.786688464777903, 13.155286302975284, 13.93413082359226, 13.63623720694134, 12.719325983224037, 11.827604396344272, 10.800759587382247, 9.8799656377201, 8.948817639613836, 8.009642156232175, 7.084441712828711, 7.876462000316199, 8.932116339527635, 9.813511376838427, 10.727583777818758, 11.697381297622265, 13.647151322494395, 14.612235364342434, 14.364733758410821, 13.467735213642865, 12.744447094719579, 12.083508389904534, 12.913618574858855, 13.769250813025181, 13.762037034864209, 12.77243732723241, 11.77614311090843, 10.905466220924763, 9.903220997640164, 8.99131821362442, 8.100525043441412, 8.849235839515373, 9.807534300389992, 10.792081712623807, 11.752537701638357, 12.62984350920252, 14.590304473409203, 14.358880771480113, 13.429266948760434, 12.53643789944092, 11.717103082850148, 11.022715998384095, 11.90526228548822, 12.69954637189989, 13.59409022858559, 13.825918974587283, 12.784196069909662, 11.931344106288353, 10.878149608308409, 9.990444813354296, 9.129429703306167, 9.792734379488763, 10.738847356500258, 11.709093939847014, 12.674080006463239, 13.616132000615057, 14.46203801149684, 13.526976344003215, 12.489810005488815, 11.563514516222137, 10.781907399413091, 10.061553356844886, 10.855688648712839, 11.68757237172062, 12.641390765637821, 13.57016795492788, 13.826394852454664, 12.81862175717803, 11.87122033220067, 11.032607291439243, 10.068227699703364, 10.730261168848623, 11.704986548008092, 12.697544052714886, 13.681780786916862, 14.55472740460801, 13.516188743949568, 12.558155363409641, 11.562607072177709, 10.600815429405424, 9.844467375405152, 9.026102377032268, 9.782312169918493, 10.678008948979542, 11.708405161296614, 12.635065435306382, 13.508395626756203, 13.768222704714061, 12.830222006944009, 12.062877498729259, 11.020080087540377, 11.710842269764305, 12.684672795089742, 13.627162211114914, 14.613509371986169, 14.52231337186269, 12.532753379679535, 11.64811886746399, 10.666056296832936, 9.675045450440576, 8.80402132930551, 7.995794947174299, 8.73305842107732, 9.715679790499014, 10.683102470897937, 11.627559224552398, 12.552909344786114, 13.489117214925898, 13.760912612191683, 13.057652864461202, 12.03512679256155, 12.64843768465334, 13.708029683861481, 14.698557420395458, 14.407188405547272, 13.473048341300956, 11.601998572160653, 10.7233238655541, 9.70089957257227, 8.7171126430411, 7.744141469909271, 7.046253412585651, 7.774277489809533, 8.75629143724445, 9.710712638160723, 10.74871028897756, 11.661628979904721, 12.663271329772755, 13.568975915764769, 14.081828984123046, 13.068277112360018, 13.640159561779964, 14.6450231670946, 14.429078167323988, 13.466972888514626, 12.541487111534172, 10.623534303065004, 9.676661017666868, 8.700620010841579, 7.784928544682083, 6.7203644322636595, 5.994564554400439, 6.783496391876505, 7.799971639281499, 8.787832064772351, 9.775874874555498, 10.651979350388164, 11.591818073449163, 12.520387290911758, 13.46083564756895, 14.092023006619417, 14.689338081499766, 14.50259317659884, 13.537920538842853, 12.577117087899913, 11.577276720568415, 9.755893305853734, 8.682482898713175, 7.721306865983894, 6.784391686000443, 5.7864281672120175, 4.9372969090252825, 5.830953407957077, 6.785977139668192, 7.7721215296435116, 8.755148653136239, 9.679897472474552, 10.65572420653521, 11.698142582685708, 12.636135160738752, 13.626101237478144, 14.619885023687933, 13.629021905886763, 12.76505226947858, 11.754897337729616, 10.720082673742453, 8.845819716689824, 7.893868505212099, 6.843895545650882, 5.851699973833246, 4.818836693810132, 3.8678067377661725, 4.823326819955302, 5.854583246735239, 6.812613473441721, 7.861412480157643, 8.735314323597546, 9.692268583522399, 10.739693163177888, 11.62087836324945, 12.600869629290576, 13.655397686477226, 12.662377170929462, 11.731774414647074, 10.719283573990145, 9.865356950386595], [7.780275637042718, 8.728995968078696, 9.722338303622685, 10.682130457164256, 11.71268729199581, 12.716000819742524, 11.701718916820687, 10.826968248531198, 9.816772214983882, 8.810890648275297, 7.901686410336284, 6.875210820050132, 5.9112681474097375, 4.921275248767635, 3.964675717913057, 3.131552202106117, 4.077216701471638, 4.976515573654705, 5.9513450159602295, 6.795980186634282, 6.80787598904528, 7.7529600833985395, 8.731417290191722, 9.789955151288353, 10.725108556013653, 11.702321768964456, 10.76182571274275, 9.826599981188059, 8.839852974555598, 7.8187369453600475, 6.864631687351268, 5.934998677950004, 4.9616231694495925, 4.013597505196518, 3.0377103251003215, 2.0659784433336705, 3.00510310280567, 4.032768782829391, 5.018548884437562, 5.867285882841399, 5.913525970605845, 6.954232584979402, 7.990061868217877, 8.942496048010826, 9.94143260691043, 10.93990222493444, 9.958348385825557, 8.940308041112829, 7.970481725474258, 7.01765277891619, 5.976907638141075, 4.997499232020685, 3.940063253792559, 2.9914792577198512, 2.018479367853084, 1.0150028187054603, 2.023157685195925, 3.0624905122543753, 4.026505386970811, 4.929519332029709, 5.00754944012944, 6.045957592827417, 7.030174259646465, 7.979985424018538, 8.988482710845762, 10.057239193857855, 9.131939237263449, 8.132854437743674, 7.176682246450105, 6.2305851795461225, 5.184711168664227, 4.13102694475973, 3.1673958960963384, 2.1222873273108247, 1.0741732063406983, 0.0, 1.0694914689297939, 2.0076210909193444, 3.005157420134677, 3.942665259869869, 5.824814973516684, 6.85649917281068, 7.824341746865007, 8.86402444774431, 9.828231314207589, 10.761879242916141, 10.000443843539596, 9.057707929916775, 8.075276444017497, 7.043776472416429, 5.976434426218286, 4.999615958156555, 4.006647903778891, 2.981823476627908, 1.9184145914526223, 0.9615842355050856, 2.0292819670783366, 2.9690863116697974, 3.9463232162081097, 4.886914369488496, 6.771857514117174, 7.727063515613905, 8.718470529217157, 9.746395730715832, 10.775170942194343, 11.695471553739043, 10.961446184157015, 9.928131037223386, 8.955218176787831, 7.969566323167825, 7.034976334310031, 6.021659534209483, 4.985613680369271, 4.014202479655115, 2.9478724682404995, 1.920205664342312, 2.8949796071378167, 3.9208846272872897, 4.857449837784692, 5.861707768989713, 7.758273393717295, 8.733858889899084, 9.750733124069246, 10.735599159704524, 11.711871411558597, 12.727861244208706, 11.833862572431848, 10.81856125179989, 9.860405187425203, 8.846716311173719, 7.840931120988895, 6.875150117201365, 5.944669578770899, 4.898831912688985, 3.8910151323893345, 2.9123054738852767, 3.8278136366550624, 4.855504490933852, 5.820965125367445, 6.826319061761262, 8.725479707015436, 9.716147289914193, 10.663757988819327, 11.675437505944812, 12.696194546472789, 13.663933835199762, 12.756627480713929, 11.76507003423999, 10.802221077653467, 9.86336395702078, 8.832956549702635, 7.877278080455646, 6.8767639146328845, 5.845540049318277, 4.861264974926141, 3.9282859446647787, 4.791745954477482, 5.723603634756006, 6.7488591547643715, 7.740115466507819, 9.654079763119594, 10.6502105884919, 11.616712375936274, 12.632964946031663, 13.659706134061997, 14.645976897899404, 13.761261735909438, 12.804839357819882, 11.77916702545204, 10.814464028664453, 9.818818023522047, 8.779091831115021, 7.819428553620277, 6.756800164601374, 5.803191441611595, 4.865452036292811, 5.794362004072789, 6.725827686551336, 7.762796623923277, 8.700667678588516, 10.660571807829704, 11.603545759203591, 12.65019786656274, 13.60216495352639, 14.000663323548395, 14.996849580493414, 14.437115416170807, 13.50170920794396, 12.531907516030662, 11.596512003786728, 10.643194411518975, 9.660345341735525, 8.6479520319024, 7.714399187132838, 6.791893436773249, 5.85138341447717, 6.85056470895341, 7.677521928214576, 8.632438845357699, 9.620358087113654, 11.62720323302614, 12.577364982409145, 13.558337844471918, 13.66100803892416, 13.056702328054998, 14.073792774794626, 14.976176173106209, 14.427978489042681, 13.511067265325378, 12.619345678445614, 11.592500869483588, 10.547376290652405, 9.616228292546142, 8.669258906770757, 7.744058463367293, 6.811087005199406, 7.866741344410841, 8.748136381721634, 9.662208782701965, 10.632006302505474, 12.5817763273776, 13.546860369225639, 13.541911186642837, 12.644912641874882, 12.014460957996674, 13.002014861723877, 13.955663924372804, 14.84342401936588, 14.55377831696555, 13.558920894726148, 12.562626678402168, 11.57287687385707, 10.57063165057247, 9.650934964163001, 8.760141793979994, 7.78386084439858, 8.7421593052732, 9.726706717507014, 10.687162706521566, 11.564468514085728, 13.524929478292412, 13.536058199712128, 12.60644437699245, 11.713615327672935, 10.987116946127243, 11.973653781313155, 12.947307635002169, 13.77371957824059, 14.668263434926288, 14.612402542081021, 13.570679637403401, 12.59875475922066, 11.545560261240714, 10.650061563892878, 9.751277622297989, 8.72735938437197, 9.673472361383466, 10.643718944730221, 11.608705011346446, 12.550757005498266, 13.639215439728854, 12.70415377223523, 11.66698743372083, 10.740691944454152, 10.051921262690186, 11.012491139773946, 11.929861855053538, 12.76174557806132, 13.71556397197852, 14.64434116126858, 14.495589518880806, 13.486032410110337, 12.538630985132976, 11.588897519536598, 10.604903849714498, 9.66488617373183, 10.6396115528913, 11.632169057598093, 12.61640579180007, 13.48935240949122, 12.693366172181584, 11.735332791641657, 10.739784500409725, 9.77799285763744, 9.114481238682247, 9.977040159961328, 10.856485376259192, 11.752182155320241, 12.782578367637313, 13.709238641647081, 14.582568833096902, 14.435633357646367, 13.497632659876315, 12.606738618792587, 11.556756237551511, 10.645467274647512, 11.619297799972951, 12.561787215998123, 13.548134376869378, 13.688581506359885, 11.709930807911551, 10.825296295696006, 9.843233725064952, 8.852222878672592, 8.074035192582604, 8.94673273010336, 9.80723162741802, 10.789852996839713, 11.757275677238637, 12.701732430893097, 13.627082551126813, 14.563290421266597, 14.42832326512399, 13.60151398452453, 12.571802942572685, 11.583062689536547, 12.64265468874469, 13.633182425278667, 13.573456540044466, 12.63931647579815, 10.779176000392669, 9.900501293786114, 8.878077000804284, 7.894290071273114, 7.014155333186366, 7.997191195514712, 8.848450696150232, 9.830464643585149, 10.784885844501423, 11.822883495318258, 12.73580218624542, 13.737444536113454, 14.643149122105468, 14.618505134134182, 13.604953262371152, 12.57478456666317, 13.579648171977805, 13.595346301821182, 12.63324102301182, 11.707755246031367, 9.80071173129702, 8.853838445898884, 7.8777974390735945, 6.962105972914099, 5.990378295540755, 6.9455023373295, 7.857669598217203, 8.874144845622197, 9.86200527111305, 10.850048080896197, 11.726152556728863, 12.665991279789862, 13.594560497252457, 14.53500885390965, 14.618923884906136, 13.623963086382973, 13.547155172419409, 12.699116408308592, 11.743385222397107, 10.74354485506561, 8.82946402431008, 7.859660326945191, 6.898484294215909, 5.961569114232459, 5.056442030489113, 6.011470115365981, 6.905126614297775, 7.86015034600889, 8.84629473598421, 9.829321859476938, 10.754070678815252, 11.729897412875909, 12.772315789026408, 13.71030836707945, 14.613299484031327, 13.57577633663334, 12.584913218832169, 11.720943582423986, 10.744351701481007, 9.7936533921988, 7.801711029635231, 7.009317240496722, 6.021072973882897, 5.028877402065262, 4.088850557087228, 4.941979944106871, 5.897500026296, 6.928756453075938, 7.886786679782419, 8.93558568649834, 9.809487529938245, 10.766441789863098, 11.813866369518587, 12.695051569590149, 13.67345785930287, 12.611288999422632, 11.618268483874868, 10.68766572759248, 9.675174886935551, 8.821248263332], [6.710784168112924, 7.659504499148902, 8.652846834692891, 9.612638988234462, 10.643195823066014, 11.647894138154864, 12.63374939276067, 11.855433387971926, 10.823328210207508, 9.756483808531833, 8.768917971594583, 7.7424423813084315, 6.778499708668037, 5.788506810025934, 4.831907279171356, 3.9641457637935558, 3.007725232541844, 3.907024104724911, 4.881853547030435, 5.7264887177044885, 5.738384520115486, 6.683468614468746, 7.661925821261927, 8.720463682358558, 9.655617087083858, 10.63283030003466, 11.693856188682734, 10.855065120628787, 9.868318113996326, 8.847202084800776, 7.893096826791995, 6.963463817390731, 5.924739799418005, 4.943463323053253, 3.9049418863586203, 2.898572005021109, 1.935611633875876, 2.9632773138995967, 3.949057415507768, 4.797794413911605, 4.8440345016760515, 5.884741116049608, 6.920570399288083, 7.87300457908103, 8.871941137980636, 9.870410756004647, 10.919624469522663, 9.989650655166054, 9.019824339527483, 8.066995392969416, 7.026250252194301, 6.046841846073911, 4.989405867845785, 4.040821871773078, 3.067821981906311, 2.0115500013335916, 0.9536662162661314, 1.992999043324581, 2.9570139180410164, 3.8600278630999147, 3.9380579711996453, 4.976466123897622, 5.96068279071667, 6.910493955088743, 7.918991241915968, 8.987747724928061, 9.971367228037838, 9.202345906673466, 8.246173715379898, 7.300076648475916, 6.2542026375940205, 5.200518413689524, 4.236887365026132, 3.1917787962406186, 2.143664675270492, 1.0694914689297939, 0.0, 0.9381296219895504, 1.935665951204883, 2.873173790940075, 4.755323504586891, 5.787007703880887, 6.754850277935214, 7.794532978814518, 8.758739845277796, 9.692387773986349, 10.68143941926137, 10.12719939884657, 9.144767912947291, 8.113267941346223, 7.04592589514808, 6.069107427086349, 5.076139372708685, 4.051314945557702, 2.987906060382416, 2.0310757044348797, 0.9802134211709872, 1.8995948427400036, 2.876831747278316, 3.8174229005587024, 5.702366045187381, 6.657572046684112, 7.648979060287363, 8.676904261786039, 9.70567947326455, 10.625980084809251, 11.66623991165821, 10.98577554096437, 10.012862680528816, 9.02721082690881, 8.092620838051015, 7.066174760229087, 5.995644306518742, 5.024233105804586, 3.9579030943899713, 2.9107159004428294, 1.9359419576473247, 2.9476557771719745, 3.8113904598023254, 4.792216300059919, 6.695568133310744, 7.671153629492533, 8.681241655139452, 9.66610769077473, 10.642379942628803, 11.658369775278912, 12.672586715472994, 11.734477078445181, 10.776321014070493, 9.76263213781901, 8.756846947634186, 7.791065943846656, 6.86058540541619, 5.814747739334277, 4.806930959034626, 3.828221300530568, 2.8687759871645704, 3.882275640818536, 4.775508775511488, 5.780862711905305, 7.6627744466088865, 8.653442029507643, 9.601052728412776, 10.612732245538261, 11.633489286066238, 12.601228574793211, 13.58788863336049, 12.680985860885281, 11.718136904298758, 10.779279783666071, 9.728675928301803, 8.772997459054814, 7.772483293232052, 6.706401484574139, 5.722126410182002, 4.780032894885649, 3.8327083049869897, 4.764565985265514, 5.715227940557263, 6.706484252300711, 8.591374502713043, 9.58750532808535, 10.554007115529723, 11.570259685625112, 12.597000873655446, 13.583271637492853, 14.592522888556, 13.657686300163528, 12.632013967795686, 11.6673109710081, 10.671664965865693, 9.631938773458668, 8.672275495963923, 7.608547114822243, 6.654938391832465, 5.717198986513681, 4.835324354582297, 5.766790037060844, 6.756599103786362, 7.667036464381408, 9.597866547423155, 10.540840498797042, 11.587492606156191, 12.539459693119838, 13.52285077927587, 14.51903703622089, 15.288862366391676, 14.35345615816483, 13.383654466251532, 12.448258954007597, 11.494941361739844, 10.512092291956394, 9.49969898212327, 8.566146137353709, 7.643640386994118, 6.7031303646980405, 5.891527059462918, 6.718484278724084, 7.673401195867206, 8.66132043762316, 10.564497972619591, 11.514659722002596, 12.495632584065369, 12.591516569994367, 13.533415049767601, 14.568025250691456, 15.486169712261228, 15.27972543926355, 14.362814215546248, 13.471092628666483, 12.444247819704458, 11.399123240873276, 10.467975242767013, 9.521005856991628, 8.595805413588163, 7.662833955420276, 6.9106720101700825, 7.7890987322311425, 8.703171133211473, 9.67296865301498, 11.519071066971051, 12.48415510881909, 12.472419717713043, 11.575421172945088, 12.508693433893502, 13.496247337620705, 14.465657463527823, 15.523070355646105, 15.40552526718642, 14.41066784494702, 13.41437362862304, 12.42462382407794, 11.42237860079334, 10.502681914383873, 9.611888744200863, 8.63560779461945, 7.908917484930734, 8.789906928914197, 9.728125057031072, 10.605430864595235, 12.526271857129768, 12.466566730782334, 11.536952908062656, 10.644123858743141, 11.595727635456315, 12.590463629732536, 13.56411748342155, 14.605565766930601, 15.535494996184585, 15.464149492301893, 14.422426587624273, 13.45050170944153, 12.397307211461586, 11.50180851411375, 10.603024572518859, 9.57910633459284, 8.960638210457308, 9.760231307205455, 10.72521737382168, 11.591719356007772, 12.56972397079906, 11.634662303305436, 10.597495964791037, 9.671200475524358, 10.660531952019259, 11.724941267380682, 12.760988056911374, 13.628977139319618, 14.582795533236819, 15.511572722526878, 15.347336469101677, 14.337779360331208, 13.390377935353847, 12.440644469757467, 11.456650799935368, 10.5166331239527, 9.926777401965142, 10.748681420073327, 11.732918154275303, 12.530314760000726, 11.62387470325179, 10.665841322711863, 9.67029303147993, 8.708501388707646, 9.768293790865055, 10.774219862171098, 11.72371693751749, 12.61941371657854, 13.649809928895612, 14.57647020290538, 15.4498003943552, 15.287380307867238, 14.349379610097186, 13.458485569013456, 12.40850318777238, 11.497214224868381, 10.906463649046792, 11.73133177838097, 12.70217376773089, 12.619090037430093, 10.640439338981757, 9.755804826766212, 8.773742256135158, 7.782731409742799, 8.833709077897934, 9.773055025894239, 10.674463188676318, 11.657084558098012, 12.624507238496935, 13.568963992151396, 14.494314112385112, 15.430521982524896, 15.28007021534486, 14.4532609347454, 13.423549892793554, 12.434809639757416, 11.92982053781853, 12.802726987661513, 12.503965071114674, 11.569825006868358, 9.709684531462875, 8.831009824856322, 7.808585531874493, 6.824798602343322, 7.824557011804766, 8.823513491305592, 9.715682257408531, 10.697696204843448, 11.652117405759721, 12.690115056576555, 13.615616506871747, 14.680584223158428, 15.588742282362004, 15.47025208435505, 14.456700212592022, 13.42653151688404, 12.89284442765754, 12.52585483289139, 11.563749554082028, 10.638263777101574, 8.731220262367225, 7.784346976969091, 6.808305970143802, 5.892614503984307, 6.822971857228194, 7.778095899016939, 8.724901159475502, 9.741376406880496, 10.729236832371349, 11.717279642154496, 12.60596687735519, 13.611584440046398, 14.540153657508993, 15.443147517144968, 14.436774529978598, 13.441813731455435, 12.477663703489615, 11.629624939378798, 10.673893753467315, 9.674053386135817, 7.759972555380288, 6.790168858015398, 5.828992825286116, 4.892077645302666, 5.889035592176552, 6.87870167662428, 7.772358175556074, 8.727381907267189, 9.71352629724251, 10.696553420735237, 11.633884999441579, 12.675490573132445, 13.717908949282943, 14.604244861912518, 13.543808015101533, 12.506284867703545, 11.515421749902375, 10.651452113494193, 9.674860232551213, 8.724161923269008, 6.732219560705437, 5.939825771566928, 4.951581504953103, 3.959385933135468, 4.921444118774667, 5.80921150536517, 6.764731587554299, 7.795988014334236, 8.754018241040718, 9.80281724775664, 10.75508069019478, 11.712034950119634, 12.759459529775123, 13.588988064423216, 12.603966390373076, 11.541797530492838, 10.548777014945074, 9.618174258662686, 8.605683418005757, 7.7517567944022066], [5.772654546123373, 6.7213748771593504, 7.71471721270334, 8.67450936624491, 9.705066201076463, 10.709764516165313, 11.695619770771119, 12.691320565591013, 11.76145783219706, 10.694613430521384, 9.707047593584134, 8.680572003297982, 7.716629330657588, 6.726636432015485, 5.770036901160907, 4.902275385783106, 3.9458548545313947, 2.9688944827353603, 3.943723925040884, 4.788359095714938, 4.800254898125935, 5.745338992479194, 6.723796199272376, 7.782334060369006, 8.717487465094306, 9.694700678045109, 10.755726566693182, 11.690952298247874, 10.806447735985877, 9.785331706790327, 8.831226448781546, 7.9015934393802825, 6.862869421407557, 5.881592945042804, 4.843071508348171, 3.8367016270106595, 2.8737412558654265, 2.025147691910046, 3.0109277935182175, 3.8596647919220546, 3.905904879686501, 4.946611494060058, 5.982440777298532, 6.93487495709148, 7.933811515991087, 8.932281134015097, 9.981494847533114, 10.927780277155604, 9.957953961517033, 9.005125014958965, 7.964379874183851, 6.984971468063461, 5.927535489835335, 4.978951493762628, 4.005951603895861, 2.949679623323142, 1.8917958382556819, 1.0548694213350307, 2.018884296051466, 2.9218982411103642, 2.9999283492100948, 4.038336501908072, 5.02255316872712, 5.9723643330991925, 6.980861619926418, 8.049618102938512, 9.033237606048289, 10.032322405568063, 9.18430333736945, 8.238206270465467, 7.192332259583571, 6.138648035679075, 5.175016987015683, 4.129908418230169, 3.0817942972600427, 2.0076210909193444, 0.9381296219895504, 0.0, 0.9975363292153325, 1.9350441689505247, 3.8171938825973406, 4.848878081891336, 5.816720655945663, 6.856403356824967, 7.820610223288245, 8.754258151996797, 9.743309797271818, 10.68604571089464, 10.08289753493684, 9.051397563335774, 7.98405551713763, 7.0072370490759, 6.014268994698235, 4.9894445675472525, 3.9260356823719667, 2.9692053264244302, 1.9183430431605375, 0.9614652207504533, 1.9387021252887657, 2.8792932785691523, 4.764236423197831, 5.719442424694561, 6.710849438297813, 7.738774639796489, 8.767549851275, 9.6878504628197, 10.728110289668658, 11.611294351679886, 10.950992302518365, 9.96534044889836, 9.030750460040565, 8.004304382218637, 6.933773928508293, 5.962362727794137, 4.896032716379522, 3.84884552243238, 2.8740715796368748, 2.0095261551824244, 2.8732608378127753, 3.8540866780703693, 5.757438511321194, 6.7330240075029835, 7.743112033149901, 8.72797806878518, 9.704250320639254, 10.720240153289362, 11.734457093483442, 12.557388298396196, 11.714450636060043, 10.70076175980856, 9.694976569623735, 8.729195565836205, 7.7987150274057395, 6.752877361323827, 5.745060581024176, 4.766350922520118, 3.8069056091541205, 2.9441460188289863, 3.837379153521938, 4.842733089915756, 6.724644824619336, 7.715312407518092, 8.662923106423225, 9.67460262354871, 10.695359664076687, 11.66309895280366, 12.64975901137094, 13.503897080836296, 12.656266526288308, 11.717409405655621, 10.666805550291354, 9.711127081044365, 8.710612915221603, 7.644531106563688, 6.660256032171552, 5.718162516875199, 4.770837926976539, 3.8893675675468766, 4.777098318567713, 5.768354630311161, 7.653244880723493, 8.6493757060958, 9.615877493540172, 10.632130063635561, 11.658871251665895, 12.645142015503302, 13.654393266566448, 14.57257731207688, 13.570143589785236, 12.605440592997649, 11.609794587855243, 10.570068395448217, 9.610405117953473, 8.546676736811794, 7.593068013822014, 6.655328608503231, 5.7734539765718464, 4.891591619342206, 5.818469481796813, 6.728906842391859, 8.659736925433606, 9.602710876807492, 10.649362984166642, 11.601330071130288, 12.584721157286321, 13.58090741423134, 14.587606814485204, 15.29158578015438, 14.321784088241081, 13.386388575997147, 12.433070983729394, 11.450221913945944, 10.43782860411282, 9.504275759343258, 8.581770008983668, 7.64125998668759, 6.829656681452468, 5.843285861005446, 6.766391905161441, 7.754311146917396, 9.626368350630042, 10.576530100013047, 11.55750296207582, 12.565289408547862, 13.507187888321097, 14.536846042576087, 15.482490668339958, 16.2178550612531, 15.300943837535797, 14.409222250656033, 13.382377441694008, 12.337252862862826, 11.406104864756562, 10.459135478981178, 9.533935035577713, 8.600963577409825, 7.848801632159632, 6.913900314512505, 7.796161842505708, 8.765959362309216, 10.580941444981502, 11.54602548682954, 12.022659347729743, 12.513550794934638, 13.446823055883051, 14.434376959610255, 15.403787085517372, 16.461199977635655, 16.34365488917597, 15.348797466936569, 14.352503250612589, 13.36275344606749, 12.36050822278289, 11.440811536373422, 10.550018366190413, 9.573737416609, 8.847047106920284, 7.91470851119556, 8.821115766325308, 9.69842157388947, 11.588142235140218, 12.016806360799034, 11.087192538079355, 11.582253480732692, 12.533857257445867, 13.528593251722087, 14.5022471054111, 15.543695388920153, 16.47362461817414, 16.402279114291442, 15.360556209613822, 14.38863133143108, 13.335436833451135, 12.439938136103299, 11.541154194508408, 10.51723595658239, 9.855279472833573, 8.885032889486817, 9.850018956103042, 10.684710065302008, 11.745862974015903, 11.121850180612755, 10.147735594807736, 10.60933009751391, 11.59866157400881, 12.663070889370236, 13.699117678900928, 14.56710676130917, 15.52092515522637, 16.449702344516428, 16.285466091091227, 15.275908982320757, 14.328507557343396, 13.378774091747017, 12.394780421924917, 11.454762745942249, 10.821418664341406, 9.87348300235469, 10.857719736556666, 11.623305469294962, 10.800013706468633, 10.085173964643529, 9.22053266149663, 9.646631010697197, 10.706423412854607, 11.712349484160649, 12.661846559507042, 13.557543338568092, 14.587939550885164, 15.514599824894932, 16.387930016344754, 16.225509929856788, 15.287509232086736, 14.396615191003006, 13.34663280976193, 12.435343846857931, 11.798622776687504, 10.856133360662332, 11.826975350012253, 11.680960415440541, 9.774665219210824, 9.127006979297459, 8.1560499201003, 8.72086103173235, 9.771838699887484, 10.711184647883789, 11.61259281066587, 12.595214180087563, 13.562636860486487, 14.507093614140947, 15.432443734374663, 16.368651604514447, 16.21819983733441, 15.39139055673495, 14.361679514783104, 13.372939261746966, 12.821979665459242, 11.927528569942876, 11.565835449125123, 10.631695384878807, 8.843910411691942, 8.061556107193805, 7.112539934285629, 7.762928224332872, 8.762686633794315, 9.761643113295142, 10.653811879398082, 11.635825826832999, 12.590247027749273, 13.628244678566109, 14.553746128861297, 15.618713845147978, 16.48616415250514, 15.452945929206605, 14.522390802248445, 13.504590418123918, 12.499726812809282, 11.587725210901839, 10.625619932092476, 9.700134155112023, 7.8654461425962925, 7.014893259306573, 6.045226189648617, 6.830744125973856, 7.761101479217745, 8.71622552100649, 9.663030781465054, 10.679506028870048, 11.667366454360899, 12.655409264144046, 13.54409649934474, 14.549714062035948, 15.44546625181261, 14.505017895155417, 13.498644907989046, 12.503684109465883, 11.539534081500063, 10.691495317389247, 9.735764131477763, 8.735923764146266, 6.821842933390737, 6.0207151403528805, 5.065913044790932, 5.830207267292216, 6.827165214166103, 7.81683129861383, 8.710487797545625, 9.665511529256738, 10.65165591923206, 11.634683042724786, 12.572014621431128, 13.613620195121994, 14.656038571272493, 13.666115239922965, 12.605678393111981, 11.568155245713994, 10.577292127912823, 9.713322491504641, 8.736730610561661, 7.786032301279457, 5.794089938715887, 5.001696149577377, 4.034021941503733, 4.897515555125018, 5.859573740764217, 6.74734112735472, 7.702861209543849, 8.734117636323788, 9.69214786303027, 10.74094686974619, 11.693210312184332, 12.650164572109183, 13.642648569988824, 12.650858442433663, 11.665836768383524, 10.603667908503287, 9.610647392955523, 8.680044636673134, 7.667553796016206, 6.813627172412656], [4.775118216908041, 5.723838547944018, 6.717180883488007, 7.676973037029579, 8.70752987186113, 9.71222818694998, 10.698083441555786, 11.69378423637568, 12.657082216093286, 11.692149759736717, 10.704583922799467, 9.678108332513315, 8.71416565987292, 7.724172761230817, 6.7675732303762395, 5.899811714998438, 4.942179754491032, 3.929987795342191, 2.976787488214844, 3.7908227664996055, 3.8027185689106022, 4.747802663263862, 5.726259870057043, 6.784797731153674, 7.719951135878974, 8.697164348829777, 9.75819023747785, 10.693415969032541, 11.680162975665002, 10.78286803600566, 9.828762777996879, 8.899129768595614, 7.860405750622889, 6.879129274258137, 5.840607837563503, 4.834237956225992, 3.871277585080759, 2.986241004516877, 2.0439913566921772, 2.862128462706722, 2.9083685504711685, 3.949075164844725, 4.984904448083199, 5.937338627876147, 6.936275186775754, 7.934744804799765, 8.983958518317781, 10.00199886303051, 10.955490290732367, 10.0026613441743, 8.961916203399184, 7.982507797278793, 6.925071819050667, 5.97648782297796, 5.003487933111193, 3.9472159525384747, 2.8893321674710144, 2.015962733941861, 1.0519478592254254, 1.9243619118950317, 2.0023920199947622, 3.040800172692739, 4.025016839511787, 4.97482800388386, 5.983325290711085, 7.052081773723179, 8.035701276832956, 9.03478607635273, 9.990958267646299, 9.2357425996808, 8.189868588798904, 7.136184364894407, 6.172553316231015, 5.127444747445502, 4.079330626475375, 3.005157420134677, 1.935665951204883, 0.9975363292153325, 0.0, 0.9375078397351922, 2.866761984709698, 3.898446184003694, 4.866288758058021, 5.905971458937325, 6.870178325400603, 7.803826254109156, 8.792877899384177, 9.735613813006998, 10.718045298906276, 10.048933892551107, 8.981591846352963, 8.004773378291233, 7.011805323913568, 5.986980896762585, 4.923572011587299, 3.9667416556397628, 2.91587937237587, 1.9590015499657858, 1.0199849588766097, 1.9288613806815096, 3.8138045253101884, 4.769010526806919, 5.76041754041017, 6.788342741908846, 7.817117953387355, 8.737418564932058, 9.777678391781016, 10.660862453792245, 11.6337753142278, 10.962876778113692, 10.028286789255898, 9.00184071143397, 7.931310257723625, 6.959899057009469, 5.893569045594854, 4.846381851647712, 3.8716079088522073, 2.8911088818980217, 1.9545436714006192, 2.9036547801827264, 4.807006613433551, 5.78259210961534, 6.792680135262258, 7.777546170897536, 8.753818422751609, 9.769808255401717, 10.7840251955958, 11.606956400508555, 12.565112464883242, 11.698298089023892, 10.692512898839068, 9.726731895051538, 8.796251356621072, 7.750413690539159, 6.7425969102395085, 5.763887251735451, 4.804441938369453, 3.825728745544583, 2.918661987109782, 3.8926970681011013, 5.7742129267316935, 6.76488050963045, 7.712491208535583, 8.724170725661066, 9.744927766189043, 10.712667054916016, 11.699327113483296, 12.553465182948655, 13.506928355111507, 12.658377807092828, 11.598775597855811, 10.643097128608822, 9.64258296278606, 8.576501154128145, 7.59222607973601, 6.650132564439657, 5.702807974540997, 4.770950294262473, 3.858381152155557, 4.849637463899005, 6.702812982835851, 7.698943808208157, 8.665445595652528, 9.681698165747918, 10.708439353778251, 11.694710117615658, 12.703961368678804, 13.622145414189239, 14.502113637349694, 13.537410640562108, 12.541764635419701, 11.502038443012676, 10.542375165517932, 9.478646784376252, 8.525038061386473, 7.587298656067689, 6.705424024136304, 5.773174346057803, 4.8997523153846565, 5.810189675979703, 7.7093050275459625, 8.652278978919849, 9.698931086278998, 10.650898173242645, 11.634289259398678, 12.630475516343697, 13.63717491659756, 14.56531778071436, 15.25375413580554, 14.318358623561606, 13.365041031293853, 12.382191961510403, 11.369798651677279, 10.436245806907717, 9.513740056548126, 8.573230034252049, 7.739390728464246, 6.724868587721043, 5.847674738749285, 6.83559398050524, 8.675936452742398, 9.626098202125403, 10.607071064188176, 11.614857510660219, 12.556755990433453, 13.586414144688444, 14.532058770452315, 15.49158706181308, 16.232913885100256, 15.341192298220491, 14.314347489258466, 13.269222910427285, 12.338074912321021, 11.391105526545637, 10.465905083142172, 9.532933624974284, 8.733965509210934, 7.795483041228101, 6.877444676093552, 7.84724219589706, 9.630509547093858, 10.595593588941897, 11.54497839581281, 12.504661169107965, 13.437933430056379, 14.425487333783582, 15.3948974596907, 16.452310351808983, 17.275624936740428, 16.28076751450103, 15.284473298177048, 14.294723493631949, 13.292478270347349, 12.372781583937881, 11.481988413754872, 10.505707464173458, 9.732210983971587, 8.796291237911156, 7.902398599913152, 8.779704407477315, 10.637710337252575, 11.117936819280752, 11.980445695632145, 12.57857838069233, 13.530182157405504, 14.524918151681725, 15.498572005370738, 16.540020288879788, 17.471160947389468, 17.3342491618559, 16.29252625717828, 15.320601378995539, 14.267406881015594, 13.371908183667758, 12.473124242072867, 11.449206004146848, 10.736862199549169, 9.766615616202413, 8.971135994269716, 9.765992898889852, 10.74832664480057, 10.154913743786715, 11.040988752360526, 11.605654997473547, 12.594986473968447, 13.65939578932987, 14.695442578860563, 15.564643090524502, 16.5184614844417, 17.447238673731764, 17.217436138655685, 16.207879029885216, 15.260477604907855, 14.310744139311476, 13.326750469489376, 12.386732793506708, 11.703001391057002, 10.755065729070285, 9.978836774723339, 10.704588302882806, 9.8024773772533, 9.118237527817488, 10.11378581904942, 10.642955910656834, 11.702748312814244, 12.708674384120286, 13.659382888722375, 14.555079667783424, 15.585475880100496, 16.512136154110266, 17.385466345560083, 17.157479977421247, 16.219479279651193, 15.328585238567465, 14.278602857326389, 13.36731389442239, 12.6802055034031, 11.737716087377928, 10.948092388178926, 10.683424086225209, 8.777128889995492, 8.160070542471418, 9.10509161156549, 9.717185931691986, 10.76816359984712, 11.707509547843427, 12.610129139881202, 13.592750509302896, 14.56017318970182, 15.50462994335628, 16.429980063589994, 17.366187933729776, 16.497144095975127, 15.486602603522366, 14.541502668128908, 13.49877596603521, 12.465214373432959, 11.608992581542577, 10.56829911990979, 9.634159055663474, 7.8463740824766095, 7.094619670367764, 8.061581625750819, 8.75925312429251, 9.759011533753954, 10.75796801325478, 11.651348208613415, 12.633362156048332, 13.587783356964605, 14.625781007781441, 15.55128245807663, 16.446156650860136, 15.488627823289809, 14.455409599991272, 13.524854473033113, 12.507054088908585, 11.50219048359395, 10.590188881686506, 9.628083602877144, 8.70259782589669, 6.86790981338096, 6.047956822480533, 6.994267881113807, 7.827069025933493, 8.758637808433077, 9.713761850221822, 10.660567110680386, 11.67704235808538, 12.664902783576231, 13.652945593359378, 14.541632828560072, 15.376499140059872, 14.447929922597277, 13.507481565940084, 12.501108578773714, 11.50614778025055, 10.54199775228473, 9.693958988173915, 8.738227802262431, 7.738387434930933, 5.824306604175405, 5.05377870352684, 6.014954736256121, 6.826532167251853, 7.824701543381434, 8.814367627829162, 9.708024126760957, 10.663047858472071, 11.649192248447392, 12.632219371940119, 13.56955095064646, 14.60694391647797, 13.67352058004703, 12.668578910707632, 11.608142063896649, 10.570618916498661, 9.57975579869749, 8.715786162289309, 7.739194281346329, 6.7884959720641245, 4.796553609500554, 4.034759712751336, 4.995115254110564, 5.893840455084655, 6.857110069979549, 7.744877456570053, 8.700397538759182, 9.73165396553912, 10.689684192245602, 11.738483198961523, 12.690746641399665, 13.64348829346516, 12.645112240773491, 11.65332211321833, 10.668300439168192, 9.606131579287954, 8.61311106374019, 7.682508307457802, 6.670017466800873, 5.8160908431973235], [3.8376103771728483, 4.786330708208825, 5.7796730437528145, 6.739465197294386, 7.770022032125938, 8.774720347214789, 9.760575601820594, 10.756276396640489, 11.719574376358095, 12.629657599471907, 11.642091762534656, 10.615616172248505, 9.65167349960811, 8.661680600966008, 7.705081070111431, 6.83731955473363, 5.814105078541806, 4.801913119392965, 3.8043431430502164, 2.853314926764413, 2.86521072917541, 3.8102948235286695, 4.788752030321851, 5.847289891418482, 6.782443296143782, 7.759656509094584, 8.820682397742658, 9.75590812929735, 10.74265513592981, 11.720375875740851, 10.76627061773207, 9.836637608330806, 8.79791359035808, 7.816637113993329, 6.778115677298695, 5.771745795961183, 4.808785424815951, 3.8581663285676506, 2.8715470115275497, 1.9246206229715297, 1.970860710735976, 3.0115673251095325, 4.0473966083480075, 4.999830788140955, 5.9987673470405625, 6.997236965064573, 8.04645067858259, 9.064491023295318, 10.034317338933889, 10.940169183909491, 9.899424043134376, 8.920015637013986, 7.862579658785861, 6.913995662713154, 5.940995772846387, 4.884723792273667, 3.8268400072062065, 2.9534705736770532, 1.9894556989606178, 0.9868540721598394, 1.06488418025957, 2.103292332957547, 3.087508999776595, 4.037320164148668, 5.0458174509758935, 6.114573933987987, 7.098193437097764, 8.097278236617539, 9.053450427911107, 9.99954749481509, 9.127376428534095, 8.073692204629598, 7.110061155966207, 6.064952587180693, 5.016838466210567, 3.942665259869869, 2.873173790940075, 1.9350441689505247, 0.9375078397351922, 0.0, 1.9292541449745058, 2.9609383442685013, 3.9287809183228277, 4.968463619202131, 5.932670485665409, 6.866318414373962, 7.855370059648983, 8.798105973271804, 9.780537459171082, 10.81203743077215, 9.919099686088156, 8.942281218026425, 7.9493131636487595, 6.924488736497777, 5.861079851322491, 4.9042494953749545, 3.8533872121110626, 2.896509389700978, 1.9319446942267038, 0.9913535409463173, 2.8762966855749963, 3.831502687071727, 4.822909700674979, 5.850834902173654, 6.879610113652164, 7.799910725196865, 8.840170552045823, 9.723354614057051, 10.696267474492606, 11.681919328112611, 10.965794628991091, 9.93934855116916, 8.868818097458817, 7.897406896744662, 6.831076885330047, 5.783889691382905, 4.8091157485874, 3.803068617248116, 2.8665034067507134, 1.9661469404475342, 3.8694987736983597, 4.845084269880148, 5.855172295527066, 6.8400383311623445, 7.816310583016417, 8.832300415666525, 9.846517355860607, 10.669448560773361, 11.627604625148049, 12.617699355074055, 11.630020738574261, 10.664239734786731, 9.733759196356266, 8.687921530274352, 7.680104749974701, 6.701395091470643, 5.741949778104646, 4.737688480894677, 3.830621722459876, 2.955189228365909, 4.836705086996502, 5.827372669895258, 6.774983368800391, 7.7866628859258755, 8.807419926453852, 9.775159215180825, 10.761819273748104, 11.615957343213461, 12.569420515376313, 13.536622984918854, 12.510735333205906, 11.555056863958917, 10.554542698136155, 9.48846088947824, 8.504185815086105, 7.562092299789751, 6.614767709891091, 5.682910029612567, 4.770340887505651, 3.963534533097838, 5.765305143100659, 6.7614359684729655, 7.7279377559173374, 8.744190326012726, 9.77093151404306, 10.757202277880467, 11.766453528943613, 12.684637574454046, 13.644393825064608, 14.449370375912201, 13.453724370769795, 12.41399817836277, 11.454334900868025, 10.390606519726346, 9.436997796736566, 8.499258391417783, 7.6173837594863985, 6.685134081407897, 5.811712050734751, 4.924086745178536, 6.771797187810771, 7.714771139184657, 8.761423246543806, 9.713390333507451, 10.696781419663484, 11.692967676608504, 12.699667076862369, 13.627809940979166, 14.597611632892464, 15.230318358911699, 14.277000766643946, 13.294151696860496, 12.281758387027372, 11.34820554225781, 10.42569979189822, 9.485189769602142, 8.651350463814339, 7.636828323071137, 6.759634474099379, 5.989550909768529, 7.7384286130072075, 8.688590362390212, 9.669563224452984, 10.677349670925027, 11.619248150698262, 12.64890630495325, 13.594550930717121, 14.554079222077887, 15.57677138218718, 16.253152033570583, 15.22630722460856, 14.181182645777378, 13.250034647671114, 12.30306526189573, 11.377864818492265, 10.444893360324377, 9.64592524456103, 8.707442776578196, 7.789404411443646, 7.001199125160349, 8.693001707358667, 9.658085749206705, 10.607470556077619, 11.567153329372774, 12.50042559032119, 13.487979494048393, 14.45738961995551, 15.514802512073793, 16.578809550476254, 17.19272724985112, 16.19643303352714, 15.206683228982042, 14.204438005697442, 13.284741319287974, 12.393948149104965, 11.417667199523551, 10.644170719321682, 9.70825097326125, 8.814358335263245, 7.933661336740604, 9.700202497517381, 10.593906691890355, 11.523520514610034, 12.49845064357472, 13.476144696385756, 14.470880690661977, 15.44453454435099, 16.48598282786004, 17.523135886112925, 18.246208897205992, 17.204485992528372, 16.232561114345632, 15.179366616365687, 14.283867919017851, 13.38508397742296, 12.361165739496942, 11.648821934899264, 10.678575351552508, 9.883095729619809, 8.919949828153142, 9.81081880506538, 10.772048554625995, 11.745754142601074, 12.47758032152432, 13.46691179801922, 14.531321113380645, 15.567367902911338, 16.502150930259692, 17.45596932417689, 18.384746513466954, 18.129395874005777, 17.119838765235308, 16.172437340257947, 15.222703874661569, 14.23871020483947, 13.298692528856801, 12.614961126407097, 11.66702546442038, 10.801238823075941, 9.858545232146096, 8.864969537518109, 9.823002918058036, 10.818551209289968, 11.514881234707607, 12.574673636865016, 13.580599708171059, 14.596890728457565, 15.492587507518614, 16.522983719835686, 17.449643993845456, 18.322974185295276, 17.446017344720307, 16.49032686148761, 15.516098475824426, 14.46611609458335, 13.498863541189051, 12.51238317108368, 11.569893755058509, 10.583546594187254, 9.745916246490015, 7.8396210502603, 8.907323341948908, 9.889385912579963, 10.58911125574276, 11.640088923897894, 12.5794348718942, 13.547636979616392, 14.530258349038085, 15.49768102943701, 16.44213778309147, 17.367487903325188, 16.51243572402658, 15.559636256239935, 14.549094763787174, 13.603994828393715, 12.561268126300016, 11.527706533697767, 10.671484741807381, 9.630791280174597, 8.69665121592828, 6.908866242741417, 7.922175325203137, 8.88913728058619, 9.631178448343283, 10.630936857804727, 11.629893337305553, 12.588856048348605, 13.570869995783521, 14.525291196699795, 15.563288847516631, 16.46940474302209, 15.508648811124946, 14.551119983554617, 13.51790176025608, 12.58734663329792, 11.569546249173392, 10.564682643858758, 9.652681041951311, 8.690575763141949, 7.765089986161496, 5.930401973645767, 6.8755124773159055, 7.8218235359491795, 8.698994349984266, 9.696145648168267, 10.651269689957012, 11.598074950415576, 12.61455019782057, 13.602410623311423, 14.59045343309457, 15.459755113505533, 14.43899130032468, 13.510422082862085, 12.569973726204893, 11.563600739038522, 10.568639940515359, 9.604489912549539, 8.756451148438721, 7.800719962527237, 6.80087959519574, 4.886798764440212, 5.881334358362213, 6.842510391091494, 7.6984574913026265, 8.762209383116625, 9.751875467564355, 10.645531966496149, 11.600555698207263, 12.586700088182583, 13.56972721167531, 14.507058790381652, 13.669436076742778, 12.73601274031184, 11.731071070972442, 10.670634224161457, 9.63311107676347, 8.6422479589623, 7.778278322554115, 6.801686441611136, 5.850988132328932, 3.8590457697653617, 4.862315367586709, 5.867040578161337, 6.765765779135429, 7.7946179097147406, 8.682385296305245, 9.637905378494374, 10.66916180527431, 11.627192031980792, 12.675991038696713, 13.628254481134855, 12.705980453729968, 11.707604401038301, 10.71581427348314, 9.730792599433, 8.668623739552762, 7.675603224004998, 6.745000467722609, 5.732509627065681, 4.878583003462131], [3.968138058148054, 4.916858389184031, 5.91020072472802, 6.831183220210237, 7.81351728192975, 8.8182155970186, 9.804070851624406, 10.7997716464443, 11.763069626161906, 12.680671604567868, 13.524241476181473, 12.497765885895321, 11.533823213254927, 10.543830314612824, 9.587230783758248, 8.719469268380447, 7.743359223516311, 6.73116726436747, 5.733597288024723, 4.782569071738919, 2.995738410150616, 3.9408225045038754, 4.919279711297057, 5.890785141222294, 6.825938545947594, 7.803151758898395, 8.86417764754647, 9.799403379101161, 10.786150385733622, 11.688517901652618, 12.6426231596614, 11.718787321977622, 10.680063304004896, 9.698786827640145, 8.660265390945511, 7.653895509608, 6.690935138462767, 5.787420473542157, 4.800801156502056, 3.8538747679460355, 1.9780171468879213, 2.9448405278026284, 3.980669811041103, 4.8618912680693285, 5.860827826968935, 6.859297444992945, 7.882128674899736, 8.900169019612465, 9.837008632623094, 10.755342327107716, 11.781573756781192, 10.802165350660802, 9.744729372432676, 8.796145376359968, 7.8231454864932015, 6.766873505920483, 5.7089897208530225, 4.8720633039323715, 3.9187098439351233, 2.916108217134345, 0.9450233002655044, 1.9834314529634813, 2.9495694797049685, 3.8993806440770413, 4.907877930904267, 5.9410725952030825, 6.9246920983128595, 7.899506718052573, 8.85567890934614, 9.801775976250124, 10.84764998713202, 9.905999444040836, 8.942368395377445, 7.897259826591932, 6.898988179857383, 5.824814973516685, 4.755323504586891, 3.8171938825973406, 2.866761984709698, 1.9292541449745058, 0.0, 1.0316841992939958, 1.9995267733483222, 3.0392094742276257, 4.003416340690904, 4.937064269399457, 5.926115914674478, 6.868851828297298, 7.851283314196577, 8.882783285797643, 9.950125331995787, 8.98844397036204, 7.995475915984375, 6.970651488833393, 5.907242603658107, 4.95041224771057, 3.882714516137319, 2.8557286618468876, 1.8784917573085749, 0.9379006040281884, 0.9470425406004905, 1.902248542097221, 2.8936555557004726, 3.9215807571991483, 4.950355968677658, 5.870656580222359, 6.910916407071317, 7.7941004690825455, 8.7670133295181, 9.752665183138106, 10.6872551719959, 9.90575350306122, 8.835223049350876, 7.863811848636721, 6.797481837222106, 5.750294643274964, 4.7755207004794595, 3.749615680329987, 2.8130504698325844, 1.877670651311409, 1.9402446287238537, 2.915830124905643, 3.925918150552561, 4.910784186187839, 5.8870564380419115, 6.90304627069202, 7.917263210886102, 8.740194415798856, 9.698350480173543, 10.68844521009955, 11.59642569046632, 10.63064468667879, 9.700164148248325, 8.654326482166411, 7.64650970186676, 6.6678000433627025, 5.708354729996705, 4.684235543976548, 3.7771687855417473, 2.866712939229784, 2.9074509420219954, 3.8981185249207515, 4.8457292238258844, 5.857408740951369, 6.878165781479346, 7.845905070206319, 8.832565128773599, 9.686703198238956, 10.640166370401808, 11.607368839944348, 12.457282396287777, 11.501603927040788, 10.501089761218026, 9.435007952560111, 8.450732878167976, 7.508639362871622, 6.561314772972962, 5.629457092694438, 4.716887950587522, 3.875058243961713, 3.8360509981261526, 4.832181823498459, 5.798683610942831, 6.81493618103822, 7.841677369068555, 8.827948132905961, 9.837199383969107, 10.75538342947954, 11.715139680090102, 12.570430890293702, 13.400271433851666, 12.36054524144464, 11.400881963949896, 10.337153582808217, 9.383544859818437, 8.445805454499654, 7.5639308225682695, 6.631681144489768, 5.758259113816622, 4.835610456042411, 4.842543042836264, 5.785516994210151, 6.8321691015693, 7.784136188532947, 8.76752727468898, 9.763713531634, 10.770412931887863, 11.698555796004662, 12.66835748791796, 13.540533322317835, 14.223547829725817, 13.240698759942367, 12.228305450109243, 11.294752605339681, 10.37224685498009, 9.431736832684013, 8.59789752689621, 7.583375386153008, 6.70618153718125, 5.9010746206324045, 5.809174468032701, 6.759336217415705, 7.740309079478477, 8.74809552595052, 9.689994005723754, 10.719652159978747, 11.665296785742617, 12.624825077103383, 13.647517237212677, 14.56336699697672, 15.17285428769043, 14.127729708859249, 13.196581710752985, 12.249612324977601, 11.324411881574136, 10.391440423406248, 9.5924723076429, 8.653989839660067, 7.735951474525517, 6.8340626746006485, 6.763747562384161, 7.728831604232199, 8.678216411103111, 9.637899184398266, 10.571171445346682, 11.558725349073885, 12.528135474981003, 13.585548367099285, 14.649555405501747, 15.554287497692291, 16.142980096609012, 15.153230292063913, 14.150985068779313, 13.231288382369845, 12.340495212186836, 11.364214262605422, 10.590717782403553, 9.654798036343122, 8.760905398345116, 7.766524886180903, 7.770948352542876, 8.664652546915848, 9.594266369635527, 10.569196498600213, 11.546890551411249, 12.54162654568747, 13.515280399376483, 14.556728682885534, 15.59388174113842, 16.565239635544486, 17.151033055610245, 16.179108177427505, 15.125913679447558, 14.230414982099722, 13.331631040504831, 12.307712802578813, 11.595368997981135, 10.62512241463438, 9.787508902088849, 8.745120825337022, 8.78176946488814, 9.627675622409885, 10.533723312907146, 11.475462774346783, 12.464794250841683, 13.502789187226679, 14.53883597675737, 15.531818685126591, 16.546581204086188, 17.52371000366825, 18.07594293708765, 17.06638582831718, 16.11898440333982, 15.16925093774344, 14.18525726792134, 13.245239591938672, 12.561508189488968, 11.613572527502251, 10.626409820259822, 9.683716229329976, 9.72761873243541, 10.664351838379112, 11.460926246218252, 12.422717888990537, 13.402234274849622, 14.408160346155665, 15.461023950325329, 16.50537856227303, 17.479566808427393, 18.443096254235304, 18.454261286919788, 17.537735367636156, 16.58204488440346, 15.607816498740279, 14.557834117499203, 13.590581564104903, 12.642781445385356, 11.785152353187907, 10.798805192316653, 9.961174844619414, 9.768875195234806, 10.836577486923414, 11.818640057554468, 12.518365400717267, 13.569343068872401, 14.508689016868708, 15.42978669326321, 16.412408062684904, 17.37983074308383, 18.32428749673829, 17.4987750049497, 16.60415374694243, 15.651354279155786, 14.640812786703025, 13.695712851309567, 12.652986149215868, 11.619424556613618, 10.885798930694234, 9.846049878303996, 8.91190981405768, 8.838120387715923, 9.851429470177642, 10.818391425560696, 11.56043259331779, 12.560191002779234, 13.55914748228006, 14.471005761995423, 15.45301970943034, 16.40744091034661, 17.445438561163446, 16.561122765937938, 15.600366834040797, 14.642838006470468, 13.609619783171931, 12.679064656213772, 11.661264272089245, 10.656400666774609, 9.866995230838164, 8.905834361271348, 7.980348584290895, 7.859656118620274, 8.804766622290412, 9.751077680923684, 10.628248494958774, 11.578295361815085, 12.53341940360383, 13.480224664062394, 14.496699911467388, 15.48456033695824, 16.47260314674139, 15.551473136421382, 14.530709323240531, 13.602140105777936, 12.661691749120743, 11.655318761954373, 10.66035796343121, 9.69620793546539, 8.886978829413927, 7.999097680034134, 7.016138193325139, 6.816052909414719, 7.810588503336719, 8.771764536066, 9.627711636277134, 10.644359096763443, 11.634025181211172, 12.527681680142965, 13.482705411854079, 14.4688498018294, 15.451876925322127, 14.623851635107822, 13.71293132654659, 12.782477753786191, 11.777536084446792, 10.762352247077308, 9.72482909967932, 8.73396598187815, 7.908806003529321, 6.932214122586342, 6.066246730458331, 5.788299914739868, 6.791569512561216, 7.796294723135842, 8.695019924109936, 9.676767623361558, 10.564535009952062, 11.52005509214119, 12.551311518921128, 13.509341745627609, 14.55814075234353, 13.679268486230816, 12.74947570353378, 11.754069414512651, 10.76227928695749, 9.777257612907352, 8.760341762468613, 7.767321246920849, 6.875528148697815, 5.863037308040886, 5.04288998260854], [4.917723571237746, 3.9762757135672038, 4.969618049111193, 5.799499020916242, 6.781833082635755, 7.786531397724605, 8.772386652330411, 9.768087447150306, 10.731385426867911, 11.648987405273873, 12.636553242211123, 13.482854865394723, 12.565507412548921, 11.57551451390682, 10.618914983052242, 9.751153467674442, 8.775043422810306, 7.762851463661465, 6.765281487318718, 5.814253271032914, 3.945323923240307, 3.0002398288870475, 3.978697035680229, 4.859100941928299, 5.794254346653599, 6.7714675596044005, 7.832493448252474, 8.767719179807166, 9.754466186439627, 10.656833702358623, 11.610938960367404, 12.540571969768669, 11.711747503298891, 10.73047102693414, 9.691949590239506, 8.685579708901995, 7.722619337756763, 6.8191046728361515, 5.8324853557960505, 4.885558967240031, 3.009701346181917, 1.999584007098235, 2.967010442875292, 3.8302070687753336, 4.82914362767494, 5.8276132456989505, 6.85044447560574, 7.868484820318469, 8.8053244333291, 9.72365812781372, 10.764403268588836, 11.743811674709226, 10.776413571726673, 9.827829575653965, 8.854829685787198, 7.7985577052144786, 6.740673920147018, 5.903747503226367, 4.950394043229119, 3.947792416428341, 1.9767074995595002, 1.0381749322590879, 1.9178852804109732, 2.8676964447830464, 3.8761937316102717, 4.909388395909087, 5.893007899018864, 6.867822518758578, 7.823994710052146, 8.770091776956129, 9.815965787838024, 10.825351355251318, 9.974052594671441, 8.928944025885928, 7.930672379151379, 6.856499172810681, 5.787007703880887, 4.848878081891336, 3.8984461840036935, 2.9609383442685013, 1.0316841992939958, 0.0, 0.9678425740543265, 2.0075252749336303, 2.9717321413969087, 3.9053800701054615, 4.894431715380483, 5.837167629003303, 6.819599114902582, 7.851099086503649, 8.918441132701792, 9.895259600763524, 9.02716011527837, 8.002335688127388, 6.938926802952102, 5.982096447004565, 4.9143987154313145, 3.8874128611408834, 2.9101759566025707, 1.969584803322184, 1.954715501548904, 0.9995095000521735, 1.9909165136554252, 3.0065386452773164, 4.035313856755826, 4.838972380928364, 5.8792322077773225, 6.762416269788551, 7.735329130224105, 8.720980983844111, 9.655570972701906, 10.682017050523836, 9.866907248644873, 8.895496047930717, 7.829166036516103, 6.781978842568961, 5.807204899773456, 4.781299879623983, 3.8447346691265802, 2.885343612259822, 2.9479175896722674, 2.0132500389243444, 3.023179108507513, 3.995742074266007, 4.97201432612008, 5.8897712765283625, 6.885579011592107, 7.708510216504862, 8.66666628087955, 9.656761010805555, 10.604238329923605, 11.570019333711135, 10.731848347542321, 9.686010681460408, 8.678193901160757, 7.699484242656699, 6.7400389292907015, 5.715919743270545, 4.8088529848357435, 3.874385900178197, 3.915123902970409, 3.0243119595626613, 3.9719226584677942, 4.983602175593279, 6.004359216121256, 6.875233952370368, 7.839146352416851, 8.655018998944962, 9.608482171107815, 10.575684640650355, 11.635286849887372, 12.533288126334783, 11.53277396051202, 10.466692151854106, 9.482417077461971, 8.540323562165618, 7.592998972266959, 6.661141291988435, 5.748572149881518, 4.882731204910126, 4.843723959074566, 4.097245928484247, 4.924877045584741, 5.94112961568013, 6.967870803710465, 7.85727701507001, 8.84378060761236, 9.723699230185547, 10.683455480796109, 11.538746690999709, 12.534392696142115, 13.392229440738637, 12.432566163243893, 11.368837782102213, 10.415229059112434, 9.47748965379365, 8.595615021862265, 7.663365343783765, 6.7899433131106175, 5.843283416990824, 5.850216003784678, 5.0714361689902585, 5.959996280763084, 6.9103296231748566, 7.89372070933089, 8.869073115416265, 9.776994155531115, 10.666871596710667, 11.636673288623966, 12.508849123023841, 13.462166715291595, 14.272382959236364, 13.25998964940324, 12.326436804633678, 11.403931054274087, 10.46342103197801, 9.629581726190207, 8.615059585447005, 7.737865736475246, 6.908747581580817, 6.816847428981115, 6.140344552012996, 7.017679253012114, 7.908532387525451, 8.837681704824288, 9.825011743761012, 10.714811359245354, 11.593140877809388, 12.615833037918682, 13.531682797682727, 14.411473173256208, 15.159413908153246, 14.228265910046982, 13.281296524271598, 12.356096080868133, 11.423124622700245, 10.624156506936897, 9.685674038954064, 8.767635673819512, 7.841735635549062, 7.771420523332575, 7.10983993882949, 7.955586584636747, 8.915269357931901, 9.848541618880315, 10.836095522607518, 11.73532360797876, 12.573329859920541, 13.637336898323003, 14.522603298398298, 15.386856696782392, 16.184914491357908, 15.18266926807331, 14.262972581663842, 13.372179411480833, 12.395898461899419, 11.62240198169755, 10.686482235637119, 9.792589597639111, 8.774197847129317, 8.77862131349129, 8.04566088151314, 8.891053394287136, 9.846566672133847, 10.824260724944882, 11.818996719221103, 12.743679897349395, 13.643034301045832, 14.645150833165916, 15.576084945753172, 16.394909655783625, 17.2107923767215, 16.157597878741555, 15.262099181393719, 14.363315239798828, 13.33939700187281, 12.627053197275131, 11.656806613928376, 10.795181863037262, 9.752793786285435, 9.789442425836553, 9.008683957007177, 9.830510337558755, 10.772249798998391, 11.759456408381938, 12.780159360760312, 13.793253534124776, 14.655008301225102, 15.597850296113684, 16.574979095695745, 17.437108438328625, 17.372222617789323, 16.42482119281196, 15.46199597586432, 14.478002306042221, 13.53947846572659, 12.590783493173014, 11.960262520520383, 10.960520614797073, 10.69138919027839, 10.735291693383825, 10.045360172976403, 10.75771327086986, 11.719504913642146, 12.696896432389877, 13.70282250369592, 14.755686107865584, 15.66457172396618, 16.53083590045489, 17.4943653462628, 17.422577087625793, 16.506051168342164, 15.550360685109466, 14.576132299446284, 13.526149918205208, 12.558897364810909, 11.611097246091362, 10.97761216221274, 9.991265001341485, 10.818839447404015, 10.735272221886063, 11.003527158322473, 11.82219601226619, 12.645274892606993, 13.696252560762128, 14.670358142292528, 15.718931712579693, 16.62690088244671, 17.556138590853568, 17.39244092588942, 16.467090805655705, 15.572469547648437, 14.619670079861791, 13.60912858740903, 12.664028652015572, 11.621301949921873, 10.587740357319623, 9.945216255077408, 9.038509687328826, 9.76957441684228, 9.8060094827088, 10.821081346898517, 11.827764017650221, 12.592116792611785, 13.59187520207323, 14.590831681574056, 15.502689961289418, 16.484703908724335, 17.382800777923205, 16.482412865616023, 15.529438566643945, 14.568682634746802, 13.611153807176473, 12.577935583877936, 11.647380456919777, 10.62958007279525, 9.624716467480614, 8.926412555221338, 8.024200217153489, 8.838013187075497, 8.827545213613151, 9.774418499011286, 10.760450273013209, 11.659932694252769, 12.60997956110908, 13.565103602897825, 14.511908863356389, 15.528384110761383, 16.43899011471242, 15.450947304929272, 14.519788937127387, 13.499025123946536, 12.570455906483941, 11.630007549826749, 10.623634562660378, 9.628673764137215, 8.664523736171395, 7.9463961537971, 7.058515004417306, 7.873802796109739, 7.8477371087087135, 8.842272702630714, 9.803448735359995, 10.659395835571129, 11.676043296057438, 12.665709380505167, 13.55936587943696, 14.514389611148074, 15.489913818338037, 14.52949901452017, 13.592167435813828, 12.681247127252595, 11.750793554492196, 10.745851885152797, 9.730668047783313, 8.693144900385326, 7.702281782584155, 6.968223327912494, 5.991631446969515, 6.923911333242931, 6.819984114033863, 7.823253711855211, 8.827978922429837, 9.72670412340393, 10.708451822655553, 11.596219209246057, 12.551739291435185, 13.582995718215123, 14.49443072512701, 13.67045251837318, 12.647584286936821, 11.717791504239784, 10.722385215218656, 9.730595087663495, 8.745573413613357, 7.728657563174618, 6.735637047626854, 5.934945473080988, 4.922454632424059, 5.900554585393141], [5.813808012154352, 4.872360154483811, 4.064805642521737, 4.831656446861915, 5.813990508581428, 6.8186888236702785, 7.804544078276084, 8.800244873095979, 9.763542852813583, 10.681144831219546, 11.668710668156796, 12.515012291340396, 13.47895496398079, 12.543357087961144, 11.586757557106568, 10.70998386034167, 9.67148292593107, 8.65929096678223, 7.661720990439481, 6.710692774153678, 4.841408364156914, 3.896324269803655, 3.0339993315128955, 3.891258367873972, 4.826411772599272, 5.803624985550074, 6.864650874198147, 7.799876605752838, 8.786623612385299, 9.688991128304297, 10.643096386313077, 11.572729395714342, 12.611453413687068, 11.698313600988465, 10.659792164293831, 9.65342228295632, 8.690461911811088, 7.715544175956915, 6.728924858916814, 5.7819984703607945, 3.9363750623883984, 2.895668448014842, 1.9991678688209658, 2.8623644947210067, 3.8613010536206134, 4.8597706716446245, 5.882601901551413, 6.900642246264142, 7.837481859274773, 8.755815553759394, 9.79656069453451, 10.7759691006549, 11.744256145780998, 10.79567214970829, 9.822672259841523, 8.766400279268804, 7.708516494201344, 6.871590077280693, 5.918236617283445, 4.915634990482667, 2.9445500736138266, 1.9342593731756947, 0.9500427063566466, 1.8998538707287196, 2.908351157555945, 3.9415458218547603, 4.925165324964537, 5.899979944704251, 6.856152135997819, 7.802249202901802, 8.848123213783698, 9.85750878119699, 10.821139829860382, 9.896786599940254, 8.898514953205705, 7.824341746865007, 6.754850277935213, 5.816720655945662, 4.86628875805802, 3.9287809183228277, 1.9995267733483222, 0.9678425740543265, 0.0, 1.0396827008793037, 2.003889567342582, 2.9375374960511347, 3.926589141326156, 4.869325054948976, 5.851756540848255, 6.883256512449322, 7.9505985586474655, 8.927417026709197, 9.920385081086861, 8.970178262181715, 7.9067693770064285, 6.949939021058892, 5.882241289485641, 4.855255435195209, 3.878018530656897, 2.9374273773765105, 2.9225580756032308, 1.9673520741065, 1.0466983289423757, 2.0386960712229896, 3.0674712827014994, 3.8711298068740367, 4.911389633722996, 5.794573695734224, 6.767486556169779, 7.753138409789784, 8.687728398647579, 9.714174476469509, 10.784704930179853, 9.863338621985044, 8.797008610570428, 7.749821416623287, 6.775047473827782, 5.749142453678309, 4.812577243180907, 3.853186186314149, 3.915760163726594, 2.981092612978671, 2.0789609237944635, 3.02789950021168, 4.004171752065753, 4.921928702474036, 5.91773643753778, 6.740667642450535, 7.698823706825223, 8.688918436751228, 9.636395755869279, 10.602176759656809, 11.532657298087274, 10.653853255514736, 9.646036475215086, 8.667326816711027, 7.707881503345028, 6.683762317324871, 5.7766955588900695, 4.842228474232524, 4.882966477024736, 3.9921545336169872, 3.0701119241137906, 4.051992597764199, 5.05983838104861, 5.907391378316041, 6.871303778362524, 7.687176424890636, 8.640639597053488, 9.607842066596028, 10.667444275833045, 11.623122745080034, 12.46475163394926, 11.434534725908433, 10.450259651516298, 9.508166136219945, 8.560841546321285, 7.628983866042761, 6.716414723935844, 5.850573778964453, 5.811566533128893, 5.00185132532749, 4.023066311230737, 5.0393188813261265, 6.066060069356461, 6.889434441015683, 7.875938033558032, 8.75585665613122, 9.715612906741782, 10.570904116945382, 11.566550122087788, 12.574290233956935, 13.40040873729822, 12.33668035615654, 11.383071633166761, 10.445332227847977, 9.563457595916592, 8.63120791783809, 7.757785887164943, 6.8111259910451505, 6.818058577839005, 5.976041565833501, 5.058185546409081, 6.008518888820853, 6.9919099749768865, 7.901230541361938, 8.809151581476787, 9.69902902265634, 10.668830714569639, 11.541006548969515, 12.494324141237268, 13.477173211020718, 14.227832223457566, 13.294279378688005, 12.371773628328414, 11.431263606032337, 10.597424300244532, 9.58290215950133, 8.705708310529571, 7.876590155635144, 7.784690003035442, 7.044949948856239, 6.115868518658109, 7.006721653171447, 7.935870970470284, 8.857169169706685, 9.746968785191026, 10.625298303755061, 11.647990463864355, 12.5638402236284, 13.443630599201882, 14.49962483333412, 15.196108484101309, 14.249139098325925, 13.32393865492246, 12.390967196754572, 11.591999080991222, 10.653516613008389, 9.735478247873838, 8.809578209603389, 8.739263097386901, 8.014445335672733, 7.053775850282743, 8.013458623577897, 8.94673088452631, 9.928947082777434, 10.767481033924431, 11.605487285866214, 12.669494324268676, 13.554760724343971, 14.419014122728065, 15.408763927273164, 16.150511842127635, 15.230815155718169, 14.34002198553516, 13.363741035953746, 12.590244555751875, 11.654324809691444, 10.760432171693438, 9.742040421183644, 9.746463887545616, 8.91885648265281, 7.98924265993313, 8.944755937779842, 9.922449990590877, 10.917185984867098, 11.775837323295066, 12.675191726991505, 13.677308259111589, 14.608242371698845, 15.427067081729298, 16.425358691882057, 16.45004934264989, 15.442582591281242, 14.448957728385087, 13.50916268103212, 12.589080110626517, 12.103132228800263, 11.76302443709159, 10.720636360339762, 10.75728499989088, 9.881879558146847, 8.92869960320475, 9.870439064644387, 10.857645674027934, 11.878348626406307, 12.825410960070446, 13.687165727170775, 14.630007722059357, 15.607136521641417, 16.4692658642743, 16.404380043734992, 15.456978618757631, 14.49415340180999, 13.51015973198789, 12.57163589167226, 11.622940919118683, 11.114682115932391, 11.856605055713679, 11.659231764332716, 11.703134267438152, 10.851450827747788, 9.855902536515856, 10.817694179288141, 11.795085698035873, 12.801011769341915, 13.85387537351158, 14.696729149911853, 15.562993326400564, 16.526522772208473, 16.45473451357147, 15.538208594287838, 14.582518111055139, 13.608289725391954, 12.558307344150878, 11.591054790756578, 10.643254672037033, 10.132031757624748, 10.887349442258092, 11.714923888320623, 11.631356662802672, 11.809617813093858, 10.920385277912185, 11.743464158252989, 12.794441826408123, 13.768547407938524, 14.817120978225688, 15.659058308392382, 16.58829601679924, 16.424598351835094, 15.49924823160138, 14.60462697359411, 13.651827505807464, 12.641286013354703, 11.696186077961242, 10.653459375867543, 9.619897783265294, 9.060636548344204, 9.934594128245433, 10.665658857758888, 10.702093923625409, 11.717165787815127, 11.963895263726856, 12.701396965652465, 13.70115537511391, 14.700111854614736, 15.679806131338188, 16.661820078773104, 16.414958203868874, 15.514570291561698, 14.561595992589618, 13.600840060692475, 12.643311233122146, 11.61009300982361, 10.67953788286545, 9.66173749874092, 8.656873893426285, 8.041832848488134, 8.920284658070095, 9.734097627992105, 9.72362965452976, 10.670502939927895, 11.656534713929817, 12.556372197373532, 13.558252727095805, 14.51337676888455, 15.469677956754095, 16.486153204159088, 15.471147540658093, 14.483104730874945, 13.55194636307306, 12.53118254989221, 11.602613332429614, 10.662164975772422, 9.655791988606051, 8.660831190082888, 7.696681162117067, 7.061816447063897, 7.954599445333914, 8.769887237026348, 8.744176611829477, 9.738712205751478, 10.699888238480758, 11.555835338691892, 12.624316462044163, 13.633551954559492, 14.527208453491285, 15.482232185202399, 14.52207124428371, 13.561656440465843, 12.6243248617595, 11.713404553198266, 10.782950980437871, 9.778009311098472, 8.762825473728986, 7.725302326330999, 6.734439208529828, 6.083643621179291, 6.887715887886122, 7.819995774159539, 7.716423617154627, 8.719693214975974, 9.724418425550603, 10.623143626524694, 11.656724988642278, 12.564061783300382, 13.51958186548951, 14.485499700231554, 13.526588151072684, 12.702609944318853, 11.679741712882494, 10.749948930185456, 9.754542641164331, 8.76275251360917, 7.777730839559031, 6.760814989120291, 5.767794473572527, 5.050365766347785, 5.818539073340666, 6.796639026309748], [6.852449642151283, 5.911001784480742, 4.9304679016562725, 3.970675748114701, 4.953009809834214, 5.957708124923064, 6.806414076237798, 7.802114871057691, 8.750142708983658, 9.641462130340242, 10.629027967277493, 11.475329590461092, 12.439272263101486, 13.429265161743588, 12.626440257985871, 11.7486254903386, 10.710124555928001, 9.69793259677916, 8.700362620436412, 7.749334404150609, 5.880049994153845, 4.934965899800586, 4.034080615523615, 3.0302776691267574, 3.9654310738520575, 4.913972993560702, 5.86652087215986, 6.801746603714552, 7.773223468555374, 8.649308427424993, 9.603413685433773, 10.533046694835038, 11.571770712807764, 12.553047189172515, 11.699474865173135, 10.693104983835624, 9.730144612690392, 8.754185805953846, 7.7675664889137455, 6.820640100357726, 4.97501669238533, 3.9343100780117735, 2.999249152831685, 2.0013837959737923, 2.9767894651424105, 3.9256345470613976, 4.84291920067211, 5.860959545384839, 6.797799158395469, 7.71613285288009, 8.756877993655205, 9.736286399775596, 10.748361928633981, 11.69694592470669, 10.862354960720827, 9.806082980148108, 8.748199195080648, 7.911272778159997, 6.95791931816275, 5.955317691361971, 3.9842327744931305, 2.9729010031726264, 1.9886843363535782, 1.0388731719815052, 2.023839569077742, 2.901863120975457, 3.885482624085234, 4.860297243824947, 5.816469435118515, 6.762566502022498, 7.808440512904394, 8.817826080317685, 9.781457128981076, 10.82656569776659, 9.938197654085009, 8.86402444774431, 7.794532978814517, 6.856403356824966, 5.905971458937325, 4.968463619202132, 3.039209474227626, 2.0075252749336303, 1.0396827008793037, 0.0, 0.9642068664632781, 1.8978547951718312, 2.886906440446852, 3.8296423540696725, 4.812073839968951, 5.843573811570018, 6.9109158577681615, 7.887734325829892, 8.880702380207557, 9.90552680735854, 8.946452077885732, 7.989621721938196, 6.921923990364945, 5.894938136074513, 4.917701231536201, 3.9771100782558144, 3.9622407764825347, 3.007034774985804, 2.026938571842362, 0.999013370343686, 2.027788581822196, 2.8314471059947333, 3.8717069328436917, 4.75489099485492, 5.727803855290475, 6.71345570891048, 7.648045697768275, 8.674491775590205, 9.745022229300549, 10.716433430014705, 9.836691311449734, 8.789504117502592, 7.814730174707086, 6.788825154557613, 5.8522599440602106, 4.892868887193453, 4.955442864605898, 4.020775313857975, 3.0519130073998335, 1.9882167993323767, 2.9644890511864492, 3.8822460015947327, 4.878053736658476, 5.700984941571231, 6.659141005945919, 7.649235735871924, 8.596713054989975, 9.562494058777505, 10.49297459720797, 11.538812263289884, 10.68571917609439, 9.70700951759033, 8.747564204224332, 7.723445018204175, 6.816378259769373, 5.881911175111828, 5.92264917790404, 4.971600112915514, 4.023989414010381, 3.0123098968848963, 4.020155680169306, 4.867708677436738, 5.83162107748322, 6.647493724011332, 7.600956896174184, 8.568159365716724, 9.627761574953741, 10.58344004420073, 11.425068933069957, 12.474217426787737, 11.489942352395602, 10.547848837099249, 9.600524247200589, 8.668666566922065, 7.756097424815148, 6.890256479843757, 6.851249234008197, 5.95572881522408, 4.9769438011273275, 4.07946489426524, 5.0515435135362035, 5.84975174013638, 6.836255332678728, 7.716173955251915, 8.675930205862478, 9.531221416066078, 10.526867421208484, 11.534607533077631, 12.36773357205735, 13.376363057035844, 12.422754334046065, 11.485014928727281, 10.603140296795896, 9.670890618717394, 8.797468588044248, 7.850808691924454, 7.857741278718309, 6.929919055730092, 6.012063036305671, 5.048664901759967, 6.032055987916, 6.861547840482635, 7.769468880597484, 8.659346321777036, 9.629148013690335, 10.50132384809021, 11.454641440357964, 12.437490510141414, 13.381069796587054, 14.314622641356616, 13.411456329207718, 12.47094630691164, 11.637107001123836, 10.622584860380634, 9.745391011408877, 8.916272856514448, 8.824372703914745, 7.99882743875283, 7.054654112582605, 6.046867666110561, 6.976016983409398, 7.817486468827383, 8.707286084311722, 9.585615602875757, 10.608307762985051, 11.524157522749096, 12.403947898322578, 13.459942132454817, 14.39109013056108, 15.288821799205229, 14.363621355801763, 13.430649897633876, 12.631681781870526, 11.693199313887693, 10.775160948753143, 9.849260910482693, 9.778945798266205, 8.968322825569324, 7.992561444207238, 7.06296306315984, 7.996235324108254, 8.889264381898133, 9.727798333045127, 10.56580458498691, 11.629811623389372, 12.515078023464667, 13.379331421848761, 14.36908122639386, 15.345493488587408, 15.580728492263907, 14.570908136944755, 13.591680522258297, 12.779820137405878, 12.694007510570747, 11.800114872572742, 10.781723122062948, 10.78614658842492, 9.857642076577305, 8.928028253857626, 7.994260377361786, 8.971954430172822, 9.950056773418572, 10.736154622415762, 11.635509026112201, 12.637625558232285, 13.56855967081954, 14.387384380849994, 15.385675991002751, 15.58906864390268, 14.58160189253403, 13.587977029637875, 12.648181982284907, 11.728099411879304, 12.695863860490505, 12.802707137970893, 11.760319061219066, 11.781894901631956, 10.820665152071342, 9.867485197129245, 8.96718376058057, 9.907150113609879, 10.911219414957781, 11.785728259191142, 12.647483026291471, 13.590325021180053, 14.567453820762113, 15.429583163394996, 15.54339934498778, 14.595997920010419, 13.633172703062778, 12.649179033240678, 11.710655192925048, 10.76196022037147, 11.707413747622633, 12.663182162448543, 12.69891446521202, 12.727744169179228, 11.790236421672283, 10.79468813044035, 9.929882847397282, 10.844590137617818, 11.85051620892386, 12.859104737985488, 13.65704644903255, 14.52331062552126, 15.486840071329171, 15.459512189292216, 14.677227895540623, 13.721537412307924, 12.747309026644741, 11.697326645403665, 10.730074092009366, 9.782273973289819, 10.72476338931499, 11.693926548992955, 12.633173802113932, 12.54960657659598, 12.748403407018353, 11.84666367275449, 10.85565282636213, 11.88503618371746, 12.85914176524786, 13.907715335535025, 14.619375607513078, 15.548613315919937, 15.429376027555843, 14.504025907322127, 13.711338445507522, 12.79084680706025, 11.780305314607489, 10.83520537921403, 9.79247867712033, 8.75891708451808, 9.799193202406148, 10.741171234980298, 11.583908771552197, 11.62140541007661, 12.650907944518824, 12.797372563292777, 11.813585633761607, 12.81334404322305, 13.808683299836508, 14.78837757655996, 15.681791546347519, 15.419735879589622, 14.519347967282446, 13.566373668310366, 12.707551532605887, 11.782330534374932, 10.749112311076395, 9.818557184118234, 8.800756799993707, 7.795893194679071, 8.780389502550078, 9.72686176480496, 10.652347541785414, 10.714759336903688, 11.661632622301823, 12.647664396303746, 12.745769732120623, 13.812504550335662, 14.767628592124407, 15.723929779993952, 15.501583048919825, 14.47592521637884, 13.487882406595693, 12.556724038793808, 11.636098276282295, 10.7416326336824, 9.801184277025207, 8.794811289858837, 7.799850491335674, 6.835700463369853, 7.80037310112584, 8.761176552068779, 9.761016919400276, 9.782818241826408, 10.777353835748407, 11.738529868477688, 12.594476968688824, 13.662958092041094, 14.673234655438796, 15.422541606958415, 14.468532933379727, 13.482388543404406, 12.521973739586539, 11.584642160880197, 10.700004409368342, 9.81994519583596, 8.815003526496563, 7.901844774981771, 6.864321627583784, 5.873458509782614, 6.905670980160071, 7.926357517883053, 8.85863740415647, 8.755065247151558, 9.758334844972904, 10.763060055547532, 11.661785256521625, 12.69536661863921, 13.603744484179686, 14.41491501895664, 13.44581699935225, 12.48690545019338, 11.66292724343955, 10.64005901200319, 9.736548786355531, 8.79153685656242, 7.79974672900726, 6.916750140811817, 5.899834290373077, 4.906813774825313, 5.9092273831919595, 6.8571807033375975, 7.835280656306679], [7.800016845886009, 6.850372332766458, 5.857029997222469, 4.897237843680897, 4.00926509594981, 4.995721433528525, 5.842207209774519, 6.8379080045944125, 7.785935842520381, 8.677255263876965, 9.664821100814216, 10.511122723997815, 11.47506539663821, 12.465058295280311, 13.421657826134888, 12.71283235680188, 11.67433142239128, 10.662139463242438, 9.66456948689969, 8.713541270613888, 6.844256860617124, 5.899172766263864, 4.9982874819868925, 3.956839764692954, 3.021686359967654, 3.9497661270974245, 4.9023140056965815, 5.837539737251273, 6.809016602092097, 7.685101560961716, 8.639206818970496, 9.568839828371761, 10.607563846344487, 11.588840322709238, 12.627361759403872, 11.657311850298903, 10.69435147915367, 9.718392672417124, 8.731773355377024, 7.7848469668210045, 5.9392235588486075, 4.898516944475051, 3.963456019294963, 2.9655906624370703, 2.0125825986791326, 2.9614276805981197, 3.878712334208832, 4.89675267892156, 5.833592291932192, 6.751925986416813, 7.7926711271919284, 8.772079533312318, 9.784155062170706, 10.732739058243414, 11.70573894811018, 10.770289846611387, 9.712406061543927, 8.875479644623274, 7.922126184626028, 6.919524557825249, 4.948439640956408, 3.937107869635904, 2.952891202816856, 2.003080038444783, 1.059632702614464, 1.9376562545121785, 2.9212757576219555, 3.896090377361669, 4.852262568655238, 5.798359635559221, 6.844233646441117, 7.853619213854409, 8.8172502625178, 9.862358831303315, 10.902404520548288, 9.828231314207589, 8.758739845277795, 7.820610223288244, 6.870178325400603, 5.93267048566541, 4.0034163406909045, 2.9717321413969082, 2.003889567342582, 0.9642068664632781, 0.0, 0.933647928708553, 1.9226995739835742, 2.8654354876063945, 3.847866973505673, 4.8793669451067405, 5.9467089913048845, 6.923527459366615, 7.916495513744279, 8.941319940895262, 9.91065894434901, 8.953828588401473, 7.886130856828222, 6.859145002537791, 5.881908097999479, 4.941316944719093, 4.926447642945813, 3.971241641449082, 2.9911454383056397, 1.963220236806964, 1.0711018837868538, 1.867240239531455, 2.9075000663804134, 3.790684128391642, 4.763596988827196, 5.7492488424472015, 6.683838831304996, 7.710284909126925, 8.78081536283727, 9.752226563551426, 10.80089817791301, 9.753710983965869, 8.778937041170364, 7.753032021020891, 6.8164668105234885, 5.857075753656731, 5.919649731069176, 4.984982180321253, 4.016119873863111, 2.9524236657956546, 2.0630449860821884, 2.9180391351314543, 3.913846870195198, 4.736778075107953, 5.694934139482641, 6.6850288694086455, 7.632506188526695, 8.598287192314224, 9.52876773074469, 10.574605396826604, 11.582422177126254, 10.671216384053608, 9.71177107068761, 8.687651884667453, 7.780585126232651, 6.846118041575106, 6.886856044367318, 5.935806979378792, 4.988196280473659, 3.976516763348174, 3.1187116150650445, 3.9035018109734603, 4.867414211019941, 5.683286857548053, 6.636750029710906, 7.603952499253447, 8.663554708490464, 9.619233177737453, 10.460862066606676, 11.52694387526459, 12.45414921885888, 11.512055703562527, 10.564731113663868, 9.632873433385344, 8.720304291278426, 7.854463346307035, 7.815456100471475, 6.919935681687358, 5.941150667590605, 5.043671760728518, 4.150099448431942, 4.885544873673102, 5.872048466215449, 6.7519670887886365, 7.7117233393991995, 8.567014549602801, 9.562660554745207, 10.570400666614354, 11.403526705594068, 12.467255086735747, 13.386961200509344, 12.44922179519056, 11.567347163259175, 10.635097485180673, 9.761675454507525, 8.815015558387731, 8.821948145181587, 7.8941259221933695, 6.976269902768949, 6.012871768223245, 5.2007697280335226, 5.897340974019357, 6.805262014134205, 7.6951394553137575, 8.664941147227056, 9.537116981626934, 10.490434573894687, 11.473283643678137, 12.416862930123772, 13.350415774893333, 14.375663195670997, 13.43515317337492, 12.601313867587114, 11.586791726843913, 10.709597877872154, 9.880479722977725, 9.788579570378023, 8.963034305216107, 8.018860979045883, 7.011074532573839, 6.14473072352692, 6.853279602364105, 7.743079217848443, 8.621408736412478, 9.644100896521772, 10.55995065628582, 11.4397410318593, 12.49573526599154, 13.426883264097803, 14.373852649873188, 14.78090836028148, 13.800070415572874, 13.595888648333805, 12.657406180350971, 11.73936781521642, 10.81346777694597, 10.743152664729482, 9.9325296920326, 8.956768310670517, 8.027169929623117, 7.1869720935852435, 7.925057515434855, 8.763591466581849, 9.601597718523632, 10.665604756926093, 11.55087115700139, 12.415124555385484, 13.404874359930583, 14.381286622124131, 14.816344546379309, 13.806524191060157, 12.8272965763737, 13.706382232972071, 13.658214377034026, 12.76432173903602, 11.745929988526225, 11.750353454888199, 10.821848943040584, 9.892235120320905, 8.958467243825062, 8.214316105454674, 8.985849906955293, 9.771947755952484, 10.671302159648922, 11.673418691769006, 12.604352804356264, 13.423177514386715, 14.421469124539472, 14.781246213124367, 13.817217946649432, 12.823593083753277, 11.883798036400309, 12.654661507445498, 13.6224259560567, 13.766914004434172, 12.724525927682345, 12.746101768095235, 11.784872018534621, 10.831692063592524, 9.931390627043845, 9.149511788891731, 9.947012548494502, 10.821521392727863, 11.683276159828193, 12.626118154716774, 13.603246954298834, 14.465376296931717, 14.734465245257496, 13.788175489232106, 12.86878875717818, 11.88479508735608, 10.94627124704045, 11.688522315937664, 12.633975843188828, 13.58974425801474, 13.663121331675299, 13.691951035642507, 12.754443288135562, 11.75889499690363, 10.894089713860557, 10.08695181289967, 10.982463528307122, 11.89489787152221, 12.69283958256927, 13.559103759057981, 14.522633204865892, 14.495305322828939, 13.784864297721466, 12.829173814488767, 11.882717082520275, 10.932942699519067, 9.965690146124768, 10.708836068856014, 11.651325484881186, 12.620488644559153, 13.55973589768013, 13.476168672162178, 13.712610273481632, 12.810870539217765, 11.819859692825405, 11.127397858999313, 12.01277095816509, 12.944151620363382, 13.655168741049799, 14.584406449456658, 14.465169161092566, 13.53981904085885, 12.747131579044245, 11.898483209241093, 10.887941716788331, 10.029631309715098, 9.028094731235733, 9.685479180084275, 10.725755297972343, 11.667733330546495, 12.510470867118395, 12.547967505642807, 13.577470040085021, 13.761579429756052, 12.777792500224882, 12.187277718395551, 12.962312492753737, 13.902932551631169, 14.71758467988424, 14.455529013126345, 13.555141100819169, 12.602166801847089, 11.74334466614261, 10.889966936555775, 9.856748713257238, 8.99648098991663, 8.036372854109109, 8.722455290245266, 9.706951598116273, 10.653423860371158, 11.578909637351611, 11.641321432469885, 12.58819471786802, 13.574226491869943, 13.709976598583898, 13.211054756041163, 14.01400135093895, 14.893713649564198, 14.537376182456548, 13.511718349915563, 12.523675540132416, 11.592517172330531, 10.671891409819018, 9.849269035863243, 8.90882067920605, 7.972735095657233, 6.987194334389306, 7.762262558936048, 8.726935196692036, 9.687738647634976, 10.687579014966474, 10.747025108289687, 11.741560702211686, 12.702736734940967, 13.558683835152102, 14.144991021092805, 15.071268996314105, 14.458334740495138, 13.50432606691645, 12.51818167694113, 11.557766873123262, 10.62043529441692, 9.735797542905065, 8.85573832937268, 7.850796660033284, 6.979995057604846, 6.051665470637417, 6.800020605348809, 7.832233075726267, 8.865728066168769, 9.798007952442186, 9.719272113614837, 10.722541711436183, 11.727266922010811, 12.625992122984904, 13.659573485102488, 14.398962052328702, 13.450708152493362, 12.48161013288897, 11.522698583730103, 10.698720376976272, 9.675852145539913, 8.772341919892254, 7.827329990099141, 6.835539862543981, 5.954763449417277, 5.022686678350331, 5.833375870391508, 6.835789478758155, 7.796551251623313, 8.774651204592395], [8.73366477459456, 7.7840202614750105, 6.790677925931021, 5.83088577238945, 4.942913024658362, 4.062073504819971, 4.908559281065966, 5.90426007588586, 6.852287913811828, 7.74360733516841, 8.73117317210566, 9.577474795289259, 10.541417467929653, 11.531410366571755, 12.488009897426332, 13.459045724682994, 12.607979351099832, 11.59578739195099, 10.598217415608243, 9.64718919932244, 7.777904789325676, 6.832820694972417, 5.931935410695446, 4.890487693401506, 3.955334288676206, 3.016118198388871, 3.968666076988029, 4.9038918085427206, 5.8753686733835435, 6.7514536322531615, 7.705558890261941, 8.635191899663205, 9.67391591763593, 10.655192394000682, 11.693713830695316, 12.590959779007456, 11.627999407862223, 10.652040601125677, 9.665421284085577, 8.718494895529556, 6.872871487557161, 5.832164873183604, 4.897103948003516, 3.8992385911456235, 2.9462305273876854, 2.0277797518895664, 2.945064405500279, 3.9631047502130077, 4.899944363223638, 5.818278057708259, 6.859023198483374, 7.838431604603764, 8.850507133462152, 9.79909112953486, 10.772091019401627, 11.70393777531994, 10.64605399025248, 9.809127573331828, 8.855774113334581, 7.8531724865338015, 5.882087569664961, 4.870755798344457, 3.886539131525409, 2.9367279671533364, 1.993280631323017, 1.0040083258036256, 1.9876278289134026, 2.962442448653116, 3.9186146399466844, 4.864711706850667, 5.9105857177325625, 6.919971285145855, 7.883602333809247, 8.92871090259476, 9.976825023564887, 10.761879242916141, 9.692387773986347, 8.754258151996797, 7.803826254109155, 6.866318414373962, 4.937064269399457, 3.9053800701054615, 2.937537496051135, 1.8978547951718312, 0.933647928708553, 0.0, 0.9890516452750211, 1.9317875588978413, 2.91421904479712, 3.9457190163981872, 5.01306106259633, 5.989879530658061, 6.982847585035725, 8.007672012186708, 9.071080897361995, 9.887476517110025, 8.819778785536775, 7.7927929312463435, 6.815556026708031, 5.874964873427645, 5.860095571654365, 4.904889570157635, 3.924793367014193, 2.8968681655155173, 1.871199370538098, 0.9335923108229021, 1.9738521376718605, 2.8570361996830886, 3.829949060118643, 4.815600913738648, 5.750190902596443, 6.776636980418372, 7.847167434128717, 8.818578634842872, 9.884908646257486, 10.687358912674421, 9.712584969878916, 8.686679949729443, 7.750114739232041, 6.790723682365283, 6.853297659777728, 5.918630109029806, 4.903110932754962, 3.839414724687505, 2.8631424728334327, 1.9843912064229015, 2.980198941486645, 3.803130146399399, 4.761286210774087, 5.751380940700092, 6.698858259818142, 7.664639263605672, 8.595119802036137, 9.640957468118051, 10.648774248417702, 11.60486431276216, 10.645418999396162, 9.621299813376005, 8.714233054941204, 7.779765970283658, 7.8134656211693985, 6.822798038270642, 5.875187339365509, 4.863507822240025, 3.918809101816289, 2.9698538822649074, 3.933766282311389, 4.7496389288395, 5.703102101002352, 6.670304570544893, 7.729906779781911, 8.685585249028899, 9.527214137898124, 10.593295946556038, 11.577571020948174, 12.44570363227108, 11.49837904237242, 10.566521362093896, 9.653952219986978, 8.788111275015588, 8.742065677273555, 7.806926740579208, 6.828141726482456, 5.930662819620369, 4.950196935183187, 3.95189694496455, 4.9384005375068964, 5.818319160080083, 6.778075410690645, 7.633366620894247, 8.629012626036653, 9.6367527379058, 10.469878776885515, 11.533607158027195, 12.487215881016974, 13.382869723899113, 12.500995091967727, 11.568745413889225, 10.695323383216078, 9.748663487096286, 9.724090932459108, 8.781116981085221, 7.863260961660799, 6.899862827115095, 5.959879302255825, 4.963693045310805, 5.871614085425652, 6.761491526605204, 7.731293218518504, 8.60346905291838, 9.556786645186133, 10.539635714969583, 11.48321500141522, 12.416767846184781, 13.475917876178627, 14.368801102083472, 13.534961796295667, 12.520439655552465, 11.643245806580707, 10.795232912549201, 10.690722357655543, 9.834498086057273, 8.8535252239945, 7.845738777522458, 6.903840297749222, 5.9196316736555525, 6.809431289139891, 7.687760807703925, 8.71045296781322, 9.626302727577265, 10.506093103150747, 11.562087337282986, 12.49323533538925, 13.440204721164633, 14.046668460739385, 14.733718344281426, 14.529536577042357, 13.591054109059524, 12.673015743924973, 11.715610564223491, 11.645295452007003, 10.803993472873767, 9.791432555619135, 8.861834174571737, 7.946081667807546, 6.991409586726302, 7.829943537873296, 8.667949789815077, 9.73195682821754, 10.617223228292836, 11.48147662667693, 12.471226431222028, 13.447638693415577, 13.994431932887961, 13.030585130126685, 13.760944505082252, 14.640030161680627, 14.591862305742579, 13.697969667744573, 12.648072775803746, 12.652496242165718, 11.656513187989201, 10.726899365269523, 9.793131488773682, 8.973425679676977, 8.05220197824674, 8.838299827243931, 9.737654230940368, 10.739770763060452, 11.67070487564771, 12.489529585678163, 13.48782119583092, 13.847598284415815, 12.995305333158084, 12.00168047026193, 12.817445965108861, 13.588309436154054, 14.556073884765254, 14.669056791711691, 13.626668714959864, 13.580766013043853, 12.619536263483239, 11.666356308541141, 10.766054871992464, 9.908621363114033, 9.01336461978595, 9.88787346401931, 10.749628231119638, 11.692470226008219, 12.669599025590278, 13.531728368223165, 13.800817316548944, 12.854527560523554, 11.979339361101738, 11.062882473864732, 11.879919175749002, 12.62217024464622, 13.567623771897383, 14.523392186723292, 14.565264118952818, 14.526615280591123, 13.58910753308418, 12.593559241852248, 11.728753958809177, 10.846061387121972, 10.04881559959857, 10.961249942813657, 11.759191653860716, 12.625455830349425, 13.588985276157336, 13.561657394120385, 12.851216369012914, 11.895525885780215, 10.949069153811722, 10.11103008602772, 10.89933807483332, 11.642483997564568, 12.58497341358974, 13.554136573267705, 14.493383826388682, 14.40981660087073, 14.54727451843025, 13.645534784166385, 12.654523937774025, 11.886507433221615, 11.079123029456538, 12.01050369165483, 12.721520812341245, 13.650758520748102, 13.531521232384012, 12.606171112150296, 11.813483650335693, 10.96483528053254, 9.954293788079779, 9.095983381006546, 9.961742659944285, 10.61912710879283, 11.659403226680896, 12.601381259255048, 13.444118795826947, 13.48161543435136, 14.511117968793574, 14.596243674704672, 13.612456745173501, 12.946387292617853, 12.028664564045185, 12.969284622922617, 13.783936751175686, 13.52188108441779, 12.621493172110615, 11.668518873138535, 10.809696737434058, 9.956319007847222, 8.923100784548685, 8.062833061208078, 8.970020782817661, 9.65610321895382, 10.640599526824825, 11.58707178907971, 12.512557566060163, 12.574969361178438, 13.521842646576573, 14.507874420578496, 14.544640843532518, 13.970164330263465, 13.080353422230397, 13.960065720855646, 13.603728253747994, 12.57807042120701, 11.590027611423862, 10.658869243621977, 9.738243481110466, 8.91562110715469, 7.975172750497497, 7.039087166948679, 7.9208422630978585, 8.695910487644602, 9.660583125400589, 10.621386576343529, 11.621226943675026, 11.68067303699824, 12.675208630920238, 13.636384663649519, 14.492331763860655, 14.904100595315107, 14.137621067605552, 13.524686811786582, 12.570678138207894, 11.584533748232573, 10.624118944414707, 9.686787365708366, 8.802149614196512, 7.922090400664128, 6.9171487313247315, 6.046347128896292, 6.985313399345969, 7.733668534057362, 8.765881004434819, 9.799375994877321, 10.731655881150738, 10.65292004232339, 11.656189640144735, 12.660914850719363, 13.559640051693457, 14.416344079664105, 13.465314123620146, 12.517060223784807, 11.547962204180415, 10.589050655021547, 9.765072448267716, 8.74220421683136, 7.8386939911837015, 6.893682061390589, 5.9018919338354285, 5.021115520708724, 5.956334607058883, 6.767023799100061, 7.769437407466707, 8.730199180331866, 9.708299133300947], [9.722716419869581, 8.773071906750031, 7.779729571206043, 6.819937417664471, 5.931964669933384, 4.945266028277388, 3.9309841253555495, 4.926684920175443, 5.863236268536806, 6.75455568989339, 7.74212152683064, 8.588423150014238, 9.552365822654632, 10.542358721296734, 11.498958252151311, 12.469994079407973, 13.508495013818575, 12.584839037226013, 11.587269060883264, 10.63624084459746, 8.766956434600697, 7.821872340247438, 6.920987055970467, 5.879539338676528, 4.944385933951228, 4.005041409807183, 2.9910909212776122, 3.9263166528323037, 4.886317028108522, 5.7624019869781415, 6.716507244986921, 7.646140254388185, 8.684864272360912, 9.666140748725663, 10.704662185420297, 11.711032066757808, 12.617051053137242, 11.6410922464007, 10.654472929360598, 9.707546540804577, 7.861923132832182, 6.821216518458625, 5.886155593278537, 4.888290236420644, 3.9352821726627067, 3.0167029633078783, 1.9674892497898622, 2.985529594502591, 3.910892717948617, 4.829226412433239, 5.869971553208353, 6.849379959328743, 7.861455488187131, 8.810039484259839, 9.783039374126606, 10.839311354699324, 11.635105635527498, 10.79817921860685, 9.844825758609602, 8.842224131808823, 6.8711392149399835, 5.859807443619478, 4.87559077680043, 3.9257796124283573, 2.9823322765980382, 1.9930599710786467, 1.0100526732029858, 1.973390803378095, 2.9295629946716635, 3.8756600615756462, 4.921534072457542, 5.930919639870834, 6.894550688534226, 7.9396592573197395, 8.987773378289866, 10.000443843539594, 10.681439419261368, 9.743309797271818, 8.792877899384177, 7.855370059648984, 5.926115914674479, 4.894431715380483, 3.926589141326156, 2.886906440446852, 1.9226995739835742, 0.9890516452750211, 0.0, 0.9427359136228203, 1.925167399522099, 2.9566673711231664, 4.0240094173213095, 5.00082788538304, 5.993795939760704, 7.018620366911687, 8.082029252086972, 9.038859608034508, 9.808830430811797, 8.781844576521365, 7.804607671983053, 6.864016518702667, 6.849147216929387, 5.8939412154326565, 4.913845012289213, 3.885919810790538, 2.860251015813119, 1.9226439560979232, 1.0624164814153194, 1.8679845544080678, 2.840897414843622, 3.8265492684636273, 4.761139257321422, 5.787585335143351, 6.858115788853696, 7.829526989567852, 8.895857000982467, 9.943044194929609, 10.701636615153937, 9.675731595004464, 8.739166384507062, 7.779775327640305, 7.84234930505275, 6.907681754304827, 5.892162578029984, 4.828466369962527, 3.852194118108454, 2.9734428516979223, 2.068763285230104, 2.8140785011243783, 3.7722345654990663, 4.762329295425071, 5.709806614543121, 6.675587618330651, 7.606068156761117, 8.65190582284303, 9.659722603142681, 10.63843226164674, 11.597877575012738, 10.610351458651026, 9.703284700216225, 8.76881761555868, 8.80251726644442, 7.811849683545664, 6.864238984640531, 5.8525594675150465, 4.90786074709131, 3.9589055275399283, 3.0223306260548477, 3.7605872835644787, 4.714050455727331, 5.681252925269872, 6.74085513450689, 7.696533603753878, 8.538162492623103, 9.604244301281017, 10.588519375673153, 11.530612890969506, 12.477937480868166, 11.555573007368917, 10.643003865262, 9.777162920290609, 9.731117322548577, 8.79597838585423, 7.817193371757478, 6.9197144648953905, 5.939248580458208, 4.940948590239571, 4.026964881250356, 4.829267514805062, 5.7890237654156245, 6.644314975619226, 7.639960980761632, 8.64770109263078, 9.480827131610496, 10.544555512752176, 11.498164235741955, 12.435903641060738, 13.44055216614826, 12.557797059164248, 11.684375028491099, 10.737715132371306, 10.713142577734128, 9.770168626360242, 8.85231260693582, 7.888914472390117, 6.948930947530846, 5.952744690585826, 4.960178429169112, 5.772439881330183, 6.742241573243483, 7.614417407643359, 8.567734999911112, 9.550584069694562, 10.4941633561402, 11.427716200909762, 12.486866230903608, 13.421835019245098, 14.495807244778339, 13.509491300827488, 12.632297451855727, 11.784284557824222, 11.679774002930564, 10.823549731332294, 9.842576869269521, 8.834790422797479, 7.892891943024243, 6.843640258647221, 5.897995632883351, 6.698709162428904, 7.721401322538198, 8.637251082302244, 9.517041457875726, 10.573035692007965, 11.504183690114228, 12.451153075889613, 13.376353519293078, 14.357191464001684, 15.41284580321312, 14.580105754334546, 13.662067389199994, 12.704662209498512, 12.634347097282024, 11.793045118148788, 10.768426945494644, 9.80874417219949, 8.875471911251076, 7.887918007523873, 6.9185078816167564, 7.678898144540057, 8.742905182942518, 9.628171583017815, 10.492424981401909, 11.482174785947008, 12.458587048140556, 13.043053283206145, 13.913777653584102, 14.742693905487977, 15.62908180695565, 15.580913951017601, 14.687021313019592, 13.637124421078767, 13.64154788744074, 12.63350757786471, 11.703893755145032, 10.740041486401434, 9.895254018952626, 8.900518024676405, 7.9268641709873915, 8.748602585665347, 9.750719117785431, 10.681653230372689, 11.50047794040314, 12.498769550555897, 12.870023128705398, 12.043926683476268, 12.884872993719346, 13.799195365514587, 14.577361081429077, 15.545125530040277, 15.658108436986714, 14.615720360234887, 14.557760402919362, 13.596530653358748, 12.64335069841665, 11.712964869620217, 10.830449702389682, 9.861680666215614, 8.976437807762771, 9.760576585844618, 10.7034185807332, 11.680547380315259, 12.542676722948142, 12.821453991119231, 11.876952404813137, 11.001764205391321, 11.94607499732215, 12.861668576154727, 13.611221889921243, 14.556675417172405, 15.512443831998315, 15.549143109065813, 15.503609670466634, 14.566101922959689, 13.570553631727757, 12.67566395643693, 11.767889726397621, 10.897131646028232, 10.049814286557117, 10.770140008585695, 11.636404185074406, 12.599933630882317, 12.572605748845366, 11.8718530435832, 10.917950730069798, 9.971493998101305, 10.994222609485137, 11.881087475239045, 12.63153564283959, 13.574025058864763, 14.543188218542728, 15.482435471663704, 15.398868246145753, 15.524268908305759, 14.592444781794137, 13.601433935401777, 12.808335772497264, 11.9274390758862, 11.09906803539829, 11.732469167066224, 12.661706875473083, 12.542469587108993, 11.617119466875277, 10.824432005060672, 9.987260124822123, 8.976718632369362, 9.979175904463963, 10.94349206035001, 11.608178754067852, 12.648454871955918, 13.59043290453007, 14.43317044110197, 14.470667079626383, 15.500169614068597, 15.543153672332425, 14.559366742801254, 13.868215631893502, 12.876980610474847, 12.057848966666077, 12.794885105900665, 12.532829439142771, 11.632441526835596, 10.679467227863515, 9.820645092159037, 8.978743852136805, 7.9455256288382685, 8.946025584665495, 9.951770183223386, 10.645154864228843, 11.629651172099848, 12.576123434354733, 13.501609211335186, 13.56402100645346, 14.510894291851596, 15.496926065853518, 15.49155084116027, 14.883793510448804, 13.92866946866006, 13.048630064599106, 12.614676608472974, 11.58901877593199, 10.600975966148843, 9.669817598346958, 8.749191835835445, 7.938045951444273, 6.99759759478708, 7.922279690406096, 8.902591663503584, 9.684962132919624, 10.649634770675611, 11.610438221618551, 12.610278588950049, 12.669724682273259, 13.664260276195261, 14.625436308924542, 15.392847426579397, 14.39488390779097, 13.545752649604236, 12.535635166511561, 11.581626492932873, 10.595482102957552, 9.635067299139688, 8.697735720433347, 7.813097968921491, 6.9445152449537115, 5.939573575614315, 6.929539652353709, 7.967062799751695, 8.722720179332384, 9.754932649709842, 10.788427640152342, 11.720707526425759, 11.641971687598408, 12.645241285419758, 13.649966495994386, 14.460155714412199, 13.427292434389084, 12.476262478345125, 11.528008578509786, 10.558910558905396, 9.599999009746526, 8.776020802992695, 7.753152571556339, 6.84964234590868, 5.916106905680172, 4.924316778125012, 5.90430804416614, 6.945386252333905, 7.7560754443750834, 8.75848905274173, 9.719250825606887, 10.697350778575968], [10.665452333492402, 9.715807820372852, 8.722465484828863, 7.762673331287291, 6.874700583556204, 5.888001941900208, 4.8737200389783695, 4.137196297230918, 4.920500354913986, 5.8118197762705694, 6.799385613207819, 7.645687236391418, 8.609629909031812, 9.599622807673914, 10.55622233852849, 11.527258165785152, 12.565759100195752, 13.527574950848832, 12.530004974506083, 11.578976758220278, 9.709692348223516, 8.764608253870257, 7.863722969593287, 6.822275252299348, 5.887121847574048, 4.947777323430004, 3.933826834900432, 3.136828029887778, 3.943581114485702, 4.819666073355321, 5.773771331364101, 6.703404340765364, 7.74212835873809, 8.723404835102842, 9.761926271797476, 10.768296153134987, 11.73125652428022, 12.583828160023518, 11.597208842983417, 10.650282454427396, 8.804659046455, 7.763952432081445, 6.828891506901357, 5.831026150043464, 4.878018086285527, 3.959438876930699, 2.9102251634126826, 2.087605552314299, 2.9681568043257966, 3.886490498810418, 4.927235639585533, 5.906644045705923, 6.918719574564311, 7.867303570637018, 8.840303460503785, 9.896575441076504, 10.954459226143964, 11.74091513222967, 10.787561672232421, 9.784960045431644, 7.8138751285628025, 6.802543357242298, 5.81832669042325, 4.868515526051177, 3.925068190220858, 2.935795884701467, 1.9527885868258061, 1.0306548897552745, 1.986827081048843, 2.932924147952826, 3.9787981588347217, 4.988183726248014, 5.951814774911406, 6.99692334369692, 8.045037464667047, 9.057707929916775, 10.12719939884657, 10.68604571089464, 9.735613813006996, 8.798105973271804, 6.868851828297299, 5.837167629003303, 4.869325054948976, 3.829642354069672, 2.865435487606394, 1.9317875588978413, 0.9427359136228203, 0.0, 0.9824314858992788, 2.013931457500346, 3.0812735036984895, 4.05809197176022, 5.051060026137884, 6.075884453288867, 7.139293338464153, 8.09612369441169, 9.16382142598494, 9.724580490144186, 8.747343585605874, 7.806752432325487, 7.791883130552207, 6.836677129055476, 5.856580925912034, 4.828655724413358, 3.8029869294359395, 2.8653798697207433, 1.9585637877188773, 0.9252486407852474, 1.8981615012208017, 2.8838133548408074, 3.818403343698602, 4.844849421520531, 5.915379875230876, 6.886791075945032, 7.953121087359647, 9.000308281306788, 9.975082224102293, 10.618467508627285, 9.681902298129883, 8.722511241263126, 8.78508521867557, 7.850417667927648, 6.834898491652804, 5.771202283585347, 4.794930031731274, 3.9161787653207427, 2.886643908133515, 1.871342587501558, 2.8294986518762464, 3.8195933818022514, 4.767070700920301, 5.732851704707831, 6.663332243138297, 7.7091699092202095, 8.71698668951986, 9.695696348023919, 10.655141661389917, 11.553087372273847, 10.646020613839045, 9.7115535291815, 9.734523003167201, 8.743855420268444, 7.79624472136331, 6.7845652042378255, 5.763808163709848, 4.7960688749828755, 3.8094088164155964, 2.8178513699416583, 3.771314542104511, 4.738517011647052, 5.79811922088407, 6.753797690131058, 7.595426579000282, 8.661508387658197, 9.645783462050332, 10.587876977346685, 11.535201567245345, 12.467059247523869, 11.58573977888482, 10.71989883391343, 10.663123059271358, 9.72798412257701, 8.749199108480257, 7.821937185107081, 6.795195997076746, 5.778111937682517, 4.8140430716111045, 3.8865316011822424, 4.8462878517928045, 5.701579061996405, 6.697225067138811, 7.70496517900796, 8.538091217987674, 9.601819599129353, 10.555428322119132, 11.493167727437916, 12.497816252525437, 13.44124699266948, 12.62711094211392, 11.680451045994127, 11.645148314456907, 10.70217436308302, 9.7843183436586, 8.769485381129826, 7.786094294973793, 6.789908038028773, 5.7472566195298604, 4.829703967707363, 5.799505659620663, 6.671681494020538, 7.624999086288291, 8.607848156071741, 9.551427442517378, 10.48498028728694, 11.544130317280786, 12.479099105622275, 13.553071331155516, 14.39294123433272, 13.575033365478548, 12.716290294547, 12.577765710822238, 11.627603961439233, 10.64663109937646, 9.638844652904417, 8.696946173131183, 7.630718449007969, 6.6850738232441, 5.755973248806084, 6.778665408915378, 7.694515168679423, 8.574305544252905, 9.630299778385144, 10.561447776491407, 11.508417162266792, 12.433617605670257, 13.414455550378863, 14.470109889590299, 15.408592357573133, 14.603103303001086, 13.602653917390185, 13.532338805173698, 12.597099348255727, 11.555505135855393, 10.595822362560238, 9.662550101611824, 8.67499619788462, 7.705586071977505, 6.736162230917237, 7.8001692693196985, 8.685435669394995, 9.549689067779088, 10.539438872324187, 11.515851134517735, 12.490093219659036, 13.449700936282957, 14.387229389578037, 15.345527850452656, 16.33007526268647, 15.585095012978835, 14.53511612897044, 14.433511202547198, 13.42058576822546, 12.49097194550578, 11.527119676762183, 10.682332209313374, 9.687596215037154, 8.71394236134814, 7.805866672042527, 8.807983204162612, 9.738917316749868, 10.557742026780321, 11.556033636933078, 12.131323331393297, 12.986662597099087, 13.827608907342166, 14.741931279137408, 15.520096995051896, 16.487861443663096, 16.45007175209317, 15.407683675341344, 15.34483859328011, 14.383608843719497, 13.4304288887774, 12.500043059980966, 11.61752789275043, 10.648758856576363, 9.76351599812352, 8.817840672221799, 9.76068266711038, 10.73781146669244, 11.599940809325323, 11.878718077496409, 11.138252607501036, 11.94450011901414, 12.888810910944969, 13.804404489777548, 14.553957803544062, 15.499411330795224, 16.455179745621134, 16.336221299426562, 16.290687860827383, 15.353180113320438, 14.357631822088505, 13.462742146797678, 12.55496791675837, 11.68420983638898, 10.836892476917866, 9.827404094962876, 10.693668271451587, 11.657197717259498, 11.629869835222545, 10.929117129960378, 10.179250932757697, 10.914229911724124, 11.936958523107956, 12.823823388861866, 13.57427155646241, 14.516760972487582, 15.485924132165547, 16.42517138528652, 16.341604159768572, 16.31134709866651, 15.379522972154886, 14.388512125762526, 13.595413962858013, 12.714517266246949, 11.772354622865098, 10.789733253443405, 11.718970961850264, 11.599733673486172, 10.674383553252456, 9.881696091437849, 9.248560327510022, 9.919454545992181, 10.921911818086782, 11.886227973972831, 12.550914667690671, 13.591190785578737, 14.53316881815289, 15.375906354724789, 15.413402993249202, 16.442905527691416, 16.33023186269317, 15.346444933162003, 14.65529382225425, 13.664058800835596, 12.731135554132885, 11.852149192277846, 11.59009352551995, 10.689705613212775, 9.736731314240695, 8.877909178536214, 8.210646747653044, 8.888261542461088, 9.888761498288314, 10.894506096846207, 11.587890777851662, 12.572387085722667, 13.518859347977552, 14.444345124958005, 14.50675692007628, 15.453630205474415, 16.36633983779771, 15.450648371638215, 14.38608425921979, 13.501743424677713, 12.545442236808167, 11.671940694850154, 10.64628286230917, 9.658240052526022, 8.727081684724137, 7.806455922212623, 7.162058122800033, 7.940333508409899, 8.865015604028915, 9.845327577126405, 10.627698046542443, 11.59237068429843, 12.55317413524137, 13.553014502572868, 13.612460595896078, 14.60699618981808, 15.387026692940026, 14.450111512956575, 13.452147994168149, 12.603016735981415, 11.59289925288874, 10.638890579310052, 9.652746189334731, 8.692331385516868, 7.754999806810526, 6.870362055298671, 6.167225132590549, 6.882309489237134, 7.872275565976528, 8.909798713374515, 9.665456092955203, 10.69766856333266, 11.731163553775163, 12.66344344004858, 12.584707601221227, 13.587977199042577, 14.509615372607012, 13.517419800789376, 12.484556520766263, 11.533526564722305, 10.585272664886965, 9.616174645282573, 8.657263096123705, 7.8332848893698745, 6.810416657933518, 5.90690643228586, 5.13881679331701, 5.867052691747832, 6.84704395778896, 7.888122165956725, 8.698811357997903, 9.70122496636455, 10.661986739229707, 11.640086692198789], [11.64788381939168, 10.69823930627213, 9.704896970728141, 8.74510481718657, 7.857132069455482, 6.854546329566068, 5.84026442664423, 4.96551375835474, 3.9553177248074243, 4.846637146164007, 5.834202983101257, 6.680504606284856, 7.6444472789252504, 8.634440177567352, 9.59103970842193, 10.562075535678591, 11.600576470089191, 12.61276842923803, 13.512436460405363, 12.561408244119558, 10.692123834122796, 9.747039739769537, 8.846154455492567, 7.804706738198626, 6.869553333473326, 5.930208809329282, 4.900371222566292, 3.9651454910116004, 2.97839848437914, 3.8544834432487587, 4.808588701257539, 5.738221710658802, 6.776945728631528, 7.75822220499628, 8.796743641690913, 9.803113523028424, 10.766073894173656, 11.81105538723116, 12.579640328882697, 11.632713940326676, 9.78709053235428, 8.746383917980724, 7.811322992800636, 6.8134576359427435, 5.860449572184805, 4.941870362829977, 3.892656649311961, 2.972800489857806, 2.0029741742192346, 2.921307868703856, 3.962053009478971, 4.9414614155993615, 5.936288088665032, 6.884872084737739, 7.857871974604507, 8.914143955177225, 9.972027740244686, 11.022459668719526, 11.769993158131701, 10.767391531330924, 8.796306614462083, 7.784974843141577, 6.800758176322529, 5.850947011950456, 4.907499676120137, 3.9182273706007456, 2.935220072725085, 1.9778166422358496, 1.021644450942281, 1.9677415178462638, 3.0136155287281596, 4.005752240348735, 4.969383289012127, 6.0144918577976405, 7.062605978767767, 8.075276444017497, 9.144767912947291, 10.08289753493684, 10.718045298906276, 9.780537459171084, 7.851283314196578, 6.819599114902582, 5.851756540848255, 4.812073839968951, 3.8478669735056727, 2.91421904479712, 1.925167399522099, 0.9824314858992788, 0.0, 1.0314999716010673, 2.098842017799211, 3.0756604858609413, 4.068628540238606, 5.093452967389589, 6.156861852564875, 7.113692208512411, 8.181389940085662, 9.208375794376094, 9.729775071505154, 8.789183918224767, 8.774314616451486, 7.8191086149547555, 6.8390124118113125, 5.811087210312637, 4.785418415335218, 3.847811355620022, 2.9409952736181557, 1.907680126684526, 1.0102186689021082, 1.9958705225221136, 2.9304605113799083, 3.9569065892018376, 5.027437042912182, 5.998848243626338, 7.065178255040953, 8.072313637349637, 9.047087580145142, 10.072992600294615, 10.664333784029163, 9.704942727162404, 9.767516704574849, 8.832849153826926, 7.817329977552082, 6.753633769484625, 5.777361517630553, 4.898610251220021, 3.8690753940327935, 2.8537740734008366, 1.9930697009558038, 2.9316505494835576, 3.8791278686016075, 4.844908872389137, 5.775389410819603, 6.821227076901517, 7.829043857201167, 8.807753515705226, 9.767198829071225, 10.840663155331713, 11.628452099738325, 10.693985015080779, 10.71695448906648, 9.726286906167722, 8.778676207262588, 7.766996690137105, 6.7462396496091275, 5.778500360882155, 4.791840302314875, 3.800282855840937, 2.9348855911840683, 3.9020880607266095, 4.9168464107238234, 5.872524879970811, 6.707483746681588, 7.773565555339502, 8.757840629731637, 9.69993414502799, 10.64725873492665, 11.579116415205174, 12.5681712647841, 11.702330319812708, 11.645554545170636, 10.710415608476287, 9.731630594379535, 8.80436867100636, 7.777627482976025, 6.7605434235817965, 5.796474557510383, 4.868963087081521, 4.009858900872362, 4.8651501110759625, 5.860796116218369, 6.823692368847714, 7.650148385668981, 8.71387676681066, 9.66748548980044, 10.605224895119223, 11.609873420206744, 12.553304160350788, 13.59027309772273, 12.662882531893406, 12.627579800356186, 11.684605848982299, 10.766749829557877, 9.751916867029104, 8.768525780873071, 7.772339523928052, 6.729688105429139, 5.812135453606642, 4.9636718685726855, 5.835252543100095, 6.7885701353678485, 7.7714192051512985, 8.663484610198685, 9.597037454968246, 10.656187484962093, 11.591156273303582, 12.665128498836824, 13.504998402014028, 14.459915319157151, 13.698721780446279, 13.560197196721516, 12.610035447338511, 11.629062585275738, 10.621276138803696, 9.679377659030461, 8.613149934907248, 7.667505309143378, 6.738404734705362, 5.942831617867401, 6.858086217758981, 7.737876593332463, 8.793870827464701, 9.691441225899352, 10.638410611674736, 11.563611055078201, 12.544448999786807, 13.600103338998244, 14.538585806981077, 15.489685256501417, 14.585085403289463, 14.514770291072976, 13.579530834155005, 12.537936621754673, 11.578253848459518, 10.644981587511104, 9.6574276837839, 8.688017557876783, 7.718593716816515, 6.985542669507572, 7.849006718474552, 8.713260116858645, 9.703009921403744, 10.64584458392568, 11.62008666906698, 12.579694385690901, 13.517222838985981, 14.4755212998606, 15.460068712094415, 16.48364948349843, 15.517547614869718, 15.415942688446478, 14.40301725412474, 13.47340343140506, 12.509551162661463, 11.664763695212653, 10.670027700936432, 9.696373847247418, 8.788298157941805, 7.993356604350485, 8.902488365829425, 9.721313075859879, 10.719604686012635, 11.620773194593925, 12.619213268796857, 13.608599045555657, 14.460721378959372, 15.406834355970867, 16.377080939317622, 17.342067005933846, 16.390115161240622, 16.32727007917939, 15.366040329618777, 14.41286037467668, 13.482474545880246, 12.599959378649709, 11.63119034247564, 10.7459474840228, 9.800272158121075, 8.946056067298251, 9.92318486688031, 10.76351185840488, 10.913535447389847, 11.746036994269659, 12.7088622112173, 13.67182018469672, 14.611837860679389, 15.536389289443342, 16.481842816694503, 17.437611231520414, 17.31865278532584, 17.27311934672666, 16.335611599219718, 15.340063307987785, 14.445173632696958, 13.537399402657648, 12.66664132228826, 11.819323962817146, 10.809835580862153, 9.879041671639458, 10.842571117447369, 10.664687205115982, 9.963934499853817, 10.78703531952632, 11.684187269540073, 12.719967796859708, 13.657659680331136, 14.55670304236169, 15.499192458386862, 16.468355618064827, 17.407602871185805, 17.324035645667855, 17.29377858456579, 16.361954458054164, 15.370943611661806, 14.57784544875729, 13.696948752146229, 12.754786108764375, 11.772164739342681, 10.904344362038135, 10.63455104337961, 9.709200923145893, 8.916513461331288, 9.856344714278645, 10.68941190380813, 11.704921091838534, 12.720064265442101, 13.533346153589951, 14.573622271478017, 15.51560030405217, 16.35833784062407, 16.39583447914848, 17.42386106240367, 16.40143676942184, 15.41764983989067, 14.444678666758842, 13.541040320488031, 12.56134604376458, 11.579332096329663, 10.62491089541339, 9.724522983106214, 8.771548684134132, 7.912726548429653, 8.818431134421667, 9.658218900277037, 10.671770772040066, 11.728342388315477, 12.570322263750942, 13.554818571621947, 14.501290833876832, 15.426776610857285, 15.48918840597556, 16.37719821451644, 15.40115720769115, 14.485465741531653, 13.42090162911323, 12.536560794571152, 11.580259606701606, 10.706758064743592, 9.681100232202608, 8.69305742241946, 7.761899054617575, 6.841273292106062, 7.769842509568656, 8.710290866225849, 9.71666385339222, 10.711624651915383, 11.610129532441723, 12.57480217019771, 13.53560562114065, 14.535445988472148, 14.594892081795358, 15.383020095562745, 14.421844062833465, 13.484928882850014, 12.486965364061588, 11.637834105874854, 10.627716622782179, 9.67370794920349, 8.687563559228169, 7.7271487554103055, 6.789817176703964, 5.9051794251921095, 6.947597801342608, 7.848853876902995, 8.838819953642389, 9.876343101040376, 10.647887578854483, 11.68010004923194, 12.713595039674441, 13.645874925947858, 13.567139087120507, 14.570408684941857, 13.544432742500451, 12.552237170682815, 11.519373890659702, 10.568343934615744, 9.620090034780404, 8.650992015176012, 7.692080466017143, 6.868102259263313, 5.845234027826956, 4.941723802179298, 5.967134254440832, 6.833597079413692, 7.8135883454548205, 8.870553651856003, 9.681242843897182, 10.683656452263829, 11.644418225128986, 12.622518178098067], [12.654356271585188, 11.704711758465638, 10.71136942292165, 9.751577269380078, 8.796660106156587, 7.791961791067736, 6.777679888145898, 5.902929219856409, 4.892733186309093, 3.9128899666229877, 4.900455803560237, 5.746757426743836, 6.710700099384231, 7.700692998026334, 8.65729252888091, 9.628328356137573, 10.666829290548172, 11.679021249697012, 12.727568490308885, 13.592908215720627, 11.723623805723863, 10.778539711370604, 9.869717051488767, 8.811179190392135, 7.876025785666836, 6.898812572716034, 5.837786684067961, 4.902560952513269, 3.915813945880809, 2.920736263707739, 3.874841521716519, 4.8044745311177826, 5.843198549090508, 6.824475025455261, 7.845602960250676, 8.851972841588188, 9.81493321273342, 10.859914705790924, 11.846534022831026, 12.664213911927742, 10.818590503955347, 9.77788388958179, 8.842822964401703, 7.844957607543811, 6.8919495437858735, 5.941998686127462, 4.892784972609446, 3.9102159513594756, 2.940389635720904, 1.9875606891628363, 3.0283058299379513, 3.986615973226109, 4.904788117063965, 5.853372113136672, 6.8263720030034385, 7.882643983576157, 8.940527768643618, 9.990959697118457, 10.954974571834892, 11.79889150293199, 9.827806586063149, 8.816474814742644, 7.832258147923596, 6.882446983551524, 5.938999647721205, 4.918967899132347, 3.9353483960225697, 2.936263596502795, 1.9800914052092264, 1.033994338305244, 2.0085695243992303, 2.9742522687476676, 3.9378833174110595, 4.982991886196573, 6.0311060071666995, 7.04377647241643, 8.113267941346223, 9.051397563335772, 10.048933892551105, 10.81203743077215, 8.882783285797645, 7.851099086503649, 6.883256512449322, 5.843573811570018, 4.8793669451067405, 3.9457190163981872, 2.9566673711231664, 2.013931457500346, 1.0314999716010673, 0.0, 1.0673420461981435, 2.044160514259874, 3.037128568637539, 4.061952995788522, 5.1253618809638075, 6.082192236911344, 7.149889968484596, 8.176875822775028, 9.15411272731334, 9.820683889825833, 9.805814588052552, 8.850608586555822, 7.870512383412381, 6.8425871819137045, 5.816918386936285, 4.879311327221089, 3.969547185411188, 2.936232038477558, 1.9633191780420036, 0.9776673244219982, 1.9122573132797926, 2.938703391101722, 4.009233844812067, 4.980645045526223, 6.046975056940838, 7.04081366574857, 8.015587608544076, 9.041492628693549, 9.978057839190951, 10.73644269876347, 10.799016676175915, 9.864349125427992, 8.84882994915315, 7.7851337410856924, 6.80886148923162, 5.930110222821089, 4.897627305825825, 3.8823259851938685, 2.9271362276349264, 1.9134473513834425, 2.860924670501492, 3.826705674289022, 4.757186212719488, 5.803023878801401, 6.810840659101052, 7.7895503176051095, 8.748995630971107, 9.822459957231596, 10.787920591665188, 11.725484986681845, 11.745506400859512, 10.754838817960755, 9.80722811905562, 8.795548601930136, 7.77479156140216, 6.807052272675187, 5.820392214107907, 4.828834767633969, 3.868952117863191, 2.930094997230505, 3.898643212623708, 4.854321681870696, 5.689280548581474, 6.755362357239387, 7.7396374316315235, 8.681730946927877, 9.629055536826536, 10.56091321710506, 11.586168737113427, 12.577425048856876, 12.674106456963669, 11.73896752026932, 10.760182506172567, 9.83292058279939, 8.806179394769057, 7.789095335374829, 6.825026469303415, 5.883532376735286, 4.8578600443674445, 3.8931570475798583, 4.888803052722265, 5.805489170747598, 6.631945187568866, 7.695673568710546, 8.649282291700326, 9.58702169701911, 10.59167022210663, 11.535100962250674, 12.572069899622615, 13.537977260937573, 13.656131712149218, 12.713157760775331, 11.79530174135091, 10.758025271216415, 9.774634185060382, 8.778447928115362, 7.70386289198807, 6.768456683761224, 5.798654991847925, 4.8632594796039905, 5.816577071871744, 6.799426141655195, 7.645281412098569, 8.57883425686813, 9.637984286861979, 10.572953075203468, 11.64692530073671, 12.486795203913914, 13.441712121057037, 14.42963136281299, 14.534371983280447, 13.584210233897442, 12.60323737183467, 11.595450925362627, 10.653552445589392, 9.58732472146618, 8.64168009570231, 7.694725964859945, 6.77781474114264, 5.886093154262876, 6.765883529836358, 7.8218777639685975, 8.673238027799236, 9.62020741357462, 10.545407856978086, 11.526245801686692, 12.581900140898128, 13.520382608880961, 14.471482058401303, 15.44127957820481, 15.488945077631907, 14.553705620713936, 13.512111408313602, 12.552428635018448, 11.619156374070034, 10.63160247034283, 9.662192344435715, 8.674914946971098, 7.820525792782812, 6.877013654978447, 7.741267053362542, 8.73101685790764, 9.627641385825564, 10.601883470966865, 11.561491187590786, 12.499019640885866, 13.457318101760485, 14.4418655139943, 15.465446285398311, 16.373741789785065, 16.390117475005407, 15.377192040683669, 14.44757821796399, 13.483725949220393, 12.638938481771584, 11.644202487495363, 10.67054863380635, 9.744619388096389, 8.828339727625725, 7.93049530233332, 8.749320012363775, 9.747611622516532, 10.60256999649381, 11.601010070696741, 12.590395847455541, 13.442518180859256, 14.388631157870751, 15.358877741217507, 16.32386380783373, 17.360030281197602, 17.30144486573832, 16.340215116177706, 15.387035161235609, 14.456649332439175, 13.57413416520864, 12.605365129034572, 11.72012227058173, 10.75659338827566, 9.781039190573491, 9.001304934268601, 9.791518794908777, 10.795244609094835, 11.59564072038607, 12.558465937333711, 13.529193843852738, 14.380044970219116, 15.354770349378585, 16.34732785408538, 17.331564588287357, 18.274258179217203, 18.24729413328559, 17.309786385778644, 16.314238094546713, 15.419348419255888, 14.51157418921658, 13.64081610884719, 12.793498749376075, 11.766156811016737, 10.714024794914698, 9.9364074538901, 9.730940025574963, 10.730215420167967, 11.675111814854306, 12.610904575571563, 13.646685102891196, 14.584376986362624, 15.563175494555198, 16.505664910580368, 17.474828070258337, 18.41407532337931, 18.29954339698809, 17.41490888477254, 16.432846314141486, 15.441835467749128, 14.53094025706606, 13.55683467553566, 12.586379795491348, 11.612683297891975, 10.64526061749305, 9.70080386383859, 8.775453743604874, 9.711661613744658, 10.744421209606632, 11.61612920983962, 12.631638397870022, 13.64678157147359, 14.53981860578346, 15.580094723671525, 16.522072756245677, 17.364810292817577, 17.368788589469204, 16.49011388286265, 15.467689589880822, 14.483902660349651, 13.510931487217823, 12.607293140947013, 11.627598864223561, 10.645584916788644, 9.69116371587237, 8.790775803565193, 7.837801504593113, 8.839443854461143, 9.745148440453157, 10.584936206308527, 11.598488078071554, 12.655059694346965, 13.57679471594445, 14.561291023815455, 15.50776328607034, 16.43324906305079, 16.390324320373555, 15.44345103497542, 14.46741002815013, 13.551718561990635, 12.48715444957221, 11.602813615030133, 10.646512427160587, 9.773010885202574, 8.74735305266159, 7.759310242878441, 6.828151875076555, 7.767990598137552, 8.696559815600146, 9.637008172257339, 10.64338115942371, 11.638341957946873, 12.616601984635231, 13.581274622391218, 14.542078073334158, 15.541918440665656, 15.522683323162285, 14.449272916021727, 13.488096883292446, 12.551181703308995, 11.553218184520569, 10.704086926333835, 9.69396944324116, 8.739960769662469, 7.753816379687149, 6.793401575869286, 5.856069997162944, 6.831896731223599, 7.874315107374098, 8.786269338404663, 9.776235415144056, 10.813758562542043, 11.654360031047991, 12.686572501425449, 13.72006749186795, 14.652347378141366, 14.598639058721576, 13.66065852252065, 12.610685562959432, 11.618489991141796, 10.585626711118683, 9.634596755074725, 8.686342855239385, 7.717244835634992, 6.758333286476123, 5.934355079722293, 4.911486848285937, 5.868441108210789, 6.9045497159425, 7.77101254091536, 8.751003806956488, 9.810081688557108, 10.68771529609069, 11.690128904457337, 12.650890677322494, 13.628990630291575], [13.60746342236293, 12.65781890924338, 11.66447657369939, 10.70468442015782, 9.749767256934327, 8.745068941845476, 7.730787038923638, 6.856036370634149, 5.845840337086832, 4.865997117400727, 4.021303331455924, 4.799056268583338, 5.762998941223732, 6.752991839865835, 7.70522630686527, 8.676262134121933, 9.714763068532534, 10.726955027681374, 11.71198810815555, 12.654812668981787, 12.666708471392784, 11.80128140905969, 10.822824202266508, 9.764286341169877, 8.829132936444577, 7.851919723493774, 6.790893834845701, 5.855668103291009, 4.868921096658548, 3.873843414485478, 2.9831670604911658, 3.8567733729572846, 4.859005986522855, 5.808148314415195, 6.778260914052534, 7.784630795390045, 8.747591166535278, 9.792572659592782, 10.779191976632884, 11.726118365188904, 11.88547234015323, 10.844765725779673, 9.909704800599584, 8.911839443741691, 7.893575454929212, 6.895105836905201, 5.845892123387185, 4.8633231021372145, 3.893496786498643, 2.9406678399405752, 2.0079912077388498, 2.9192739270279655, 3.8374460708658216, 4.786030066938529, 5.759029956805296, 6.815301937378015, 7.873185722445475, 8.923617650920315, 9.88763252563675, 10.905953758247994, 10.895148632261293, 9.883356650940526, 8.899139984121478, 7.949328819749404, 6.940831532922179, 5.8720750499100856, 4.888455546800309, 3.889370747280534, 2.9331985559869653, 1.9871014890829826, 0.9412274782010868, 1.9069102225495242, 2.870541271212916, 3.915649839998429, 4.9637639609685555, 5.976434426218286, 7.04592589514808, 7.98405551713763, 8.981591846352963, 9.919099686088154, 9.950125331995789, 8.918441132701792, 7.9505985586474655, 6.9109158577681615, 5.946708991304884, 5.01306106259633, 4.0240094173213095, 3.0812735036984895, 2.098842017799211, 1.0673420461981435, 0.0, 0.9768184680617304, 1.9697865224393953, 2.9946109495903777, 4.0580198347656635, 5.0148501907132, 6.082547922286452, 7.109533776576884, 8.086770681115196, 9.027361834395583, 10.873156634250696, 9.917950632753966, 8.937854429610523, 7.909929228111848, 6.884260433134429, 5.946653373419233, 4.985011757938729, 3.9516966110050986, 2.9787837505695443, 1.993131896949539, 1.0585419080917446, 1.9988620441146587, 2.9711461564798345, 3.9425573571939907, 5.0088873686086055, 5.973471619550426, 6.948245562345931, 7.974150582495404, 8.910715792992807, 9.96216543826737, 11.81153934892541, 10.931691171626136, 9.916171995351293, 8.852475787283836, 7.876203535429764, 6.985506801411775, 5.913091878353367, 4.897790557721409, 3.942600800162467, 2.928911923910983, 2.0072092653134437, 2.9729902691009737, 3.9034708075314395, 4.936300192508782, 5.944116972808433, 6.922826631312491, 7.881079591863177, 8.908770446141965, 9.874231080575559, 10.879585016969376, 12.760970973387051, 11.770303390488294, 10.82269269158316, 9.811013174457676, 8.790256133929699, 7.822516845202727, 6.835856786635447, 5.844299340161509, 4.884416690390731, 3.9455595697580454, 3.0449278074356596, 4.000606276682648, 4.835565143393425, 5.901646952051339, 6.885922026443474, 7.828015541739827, 8.775340131638487, 9.70719781191701, 10.732453331925377, 11.723709643668826, 13.689571029491209, 12.75443209279686, 11.775647078700107, 10.84838515532693, 9.821643967296597, 8.80455990790237, 7.840491041830955, 6.898996949262826, 5.873324616894984, 4.908621620107398, 4.0968683059084094, 4.95177376555955, 5.7782297823808175, 6.841958163522497, 7.795566886512275, 8.73330629183106, 9.737954816918581, 10.681385557062626, 11.718354494434568, 12.684261855749524, 14.647057937715037, 13.728622333302871, 12.81076631387845, 11.773489843743956, 10.790098757587923, 9.793912500642904, 8.719327464515612, 7.783921256288765, 6.814119564375465, 5.878724052131531, 5.076485935142459, 5.953189748315523, 6.7915660069105215, 7.725118851680083, 8.78426888167393, 9.719237670015419, 10.79320989554866, 11.633079798725866, 12.58799671586899, 13.575915957624943, 15.549836555807989, 14.599674806424984, 13.618701944362211, 12.610915497890169, 11.669017018116934, 10.602789293993721, 9.65714466822985, 8.710190537387485, 7.793279313670181, 6.901557726790417, 6.025792393107074, 6.983551406410796, 7.8195226226111885, 8.766492008386573, 9.691692451790038, 10.672530396498644, 11.72818473571008, 12.666667203692914, 13.617766653213256, 14.587564173016762, 16.50440965015945, 15.569170193241478, 14.527575980841144, 13.567893207545989, 12.634620946597575, 11.647067042870372, 10.677656916963256, 9.690379519498638, 8.835990365310352, 7.892478227505988, 7.001175916633257, 7.990925721178356, 8.773925980637516, 9.748168065778817, 10.707775782402738, 11.645304235697818, 12.603602696572437, 13.588150108806252, 14.611730880210263, 15.520026384597017, 17.40558204753295, 16.39265661321121, 15.463042790491532, 14.499190521747934, 13.654403054299125, 12.659667060022905, 11.686013206333891, 10.760083960623929, 9.843804300153264, 8.945959874860861, 8.00922887563449, 9.007520485787246, 9.748854591305761, 10.747294665508694, 11.736680442267494, 12.588802775671208, 13.534915752682704, 14.505162336029459, 15.470148402645684, 16.506314876009554, 18.31690943826586, 17.355679688705248, 16.40249973376315, 15.472113904966717, 14.589598737736182, 13.620829701562114, 12.735586843109271, 11.772057960803199, 10.796503763101033, 10.016769506796143, 9.051427658179492, 10.05515347236555, 10.741925315198023, 11.704750532145663, 12.67547843866469, 13.526329565031068, 14.501054944190537, 15.49361244889733, 16.47784918309931, 17.420542774029155, 18.33091253924248, 17.372879158702553, 16.377330867470622, 15.415539224698337, 14.63337980587526, 13.649135608103185, 12.697627047042078, 11.677701126931021, 10.773251978450245, 10.206516789743104, 10.023266426728183, 11.00475441990158, 11.700926989941362, 12.719872380803372, 13.627330826501703, 14.50691066594675, 15.480741191272188, 16.42323060729736, 17.409577768168614, 18.45882492643033, 17.34747717497245, 16.462842662756906, 15.48078009212585, 14.48976924573349, 13.592933759775617, 12.618828178245217, 11.648373298200905, 10.715371968450492, 9.747949288051569, 9.19901057898912, 9.728560894382612, 10.664768764522396, 11.69752836038437, 12.569236360617362, 13.584745548647765, 14.599888722251332, 15.4929257565612, 16.533201874449265, 17.47517990702342, 18.28777213659387, 16.416722367453566, 15.538047660847013, 14.515623367865183, 13.531836438334013, 12.558865265202183, 11.66928664365657, 10.689592366933118, 9.720057620782546, 8.765636419866272, 8.199984846335436, 8.79090865537085, 9.792551005238884, 10.698255591230899, 11.538043357086268, 12.551595228849298, 13.608166845124709, 14.529901866722192, 15.514398174593197, 16.460870436848083, 17.356210906827084, 15.438258098357917, 14.491384812959781, 13.515343806134492, 12.599652339974996, 11.535088227556571, 10.655112456869634, 9.698811269000089, 8.847483589196473, 7.82182575665549, 7.168519285648683, 7.781259025854294, 8.721097748915293, 9.649666966377888, 10.59011532303508, 11.596488310201451, 12.591449108724614, 13.569709135412973, 14.53438177316896, 15.4951852241119, 16.392000515861326, 14.570617101146647, 13.497206694006088, 12.536030661276808, 11.599115481293357, 10.601151962504929, 9.752020704318193, 8.746268285080662, 7.79225961150197, 6.8061152215266505, 6.1266666713134015, 6.809177147940683, 7.785003882001339, 8.827422258151838, 9.739376489182401, 10.729342565921796, 11.766865713319783, 12.607467181825733, 13.63967965220319, 14.67317464264569, 15.534806469035367, 13.660543511982736, 12.708592300505012, 11.658619340943794, 10.666423769126158, 9.633560489103044, 8.682530533059083, 7.7386416970788865, 6.769543677474494, 5.810632128315625, 5.05520260761798, 5.8645939990636755, 6.8215482589885275, 7.85765686672024, 8.7241196916931, 9.704110957734228, 10.763188839334848, 11.640822446868432, 12.643236055235079, 13.603997828100235, 14.582097781069317], [12.662289651328493, 13.57370701408598, 12.58036467854199, 11.62057252500042, 10.665655361776924, 9.660957046688074, 8.646675143766236, 7.771924475476748, 6.761728441929432, 5.755846875220847, 4.847724185261576, 3.8222378005216076, 4.786180473162002, 5.776173371804105, 6.728407838803539, 7.699443666060201, 8.7379446004708, 9.75013655961964, 10.73516964009382, 11.677994200920057, 11.689890003331055, 12.634974097684314, 11.738712307109108, 10.680174446012476, 9.745021041287176, 8.767807828336373, 7.7067819396883, 6.7715562081336085, 5.784809201501148, 4.763693172305598, 3.8095879142968183, 2.879954904895554, 3.8821875184611248, 4.831329846353466, 5.801442445990803, 6.807812327328315, 7.7707726984735475, 8.815754191531052, 9.802373508571154, 10.749299897127175, 10.913141928762402, 11.821584193841403, 10.886523268661316, 9.888657911803422, 8.870393922990942, 7.871924304966932, 6.8227105914489155, 5.840141570198945, 4.870315254560373, 3.9174863080023057, 2.921863865086625, 1.942455458966235, 2.860627602804091, 3.8092115988767987, 4.782211488743566, 5.8384834693162855, 6.896367254383746, 7.9467991828585856, 8.91081405757502, 9.929135290186265, 9.933467270627544, 10.860175119002257, 9.875958452183209, 8.926147287811135, 7.91765000098391, 6.848893517971816, 5.865274014862039, 4.866189215342264, 3.9100170240486958, 2.963919957144713, 1.9180459462628172, 0.9300917544877938, 1.8937228031511855, 2.9388313719366987, 3.986945492906825, 4.999615958156555, 6.069107427086349, 7.0072370490759, 8.004773378291233, 8.942281218026425, 8.98844397036204, 9.895259600763522, 8.927417026709195, 7.887734325829892, 6.923527459366614, 5.989879530658061, 5.00082788538304, 4.05809197176022, 3.0756604858609413, 2.044160514259874, 0.9768184680617304, 0.0, 0.9929680543776648, 2.017792481528647, 3.081201366703933, 4.0380317226514695, 5.10572945422472, 6.132715308515152, 7.1099522130534645, 8.050543366333851, 9.915975080916558, 10.871181082413289, 9.914672897672252, 8.886747696173577, 7.861078901196159, 6.923471841480962, 5.96183022600046, 4.92851507906683, 3.9556022186312756, 2.96995036501127, 2.0353603761534753, 1.0220435760529283, 1.994327688418104, 2.9657388891322602, 4.032068900546875, 4.996653151488696, 5.9714270942842, 6.997332114433673, 7.933897324931076, 8.98534697020564, 10.83472088086368, 11.81030637704547, 10.892990463413023, 9.829294255345566, 8.853022003491493, 7.9623252694735065, 6.889910346415098, 5.874609025783141, 4.919419268224198, 3.905730391972714, 2.9840277333751746, 2.072599590511253, 3.0030801289417193, 3.9594817244470524, 4.967298504746703, 5.94600816325076, 6.9042611238014455, 7.931951978080235, 8.897412612513829, 9.902766548907646, 11.801927194161822, 12.74712185855003, 11.799511159644895, 10.78783164251941, 9.767074601991434, 8.79933531326446, 7.81267525469718, 6.821117808223242, 5.8612351584524625, 4.922378037819777, 4.0217462754973905, 3.1044025385156444, 3.935174464803705, 5.001256273461618, 5.937548347283509, 6.879641862579862, 7.826966452478522, 8.758824132757045, 9.784079652765412, 10.77533596450886, 12.730527250265979, 13.726658075638285, 12.752465546761842, 11.825203623388665, 10.798462435358331, 9.781378375964103, 8.817309509892688, 7.875815417324557, 6.8501430849567155, 5.88544008816913, 5.07368677397014, 4.055570027392546, 4.877839103791097, 5.9415674849327775, 6.895176207922556, 7.816807954207894, 8.821456479295415, 9.761048184552376, 10.798017121924318, 11.735888176589558, 13.726720565204786, 14.669694516578673, 13.787584781940184, 12.750308311805686, 11.766917225649653, 10.770730968704633, 9.696145932577341, 8.760739724350495, 7.790938032437197, 6.8555425201932625, 6.03983507993197, 5.05698601014852, 5.8911753283208, 6.824728173090362, 7.88387820308421, 8.802739332392253, 9.876711557925494, 10.712742426215616, 11.66765934335874, 12.655578585114693, 14.69211500707446, 15.576493274486714, 14.59552041242394, 13.587733965951898, 12.645835486178663, 11.579607762055451, 10.63396313629158, 9.687009005449216, 8.770097781731913, 7.878376194852148, 6.989141537896585, 6.087347668243792, 6.919131944021467, 7.866101329796852, 8.791301773200317, 9.762442923114488, 10.818097262325924, 11.756579730308758, 12.697429280703005, 13.667226800506512, 15.634001165149762, 16.545988661303205, 15.504394448902874, 14.544711675607719, 13.611439414659305, 12.623885510932102, 11.654475385024986, 10.66719798756037, 9.812808833372085, 8.86929669556772, 7.964525061422768, 7.112848251448456, 7.873535302047795, 8.847777387189096, 9.807385103813017, 10.735216762313662, 11.693515223188282, 12.678062635422096, 13.701643406826108, 14.599689012086767, 16.56014997629345, 17.369475081272938, 16.43986125855326, 15.476008989809664, 14.631221522360855, 13.636485528084634, 12.66283167439562, 11.73690242868566, 10.820622768214998, 9.922778342922593, 8.972578020424, 8.154866220778702, 8.84846391271604, 9.846903986918973, 10.836289763677772, 11.678715302287053, 12.624828279298548, 13.595074862645303, 14.560060929261528, 15.585977503499304, 17.501838006791445, 17.364881671234393, 16.327715332719993, 15.401419843453317, 14.59400136182147, 13.707768119854073, 12.703428789979586, 11.710446081610367, 10.72941911472972, 10.993587974857874, 10.014776802969003, 9.202499207357006, 9.841534636608301, 10.804359853555942, 11.77508776007497, 12.616242091646912, 13.590967470806381, 14.583524975513175, 15.567761709715151, 16.510455300644995, 17.354094071180747, 16.39606069064082, 15.400512399408889, 14.438720756636604, 13.65656133781353, 12.672317140041455, 11.720808578980348, 10.70088265886929, 9.796433510388514, 10.723093784398282, 10.986615571517694, 10.152100154893036, 10.80053631135164, 11.81948170221365, 12.726940147911982, 13.596823192562594, 14.570653717888032, 15.513143133913204, 16.499490294784458, 17.548737453046176, 16.370658706910717, 15.48602419469517, 14.503961624064116, 13.512950777671756, 12.616115291713887, 11.642009710183487, 10.671554830139176, 9.738553500388761, 8.771130819989837, 9.715587573644298, 10.618410652202734, 11.199521193415565, 11.731226916599315, 12.741768409052076, 13.741986852933156, 14.534418607451629, 15.59401060665977, 16.58453834319375, 17.452245608797117, 17.310953668532136, 15.439903899391833, 14.56122919278528, 13.53880489980345, 12.55501797027228, 11.582046797140451, 10.69246817559484, 9.712773898871388, 8.743239152720815, 7.788817951804541, 8.826815602621377, 9.680758413190972, 10.682400763059004, 11.588105349051018, 12.427893114906388, 13.441444986669417, 14.498016602944828, 15.426023192670502, 16.410519500541508, 17.304878215745802, 16.37939243876535, 14.461439630296184, 13.514566344898048, 12.538525338072759, 11.622833871913263, 10.55826975949484, 9.678293988807905, 8.72199280093836, 7.870665121134743, 6.845007288593759, 7.833050098376907, 8.671108783674415, 9.610947506735412, 10.539516724198007, 11.4799650808552, 12.48633806802157, 13.481298866544734, 14.465830461361284, 15.43050309911727, 16.39130655006021, 15.415182047799595, 13.593798633084914, 12.520388225944355, 11.559212193215075, 10.622297013231623, 9.624333494443198, 8.775202236256462, 7.7694498170189314, 6.81544114344024, 5.82929675346492, 6.812323876957647, 7.699026905760803, 8.674853639821459, 9.717272015971957, 10.655264594025, 11.645230670764393, 12.68275381816238, 13.523355286668332, 14.55556775704579, 15.58906274748829, 14.557988000973634, 12.683725043921006, 11.73177383244328, 10.68180087288206, 9.689605301064425, 8.656742021041312, 7.7057120649973525, 6.761823229017156, 5.7927252094127635, 4.833813660253894, 5.881623461423633, 6.754443756883796, 7.711398016808648, 8.758822596464137, 9.640007796535699, 10.619999062576825, 11.679076944177446, 12.556710551711031, 13.559124160077678, 14.519885932942834, 13.703262277617775], [11.74453946765415, 12.693259798690127, 13.573332732919654, 12.613540579378084, 11.658623416154589, 10.653925101065738, 9.6396431981439, 8.764892529854412, 7.754696496307097, 6.748814929598511, 5.840692239639241, 4.815205854899273, 4.030004535166765, 4.865516943148726, 5.810657655129196, 6.781693482385858, 7.8201944167964585, 8.8323863759453, 9.817419456419477, 10.760244017245714, 10.772139819656712, 11.71722391400997, 12.695681120803153, 11.67314250039014, 10.73798909566484, 9.760775882714038, 8.699749994065964, 7.764524262511273, 6.777777255878813, 5.756661226683263, 4.802555968674483, 3.872922959273219, 2.9644373347867807, 3.9135796626791217, 4.88369226231646, 5.890062143653972, 6.853022514799204, 7.898004007856709, 8.884623324896811, 9.831549713452832, 9.920173874384737, 10.940316443787005, 11.87949132303898, 10.881625966181087, 9.863361977368609, 8.864892359344598, 7.815678645826581, 6.833109624576609, 5.863283308938038, 4.91045436237997, 3.91483191946429, 2.9354235133439, 1.9428774191297475, 2.891461415202455, 3.8644613050692223, 4.9207332856419415, 5.978617070709402, 7.029048999184241, 7.993063873900676, 8.9361672358086, 8.94049921624988, 9.978907368947857, 10.868926506560873, 9.9191153421888, 8.910618055361574, 7.841861572349481, 6.858242069239704, 5.85915726971993, 4.902985078426361, 3.956888011522378, 2.911014000640482, 1.9230598088654585, 0.9759726194768421, 1.9514327649095216, 2.9995468858796484, 4.006647903778891, 5.076139372708685, 6.014268994698235, 7.011805323913568, 7.94931316364876, 7.9954759159843745, 9.02716011527837, 9.920385081086861, 8.880702380207557, 7.916495513744279, 6.982847585035726, 5.993795939760705, 5.051060026137885, 4.068628540238606, 3.037128568637539, 1.9697865224393953, 0.9929680543776648, 0.0, 1.0248244271509825, 2.0882333123262686, 3.045063668273805, 4.112761399847056, 5.139747254137488, 6.1169841586758, 7.057575311956186, 8.923007026538894, 9.878213028035624, 10.869620041638877, 9.879715750551243, 8.854046955573825, 7.916439895858629, 6.9547982803781245, 5.921483133444495, 4.94857027300894, 3.9629184193889344, 3.0283284305311398, 2.015011630430593, 1.0013596340404392, 1.9727708347545951, 3.0391008461692097, 4.003685097111031, 4.978459039906536, 6.004364060056009, 6.940929270553411, 7.992378915827975, 9.841752826486015, 10.817338322667805, 11.88090266256392, 10.822262309723232, 9.845990057869159, 8.955293323851171, 7.882878400792762, 6.867577080160806, 5.912387322601862, 4.898698446350378, 3.9429318220956135, 2.9771508183080835, 2.0466702798776173, 2.966513670069387, 3.9743304503690373, 4.953040108873095, 5.911293069423781, 6.938983923702571, 7.904444558136164, 8.909798494529982, 10.808959139784157, 11.799626722682914, 12.747237421588048, 11.780799696897075, 10.760042656369098, 9.792303367642125, 8.805643309074846, 7.814085862600907, 6.854203212830127, 5.915346092197441, 4.934957250809353, 3.979278781562365, 2.978764615739603, 4.034673899649736, 4.944580292905844, 5.886673808202197, 6.8339983981008565, 7.765856078379381, 8.791111598387747, 9.782367910131196, 11.737559195888315, 12.733690021260621, 13.700191808704995, 12.81817167776633, 11.791430489735996, 10.774346430341767, 9.810277564270354, 8.868783471702223, 7.84311113933438, 6.878408142546794, 5.920818724628766, 4.88109253222174, 3.9214292547269953, 4.985157635868675, 5.938766358858453, 6.8238398998302285, 7.82848842491775, 8.76808013017471, 9.805049067546651, 10.742920122211894, 12.73375251082712, 13.676726462201007, 14.723378569560156, 13.71344096864134, 12.730049882485307, 11.733863625540288, 10.659278589412995, 9.72387238118615, 8.75407068927285, 7.818675177028917, 6.865357584761163, 5.882508514977713, 4.934765479256699, 5.86831832402626, 6.927468354020107, 7.809771278014588, 8.883743503547828, 9.71977437183795, 10.674691288981073, 11.662610530737027, 13.699146952696793, 14.649308702079798, 15.558653069259595, 14.550866622787552, 13.608968143014318, 12.542740418891105, 11.597095793127234, 10.65014166228487, 9.733230438567567, 8.841508851687802, 7.814664042725778, 6.893870093063629, 5.962722094957366, 6.90969148073275, 7.8348919241362145, 8.769474868736824, 9.82512920794826, 10.763611675931093, 11.70446122632534, 12.674258746128846, 14.641033110772096, 15.618804088896292, 16.467527105738526, 15.507844332443373, 14.57457207149496, 13.587018167767756, 12.61760804186064, 11.630330644396023, 10.775941490207739, 9.78634178257594, 8.79004756625196, 7.919370676268294, 6.917125452983694, 7.891367538124995, 8.850975254748915, 9.742248707935998, 10.700547168810617, 11.685094581044432, 12.708675352448443, 13.6067209577091, 15.567181921915784, 16.554625031579942, 16.349422092317273, 15.456593042997756, 14.618540616603147, 13.758274332737903, 12.933102265894696, 12.19176939065968, 11.783755425050652, 10.839823429930814, 9.798100525253194, 8.945248561631884, 7.892054063651938, 8.890494137854873, 9.87987991461367, 10.685747247909388, 11.631860224920883, 12.602106808267639, 13.567092874883864, 14.593009449121638, 16.508869952413782, 16.44713148756005, 15.409965149045652, 14.483669659778974, 13.68334493316609, 12.797111691198694, 11.883528629119315, 11.17979539048041, 11.722387169107387, 11.82371867705833, 10.840299307798196, 9.83252621252156, 8.885124787544198, 9.847950004491839, 10.818677911010868, 11.623274037269248, 12.597999416428717, 13.59055692113551, 14.574793655337487, 15.517487246267333, 16.436343887506403, 15.478310506966478, 14.482762215734546, 13.520970572962261, 12.74590490915815, 11.761660711386076, 10.810152150324969, 10.170231967739332, 10.78940156476618, 11.716061838775948, 11.781402554650594, 10.78212716005759, 9.844126462287537, 10.863071853149547, 11.77053029884788, 12.60385513818493, 13.577685663510369, 14.52017507953554, 15.506522240406795, 16.555769398668513, 15.452908523236372, 14.568274011020828, 13.586211440389773, 12.595200593997413, 11.705458863058508, 10.731353281528108, 9.760898401483797, 9.207902809258803, 9.764098874367503, 10.708555628021964, 11.611378706580398, 11.807576663397185, 10.774817067535212, 11.785358559987973, 12.785577003869054, 13.541450553073965, 14.601042552282108, 15.591570288816085, 16.459277554419455, 16.393203484857793, 14.52215371571749, 13.643479009110937, 12.621054716129107, 11.637267786597937, 10.664296613466108, 9.78181174693946, 8.80211747021601, 8.145486870424362, 8.781786006182207, 9.819783656999043, 10.673726467568637, 11.675368817436668, 11.81273064739219, 12.816551563519067, 13.818727323667522, 14.533172430200588, 15.538036035515223, 16.610373988672155, 16.387128032071463, 15.461642255091009, 13.54368944662184, 12.596816161223705, 11.620775154398416, 10.70508368823892, 9.640519575820496, 8.767637560152526, 7.81133637228298, 7.175531285845533, 7.837975342971425, 8.826018152754573, 9.664076838052079, 10.603915561113077, 11.532484778575672, 12.472933135232864, 13.479306122399235, 14.474266920922398, 15.458798515738948, 16.423471153494937, 15.49727223145675, 14.497431864125252, 12.67604844941057, 11.602638042270012, 10.641462009540732, 9.70454682955728, 8.706583310768854, 7.857452052582119, 6.858793388363552, 6.110509052987547, 6.822264807842585, 7.8052919313353115, 8.691994960138468, 9.667821694199123, 10.710240070349622, 11.648232648402665, 12.638198725142058, 13.675721872540045, 14.516323341045997, 15.548535811423454, 14.675052481286453, 13.64023781729929, 11.765974860246663, 10.814023648768936, 9.764050689207718, 8.771855117390082, 7.738991837366969, 6.787961881323009, 5.851166800361777, 5.074618979962514, 5.82678171463156, 6.874591515801297, 7.74741181126146, 8.704366071186312, 9.751790650841802, 10.632975850913363, 11.61296711695449, 12.67204499855511, 13.549678606088696, 14.552092214455342, 13.639438717546982, 12.785512093943431], [10.762099113670624, 11.710819444706601, 12.70416178025059, 13.62582872572007, 12.670911562496574, 11.666213247407724, 10.651931344485886, 9.777180676196398, 8.766984642649083, 7.761103075940497, 6.852980385981226, 5.827494001241258, 4.937516973314557, 3.9475240746724545, 4.865224970301025, 5.836260797557687, 6.874761731968287, 7.886953691117128, 8.871986771591306, 9.77780366326219, 9.789699465673186, 10.734783560026445, 11.713240766819627, 12.685430646732126, 11.750277242006826, 10.773064029056023, 9.71203814040795, 8.776812408853258, 7.790065402220798, 6.768949373025248, 5.814844115016468, 4.8852111056152046, 3.9436124584559247, 2.99558679420285, 3.9382595774882887, 4.9446294588258, 5.907589829971033, 6.952571323028538, 7.939190640068639, 8.849109359469306, 8.895349447233754, 9.91549201663602, 10.951321299874493, 11.832542756902722, 10.888186404519589, 9.889716786495578, 8.840503072977562, 7.857934051727592, 6.888107736089021, 5.935278789530953, 4.9271200658062755, 3.9477116596858854, 2.922052542798891, 1.9734685467261834, 2.9190286202410514, 3.9753006008137706, 5.004981161823833, 6.044313988882283, 7.008328863598718, 7.911342808657617, 7.915674789098896, 8.954082941796873, 9.920220968538361, 10.870032132910435, 9.935442482512556, 8.866685999500463, 7.883066496390686, 6.8839816968709115, 5.927809505577343, 4.981712438673361, 3.9358384277914644, 2.935347955207444, 1.9717169065440525, 0.9266083377585389, 1.9747224587286656, 2.981823476627908, 4.051314945557702, 4.9894445675472525, 5.986980896762585, 6.924488736497778, 6.970651488833392, 8.002335688127388, 8.970178262181715, 9.905526807358541, 8.941319940895262, 8.00767201218671, 7.018620366911688, 6.075884453288868, 5.093452967389589, 4.061952995788522, 2.9946109495903777, 2.017792481528647, 1.0248244271509825, 0.0, 1.0634088851752859, 2.0202392411228223, 3.0879369726960735, 4.114922826986505, 5.092159731524817, 6.032750884805203, 7.89818259938791, 8.85338860088464, 9.844795614487893, 10.872720815986568, 9.878871382724808, 8.941264323009612, 7.979622707529106, 6.946307560595477, 5.973394700159923, 4.987742846539917, 4.0531528576821225, 3.0398360575815753, 2.012732719968243, 1.041321519254087, 2.092866761963163, 2.9788606699600484, 3.953634612755553, 4.979539632905026, 5.916104843402429, 6.967554488676992, 8.816928399335032, 9.792513895516821, 10.856078235412935, 11.847086736874214, 10.870814485020142, 9.980117751002153, 8.907702827943744, 7.892401507311788, 6.937211749752845, 5.923522873501361, 4.954304908023417, 3.988523904235887, 3.058043365805421, 2.035064354568879, 3.042881134868529, 3.970960479503013, 4.886468642272799, 5.914159496551588, 6.879620130985181, 7.884974067378998, 9.784134712633174, 10.77480229553193, 11.722412994437065, 12.73409251156255, 11.78486708352008, 10.817127794793107, 9.830467736225827, 8.838910289751889, 7.87902763998111, 6.940170519348424, 5.946330336737156, 4.990651867490168, 3.9901377016674067, 3.1032245841492276, 4.013130977405336, 4.955224492701689, 5.850400960095218, 6.782258640373742, 7.807514160382108, 8.798770472125556, 10.71273476873733, 11.708865594109637, 12.675367381554011, 13.6916199516494, 12.816254916886978, 11.799170857492749, 10.835101991421336, 9.893607898853206, 8.867935566485365, 7.903232569697778, 6.932191810556569, 5.892465618149544, 4.932802340654799, 4.097322776986517, 5.028732879954922, 5.89239058432972, 6.853017009690525, 7.784482692169072, 8.821451629541013, 9.759322684206253, 11.719226813447442, 12.662200764821328, 13.708852872180477, 14.660819959144128, 13.741422968413112, 12.745236711468092, 11.6706516753408, 10.735245467113954, 9.765443775200655, 8.830048262956721, 7.876730670688968, 6.893881600905517, 5.946138565184503, 5.054921799517982, 6.017434875116576, 6.87832196251408, 7.9092197145711465, 8.736176933832311, 9.691093850975435, 10.679013092731388, 12.685858238643878, 13.636019988026883, 14.616992850089655, 15.562239708715357, 14.620341228942122, 13.55411350481891, 12.608468879055039, 11.661514748212674, 10.744603524495371, 9.852881937615606, 8.826037128653581, 7.905243178991434, 6.97409518088517, 6.101320676490226, 6.9695999017106205, 7.8380255532363154, 8.893679892447752, 9.80679138733937, 10.7208637883197, 11.690661308123207, 13.640431332995337, 14.605515374843376, 15.55490018171429, 15.442457672371532, 14.719169553448245, 13.90107385578207, 13.02346568678906, 12.641703730323828, 11.787314576135543, 10.797714868503745, 9.801420652179765, 8.930743762196098, 7.928498538911498, 7.082996733882471, 7.985683232323321, 8.81079939243549, 9.76909785331011, 10.753645265543923, 11.7458177121393, 12.623123519703462, 14.583584483910146, 15.541336317527026, 15.4039894074891, 14.511160358169585, 13.691825541578813, 12.840281464261631, 12.015109397418424, 12.809393483830094, 12.795128510978456, 11.851196515858618, 10.809473611180998, 9.956621647559688, 8.903427149579743, 8.082123333612348, 9.014587892188077, 9.75429793240888, 10.700410909420375, 11.67065749276713, 12.635643559383356, 13.609412011116, 15.539390121255405, 15.50169880273188, 14.46453246421748, 13.538236974950802, 12.756629858141757, 11.879118822722422, 10.965535760643043, 11.797419483650824, 12.73467531544937, 12.835091762986135, 11.851672393726, 10.843899298449365, 9.896497873472004, 9.124285811697295, 9.953385888585274, 10.69182472176874, 11.666550100928209, 12.659107605635002, 13.643344339836979, 14.548007415108954, 15.490911202678234, 14.532877822138307, 13.537329530906375, 12.57553788813409, 11.819189834133818, 10.843667842909804, 9.892159281848697, 10.787856060909746, 11.801689711108164, 12.728349985117932, 12.7927756405784, 11.793500245985395, 10.855499548215343, 10.15455601898731, 10.905238276422287, 11.672405822684421, 12.646236348009861, 13.588725764035033, 14.575072924906287, 15.588674770501832, 14.5074758384082, 13.622841326192656, 12.640778755561602, 11.649767909169242, 10.778743788034175, 9.813360413051836, 8.842905533007524, 9.825526902429218, 10.776387020709487, 11.720843774363948, 12.623666852922382, 12.818949749324991, 11.786190153463018, 11.149331384719254, 11.92028498144346, 12.610001237573456, 13.6695932367816, 14.660120973315577, 15.527828238918946, 15.44777080002962, 13.576721030889317, 12.698046324282764, 11.675622031300936, 10.691835101769765, 9.718863928637937, 8.863818878463189, 7.884124601739737, 8.866138549174654, 9.79407415252419, 10.832071803341027, 11.68601461391062, 12.687656963778654, 12.824103733319996, 12.180524388250348, 12.953435301241928, 13.60172311470008, 14.606586720014715, 15.678924673171647, 15.44169534724329, 14.516209570262836, 12.598256761793667, 11.651383476395532, 10.675342469570243, 9.759651003410749, 8.695086890992325, 7.8496446916762554, 6.893343503806709, 7.909818751211703, 8.85026348931341, 9.838306299096557, 10.676364984394063, 11.616203707455062, 12.544772924917657, 13.128452422301535, 13.977181195501327, 14.650901634419883, 15.566779451323933, 15.512642997571517, 14.551839546628576, 13.551999179297079, 11.730615764582398, 10.657205357441839, 9.696029324712558, 8.759114144729109, 7.761150625940683, 6.912019367753948, 5.940800519887281, 6.895824251598396, 7.834552954184571, 8.817580077677297, 9.704283106480451, 10.680109840541109, 11.722528216691607, 12.66052079474465, 13.650486871484043, 14.68801001888203, 15.528611487387982, 14.702767059051892, 13.726175178108912, 12.694805132471117, 10.78353450626314, 9.868590963940765, 8.818618004379546, 7.826422432561911, 6.793559152538798, 5.842529196494838, 4.933173931885506, 5.964430358665443, 6.839069860973545, 7.886879662143283, 8.759699957603445, 9.716654217528298, 10.764078797183787, 11.645263997255348, 12.625255263296475, 13.684333144897096, 14.561966752430681, 13.669489204220385, 12.656998363563456, 11.803071739959908], [9.69869022849534, 10.647410559531316, 11.640752895075305, 12.600545048616876, 13.63110188344843, 12.711956488076169, 11.697674585154331, 10.822923916864843, 9.812727883317526, 8.806846316608942, 7.897642078669929, 6.871166488383777, 5.907223815743382, 4.917230917101279, 3.960631386246702, 4.931667213503364, 5.970168147913965, 6.894930165107327, 7.869759607412852, 8.714394778086906, 8.726290580497901, 9.67137467485116, 10.649831881644342, 11.708369742740974, 12.643523147466274, 11.818807269724468, 10.757781381076395, 9.822555649521703, 8.835808642889242, 7.814692613693692, 6.860587355684912, 5.930954346283649, 4.957578837783237, 4.009553173530163, 3.0336659934339663, 3.984393034786293, 4.923517694258292, 5.951183374282014, 6.936963475890185, 7.785700474294021, 7.831940562058468, 8.852083131460734, 9.887912414699208, 10.769133871727437, 11.768070430627043, 10.953125671670866, 9.90391195815285, 8.921342936902878, 7.951516621264307, 6.99868767470624, 5.97286330647472, 4.99345490035433, 3.9360189221262036, 2.987434926053496, 2.014435036186729, 2.9334174101580825, 3.9415722766485475, 4.980905103706998, 5.9449199784234334, 6.847933923482331, 6.852265903923611, 7.890674056621588, 8.856812083363076, 9.80662324773515, 10.815120534562375, 9.93009488467575, 8.946475381565973, 7.947390582046198, 6.99121839075263, 6.045121323848647, 4.999247312966752, 3.99875684038273, 3.035125791719338, 1.9900172229338247, 1.070128874674343, 1.9184145914526223, 2.987906060382416, 3.9260356823719667, 4.923572011587299, 5.861079851322492, 5.907242603658107, 6.9389268029521025, 7.906769377006429, 8.946452077885732, 9.910658944349011, 9.071080897361997, 8.082029252086976, 7.139293338464155, 6.156861852564876, 5.125361880963808, 4.058019834765664, 3.0812013667039335, 2.0882333123262686, 1.0634088851752859, 0.0, 0.9568303559475366, 2.024528087520788, 3.0515139418112196, 4.028750846349532, 4.969341999629918, 6.834773714212625, 7.7899797157093555, 8.781386729312608, 9.809311930811283, 10.838087142289794, 10.004673208184899, 9.043031592704393, 8.009716445770763, 7.0368035853352096, 6.051151731715204, 5.116561742857409, 4.103244942756862, 3.067199088916648, 2.095787888202492, 1.0294578767878773, 1.915451784784763, 2.890225727580268, 3.916130747729741, 4.852695958227144, 5.904145603501707, 7.753519514159747, 8.729105010341536, 9.79266935023765, 10.798515359799975, 11.774787611654048, 11.04352663617744, 9.971111713119031, 8.955810392487074, 8.000620634928133, 6.986931758676648, 6.008771276971822, 5.042990273184292, 4.112509734753826, 3.089530723517284, 2.087594071312277, 2.9075515943277277, 3.8230597570975138, 4.850750611376303, 5.816211245809896, 6.821565182203713, 8.720725827457889, 9.711393410356646, 10.65900410926178, 11.670683626387264, 12.691440666915241, 11.880536679968392, 10.893876621401112, 9.902319174927174, 8.942436525156397, 8.00357940452371, 7.000796705685562, 6.045118236438574, 5.0446040706158115, 4.042118988241219, 3.0578439138490836, 3.9235320651072296, 4.786992074919933, 5.718849755198457, 6.744105275206823, 7.735361586950271, 9.649325883562046, 10.645456708934352, 11.611958496378726, 12.628211066474115, 13.65495225450445, 12.862579742668034, 11.898510876596621, 10.957016784028493, 9.931344451660651, 8.966641454873065, 7.986658179504975, 6.946931987097949, 5.987268709603204, 5.027054539388448, 4.07344581639867, 4.860698156735261, 5.78960812451524, 6.721073806993787, 7.758042744365728, 8.695913799030969, 10.655817928272157, 11.598791879646043, 12.645443987005192, 13.597411073968843, 14.580802160124875, 13.781954827085173, 12.70736979095788, 11.771963582731034, 10.802161890817736, 9.866766378573802, 8.913448786306049, 7.9305997165225985, 6.918206406689475, 5.984653561919913, 5.062147811560324, 5.846629534919621, 6.8458108293958615, 7.672768048657027, 8.62768496580015, 9.615604207556103, 11.622449353468593, 12.572611102851598, 13.55358396491437, 14.561370411386413, 14.856817339452245, 14.225415177649626, 13.64518699467212, 12.698232863829755, 11.781321640112452, 10.889600053232687, 9.862755244270662, 8.81763066543948, 7.886482667333217, 6.939513281557833, 6.0143128381543685, 6.806333125641856, 7.861987464853292, 8.743382502164085, 9.657454903144416, 10.627252422947922, 12.577022447820053, 13.542106489668091, 14.491491296539005, 14.537864088317207, 13.814575969393921, 13.153637264578876, 13.983747449533197, 13.678421845940909, 12.824032691752624, 11.829175269513224, 10.832881053189244, 9.843131248644145, 8.840886025359545, 7.921189338950078, 7.030396168767069, 7.779106964841031, 8.73740542571565, 9.721952837949464, 10.682408826964014, 11.559714634528177, 13.52017559873486, 14.477927432351741, 14.499395823434776, 13.606566774115262, 12.78723195752449, 12.092844873058437, 12.975391160162562, 13.769675246574234, 13.831846626595537, 12.882656916868097, 11.840934012190477, 10.869009134007735, 9.81581463602779, 8.920315938679956, 8.059300828631825, 8.722605504814421, 9.668718481825916, 10.638965065172671, 11.603951131788897, 12.546003125940715, 14.47598123608012, 14.597105218677557, 13.559938880163157, 12.633643390896479, 11.852036274087434, 11.131682231519228, 11.925817523387183, 12.757701246394964, 13.711519640312165, 13.749263262928016, 12.765843893667881, 11.756286784897412, 10.808885359920051, 9.962478416764903, 8.998098825029022, 9.66013229417428, 10.63485767333375, 11.627415178040543, 12.61165191224252, 13.484598529933669, 14.58631761862391, 13.628284238083983, 12.632735946852051, 11.670944304079766, 10.914596250079494, 10.096231251706609, 10.852441044592837, 11.748137823653886, 12.778534035970958, 13.705194309980726, 13.705163127026447, 12.705887732433442, 11.76788703466339, 10.992748624054919, 9.949951212866035, 10.640713395089962, 11.6145439204154, 12.557033336440572, 13.543380497311826, 14.525265885326547, 13.602882254353878, 12.718247742138333, 11.736185171507278, 10.745174325114919, 9.874150203979852, 9.06592382184864, 9.803187295751664, 10.785808665173358, 11.753231345572281, 12.697688099226742, 13.623038219460458, 13.731337235773038, 12.698577639911065, 11.987523989786862, 10.964997917887208, 11.578308809978997, 12.637900809187139, 13.628428545721116, 14.496135811324486, 14.543177215975298, 12.672127446834995, 11.793452740228442, 10.771028447246612, 9.787241517715442, 8.814270344583614, 8.116382287259993, 8.844406364483877, 9.826420311918794, 10.780841512835067, 11.818839163651901, 12.731757854579065, 13.733400204447097, 13.736491219768043, 13.011700109448704, 11.998148237685676, 12.570030687105621, 13.574894292420257, 14.647232245577186, 14.537101763188968, 13.611615986208514, 11.693663177739346, 10.74678989234121, 9.770748885515921, 8.855057419356426, 7.790493306938003, 7.064693429074782, 7.853625266550848, 8.870100513955842, 9.857960939446695, 10.846003749229842, 11.722108225062508, 12.661946948123505, 13.5905161655861, 13.959628143499891, 13.021894131945075, 13.619209206825424, 14.535087023729476, 14.608049413517195, 13.647245962574255, 12.647405595242757, 10.747878615762705, 9.752611773387518, 8.791435740658237, 7.854520560674786, 6.856557041886361, 6.007425783699626, 6.90108228263142, 7.856106014342535, 8.842250404317856, 9.825277527810583, 10.750026347148896, 11.725853081209552, 12.76827145736005, 13.706264035413096, 14.014634169997462, 14.554738070577313, 14.50332781028479, 13.639358173876607, 12.662766292933627, 11.712067983651425, 9.720125621087854, 8.927731831949345, 7.914024420325224, 6.921828848507588, 5.888965568484475, 4.937935612440516, 5.893455694629645, 6.924712121409582, 7.8827423481160634, 8.931541354831985, 9.80544319827189, 10.762397458196741, 11.80982203785223, 12.691007237923793, 13.67099850396492, 14.529703590875252, 13.536683075327488, 12.6060803190451, 11.593589478388171, 10.739662854784623], [8.741859872547803, 9.690580203583782, 10.68392253912777, 11.643714692669342, 12.674271527500895, 13.668786844023705, 12.654504941101868, 11.77975427281238, 10.769558239265063, 9.763676672556478, 8.854472434617465, 7.827996844331314, 6.86405417169092, 5.874061273048817, 4.917461742194239, 4.093136437611203, 5.038800936976724, 5.938099809159791, 6.912929251465315, 7.757564422139368, 7.7694602245503654, 8.714544318903625, 9.693001525696808, 10.75153938679344, 11.68669279151874, 12.663906004469542, 11.714611737023931, 10.77938600546924, 9.792638998836779, 8.771522969641229, 7.817417711632449, 6.887784702231185, 5.914409193730774, 4.9663835294776995, 3.9904963493815027, 3.0275626788387564, 3.9666873383107557, 4.994353018334477, 5.980133119942648, 6.828870118346485, 6.875110206110931, 7.895252775513199, 8.931082058751674, 9.812303515779899, 10.811240074679505, 11.809709692703516, 10.860742314100385, 9.878173292850413, 8.908346977211842, 7.955518030653774, 6.929693662422256, 5.950285256301866, 4.89284927807374, 3.9442652820010324, 2.9712653921342653, 1.976587054210546, 2.984741920701011, 4.024074747759461, 4.988089622475897, 5.8911035675347945, 5.895435547976074, 6.933843700674052, 7.899981727415539, 8.849792891787612, 9.858290178614837, 10.886925240623285, 9.903305737513508, 8.904220937993733, 7.948048746700165, 7.001951679796182, 5.956077668914286, 4.955587196330266, 3.9919561476668743, 2.946847578881361, 2.0269592306218795, 0.9615842355050856, 2.0310757044348797, 2.9692053264244302, 3.9667416556397628, 4.904249495374955, 4.950412247710569, 5.982096447004565, 6.949939021058892, 7.989621721938196, 8.953828588401475, 9.887476517110027, 9.03885960803451, 8.09612369441169, 7.11369220851241, 6.082192236911343, 5.0148501907132, 4.0380317226514695, 3.045063668273805, 2.0202392411228223, 0.9568303559475366, 0.0, 1.0676977315732512, 2.0946835858636828, 3.071920490401995, 4.012511643682381, 5.877943358265089, 6.833149359761819, 7.824556373365071, 8.852481574863747, 9.881256786342256, 10.818863846057452, 9.99986194865193, 8.9665468017183, 7.993633941282745, 7.0079820876627394, 6.073392098804945, 5.0600752987043975, 4.024029444864185, 3.052618244150029, 1.9862882327354139, 0.9586214288372262, 1.9333953716327312, 2.9593003917822043, 3.8958656022796068, 4.947315247554171, 6.796689158212209, 7.772274654393998, 8.835838994290112, 9.841685003852437, 10.81795725570651, 11.833947088356618, 10.872278336926762, 9.856977016294804, 8.898820951920117, 7.885132075668633, 6.879346885483809, 5.913565881696279, 4.983085343265813, 3.9372476771838993, 2.929430896884249, 1.950721238380191, 2.866229401149977, 3.8939202554287657, 4.859380889862359, 5.864734826256176, 7.763895471510351, 8.754563054409108, 9.702173753314241, 10.713853270439726, 11.734610310967703, 12.702349599694676, 11.795043245208843, 10.803485798734904, 9.840636842148381, 8.901779721515695, 7.871372314197548, 6.91569384495056, 5.915179679127799, 4.883955813813191, 3.8996807394210555, 2.9667017091596932, 3.8301617189723958, 4.76201939925092, 5.787274919259286, 6.7785312310027335, 8.692495527614508, 9.688626352986814, 10.655128140431188, 11.671380710526577, 12.698121898556911, 13.684392662394318, 12.799677500404352, 11.843255122314796, 10.817582789946954, 9.852879793159367, 8.857233788016961, 7.817507595609936, 6.857844318115191, 5.795215929096288, 4.841607206106509, 3.903867800787725, 4.832777768567703, 5.76424345104625, 6.801212388418191, 7.739083443083431, 9.698987572324619, 10.641961523698505, 11.688613631057654, 12.640580718021305, 13.623971804177337, 14.550116216793013, 13.47553118066572, 12.540124972438875, 11.570323280525576, 10.634927768281642, 9.681610176013889, 8.698761106230439, 7.686367796397314, 6.7528149516277525, 5.830309201268163, 4.889799178972084, 5.888980473448324, 6.71593769270949, 7.670854609852612, 8.658773851608567, 10.665618997521054, 11.61578074690406, 12.596753608966832, 13.604540055438875, 14.018286563560084, 15.035377010299712, 14.41334838437996, 13.466394253537596, 12.549483029820292, 11.657761442940528, 10.630916633978503, 9.58579205514732, 8.654644057041056, 7.707674671265671, 6.782474227862207, 5.84950276969432, 6.9051571089057555, 7.786552146216549, 8.70062454719688, 9.670422067000386, 11.620192091872514, 12.585276133720553, 13.534660940591467, 13.606496877379968, 12.97604519350176, 13.963599097228963, 14.91724815987789, 14.446583235648749, 13.592194081460464, 12.597336659221062, 11.601042442897082, 10.611292638351983, 9.609047415067383, 8.689350728657915, 7.798557558474908, 6.822276608893494, 7.780575069768114, 8.765122482001928, 9.72557847101648, 10.60288427858064, 12.563345242787324, 13.521097076404203, 13.568028612497535, 12.67519956317802, 11.948701181632329, 12.935238016818241, 13.908891870507254, 14.72650560252177, 14.600008016303377, 13.650818306575935, 12.609095401898315, 11.637170523715573, 10.583976025735629, 9.688477328387792, 8.789693386792901, 7.765775148866884, 8.711888125878378, 9.682134709225133, 10.647120775841358, 11.589172769993178, 13.519150880132583, 13.665738007740316, 12.628571669225916, 11.702276179959238, 11.013505498195272, 11.974075375279032, 12.88264787933472, 13.7145316023425, 14.668349996259701, 14.517424652635855, 13.53400528337572, 12.52444817460525, 11.57704674962789, 10.627313284031512, 9.643319614209412, 8.703301938226744, 9.678027317386212, 10.670584822093005, 11.654821556294982, 12.527768173986132, 13.65495040768667, 12.696917027146743, 11.70136873591481, 10.739577093142525, 10.076065474187333, 10.938624395466412, 11.809271400540373, 12.704968179601423, 13.735364391918495, 14.662024665928262, 14.473324516734285, 13.474049122141281, 12.536048424371229, 11.645154383287501, 10.595172002046425, 9.683883039142426, 10.657713564467862, 11.600202980493034, 12.586550141364288, 13.56843552937901, 12.671515043416637, 11.786880531201092, 10.804817960570038, 9.813807114177678, 9.03561942808769, 9.908316965608444, 10.7600176516992, 11.742639021120894, 12.710061701519818, 13.654518455174278, 14.579868575407994, 14.499498625480877, 13.466739029618903, 12.639929749019444, 11.610218707067599, 10.621478454031461, 11.6810704532396, 12.671598189773578, 13.539305455376947, 13.600900711303236, 11.740760235897755, 10.8620855292912, 9.839661236309372, 8.855874306778201, 7.975739568691452, 8.958775431019797, 9.801236720431413, 10.78325066786633, 11.737671868782604, 12.77566951959944, 13.688588210526602, 14.690230560394635, 14.504652609475881, 13.656920898629096, 12.643369026866067, 11.613200331158085, 12.61806393647272, 13.690401889629648, 13.594825258516906, 12.669339481536452, 10.762295966802105, 9.81542268140397, 8.83938167457868, 7.923690208419185, 6.951962531045841, 7.907086572834586, 8.810455622498385, 9.826930869903379, 10.814791295394231, 11.802834105177379, 12.678938581010044, 13.618777304071044, 14.547346521533639, 14.604848932680284, 13.65733964940105, 12.662378850877888, 13.578256667781938, 13.660700643813678, 12.704969457902193, 11.705129090570695, 9.791048259815167, 8.821244562450277, 7.860068529720995, 6.923153349737545, 6.018026265994199, 6.964256139647162, 7.857912638578957, 8.812936370290071, 9.799080760265392, 10.782107883758119, 11.706856703096433, 12.68268343715709, 13.725101813307589, 14.663094391360632, 14.635430862027764, 13.597907714629777, 13.546497454337254, 12.682527817929072, 11.705935936986092, 10.755237627703886, 8.763295265140316, 7.970901476001808, 6.982657209387983, 5.990461637570347, 5.050434792592314, 5.894765968388052, 6.850286050577181, 7.881542477357119, 8.8395727040636, 9.888371710779522, 10.762273554219426, 11.71922781414428, 12.766652393799768, 13.64783759387133, 14.627828859912457, 13.572873234927718, 12.579852719379954, 11.649249963097565, 10.636759122440637, 9.782832498837085], [7.690997589283911, 8.639717920319889, 9.633060255863878, 10.592852409405449, 11.623409244237003, 12.628107559325853, 13.613962813931659, 12.835646809142913, 11.803541631378495, 10.73669722970282, 9.74913139276557, 8.722655802479418, 7.758713129839024, 6.768720231196921, 5.812120700342343, 4.944359184964543, 3.987938653712831, 4.887237525895898, 5.862066968201423, 6.7067021388754755, 6.718597941286473, 7.663682035639733, 8.642139242432915, 9.700677103529546, 10.635830508254847, 11.61304372120565, 12.674069609853722, 11.835278541799774, 10.848531535167313, 9.827415505971762, 8.873310247962982, 7.943677238561718, 6.904953220588992, 5.92367674422424, 4.885155307529607, 3.878785426192096, 2.915825055046863, 3.943490735070584, 4.929270836678755, 5.778007835082592, 5.8242479228470385, 6.827555043939948, 7.863384327178423, 8.744605784206648, 9.743542343106254, 10.742011961130265, 11.764843191037055, 10.945871024423665, 9.976044708785095, 9.023215762227027, 7.997391393995508, 7.017982987875118, 5.960547009646992, 5.0119630135742845, 4.038963123707517, 2.991763422504579, 1.9338796374371185, 2.9732124644955684, 3.937227339212004, 4.840241284270902, 4.8277378164028235, 5.866145969100801, 6.832283995842288, 7.782095160214361, 8.790592447041586, 9.823787111340401, 10.807406614450178, 9.971918669566985, 9.015746478273417, 8.069649411369435, 7.023775400487539, 6.023284927903519, 5.059653879240127, 4.014545310454613, 3.094656962195131, 2.0292819670783366, 0.9802134211709872, 1.9183430431605375, 2.91587937237587, 3.853387212111062, 3.882714516137319, 4.9143987154313145, 5.882241289485641, 6.921923990364945, 7.886130856828223, 8.819778785536776, 9.808830430811797, 9.16382142598494, 8.181389940085662, 7.149889968484596, 6.082547922286452, 5.105729454224721, 4.112761399847057, 3.087936972696074, 2.024528087520788, 1.0676977315732512, 0.0, 1.0269858542904315, 2.0042227588287442, 2.944813912109131, 4.82975705673781, 5.78496305823454, 6.776370071837792, 7.804295273336468, 8.833070484814979, 9.753371096359679, 10.793630923208637, 10.005562119793384, 9.032649259357829, 8.046997405737823, 7.112407416880029, 6.0859613390581, 5.015430885347755, 4.044019684633599, 2.9776896732189844, 1.9305024792718424, 0.9557285364763374, 1.9816335566258103, 2.918198767123213, 3.919607311610348, 5.819022323055815, 6.794607819237605, 7.8086326666898795, 8.79349870232516, 9.769770954179233, 10.785760786829341, 11.769564977906152, 10.754263657274194, 9.796107592899506, 8.782418716648023, 7.776633526463199, 6.810852522675669, 5.880371984245203, 4.834534318163289, 3.8267175378636384, 2.8480078793595807, 1.888562565993583, 2.9162534202723718, 3.8817140547059648, 4.887067991099782, 6.7862286363539575, 7.776896219252714, 8.724506918157847, 9.736186435283331, 10.756943475811308, 11.724682764538281, 12.692329886188233, 11.700772439714294, 10.737923483127771, 9.799066362495084, 8.748462507130814, 7.792784037883825, 6.7922698720610635, 5.72618806340315, 4.7419129890110145, 3.7998194737146616, 2.852494883816002, 3.784352564094526, 4.809608084102892, 5.8008643958463395, 7.714828692458115, 8.710959517830421, 9.677461305274793, 10.693713875370182, 11.720455063400516, 12.706725827237923, 13.668708945810291, 12.67747287899254, 11.651800546624699, 10.687097549837112, 9.691451544694706, 8.65172535228768, 7.692062074792936, 6.628333693651256, 5.674724970661478, 4.736985565342693, 3.855110933411309, 4.786576615889856, 5.823545553261797, 6.761416607927037, 8.721320737168227, 9.664294688542114, 10.710946795901263, 11.66291388286491, 12.646304969020942, 13.642491225965962, 14.308648945220689, 13.373242736993843, 12.403441045080545, 11.46804553283661, 10.514727940568857, 9.531878870785407, 8.519485560952283, 7.585932716182721, 6.663426965823131, 5.722916943527053, 4.91131363829193, 5.738270857553096, 6.693187774696218, 7.681107016452173, 9.687952162364663, 10.638113911747668, 11.61908677381044, 12.626873220282484, 13.568771700055718, 14.598429854310709, 15.246466148934928, 14.299512018092564, 13.38260079437526, 12.490879207495496, 11.464034398533471, 10.418909819702288, 9.487761821596024, 8.54079243582064, 7.615591992417175, 6.682620534249288, 5.930458588999095, 6.808885311060154, 7.722957712040485, 8.692755231843993, 10.642525256716123, 11.607609298564162, 12.556994105435075, 12.555634594116075, 13.488906855064489, 14.476460758791692, 15.44587088469881, 15.279701000203717, 14.425311846015433, 13.43045442377603, 12.43416020745205, 11.444410402906952, 10.442165179622352, 9.522468493212884, 8.631675323029876, 7.655394373448463, 6.9287040637597475, 7.809693507743209, 8.747911635860085, 9.625217443424248, 11.585678407630931, 12.543430241247812, 12.517166329233643, 11.624337279914128, 12.575941056627302, 13.570677050903523, 14.544330904592536, 15.585779188101588, 15.433125780858346, 14.483936071130904, 13.442213166453282, 12.470288288270542, 11.417093790290597, 10.52159509294276, 9.622811151347872, 8.598892913421853, 7.980424789286321, 8.780017886034466, 9.745003952650691, 10.611505934836785, 12.54148404497619, 12.614875724476423, 11.577709385962024, 10.651413896695345, 11.640745373190246, 12.70515468855167, 13.741201478082361, 14.609190560490607, 15.563008954407808, 15.350542417190821, 14.367123047930686, 13.357565939160219, 12.410164514182858, 11.46043104858648, 10.47643737876438, 9.536419702781712, 8.946563980794155, 9.768467998902338, 10.752704733104315, 11.550101338829739, 12.604088124422777, 11.64605474388285, 10.650506452650918, 9.688714809878633, 10.748507212036042, 11.754433283342085, 12.70393035868848, 13.599627137749529, 14.630023350066601, 15.556683624076369, 15.306442281289254, 14.30716688669625, 13.369166188926197, 12.47827214784247, 11.428289766601393, 10.517000803697394, 9.926250227875805, 10.75111835720998, 11.721960346559902, 12.590768694222618, 11.620652760152744, 10.7360182479372, 9.753955677306145, 8.762944830913785, 9.81392249906892, 10.753268447065224, 11.654676609847307, 12.637297979269, 13.604720659667924, 14.549177413322385, 15.4745275335561, 15.332616390035845, 14.299856794173872, 13.473047513574413, 12.443336471622567, 11.45459621858643, 10.949607116647543, 11.822513566490525, 12.67471566057256, 12.550038428039343, 10.689897952633862, 9.811223246027307, 8.788798953045477, 7.8050120235143075, 8.80477043297575, 9.803726912476577, 10.69589567857952, 11.677909626014436, 12.63233082693071, 13.670328477747546, 14.595829928042734, 15.660797644329415, 15.33777037403085, 14.490038663184063, 13.476486791421035, 12.446318095713053, 11.912631006486553, 12.841317266346595, 12.543962975253013, 11.61847719827256, 9.711433683538212, 8.764560398140077, 7.788519391314788, 6.872827925155292, 7.803185278399181, 8.758309320187927, 9.705114580646491, 10.721589828051485, 11.709450253542336, 12.697493063325483, 13.586180298526177, 14.591797861217385, 15.52036707867998, 15.43796669723525, 14.490457413956019, 13.495496615432856, 12.872823737795771, 12.609838360549785, 11.6541071746383, 10.654266807306803, 8.740185976551274, 7.770382279186384, 6.809206246457102, 5.872291066473652, 6.869249013347539, 7.858915097795267, 8.752571596727062, 9.707595328438176, 10.693739718413497, 11.676766841906224, 12.614098420612565, 13.655703994303432, 14.69812237045393, 15.584458283083505, 14.52402143627252, 13.486498288874532, 12.495635171073362, 11.63166553466518, 10.6550736537222, 9.704375344439994, 7.712432981876424, 6.9200391927379155, 5.93179492612409, 4.939599354306455, 5.901657539945654, 6.789424926536157, 7.744945008725286, 8.776201435505223, 9.734231662211705, 10.783030668927626, 11.735294111365768, 12.69224837129062, 13.73967295094611, 14.569201485594203, 13.584179811544063, 12.522010951663825, 11.528990436116061, 10.598387679833673, 9.585896839176744, 8.731970215573194], [6.734119766873826, 7.6828400979098035, 8.676182433453793, 9.635974586995363, 10.666531421826916, 11.671229736915766, 12.657084991521572, 13.652785786341466, 12.722923052947513, 11.656078651271837, 10.668512814334587, 9.642037224048435, 8.67809455140804, 7.688101652765938, 6.73150212191136, 5.863740606533558, 4.907320075281848, 3.9303597034858138, 4.905189145791338, 5.749824316465391, 5.761720118876388, 6.706804213229647, 7.685261420022829, 8.74379928111946, 9.67895268584476, 10.656165898795562, 11.717191787443635, 12.652417518998327, 11.767912956736332, 10.746796927540782, 9.792691669532001, 8.863058660130736, 7.82433464215801, 6.843058165793257, 5.804536729098624, 4.798166847761112, 3.8352064766158795, 2.9866129126604997, 3.972393014268671, 4.821130012672508, 4.833745808734808, 5.800569189649516, 6.836398472887991, 7.717619929916216, 8.716556488815822, 9.715026106839833, 10.737857336746625, 11.755897681459354, 10.919419182267488, 9.96659023570942, 8.925845094934305, 7.946436688813914, 6.889000710585788, 5.940416714513081, 4.967416824646314, 3.911144844073595, 2.853261059006135, 2.016334642085484, 2.9803495168019194, 3.8833634618608177, 3.8007519621123915, 4.839160114810369, 5.805298141551856, 6.755109305923929, 7.763606592751154, 8.796801257049971, 9.780420760159748, 10.75523537989946, 10.042732332563848, 9.096635265659865, 8.050761254777969, 7.05027078219395, 6.086639733530558, 5.041531164745044, 4.043259518010496, 2.9690863116697974, 1.8995948427400036, 0.9614652207504533, 1.9590015499657858, 2.896509389700978, 2.855728661846887, 3.887412861140883, 4.855255435195209, 5.894938136074513, 6.859145002537791, 7.792792931246344, 8.781844576521365, 9.724580490144186, 9.208375794376092, 8.176875822775026, 7.109533776576883, 6.132715308515152, 5.139747254137488, 4.114922826986505, 3.051513941811219, 2.0946835858636828, 1.0269858542904315, 0.0, 0.9772369045383125, 1.9178280578186988, 3.802771202447378, 4.757977203944108, 5.74938421754736, 6.777309419046036, 7.806084630524546, 8.726385242069247, 9.766645068918205, 10.649829130929433, 10.05963511364826, 9.073983260028255, 8.13939327117046, 7.112947193348531, 6.0424167396381865, 5.07100553892403, 4.0046755275094155, 2.9574883335622735, 1.9827143907667688, 1.048060934431971, 1.9117956170623218, 2.892621457319916, 4.795973290570741, 5.77155878675253, 6.7816468123994476, 7.7665128480347265, 8.742785099888799, 9.758774932538907, 10.77299187273299, 11.595923077645743, 10.823093447189938, 9.809404570938455, 8.80361938075363, 7.837838376966101, 6.907357838535635, 5.861520172453721, 4.85370339215407, 3.874993733650012, 2.9155484202840145, 1.9826807980785326, 2.8759139327714847, 3.8812678691653018, 5.763179603868883, 6.753847186767639, 7.701457885672772, 8.713137402798257, 9.733894443326234, 10.701633732053207, 11.688293790620486, 12.542431860085843, 11.764909337418203, 10.815329859626775, 9.755727650389758, 8.80004918114277, 7.799535015320008, 6.7334532066620945, 5.749178132269959, 4.807084616973606, 3.859760027074947, 2.9279023467964227, 3.8156330978172592, 4.806889409560707, 6.69177965997304, 7.687910485345347, 8.654412272789719, 9.670664842885108, 10.697406030915442, 11.683676794752849, 12.692928045815995, 13.611112091326428, 12.659065689883644, 11.694362693096057, 10.69871668795365, 9.658990495546625, 8.69932721805188, 7.635598836910201, 6.681990113920422, 5.744250708601638, 4.8623760766702535, 3.9301263985917525, 4.857004261046359, 5.767441621641405, 7.698271704683152, 8.64124565605704, 9.687897763416188, 10.639864850379833, 11.623255936535866, 12.619442193480886, 13.62614159373475, 14.380507880252788, 13.41070618833949, 12.475310676095555, 11.521993083827802, 10.539144014044352, 9.526750704211228, 8.593197859441666, 7.670692109082076, 6.730182086785997, 5.896342780998195, 4.881820640254992, 5.804926684410987, 6.792845926166941, 8.664903129879589, 9.615064879262594, 10.596037741325366, 11.603824187797409, 12.545722667570644, 13.575380821825632, 14.521025447589503, 15.306777161351508, 14.389865937634205, 13.49814435075444, 12.471299541792416, 11.426174962961234, 10.49502696485497, 9.548057579079586, 8.62285713567612, 7.689885677508233, 6.890917561744884, 5.95243509376205, 6.834696621755254, 7.804494141558761, 9.619476224231049, 10.584560266079087, 11.53394507295, 12.493627846245156, 13.426900107193571, 14.414454010920775, 15.383864136827892, 16.28696614346266, 15.432576989274377, 14.437719567034977, 13.441425350710997, 12.451675546165898, 11.449430322881298, 10.52973363647183, 9.63894046628882, 8.662659516707407, 7.889163036505536, 6.953243290445105, 7.859650545574853, 8.736956353139016, 10.626677014389763, 11.520381208762737, 12.048657758829806, 12.543718701483145, 13.49532247819632, 14.49005847247254, 15.463712326161554, 16.505160609670604, 16.440390924117292, 15.49120121438985, 14.44947830971223, 13.477553431529488, 12.424358933549543, 11.528860236201707, 10.630076294606816, 9.606158056680798, 8.893814252083116, 7.923567668736362, 8.888553735352586, 9.723244844551553, 11.637498126735027, 12.083315401363208, 11.109200815558188, 11.570795318264363, 12.560126794759263, 13.624536110120687, 14.660582899651379, 15.52857198205962, 16.48239037597682, 16.35780756044977, 15.374388191189635, 14.364831082419165, 13.417429657441804, 12.467696191845425, 11.483702522023325, 10.543684846040657, 9.85995344359095, 8.912017781604233, 9.89625451580621, 10.661840248544507, 11.761478927219086, 11.046639185393982, 10.181997882247082, 10.60809623144765, 11.66788863360506, 12.673814704911102, 13.623311780257493, 14.519008559318543, 15.549404771635615, 16.476065045645385, 16.3137074245482, 15.314432029955196, 14.376431332185144, 13.485537291101414, 12.435554909860338, 11.524265946956339, 10.837157555937047, 9.894668139911875, 10.865510129261796, 11.702507603937386, 10.736130439961277, 10.088472200047912, 9.117515140850752, 9.682326252482802, 10.733303920637937, 11.672649868634243, 12.574058031416321, 13.556679400838014, 14.524102081236938, 15.468558834891398, 16.393908955125113, 16.339881533294793, 15.307121937432818, 14.480312656833357, 13.450601614881512, 12.461861361845374, 11.860514444708786, 10.966063349192419, 11.818265443274456, 11.59316060562926, 9.805375632442395, 9.023021327944258, 8.074005155036081, 8.724393445083326, 9.72415185454477, 10.723108334045596, 11.615277100148534, 12.59729104758345, 13.551712248499724, 14.58970989931656, 15.51521134961175, 16.58017906589843, 16.345035517289798, 15.497303806443007, 14.48375193467998, 13.453583238971998, 12.823538334547795, 11.98486704904849, 11.58708515284293, 10.661599375862476, 8.826911363346746, 7.976358480057027, 7.00669141039907, 7.792209346724309, 8.722566699968198, 9.677690741756942, 10.624496002215505, 11.640971249620499, 12.628831675111352, 13.616874484894499, 14.505561720095193, 15.511179282786403, 16.406931472563063, 15.46648311590587, 14.4601101287395, 13.465149330216336, 12.500999302250516, 11.6529605381397, 10.697229352228216, 9.697388984896719, 7.78330815414119, 6.982180361103334, 6.027378265541385, 6.791672488042669, 7.788630434916555, 8.778296519364282, 9.671953018296078, 10.626976750007191, 11.613121139982512, 12.59614826347524, 13.533479842181581, 14.575085415872449, 15.617503792022948, 14.62758046067342, 13.567143613862434, 12.529620466464447, 11.538757348663276, 10.674787712255094, 9.698195831312114, 8.74749752202991, 6.75555515946634, 5.963161370327831, 4.995487162254186, 5.858980775875471, 6.821038961514669, 7.708806348105173, 8.664326430294302, 9.695582857074239, 10.653613083780723, 11.702412090496644, 12.654675532934785, 13.611629792859638, 14.604113790739278, 13.612323663184117, 12.627301989133978, 11.56513312925374, 10.572112613705976, 9.641509857423587, 8.629019016766659, 7.775092393163109], [5.7695550713995525, 6.7182754024355305, 7.71161773797952, 8.67140989152109, 9.692009039238325, 10.696707354327176, 11.682562608932981, 12.678263403752876, 13.641561383470481, 12.633315555810148, 11.645749718872898, 10.619274128586746, 9.655331455946351, 8.66533855730425, 7.708739026449672, 6.840977511071871, 5.88455697982016, 4.907596608024126, 3.9967724470914536, 4.785259620991117, 4.797155423402114, 5.742239517755374, 6.720696724548556, 7.769276898530869, 8.704430303256169, 9.681643516206972, 10.742669404855045, 11.677895136409736, 12.664642143042197, 11.724033832079092, 10.769928574070311, 9.840295564669047, 8.801571546696321, 7.82029507033157, 6.781773633636936, 5.775403752299424, 4.812443381154192, 3.963849817198812, 3.063976315568787, 3.8565653171982337, 3.856508904196496, 4.823332285111203, 5.859161568349677, 6.740383025377904, 7.73931958427751, 8.73778920230152, 9.76062043220831, 10.778660776921038, 11.71550038993167, 10.943827140247732, 9.903081999472617, 8.923673593352227, 7.866237615124102, 6.917653619051395, 5.944653729184628, 4.888381748611908, 3.8304979635444476, 2.993571546623796, 2.0719328181020353, 2.9187987663865433, 2.8235150575740793, 3.861923210272056, 4.828061237013544, 5.777872401385617, 6.786369688212842, 7.819564352511658, 8.803183855621434, 9.777998475361148, 10.734170666654716, 10.073872170198179, 9.027998159316283, 8.027507686732262, 7.063876638068871, 6.018768069283357, 5.020496422548808, 3.94632321620811, 2.8768317472783163, 1.9387021252887657, 1.0199849588766097, 1.9319446942267038, 1.8784917573085749, 2.9101759566025707, 3.878018530656897, 4.917701231536201, 5.881908097999479, 6.815556026708032, 7.804607671983053, 8.747343585605874, 9.729775071505152, 9.15411272731334, 8.086770681115196, 7.109952213053465, 6.116984158675801, 5.092159731524818, 4.028750846349532, 3.0719204904019954, 2.0042227588287442, 0.9772369045383125, 0.0, 0.9405911532803864, 2.8255342979090656, 3.780740299405796, 4.7721473130090475, 5.800072514507724, 6.8288477259862335, 7.749148337530935, 8.789408164379893, 9.67259222639112, 10.645505086826676, 9.988297812432371, 9.053707823574577, 8.027261745752647, 6.956731292042303, 5.985320091328147, 4.918990079913532, 3.8718028859663898, 2.897028943170885, 1.871123923021412, 0.9345587125240095, 1.9153845527816034, 3.818736386032429, 4.794321882214218, 5.804409907861135, 6.789275943496414, 7.765548195350487, 8.781538028000595, 9.795754968194677, 10.618686173107431, 11.576842237482118, 10.72371912334257, 9.717933933157747, 8.752152929370217, 7.821672390939751, 6.775834724857837, 5.768017944558187, 4.789308286054129, 3.829862972688131, 2.805743786667974, 1.8986770282331724, 2.9040309646269895, 4.785942699330571, 5.776610282229327, 6.72422098113446, 7.735900498259944, 8.756657538787922, 9.724396827514894, 10.711056886082174, 11.56519495554753, 12.518658127710383, 11.638392848216219, 10.578790638979202, 9.623112169732213, 8.62259800390945, 7.556516195251536, 6.572241120859401, 5.630147605563048, 4.682823015664388, 3.7509653353858643, 2.838396193278947, 3.829652505022395, 5.714542755434728, 6.710673580807034, 7.677175368251406, 8.693427938346796, 9.72016912637713, 10.706439890214536, 11.715691141277683, 12.633875186788115, 13.482128678473085, 12.517425681685499, 11.521779676543092, 10.482053484136067, 9.522390206641322, 8.458661825499643, 7.505053102509864, 6.5673136971910795, 5.685439065259695, 4.7531893871811945, 3.8797673565080464, 4.790204717103093, 6.72103480014484, 7.664008751518726, 8.710660858877876, 9.662627945841521, 10.646019031997554, 11.642205288942574, 12.648904689196439, 13.577047553313236, 14.23376917692893, 13.298373664684997, 12.345056072417243, 11.362207002633793, 10.34981369280067, 9.416260848031108, 8.493755097671517, 7.553245075375439, 6.719405769587636, 5.704883628844435, 4.827689779872674, 5.815609021628629, 7.687666225341276, 8.637827974724281, 9.618800836787054, 10.626587283259097, 11.568485763032331, 12.59814391728732, 13.54378854305119, 14.503316834411956, 15.212928926223647, 14.321207339343882, 13.294362530381857, 12.249237951550676, 11.318089953444412, 10.371120567669028, 9.445920124265562, 8.512948666097675, 7.713980550334328, 6.775498082351493, 5.857459717216941, 6.827257237020449, 8.642239319692736, 9.607323361540775, 10.556708168411689, 11.516390941706844, 12.449663202655259, 13.437217106382462, 14.40662723228958, 15.464040124407862, 16.25563997786382, 15.260782555624418, 14.264488339300438, 13.27473853475534, 12.27249331147074, 11.352796625061272, 10.462003454878262, 9.485722505296849, 8.71222602509498, 7.776306279034548, 6.882413641036541, 7.759719448600704, 9.64944010985145, 10.543144304224425, 11.472758126944104, 12.44768825590879, 13.425382308719826, 14.420118302996046, 15.39377215668506, 16.43522044019411, 17.263453912706733, 16.31426420297929, 15.272541298301672, 14.30061642011893, 13.247421922138985, 12.351923224791149, 11.453139283196258, 10.42922104527024, 9.716877240672561, 8.746630657325806, 7.951151035393105, 8.746007940013241, 10.660261222196715, 11.174898702663324, 12.060973711237136, 12.548032222802675, 13.537363699297575, 14.601773014658999, 15.637819804189691, 16.505808886597933, 17.459627280515136, 17.180870549039213, 16.197451179779076, 15.187894071008607, 14.240492646031246, 13.290759180434867, 12.306765510612767, 11.366747834630099, 10.683016432180395, 9.735080770193678, 8.958851815846728, 9.684603344006195, 10.796914231744813, 10.138222486694097, 11.13377077792603, 11.585333135985962, 12.645125538143372, 13.651051609449414, 14.600548684795806, 15.496245463856855, 16.526641676173927, 17.453301950183697, 17.13677041313764, 16.137495018544637, 15.199494320774585, 14.308600279690856, 13.25861789844978, 12.34732893554578, 11.660220544526492, 10.71773112850132, 9.928107429302315, 10.725270699399074, 9.771565744487004, 9.180055501348027, 10.094752045389065, 10.659563157021115, 11.710540825176249, 12.649886773172556, 13.551294935954633, 14.533916305376327, 15.50133898577525, 16.445795739429713, 17.37114585966343, 17.162944521884235, 16.13018492602226, 15.303375645422799, 14.273664603470953, 13.284924350434816, 12.68357743329823, 11.789126337781864, 10.880862743314974, 10.628595910154985, 8.840810936968122, 8.114604629244374, 9.051242059574394, 9.701630349621638, 10.701388759083082, 11.700345238583909, 12.592514004686846, 13.574527952121763, 14.528949153038036, 15.566946803854872, 16.492448254150062, 17.44059350535165, 16.48306467778132, 15.449846454482785, 14.519291327524623, 13.501490943400096, 12.496627338085462, 11.584625736178017, 10.622520457368655, 9.697034680388201, 7.862346667872472, 7.067941781357143, 7.9839283149373825, 8.769446251262622, 9.699803604506508, 10.654927646295253, 11.601732906753817, 12.618208154158811, 13.606068579649664, 14.594111389432811, 15.482798624633505, 16.370935994551385, 15.44236677708879, 14.501918420431597, 13.495545433265226, 12.500584634742063, 11.536434606776243, 10.688395842665427, 9.732664656753942, 8.732824289422444, 6.8187434586669164, 6.07376366240345, 7.004615170079697, 7.768909392580981, 8.765867339454866, 9.755533423902596, 10.64918992283439, 11.604213654545504, 12.590358044520825, 13.573385168013552, 14.510716746719893, 15.552322320410758, 14.660969511094768, 13.65602784175537, 12.602578918388161, 11.565055770990174, 10.574192653189003, 9.710223016780821, 8.733631135837841, 7.782932826555636, 5.790990463992066, 5.0547446716279465, 5.972724066792498, 6.8362176804137835, 7.798275866052982, 8.686043252643486, 9.641563334832615, 10.672819761612551, 11.630849988319033, 12.679648995034954, 13.631912437473096, 14.588866697397947, 13.632561171821228, 12.640771044266067, 11.655749370215927, 10.600568433779467, 9.607547918231703, 8.676945161949314, 7.664454321292386, 6.810527697688835], [4.8289639181191655, 5.7776842491551434, 6.771026584699133, 7.730818738240704, 8.751417885957938, 9.756116201046789, 10.741971455652594, 11.737672250472489, 12.700970230190094, 13.573906709090535, 12.586340872153285, 11.559865281867133, 10.595922609226738, 9.605929710584636, 8.64933017973006, 7.781568664352258, 6.805458619488122, 5.793266660339281, 4.795696683996534, 3.8446684677107306, 3.8565642701217273, 4.801648364474987, 5.780105571268169, 6.828685745250482, 7.763839149975782, 8.741052362926585, 9.802078251574658, 10.73730398312935, 11.72405098976181, 12.626418505680807, 11.710519727350698, 10.780886717949434, 9.742162699976708, 8.760886223611957, 7.722364786917323, 6.715994905579811, 5.753034534434579, 4.849519869513967, 3.862900552473867, 2.915974163917847, 2.9159177509161096, 3.8827411318308167, 4.918570415069292, 5.799791872097517, 6.798728430997123, 7.797198049021134, 8.820029278927924, 9.838069623640653, 10.774909236651283, 11.693242931135904, 10.843673152753004, 9.864264746632614, 8.806828768404488, 7.85824477233178, 6.885244882465013, 5.8289729018922944, 4.771089116824834, 3.934162699904183, 2.980809239906935, 1.9782076131061568, 1.8829239042936927, 2.9213320569916696, 3.887470083733157, 4.83728124810523, 5.845778534932455, 6.878973199231271, 7.862592702341048, 8.837407322080761, 9.793579513374329, 10.739676580278312, 9.968589312596668, 8.968098840012647, 8.004467791349256, 6.9593592225637435, 5.961087575829195, 4.886914369488497, 3.817422900558703, 2.8792932785691523, 1.9288613806815096, 0.9913535409463173, 0.9379006040281884, 1.969584803322184, 2.9374273773765105, 3.977110078255814, 4.941316944719092, 5.874964873427645, 6.864016518702666, 7.806752432325486, 8.789183918224765, 9.820683889825833, 9.027361834395581, 8.050543366333851, 7.057575311956187, 6.032750884805204, 4.969341999629918, 4.012511643682382, 2.9448139121091303, 1.9178280578186988, 0.9405911532803864, 0.0, 1.884943144628679, 2.84014914612541, 3.8315561597286614, 4.859481361227337, 5.8882565727058465, 6.808557184250548, 7.848817011099506, 8.732001073110734, 9.704913933546289, 10.690565787166294, 9.994298976854964, 8.967852899033034, 7.89732244532269, 6.925911244608534, 5.859581233193919, 4.812394039246777, 3.8376200964512717, 2.8117150763017986, 1.875149865804396, 0.9747933995012169, 2.8781452327520425, 3.8537307289338316, 4.863818754580749, 5.848684790216027, 6.8249570420701, 7.840946874720208, 8.85516381491429, 9.678095019827044, 10.636251084201731, 11.626345814127738, 10.658525086438132, 9.692744082650602, 8.762263544220136, 7.716425878138224, 6.708609097838573, 5.729899439334515, 4.770454125968517, 3.74633493994836, 2.839268181513559, 1.963835687419592, 3.8453515460501846, 4.836019128948941, 5.783629827854074, 6.795309344979558, 7.816066385507535, 8.783805674234507, 9.770465732801787, 10.624603802267144, 11.578066974429996, 12.545269443972536, 11.519381792259589, 10.5637033230126, 9.563189157189838, 8.497107348531923, 7.512832274139787, 6.570738758843434, 5.623414168944774, 4.69155648866625, 3.778987346559334, 2.9721809921515208, 4.773951602154342, 5.770082427526648, 6.73658421497102, 7.7528367850664095, 8.779577973096744, 9.76584873693415, 10.775099987997296, 11.693284033507728, 12.65304028411829, 13.458016834965884, 12.462370829823477, 11.422644637416452, 10.462981359921708, 9.399252978780028, 8.44564425579025, 7.507904850471466, 6.626030218540081, 5.69378054046158, 4.820358509788433, 3.9327332042322185, 5.7804436468644536, 6.72341759823834, 7.770069705597489, 8.722036792561136, 9.705427878717169, 10.701614135662188, 11.708313535916052, 12.636456400032849, 13.606258091946147, 14.238964817965382, 13.285647225697629, 12.302798155914179, 11.290404846081055, 10.356852001311493, 9.434346250951902, 8.493836228655825, 7.659996922868022, 6.64547478212482, 5.768280933153061, 4.998197368822212, 6.74707507206089, 7.697236821443894, 8.678209683506667, 9.68599612997871, 10.627894609751944, 11.657552764006935, 12.603197389770806, 13.56272568113157, 14.585417841240863, 15.261798492624267, 14.234953683662242, 13.18982910483106, 12.258681106724797, 11.311711720949413, 10.386511277545948, 9.45353981937806, 8.654571703614712, 7.716089235631879, 6.798050870497328, 6.009845584214032, 7.70164816641235, 8.666732208260388, 9.616117015131302, 10.575799788426457, 11.509072049374872, 12.496625953102075, 13.466036079009193, 14.523448971127475, 15.587456009529937, 16.201373708904804, 15.205079492580824, 14.215329688035725, 13.213084464751125, 12.293387778341657, 11.402594608158648, 10.426313658577234, 9.652817178375365, 8.716897432314934, 7.823004794316928, 6.942307795794287, 8.708848956571066, 9.602553150944038, 10.532166973663717, 11.507097102628403, 12.484791155439439, 13.47952714971566, 14.453181003404673, 15.494629286913725, 16.531782345166608, 17.254855356259675, 16.213132451582055, 15.241207573399315, 14.18801307541937, 13.292514378071534, 12.393730436476643, 11.369812198550624, 10.657468393952946, 9.687221810606191, 8.891742188673492, 7.928596287206824, 9.71967006891633, 10.565576226438075, 11.471623916935336, 12.413363378374973, 13.402694854869873, 14.440689791254869, 15.47673658078556, 16.46971928915478, 17.484481808114374, 18.1214617023196, 17.138042333059463, 16.128485224288994, 15.181083799311631, 14.231350333715252, 13.247356663893152, 12.307338987910484, 11.62360758546078, 10.675671923474063, 9.809885282129624, 8.867191691199778, 9.856323078464426, 10.814356459004353, 11.809904750236285, 12.506234775653924, 13.566027177811334, 14.571953249117376, 15.541139838076193, 16.436836617137242, 17.467232829454318, 18.393893103464084, 18.077361566418027, 17.078086171825024, 16.14008547405497, 15.24919143297124, 14.199209051730165, 13.287920088826166, 12.600811697806877, 11.658322281781706, 10.779140895585211, 9.907859046592657, 8.830974591206617, 9.898676882895225, 10.88073945352628, 11.580464796689077, 12.631442464844211, 13.570788412840518, 14.49188608923502, 15.474507458656714, 16.44193013905564, 17.3863868927101, 18.311737012943816, 17.503789264972898, 16.550989797186254, 15.540448304733491, 14.595348369340032, 13.552621667246333, 12.519060074644084, 11.6628382827537, 10.622144821120914, 9.688004756874598, 7.900219783687734, 8.913528866149454, 9.880490821532508, 10.6225319892896, 11.622290398751044, 12.62124687825187, 13.533105157967233, 14.51511910540215, 15.469540306318423, 16.50753795713526, 17.43303940743045, 16.500002352071263, 15.542473524500934, 14.509255301202398, 13.578700174244236, 12.56089979011971, 11.556036184805075, 10.64403458289763, 9.681929304088268, 8.756443527107814, 6.921755514592085, 7.866866018262223, 8.813177076895496, 9.690347890930584, 10.640394757786895, 11.59551879957564, 12.542324060034204, 13.558799307439198, 14.54665973293005, 15.534702542713198, 16.423389777913894, 15.430344841270998, 14.501775623808403, 13.56132726715121, 12.55495427998484, 11.559993481461676, 10.595843453495856, 9.74780468938504, 8.792073503473555, 7.792233136142057, 5.878152305386529, 6.87268789930853, 7.833863932037811, 8.689811032248944, 9.706458492735253, 10.696124577182983, 11.589781076114777, 12.54480480782589, 13.530949197801212, 14.513976321293939, 15.45130790000028, 14.650831930574778, 13.720378357814381, 12.715436688474982, 11.661987765107774, 10.624464617709787, 9.633601499908616, 8.769631863500434, 7.793039982557454, 6.842341673275249, 4.850399310711679, 5.8536689085330265, 6.858394119107654, 7.757119320081745, 8.738867019333368, 9.626634405923873, 10.582154488113002, 11.613410914892938, 12.57144114159942, 13.620240148315341, 14.572503590753483, 13.687376307561967, 12.691970018540841, 11.70017989098568, 10.71515821693554, 9.65997728049908, 8.666956764951316, 7.736354008668927, 6.723863168011999, 5.869936544408448], [4.915180598748545, 5.863900929784522, 6.857243265328512, 7.754214522465145, 8.736548584184657, 9.741246899273508, 10.727102153879313, 11.722802948699208, 12.686100928416813, 13.603702906822775, 14.471284016781963, 13.444808426495811, 12.480865753855417, 11.490872855213315, 10.534273324358738, 9.666511808980937, 8.690401764116801, 7.678209804967961, 6.680639828625213, 5.72961161233941, 3.9427809507511067, 4.887865045104366, 5.8663222518975475, 6.813816443477202, 7.748969848202502, 8.726183061153304, 9.787208949801377, 10.722434681356068, 11.70918168798853, 12.611549203907526, 13.565654461916306, 12.665829862578112, 11.627105844605387, 10.645829368240635, 9.607307931546002, 8.600938050208491, 7.637977679063257, 6.734463014142647, 5.747843697102546, 4.800917308546526, 2.925059687488412, 3.8918830684031187, 4.921725944424196, 5.784922570324237, 6.783859129223844, 7.782328747247854, 8.805159977154645, 9.823200321867374, 10.760039934878002, 11.678373629362623, 12.719118770137738, 11.749207891261293, 10.691771913033167, 9.743187916960458, 8.770188027093692, 7.713916046520973, 6.656032261453513, 5.819105844532862, 4.865752384535614, 3.863150757734836, 1.892065840865995, 2.9304739935639716, 3.8726007819598767, 4.8224119463319495, 5.830909233159175, 6.864103897457991, 7.847723400567768, 8.82253802030748, 9.778710211601048, 10.72480727850503, 11.770681289386927, 10.833530554595354, 9.869899505931963, 8.82479093714645, 7.846030720457874, 6.771857514117175, 5.702366045187381, 4.764236423197831, 3.8138045253101884, 2.8762966855749963, 0.9470425406004905, 1.954715501548904, 2.9225580756032303, 3.962240776482534, 4.926447642945812, 5.860095571654365, 6.849147216929386, 7.791883130552206, 8.774314616451484, 9.805814588052552, 10.873156634250696, 9.915975080916558, 8.923007026538894, 7.898182599387911, 6.834773714212625, 5.877943358265089, 4.82975705673781, 3.802771202447378, 2.8255342979090656, 1.884943144628679, 0.0, 0.9552060014967305, 1.9466130150999823, 2.974538216598658, 4.003313428077168, 4.940920487792364, 5.981180314641323, 7.014495461574953, 7.987408322010507, 8.973060175630513, 9.907650164488308, 9.074780789214119, 8.004250335503775, 7.0328391347896195, 5.966509123375005, 4.919321929427863, 3.9445479866323576, 2.9186429664828846, 1.9820777559854819, 0.9306281107109184, 0.9932020881233633, 1.9687875843051525, 2.9788756099520706, 3.9637416455873486, 4.940013897441421, 5.956003730091529, 6.987527118456107, 7.960589408291264, 8.918745472665952, 9.908840202591957, 10.765452976619219, 9.799671972831689, 8.869191434401223, 7.8233537683193095, 6.815536988019659, 5.836827329515601, 4.877382016149603, 3.853262830129446, 2.9250243350231107, 1.9196703986292933, 1.960408401421505, 2.951075984320261, 3.898686683225394, 4.910366200350879, 5.931123240878856, 6.898862529605829, 7.885522588173108, 8.877080034647047, 9.860561362894217, 10.827763832436757, 11.626309682440674, 10.670631213193685, 9.670117047370923, 8.604035238713008, 7.619760164320873, 6.67766664902452, 5.73034205912586, 4.798484378847336, 3.8647435000688857, 2.9280157033612224, 2.8890084575256623, 3.8851392828979687, 4.851641070342341, 5.86789364043773, 6.894634828468065, 7.880905592305471, 8.890156843368617, 9.881392910186367, 10.907065242554209, 11.79082588278611, 12.569298720004564, 11.529572527597539, 10.569909250102794, 9.506180868961115, 8.552572145971336, 7.614832740652552, 6.732958108721167, 5.800708430642666, 4.906114663297985, 3.88856791544192, 3.895500502235774, 4.838474453609661, 5.88512656096881, 6.837093647932456, 7.82048473408849, 8.81667099103351, 9.823370391287373, 10.758776599514219, 11.728578291427517, 12.663973803671452, 13.392575115878715, 12.409726046095265, 11.397332736262141, 10.46377989149258, 9.54127414113299, 8.60076411883691, 7.766924813049108, 6.752402672305906, 5.854037086662613, 4.954032080031913, 4.862131927432211, 5.812293676815215, 6.793266538877987, 7.80105298535003, 8.742951465123266, 9.772609619378256, 10.718254245142127, 11.68504588061294, 12.707738040722234, 13.684566464168874, 14.34188157384333, 13.296756995012148, 12.365608996905884, 11.4186396111305, 10.493439167727034, 9.560467709559145, 8.761499593795797, 7.823017125812964, 6.88380702400688, 5.887020134000158, 5.816705021783671, 6.781789063631709, 7.73117387050262, 8.690856643797774, 9.62412890474619, 10.611682808473393, 11.58109293438051, 12.638505826498793, 13.702512864901255, 14.675486964884445, 15.31200738276191, 14.322257578216812, 13.320012354932212, 12.400315668522744, 11.509522498339734, 10.533241548758319, 9.75974506855645, 8.823825322496019, 7.869461229588807, 6.819482345580413, 6.823905811942386, 7.717610006315358, 8.647223829035037, 9.622153957999721, 10.599848010810756, 11.594584005086977, 12.56823785877599, 13.609686142285042, 14.646839200537928, 15.618197094943994, 16.320060341763142, 15.348135463580402, 14.294940965600457, 13.39944226825262, 12.500658326657728, 11.47674008873171, 10.764396284134031, 9.794149700787276, 8.840466361488359, 7.798078284736532, 7.834726924287649, 8.680633081809395, 9.586680772306655, 10.528420233746292, 11.517751710241193, 12.555746646626186, 13.591793436156879, 14.5847761445261, 15.599538663485696, 16.576667463067757, 17.244970223240546, 16.235413114470077, 15.288011689492718, 14.338278223896337, 13.354284554074237, 12.414266878091569, 11.730535475641865, 10.720361042058123, 9.679367279659333, 8.736673688729487, 8.780576191834921, 9.717309297778622, 10.513883705617761, 11.475675348390046, 12.455191734249132, 13.461117805555174, 14.513981409724838, 15.55833602167254, 16.5325242678269, 17.49605371363481, 18.18428945659911, 17.185014062006108, 16.247013364236057, 15.356119323152326, 14.30613694191125, 13.39484797900725, 12.577459470011346, 11.634970053986175, 10.64862289311492, 9.777341044122366, 9.80592467909273, 10.675476283124691, 11.57836644701409, 12.401445327354894, 13.452422995510029, 14.426528577040429, 15.475102147327593, 16.457723516749287, 17.425146197148212, 18.369602950802673, 18.42180630720461, 17.52718504919734, 16.574385581410695, 15.563844088957932, 14.618744153564473, 13.576017451470774, 12.542455858868525, 11.832841471294726, 10.793092418904488, 9.858952354658172, 9.785162928316414, 10.798472010778134, 11.765433966161186, 12.50747513391828, 13.507233543379725, 14.506190022880551, 15.418048302595912, 16.400062250030828, 17.3544834509471, 18.392481101763934, 17.484154068192847, 16.523398136295704, 15.565869308725375, 14.532651085426838, 13.602095958468677, 12.58429557434415, 11.579431969029516, 10.814037771438656, 9.852876901871841, 8.927391124891388, 8.806698659220764, 9.751809162890902, 10.698120221524174, 11.575291035559264, 12.525337902415576, 13.48046194420432, 14.427267204662883, 15.443742452067877, 16.43160287755873, 17.405662806478176, 16.47450443867629, 15.453740625495438, 14.525171408032843, 13.58472305137565, 12.57835006420928, 11.583389265686117, 10.619239237720297, 9.834021370014419, 8.946140220634625, 7.963180733925631, 7.763095450015209, 8.75763104393721, 9.71880707666649, 10.574754176877624, 11.591401637363933, 12.581067721811662, 13.474724220743456, 14.42974795245457, 15.41589234242989, 16.398919465922617, 15.54688293736273, 14.635962628801497, 13.7055090560411, 12.700567386701701, 11.685383549332215, 10.647860401934228, 9.656997284133057, 8.855848544129813, 7.879256663186833, 7.013289271058822, 6.7353424553403585, 7.738612053161706, 8.743337263736333, 9.642062464710426, 10.623810163962048, 11.511577550552552, 12.46709763274168, 13.498354059521617, 14.456384286228099, 15.50518329294402, 14.602299788485723, 13.672507005788686, 12.67710071676756, 11.6853105892124, 10.70028891516226, 9.68337306472352, 8.690352549175756, 7.822570689298306, 6.810079848641378, 5.989932523209031], [5.870386600245276, 4.975785213619377, 5.969127549163367, 6.799008520968415, 7.781342582687928, 8.786040897776779, 9.771896152382583, 10.767596947202478, 11.730894926920083, 12.648496905326045, 13.636062742263295, 14.40001442799254, 13.436071755352145, 12.446078856710043, 11.489479325855466, 10.621717810477666, 9.645607765613534, 8.633415806464692, 7.635845830121943, 6.68481761383614, 4.897986952247837, 3.999749328939221, 4.978206535732403, 5.858610441980471, 6.7937638467057715, 7.770977059656573, 8.832002948304646, 9.767228679859338, 10.753975686491799, 11.656343202410795, 12.610448460419576, 13.54008146982084, 12.582311846102115, 11.601035369737364, 10.56251393304273, 9.55614405170522, 8.593183680559987, 7.689669015639377, 6.703049698599276, 5.7561233100432565, 3.8802656889851423, 2.9990935071504086, 3.966519942927466, 4.829716568827506, 5.828653127727113, 6.827122745751124, 7.849953975657914, 8.867994320370642, 9.804833933381271, 10.723167627865893, 11.763912768641008, 12.704413892758023, 11.646977914529897, 10.698393918457189, 9.725394028590422, 8.669122048017703, 7.611238262950243, 6.774311846029592, 5.820958386032344, 4.818356759231566, 2.8472718423627255, 2.0376844323112615, 2.9173947804631464, 3.867205944835219, 4.8757032316624445, 5.90889789596126, 6.892517399071037, 7.86733201881075, 8.823504210104318, 9.7696012770083, 10.815475287890196, 11.788736556092086, 10.825105507428695, 9.779996938643182, 8.801236721954604, 7.727063515613906, 6.657572046684112, 5.719442424694561, 4.769010526806919, 3.8315026870717266, 1.902248542097221, 0.9995095000521735, 1.9673520741065, 3.0070347749858035, 3.9712416414490814, 4.904889570157635, 5.893941215432656, 6.8366771290554755, 7.819108614954755, 8.850608586555822, 9.917950632753966, 10.871181082413289, 9.878213028035624, 8.853388600884642, 7.7899797157093555, 6.833149359761819, 5.78496305823454, 4.757977203944108, 3.780740299405796, 2.8401491461254094, 0.9552060014967305, 0.0, 0.9914070136032517, 2.0193322151019273, 3.048107426580437, 3.985714486295633, 5.025974313144591, 6.059289460078221, 7.032202320513775, 8.017854174133781, 8.952444162991576, 9.978890240813506, 8.959456337000505, 7.98804513628635, 6.921715124871735, 5.874527930924593, 4.899753988129088, 3.873848967979615, 2.9372837574822124, 1.885834112207649, 1.9484080896200937, 1.0137405388721707, 2.02366960845534, 3.008535644090618, 3.9848078959446904, 5.000797728594798, 6.032321116959375, 7.0053834067945315, 7.96353947116922, 8.953634201095225, 9.901111520213275, 10.75487797432842, 9.824397435897954, 8.77855976981604, 7.770742989516389, 6.792033331012331, 5.832588017646334, 4.808468831626176, 3.8802303365198414, 2.874876400126024, 2.9156144029182354, 2.0248024595104877, 2.9724131584156206, 3.9840926755411052, 5.004849716069082, 5.972589004796055, 6.959249063363335, 7.950806509837273, 8.905355361397485, 9.872557830940025, 10.932160040177042, 11.625837214690415, 10.625323048867653, 9.559241240209738, 8.574966165817603, 7.63287265052125, 6.68554806062259, 5.753690380344066, 4.819949501565616, 3.883221704857953, 3.8442144590223926, 3.097736428432073, 3.9253675455325667, 4.941620115627956, 5.96836130365829, 6.954632067495697, 7.9638833185588425, 8.955119385376593, 9.980328671085779, 10.835619881289379, 11.831265886431785, 12.48477852909427, 11.525115251599525, 10.461386870457845, 9.507778147468066, 8.570038742149283, 7.6881641102178975, 6.755914432139396, 5.861320664794715, 4.843773916938651, 4.850706503732504, 4.071926668938085, 4.96048678071091, 5.910820123122682, 6.894211209278716, 7.890397466223735, 8.897096866477598, 9.832503074704444, 10.802304766617743, 11.737700278861677, 12.69101787112943, 13.364932047591996, 12.352538737758872, 11.41898589298931, 10.49648014262972, 9.555970120333642, 8.722130814545839, 7.707608673802636, 6.809243088159343, 5.9092380815286445, 5.817337928928941, 5.140835051960822, 6.018169752959938, 6.909022887473276, 7.838172204772113, 8.846336094568482, 9.791980720332353, 10.758772355803165, 11.78146451591246, 12.7582929393591, 13.640324329094044, 14.251962996508878, 13.320814998402614, 12.37384561262723, 11.448645169223765, 10.515673711055877, 9.716705595292527, 8.778223127309694, 7.83901302550361, 6.8422261354968885, 6.771911023280401, 6.110330438777316, 6.956077084584572, 7.915759857879726, 8.849032118828141, 9.836586022555345, 10.805996148462462, 11.738961337914319, 12.80296837631678, 13.749213440074671, 14.615707852620227, 15.277463579713542, 14.275218356428942, 13.355521670019474, 12.464728499836465, 11.488447550255051, 10.71495107005318, 9.779031323992749, 8.824667231085538, 7.774688347077143, 7.779111813439116, 7.046151381460965, 7.891543894234959, 8.847057172081673, 9.824751224892708, 10.819487219168929, 11.793141072857942, 12.80866577903961, 13.810782311159693, 14.78214020556576, 15.623760811621459, 16.303341465077132, 15.250146967097187, 14.354648269749351, 13.45586432815446, 12.431946090228442, 11.719602285630762, 10.749355702284006, 9.795672362985089, 8.753284286233262, 8.78993292578438, 8.009174456955003, 8.83100083750658, 9.772740298946216, 10.759946908329765, 11.780649860708138, 12.81669665023883, 13.80967935860805, 14.763481774107461, 15.740610573689521, 16.66595959416646, 17.190619115966808, 16.243217690989447, 15.293484225393069, 14.309490555570969, 13.3694728795883, 12.685741477138595, 11.675567043554851, 10.634573281156062, 9.691879690226216, 9.735782193331652, 9.04585067292423, 9.758203770817685, 10.71999541358997, 11.697386932337704, 12.703313003643746, 13.75617660781341, 14.800531219761112, 15.696467378448668, 16.659996824256577, 17.637798362715152, 17.505560668394335, 16.549870185161637, 15.575641799498454, 14.525659418257378, 13.558406864863079, 12.610606746143533, 11.97712166226491, 10.990774501393656, 10.732547045619095, 10.76113068058946, 10.0040176582703, 10.822686512214016, 11.645765392554818, 12.696743060709952, 13.670848642240353, 14.719422212527517, 15.70204358194921, 16.669466262348134, 17.613923016002595, 17.46660030570788, 16.57197904770061, 15.619179579913963, 14.608638087461202, 13.663538152067742, 12.620811449974044, 11.587249857371795, 10.94472575512958, 10.038019187380998, 10.769083916894454, 10.740368929813144, 11.069468530373953, 11.866196498028687, 12.603698199954295, 13.603456609415739, 14.602413088916565, 15.582107365640017, 16.564121313074935, 17.518542513991207, 17.481922365668197, 16.528948066696117, 15.568192134798974, 14.610663307228645, 13.577445083930108, 12.646889956971947, 11.62908957284742, 10.624225967532785, 9.92592205527351, 9.02370971720566, 9.83752268712767, 9.761904660717494, 10.707015164387633, 11.653326223020905, 12.530497037055996, 13.480543903912304, 14.435667945701049, 15.382473206159613, 16.398948453564607, 17.386808879055458, 16.450456804981446, 15.519298437179561, 14.498534623998708, 13.569965406536113, 12.62951704987892, 11.62314406271255, 10.628183264189387, 9.664033236223567, 8.945905653849273, 8.05802450446948, 8.873312296161913, 8.71830145151194, 9.71283704543394, 10.67401307816322, 11.529960178374356, 12.546607638860662, 13.53627372330839, 14.429930222240184, 15.384953953951298, 16.37109834392662, 15.529008514572341, 14.591676935866, 13.680756627304767, 12.75030305454437, 11.745361385204971, 10.730177547835485, 9.692654400437497, 8.701791282636327, 7.967732827964667, 6.991140947021688, 7.923420833295105, 7.690548456837089, 8.693818054658436, 9.698543265233065, 10.597268466207158, 11.579016165458777, 12.46678355204928, 13.422303634238409, 14.453560061018347, 15.411590287724827, 14.669962018425352, 13.647093786988993, 12.717301004291956, 11.72189471527083, 10.730104587715669, 9.74508291366553, 8.72816706322679, 7.735146547679026, 6.934454973133161, 5.921964132476233, 6.900064085445314], [6.860506341096729, 5.919058483426187, 5.1115039714641135, 5.878354775804291, 6.860688837523804, 7.865387152612654, 8.83335264808016, 9.829053442900053, 10.77708128082602, 11.668400702182604, 12.655966539119854, 13.502268162303453, 14.427478768955398, 13.437485870313296, 12.480886339458719, 11.613124824080918, 10.637014779216784, 9.624822820067942, 8.627252843725195, 7.6762246274393915, 5.8881066930992905, 4.943022598746031, 4.080697660455272, 4.9379566968163475, 5.873110101541648, 6.850323314492449, 7.8934594440022225, 8.828685175556913, 9.800162040397735, 10.676246999267354, 11.630352257276135, 12.5599852666774, 13.573718859705368, 12.592442383340616, 11.553920946645983, 10.547551065308472, 9.58459069416324, 8.681076029242629, 7.694456712202528, 6.747530323646508, 4.871672702588395, 3.9423667769572175, 3.0458661977633414, 3.9090628236633824, 4.9079993825629895, 5.906469000587, 6.8698577725144725, 7.887898117227201, 8.82473773023783, 9.743071424722451, 10.783816565497567, 11.763224971617957, 12.63838492813315, 11.689800932060441, 10.716801042193675, 9.660529061620956, 8.602645276553496, 7.765718859632844, 6.812365399635596, 5.809763772834818, 3.8386788559659775, 2.9809577021180704, 1.9967410352990222, 2.9465521996710953, 3.9550494864983206, 4.928801692817819, 5.912421195927596, 6.887235815667308, 7.8434080069608765, 8.78950507386486, 9.835379084746755, 10.844764652160048, 11.80839570082344, 10.771403952246432, 9.792643735557856, 8.718470529217157, 7.648979060287363, 6.710849438297813, 5.760417540410171, 4.822909700674979, 2.893655555700473, 1.9909165136554252, 1.0466983289423757, 2.026938571842362, 2.99114543830564, 3.924793367014193, 4.913845012289214, 5.856580925912034, 6.839012411811313, 7.870512383412381, 8.937854429610525, 9.914672897672254, 10.869620041638875, 9.844795614487893, 8.781386729312608, 7.824556373365071, 6.776370071837791, 5.74938421754736, 4.7721473130090475, 3.8315561597286614, 1.9466130150999823, 0.9914070136032517, 0.0, 1.0279252014986757, 2.0567004129771855, 2.9943074726923813, 4.03456729954134, 5.06788244647497, 6.040795306910525, 7.02644716053053, 7.961037149388325, 8.987483227210255, 9.950863350603758, 8.979452149889601, 7.913122138474987, 6.865934944527845, 5.89116100173234, 4.865255981582867, 3.9286907710854644, 2.877241125810901, 2.9398151032233457, 2.0051475524754223, 1.032262594852088, 2.0171286304873663, 2.993400882341439, 4.009390714991547, 5.040914103356124, 6.013976393191281, 6.972132457565969, 7.962227187491974, 8.909704506610025, 9.875485510397555, 10.80596604882802, 9.769966783419292, 8.762150003119642, 7.783440344615584, 6.823995031249586, 5.799875845229429, 4.871637350123093, 3.866283413729276, 3.907021416521488, 2.9710242940765488, 2.0234135951714154, 3.0350931122968996, 4.049067511324295, 4.994853390833552, 5.981513449400832, 6.960485175631382, 7.913948347794234, 8.881150817336774, 9.940753026573791, 10.89643149582078, 11.616730062470905, 10.55064825381299, 9.566373179420856, 8.624279664124503, 7.676955074225843, 6.745097393947319, 5.8113565151688675, 4.874628718461205, 4.835621472625645, 3.955152996385114, 2.9763679822883615, 3.992620552383751, 5.019361740414086, 5.976896453533194, 6.986147704596339, 7.9773837714140905, 8.988921657482528, 9.844212867686128, 10.839858872828534, 11.847598984697681, 12.516522265202777, 11.452793884061098, 10.499185161071319, 9.561445755752535, 8.67957112382115, 7.7473214457426485, 6.852727678397967, 5.8351809305419025, 5.842113517335757, 4.929343236891126, 4.011487217466705, 4.961820559878477, 5.945211646034511, 6.941397902979531, 7.919361252515095, 8.854767460741941, 9.82456915265524, 10.759964664899174, 11.713282257166927, 12.696131326950377, 13.343945751362124, 12.410392906592563, 11.487887156232972, 10.547377133936894, 9.71353782814909, 8.699015687405888, 7.800650101762596, 6.900645095131896, 6.8087449425321935, 5.998251619913864, 5.069170189715734, 5.960023324229072, 6.889172641527908, 7.897336531324279, 8.842981157088149, 9.781036741840662, 10.803728901949956, 11.780557325396597, 12.662588715131541, 13.71858294926378, 14.312222012005867, 13.365252626230482, 12.440052182827017, 11.50708072465913, 10.70811260889578, 9.769630140912946, 8.830420039106862, 7.833633149100141, 7.763318036883653, 6.967747006730358, 6.007077521340368, 6.966760294635522, 7.900032555583937, 8.887586459311139, 9.856996585218255, 10.761225723951815, 11.825232762354277, 12.771477826112168, 13.637972238657724, 14.627722043202823, 15.266625370032195, 14.346928683622727, 13.456135513439717, 12.479854563858304, 11.706358083656433, 10.770438337596001, 9.81607424468879, 8.766095360680396, 8.77051882704237, 7.872158153710434, 6.9425443309907555, 7.898057608837468, 8.875751661648504, 9.870487655924725, 10.844141509613738, 11.830930165077106, 12.83304669719719, 13.804404591603257, 14.646025197658957, 15.644316807811714, 16.241553980700438, 15.346055283352603, 14.447271341757713, 13.423353103831694, 12.711009299234014, 11.740762715887259, 10.787079376588343, 9.744691299836516, 9.781339939387633, 8.835181229204473, 7.882001274262374, 8.82374073570201, 9.81094734508556, 10.831650297463934, 11.867697086994626, 12.842904165256376, 13.785746160144956, 14.762874959727016, 15.68822398020396, 16.69194979439002, 16.503676947700008, 15.540851730752367, 14.556858060930267, 13.618334220614637, 12.66963924806106, 12.161380444874768, 11.625980294759316, 10.68328670382947, 10.727189206934906, 9.804752498805412, 8.80920420757348, 9.770995850345765, 10.7483873690935, 11.754313440399542, 12.807177044569206, 13.851531656516908, 14.718731764486163, 15.682261210294074, 16.66006274875265, 16.58490692323021, 15.629216439997514, 14.65498805433433, 13.605005673093254, 12.637753119698955, 11.68995300097941, 11.178730086567125, 11.934047771200465, 11.723954059222349, 11.752537694192714, 10.762919484151482, 9.873686948969809, 10.696765829310612, 11.747743497465747, 12.721849078996147, 13.770422649283312, 14.753044018705005, 15.720466699103929, 16.66492345275839, 16.53096447916449, 15.651325302536485, 14.698525834749839, 13.687984342297078, 12.742884406903618, 11.70015770480992, 10.666596112207671, 10.107334877286581, 10.981292457187807, 11.712357186701265, 11.731775943416395, 11.828370356255135, 10.91719693478448, 11.654698636710089, 12.654457046171533, 13.65341352567236, 14.633107802395811, 15.615121749830728, 16.569542950747, 16.546286539124807, 15.593312240152727, 14.64753838963485, 13.690009562064521, 12.656791338765984, 11.726236211807823, 10.708435827683296, 9.703572222368662, 9.08853117743051, 9.96698298701247, 10.780795956934481, 10.753311674320745, 11.698422177990883, 11.984510679421492, 12.586882735069105, 13.653617553284144, 14.608741595072889, 15.565042782942434, 16.58151803034743, 16.5028637882212, 15.514820978438054, 14.58366261063617, 13.577880878834584, 12.64931166137199, 11.708863304714797, 10.702490317548426, 9.707529519025263, 8.743379491059443, 8.108514776006274, 9.001297774276289, 9.816585565968724, 9.70970846511519, 10.70424405903719, 11.665420091766471, 12.521367191977607, 13.538014652463914, 14.527680736911643, 15.421337235843437, 16.37636096755455, 15.509327115246768, 14.5489123114289, 13.611580732722558, 12.726942981210703, 11.829649309380246, 10.824707640040847, 9.809523802671361, 8.772000655273374, 7.781137537472203, 7.130341950121667, 7.934414216828498, 8.866694103101915, 8.68195547044034, 9.685225068261687, 10.689950278836315, 11.588675479810409, 12.570423179062029, 13.458190565652533, 14.413710647841661, 15.444967074621598, 14.513844022035741, 13.68986581528191, 12.666997583845552, 11.763487358197892, 10.801240970106706, 9.809450842551545, 8.824429168501407, 7.807513318062666, 6.814492802514902, 6.097064095290161, 6.865237402283042, 7.843337355252124], [7.851463012494969, 6.910015154824428, 5.929481271999959, 4.969689118458387, 5.9520231801779, 6.95672149526675, 7.805427446581483, 8.801128241401377, 9.749156079327344, 10.640475500683928, 11.628041337621179, 12.474342960804778, 13.438285633445172, 14.428278532087274, 13.508811540957394, 12.641050025579593, 11.66493998071546, 10.652748021566618, 9.65517804522387, 8.704149828938068, 6.879063364497531, 5.933979270144272, 5.033093985867301, 4.0292910394704435, 4.964444444195744, 5.9129863639043885, 6.8655342425035455, 7.800759974058237, 8.77223683889906, 9.648321797768679, 10.60242705577746, 11.532060065178724, 12.57078408315145, 13.552060559516201, 12.581846148144658, 11.575476266807147, 10.612515895661915, 9.709001230741304, 8.722381913701204, 7.775455525145183, 5.899597904087069, 4.933323448355459, 3.998262523175371, 3.0003971663174784, 3.9758028354860966, 4.924647917405084, 5.841932571015795, 6.859972915728524, 7.796812528739155, 8.715146223223776, 9.755891363998892, 10.735299770119282, 11.74737529897767, 12.695959295050377, 11.74472624369235, 10.688454263119631, 9.63057047805217, 8.793644061131518, 7.840290601134272, 6.837688974333493, 4.866604057464652, 3.971914373516312, 2.987697706697264, 2.0378865423251913, 3.022852939421428, 3.9008764913191425, 4.884495994428919, 5.859310614168633, 6.815482805462201, 7.761579872366184, 8.80745388324808, 9.816839450661373, 10.780470499324764, 11.799329153745107, 10.820568937056532, 9.746395730715832, 8.676904261786039, 7.738774639796488, 6.7883427419088465, 5.850834902173654, 3.9215807571991483, 3.006538645277316, 2.0386960712229896, 0.999013370343686, 1.963220236806964, 2.896868165515517, 3.885919810790538, 4.828655724413358, 5.811087210312637, 6.8425871819137045, 7.909929228111848, 8.886747696173579, 9.879715750551243, 10.872720815986568, 9.809311930811283, 8.852481574863747, 7.804295273336466, 6.777309419046035, 5.800072514507723, 4.859481361227337, 2.974538216598658, 2.0193322151019273, 1.0279252014986757, 0.0, 1.0287752114785098, 1.9663822711937058, 3.006642098042664, 4.039957244976294, 5.012870105411848, 5.998521959031853, 6.933111947889648, 7.959558025711577, 9.030088479421922, 10.001499680136078, 8.941047339973661, 7.89386014602652, 6.919086203231015, 5.893181183081542, 4.95661597258414, 3.9051663273095762, 3.9677403047220214, 3.033072753974098, 2.0528996370561474, 0.9892034289886906, 1.9654756808427631, 2.9814655134928714, 4.012988901857449, 4.986051191692605, 5.944207256067293, 6.934301985993297, 7.881779305111347, 8.847560308898878, 9.778040847329343, 10.79789198491797, 9.790075204618319, 8.81136554611426, 7.851920232748261, 6.827801046728104, 5.899562551621768, 4.894208615227951, 4.934946618020163, 3.9725867425718278, 3.024976043666695, 2.01329652654121, 3.0211423098256196, 3.9669281893348773, 4.953588247902157, 5.932559974132705, 6.886023146295558, 7.853225615838099, 8.912827825075116, 9.868506294322104, 10.71013518319133, 11.578573455311666, 10.59429838091953, 9.652204865623178, 8.704880275724518, 7.773022595445994, 6.839281716667543, 5.90255391995988, 5.86354667412432, 4.956715444880393, 3.977930430783641, 3.080451523921554, 4.052530143192517, 4.94897125203452, 5.958222503097665, 6.949458569915416, 7.960996455983851, 8.816287666187453, 9.811933671329859, 10.819673783199006, 11.652799822178721, 12.480719085559773, 11.527110362569994, 10.58937095725121, 9.707496325319825, 8.775246647241325, 7.880652879896642, 6.863106132040578, 6.870038718834432, 5.930905685386405, 5.013049665961984, 4.049651531416281, 5.033042617572314, 5.960767352380775, 6.891436051016421, 7.826842259243267, 8.796643951156566, 9.7320394634005, 10.685357055668254, 11.668206125451704, 12.666136046708425, 13.438318108091238, 12.515812357731647, 11.57530233543557, 10.741463029647766, 9.726940888904565, 8.828575303261271, 7.928570296630571, 7.836670144030869, 6.999814068409142, 6.055640742238919, 5.047854295766875, 5.977003613065712, 6.9167059807255225, 7.829253254730659, 8.753111540341987, 9.775803700451283, 10.752632123897923, 11.634663513632868, 12.690657747765107, 13.62180574587137, 14.393177827729158, 13.467977384325692, 12.535005926157805, 11.736037810394457, 10.797555342411624, 9.858345240605537, 8.861558350598816, 8.791243238382329, 7.969309455225636, 6.993548073863552, 6.063949692816154, 6.997221953764568, 7.984775857491771, 8.849765503464065, 9.73330052245314, 10.797307560855602, 11.743552624613494, 12.61004703715905, 13.59979684170415, 14.576209103897698, 15.374853885121402, 14.484060714938392, 13.507779765356979, 12.73428328515511, 11.798363539094678, 10.843999446187466, 9.794020562179071, 9.798444028541045, 8.858628706233619, 7.92901488351394, 6.9952470070181, 7.972941059829135, 8.967677054105355, 9.8581217928347, 10.80300496357843, 11.805121495698515, 12.776479390104582, 13.618099996160282, 14.616391606313039, 15.551137714565943, 15.580615262877716, 14.58699039998156, 13.647195352628593, 12.72711278222299, 12.768687917385936, 11.815004578087018, 10.772616501335191, 10.78288153128827, 9.821651781727656, 8.868471826785559, 7.9681703902368834, 8.908136743266192, 9.928839695644564, 10.90769542961008, 11.814978963757701, 12.757820958646281, 13.73494975822834, 14.660298778705284, 15.664024592891343, 15.595011290354105, 14.632186073406464, 13.648192403584364, 12.709668563268734, 11.760973590715157, 12.706427117966319, 12.653905496257991, 11.711211905328145, 11.728730798835542, 10.791223051328597, 9.795674760096665, 8.930869477053596, 9.845576767274132, 10.851502838580174, 11.904366442749838, 12.824542386498779, 13.690806562987488, 14.654336008795399, 15.632137547253976, 15.67624126588431, 14.72055078265161, 13.746322396988427, 12.696340015747351, 11.729087462353052, 10.781287343633505, 11.723776759658676, 12.692939919336645, 12.751879260721024, 12.75407928609335, 11.749390036674667, 10.847650302410804, 9.856639456018444, 10.886022813373774, 11.860128394904175, 12.908701965191339, 13.786871544979308, 14.716109253386165, 15.660566007040625, 15.503039277665813, 14.710351815851208, 13.789860177403936, 12.779318684951175, 11.834218749557715, 10.791492047464017, 9.757930454861766, 10.798206572749834, 11.740184605323986, 12.582922141895885, 12.620418780420298, 12.81484090877832, 11.798359192949091, 10.81457226341792, 11.814330672879365, 12.809669929492822, 13.789364206216273, 14.77137815365119, 15.698422121571461, 15.518361337626132, 14.565387038654052, 13.706564902949573, 12.781343904718618, 11.748125681420081, 10.81757055446192, 9.799770170337393, 8.794906565022757, 9.779402872893764, 10.725875135148648, 11.651360912129102, 11.713772707247376, 12.660645992645511, 12.766846753095033, 11.746756361776937, 12.813491179991976, 13.76861522178072, 14.724916409650266, 15.741333738230018, 15.474938586722526, 14.48689577693938, 13.555737409137494, 12.635111646625981, 11.740646004026086, 10.800197647368893, 9.793824660202523, 8.79886386167936, 7.834713833713539, 8.799386471469527, 9.760189922412467, 10.760030289743964, 10.737633666613867, 11.732169260535866, 12.693345293265146, 12.747293220458577, 13.747427445043618, 14.820201186076941, 15.677459393569695, 15.467546303723413, 14.481401913748092, 13.520987109930225, 12.583655531223883, 11.699017779712028, 10.818958566179646, 9.814016896840247, 8.900858145325458, 7.8633349979274705, 6.8724718801263, 7.904684350503757, 8.92537088822674, 9.857650774500156, 9.709880671939016, 10.713150269760362, 11.71787548033499, 12.616600681309084, 13.598348380560704, 14.486115767151208, 15.413928389300326, 14.444830369695936, 13.485918820537066, 12.661940613783235, 11.639072382346876, 10.735562156699217, 9.790550226906106, 8.798760099350945, 7.915763511155503, 6.898847660716763, 5.905827145168999, 6.908240753535646, 7.856194073681284, 8.834294026650365], [8.871118729672862, 7.921474216553312, 6.928131881009323, 5.968339727467751, 5.080366979736664, 5.933272875358069, 6.779758651604064, 7.775459446423959, 8.723487284349925, 9.61480670570651, 10.60237254264376, 11.44867416582736, 12.412616838467754, 13.402609737109856, 14.359209267964433, 13.6698252370581, 12.69371519219397, 11.681523233045128, 10.68395325670238, 9.732925040416575, 7.907838575976042, 6.962754481622782, 6.0618691973458105, 5.027941648479808, 4.092788243754508, 4.887317568926969, 5.839865447526127, 6.775091179080818, 7.746568043921641, 8.62265300279126, 9.576758260800041, 10.506391270201306, 11.545115288174031, 12.526391764538783, 13.564913201233416, 12.604251478285654, 11.641291107140422, 10.737776442219815, 9.751157125179713, 8.804230736623692, 6.92837311556558, 5.962098659833969, 5.027037734653881, 4.029172377795988, 3.0836844824659866, 3.898979122427664, 4.816263776038377, 5.8343041207511055, 6.771143733761736, 7.689477428246358, 8.730222569021473, 9.709630975141863, 10.721706504000249, 11.670290500072957, 12.643290389939724, 11.717229474598138, 10.659345689530678, 9.822419272610029, 8.869065812612781, 7.866464185812003, 5.895379268943163, 5.000689584994822, 4.016472918175774, 3.066661753803701, 2.130734586401318, 2.8752076963417235, 3.8588271994515004, 4.8336418191912145, 5.789814010484783, 6.735911077388765, 7.781785088270661, 8.791170655683953, 9.754801704347344, 10.799910273132857, 11.848024394102984, 10.775170942194341, 9.705679473264547, 8.767549851274998, 7.817117953387356, 6.879610113652164, 4.950355968677658, 4.035313856755827, 3.0674712827015, 2.027788581822196, 1.0711018837868538, 1.871199370538098, 2.860251015813119, 3.8029869294359395, 4.785418415335219, 5.816918386936286, 6.884260433134429, 7.8610789011961595, 8.854046955573825, 9.878871382724807, 10.838087142289792, 9.881256786342256, 8.833070484814977, 7.806084630524545, 6.828847725986233, 5.8882565727058465, 4.003313428077168, 3.048107426580437, 2.0567004129771855, 1.0287752114785098, 0.0, 0.937607059715196, 1.9778668865641544, 3.0111820334977843, 3.9840948939333387, 4.969746747553344, 5.904336736411139, 6.930782814233068, 8.001313267943413, 8.97272446865757, 9.969822551452172, 8.92263535750503, 7.947861414709525, 6.921956394560052, 5.9853911840626495, 4.933941538788086, 4.996515516200531, 4.061847965452608, 3.031911562216864, 1.9682153541494074, 0.9919431022953348, 1.9884059553151954, 2.9842136903789394, 3.957275980214095, 4.915432044588783, 5.905526774514788, 6.853004093632838, 7.818785097420368, 8.749265635850834, 9.795103301932748, 10.802920082232399, 9.840140757592769, 8.88069544422677, 7.856576258206614, 6.928337763100278, 5.922983826706461, 5.942266250631301, 4.9515986677325445, 4.003987968827412, 2.992308451701927, 2.047609731278191, 2.973868631157201, 3.937781031203683, 4.903784762654196, 5.857247934817048, 6.824450404359589, 7.884052613596607, 8.839731082843596, 9.681359971712821, 10.747441780370735, 11.623073592398041, 10.680980077101689, 9.733655487203029, 8.801797806924505, 7.868056928146053, 6.93132913143839, 6.870866306735458, 5.935727370041111, 4.956942355944358, 4.059463449082271, 3.0789975646450887, 3.9559116938568435, 4.942415286399191, 5.933651353216942, 6.9322212445053415, 7.787512454708942, 8.783158459851348, 9.790898571720497, 10.624024610700214, 11.687752991841894, 12.555885574048505, 11.618146168729721, 10.736271536798336, 9.804021858719835, 8.909428091375153, 7.8918813435190875, 7.852891561921009, 6.909917610547122, 5.9920615911227015, 5.028663456576997, 4.1296678442466686, 4.967707794203099, 5.875628834317947, 6.811035042544793, 7.780836734458092, 8.716232246702027, 9.66954983896978, 10.65239890875323, 11.637360835229918, 12.57091367999948, 13.544587569210158, 12.60407754691408, 11.770238241126277, 10.755716100383076, 9.857350514739782, 8.924033542011102, 8.819522987117445, 7.97882599356986, 7.023313765985345, 6.015527319513302, 5.073628839740066, 5.923646422547846, 6.813446038032186, 7.737304323643514, 8.759996483752808, 9.736824907199448, 10.618856296934394, 11.674850531066634, 12.605998529172897, 13.552967914948281, 14.478168358351747, 13.563781137636315, 12.764813021872968, 11.826330553890134, 10.844860579296293, 9.844411193685392, 9.774096081468905, 8.948321380386353, 7.961221097609979, 7.03162271656258, 6.1158702097983895, 6.995424335618596, 7.833958286765592, 8.717493305754667, 9.781500344157129, 10.72774540791502, 11.594239820460578, 12.583989625005676, 13.560401887199225, 14.534643972340525, 14.877626074847011, 13.898398460160553, 13.76305849663362, 12.827138750573189, 11.826852289274042, 10.776873405265647, 10.781296871627621, 9.826301729980045, 8.896687907260366, 7.9629200307645265, 7.1432142216678205, 8.056216727139034, 8.842314576136227, 9.787197746879958, 10.789314279000042, 11.760672173406109, 12.60229277946181, 13.600584389614566, 14.53533049786747, 14.866504703696181, 13.872879840800026, 12.954899920187163, 13.725763391232354, 13.76284348778982, 12.797857421173594, 11.755469344421767, 11.750554555034697, 10.789324805474083, 9.836144850531985, 8.93584341398331, 8.078409905104877, 9.017379368678244, 9.891888212911606, 10.799171747059228, 11.742013741947808, 12.719142541529868, 13.644491562006811, 14.64821737619287, 14.72572693106165, 13.850538731639835, 12.93408184440283, 12.017373130827304, 12.75962419972452, 13.705077726975684, 13.636758339344567, 12.694064748414721, 12.696403822581967, 11.758896075075024, 10.763347783843091, 9.898542500800023, 9.015849929112816, 10.021776000418859, 10.965264691705952, 11.808735169800306, 12.674999346289015, 13.638528792096926, 14.616330330555503, 14.72241573955101, 13.766725256318312, 12.82026852434982, 11.982229456565817, 11.036792029911622, 11.77993795264287, 12.722427368668042, 13.691590528346008, 13.7347321038076, 13.721752309839776, 12.717063060421093, 11.81532332615723, 10.82431247976487, 10.056295975212459, 11.03040155674286, 12.014518440547125, 12.771064328280834, 13.700302036687692, 14.644758790342152, 14.477370482688395, 13.68468302087379, 12.836034651070637, 11.825493158617876, 10.967182751544643, 10.099196615022587, 10.756581063871131, 11.796857181759197, 12.73883521433335, 13.581572750905249, 13.619069389429661, 13.782513932524747, 12.766032216695518, 11.782245287164347, 11.116175834608697, 11.979943091331506, 12.959637368054958, 13.833480267115275, 14.682614904872988, 14.492692542648713, 13.539718243676633, 12.680896107972154, 11.827518378385319, 10.794300155086782, 9.934032431746175, 9.107474737895963, 9.793557174032122, 10.778053481903127, 11.724525744158012, 12.650011521138465, 12.71242331625674, 13.659296601654875, 13.73451977684146, 12.714429385523363, 12.139952872254309, 13.031631949516719, 13.950418465987987, 14.803435851694104, 14.449269791745108, 13.46122698196196, 12.530068614160076, 11.609442851648563, 10.786820477692787, 9.846372121035595, 8.910286537486778, 8.05829621817616, 8.833364442722903, 9.79803708047889, 10.75884053142183, 11.758680898753328, 11.766408878092374, 12.760944472014376, 13.722120504743657, 13.714966244205003, 13.073889137305951, 14.088899594891874, 14.902961449907416, 14.441877508745995, 13.455733118770674, 12.495318314952806, 11.557986736246464, 10.67334898473461, 9.793289771202227, 8.788348101862828, 7.9175464994343905, 7.122767354424271, 7.871122489135663, 8.90333495951312, 9.936829949955623, 10.86910983622904, 10.738655883417524, 11.741925481238873, 12.746650691813501, 13.645375892787595, 14.041480610707836, 15.068116734635073, 14.388259594322907, 13.419161574718515, 12.460250025559647, 11.636271818805817, 10.613403587369458, 9.709893361721798, 8.764881431928687, 7.773091304373526, 6.892314891246822, 6.093788562137185, 6.904477754178362, 7.906891362545009, 8.867653135410167, 9.845753088379249], [9.667257085417463, 8.717612572297913, 7.724270236753924, 6.764478083212352, 5.876505335481265, 4.995665815642874, 5.842151591888868, 6.837852386708763, 7.785880224634729, 8.677199645991314, 9.664765482928564, 10.511067106112163, 11.475009778752558, 12.46500267739466, 13.421602208249237, 14.392638035505898, 13.541571661922735, 12.529379702773893, 11.531809726431145, 10.580781510145343, 8.711497100148579, 7.766413005795319, 6.8655277215183474, 5.824080004224409, 4.888926599499109, 3.9497105092117737, 4.902258387810931, 5.837484119365622, 6.808960984206445, 7.685045943076064, 8.639151201084845, 9.56878421048611, 10.607508228458835, 11.588784704823587, 12.62730614151822, 13.524552089830358, 12.561591718685126, 11.58563291194858, 10.59901359490848, 9.652087206352459, 7.806463798380062, 6.765757184006506, 5.830696258826418, 4.832830901968525, 3.8798228382105875, 2.961372062712469, 3.878656716323181, 4.89669706103591, 5.83353667404654, 6.751870368531161, 7.792615509306277, 8.772023915426667, 9.784099444285054, 10.732683440357762, 11.70568333022453, 12.637530086142842, 11.579646301075382, 10.742719884154731, 9.789366424157482, 8.786764797356705, 6.815679880487863, 5.804348109167359, 4.820131442348311, 3.870320277976238, 2.926872942145919, 1.9376006366265277, 2.9212201397363047, 3.896034759476018, 4.852206950769586, 5.798304017673569, 6.844178028555465, 7.853563595968757, 8.81719464463215, 9.862303213417663, 10.91041733438779, 11.695471553739043, 10.62598008480925, 9.6878504628197, 8.737418564932057, 7.799910725196865, 5.870656580222359, 4.838972380928364, 3.8711298068740367, 2.831447105994733, 1.867240239531455, 0.9335923108229021, 1.9226439560979232, 2.8653798697207433, 3.847811355620022, 4.879311327221089, 5.946653373419233, 6.923471841480963, 7.916439895858628, 8.94126432300961, 10.004673208184897, 10.81886384605745, 9.753371096359679, 8.726385242069247, 7.749148337530934, 6.808557184250548, 4.940920487792363, 3.985714486295633, 2.9943074726923813, 1.9663822711937058, 0.937607059715196, 0.0, 1.0402598268489585, 2.0735749737825886, 3.046487834218143, 4.032139687838148, 4.966729676695943, 5.993175754517872, 7.063706208228217, 8.035117408942373, 9.101447420356987, 9.860242417220224, 8.88546847442472, 7.859563454275247, 6.922998243777845, 5.871548598503281, 5.934122575915726, 4.999455025167803, 3.9695186219320595, 2.905822413864603, 1.9295501620105306, 1.0507988955999994, 2.046606630663743, 3.019668920498899, 3.977824984873587, 4.967919714799592, 5.915397033917642, 6.881178037705172, 7.811658576135637, 8.85749624221755, 9.865313022517201, 10.777747817307963, 9.818302503941965, 8.794183317921808, 7.865944822815473, 6.860590886421656, 6.879873310346496, 5.88920572744774, 4.941595028542607, 3.9299155114171223, 2.9852167909933867, 2.0362615714420054, 3.0001739714884867, 3.9661777029389995, 4.919640875101852, 5.886843344644393, 6.946445553881411, 7.9021240231283985, 8.743752911997623, 9.809834720655537, 10.794109795047673, 11.618587136816883, 10.671262546918223, 9.739404866639699, 8.805663987861248, 7.868936191153585, 7.808473366450653, 6.873334429756306, 5.8945494156595535, 4.997070508797466, 4.016604624360284, 3.0183046341416477, 4.004808226683995, 4.996044293501746, 5.994614184790145, 6.849905394993746, 7.845551400136152, 8.8532915120053, 9.686417550985016, 10.750145932126696, 11.703754655116475, 12.555753228444916, 11.67387859651353, 10.74162891843503, 9.847035151090347, 8.829488403234283, 8.790498621636205, 7.847524670262318, 6.929668650837897, 5.966270516292193, 5.026286991432924, 4.030100734487903, 4.938021774602751, 5.873427982829597, 6.843229674742896, 7.77862518698683, 8.731942779254583, 9.714791849038033, 10.69975377551472, 11.633306620284282, 12.692456650278128, 13.541684606629275, 12.707845300841472, 11.69332316009827, 10.794957574454976, 9.861640601726299, 9.757130046832641, 8.900905775234373, 7.919932913171601, 6.912146466699557, 5.970247986926322, 4.986039362832651, 5.87583897831699, 6.7996972639283175, 7.8223894240376115, 8.799217847484252, 9.681249237219197, 10.737243471351436, 11.6683914694577, 12.615360855233083, 13.540561298636549, 14.50138819735151, 13.702420081588162, 12.763937613605329, 11.78246763901149, 10.782018253400588, 10.7117031411841, 9.870401162050866, 8.857840244796234, 7.928241863748836, 7.012489356984645, 6.057817275903401, 6.8963512270503955, 7.77988624603947, 8.843893284441931, 9.790138348199823, 10.65663276074538, 11.646382565290478, 12.622794827484027, 13.597036912625327, 13.964177440949587, 14.694536815905154, 14.700665556348815, 13.764745810288384, 12.764459348989238, 11.714480464980843, 11.718903931342815, 10.7229208771663, 9.793307054446622, 8.859539177950783, 8.039833368854076, 7.11860966742384, 7.9047075164210305, 8.84959068716476, 9.851707219284844, 10.82306511369091, 11.664685719746611, 12.662977329899368, 13.597723438152272, 13.928897643980987, 12.935272781084832, 13.751038275931764, 14.521901746976956, 14.700450547505014, 13.735464480888789, 12.693076404136962, 12.647173702220952, 11.685943952660338, 10.73276399771824, 9.832462561169566, 8.975029052291132, 8.079772308963049, 8.954281153196412, 9.86156468734403, 10.80440668223261, 11.78153548181467, 12.706884502291613, 13.710610316477672, 13.788119871346455, 12.912931671924639, 11.996474784687635, 12.813511486571905, 13.555762555469123, 14.501216082720285, 14.574365399059761, 13.631671808129916, 13.593022969768224, 12.655515222261279, 11.659966931029347, 10.795161647986278, 9.912469076299072, 9.115223288775667, 10.027657631990758, 10.871128110085108, 11.737392286573817, 12.700921732381728, 13.678723270840305, 13.784808679835814, 12.829118196603115, 11.882661464634623, 11.044622396850622, 11.832930385656223, 12.57607630838747, 13.518565724412642, 14.487728884090608, 14.64466539856738, 14.618371457026033, 13.613682207607349, 12.711942473343486, 11.720931626951126, 10.952915122398714, 10.145530718633635, 11.07691138083193, 11.833457268565637, 12.762694976972494, 13.707151730626954, 13.539763422973198, 12.747075961158593, 11.898427591355441, 10.88788609890268, 10.029575691829448, 10.895334970767188, 11.552719419615732, 12.592995537503798, 13.53497357007795, 14.37771110664985, 14.415207745174262, 14.679133079711002, 13.662651363881773, 12.678864434350603, 12.012794981794952, 11.095072253222282, 12.035692312099718, 12.895873207400077, 13.74500784515779, 13.555085482933517, 12.602111183961437, 11.743289048256958, 10.889911318670123, 9.856693095371586, 8.99642537203098, 9.903613093640564, 10.589695529776723, 11.574191837647728, 12.520664099902612, 13.446149876883066, 13.50856167200134, 14.455434957399476, 14.631138924027715, 13.611048532709619, 13.036572019440564, 12.146761111407494, 13.026473410032747, 13.865828791978906, 13.511662732029912, 12.523619922246764, 11.59246155444488, 10.671835791933367, 9.849213417977591, 8.908765061320398, 7.972679477771582, 8.854434573920761, 9.629502798467504, 10.594175436223491, 11.554978887166431, 12.554819254497929, 12.614265347821142, 13.60880094174314, 14.569976974472421, 14.611585391391259, 13.970508284492206, 13.20402875678265, 13.979016393952175, 13.504270449030798, 12.518126059055477, 11.55771125523761, 10.620379676531268, 9.735741925019413, 8.855682711487031, 7.850741042147632, 6.979939439719194, 7.918905710168872, 8.667260844880264, 9.699473315257721, 10.732968305700224, 11.66524819197364, 11.586512353146292, 12.589781950967637, 13.594507161542266, 14.493232362516359, 14.938099757894092, 14.27351892804176, 13.45065253460771, 12.481554515003321, 11.522642965844451, 10.69866475909062, 9.675796527654262, 8.772286302006602, 7.82727437221349, 6.83548424465833, 5.954707831531627, 6.889926917881786, 7.700616109922963, 8.70302971828961, 9.663791491154768, 10.64189144412385], [10.70751691226642, 9.757872399146871, 8.764530063602882, 7.80473791006131, 6.916765162330223, 6.007682509692707, 4.9934006067708685, 5.989101401590762, 6.879064142632863, 7.770383563989446, 8.757949400926696, 9.604251024110296, 10.56819369675069, 11.558186595392792, 12.514786126247369, 13.485821953504031, 14.524322887914632, 13.569639529622853, 12.572069553280103, 11.621041336994299, 9.751756926997537, 8.806672832644278, 7.905787548367306, 6.864339831073367, 5.929186426348067, 4.989970336060732, 4.053507402692931, 4.988733134247623, 5.902144902204579, 6.778229861074197, 7.732335119082977, 8.661968128484242, 9.700692146456968, 10.681968622821719, 11.720490059516353, 12.726859940853863, 13.601851545534082, 12.625892738797539, 11.639273421757437, 10.692347033201417, 8.846723625229021, 7.806017010855465, 6.870956085675377, 5.873090728817484, 4.920082665059546, 4.001631889561427, 3.0299057312051816, 4.046169340033176, 4.926720592044674, 5.845054286529295, 6.885799427304409, 7.865207833424799, 8.822457828804552, 9.77104182487726, 10.744041714744027, 11.800313695316746, 12.619906127924338, 11.782979711003689, 10.829626251006442, 9.827024624205665, 7.855939707336823, 6.844607936016318, 5.86039126919727, 4.910580104825197, 3.9671327689948774, 2.977860463475486, 2.072469154618305, 2.9892186774741516, 3.94539086876772, 4.8914879356717025, 5.926239236139816, 6.891921980488254, 7.855553029151646, 8.900661597937159, 9.948775718907285, 10.961446184157015, 11.666239911658208, 10.728110289668658, 9.777678391781016, 8.840170552045825, 6.910916407071318, 5.8792322077773225, 4.911389633722996, 3.8717069328436917, 2.9075000663804134, 1.9738521376718605, 1.0624164814153194, 1.9585637877188773, 2.940995273618156, 3.969547185411188, 4.98501175793873, 5.96183022600046, 6.9547982803781245, 7.979622707529107, 9.043031592704393, 9.99986194865193, 10.793630923208637, 9.766645068918205, 8.789408164379893, 7.848817011099507, 5.981180314641322, 5.025974313144592, 4.03456729954134, 3.006642098042664, 1.9778668865641544, 1.0402598268489585, 0.0, 1.03331514693363, 2.0062280073691845, 2.99187986098919, 3.9264698498469848, 4.952915927668914, 6.023446381379259, 6.994857582093415, 8.06118759350803, 9.108374787455173, 9.92572830127368, 8.899823281124206, 7.963258070626804, 6.91180842535224, 6.974382402764685, 6.039714852016763, 5.009778448781018, 3.9460822407135616, 2.969809988859489, 2.0787617268731937, 1.0063468038147847, 1.9794090936499407, 2.937565158024629, 3.927659887950634, 4.875137207068684, 5.840918210856214, 6.771398749286679, 7.817236415368592, 8.825053195668243, 9.803762854172302, 10.7632081675383, 9.834443144770768, 8.906204649664433, 7.900850713270615, 7.885028331391132, 6.8943607484923755, 5.9467500495872425, 4.935070532461758, 3.9143134919337808, 2.946574203206808, 1.9599141446395283, 2.925917876090041, 3.8793810482528936, 4.846583517795435, 5.906185727032453, 6.86186419627944, 7.703493085148665, 8.76957489380658, 9.753849968198715, 10.695943483495068, 11.643268073393727, 10.779664693488659, 9.845923814710208, 8.909196018002545, 8.813628387495289, 7.8784894508009415, 6.899704436704189, 5.972442513331013, 4.9457013253006785, 3.92861726590645, 2.964548399835036, 3.955784466652787, 4.954354357941187, 5.809645568144788, 6.805291573287194, 7.813031685156343, 8.646157724136057, 9.709886105277736, 10.663494828267515, 11.601234233586299, 12.60588275867382, 11.78188874528399, 10.887294977939307, 9.865400266028868, 9.79565364268084, 8.852679691306953, 7.9348236718825325, 6.919990709353759, 5.936599623197726, 4.940413366252706, 3.8977619477537915, 4.833168155980638, 5.802969847893937, 6.7383653601378715, 7.691682952405625, 8.674532022189075, 9.65949394866576, 10.593046793435322, 11.652196823429168, 12.587165611770658, 13.6611378373039, 12.73358298694723, 11.835217401303936, 10.866795622770933, 10.728271039046168, 9.778109289663163, 8.79713642760039, 7.789349981128348, 6.847451501355113, 5.7812237772319, 4.83557915146803, 5.759437437079359, 6.782129597188653, 7.758958020635293, 8.640989410370238, 9.696983644502478, 10.628131642608741, 11.575101028384125, 12.50030147178759, 13.481139416496196, 14.536793755707633, 13.751275744599269, 12.753608631225017, 11.753159245614116, 11.682844133397628, 10.747604676479657, 9.706010464079325, 8.74632769078417, 7.813055429835755, 6.825501526108552, 5.856091400201436, 6.739626419190511, 7.803633457592973, 8.749878521350865, 9.616372933896422, 10.60612273844152, 11.582535000635069, 12.55677708577637, 13.51638480240029, 14.45391325569537, 15.41221171656999, 14.752083941282324, 13.735600341202765, 12.68562145719437, 12.58401653077113, 11.571091096449392, 10.641477273729713, 9.677625004986115, 8.832837537537305, 7.838101543261085, 6.864447689572071, 7.809330860315802, 8.811447392435886, 9.782805286841953, 10.624425892897655, 11.622717503050412, 12.557463611303314, 13.106343164891587, 13.947289475134665, 14.791298102780722, 15.562161573825913, 15.565563146933329, 14.600577080317104, 13.558189003565277, 13.495343921504043, 12.534114171943429, 11.580934217001332, 10.650548388204898, 9.768033220974361, 8.799264184800295, 7.914021326347451, 8.821304860495072, 9.764146855383654, 10.741275654965714, 11.666624675442657, 12.670350489628715, 12.939368886228456, 12.06418068680664, 13.008491478737469, 13.853771313420863, 14.596022382318079, 15.541475909569243, 15.42942021858034, 14.486726627650494, 14.441193189051315, 13.50368544154437, 12.508137150312438, 11.61324747502161, 10.7054732449823, 9.834715164612913, 8.987397805141798, 9.83086828323615, 10.69713245972486, 11.660661905532772, 12.638463443991348, 12.887680917679258, 11.980367211485117, 11.033910479516624, 12.056639090900456, 12.87319021250518, 13.616336135236429, 14.5588255512616, 15.527988710939567, 15.49283561785047, 15.466541676309124, 14.46185242689044, 13.530028300378818, 12.539017453986459, 11.745919291081943, 10.865022594470881, 10.03665155398297, 10.793197441716678, 11.722435150123538, 12.666891903777998, 12.63294734097133, 11.84025987915673, 11.049676606237442, 10.039135113784681, 11.041592385879282, 11.935594797616146, 12.59297924646469, 13.633255364352756, 14.575233396926908, 15.417970933498808, 15.45546757202322, 15.519059126489594, 14.480737190917106, 13.496950261385935, 12.805799150478181, 11.814564129059528, 10.995432485250758, 11.85561338055112, 12.704748018308834, 12.64826940093165, 11.69529510195957, 10.836472966255094, 10.041160333552124, 9.007942110253587, 10.008442066080814, 10.943872920489522, 11.62995535662568, 12.614451664496686, 13.56092392675157, 14.486409703732024, 14.548821498850298, 15.495694784248434, 15.449224751063047, 14.429134359744952, 13.821377029033485, 12.86625298724474, 11.986213583183787, 12.825568965129948, 12.604846650028044, 11.616803840244897, 10.685645472443012, 9.765019709931503, 9.000462432859592, 8.0600140762024, 8.984696171821415, 9.894694400769719, 10.669762625316462, 11.634435263072449, 12.59523871401539, 13.595079081346887, 13.654525174670098, 14.6490607685921, 15.610236801321381, 15.429671218426591, 14.755313294085127, 13.923520632619896, 12.938756567103216, 12.59745436702893, 11.61130997705361, 10.650895173235742, 9.7135635945294, 8.828925843017549, 8.00693172636903, 7.001990057029634, 7.991956133769028, 8.95916553701783, 9.707520671729222, 10.73973314210668, 11.773228132549182, 12.705508018822599, 12.626772179995248, 13.630041777816597, 14.634766988391226, 15.475983588508257, 14.443120308485142, 13.492090352441183, 12.543836452605843, 11.574738433001453, 10.615826883842583, 9.791848677088753, 8.768980445652394, 7.865470220004737, 6.978523387095491, 5.986733259540331, 6.966724525581459, 7.930186744730744, 8.740875936771921, 9.743289545138568, 10.704051318003726, 11.682151270972808], [11.590700974277649, 10.641056461158099, 9.64771412561411, 8.68792197207254, 7.799949224341451, 6.8132505826854555, 5.798968679763617, 5.062444938016165, 5.845748995699234, 6.737068417055817, 7.724634253993067, 8.570935877176666, 9.53487854981706, 10.524871448459162, 11.48147097931374, 12.452506806570401, 13.491007740981, 14.45282359163408, 13.455253615291332, 12.504225399005527, 10.634940989008765, 9.689856894655506, 8.788971610378535, 7.747523893084595, 6.812370488359295, 5.873025964215251, 4.85907547568568, 4.062076670673025, 4.86882975527095, 5.7449147141405685, 6.699019972149348, 7.628652981550612, 8.667376999523338, 9.64865347588809, 10.687174912582723, 11.693544793920234, 12.656505165065466, 13.509076800808767, 12.522457483768665, 11.575531095212645, 9.72990768724025, 8.689201072866693, 7.754140147686605, 6.756274790828712, 5.803266727070774, 4.884687517715946, 3.83547380419793, 3.012854193099546, 3.893405445111044, 4.811739139595666, 5.852484280370781, 6.831892686491171, 7.789142681870921, 8.737726677943629, 9.710726567810395, 10.766998548383114, 11.824882333450574, 12.666163773014919, 11.71281031301767, 10.710208686216893, 8.739123769348051, 7.727791998027546, 6.743575331208498, 5.793764166836425, 4.850316831006106, 3.8610445254867143, 2.8780372276110535, 1.955903530540522, 2.9120757218340905, 3.8581727887380732, 4.892924089206186, 5.8586068335546235, 6.822237882218015, 7.867346451003529, 8.915460571973655, 9.928131037223386, 10.98577554096437, 11.611294351679888, 10.660862453792245, 9.723354614057053, 7.794100469082546, 6.762416269788551, 5.794573695734224, 4.75489099485492, 3.7906841283916415, 2.8570361996830886, 1.8679845544080678, 0.9252486407852474, 1.907680126684526, 2.936232038477558, 3.951696611005099, 4.9285150790668295, 5.921483133444494, 6.946307560595477, 8.009716445770763, 8.9665468017183, 10.005562119793384, 10.649829130929435, 9.672592226391123, 8.732001073110736, 7.014495461574952, 6.0592894600782214, 5.06788244647497, 4.039957244976295, 3.011182033497785, 2.0735749737825886, 1.03331514693363, 0.0, 0.9729128604355544, 1.9585647140555598, 2.893154702913354, 3.9196007807352835, 4.990131234445628, 5.961542435159784, 7.027872446574399, 8.075059640521541, 9.049833583317046, 9.933138428057836, 8.996573217560433, 7.94512357228587, 8.007697549698316, 7.073029998950393, 6.043093595714649, 4.979397387647192, 4.00312513579312, 3.0338101904066765, 1.9613952673482675, 0.9460939467163106, 1.904250011090999, 2.894344741017004, 3.8418220601350535, 4.807603063922583, 5.738083602353049, 6.783921268434963, 7.791738048734613, 8.770447707238672, 9.72989302060467, 10.803357346865159, 9.939519796598063, 8.934165860204246, 8.809274362381952, 7.818606779483196, 6.870996080578063, 5.859316563452579, 4.8385595229246015, 3.8708202341976286, 2.884160175630349, 1.892602729156411, 2.8460659013192635, 3.8132683708618047, 4.872870580098822, 5.82854904934581, 6.670177938215034, 7.736259746872948, 8.720534821265083, 9.662628336561436, 10.609952926460096, 11.54181060673862, 10.861203215856472, 9.869946904113023, 9.73787441848611, 8.802735481791762, 7.82395046769501, 6.896688544321834, 5.869947356291499, 4.8528632968972705, 3.8887944308258566, 2.9612829603969946, 3.9210392110075576, 4.776330421211158, 5.7719764263535644, 6.779716538222712, 7.612842577202427, 8.676570958344106, 9.630179681333885, 10.567919086652669, 11.57256761174019, 12.515998351884235, 11.848977040643797, 10.789646297019688, 10.71989967367166, 9.776925722297774, 8.859069702873352, 7.84423674034458, 6.860845654188546, 5.864659397243526, 4.822007978744613, 3.9044553269221156, 4.874257018835415, 5.746432853235291, 6.699750445503044, 7.682599515286494, 8.62617880173213, 9.559731646501692, 10.618881676495539, 11.553850464837028, 12.62782269037027, 13.467692593547476, 12.77896089551771, 11.791041653761754, 11.652517070036989, 10.702355320653984, 9.721382458591211, 8.713596012119169, 7.771697532345934, 6.705469808222721, 5.759825182458851, 4.830724608020836, 5.85341676813013, 6.769266527894176, 7.649056903467659, 8.705051137599899, 9.636199135706162, 10.583168521481547, 11.508368964885012, 12.489206909593618, 13.544861248805054, 14.483343716787887, 13.677854662215838, 12.677405276604937, 12.607090164388449, 11.671850707470478, 10.630256495070144, 9.67057372177499, 8.737301460826576, 7.749747557099373, 6.780337431192256, 5.810913590131989, 6.874920628534451, 7.760187028609748, 8.624440426993843, 9.614190231538942, 10.59060249373249, 11.56484457887379, 12.524452295497712, 13.461980748792792, 14.420279209667411, 15.404826621901226, 14.659846372193586, 13.609867488185191, 13.50826256176195, 12.49533712744021, 11.565723304720532, 10.601871035976934, 9.757083568528126, 8.762347574251905, 7.788693720562891, 6.8806180312572796, 7.882734563377364, 8.813668675964621, 9.632493385995076, 10.630784996147833, 11.565531104400735, 12.563971178603667, 13.553356955362467, 14.405479288766182, 15.351592265777677, 16.321838849124433, 15.524823111307922, 14.482435034556095, 14.419589952494862, 13.458360202934248, 12.50518024799215, 11.574794419195717, 10.692279251965182, 9.723510215791114, 8.838267357338271, 7.89259203143655, 8.835434026325132, 9.812562825907191, 10.674692168540078, 11.678417982726137, 12.063501248286283, 12.86974875979939, 13.814059551730217, 14.729653130562797, 15.47920644432931, 16.424659971580475, 16.35366624957116, 15.410972658641313, 15.365439220042134, 14.427931472535189, 13.432383181303257, 12.53749350601243, 11.629719275973121, 10.758961195603732, 9.911643836132617, 8.902155454177628, 9.768419630666338, 10.73194907647425, 11.64653093708877, 11.854365770745629, 11.104499573542943, 11.839478552509373, 12.862207163893205, 13.749072029647115, 14.499520197247659, 15.44200961327283, 16.411172772950795, 16.41708164884129, 16.390787707299943, 15.386098457881259, 14.454274331369637, 13.463263484977277, 12.670165322072764, 11.7892686254617, 10.84710598207985, 9.864484612658156, 10.793722321065015, 11.738179074719476, 11.599632194037703, 10.8069447322231, 10.173808968295269, 10.84470318677743, 11.84716045887203, 12.81147661475808, 13.47616330847592, 14.516439426363986, 15.458417458938138, 16.30115499551004, 16.33865163403445, 16.443305157480413, 15.404983221907925, 14.421196292376754, 13.730045181469002, 12.738810160050347, 11.805886913347637, 10.926900551492597, 11.776035189250312, 11.614954253998022, 10.661979955025942, 9.803157819321465, 9.135895388438291, 9.813510183246336, 10.814010139073563, 11.819754737631456, 12.51313941863691, 13.497635726507916, 14.4441079887628, 15.369593765743254, 15.432005560861528, 16.378878846259664, 16.373470782053865, 15.35338039073577, 14.708093240938956, 13.752969199150211, 12.796668011280666, 11.896856136071426, 11.571531503094416, 10.583488693311269, 9.652330325509384, 8.731704562997873, 8.08730676358528, 8.865582149195149, 9.790264244814164, 10.770576217911653, 11.552946687327692, 12.517619325083679, 13.478422776026619, 14.478263143358117, 14.537709236681327, 15.532244830603329, 16.312275333725275, 15.375360153741823, 14.377396634953397, 13.528265376766663, 12.518147893673989, 11.564139220095301, 10.57799483011998, 9.617580026302115, 8.680248447595773, 7.795610696083919, 7.092473773375796, 7.807558130022382, 8.797524206761777, 9.835047354159764, 10.590704733740452, 11.62291720411791, 12.65641219456041, 13.588692080833827, 13.509956242006476, 14.513225839827825, 15.43486401339226, 14.442668441574625, 13.409805161551512, 12.458775205507553, 11.510521305672214, 10.541423286067822, 9.582511736908954, 8.758533530155123, 7.735665298718766, 6.832155073071108, 6.064065434102257, 6.792301332533079, 7.772292598574208, 8.813370806741972, 9.624059998783151, 10.626473607149798, 11.587235380014954, 12.565335332984036], [12.563613834713204, 11.613969321593654, 10.620626986049665, 9.660834832508094, 8.772862084777007, 7.78616344312101, 6.771881540199172, 5.9757324272568475, 4.965536393709532, 5.856855815066115, 6.844421652003365, 7.690723275186964, 8.654665947827358, 9.64465884646946, 10.601258377324037, 11.572294204580698, 12.6107951389913, 13.62298709814014, 14.428166475726886, 13.477138259441084, 11.60785384944432, 10.66276975509106, 9.76188447081409, 8.72043675352015, 7.78528334879485, 6.845938824650806, 5.831988336121235, 4.975364159913708, 3.9886171532812478, 4.864702112150867, 5.8188073701596466, 6.74844037956091, 7.787164397533636, 8.768440873898388, 9.757044664622079, 10.76341454595959, 11.726374917104822, 12.771356410162326, 13.49537034420422, 12.5484439556482, 10.702820547675804, 9.662113933302248, 8.72705300812216, 7.729187651264267, 6.776179587506329, 5.857600378151501, 4.808386664633485, 3.983019158759914, 3.0131928431213426, 3.931526537605964, 4.9722716783810785, 5.89805767759751, 6.816229821435366, 7.764813817508073, 8.73781370737484, 9.79408568794756, 10.85196947301502, 11.90240140148986, 12.685723173453223, 11.683121546652446, 9.712036629783604, 8.700704858463101, 7.716488191644053, 6.76667702727198, 5.823229691441661, 4.833957385922269, 3.850950088046608, 2.9288163909760763, 2.031863119844389, 2.977960186748372, 3.920011228770631, 4.885693973119069, 5.849325021782461, 6.894433590567974, 7.942547711538101, 8.95521817678783, 10.012862680528816, 10.950992302518365, 11.633775314227798, 10.696267474492606, 8.7670133295181, 7.735329130224105, 6.767486556169779, 5.727803855290475, 4.763596988827197, 3.8299490601186434, 2.840897414843622, 1.8981615012208017, 1.0102186689021082, 1.9633191780420036, 2.9787837505695443, 3.9556022186312747, 4.948570273008939, 5.973394700159922, 7.036803585335208, 7.993633941282744, 9.032649259357829, 10.05963511364826, 10.645505086826676, 9.704913933546289, 7.9874083220105065, 7.032202320513776, 6.040795306910525, 5.0128701054118485, 3.9840948939333387, 3.046487834218143, 2.0062280073691845, 0.9729128604355544, 0.0, 0.9856518536200054, 1.9202418424777998, 2.946687920299729, 4.017218374010073, 4.9886295747242295, 6.054959586138844, 7.102146780085986, 8.076920722881491, 9.102825743030964, 9.969486077995988, 8.918036432721426, 8.98061041013387, 8.045942859385947, 7.016006456150203, 5.952310248082746, 4.976037996228674, 4.006723050842231, 2.934308127783822, 1.919006807151865, 0.9828510320536957, 1.9214318805814496, 2.868909199699499, 3.834690203487029, 4.765170741917495, 5.811008407999408, 6.8188251882990585, 7.797534846803116, 8.756980160169114, 9.830444486429602, 10.795905120863196, 9.9070787206398, 9.782187222817509, 8.791519639918752, 7.843908941013618, 6.832229423888133, 5.811472383360156, 4.843733094633183, 3.8570730360659033, 2.8655155895919653, 1.9246669222819601, 2.891869391824501, 3.906627741821715, 4.862306211068703, 5.69726507777948, 6.763346886437394, 7.74762196082953, 8.689715476125883, 9.637040066024543, 10.568897746303067, 11.594153266311434, 10.84285976454858, 10.710787278921666, 9.775648342227317, 8.796863328130565, 7.869601404757389, 6.842860216727054, 5.825776157332825, 4.861707291261411, 3.9341958208325494, 2.999640231970254, 3.8549314421738545, 4.850577447316261, 5.813473699945606, 6.639929716766873, 7.703658097908553, 8.657266820898332, 9.595006226217116, 10.599654751304637, 11.543085491448682, 12.580054428820624, 11.762559157455245, 11.692812534107215, 10.749838582733329, 9.831982563308907, 8.817149600780134, 7.833758514624101, 6.8375722576790805, 5.794920839180167, 4.87736818735767, 3.953453199670577, 4.825033874197987, 5.7783514664657405, 6.761200536249191, 7.653265941296576, 8.586818786066138, 9.645968816059986, 10.580937604401475, 11.654909829934716, 12.494779733111923, 13.449696650255046, 12.763954514197309, 12.625429930472544, 11.675268181089539, 10.694295319026766, 9.686508872554723, 8.744610392781489, 7.6783826686582755, 6.732738042894406, 5.803637468456391, 4.932612948965293, 5.847867548856873, 6.727657924430355, 7.783652158562594, 8.681222556997243, 9.628191942772627, 10.553392386176093, 11.534230330884698, 12.589884670096135, 13.528367138078968, 14.479466587599312, 13.650318137040491, 13.580003024824004, 12.644763567906033, 11.6031693555057, 10.643486582210546, 9.710214321262132, 8.722660417534929, 7.753250291627811, 6.783826450567544, 5.975324000605465, 6.838788049572444, 7.703041447956538, 8.692791252501637, 9.63562591502357, 10.609868000164871, 11.569475716788792, 12.507004170083873, 13.465302630958492, 14.449850043192306, 15.473430814596318, 14.582780348620746, 14.481175422197506, 13.468249987875767, 12.538636165156088, 11.574783896412491, 10.72999642896368, 9.73526043468746, 8.761606580998446, 7.853530891692834, 6.983137935448378, 7.8922696969273165, 8.71109440695777, 9.709386017110527, 10.610554525691816, 11.608994599894748, 12.598380376653548, 13.450502710057263, 14.396615687068758, 15.366862270415513, 16.331848337031737, 15.455347894991652, 15.392502812930418, 14.431273063369805, 13.478093108427707, 12.547707279631274, 11.665192112400737, 10.696423076226669, 9.811180217773828, 8.865504891872105, 7.935837398396145, 8.912966197978205, 9.753293189502772, 10.75701900368883, 11.603625249584077, 12.566450466531718, 13.537178373050745, 14.388029499417122, 15.362754878576592, 16.355312383283383, 17.326579110006715, 16.38388551907687, 16.33835208047769, 15.400844332970745, 14.405296041738813, 13.510406366447986, 12.602632136408676, 11.731874056039288, 10.884556696568174, 9.875068314613182, 8.86882300273735, 9.832352448545262, 10.725131958051463, 10.974153168755924, 11.797253988428427, 12.69440593844218, 13.730186465761813, 14.667878349233241, 15.472433057683213, 16.414922473708383, 17.384085633386352, 17.389994509276846, 17.3637005677355, 16.359011318316817, 15.427187191805194, 14.436176345412834, 13.643078182508319, 12.762181485897257, 11.820018842515404, 10.837397473093711, 9.894125693136028, 10.838582446790488, 10.719419592048002, 9.926732130233395, 10.866563383180752, 11.699630572710237, 12.71513976074064, 13.730282934344206, 14.449076168911475, 15.48935228679954, 16.431330319373693, 17.274067855945592, 17.31156449447, 17.41621801791597, 16.37789608234348, 15.39410915281231, 14.702958041904557, 13.711723020485904, 12.778799773783192, 11.830859762237598, 10.876438561321324, 10.73474165200832, 9.78176735303624, 8.92294521733176, 9.828649803323774, 10.668437569179144, 11.681989440942171, 12.738561057217582, 13.486052279072466, 14.47054858694347, 15.417020849198355, 16.342506626178807, 16.404918421297083, 17.351791706695217, 16.411375876593258, 15.495684410433762, 14.431120298015337, 13.54677946347326, 12.590478275603715, 11.7169767336457, 10.691318901104715, 9.703276091321568, 8.772117723519683, 7.851491961008169, 8.780061178470763, 9.720509535127956, 10.726882522294327, 11.72184332081749, 12.525859547763247, 13.490532185519234, 14.451335636462174, 15.451176003793671, 15.510622097116883, 16.393238764464854, 15.432062731735574, 14.495147551752122, 13.497184032963695, 12.64805277477696, 11.637935291684286, 10.683926618105598, 9.697782228130277, 8.737367424312414, 7.800035845606072, 6.915398094094217, 7.957816470244715, 8.780470990457937, 9.77043706719733, 10.807960214595317, 11.563617594176007, 12.595830064553464, 13.629325054995965, 14.561604941269382, 14.482869102442033, 15.486138700263378, 14.55465141140256, 13.562455839584924, 12.52959255956181, 11.57856260351785, 10.63030870368251, 9.661210684078121, 8.702299134919251, 7.8783209281654205, 6.855452696729064, 5.951942471081406, 6.977352923342939, 7.765214192968634, 8.745205459009762, 9.786283667177528, 10.596972859218706, 11.599386467585353, 12.56014824045051, 13.53824819341959], [13.54926568833321, 12.59962117521366, 11.60627883966967, 10.6464866861281, 9.758513938397012, 8.769629115489735, 7.755347212567897, 6.880596544278408, 5.870400510731091, 4.890557291044986, 5.878123127982235, 6.724424751165834, 7.688367423806229, 8.67836032244833, 9.634959853302908, 10.60599568055957, 11.64449661497017, 12.65668857411901, 13.705120005105089, 14.46279011306109, 12.593505703064325, 11.648421608711066, 10.747536324434096, 9.706088607140156, 8.770935202414856, 7.8315906782708105, 6.81545400848996, 5.880228276935268, 4.893481270302807, 3.898403588129737, 4.852508846138517, 5.7821418555397806, 6.820865873512506, 7.801280211364734, 8.771392811002073, 9.777762692339584, 10.740723063484817, 11.78570455654232, 12.772323873582422, 13.534095809268205, 11.68847240129581, 10.647765786922253, 9.712704861742166, 8.714839504884273, 7.7618314411263345, 6.843252231771506, 5.7940385182534895, 4.887883275781474, 3.918056960142902, 2.9652280135848343, 4.001123104688389, 4.912405823977505, 5.83057796781536, 6.779161963888067, 7.752161853754835, 8.808433834327554, 9.866317619395014, 10.916749547869854, 11.880764422586289, 12.668773400272451, 10.69768848340361, 9.686356712083107, 8.70214004526406, 7.7523288808919855, 6.808881545061666, 5.819609239542275, 4.836601941666613, 3.9139309209247934, 2.957758729631225, 2.011661662727242, 2.934359375150626, 3.900042119499063, 4.863673168162455, 5.908781736947969, 6.956895857918095, 7.969566323167825, 9.02721082690881, 9.96534044889836, 10.962876778113692, 11.681919328112611, 9.752665183138106, 8.720980983844111, 7.753138409789784, 6.71345570891048, 5.749248842447202, 4.815600913738649, 3.8265492684636278, 2.8838133548408074, 1.9958705225221136, 0.9776673244219982, 1.993131896949539, 2.9699503650112695, 3.9629184193889344, 4.987742846539917, 6.051151731715203, 7.0079820876627394, 8.046997405737823, 9.073983260028255, 9.988297812432371, 10.690565787166294, 8.973060175630513, 8.017854174133783, 7.02644716053053, 5.998521959031854, 4.969746747553344, 4.032139687838148, 2.9918798609891897, 1.9585647140555598, 0.9856518536200054, 0.0, 0.9345899888577945, 1.961036066679724, 3.0315665203900686, 4.002977721104225, 5.06930773251884, 6.116494926465982, 7.091268869261486, 8.11717388941096, 9.053739099908363, 9.903688286341431, 9.966262263753876, 9.031594713005953, 8.001658309770209, 6.937962101702752, 5.961689849848679, 4.9923749044622365, 3.9199599814038275, 2.9046586607718705, 1.949468903212928, 0.9357800269614441, 1.8832573460794937, 2.8490383498670235, 3.7795188882974893, 4.825356554379402, 5.833173334679053, 6.811882993183111, 7.771328306549108, 8.844792632809597, 9.81025326724319, 10.815607203637008, 10.767839076437514, 9.777171493538757, 8.829560794633624, 7.817881277508139, 6.797124236980162, 5.829384948253189, 4.842724889685909, 3.851167443211971, 2.8912847934411925, 1.9524276728085068, 2.92097588820171, 3.8766543574486976, 4.711613224159475, 5.777695032817388, 6.761970107209525, 7.704063622505878, 8.651388212404537, 9.583245892683061, 10.608501412691428, 11.599757724434877, 11.696439132541672, 10.761300195847323, 9.78251518175057, 8.855253258377394, 7.82851207034706, 6.811428010952831, 5.847359144881417, 4.905865052313288, 3.8801927199454465, 2.9154897231578603, 3.911135728300267, 4.8278218463256, 5.654277863146867, 6.7180062442885475, 7.671614967278326, 8.60935437259711, 9.614002897684632, 10.557433637828677, 11.594402575200618, 12.560309936515575, 12.678464387727221, 11.735490436353334, 10.817634416928913, 9.780357946794418, 8.796966860638385, 7.800780603693364, 6.726195567566072, 5.790789359339226, 4.820987667425927, 3.8855921551819925, 4.838909747449746, 5.821758817233196, 6.66761408767657, 7.601166932446132, 8.66031696243998, 9.59528575078147, 10.66925797631471, 11.509127879491917, 12.46404479663504, 13.451964038390994, 13.556704658858449, 12.606542909475444, 11.62557004741267, 10.617783600940628, 9.675885121167394, 8.609657397044181, 7.66401277128031, 6.717058640437947, 5.800147416720642, 4.908425829840878, 5.78821620541436, 6.8442104395465995, 7.695570703377237, 8.642540089152622, 9.567740532556087, 10.548578477264693, 11.604232816476129, 12.542715284458962, 13.493814733979306, 14.463612253782813, 14.511277753209908, 13.576038296291937, 12.534444083891605, 11.57476131059645, 10.641489049648037, 9.653935145920833, 8.684525020013716, 7.697247622549099, 6.842858468360813, 5.899346330556449, 6.763599728940544, 7.753349533485642, 8.649974061403565, 9.624216146544866, 10.583823863168787, 11.521352316463867, 12.479650777338486, 13.4641981895723, 14.487778960976312, 15.396074465363068, 15.41245015058341, 14.399524716261672, 13.469910893541993, 12.506058624798396, 11.661271157349585, 10.666535163073364, 9.69288130938435, 8.76695206367439, 7.850672403203726, 6.952827977911323, 7.771652687941776, 8.769944298094533, 9.62490267207181, 10.623342746274743, 11.612728523033542, 12.464850856437257, 13.410963833448752, 14.381210416795508, 15.346196483411733, 16.382362956775605, 16.32377754131632, 15.36254779175571, 14.409367836813612, 13.478982008017178, 12.596466840786642, 11.627697804612573, 10.742454946159732, 9.77892606385366, 8.803371866151494, 8.023637609846604, 8.813851470486778, 9.817577284672836, 10.617973395964071, 11.580798612911712, 12.55152651943074, 13.402377645797117, 14.377103024956586, 15.36966052966338, 16.353897263865356, 17.296590854795202, 17.269626808863592, 16.33211906135665, 15.336570770124718, 14.441681094833891, 13.53390686479458, 12.663148784425193, 11.815831424954078, 10.788489486594738, 9.7363574704927, 8.958740129468103, 9.78569023903547, 10.767178232208867, 11.57697507070741, 12.59592046156942, 13.503378907267752, 14.382958746712799, 15.356789272038238, 16.29927868806341, 17.285625848934664, 18.321269237662747, 18.2949752961214, 17.29028604670272, 16.358461920191097, 15.367451073798739, 14.574352910894223, 13.693456214283161, 12.711704210711995, 11.729082841290301, 10.761660160891378, 9.966246340222087, 9.753121068026871, 10.689328938166655, 11.722088534028629, 12.593796534261621, 13.609305722292023, 14.62444889589559, 15.43472802253148, 16.475004140419546, 17.4169821729937, 18.259719709565598, 18.297216348090007, 17.46778120728465, 16.445356914302817, 15.461569984771648, 14.48859881163982, 13.58496046536901, 12.605266188645558, 11.623252241210642, 10.668831040294368, 9.768443127987192, 8.81546882901511, 9.817111178883144, 10.722815764875158, 11.562603530730527, 12.576155402493555, 13.632727018768966, 14.471704132692471, 15.456200440563476, 16.40267270281836, 17.328158479798812, 17.367991644795552, 16.42111835939742, 15.445077352572127, 14.529385886412632, 13.464821773994208, 12.58048093945213, 11.624179751582584, 10.75067820962457, 9.725020377083586, 8.736977567300439, 7.805819199498553, 8.745657922559552, 9.674227140022147, 10.61467549667934, 11.62104848384571, 12.616009282368873, 13.511511401383252, 14.47618403913924, 15.43698749008218, 16.436827857413675, 16.49627395073689, 15.426940240443724, 14.465764207714443, 13.528849027730992, 12.530885508942566, 11.681754250755832, 10.671636767663157, 9.717628094084468, 8.731483704109147, 7.771068900291284, 6.833737321584942, 7.809564055645598, 8.851982431796097, 9.76393666282666, 10.753902739566055, 11.791425886964042, 12.549269447796012, 13.58148191817347, 14.61497690861597, 15.547256794889387, 15.468520956062038, 14.638325846942648, 13.58835288738143, 12.596157315563794, 11.56329403554068, 10.612264079496722, 9.664010179661382, 8.69491216005699, 7.736000610898121, 6.912022404144292, 5.889154172707935, 6.846108432632787, 7.882217040364499, 8.748679865337358, 9.728671131378487, 10.771935520797534, 11.582624712838712, 12.585038321205358, 13.545800094070515, 14.523900047039596], [14.483855677191004, 13.534211164071454, 12.540868828527465, 11.581076674985894, 10.693103927254807, 9.704219104347528, 8.68993720142569, 7.8151865331362025, 6.804990499588886, 5.82514727990278, 5.079845239547668, 5.857598176675084, 6.821540849315478, 7.811533747957581, 8.763768214957013, 9.734804042213675, 10.773304976624274, 11.785496935773114, 12.770530016247294, 13.713354577073531, 13.52809569192212, 12.583011597568861, 11.682126313291889, 10.64067859599795, 9.70552519127265, 8.766180667128605, 7.750043997347754, 6.814818265793063, 5.828071259160602, 4.832993576987532, 4.041708968582911, 4.91531528104903, 5.9175478946146, 6.86669022250694, 7.836802822144278, 8.84317270348179, 9.806133074627022, 10.851114567684526, 11.837733884724628, 12.784660273280648, 12.623062390153605, 11.582355775780048, 10.647294850599959, 9.649429493742065, 8.69642142998413, 7.7778422206293, 6.728628507111284, 5.822473264639268, 4.852646949000697, 3.899818002442629, 3.0665331158305946, 3.977815835119711, 4.895987978957566, 5.844571975030274, 6.81757186489704, 7.873843845469759, 8.93172763053722, 9.982159559012059, 10.946174433728494, 11.952648701150931, 11.632278472261405, 10.6209467009409, 9.636730034121852, 8.686918869749778, 7.74347153391946, 6.7541992284000685, 5.771191930524408, 4.848520909782588, 3.8923487184890195, 2.9462516515850368, 1.9997693862928314, 2.9654521306412693, 3.929083179304661, 4.974191748090175, 6.022305869060301, 7.034976334310031, 8.092620838051017, 9.030750460040567, 10.0282867892559, 10.965794628991091, 10.6872551719959, 9.655570972701904, 8.687728398647577, 7.648045697768274, 6.683838831304996, 5.750190902596443, 4.761139257321422, 3.8184033436986016, 2.9304605113799083, 1.9122573132797926, 1.0585419080917446, 2.0353603761534753, 3.02832843053114, 4.0531528576821225, 5.116561742857408, 6.073392098804945, 7.112407416880029, 8.13939327117046, 9.053707823574577, 9.994298976854964, 9.907650164488308, 8.952444162991577, 7.961037149388325, 6.933111947889649, 5.904336736411139, 4.966729676695943, 3.926469849846984, 2.893154702913354, 1.9202418424777998, 0.9345899888577945, 0.0, 1.0264460778219293, 2.096976531532274, 3.06838773224643, 4.134717743661045, 5.181904937608187, 6.156678880403692, 7.182583900553165, 8.119149111050568, 9.17059875632513, 10.812971546735247, 9.966184701863748, 8.936248298628003, 7.872552090560546, 6.896279838706474, 5.926964893320031, 4.854549970261622, 3.8392486496296647, 2.8840588920707226, 1.8703700158192387, 0.9486673572216991, 1.9144483610092293, 2.8449288994396955, 3.890766565521609, 4.898583345821259, 5.877293004325317, 6.836738317691315, 7.910202643951802, 8.875663278385396, 9.881017214779213, 11.702429065295307, 10.71176148239655, 9.764150783491417, 8.752471266365932, 7.731714225837956, 6.763974937110983, 5.777314878543703, 4.785757432069765, 3.825874782298987, 2.8870176616663015, 1.9863858993439152, 2.942064368590903, 3.777023235301681, 4.843105043959595, 5.82738011835173, 6.769473633648083, 7.716798223546743, 8.648655903825267, 9.673911423833633, 10.665167735577082, 12.631029121399465, 11.695890184705116, 10.717105170608363, 9.789843247235188, 8.763102059204854, 7.746017999810625, 6.781949133739211, 5.840455041171083, 4.814782708803241, 3.850079712015655, 3.038326397816665, 3.8932318574678053, 4.7196878742890735, 5.783416255430753, 6.737024978420531, 7.674764383739316, 8.679412908826837, 9.622843648970882, 10.659812586342824, 11.62571994765778, 13.588516029623293, 12.670080425211127, 11.752224405786706, 10.714947935652212, 9.73155684949618, 8.73537059255116, 7.660785556423867, 6.725379348197021, 5.755577656283721, 4.820182144039787, 4.0179440270507145, 4.8946478402237785, 5.7330240988187775, 6.666576943588339, 7.725726973582185, 8.660695761923675, 9.734667987456916, 10.574537890634122, 11.529454807777245, 12.517374049533199, 14.491294647716243, 13.541132898333238, 12.560160036270466, 11.552373589798423, 10.610475110025188, 9.544247385901976, 8.598602760138105, 7.6516486292957415, 6.734737405578437, 5.843015818698673, 4.967250485015329, 5.925009498319051, 6.7609807145194445, 7.707950100294829, 8.633150543698294, 9.6139884884069, 10.669642827618336, 11.60812529560117, 12.559224745121512, 13.529022264925018, 15.445867742067703, 14.510628285149732, 13.4690340727494, 12.509351299454245, 11.576079038505831, 10.588525134778628, 9.61911500887151, 8.631837611406894, 7.777448457218608, 6.833936319414244, 5.942634008541512, 6.932383813086611, 7.715384072545772, 8.689626157687073, 9.649233874310994, 10.586762327606074, 11.545060788480694, 12.529608200714508, 13.55318897211852, 14.461484476505273, 16.347040139441205, 15.334114705119466, 14.404500882399788, 13.44064861365619, 12.59586114620738, 11.601125151931159, 10.627471298242146, 9.701542052532185, 8.78526239206152, 7.887417966769117, 6.950686967542745, 7.9489785776955015, 8.690312683214017, 9.68875275741695, 10.67813853417575, 11.530260867579464, 12.47637384459096, 13.446620427937715, 14.41160649455394, 15.44777296791781, 17.258367530174116, 16.297137780613504, 15.343957825671406, 14.413571996874973, 13.531056829644436, 12.562287793470368, 11.677044935017527, 10.713516052711455, 9.737961855009289, 8.958227598704399, 7.992885750087746, 8.996611564273806, 9.683383407106279, 10.64620862405392, 11.616936530572946, 12.467787656939324, 13.442513036098793, 14.435070540805587, 15.419307275007563, 16.362000865937407, 18.204216797721386, 17.26670905021444, 16.27116075898251, 15.376271083691686, 14.468496853652375, 13.597738773282988, 12.750421413811873, 11.723079475452533, 10.670947459350495, 9.893330118325897, 8.964724518636437, 9.946212511809836, 10.642385081849618, 11.661330472711628, 12.56878891840996, 13.448368757855006, 14.422199283180444, 15.364688699205615, 16.35103586007687, 17.400283018338587, 18.40601908306419, 17.521384570848642, 16.539322000217588, 15.54831115382523, 14.651475667867365, 13.677370086336964, 12.706915206292653, 11.773913876542238, 10.806491196143314, 10.257552487080863, 9.920210800606526, 10.85641867074631, 11.573075687097292, 12.583617179550053, 13.583835623431133, 14.38596417274404, 15.445556171952182, 16.43608390848616, 17.30379117408953, 18.237931238335847, 17.475264275545307, 16.596589568938754, 15.574165275956924, 14.590378346425753, 13.617407173293925, 12.727828551748317, 11.748134275024865, 10.778599528874292, 9.824178327958018, 9.25852675442718, 9.750058817872906, 10.751701167740938, 11.657405753732952, 12.497193519588322, 13.51074539135135, 14.56731700762676, 15.406294121550266, 16.390790429421273, 17.337262691676155, 18.262748468656607, 16.496800006449657, 15.549926721051522, 14.573885714226233, 13.658194248066737, 12.593630135648313, 11.713654364961382, 10.757353177091836, 9.906025497288221, 8.880367664747236, 8.227061193740427, 8.740409188356349, 9.680247911417347, 10.608817128879942, 11.549265485537134, 12.555638472703505, 13.550599271226668, 14.446101390241047, 15.410774027997034, 16.371577478939972, 17.37141784627147, 15.629159009238387, 14.555748602097829, 13.594572569368548, 12.657657389385097, 11.659693870596671, 10.810562612409937, 9.804810193172408, 8.850801519593716, 7.864657129618396, 7.1852085794051455, 7.768327310442737, 8.744154044503393, 9.786572420653892, 10.698526651684455, 11.688492728423848, 12.726015875821835, 13.483859436653807, 14.516071907031264, 15.549566897473765, 16.481846783747184, 14.71908542007448, 13.767134208596753, 12.717161249035534, 11.724965677217899, 10.692102397194786, 9.741072441150827, 8.797183605170632, 7.82808558556624, 6.869174036407371, 6.113744515709724, 6.823744161565729, 7.780698421490581, 8.816807029222293, 9.683269854195153, 10.66326112023628, 11.706525509655329, 12.517214701696506, 13.519628310063153, 14.48039008292831, 15.458490035897391], [13.684333227381423, 14.560657241893383, 13.567314906349393, 12.607522752807823, 11.687698937829852, 10.683000622741002, 9.668718719819164, 8.793968051529676, 7.78377201798236, 6.777890451273775, 5.869767761314504, 4.8442813765745365, 5.808224049214931, 6.798216947857034, 7.750451414856468, 8.721487242113131, 9.75998817652373, 10.77218013567257, 11.75721321614675, 12.700037776972987, 12.711933579383984, 13.609457675390791, 12.708572391113819, 11.66712467381988, 10.73197126909458, 9.789851404389301, 8.728825515741228, 7.7935997841865365, 6.806852777554076, 5.785736748358526, 4.831631490349746, 3.9019984809484827, 4.904231094514053, 5.853373422406394, 6.823486022043732, 7.829855903381244, 8.792816274526476, 9.837797767583982, 10.824417084624084, 11.771343473180105, 11.883770649949142, 12.608801853601978, 11.67374092842189, 10.675875571563996, 9.722867507806058, 8.80428829845123, 7.755074584933213, 6.848919342461198, 5.879093026822626, 4.926264080264558, 3.9439074411395536, 2.9644990350191636, 3.8826711788570196, 4.831255174929727, 5.804255064796495, 6.8605270453692135, 7.918410830436674, 8.968842758911514, 9.932857633627949, 10.926202623329, 10.850776803326726, 11.64739277876283, 10.663176111943782, 9.713364947571709, 8.76991761174139, 7.780645306221998, 6.797638008346337, 5.874966987604518, 4.918794796310949, 3.972697729406966, 2.9400895223157457, 1.952135330540722, 2.915766379204114, 3.9608749479896277, 5.008989068959754, 6.021659534209483, 7.066174760229086, 8.004304382218637, 9.00184071143397, 9.93934855116916, 9.905753503061222, 10.682017050523834, 9.714174476469507, 8.674491775590203, 7.710284909126925, 6.776636980418372, 5.787585335143351, 4.844849421520531, 3.9569065892018376, 2.938703391101722, 1.9988620441146587, 1.0220435760529283, 2.015011630430593, 3.0398360575815753, 4.103244942756861, 5.0600752987043975, 6.085961339058099, 7.11294719334853, 8.027261745752647, 8.967852899033034, 9.074780789214119, 9.978890240813508, 8.987483227210255, 7.959558025711579, 6.930782814233069, 5.993175754517873, 4.952915927668914, 3.919600780735284, 2.9466879202997296, 1.961036066679724, 1.0264460778219293, 0.0, 1.0705304537103444, 2.0419416544245004, 3.108271665839115, 4.155458859786257, 5.130232802581761, 6.156137822731234, 7.092703033228637, 8.1441526785032, 9.949079200184341, 10.924664696366131, 9.962694376449933, 8.898998168382477, 7.922725916528404, 6.95341097114196, 5.880996048083551, 4.8656947274515945, 3.910504969892652, 2.896816093641168, 1.9751134350436286, 1.0505560144583248, 1.9810365528887908, 3.026874218970704, 4.034690999270355, 5.013400657774413, 5.97284597114041, 7.046310297400899, 8.01177093183449, 9.017124868228308, 10.86194793075725, 11.73820756021848, 10.790596861313347, 9.778917344187862, 8.758160303659885, 7.790421014932913, 6.803760956365633, 5.812203509891695, 4.8523208601209165, 3.913463739488231, 3.0128319771658445, 2.082358962462716, 2.9131308887507763, 3.9792126974086903, 4.963487771800827, 5.9055812870971796, 6.852905876995839, 7.784763557274363, 8.81001907728273, 9.801275389026179, 11.790547986861407, 12.722336262527046, 11.743551248430293, 10.816289325057117, 9.789548137026783, 8.772464077632556, 7.808395211561141, 6.866901118993012, 5.84122878662517, 4.876525789837585, 4.064772475638595, 3.0335264513396183, 3.855795527738169, 4.919523908879849, 5.873132631869627, 6.81087203718841, 7.815520562275932, 8.758951302419977, 9.795920239791919, 10.761827601106877, 12.724623683072387, 13.667597634446274, 12.778670483608636, 11.741394013474142, 10.75800292731811, 9.76181667037309, 8.687231634245798, 7.751825426018951, 6.7820237341056515, 5.846628221861717, 5.017791503879042, 4.0349424340955915, 4.869131752267872, 5.802684597037434, 6.86183462703128, 7.79680341537277, 8.870775640906011, 9.710645544083217, 10.66556246122634, 11.653481702982294, 13.69001812494206, 14.56757897615517, 13.586606114092397, 12.578819667620355, 11.63692118784712, 10.570693463723908, 9.625048837960037, 8.67809470711767, 7.761183483400367, 6.869461896520603, 5.967097961843657, 5.065304092190864, 5.897088367968539, 6.8440577537439236, 7.769258197147388, 8.750096141855993, 9.80575048106743, 10.744232949050263, 11.695332398570606, 12.665129918374113, 14.631904283017363, 15.537074362971664, 14.49548015057133, 13.535797377276175, 12.602525116327762, 11.614971212600558, 10.645561086693442, 9.658283689228824, 8.803894535040538, 7.860382397236174, 6.94248148536984, 6.090804675395528, 6.851491725994867, 7.8257338111361685, 8.785341527760089, 9.722869981055167, 10.681168441929787, 11.6657158541636, 12.689296625567613, 13.597592129954368, 15.558053094161052, 16.3605607829414, 15.430946960221718, 14.46709469147812, 13.622307224029312, 12.62757122975309, 11.653917376064078, 10.727988130354115, 9.81170846988345, 8.913864044591048, 7.950534444371073, 7.132822644725774, 7.826420336663111, 8.824860410866046, 9.814246187624844, 10.666368521028557, 11.612481498040053, 12.582728081386808, 13.547714148003033, 14.583880621366905, 16.48949122553295, 17.323583858435438, 16.370403903493337, 15.440018074696903, 14.557502907466368, 13.5887338712923, 12.703491012839457, 11.739962130533385, 10.764407932831219, 9.97615259617621, 8.992733226916075, 8.180455631304078, 8.819491060555372, 9.782316277503012, 10.753044184022041, 11.603895310388417, 12.578620689547886, 13.57117819425468, 14.555414928456656, 15.498108519386502, 17.435340493080222, 17.41810426669375, 16.42255597546182, 15.460764332689534, 14.67860491386646, 13.694360716094385, 12.742852155033278, 11.72292623492222, 10.818477086441444, 10.911255115797708, 9.964571995464766, 9.130056578840108, 9.77849273529871, 10.79743812616072, 11.704896571859054, 12.584476411304099, 13.558306936629538, 14.50079635265471, 15.487143513525965, 16.536390671787682, 17.392702282963647, 16.508067770748102, 15.526005200117046, 14.534994353724686, 13.638158867766817, 12.664053286236417, 11.693598406192105, 10.760597076441691, 9.793174396042767, 10.737631149697227, 10.920058277434855, 10.177477617362637, 10.709183340546385, 11.719724832999146, 12.719943276880228, 13.522071826193134, 14.581663825401277, 15.572191561935254, 16.439898827538624, 17.37403889178494, 16.461947475444763, 15.58327276883821, 14.56084847585638, 13.57706154632521, 12.604090373193381, 11.71451175164777, 10.734817474924318, 9.765282728773744, 8.81086152785747, 9.848859178674306, 10.7028019892439, 11.181264530264272, 11.747096920403363, 12.75091783653024, 13.753093596678696, 14.513793703319758, 15.518657308634392, 16.590995261791324, 17.45420829771396, 17.40143601481828, 15.483483206349113, 14.536609920950978, 13.560568914125689, 12.644877447966193, 11.58031333554777, 10.700337564860835, 9.74403637699129, 8.892708697187672, 7.867050864646688, 8.855093674429837, 9.693152359727343, 10.63299108278834, 11.561560300250935, 12.502008656908128, 13.508381644074499, 14.503342442597662, 15.472547468062976, 16.437220105818962, 17.398023556761903, 16.437225623852523, 14.615842209137844, 13.542431801997285, 12.581255769268004, 11.644340589284553, 10.646377070496127, 9.797245812309392, 8.79149339307186, 7.837484719493169, 6.851340329517849, 7.834367453010575, 8.721070481813731, 9.696897215874387, 10.739315592024886, 11.677308170077929, 12.667274246817321, 13.704797394215309, 14.510305514475736, 15.542517984853193, 16.576012975295694, 15.580031577026563, 13.705768619973936, 12.753817408496209, 11.70384444893499, 10.711648877117355, 9.678785597094242, 8.727755641050281, 7.783866805070085, 6.814768785465692, 5.855857236306823, 6.903667037476561, 7.776487332936724, 8.733441592861576, 9.780866172517065, 10.662051372588627, 11.642042638629754, 12.701120520230374, 13.543660779518435, 14.546074387885081, 15.506836160750238, 14.725305853670704], [12.706428474631664, 13.655148805667642, 14.574692366960095, 13.614900213418524, 12.659983050195029, 11.655284735106179, 10.641002832184341, 9.766252163894853, 8.756056130347536, 7.750174563638951, 6.842051873679679, 5.8165654889397125, 5.031364169207205, 5.866876577189165, 6.812017289169635, 7.783053116426297, 8.821554050836898, 9.833746009985738, 10.818779090459914, 11.72213302422323, 11.734028826634226, 12.679112920987485, 13.657570127780668, 12.67450213443058, 11.73934872970528, 10.762135516754478, 9.701109628106405, 8.765883896551713, 7.779136889919252, 6.758020860723702, 5.803915602714922, 4.874282593313659, 3.9657969688272203, 4.914939296719561, 5.885051896356899, 6.8914217776944104, 7.854382148839643, 8.899363641897148, 9.885982958937248, 10.793438720430347, 10.813240196238798, 11.780063577153506, 12.744271382132235, 11.746406025274341, 10.793397961516403, 9.866251993385037, 8.81703827986702, 7.834469258617049, 6.864642942978477, 5.91181399642041, 4.91619155350473, 3.9367831473843395, 2.9442370531701867, 3.8928210492428943, 4.865820939109661, 5.922092919682381, 6.949310522784874, 7.988643349843324, 8.952658224559759, 9.855672169618657, 9.780246349616382, 10.81865450231436, 11.733706565654128, 10.783895401282054, 9.840448065451735, 8.84322120638992, 7.859601703280143, 6.860516903760368, 5.9043447124668, 4.9582476455628175, 3.9123736346809213, 2.924419442905898, 1.9773322535172813, 2.939341057726782, 3.9874551786969086, 4.985613680369271, 5.995644306518742, 6.933773928508293, 7.931310257723625, 8.868818097458817, 8.835223049350878, 9.866907248644875, 10.784704930179853, 9.745022229300549, 8.78081536283727, 7.847167434128717, 6.858115788853696, 5.915379875230876, 5.027437042912182, 4.009233844812067, 2.9711461564798345, 1.994327688418104, 1.0013596340404392, 2.012732719968243, 3.0671990889166483, 4.024029444864185, 5.015430885347755, 6.0424167396381865, 6.956731292042303, 7.897322445322689, 8.004250335503775, 8.959456337000505, 9.950863350603758, 9.030088479421924, 8.001313267943413, 7.063706208228217, 6.023446381379259, 4.990131234445629, 4.017218374010074, 3.0315665203900686, 2.096976531532274, 1.0705304537103444, 0.0, 0.971411200714156, 2.037741212128771, 3.084928406075913, 4.059702348871418, 5.085607369020891, 6.022172579518293, 7.073622224792857, 8.887359017242584, 9.862944513424374, 10.926508853320488, 9.96952862209282, 8.993256370238747, 8.006918562556535, 6.934503639498127, 5.91920231886617, 4.961046254491482, 3.9473573782399978, 2.941572188055174, 1.975791184267644, 1.0453106458371781, 1.965154036028948, 2.9729708163285986, 3.9516804748326564, 4.911125788198654, 5.984590114459142, 6.9500507488927346, 7.955404685286552, 9.841680817821826, 10.832348400720583, 11.779959099625717, 10.83242493560244, 9.811667895074462, 8.84392860634749, 7.857268547780209, 6.865711101306271, 5.902862144719746, 4.964005024087061, 3.933597616768914, 2.9779191475219258, 1.9774049816991637, 3.033314265609296, 3.943220658865405, 4.885314174161758, 5.832638764060418, 6.764496444338942, 7.789751964347308, 8.781008276090756, 10.770280873925984, 11.76641169929829, 12.732913486742664, 11.869796916471694, 10.84305572844136, 9.825971669047131, 8.861902802975717, 7.90548042488616, 6.879808092518318, 5.915105095730732, 4.919459090588326, 3.879732898181301, 2.920069620686556, 3.983798001828236, 4.937406724818015, 5.82248026578979, 6.827128790877311, 7.766720496134272, 8.803689433506213, 9.741560488171453, 11.732392876786683, 12.67536682816057, 13.722018935519719, 12.712081334600901, 11.728690248444869, 10.732503991499849, 9.657918955372557, 8.72251274714571, 7.752711055232412, 6.817315542988478, 5.863997950720725, 4.881148880937275, 3.9334058452162597, 4.866958689985822, 5.926108719979668, 6.808411643974149, 7.88238386950739, 8.718414737797511, 9.673331654940634, 10.66125089669659, 12.697787318656356, 13.647949068039361, 14.557293435219156, 13.549506988747114, 12.607608508973879, 11.541380784850666, 10.595736159086796, 9.648782028244431, 8.731870804527128, 7.8401492176473635, 6.813304408685339, 5.892510459023191, 4.961362460916927, 5.908331846692311, 6.833532290095776, 7.768115234696385, 8.823769573907821, 9.762252041890655, 10.7031015922849, 11.672899112088409, 13.639673476731659, 14.617444454855855, 15.46616747169809, 14.506484698402936, 13.573212437454522, 12.585658533727319, 11.616248407820201, 10.628971010355585, 9.7745818561673, 8.784982148535503, 7.788687932211523, 6.918011042227855, 5.915765818943255, 6.890007904084556, 7.849615620708477, 8.74088907389556, 9.699187534770179, 10.683734947003993, 11.707315718408005, 12.605361323668664, 14.565822287875347, 15.553265397539505, 16.40163428134848, 15.437782012604881, 14.59299454515607, 13.59825855087985, 12.624604697190836, 11.698675451480876, 10.782395791010213, 9.838463795890377, 8.796740891212755, 7.943888927591445, 6.890694429611499, 7.889134503814433, 8.878520280573232, 9.68438761386895, 10.630500590880445, 11.6007471742272, 12.565733240843425, 13.591649815081201, 15.507510318373345, 16.468740067933958, 16.41132478308609, 15.485029293819414, 14.68470456720653, 13.798471325239134, 12.884888263159755, 12.181155024520848, 11.73509525395798, 10.822359043017892, 9.838939673757757, 8.83116657848112, 7.883765153503759, 8.8465903704514, 9.817318276970429, 10.621914403228809, 11.596639782388278, 12.589197287095072, 13.573434021297048, 14.516127612226894, 16.453359585920616, 16.479670141006917, 15.484121849774986, 14.522330207002701, 13.747264543198591, 12.763020345426517, 11.81151178436541, 11.17159160177977, 11.790761198806619, 11.75746156263939, 10.780042920610155, 9.78076752601715, 8.842766828247099, 9.861712219109108, 10.769170664807442, 11.60249550414449, 12.576326029469929, 13.5188154454951, 14.505162606366355, 15.554409764628073, 16.454268157276815, 15.569633645061268, 14.587571074430214, 13.596560228037854, 12.706818497098949, 11.732712915568548, 10.762258035524237, 10.209262443299242, 10.765458508407942, 11.709915262062403, 11.735529202580244, 10.806217029356747, 9.773457433494773, 10.783998925947534, 11.784217369828616, 12.540090919033526, 13.599682918241667, 14.590210654775644, 15.457917920379014, 16.392057984625332, 15.52351334975793, 14.644838643151378, 13.622414350169548, 12.638627420638377, 11.665656247506547, 10.783171380979901, 9.80347710425645, 9.1468465044648, 9.783145640222646, 10.82114329103948, 11.675086101609075, 11.76889984092208, 10.811371013351751, 11.815191929478628, 12.817367689627083, 13.53181279616015, 14.536676401474786, 15.609014354631714, 16.47222739055435, 16.463001889131448, 14.545049080662281, 13.598175795264146, 12.622134788438856, 11.70644332227936, 10.641879209860935, 9.768997194192966, 8.81269600632342, 8.176890919885972, 8.839334977011864, 9.827377786795012, 10.665436472092518, 11.605275195153515, 11.859959638204762, 12.763119963529816, 13.769492950696186, 14.580991315879952, 15.496869132784004, 16.46154177053999, 16.498631865497188, 15.498791498165692, 13.677408083451011, 12.603997676310453, 11.642821643581172, 10.70590646359772, 9.707942944809293, 8.858811686622557, 7.860153022403992, 7.111868687027987, 7.823624441883025, 8.806651565375752, 9.693354594178906, 10.669181328239562, 11.71159970439006, 12.649592282443106, 13.639558359182498, 14.677081506580485, 15.517682975086437, 16.549895445463893, 15.670504539069952, 14.641597451339731, 12.727863867224178, 11.815383282809377, 10.765410323248158, 9.773214751430523, 8.740351471407408, 7.789321515363448, 6.8525264344022165, 6.0759786140029535, 6.828141348671999, 7.875951149841736, 8.7487714453019, 9.705725705226751, 10.75315028488224, 11.634335484953803, 12.61432675099493, 13.67340463259555, 14.551038240129136, 15.553451848495783, 14.601327724524497, 13.747401100920946], [11.735017273917508, 12.683737604953485, 13.677079940497475, 14.58631141413268, 13.631394250909185, 12.626695935820335, 11.612414032898497, 10.73766336460901, 9.727467331061693, 8.721585764353106, 7.813463074393836, 6.787976689653868, 5.978838492568644, 4.988845593926541, 5.906546489555112, 6.877582316811774, 7.916083251222374, 8.928275210371215, 9.90608665283502, 10.750721823509075, 10.76261762592007, 11.70770172027333, 12.686158927066511, 13.645913335144737, 12.710759930419437, 11.733546717468634, 10.672520828820561, 9.73729509726587, 8.750548090633409, 7.7294320614378575, 6.775326803429078, 5.845693794027814, 4.9372081695413765, 4.036908313456937, 4.9795810967423755, 5.985950978079887, 6.94891134922512, 7.987510419704183, 8.973290521312354, 9.82202751971619, 9.841828995524644, 10.808652376439351, 11.844481659677825, 12.717817225988496, 11.764809162230558, 10.837663194099191, 9.788449480581175, 8.805880459331204, 7.836054143692633, 6.883225197134565, 5.887602754218885, 4.908194348098495, 3.915648253884343, 3.0147900659802707, 3.960350139495138, 5.016622120067858, 5.9778993220707175, 7.017232149129168, 7.981247023845603, 8.884260968904501, 8.808835148902226, 9.847243301600203, 10.81338132834169, 11.755306601996208, 10.81185926616589, 9.814632407104076, 8.8310129039943, 7.831928104474525, 6.875755913180956, 5.929658846276973, 4.883784835395077, 3.8958306436200534, 2.9487434542314372, 1.967929857012626, 3.0160439779827524, 4.014202479655115, 5.024233105804586, 5.962362727794137, 6.959899057009469, 7.897406896744662, 7.863811848636721, 8.895496047930717, 9.863338621985044, 10.716433430014703, 9.752226563551424, 8.818578634842872, 7.82952698956785, 6.88679107594503, 5.9988482436263375, 4.980645045526222, 3.9425573571939903, 2.96573888913226, 1.9727708347545951, 1.041321519254087, 2.095787888202492, 3.052618244150029, 4.044019684633599, 5.07100553892403, 5.985320091328147, 6.925911244608533, 7.032839134789619, 7.988045136286349, 8.979452149889601, 10.001499680136078, 8.972724468657567, 8.035117408942371, 6.994857582093413, 5.961542435159783, 4.9886295747242295, 4.002977721104224, 3.0683877322464297, 2.0419416544245004, 0.971411200714156, 0.0, 1.0663300114146148, 2.113517205361757, 3.0882911481572615, 4.1141961683067345, 5.050761378804137, 6.1022110240787, 7.915947816528429, 8.891533312710218, 9.955097652606332, 10.940939822806975, 9.964667570952901, 8.978329763270692, 7.905914840212283, 6.890613519580326, 5.932457455205638, 4.918768578954154, 3.91298338876933, 2.9472023849818, 2.0167218465513344, 0.993742835314792, 2.0015596156144424, 2.9802692741185, 3.939714587484498, 5.013178913744985, 5.978639548178578, 6.983993484572395, 8.87026961710767, 9.860937200006427, 10.808547898911561, 11.803836136316596, 10.783079095788619, 9.815339807061646, 8.828679748494366, 7.837122302020427, 6.8742733454339024, 5.935416224801217, 4.90500881748307, 3.949330348236082, 2.94881618241332, 2.0619030648951404, 2.971809458151249, 3.913902973447602, 4.861227563346262, 5.793085243624786, 6.8183407636331514, 7.809597075376599, 9.798869673211827, 10.795000498584134, 11.761502286028508, 12.777754856123897, 11.814466929155516, 10.797382869761288, 9.833314003689875, 8.876891625600317, 7.851219293232474, 6.8865162964448885, 5.890870291302482, 4.851144098895457, 3.8914808214007124, 3.0560012577324294, 3.9874113607008352, 4.851069065075634, 5.855717590163155, 6.7953092954201155, 7.832278232792056, 8.770149287457297, 10.760981676072525, 11.703955627446412, 12.75060773480556, 13.683492535315057, 12.700101449159025, 11.703915192214005, 10.629330156086713, 9.693923947859867, 8.724122255946568, 7.788726743702634, 6.835409151434881, 5.85256008165143, 4.904817045930416, 4.013600280263894, 4.9761133558624895, 5.837000443259993, 6.910972668793233, 7.747003537083356, 8.701920454226478, 9.689839695982432, 11.726376117942198, 12.676537867325203, 13.657510729387976, 14.52091818946127, 13.579019709688035, 12.512791985564823, 11.567147359800952, 10.620193228958588, 9.703282005241284, 8.81156041836152, 7.784715609399496, 6.863921659737347, 5.932773661631083, 5.059999157236138, 5.928278382456534, 6.796704033982229, 7.852358373193664, 8.790840841176498, 9.731690391570744, 10.701487911374251, 12.6682622760175, 13.646033254141697, 14.59541806101261, 15.47789589911709, 14.544623638168677, 13.557069734441473, 12.587659608534358, 11.600382211069741, 10.745993056881456, 9.756393349249658, 8.760099132925678, 7.889422242942011, 6.887177019657411, 6.041675214628383, 6.9443617130692346, 7.769477873181403, 8.727776334056022, 9.712323746289837, 10.735904517693848, 11.633950122954506, 13.59441108716119, 14.581854196825347, 15.511468019545026, 15.552481877423672, 14.7331470608329, 13.881602983515718, 13.056430916672511, 12.670086652195032, 11.75380699172437, 10.809874996604531, 9.768152091926911, 8.915300128305601, 7.862105630325655, 7.04080181435826, 7.97326637293399, 8.712976413154793, 9.659089390166288, 10.629335973513044, 11.594322040129269, 12.620238614367043, 14.53609911765919, 15.497328867219803, 15.505853983471567, 14.579558494204889, 13.797951377395844, 12.920440341976509, 12.00685727989713, 12.83874100290491, 12.706506454672137, 11.793770243732048, 10.810350874471913, 9.802577779195277, 8.855176354217916, 8.082964292443206, 8.912064369331187, 9.650503202514653, 10.625228581674122, 11.617786086380915, 12.602022820582892, 13.544716411512738, 15.481948385206461, 15.574199341392394, 14.578651050160461, 13.616859407388176, 12.860511353387905, 11.884989362163891, 10.933480801102784, 11.829177580163833, 12.762172399520775, 12.728872763353547, 11.751454121324311, 10.752178726731307, 9.814178028961255, 9.113234499733222, 9.8639167571682, 10.631084303430335, 11.604914828755774, 12.547404244780946, 13.5337514056522, 14.582998563913918, 15.548797357662286, 14.664162845446743, 13.682100274815689, 12.691089428423329, 11.820065307288262, 10.854681932305922, 9.884227052261611, 10.866848421683304, 11.736869709122098, 12.681326462776559, 12.7069404032944, 11.777628230070903, 10.74486863420893, 10.108009865465165, 10.878963462189374, 11.56867971831937, 12.628271717527513, 13.61879945406149, 14.48650671966486, 15.420646783911176, 14.618042550143404, 13.73936784353685, 12.716943550555023, 11.733156621023852, 10.760185447892024, 9.905140397717275, 8.925446120993824, 9.90746006842874, 10.754556840936802, 11.792554491753638, 12.64649730232323, 12.740311041636236, 11.782782214065907, 11.139202868996259, 11.912113781987841, 12.560401595445994, 13.565265200760628, 14.63760315391756, 15.500816189840197, 15.557531089516923, 13.639578281047754, 12.692704995649619, 11.71666398882433, 10.800972522664836, 9.736408410246412, 8.890966210930342, 7.934665023060796, 8.951140270465789, 9.81074617772602, 10.798788987509168, 11.636847672806672, 12.57668639586767, 12.831370838918918, 12.087130903047447, 12.93585967624724, 13.609580115165796, 14.525457932069846, 15.490130569825833, 15.593161065882663, 14.593320698551166, 12.771937283836484, 11.698526876695926, 10.737350843966645, 9.800435663983196, 8.80247214519477, 7.953340887008035, 6.982122039141368, 7.937145770852482, 8.795035642597181, 9.778062766089908, 10.66476579489306, 11.640592528953716, 12.683010905104215, 13.145154922220213, 13.928599714299628, 14.545108978917686, 15.487699885657086, 15.675685219298776, 14.699093338355796, 13.736126651725204, 11.756452666510024, 10.909912483194852, 9.859939523633633, 8.867743951815998, 7.8348806717928845, 6.883850715748925, 5.9744954511395925, 7.00575187791953, 7.799552549386155, 8.847362350555892, 9.720182646016054, 10.677136905940905, 11.724561485596395, 12.60574668566796, 13.585737951709087, 14.644815833309707, 15.522449440843292, 14.64240736446727, 13.62991652381034, 12.775989900206792], [10.668687262502894, 11.617407593538871, 12.61074992908286, 13.570542082624431, 14.601098917455985, 13.69302594723495, 12.678744044313113, 11.803993376023625, 10.793797342476308, 9.787915775767724, 8.879793085808451, 7.8543067010684835, 6.93668169253126, 5.946688793889157, 4.990089263034579, 5.961125090291242, 6.9656283269318156, 7.864927199114883, 8.839756641420406, 9.68439181209446, 9.696287614505456, 10.641371708858715, 11.619828915651897, 12.678366776748529, 13.61352018147383, 12.79987672888325, 11.738850840235177, 10.803625108680485, 9.816878102048024, 8.795762072852474, 7.841656814843693, 6.91202380544243, 5.987036714571113, 5.039011050318039, 4.063123870221843, 5.0138509115741705, 5.893514728265847, 6.921180408289569, 7.90696050989774, 8.755697508301576, 8.775498984110026, 9.742322365024734, 10.778151648263208, 11.659373105291435, 12.65830966419104, 11.903993205513805, 10.854779491995789, 9.872210470745818, 8.902384155107248, 7.94955520854918, 6.953932765633501, 5.974524359513111, 4.96547679891408, 4.016892802841372, 3.0438929129746057, 3.96287528694596, 4.911569310656103, 5.950902137714553, 6.914917012430989, 7.817930957489886, 7.74250513748761, 8.780913290185588, 9.747051316927074, 10.696862481299148, 11.705359768126373, 10.88096241851869, 9.897342915408913, 8.898258115889139, 7.94208592459557, 6.995988857691588, 5.950114846809692, 4.962160655034669, 4.0150734656460525, 3.019475099721702, 2.09958675146222, 2.9478724682404995, 3.9579030943899713, 4.896032716379522, 5.893569045594854, 6.831076885330047, 6.797481837222106, 7.829166036516102, 8.797008610570428, 9.836691311449732, 10.80089817791301, 9.884908646257488, 8.895857000982467, 7.953121087359646, 7.065178255040953, 6.046975056940838, 5.0088873686086055, 4.032068900546875, 3.03910084616921, 2.092866761963163, 1.0294578767878773, 1.9862882327354139, 2.977689673218984, 4.0046755275094155, 4.918990079913532, 5.859581233193918, 5.966509123375004, 6.921715124871734, 7.913122138474986, 8.941047339973661, 9.969822551452172, 9.101447420356987, 8.061187593508029, 7.027872446574399, 6.054959586138845, 5.06930773251884, 4.134717743661045, 3.1082716658391156, 2.037741212128771, 1.0663300114146148, 0.0, 1.0471871939471418, 2.0219611367426467, 3.0478661568921197, 3.984431367389522, 5.035881012664086, 6.885254923322125, 7.860840419503914, 8.924404759400028, 9.930250768962352, 10.906523020816426, 10.044659774685307, 8.972244851626899, 7.956943530994941, 6.998787466620253, 5.985098590368769, 4.979313400183945, 4.013532396396415, 3.083051857965949, 2.060072846729407, 1.0581361945244, 2.036845853028458, 2.9547951662598924, 3.9824860205386816, 4.947946654972275, 5.953300591366092, 7.852461236620267, 8.843128819519023, 9.790739518424157, 10.802419035549642, 11.823176076077619, 10.88166981847626, 9.89500975990898, 8.903452313435041, 7.940603356848517, 7.001746236215832, 5.971338828897685, 5.015660359650697, 4.015146193827935, 3.0126611114533426, 2.028386037061207, 2.97047955235756, 3.9178041422562195, 4.849661822534744, 5.874917342543109, 6.866173654286557, 8.781061292724424, 9.77719211809673, 10.743693905541104, 11.759946475636493, 12.786687663666827, 11.863712881175902, 10.899644015104489, 9.943221637014933, 8.91754930464709, 7.952846307859504, 6.957200302717098, 5.9174741103100725, 4.957810832815327, 3.997596662600572, 3.043987939610793, 3.9076456439855916, 4.912294169073113, 5.8518858743300735, 6.888854811702014, 7.826725866367255, 9.787553337434534, 10.730527288808421, 11.77717939616757, 12.72914648313122, 13.712537569287253, 12.752496950297296, 11.677911914170004, 10.742505705943158, 9.772704014029859, 8.837308501785925, 7.883990909518172, 6.901141839734722, 5.888748529901598, 4.955195685132036, 4.032689934772447, 4.893577022169951, 5.967549247703191, 6.803580115993314, 7.758497033136436, 8.74641627489239, 10.75418476263097, 11.704346512013975, 12.685319374076748, 13.69310582054879, 14.627601467771326, 13.561373743648113, 12.615729117884243, 11.668774987041878, 10.751863763324575, 9.86014217644481, 8.833297367482785, 7.788172788651604, 6.85702479054534, 5.910055404769956, 4.984854961366492, 5.853280612892187, 6.908934952103622, 7.847417420086456, 8.788266970480702, 9.758064490284209, 11.70875785698243, 12.673841898830469, 13.623226705701382, 14.582909478996537, 14.8440338461818, 14.183095141366753, 13.636241366617648, 12.648963969153032, 11.794574814964747, 10.799717392725347, 9.803423176401367, 8.813673371856268, 7.811428148571668, 6.891731462162201, 6.0009382919791925, 6.826054452091361, 7.78435291296598, 8.768900325199795, 9.792481096603806, 10.690526701864464, 12.650987666071147, 13.609662841514119, 14.539276664233798, 14.602026953133112, 13.816689834312369, 13.122302749846314, 14.00484903695044, 13.718668410278323, 12.80238874980766, 11.85319904008022, 10.8114761354026, 9.839551257219858, 8.786356759239913, 7.890858061892078, 7.029842951843948, 7.76955299206475, 8.715665969076245, 9.685912552423, 10.650898619039225, 11.676815193277001, 13.592675696569145, 14.55390544612976, 14.555399059181008, 13.62910356991433, 12.881494150875312, 12.161140108307105, 12.95527540017506, 13.78715912318284, 13.6969341857222, 12.71980538614014, 11.736386016880004, 10.726828908109535, 9.779427483132174, 8.933020539977024, 7.968640948241145, 8.70707978142461, 9.681805160584078, 10.674362665290872, 11.658599399492848, 12.601292990422694, 14.538524964116416, 14.623744417101834, 13.628196125869902, 12.666404483097617, 11.944054126867373, 11.125689128494486, 11.881898921380714, 12.777595700441763, 13.807991912758835, 13.654907905761638, 12.67570525023857, 11.676429855645566, 10.738429157875514, 9.96329074726704, 8.920493336078158, 9.687660882340293, 10.661491407665729, 11.6039808236909, 12.590327984562155, 13.639575142823873, 14.598342433371728, 13.713707921156184, 12.73164535052513, 11.74063450413277, 10.90360808076773, 10.095381698636517, 10.832645172539541, 11.815266541961234, 12.782689222360158, 13.727145976014619, 13.631191532208659, 12.701879358985162, 11.669119763123188, 10.958066112998983, 9.935540041099332, 10.625256297229328, 11.684848296437467, 12.675376032971444, 13.543083298574814, 14.47722336282113, 13.667587625852846, 12.788912919246293, 11.766488626264463, 10.782701696733293, 9.843728221371492, 9.14584016404787, 9.873864241271754, 10.85587818870667, 11.810299389622944, 12.848297040439778, 13.712827313737847, 13.664562170550495, 12.707033342980166, 11.982242232660827, 10.9686903608978, 11.616978174355951, 12.621841779670586, 13.694179732827514, 14.557392768750152, 14.596166871491546, 12.689123356757197, 11.742250071359061, 10.766209064533772, 9.850517598374276, 8.81995118372588, 8.094151305862658, 8.883083143338725, 9.899558390743719, 10.877076189140636, 11.865118998923784, 12.70317768422129, 13.643016407282287, 13.755621967833177, 12.930170266712015, 11.992436255157198, 12.666156694075754, 13.582034510979804, 14.546707148735791, 14.631796847857286, 13.631956480525789, 11.71787564977026, 10.748071952405368, 9.786895919676088, 8.849980739692636, 7.886014918674238, 7.0368836604875025, 7.930540159419297, 8.885563891130412, 9.861365654011797, 10.844392777504524, 11.731095806307678, 12.706922540368334, 13.749340916518833, 13.98819428588478, 12.985176293209586, 13.601685557827643, 14.544276464567044, 14.609355207884162, 13.632763326941182, 12.68206501765898, 10.69012265509541, 9.8977288659569, 8.909484599343074, 7.917289027525439, 6.918423445272353, 5.967393489228392, 6.922913571417522, 7.954169998197459, 8.86588256080077, 9.913692361970508, 10.786512657430672, 11.743466917355523, 12.790891497011012, 13.672076697082575, 14.010407901397153, 14.63066435011473, 14.506680109335043, 13.576077353052655, 12.563586512395727, 11.709659888792178], [9.621500068555752, 10.57022039959173, 11.563562735135719, 12.52335488867729, 13.553911723508843, 14.558610038597694, 13.613126369939094, 12.738375701649606, 11.728179668102289, 10.722298101393704, 9.813093863454691, 8.78661827316854, 7.822675600528146, 6.832682701886043, 5.876083171031465, 5.051757866448429, 5.918441132984674, 6.817740005167741, 7.792569447473265, 8.637204618147319, 8.649100420558314, 9.594184514911573, 10.572641721704755, 11.631179582801387, 12.566332987526687, 13.54354620047749, 12.673233165861157, 11.738007434306466, 10.751260427674005, 9.730144398478455, 8.776039140469674, 7.84640613106841, 6.873030622567999, 5.925004958314925, 4.949117778218729, 3.9861841076759825, 4.846327534318705, 5.873993214342427, 6.859773315950598, 7.7085103143544345, 7.728311790162885, 8.695135171077592, 9.730964454316066, 10.612185911344294, 11.6111224702439, 12.609592088267911, 11.819363742937611, 10.836794721687639, 9.866968406049068, 8.914139459491, 7.888315091259481, 6.908906685139091, 5.851470706910965, 4.902886710838258, 3.9298868209714914, 2.9352084830477723, 3.8643821167089607, 4.903714943767411, 5.867729818483847, 6.770743763542744, 6.695317943540468, 7.7337260962384455, 8.699864122979934, 9.649675287352007, 10.658172574179233, 11.691367238478048, 10.861927166350734, 9.862842366830959, 8.906670175537391, 7.960573108633408, 6.914699097751512, 5.914208625167493, 4.950577576504101, 3.9054690077185876, 2.9855806594591057, 1.920205664342312, 2.9107159004428294, 3.84884552243238, 4.846381851647712, 5.783889691382905, 5.750294643274964, 6.78197884256896, 7.749821416623287, 8.78950411750259, 9.753710983965869, 10.687358912674421, 9.943044194929609, 9.000308281306788, 8.072313637349637, 7.040813665748569, 5.973471619550426, 4.996653151488696, 4.003685097111031, 2.978860669960049, 1.915451784784763, 0.9586214288372262, 1.9305024792718424, 2.957488333562274, 3.8718028859663898, 4.812394039246776, 4.919321929427862, 5.874527930924592, 6.865934944527844, 7.893860146026519, 8.92263535750503, 9.860242417220226, 9.10837478745517, 8.075059640521541, 7.102146780085987, 6.116494926465982, 5.181904937608187, 4.155458859786258, 3.084928406075913, 2.113517205361757, 1.0471871939471418, 0.0, 0.9747739427955049, 2.0006789629449777, 2.93724417344238, 3.9886938187169436, 5.838067729374983, 6.813653225556772, 7.877217565452886, 8.88306357501521, 9.859335826869284, 10.875325659519392, 9.913656908089536, 8.898355587457578, 7.940199523082891, 6.926510646831407, 5.920725456646583, 4.954944452859053, 4.024463914428587, 2.9786262483466732, 1.9708094680470227, 0.9920998095429648, 1.9076079723127506, 2.9352988265915396, 3.9007594610251326, 4.90611339741895, 6.805274042673125, 7.795941625571881, 8.743552324477015, 9.7552318416025, 10.775988882130477, 11.74372817085745, 10.836421816371617, 9.844864369897678, 8.882015413311155, 7.943158292678469, 6.912750885360322, 5.957072416113334, 4.9565582502905725, 3.925334384975965, 2.9410593105838294, 2.0080802803224667, 2.8715402901351696, 3.8033979704136938, 4.8286534904220595, 5.819909802165507, 7.7338740987772825, 8.73000492414959, 9.696506711593962, 10.712759281689351, 11.739500469719685, 12.725771233557092, 11.841056071567126, 10.88463369347757, 9.858961361109728, 8.894258364322141, 7.898612359179735, 6.8588861667727095, 5.899222889277965, 4.836594500259061, 3.8829857772692824, 2.9452463719504984, 3.874156339730477, 4.805622022209024, 5.842590959580965, 6.780462014246205, 8.740366143487394, 9.683340094861281, 10.72999220222043, 11.681959289184078, 12.665350375340111, 13.591494787955785, 12.516909751828493, 11.581503543601647, 10.611701851688348, 9.676306339444414, 8.722988747176661, 7.740139677393211, 6.727746367560087, 5.7941935227905255, 4.871687772430937, 3.9311777501348577, 4.930359044611098, 5.757316263872264, 6.712233181015386, 7.700152422771341, 9.70699756868383, 10.657159318066835, 11.638132180129608, 12.64591862660165, 13.587817106374885, 14.400371581306603, 13.454726955542732, 12.507772824700368, 11.590861600983065, 10.6991400141033, 9.672295205141275, 8.627170626310093, 7.6960226282038295, 6.749053242428445, 5.823852799024981, 4.890881340857093, 5.9465356800685285, 6.8279307173793224, 7.742003118359653, 8.71180063816316, 10.66157066303529, 11.626654704883329, 12.576039511754242, 13.535722285049397, 13.934666622338986, 14.922220526066189, 14.475239204276138, 13.487961806811521, 12.633572652623236, 11.638715230383836, 10.642421014059856, 9.652671209514757, 8.650425986230157, 7.73072929982069, 6.839936129637682, 5.863655180056266, 6.821953640930886, 7.8065010531647, 8.766957042179254, 9.644262849743415, 11.604723813950098, 12.562475647566979, 13.492089470286658, 13.55483975918597, 12.907322610469555, 13.893859445655467, 14.86751329934448, 14.557666247936812, 13.64138658746615, 12.69219687773871, 11.65047397306109, 10.678549094878347, 9.625354596898402, 8.729855899550568, 7.8310719579556745, 6.807153720029656, 7.75326669704115, 8.723513280387905, 9.68849934700413, 10.630551341155952, 12.560529451295357, 13.521759200855971, 13.508211865233866, 12.581916375967188, 11.972126927032498, 12.932696804116258, 13.841269308171945, 14.673153031179726, 14.535932023380688, 13.558803223798629, 12.575383854538494, 11.565826745768025, 10.618425320790664, 9.668691855194284, 8.684698185372184, 7.744680509389515, 8.719405888548984, 9.711963393255777, 10.696200127457754, 11.569146745148906, 13.50637871884263, 13.576557223154692, 12.58100893192276, 11.619217289150475, 11.034686903024559, 11.89724582430364, 12.7678928293776, 13.663589608438649, 14.69398582075572, 14.493905743420127, 13.51470308789706, 12.515427693304055, 11.577426995534003, 10.686532954450273, 9.636550573209197, 8.725261610305196, 9.699092135630636, 10.641581551655808, 11.627928712527062, 12.609814100541785, 13.551155239424586, 12.666520727209042, 11.684458156577987, 10.693447310185627, 9.994240856924916, 10.866938394445672, 11.718639080536427, 12.70126044995812, 13.668683130357044, 14.613139884011504, 14.470189369867148, 13.54087719664365, 12.508117600781677, 11.681308320182216, 10.651597278230371, 9.662857025194231, 10.722449024402374, 11.712976760936352, 12.580684026539721, 13.514824090786037, 12.620400431905704, 11.741725725299151, 10.719301432317321, 9.73551450278615, 8.934360997528678, 9.917396859857025, 10.75985814926864, 11.741872096703556, 12.69629329761983, 13.734290948436666, 14.647209639363828, 14.503560008208984, 13.546031180638655, 12.698299469791866, 11.684747598028839, 10.654578902320855, 11.65944250763549, 12.731780460792422, 13.594993496715059, 13.548979677544404, 11.641936162810055, 10.69506287741192, 9.71902187058663, 8.803330404427134, 7.910583959883067, 8.865708001671813, 9.76907705133561, 10.785552298740605, 11.773412724231456, 12.761455534014603, 13.63756000984727, 14.57739873290827, 14.586675860500247, 13.646227503843054, 12.698718220563821, 11.703757422040658, 12.619635238944708, 13.584307876700695, 13.584609653910144, 12.584769286578647, 10.670688455823118, 9.700884758458226, 8.739708725728946, 7.802793545745494, 6.976647694831425, 7.922877568484388, 8.816534067416182, 9.771557799127295, 10.757702189102616, 11.740729312595343, 12.665478131933659, 13.641304865994316, 14.683723242144815, 14.70425152301582, 13.676809433190535, 12.639286285792547, 13.581877192531948, 13.56216801393702, 12.58557613299404, 11.634877823711838, 9.642935461148268, 8.850541672009758, 7.862297405395933, 6.870101833578297, 6.00905622142954, 6.853387397225278, 7.808907479414407, 8.840163906194345, 9.798194132900827, 10.846993139616748, 11.720894983056652, 12.677849242981505, 13.725273822636995, 14.606459022708556, 14.702041041378102, 13.668265078079633, 13.459492915387901, 12.528890159105513, 11.516399318448585, 10.662472694845036], [8.64672612576025, 9.595446456796227, 10.588788792340216, 11.548580945881787, 12.57913778071334, 13.58383609580219, 14.569691350407997, 13.713149644445114, 12.702953610897797, 11.692425766179158, 10.704859929241907, 9.678384338955755, 8.714441666315361, 7.724448767673259, 6.767849236818681, 5.90008772144088, 4.943667190189169, 5.842966062372236, 6.81779550467776, 7.662430675351813, 7.67432647776281, 8.61941057211607, 9.597867778909253, 10.656405640005884, 11.591559044731184, 12.568772257681987, 13.62979814633006, 12.712781377101974, 11.726034370469513, 10.704918341273963, 9.750813083265182, 8.821180073863918, 7.847804565363505, 6.879405280700578, 5.840883844005945, 4.834513962668433, 3.8715535915232007, 4.899219271546922, 5.884999373155093, 6.73373637155893, 6.753537847367382, 7.72036122828209, 8.756190511520565, 9.63741196854879, 10.636348527448396, 11.634818145472407, 12.657649375379197, 11.811568664483145, 10.841742348844575, 9.888913402286507, 8.863089034054989, 7.883680627934598, 6.826244649706472, 5.8776606536337646, 4.904660763766997, 3.909982425843277, 2.889608173913456, 3.928941000971906, 4.892955875688342, 5.795969820747239, 5.720544000744965, 6.758952153442943, 7.72509018018443, 8.674901344556503, 9.683398631383728, 10.716593295682543, 11.70021279879232, 10.837616309626465, 9.881444118332897, 8.935347051428915, 7.889473040547019, 6.888982567962999, 5.925351519299607, 4.880242950514093, 3.9603546022546112, 2.8949796071378167, 1.9359419576473247, 2.874071579636875, 3.8716079088522077, 4.8091157485874, 4.77552070047946, 5.807204899773456, 6.775047473827783, 7.814730174707087, 8.778937041170366, 9.712584969878918, 10.701636615153939, 9.975082224102293, 9.047087580145142, 8.015587608544076, 6.948245562345932, 5.971427094284201, 4.978459039906537, 3.953634612755554, 2.890225727580268, 1.9333953716327312, 0.9557285364763374, 1.9827143907667688, 2.897028943170885, 3.8376200964512717, 3.944547986632357, 4.8997539881290875, 5.891161001732339, 6.919086203231014, 7.947861414709524, 8.88546847442472, 9.925728301273677, 9.049833583317046, 8.076920722881491, 7.091268869261486, 6.156678880403692, 5.130232802581762, 4.059702348871418, 3.0882911481572615, 2.0219611367426467, 0.9747739427955049, 0.0, 1.025905020149473, 1.9624702306468755, 3.013919875921439, 4.8632937865794785, 5.838879282761267, 6.9024436226573815, 7.908289632219705, 8.884561884073777, 9.900551716723886, 10.813836441429814, 9.798535120797856, 8.840379056423169, 7.826690180171685, 6.820904989986861, 5.855123986199331, 4.924643447768865, 3.8788057816869514, 2.870989001387301, 1.8922793428832434, 0.9328340295172457, 1.9605248837960347, 2.925985518229628, 3.931339454623445, 5.830500099877621, 6.821167682776377, 7.76877838168151, 8.780457898806993, 9.80121493933497, 10.768954228061943, 11.736601349711895, 10.745043903237956, 9.782194946651433, 8.843337826018747, 7.792733970654477, 6.837055501407489, 5.836541335584727, 4.770459526926813, 3.7861844525346773, 2.8440909372383243, 1.8967663473396648, 2.8286240276181887, 3.853879547626555, 4.845135859370003, 6.759100155981778, 7.755230981354084, 8.721732768798455, 9.737985338893845, 10.764726526924179, 11.750997290761585, 12.712980409333953, 11.721744342516203, 10.696072010148361, 9.731369013360775, 8.735723008218368, 7.695996815811343, 6.7363335383165985, 5.672605157174918, 4.71899643418514, 3.781257028866356, 2.899382396934972, 3.8308480794135185, 4.86781701678546, 5.8056880714507, 7.76559220069189, 8.708566152065776, 9.755218259424925, 10.70718534638857, 11.690576432544603, 12.686762689489623, 13.352920408744351, 12.417514200517505, 11.447712508604207, 10.512316996360273, 9.55899940409252, 8.57615033430907, 7.563757024475945, 6.630204179706383, 5.707698429346793, 4.767188407050716, 3.9555851018155934, 4.782542321076758, 5.737459238219881, 6.725378479975835, 8.732223625888325, 9.68238537527133, 10.663358237334103, 11.671144683806146, 12.61304316357938, 13.64270131783437, 14.29073761245859, 13.343783481616226, 12.426872257898923, 11.535150671019158, 10.508305862057133, 9.46318128322595, 8.532033285119686, 7.585063899344302, 6.659863455940838, 5.7268919977729515, 4.974730052522758, 5.853156774583816, 6.767229175564148, 7.737026695367655, 9.686796720239785, 10.651880762087824, 11.601265568958738, 12.560948342253893, 13.494220603202308, 14.481774506929511, 15.311249861191996, 14.32397246372738, 13.469583309539095, 12.474725887299693, 11.478431670975713, 10.488681866430614, 9.486436643146014, 8.566739956736546, 7.6759467865535385, 6.699665836972125, 5.97297552728341, 6.853964971266871, 7.792183099383747, 8.66948890694791, 10.629949871154594, 11.587701704771474, 12.517315527491153, 12.580065816390466, 13.53166959310364, 14.52640558737986, 15.500059441068874, 15.39367690485267, 14.477397244382008, 13.528207534654566, 12.486484629976946, 11.514559751794204, 10.46136525381426, 9.565866556466423, 8.667082614871532, 7.643164376945514, 7.024696252809983, 7.824289349558128, 8.789275416174352, 9.655777398360447, 11.585755508499853, 12.546985258060467, 12.533437922438361, 11.607142433171683, 12.596473909666583, 13.660883225028009, 14.696930014558701, 15.564919096966943, 15.371942680296545, 14.394813880714485, 13.41139451145435, 12.401837402683881, 11.45443597770652, 10.504702512110143, 9.520708842288043, 8.580691166305375, 7.990835444317818, 8.812739462425998, 9.796976196627975, 10.594372802353401, 12.531604776047125, 12.601783280359188, 11.606234989127255, 10.64444334635497, 11.70423574851238, 12.710161819818422, 13.659658895164815, 14.555355674225865, 15.585751886542937, 15.329916400335984, 14.350713744812916, 13.351438350219912, 12.41343765244986, 11.522543611366132, 10.472561230125056, 9.561272267221057, 8.970521691399469, 9.795389820733641, 10.766231810083562, 11.63504015774628, 12.576381296629082, 11.691746784413537, 10.709684213782483, 9.718673367390123, 10.769651035545257, 11.708996983541564, 12.610405146323643, 13.593026515745336, 14.56044919614426, 15.50490594979872, 15.306200026783005, 14.376887853559507, 13.344128257697534, 12.517318977098075, 11.48760793514623, 10.498867682110092, 9.993878580171208, 10.866785030014185, 11.71898712409622, 12.653127188342536, 11.6456264891102, 10.766951782503646, 9.744527489521817, 8.760740559990646, 9.76049896945209, 10.759455448952917, 11.651624215055856, 12.633638162490772, 13.588059363407046, 14.626057014223882, 15.55155846451907, 15.33957066512484, 14.382041837554512, 13.534310126707727, 12.520758254944697, 11.490589559236716, 10.956902470010217, 11.885588729870255, 12.733296594271557, 12.574205734748897, 10.66716222001455, 9.720288934616415, 8.744247927791125, 7.82855646163163, 8.758913814875518, 9.714037856664262, 10.660843117122827, 11.677318364527821, 12.665178790018672, 13.65322159980182, 14.541908835002513, 15.547526397693721, 15.422686517416107, 14.482238160758914, 13.534728877479681, 12.539768078956518, 11.917095201319436, 12.865605131294492, 12.609835711114638, 11.60999534378314, 9.695914513027612, 8.726110815662722, 7.76493478293344, 6.82801960294999, 7.824977549823876, 8.814643634271604, 9.708300133203398, 10.663323864914512, 11.649468254889833, 12.63249537838256, 13.569826957088901, 14.611432530779767, 15.653850906930266, 15.54026217993168, 14.512820090106395, 13.475296942708407, 12.879337154906676, 12.587394071141517, 11.610802190198537, 10.660103880916331, 8.668161518352761, 7.875767729214253, 6.887523462600428, 5.895327890782792, 6.8573860764219905, 7.745153463012494, 8.700673545201623, 9.731929971981561, 10.689960198688043, 11.738759205403964, 12.691022647842106, 13.647976907766957, 14.695401487422446, 15.524930022070539, 14.5399083480204, 13.477739488140163, 12.484718972592399, 11.55411621631001, 10.541625375653082, 9.687698752049531], [7.6406789944209645, 8.589399325456942, 9.58274166100093, 10.542533814542502, 11.563132962259738, 12.567831277348589, 13.553686531954394, 14.549387326774289, 13.728858631047267, 12.704139585703807, 11.716573748766557, 10.690098158480405, 9.72615548584001, 8.736162587197908, 7.779563056343331, 6.91180154096553, 5.955381009713819, 4.978420637917784, 5.867896370112866, 6.656383544012529, 6.668279346423526, 7.613363440776785, 8.591820647569968, 9.640400821552282, 10.575554226277582, 11.552767439228385, 12.613793327876458, 13.54901905943115, 12.751939390618983, 11.730823361423433, 10.776718103414652, 9.847085094013387, 8.87239557658998, 7.891119100225229, 6.852597663530595, 5.8462277821930835, 4.883267411047851, 4.034673847092471, 4.9351002385901985, 5.727689240219646, 5.727632827217908, 6.694456208132615, 7.73028549137109, 8.611506948399317, 9.610443507298923, 10.608913125322934, 11.631744355229724, 12.649784699942453, 11.867647368994046, 10.914818422435978, 9.888994054204458, 8.909585648084068, 7.852149669855943, 6.903565673783236, 5.930565783916469, 4.9358874459927495, 3.9013219934381063, 3.0643955765174553, 3.9430567411234474, 4.789922689407955, 4.694638980595491, 5.733047133293468, 6.699185160034957, 7.64899632440703, 8.657493611234255, 9.69068827553307, 10.674307778642847, 11.649122398382561, 10.907349138482369, 9.961252071578386, 8.91537806069649, 7.914887588112471, 6.951256539449079, 5.906147970663565, 4.986259622404083, 3.9208846272872897, 2.947655777171975, 2.0095261551824244, 2.8911088818980217, 3.803068617248116, 3.749615680329987, 4.781299879623983, 5.74914245367831, 6.788825154557614, 7.753032021020892, 8.686679949729445, 9.675731595004466, 10.618467508627287, 10.072992600294615, 9.041492628693547, 7.974150582495404, 6.997332114433673, 6.004364060056009, 4.979539632905026, 3.9161307477297402, 2.959300391782204, 1.9816335566258103, 1.048060934431971, 1.871123923021412, 2.8117150763017986, 2.918642966482884, 3.8738489679796144, 4.865255981582866, 5.893181183081541, 6.921956394560051, 7.859563454275247, 8.899823281124206, 9.933138428057836, 9.102825743030964, 8.117173889410958, 7.182583900553165, 6.156137822731235, 5.085607369020891, 4.1141961683067345, 3.0478661568921197, 2.0006789629449777, 1.025905020149473, 0.0, 0.9365652104974026, 1.988014855771966, 3.837388766430005, 4.812974262611794, 5.8765386025079085, 6.882384612070232, 7.858656863924304, 8.874646696574413, 9.90617008493899, 10.82444014094733, 9.866284076572642, 8.852595200321158, 7.846810010136334, 6.881029006348804, 5.950548467918338, 4.9047108018364245, 3.896894021536774, 2.9181843630327164, 1.9587390496667187, 0.9346198636465617, 1.9000804980801547, 2.905434434473972, 4.804595079728147, 5.795262662626903, 6.742873361532036, 7.75455287865752, 8.775309919185498, 9.74304920791247, 10.72970926647975, 11.721266712953689, 10.734471394737346, 9.767268925194806, 8.707666715957789, 7.7519882467108, 6.7514740808880385, 5.685392272230125, 4.701117197837989, 3.7590236825416357, 2.811699092642976, 1.8798414123644518, 2.8397996631259295, 3.8310559748693773, 5.733195135832304, 6.72932596120461, 7.695827748648982, 8.712080318744372, 9.738821506774705, 10.725092270612112, 11.734343521675259, 12.636677087819514, 11.611004755451672, 10.646301758664086, 9.65065575352168, 8.610929561114654, 7.6512662836199095, 6.587537902478229, 5.633929179488451, 4.696189774169667, 3.814315142238283, 2.8820654641597816, 3.881170826355029, 4.791608186950075, 6.739687180542416, 7.682661131916302, 8.729313239275452, 9.681280326239097, 10.66467141239513, 11.66085766934015, 12.667557069594015, 13.332446945820816, 12.362645253907518, 11.427249741663584, 10.47393214939583, 9.49108307961238, 8.478689769779256, 7.545136925009694, 6.622631174650104, 5.682121152354027, 4.848281846566223, 3.833759705823022, 4.788676622966144, 5.776595864722099, 7.706318605738852, 8.656480355121857, 9.63745321718463, 10.645239663656673, 11.587138143429907, 12.616796297684896, 13.562440923448767, 14.258716226919537, 13.341805003202234, 12.45008341632247, 11.423238607360444, 10.37811402852926, 9.446966030422997, 8.499996644647613, 7.5747962012441485, 6.6418247430762625, 5.842856627312915, 4.9043741593300805, 5.818446560310411, 6.788244080113918, 8.660891700090312, 9.625975741938351, 10.575360548809265, 11.53504332210442, 12.468315583052835, 13.455869486780038, 14.425279612687156, 15.23890520903069, 14.384516054842406, 13.389658632603004, 12.393364416279024, 11.403614611733925, 10.401369388449325, 9.481672702039857, 8.59087953185685, 7.614598582275436, 6.841102102073567, 5.905182356013135, 6.843400484130011, 7.720706291694173, 9.668092490249027, 10.561796684622001, 11.49141050734168, 12.466340636306366, 13.444034689117402, 14.438770683393622, 15.412424537082636, 16.30860965015598, 15.392329989685319, 14.443140279957877, 13.401417375280257, 12.429492497097515, 11.37629799911757, 10.480799301769734, 9.582015360174845, 8.558097122248826, 7.8457533176511465, 6.875506734304392, 7.840492800920617, 8.70699478310671, 10.636972893246115, 11.524819760116038, 12.15726174999016, 12.618856252696334, 13.608187729191235, 14.67259704455266, 15.708643834083352, 16.576632916491594, 16.286875425599856, 15.309746626017796, 14.326327256757661, 13.316770147987192, 12.369368723009831, 11.419635257413454, 10.435641587591354, 9.495623911608686, 8.81189250915898, 7.863956847172263, 8.848193581374241, 9.645590187099664, 11.582822160793388, 12.00934640971551, 11.230058816679055, 11.656157165879621, 12.715949568037031, 13.721875639343073, 14.671372714689467, 15.567069493750516, 16.597465706067588, 16.244849145639293, 15.265646490116227, 14.266371095523223, 13.32837039775317, 12.437476356669443, 11.387493975428367, 10.476205012524368, 9.789096621505077, 8.846607205479906, 9.817449194829829, 10.686257542492543, 11.642689667508415, 11.05117942436944, 10.165576075282724, 10.730387186914774, 11.781364855069908, 12.720710803066215, 13.622118965848294, 14.604740335269987, 15.572163015668911, 16.516619769323373, 16.221132772086317, 15.291820598862818, 14.259061003000845, 13.432251722401386, 12.40254068044954, 11.413800427413403, 10.812453510276816, 9.91800241476045, 10.770204508842486, 11.704344573088802, 10.711934859989533, 9.985728552265787, 9.122066089468053, 9.772454379515297, 10.772212788976741, 11.771169268477568, 12.663338034580507, 13.645351982015423, 14.599773182931697, 15.637770833748533, 16.56327228404372, 16.25450341042815, 15.296974582857823, 14.449242872011038, 13.435691000248008, 12.405522304540026, 11.775477400115825, 10.93680611461652, 11.784513979017824, 11.568158603409614, 9.733470590893884, 8.939065704378555, 8.05475234483104, 8.84027028115628, 9.770627634400167, 10.725751676188912, 11.672556936647478, 12.689032184052472, 13.676892609543323, 14.66493541932647, 15.553622654527164, 16.55924021721837, 16.337619262719418, 15.397170906062225, 14.449661622782992, 13.45470082425983, 12.735670131425044, 11.916822516040757, 11.603788579775355, 10.603948212443857, 8.689867381688329, 7.944887585424862, 7.075439199973356, 7.83973342247464, 8.836691369348525, 9.826357453796255, 10.72001395272805, 11.675037684439163, 12.661182074414484, 13.64420919790721, 14.581540776613553, 15.623146350304419, 16.532093434116177, 15.52715176477678, 14.473702841409573, 13.436179694011585, 12.445316576210415, 11.581346939802232, 10.604755058859253, 9.654056749577048, 7.662114387013478, 6.925868594649359, 6.043548096686157, 6.907041710307443, 7.869099895946641, 8.756867282537145, 9.712387364726274, 10.743643791506212, 11.701674018212692, 12.750473024928613, 13.702736467366755, 14.659690727291608, 15.50368509484264, 14.511894967287478, 13.52687329323734, 12.471692356800878, 11.478671841253114, 10.548069084970725, 9.535578244313797, 8.681651620710248], [6.704113783923562, 7.652834114959539, 8.646176450503528, 9.6059686040451, 10.626567751762334, 11.631266066851184, 12.61712132145699, 13.612822116276885, 14.57612009599449, 13.567874268334156, 12.580308431396906, 11.553832841110754, 10.58989016847036, 9.599897269828258, 8.643297738973681, 7.77553622359588, 6.81911569234417, 5.842155320548136, 4.931331159615463, 5.719818333515127, 5.731714135926124, 6.676798230279383, 7.655255437072564, 8.703835611054878, 9.638989015780178, 10.61620222873098, 11.677228117379054, 12.612453848933745, 13.599200855566206, 12.658592544603101, 11.70448728659432, 10.774854277193056, 9.73613025922033, 8.754853782855578, 7.716332346160946, 6.709962464823434, 5.747002093678201, 4.898408529722822, 3.9985350280927965, 4.791124029722243, 4.791067616720506, 5.757890997635212, 6.793720280873687, 7.674941737901913, 8.67387829680152, 9.672347914825531, 10.695179144732322, 11.71321948944505, 12.65005910245568, 11.851383632933382, 10.825559264701862, 9.846150858581472, 8.788714880353346, 7.840130884280638, 6.867130994413872, 5.822940461135917, 4.765056676068457, 3.928130259147806, 3.006491530626045, 3.853357478910553, 3.758073770098089, 4.796481922796065, 5.762619949537553, 6.712431113909626, 7.7209284007368515, 8.754123065035667, 9.737742568145444, 10.712557187885158, 11.668729379178727, 10.89781728207579, 9.851943271193894, 8.851452798609873, 7.8878217499464816, 6.842713181160968, 5.922824832901486, 4.857449837784692, 3.8113904598023254, 2.873260837812775, 1.9545436714006192, 2.8665034067507134, 2.8130504698325844, 3.8447346691265802, 4.812577243180907, 5.8522599440602106, 6.8164668105234885, 7.750114739232042, 8.739166384507064, 9.681902298129884, 10.664333784029163, 9.978057839190951, 8.910715792992807, 7.933897324931076, 6.940929270553411, 5.916104843402429, 4.852695958227143, 3.8958656022796063, 2.918198767123213, 1.9117956170623218, 0.9345587125240095, 1.875149865804396, 1.9820777559854819, 2.9372837574822124, 3.928690771085464, 4.95661597258414, 5.9853911840626495, 6.922998243777846, 7.963258070626804, 8.996573217560433, 9.969486077995988, 9.053739099908363, 8.119149111050568, 7.092703033228638, 6.022172579518293, 5.050761378804137, 3.984431367389522, 2.93724417344238, 1.9624702306468755, 0.9365652104974026, 0.0, 1.0514496452745634, 2.9014265840590134, 3.8770120802408026, 4.9405764201369164, 5.94581940157283, 6.922091653426903, 7.938081486077011, 8.969604874441588, 9.942667164276743, 10.802849287070044, 9.78916041081856, 8.783375220633737, 7.8175942168462065, 6.887113678415741, 5.841276012333828, 4.833459232034177, 3.854749573530119, 2.8953042601641212, 1.8711850741439644, 0.964118315709163, 1.9694722521029804, 3.8686328973571555, 4.859300480255912, 5.806911179161045, 6.818590696286529, 7.839347736814506, 8.80708702554148, 9.793747084108759, 10.785304530582698, 11.671036605234749, 10.703834135692208, 9.644231926455191, 8.688553457208203, 7.688039291385441, 6.621957482727527, 5.637682408335391, 4.695588893039038, 3.748264303140379, 2.8164066228618547, 1.9038374807549379, 2.895093792498386, 4.797232953461313, 5.793363778833619, 6.759865566277991, 7.7761181363733805, 8.802859324403714, 9.789130088241121, 10.798381339304267, 11.789617406122018, 12.547569965949075, 11.582866969161488, 10.587220964019082, 9.547494771612056, 8.587831494117312, 7.524103112975632, 6.5704943899858534, 5.63275498466707, 4.750880352735686, 3.8186306746571845, 2.9452086439840377, 3.855646004579084, 5.8037249981714245, 6.746698949545311, 7.79335105690446, 8.745318143868108, 9.72870923002414, 10.72489548696916, 11.731594887223023, 12.66700109544987, 13.299210464404918, 12.363814952160984, 11.410497359893231, 10.427648290109781, 9.415254980276657, 8.481702135507096, 7.559196385147507, 6.618686362851429, 5.784847057063626, 4.770324916320424, 3.893131067348666, 4.881050309104621, 6.770356423367861, 7.720518172750865, 8.701491034813637, 9.70927748128568, 10.651175961058915, 11.680834115313907, 12.626478741077777, 13.59327037654859, 14.278370213699635, 13.38664862681987, 12.359803817857845, 11.314679239026665, 10.383531240920401, 9.436561855145017, 8.511361411741552, 7.578389953573665, 6.779421837810317, 5.840939369827483, 4.922901004692933, 5.89269852449644, 7.724929517719321, 8.690013559567358, 9.639398366438272, 10.599081139733427, 11.532353400681842, 12.519907304409045, 13.489317430316163, 14.546730322434446, 15.321081265339807, 14.326223843100408, 13.329929626776428, 12.34017982223133, 11.33793459894673, 10.418237912537261, 9.527444742354252, 8.551163792772838, 7.777667312570969, 6.841747566510538, 5.947854928512532, 6.825160736076695, 8.732130307878037, 9.625834502251008, 10.555448324970687, 11.530378453935374, 12.508072506746409, 13.50280850102263, 14.476462354711643, 15.517910638220695, 16.32889520018272, 15.379705490455281, 14.33798258577766, 13.36605770759492, 12.312863209614974, 11.417364512267138, 10.518580570672247, 9.494662332746229, 8.782318528148549, 7.812071944801795, 7.016592322869096, 7.811449227489232, 9.741427337628638, 10.588857577745046, 11.494905268242306, 12.436644729681943, 13.425976206176843, 14.463971142561839, 15.50001793209253, 16.49300064046175, 17.223440636097262, 16.2463118365152, 15.262892467255064, 14.253335358484597, 13.305933933507236, 12.356200467910856, 11.372206798088756, 10.432189122106088, 9.748457719656383, 8.800522057669665, 8.02429310332272, 8.750044631482186, 10.68727660517591, 11.072781199218108, 12.06832949045004, 12.519891848509971, 13.57968425066738, 14.585610321973423, 15.535107397319814, 16.430804176380864, 17.46120038869794, 17.1814143561367, 16.20221170061363, 15.202936306020627, 14.264935608250575, 13.374041567166845, 12.324059185925769, 11.41277022302177, 10.72566183200248, 9.783172415977308, 8.993548716778307, 9.790711986875065, 10.706124457011013, 10.114614213872038, 11.029310757913075, 11.594121869545123, 12.645099537700258, 13.584445485696564, 14.485853648478642, 15.468475017900335, 16.43589769829926, 17.38035445195372, 17.15769798258372, 16.228385809360223, 15.19562621349825, 14.368816932898788, 13.339105890946943, 12.350365637910805, 11.749018720774218, 10.854567625257852, 9.946304030790966, 10.8399770174368, 9.77536964949213, 9.049163341768384, 9.985800772098404, 10.636189062145647, 11.635947471607091, 12.634903951107917, 13.527072717210855, 14.509086664645771, 15.463507865562045, 16.50150551637888, 17.42700696667407, 17.191068620925556, 16.233539793355227, 15.38580808250844, 14.37225621074541, 13.342087515037429, 12.712042610613228, 11.873371325113922, 10.960613500966303, 10.631593392912212, 8.796905380396481, 8.002500493881152, 8.918487027461392, 9.70400496378663, 10.634362317030519, 11.589486358819263, 12.536291619277826, 13.55276686668282, 14.540627292173673, 15.52867010195682, 16.417357337157515, 17.305494707075393, 16.3769254896128, 15.436477132955606, 14.430104145789235, 13.435143347266072, 12.470993319300252, 11.622954555189436, 10.667223369277952, 9.667383001946455, 7.753302171190926, 7.0083223749274595, 7.939173882603708, 8.70346810510499, 9.700426051978877, 10.690092136426605, 11.583748635358399, 12.538772367069512, 13.524916757044833, 14.50794388053756, 15.445275459243902, 16.486881032934768, 15.595528223618777, 14.590586554279378, 13.53713763091217, 12.499614483514183, 11.508751365713012, 10.64478172930483, 9.66818984836185, 8.717491539079646, 6.7255491765160755, 5.989303384151956, 6.907282779316509, 7.770776392937793, 8.732834578576991, 9.620601965167495, 10.576122047356623, 11.60737847413656, 12.565408700843042, 13.614207707558963, 14.566471149997104, 15.523425409921956, 14.567119884345237, 13.575329756790076, 12.590308082739936, 11.535127146303475, 10.542106630755711, 9.611503874473323, 8.599013033816394, 7.745086410212845], [5.8037573176203825, 6.75247764865636, 7.745819984200349, 8.684842633176064, 9.667176694895577, 10.671875009984428, 11.657730264590233, 12.653431059410128, 13.616729039127733, 14.534331017533695, 13.5611342716545, 12.534658681368349, 11.570716008727954, 10.580723110085852, 9.624123579231275, 8.756362063853475, 7.78025201898934, 6.768060059840499, 5.7704900834977515, 4.819461867211947, 4.831357669622944, 5.776441763976203, 6.754898970769385, 7.744444554188121, 8.679597958913421, 9.656811171864224, 10.717837060512297, 11.653062792066988, 12.63980979869945, 13.542177314618446, 12.685313126851915, 11.75568011745065, 10.716956099477924, 9.735679623113173, 8.69715818641854, 7.690788305081028, 6.727827933935796, 5.824313269015185, 4.837693951975084, 3.890767563419064, 3.8556877981993303, 4.822511179114038, 5.852354055135115, 6.715550681035156, 7.714487239934762, 8.712956857958773, 9.735788087865561, 10.75382843257829, 11.690668045588922, 12.609001740073543, 11.818466552254222, 10.839058146133832, 9.781622167905706, 8.833038171832998, 7.860038281966231, 6.8037663013935115, 5.745882516326051, 4.9089560994054, 3.955602639408152, 2.953001012607374, 2.8226939515769134, 3.8611021042748903, 4.803228892670796, 5.753040057042869, 6.761537343870094, 7.79473200816891, 8.778351511278686, 9.7531661310184, 10.709338322311968, 11.65543538921595, 10.903392916468457, 9.902902443884436, 8.939271395221045, 7.894162826435531, 6.935880975330412, 5.861707768989714, 4.79221630005992, 3.8540866780703693, 2.9036547801827264, 1.9661469404475342, 1.877670651311409, 2.8853436122598226, 3.853186186314149, 4.892868887193453, 5.857075753656731, 6.790723682365284, 7.779775327640305, 8.722511241263126, 9.704942727162404, 10.736442698763472, 9.96216543826737, 8.98534697020564, 7.992378915827975, 6.967554488676992, 5.904145603501706, 4.94731524755417, 3.9196073116103474, 2.892621457319916, 1.9153845527816034, 0.9747933995012169, 0.9306281107109184, 1.885834112207649, 2.8772411258109005, 3.9051663273095762, 4.933941538788086, 5.871548598503282, 6.911808425352241, 7.945123572285871, 8.918036432721426, 9.903688286341431, 9.17059875632513, 8.1441526785032, 7.073622224792857, 6.1022110240787, 5.035881012664086, 3.9886938187169436, 3.013919875921439, 1.988014855771966, 1.0514496452745634, 0.0, 1.920996619874408, 2.896582116056197, 3.909503720662989, 4.894369756298267, 5.870642008152339, 6.886631840802448, 7.918155229167025, 8.891217519002181, 9.849373583376869, 10.839468313302875, 9.8348248659083, 8.86904386212077, 7.938563323690305, 6.892725657608391, 5.884908877308741, 4.906199218804683, 3.9467539054386847, 2.922634719418528, 1.9943962243121922, 0.9890422879183749, 2.8882029331725496, 3.8788705160713057, 4.826481214976439, 5.838160732101923, 6.8589177726299, 7.826657061356873, 8.813317119924154, 9.804874566398093, 10.791189473605133, 11.755283780966773, 10.695681571729756, 9.740003102482767, 8.739488936660004, 7.67340712800209, 6.6891320536099546, 5.747038538313602, 4.799713948414942, 3.867856268136418, 2.934115389357967, 1.997387592650304, 3.816802989276707, 4.812933814649013, 5.779435602093385, 6.7956881721887745, 7.822429360219109, 8.808700124056516, 9.817951375119662, 10.809187441937413, 11.834859774305254, 12.634316614436052, 11.638670609293646, 10.59894441688662, 9.639281139391876, 8.575552758250197, 7.621944035260418, 6.684204629941633, 5.802329998010249, 4.870080319931748, 3.975486552587067, 2.9579398047310015, 4.823295033986819, 5.766268985360705, 6.812921092719854, 7.764888179683501, 8.748279265839534, 9.744465522784553, 10.751164923038418, 11.686571131265264, 12.656372823178563, 13.41526459743555, 12.461947005167797, 11.479097935384347, 10.466704625551223, 9.533151780781662, 8.610646030422071, 7.670136008125993, 6.83629670233819, 5.821774561594989, 4.923408975951695, 4.023403969320995, 5.789926459183255, 6.7400882085662595, 7.721061070629031, 8.728847517101075, 9.67074599687431, 10.7004041511293, 11.64604877689317, 12.612840412363985, 13.635532572473279, 14.438098272094436, 13.411253463132411, 12.36612888430123, 11.434980886194966, 10.488011500419582, 9.562811057016116, 8.629839598848228, 7.830871483084882, 6.892389015102047, 5.953178913295962, 5.035052184712814, 6.744499553534715, 7.709583595382753, 8.658968402253665, 9.61865117554882, 10.551923436497233, 11.539477340224437, 12.508887466131554, 13.566300358249837, 14.630307396652299, 15.377673488374972, 14.381379272050992, 13.391629467505894, 12.389384244221294, 11.469687557811826, 10.578894387628816, 9.602613438047403, 8.829116957845534, 7.893197211785102, 6.978132837115561, 5.967514396293069, 7.751700343693431, 8.645404538066403, 9.575018360786082, 10.549948489750765, 11.5276425425618, 12.522378536838021, 13.496032390527034, 14.537480674036086, 15.574633732288971, 16.431155135729846, 15.389432231052226, 14.417507352869483, 13.364312854889539, 12.468814157541702, 11.570030215946812, 10.546111978020793, 9.833768173423115, 8.86352159007636, 7.9961909644574325, 6.953802887705606, 8.762521456038694, 9.60842761356044, 10.5144753040577, 11.456214765497338, 12.445546241992238, 13.48354117837723, 14.519587967907922, 15.512570676277143, 16.52733319523674, 17.297761481789767, 16.31434211252963, 15.30478500375916, 14.3573835787818, 13.40765011318542, 12.42365644336332, 11.483638767380652, 10.799907364930949, 9.851971702944232, 8.835091882628406, 7.89239829169856, 9.708370723585965, 10.645103829529667, 11.441678237368807, 12.403469880141092, 13.382986266000177, 14.38891233730622, 15.441775941475884, 16.486130553423585, 17.460318799577948, 18.232864001411265, 17.253661345888194, 16.25438595129519, 15.316385253525139, 14.42549121244141, 13.375508831200333, 12.464219868296334, 11.73318407298042, 10.790694656955248, 9.804347496083993, 8.93306564709144, 9.805767990707833, 10.873470282396442, 11.855532853027496, 12.555258196190294, 13.606235864345429, 14.545581812341736, 15.466679488736236, 16.44930085815793, 17.416723538556855, 18.361180292211316, 18.209147627858282, 17.27983545463479, 16.247075858772813, 15.420266578173353, 14.390555536221507, 13.40181528318537, 12.756540961752158, 11.81845331676341, 10.75710281009665, 9.982330677653174, 8.875013183188951, 9.888322265650672, 10.855284221033726, 11.597325388790818, 12.597083798252262, 13.596040277753088, 14.50789855746845, 15.489912504903366, 16.444333705819638, 17.48233135663647, 18.407832806931665, 17.454026247006624, 16.496497419436295, 15.463279196137758, 14.532724069179597, 13.51492368505507, 12.510060079740436, 11.618827982398848, 10.656722703589486, 9.731236926609032, 7.896548914093302, 8.841659417763442, 9.787970476396714, 10.665141290431801, 11.615188157288113, 12.570312199076858, 13.51711745953542, 14.533592706940414, 15.521453132431267, 16.509495942214414, 17.39818317741511, 16.38436873620636, 15.455799518743763, 14.51535116208657, 13.5089781749202, 12.514017376397037, 11.549867348431217, 10.722598088886256, 9.766866902974773, 8.767026535643275, 6.8529457048877465, 7.847481298809748, 8.80865733153903, 9.664604431750162, 10.681251892236471, 11.6709179766842, 12.564574475615993, 13.519598207327107, 14.505742597302428, 15.488769720795155, 16.426101299501497, 15.566590739512417, 14.63613716675202, 13.631195497412621, 12.616011660043135, 11.578488512645148, 10.587625394843977, 9.74442526300165, 8.76783338205867, 7.817135072776466, 5.825192710212896, 6.828462308034244, 7.833187518608872, 8.731912719582963, 9.713660418834586, 10.60142780542509, 11.556947887614218, 12.588204314394154, 13.546234541100636, 14.595033547816557, 15.532927899196643, 14.603135116499606, 13.60772882747848, 12.61593869992332, 11.63091702587318, 10.61400117543444, 9.620980659886676, 8.711147408170143, 7.698656567513215, 6.844729943909665], [5.908382686871908, 6.857103017907885, 7.8504453534518746, 8.747416610588509, 9.729750672308022, 10.734448987396872, 11.720304242002678, 12.716005036822573, 13.679303016540178, 14.59690499494614, 15.464486104905324, 14.438010514619172, 13.474067841978778, 12.484074943336676, 11.527475412482099, 10.659713897104298, 9.683603852240164, 8.671411893091324, 7.673841916748576, 6.722813700462773, 4.93598303887447, 5.881067133227729, 6.8595243400209105, 7.807018531600566, 8.742171936325866, 9.719385149276668, 10.780411037924742, 11.715636769479433, 12.702383776111894, 13.60475129203089, 14.558856550039671, 13.659031950701474, 12.620307932728748, 11.639031456363996, 10.600510019669363, 9.594140138331852, 8.63117976718662, 7.72766510226601, 6.741045785225909, 5.794119396669889, 3.918261775611775, 4.885085156526483, 5.91492803254756, 6.7781246584476005, 7.777061217347207, 8.775530835371217, 9.798362065278006, 10.816402409990735, 11.753242023001366, 12.671575717485988, 13.712320858261103, 12.742409979384655, 11.68497400115653, 10.736390005083821, 9.763390115217055, 8.707118134644336, 7.649234349576876, 6.812307932656225, 5.858954472658977, 4.856352845858199, 2.885267928989358, 3.923676081687335, 4.8658028700832405, 5.815614034455313, 6.824111321282539, 7.8573059855813545, 8.84092548869113, 9.815740108430845, 10.771912299724413, 11.718009366628396, 12.752766827126495, 11.752276354542476, 10.788645305879085, 9.74353673709357, 8.823648388834089, 7.758273393717295, 6.695568133310744, 5.757438511321194, 4.807006613433551, 3.8694987736983593, 1.9402446287238537, 2.9479175896722674, 3.9157601637265937, 4.955442864605898, 5.919649731069176, 6.853297659777729, 7.84234930505275, 8.78508521867557, 9.767516704574849, 10.799016676175917, 11.811539348925407, 10.834720880863678, 9.841752826486013, 8.816928399335032, 7.753519514159746, 6.796689158212209, 5.819022323055816, 4.795973290570741, 3.8187363860324286, 2.878145232752042, 0.9932020881233633, 1.9484080896200937, 2.9398151032233453, 3.967740304722021, 4.996515516200531, 5.934122575915727, 6.974382402764686, 8.007697549698316, 8.98061041013387, 9.966262263753876, 10.812971546735247, 9.949079200184341, 8.887359017242586, 7.91594781652843, 6.885254923322125, 5.838067729374983, 4.8632937865794785, 3.8373887664300055, 2.9014265840590134, 1.920996619874408, 0.0, 0.9755854961817891, 2.039149836077903, 3.10284604414536, 4.079118295999432, 5.0951081286495405, 6.167523051707949, 7.182824372339907, 8.140980436714594, 9.154669312966078, 9.864304189513547, 8.898523185726017, 7.968042647295551, 6.922204981213638, 5.914388200913987, 4.93567854240993, 3.9762332290439315, 2.9027689027834436, 1.9373082683498506, 0.9319543319560332, 0.9672063132981419, 1.9578738961968982, 2.905484595102031, 3.917164112227516, 4.937921152755493, 5.905660441482466, 6.892320500049745, 7.8838779465236835, 8.925790133837745, 9.892992603380286, 10.675815755094671, 9.720137285847683, 8.71962312002492, 7.653541311367006, 6.66926623697487, 5.727172721678517, 4.779848131779858, 3.847990451501334, 2.877027433395625, 1.9402996366879623, 1.8958063694022989, 2.8919371947746053, 3.8584389822189773, 4.874691552314366, 5.901432740344701, 6.887703504182108, 7.896954755245253, 8.888190822063004, 9.913863154430846, 10.85605465372964, 11.618804792658562, 10.579078600251536, 9.619415322756792, 8.555686941615113, 7.6020782186253335, 6.664338813306549, 5.782464181375165, 4.850214503296664, 3.9183985966247246, 2.90085184876866, 2.9022984141124106, 3.8452723654862973, 4.891924472845446, 5.843891559809093, 6.827282645965126, 7.823468902910147, 8.830168303164008, 9.765574511390854, 10.735376203304153, 11.670771715548087, 12.442081188532713, 11.459232118749263, 10.446838808916139, 9.513285964146577, 8.590780213786987, 7.650270191490908, 6.816430885703106, 5.8019087449599045, 4.866321019989353, 3.9663160133586537, 3.868929839308847, 4.819091588691851, 5.800064450754623, 6.8078508972266665, 7.749749376999901, 8.779407531254893, 9.725052157018764, 10.691843792489575, 11.714535952598869, 12.69136437604551, 13.391387646497327, 12.346263067666145, 11.415115069559882, 10.468145683784497, 9.542945240381032, 8.609973782213144, 7.811005666449797, 6.872523198466963, 5.894267431487695, 4.8938180458767935, 4.823502933660307, 5.788586975508345, 6.737971782379256, 7.6976545556744105, 8.630926816622825, 9.618480720350028, 10.587890846257146, 11.645303738375429, 12.70931077677789, 13.68228487676108, 14.361513455415908, 13.37176365087081, 12.36951842758621, 11.449821741176741, 10.559028570993732, 9.582747621412318, 8.80925114121045, 7.873331395150018, 6.876259141465442, 5.826280257457048, 5.830703723819022, 6.724407918191994, 7.654021740911673, 8.628951869876357, 9.606645922687392, 10.601381916963613, 11.575035770652626, 12.616484054161678, 13.653637112414563, 14.62499500682063, 15.36956641441714, 14.3976415362344, 13.344447038254454, 12.448948340906618, 11.550164399311727, 10.526246161385709, 9.782496923327974, 8.812250339981219, 7.847264273364995, 6.804876196613169, 6.841524836164286, 7.687430993686032, 8.593478684183292, 9.53521814562293, 10.52454962211783, 11.562544558502822, 12.598591348033514, 13.591574056402735, 14.60633657536233, 15.58346537494439, 16.294476295894544, 15.284919187124077, 14.337517762146716, 13.387784296550336, 12.403790626728236, 11.463772950745568, 10.748636114835808, 9.727158953934758, 8.686165191535968, 7.743471600606123, 7.787374103711557, 8.724107209655259, 9.520681617494398, 10.482473260266683, 11.461989646125769, 12.467915717431811, 13.520779321601475, 14.565133933549177, 15.539322179703538, 16.502851625511447, 17.23379552925311, 16.23452013466011, 15.296519436890055, 14.405625395806325, 13.35564301456525, 12.44435405166125, 11.584257381887982, 10.64176796586281, 9.655420804991556, 8.784138955999001, 8.812722590969365, 9.682274195001328, 10.58516435889073, 11.408243239231531, 12.459220907386666, 13.433326488917066, 14.48190005920423, 15.464521428625924, 16.431944109024847, 17.376400862679308, 18.1892818112232, 17.259969637999703, 16.227210042137727, 15.400400761538268, 14.370689719586423, 13.381949466550285, 12.60761427065972, 11.669526625670972, 10.608176119004213, 9.778420396013148, 9.743477398488247, 10.747725067104982, 11.6286743447054, 12.366176046631008, 13.365934456092452, 14.364890935593278, 15.34458521231673, 16.326599159751648, 17.28102036066792, 18.319018011484754, 18.477356156316212, 17.51660022441907, 16.55907139684874, 15.525853173550203, 14.595298046592042, 13.577497662467515, 12.57263405715288, 11.807239859562019, 10.846078989995204, 9.920593213014751, 9.799900747344127, 10.745011251014265, 11.691322309647537, 12.568493123682627, 13.518539990538937, 14.473664032327681, 15.420469292786244, 16.436944540191238, 17.42480496568209, 18.39886489460154, 17.467706526799656, 16.446942713618803, 15.518373496156208, 14.577925139499015, 13.571552152332645, 12.576591353809482, 11.612441325843662, 10.827223458137782, 9.939342308757988, 8.956382822048994, 8.756297538138572, 9.750833132060572, 10.712009164789853, 11.567956265000987, 12.584603725487295, 13.574269809935023, 14.467926308866817, 15.42295004057793, 16.40909443055325, 17.392121554045975, 16.540085025486096, 15.629164716924862, 14.698711144164465, 13.693769474825066, 12.67858563745558, 11.641062490057593, 10.650199372256422, 9.849050632253176, 8.872458751310196, 8.006491359182185, 7.728544543463721, 8.731814141285069, 9.736539351859697, 10.635264552833789, 11.61701225208541, 12.504779638675913, 13.460299720865041, 14.491556147644978, 15.44958637435146, 16.49838538106738, 15.595501876609088, 14.665709093912051, 13.670302804890925, 12.678512677335764, 11.693491003285624, 10.676575152846885, 9.683554637299121, 8.81577277742167, 7.803281936764741, 6.983134611332394], [6.883968183053698, 5.989525752491549, 6.982868088035538, 7.812749059840586, 8.795083121560099, 9.79978143664895, 10.785636691254755, 11.78133748607465, 12.744635465792255, 13.662237444198217, 14.649803281135467, 15.413596010800962, 14.449653338160568, 13.459660439518466, 12.503060908663889, 11.635299393286088, 10.659189348421954, 9.646997389273112, 8.649427412930365, 7.698399196644561, 5.91156853505626, 5.013489867811392, 5.991947074604574, 6.872350980852643, 7.807504385577943, 8.784717598528745, 9.845743487176819, 10.78096921873151, 11.767716225363971, 12.670083741282967, 13.624188999291748, 14.553822008693013, 13.595893428910538, 12.614616952545786, 11.576095515851152, 10.569725634513642, 9.606765263368409, 8.703250598447799, 7.716631281407698, 6.769704892851678, 4.893847271793565, 4.012834046022579, 4.980260481799637, 5.8434571076996775, 6.842393666599284, 7.840863284623294, 8.863694514530085, 9.881734859242814, 10.818574472253443, 11.736908166738065, 12.77765330751318, 13.717995475566445, 12.660559497338319, 11.711975501265611, 10.738975611398844, 9.682703630826126, 8.624819845758665, 7.7878934288380135, 6.834539968840766, 5.8319383420399875, 3.8608534251711473, 3.0514249711834323, 3.9311353193353176, 4.88094648370739, 5.889443770534616, 6.9226384348334316, 7.9062579379432085, 8.881072557682922, 9.83724474897649, 10.783341815880473, 11.829215826762368, 12.727861850724263, 11.764230802060872, 10.719122233275359, 9.799233885015877, 8.733858889899084, 7.671153629492533, 6.733024007502983, 5.782592109615341, 4.845084269880148, 2.915830124905643, 2.0132500389243444, 2.981092612978671, 4.020775313857975, 4.984982180321253, 5.918630109029806, 6.907681754304827, 7.850417667927647, 8.832849153826926, 9.864349125427992, 10.931691171626136, 11.810306377045466, 10.817338322667801, 9.79251389551682, 8.729105010341534, 7.772274654393998, 6.794607819237605, 5.7715587867525295, 4.794321882214217, 3.853730728933831, 1.9687875843051525, 1.0137405388721707, 2.0051475524754223, 3.033072753974098, 4.061847965452608, 4.999455025167804, 6.039714852016763, 7.073029998950393, 8.045942859385947, 9.031594713005953, 9.966184701863748, 10.924664696366131, 9.862944513424376, 8.89153331271022, 7.860840419503914, 6.813653225556772, 5.838879282761267, 4.812974262611794, 3.877012080240802, 2.896582116056197, 0.9755854961817891, 0.0, 1.063564339896114, 2.1272605479635707, 3.103532799817643, 4.119522632467751, 5.1919375555261595, 6.207238876158117, 7.1653949405328055, 8.179083816784289, 9.184869006969112, 9.874108681907806, 8.94362814347734, 7.897790477395427, 6.889973697095776, 5.911264038591718, 4.951818725225721, 3.8783543989652323, 2.9128937645316393, 1.9075398281378222, 1.942791809479931, 1.0110619206383167, 1.9586726195434498, 2.970352136668934, 3.991109177196911, 4.958848465923884, 5.945508524491164, 6.937065970965102, 7.978978158279165, 8.946180627821706, 10.005782837058723, 10.695722782029472, 9.69520861620671, 8.629126807548795, 7.644851733156659, 6.702758217860306, 5.755433627961646, 4.823575947683122, 3.852612929577414, 2.915885132869751, 2.871391865584088, 2.083995889559902, 2.911627006660396, 3.9278795767557853, 4.95462076478612, 5.940891528623526, 6.950142779686671, 7.941378846504422, 8.967051178872264, 9.90924267817106, 10.904888683313466, 11.554664096433324, 10.59500081893858, 9.5312724377969, 8.577663714807121, 7.639924309488338, 6.758049677556953, 5.825799999478452, 4.893984092806513, 3.876437344950449, 3.8778839102941998, 3.0581861300659137, 3.9467462418387393, 4.897079584250512, 5.880470670406545, 6.876656927351565, 7.883356327605427, 8.818762535832274, 9.788564227745573, 10.723959739989507, 11.67727733225726, 12.43481761493105, 11.422424305097927, 10.488871460328365, 9.566365709968775, 8.625855687672697, 7.792016381884894, 6.777494241141692, 5.841906516171141, 4.941901509540442, 4.8445153354906365, 4.127094513088652, 5.004429214087768, 5.895282348601106, 6.824431665899943, 7.8325955556963125, 8.778240181460182, 9.745031816930995, 10.767723977040289, 11.74455240048693, 12.626583790221874, 13.321848563847933, 12.39070056574167, 11.443731179966285, 10.51853073656282, 9.585559278394932, 8.786591162631584, 7.848108694648751, 6.869852927669484, 5.869403542058583, 5.799088429842096, 5.096589899905146, 5.9423365457124016, 6.902019319007556, 7.83529157995597, 8.822845483683173, 9.792255609590288, 10.725220799042148, 11.78922783744461, 12.7354729012025, 13.601967313748057, 14.347349147052597, 13.345103923767997, 12.42540723735853, 11.53461406717552, 10.558333117594106, 9.784836637392237, 8.848916891331806, 7.851844637647232, 6.801865753638838, 6.806289220000812, 6.032410842588795, 6.877803355362789, 7.833316633209502, 8.811010686020538, 9.805746680296759, 10.779400533985772, 11.794925240167439, 12.797041772287523, 13.76839966669359, 14.610020272749288, 15.373227032416187, 14.320032534436242, 13.424533837088406, 12.525749895493515, 11.501831657567497, 10.758082419509766, 9.78783583616301, 8.822849769546785, 7.780461692794958, 7.8171103323460756, 6.995433918082833, 7.817260298634408, 8.758999760074044, 9.746206369457594, 10.766909321835968, 11.80295611136666, 12.79593881973588, 13.749741235235291, 14.72687003481735, 15.65221905529429, 16.260504683305864, 15.313103258328503, 14.363369792732124, 13.379376122910024, 12.439358446927356, 11.7242216110176, 10.702744450116548, 9.661750687717758, 8.719057096787912, 8.762959599893346, 8.03211013405206, 8.744463231945513, 9.706254874717798, 10.683646393465533, 11.689572464771576, 12.74243606894124, 13.786790680888942, 14.682726839576498, 15.646256285384409, 16.624057823842982, 17.210105630841895, 16.27210493307184, 15.381210891988113, 14.331228510747037, 13.419939547843038, 12.559842878069771, 11.6173534620446, 10.631006301173345, 9.75972445218079, 9.788308087151155, 8.99027711939813, 9.808945973341842, 10.632024853682646, 11.68300252183778, 12.65710810336818, 13.705681673655345, 14.688303043077038, 15.655725723475962, 16.600182477130424, 17.52553259736414, 17.58571958657278, 16.632920118786135, 15.622378626333374, 14.677278690939916, 13.634551988846217, 12.600990396243967, 11.958466294001752, 11.05175972625317, 10.754005892194938, 10.719062894670037, 10.055727991501783, 10.852455959156513, 11.589957661082122, 12.589716070543567, 13.588672550044393, 14.568366826767845, 15.550380774202761, 16.504801975119033, 17.542799625935867, 17.542688605568287, 16.581932673671144, 15.624403846100817, 14.59118562280228, 13.66063049584412, 12.642830111719594, 11.637966506404958, 10.939662594145682, 10.037450256077832, 10.851263225999842, 10.775486243525915, 11.102390839389013, 11.919769703793525, 12.522141759441139, 13.588876577656178, 14.544000619444923, 15.500301807314468, 16.516777054719462, 17.448612638329816, 17.464197343853616, 16.53303897605173, 15.51227516287088, 14.583705945408285, 13.643257588751093, 12.636884601584722, 11.641923803061559, 10.677773775095739, 9.959646192721445, 9.071765043341651, 9.887052835034085, 9.73188303432036, 10.72641862824236, 11.68759466097164, 12.543541761182777, 13.560189221669084, 14.549855306116813, 15.443511805048606, 16.39853553675972, 17.38467992673504, 16.542749053444513, 15.605417474738172, 14.694497166176939, 13.76404359341654, 12.759101924077141, 11.743918086707657, 10.70639493930967, 9.715531821508499, 8.98147336683684, 8.00488148589386, 8.937161372167276, 8.70413003964551, 9.707399637466857, 10.712124848041485, 11.610850049015578, 12.592597748267199, 13.480365134857703, 14.435885217046831, 15.467141643826768, 16.425171870533248, 15.683702557297524, 14.660834325861165, 13.731041543164128, 12.735635254143, 11.74384512658784, 10.758823452537701, 9.741907602098962, 8.748887086551198, 7.9481955120053325, 6.935704671348404, 7.9138046243174855], [7.892768935948816, 6.951321078278275, 6.143766566316201, 6.910617370656379, 7.892951432375892, 8.897649747464742, 9.811670213820928, 10.807371008640823, 11.75539884656679, 12.646718267923374, 13.634284104860624, 14.480585728044224, 15.444528400684618, 14.469748465165381, 13.513148934310804, 12.645387418933003, 11.669277374068873, 10.657085414920031, 9.659515438577282, 8.70848722229148, 6.920369287951377, 5.975285193598118, 5.112960255307359, 5.970219291668435, 6.905372696393735, 7.882585909344537, 8.871777009742992, 9.807002741297683, 10.778479606138506, 11.654564565008124, 12.608669823016905, 13.53830283241817, 14.577026850390896, 13.624704978192701, 12.586183541498068, 11.579813660160557, 10.616853289015324, 9.713338624094717, 8.726719307054616, 7.779792918498596, 5.903935297440483, 4.974629371809305, 4.07812879261543, 4.94132541851547, 5.9402619774150764, 6.930890684644529, 7.848175338255242, 8.86621568296797, 9.8030552959786, 10.721388990463222, 11.762134131238337, 12.741542537358727, 13.670647522985234, 12.722063526912526, 11.74906363704576, 10.692791656473041, 9.63490787140558, 8.797981454484932, 7.844627994487684, 6.8420263676869055, 4.870941450818066, 4.013220296970158, 3.0290036301511103, 3.978814794523183, 4.987312081350408, 5.9071192585585885, 6.8907387616683655, 7.865553381408079, 8.821725572701647, 9.76782263960563, 10.813696650487525, 11.823082217900819, 12.78671326656421, 11.782686573171473, 10.824906330409942, 9.750733124069244, 8.68124165513945, 7.743112033149901, 6.792680135262259, 5.855172295527066, 3.925918150552561, 3.0231791085075135, 2.0789609237944635, 3.0519130073998335, 4.016119873863111, 4.903110932754963, 5.892162578029984, 6.834898491652804, 7.817329977552083, 8.84882994915315, 9.916171995351293, 10.892990463413025, 11.880902662563916, 10.856078235412934, 9.792669350237649, 8.835838994290112, 7.8086326666898795, 6.7816468123994476, 5.804409907861135, 4.863818754580749, 2.9788756099520706, 2.02366960845534, 1.032262594852088, 2.0528996370561474, 3.031911562216864, 3.9695186219320604, 5.009778448781018, 6.043093595714648, 7.016006456150203, 8.001658309770209, 8.936248298628003, 9.962694376449932, 10.92650885332049, 9.955097652606334, 8.924404759400028, 7.877217565452886, 6.9024436226573815, 5.8765386025079085, 4.9405764201369164, 3.909503720662989, 2.039149836077903, 1.063564339896114, 0.0, 1.0636962080674566, 2.0399684599215293, 3.0559582925716375, 4.128373215630047, 5.143674536262004, 6.101830600636693, 7.115519476888177, 8.121304667073, 9.08708567086053, 10.007192483373455, 8.961354817291541, 7.95353803699189, 6.974828378487833, 6.015383065121835, 4.941918738861347, 3.9764581044277536, 2.971104168033936, 2.9294292821232166, 1.9387616992244605, 0.9911510003193272, 2.0028305174448118, 3.023587557972789, 3.991326846699762, 4.977986905267041, 5.969544351740979, 7.011456539055042, 7.9786590085975835, 9.0382612178346, 9.993939687081589, 10.758772956102824, 9.69269114744491, 8.708416073052774, 7.76632255775642, 6.818997967857761, 5.8871402875792365, 4.916177269473528, 3.9794494727658654, 3.8580293382273734, 2.922890401533026, 1.9441053874362735, 2.9603579575316625, 3.987099145561997, 4.973369909399404, 5.982621160462549, 6.9738572272803, 7.999529559648142, 8.941721058946937, 9.937367064089344, 10.94510717595849, 11.658565158834694, 10.594836777693015, 9.641228054703236, 8.703488649384452, 7.821614017453068, 6.889364339374566, 5.957548432702628, 4.909801216760952, 4.840054593412924, 3.897080642039038, 2.9792246226146166, 3.929557965026389, 4.912949051182422, 5.909135308127443, 6.915834708381305, 7.851240916608151, 8.82104260852145, 9.756438120765385, 10.709755713033138, 11.692604782816588, 12.485988644994041, 11.55243580022448, 10.629930049864889, 9.689420027568811, 8.855580721781008, 7.841058581037807, 6.8991158152589716, 5.911196573503017, 5.806686018609361, 4.965989025061775, 4.036907594863646, 4.927760729376984, 5.85691004667582, 6.86507393647219, 7.81071856223606, 8.77751019770687, 9.800202357816167, 10.777030781262807, 11.659062170997752, 12.71505640512999, 13.454264905637784, 12.5072955198624, 11.582095076458934, 10.649123618291046, 9.768173192145294, 8.829690724162461, 7.832023610788209, 6.831574225177308, 6.761259112960821, 5.935484411878269, 4.974814926488279, 5.934497699783433, 6.867769960731848, 7.85532386445905, 8.824733990366166, 9.757699179818024, 10.821706218220486, 11.767951281978378, 12.634445694523935, 13.624195499069033, 14.408668263664111, 13.488971577254643, 12.598178407071634, 11.62189745749022, 10.766418666905947, 9.830498920845516, 8.814015320765957, 7.7640364367575625, 7.7684599031195365, 6.839895558858346, 5.910281736138667, 6.865795013985379, 7.8434890667964146, 8.838225061072635, 9.811878914761648, 10.827403620943315, 11.829520153063399, 12.800878047469466, 13.642498653525166, 14.640790263677923, 15.383596874332357, 14.48809817698452, 13.58931423538963, 12.565395997463611, 11.72025310262849, 10.750006519281735, 9.78502045266551, 8.742632375913683, 8.764148383912998, 7.802918634352384, 6.849738679410286, 7.7914781408499225, 8.778684750233472, 9.799387702611844, 10.835434492142536, 11.828417200511755, 12.782219616011165, 13.759348415593225, 14.684697436070168, 15.688423250256227, 16.376667598224618, 15.426934132628238, 14.442940462806138, 13.50292278682347, 12.686392294136324, 11.664915133235272, 10.623921370836483, 9.681227779906637, 9.70999765146027, 8.772489903953323, 7.776941612721391, 8.738733255493676, 9.716124774241411, 10.722050845547454, 11.774914449717118, 12.81926906166482, 13.715205220352372, 14.678734666160283, 15.65653620461886, 16.63802419779226, 16.661479034849602, 15.687250649186419, 14.637268267945343, 13.670015714551043, 12.722215595831498, 12.210992681419214, 11.59317698429207, 10.721895135299516, 10.735346138718079, 9.730656889299393, 8.84142435411772, 9.664503234458524, 10.715480902613658, 11.689586484144058, 12.738160054431223, 13.720781423852916, 14.68820410425184, 15.6326608579063, 16.558010978140018, 16.683587897388573, 15.730788429601928, 14.720246937149167, 13.775147001755707, 12.732420299662008, 11.69885870705976, 11.13959747213867, 12.013555052039896, 11.701043943761862, 11.666100946236961, 10.796107761403047, 9.884934339932391, 10.622436041858, 11.622194451319444, 12.62115093082027, 13.600845207543722, 14.582859154978639, 15.537280355894913, 16.57527800671175, 16.571629805893497, 15.679800984486938, 14.72227215691661, 13.689053933618073, 12.758498806659912, 11.740698422535385, 10.73583481722075, 10.1207937722826, 10.999245581864558, 11.813058551786568, 11.785574269172834, 11.842770609290277, 10.952248084569403, 11.554620140217017, 12.621354958432056, 13.5764790002208, 14.532780188090346, 15.54925543549534, 16.481091019105694, 16.493138544178827, 15.56198017637694, 14.610143473686673, 13.681574256224078, 12.741125899566885, 11.734752912400515, 10.739792113877352, 9.775642085911532, 9.140777370858363, 10.033560369128377, 10.848848160820811, 10.741971059967279, 11.736506653889279, 11.931561229427087, 12.555156998898656, 13.555291223483698, 14.628064964517021, 15.485323172009775, 16.44034690372089, 16.487644680987536, 15.52722987716967, 14.589898298463329, 13.705260546951473, 12.825201333419091, 11.820259664079693, 10.84178639752345, 9.804263250125462, 8.813400132324292, 8.162604544973757, 8.966676811680586, 9.898956697954002, 9.714218065292428, 10.717487663113776, 11.722212873688404, 12.620938074662497, 13.602685773914114, 14.490453160504618, 15.445973242693746, 16.45107313693538, 15.492161587776511, 14.668183381022681, 13.645315149586322, 12.741804923938663, 11.796792994145552, 10.80500286659039, 9.856691763353494, 8.839775912914755, 7.846755397366991, 7.12932669014225, 7.89749999713513, 8.875599950104212], [8.84066644148366, 7.899218583813119, 6.918684700988649, 5.9588925474470775, 6.94122660916659, 7.901488229507477, 8.747974005753472, 9.743674800573364, 10.691702638499333, 11.583022059855917, 12.570587896793167, 13.416889519976767, 14.380832192617161, 15.370825091259263, 14.498014969946082, 13.630253454568281, 12.654143409704151, 11.64195145055531, 10.64438147421256, 9.693353257926756, 7.868266793486223, 6.923182699132963, 6.022297414855991, 5.018494468459134, 5.953647873184434, 6.855532923076376, 7.808080801675534, 8.743306533230225, 9.714783398071049, 10.590868356940668, 11.544973614949448, 12.474606624350713, 13.513330642323439, 14.49460711868819, 13.571049577133346, 12.564679695795835, 11.601719324650603, 10.698204659729996, 9.711585342689894, 8.764658954133873, 6.888801333075761, 5.92252687734415, 4.987465952164062, 3.989600595306169, 4.965006264474788, 5.867194476577072, 6.784479130187784, 7.802519474900513, 8.739359087911144, 9.657692782395765, 10.69843792317088, 11.67784632929127, 12.689921858149656, 13.638505854222364, 12.733929672681038, 11.677657692108319, 10.619773907040859, 9.78284749012021, 8.829494030122962, 7.826892403322184, 5.855807486453344, 4.961117802505003, 3.9769011356859547, 3.027089971313882, 4.012056368410119, 4.843423050491131, 5.827042553600908, 6.801857173340622, 7.75802936463419, 8.704126431538173, 9.750000442420069, 10.75938600983336, 11.723017058496751, 12.768125627282265, 11.80977236604522, 10.735599159704522, 9.666107690774728, 8.727978068785179, 7.777546170897537, 6.8400383311623445, 4.910784186187839, 3.995742074266007, 3.0278995002116806, 1.9882167993323767, 2.9524236657956546, 3.8394147246875057, 4.828466369962527, 5.771202283585347, 6.753633769484626, 7.785133741085693, 8.852475787283836, 9.829294255345566, 10.82226230972323, 11.847086736874212, 10.798515359799973, 9.841685003852437, 8.793498702325158, 7.766512848034726, 6.789275943496413, 5.848684790216027, 3.9637416455873486, 3.008535644090618, 2.0171286304873663, 0.9892034289886906, 1.9682153541494074, 2.9058224138646036, 3.946082240713562, 4.979397387647192, 5.952310248082746, 6.937962101702752, 7.872552090560546, 8.898998168382477, 9.96952862209282, 10.940939822806977, 9.930250768962352, 8.88306357501521, 7.908289632219706, 6.882384612070233, 5.94581940157283, 4.894369756298267, 3.10284604414536, 2.1272605479635707, 1.0636962080674566, 0.0, 0.9762722518540725, 1.9922620845041805, 3.0646770075625893, 4.079978328194546, 5.038134392569234, 6.051823268820718, 7.057608459005542, 8.023389462793073, 8.953870001223539, 9.999707667305453, 9.017234245059349, 8.03852458655529, 7.079079273189292, 6.005614946928803, 5.04015431249521, 4.034800376101393, 3.9740508964818932, 2.983383313583137, 2.0357726146780037, 1.0240930975525193, 2.031938880836929, 2.9777247603461863, 3.964384818913466, 4.955942265387404, 5.979950282797499, 6.94715275234004, 8.006754961577057, 8.962433430824046, 9.885964337085525, 10.756387355512365, 9.77211228112023, 8.830018765823876, 7.882694175925217, 6.950836495646693, 5.979873477540985, 5.034723438212964, 4.90265095258605, 3.9675120158917023, 2.98872700179495, 2.091248094932863, 3.0633267142038267, 3.9597678230458286, 4.9690190741089735, 5.960255140926725, 6.985927473294566, 7.910214802689394, 8.9058608078318, 9.913600919700947, 10.828628976072917, 11.658532985760472, 10.704924262770692, 9.767184857451909, 8.885310225520524, 7.953060547442023, 7.013753574743738, 5.954422831119629, 5.884676207771601, 4.941702256397714, 4.023846236973293, 3.0604481024275896, 4.043839188583623, 4.971563923392084, 5.9022326220277295, 6.837638830254575, 7.807440522167875, 8.742836034411809, 9.696153626679562, 10.679002696463012, 11.691396006296136, 12.616132008291936, 11.693626257932346, 10.753116235636268, 9.913176487503971, 8.89865434676077, 7.943737429617648, 6.955818187861693, 6.851307632968037, 6.010610639420452, 5.066437313250228, 4.058650866778184, 4.98780018407702, 5.927502551736832, 6.840049825741968, 7.763908111353296, 8.786600271462591, 9.763428694909232, 10.645460084644176, 11.701454318776415, 12.632602316882679, 13.570991727929856, 12.645791284526391, 11.712819826358503, 10.812794806503971, 9.874312338521138, 8.876645225146886, 7.876195839535985, 7.805880727319497, 6.980106026236946, 6.004344644874862, 5.074746263827462, 6.008018524775877, 6.995572428503079, 7.860562074475373, 8.744097093464449, 9.80810413186691, 10.754349195624803, 11.62084360817036, 12.610593412715458, 13.587005674909006, 14.5526677853221, 13.66187461513909, 12.685593665557677, 11.811040281264624, 10.875120535204193, 9.858636935124634, 8.80865805111624, 8.813081517478214, 7.869425277244928, 6.939811454525249, 6.006043578029408, 6.9837376308404435, 7.9784736251166635, 8.868918363846008, 9.81380153458974, 10.815918066709823, 11.78727596111589, 12.62889656717159, 13.627188177324348, 14.561934285577252, 15.551794385051977, 14.653010443457086, 13.629092205531068, 12.764874716987167, 11.794628133640412, 10.829642067024187, 9.78725399027236, 9.79367810229958, 8.832448352738966, 7.879268397796868, 6.978966961248192, 7.918933314277501, 8.939636266655873, 9.918492000621388, 10.82577553476901, 11.76861752965759, 12.74574632923965, 13.671095349716593, 14.674821163902651, 15.555005009469513, 15.621389502395155, 14.637395832573056, 13.698871992257425, 12.750177019703848, 12.70953674759395, 11.66854298519516, 10.725849394265314, 10.73952736984685, 9.802019622339905, 8.806471331107973, 7.941666048064905, 8.85637333828544, 9.862299409591483, 10.915163013761147, 11.835338957510087, 12.701603133998796, 13.665132579806707, 14.642934118265284, 15.624422111438681, 15.7097542116403, 14.735525825977119, 13.685543444736043, 12.718290891341743, 11.770490772622196, 12.712980188647368, 12.637798598650747, 11.766516749658193, 11.76487585710466, 10.760186607685975, 9.858446873422112, 8.867436027029752, 9.896819384385083, 10.870924965915483, 11.919498536202648, 12.797668115990616, 13.726905824397473, 14.671362578051934, 15.59671269828565, 15.652898375023197, 14.779063606392626, 13.768522113939865, 12.823422178546407, 11.780695476452708, 10.747133883850458, 11.787410001738523, 12.729388034312676, 12.730573662148442, 12.695630664623542, 11.825637479789629, 10.8091557639604, 9.825368834429229, 10.825127243890673, 11.82046650050413, 12.800160777227582, 13.782174724662498, 14.70921869258277, 15.670388310705617, 15.50793359782604, 14.649111462121562, 13.770547333707308, 12.737329110408771, 11.806773983450611, 10.788973599326084, 9.784109994011448, 10.768606301882453, 11.715078564137338, 12.640564341117791, 12.702976136236066, 12.763675098108264, 11.777643324106341, 10.757552932788245, 11.824287751003284, 12.779411792792029, 13.735712980661575, 14.752130309241327, 15.653029355793551, 15.429442336111368, 14.498283968309483, 13.57765820579797, 12.729849433014776, 11.789401076357583, 10.783028089191212, 9.78806729066805, 8.82391726270223, 9.788589900458216, 10.749393351401157, 11.749233718732654, 11.726837095602555, 12.721372689524557, 12.695004971453336, 11.758089791469885, 12.758224016054927, 13.83099775708825, 14.688255964581003, 15.643279696292117, 15.423948472920081, 14.463533669102214, 13.526202090395872, 12.641564338884017, 11.761505125351635, 10.756563456012236, 9.885761853583796, 8.85253842691616, 7.86167530911499, 8.893887779492447, 9.914574317215429, 10.846854203488846, 10.699084100927704, 11.702353698749054, 12.707078909323682, 12.690781503637083, 13.724362865754667, 14.750998989681904, 15.695882552582779, 15.387376928867923, 14.428465379709055, 13.604487172955224, 12.581618941518865, 11.678108715871206, 10.733096786078095, 9.741306658522934, 8.860530245396228, 7.888051089705453, 6.895030574157689, 7.897444182524335, 8.845397502669973, 9.823497455639055], [9.816938693337733, 8.875490835667192, 7.894956952842722, 6.93516479930115, 6.072310082031998, 6.925215977653404, 7.771701753899399, 8.767402548719293, 9.71543038664526, 10.606749808001844, 11.594315644939094, 12.440617268122693, 13.404559940763088, 14.39455283940519, 14.977871690650275, 14.006835863393613, 13.630415661558224, 12.618223702409383, 11.620653726066633, 10.669625509780829, 8.844539045340294, 7.899454950987035, 6.998569666710064, 5.994766720313207, 5.084731346049842, 5.879260671222304, 6.831808549821462, 7.767034281376153, 8.738511146216975, 9.614596105086594, 10.568701363095375, 11.49833437249664, 12.537058390469365, 13.518334866834117, 14.54732182898742, 13.540951947649909, 12.577991576504676, 11.674476911584069, 10.687857594543967, 9.740931205987946, 7.865073584929832, 6.898799129198222, 5.963738204018134, 4.965872847160242, 4.075627584761321, 4.890922224722999, 5.808206878333712, 6.82624722304644, 7.76308683605707, 8.681420530541692, 9.722165671316807, 10.701574077437197, 11.713649606295583, 12.66223360236829, 13.635233492235058, 12.653929943962392, 11.596046158894932, 10.759119741974283, 9.805766281977034, 8.803164655176257, 6.832079738307415, 5.937390054359075, 4.953173387540027, 4.003362223167954, 3.1226776886966525, 3.8671507986370584, 4.850770301746835, 5.8255849214865485, 6.781757112780117, 7.727854179684099, 8.773728190565995, 9.783113757979287, 10.746744806642678, 11.791853375428191, 12.786044617899293, 11.711871411558596, 10.642379942628802, 9.704250320639252, 8.753818422751609, 7.816310583016417, 5.8870564380419115, 4.97201432612008, 4.004171752065753, 2.9644890511864492, 2.0630449860821884, 2.8631424728334327, 3.8521941181084536, 4.7949300317312735, 5.777361517630553, 6.80886148923162, 7.876203535429763, 8.853022003491493, 9.845990057869157, 10.870814485020139, 11.774787611654046, 10.81795725570651, 9.769770954179231, 8.742785099888799, 7.765548195350486, 6.8249570420701, 4.940013897441421, 3.9848078959446904, 2.993400882341439, 1.9654756808427631, 0.9919431022953348, 1.9295501620105306, 2.969809988859489, 4.003125135793119, 4.976037996228673, 5.961689849848678, 6.896279838706473, 7.922725916528402, 8.993256370238747, 9.964667570952903, 10.906523020816426, 9.859335826869284, 8.88456188407378, 7.858656863924305, 6.922091653426903, 5.870642008152339, 4.079118295999432, 3.1035327998176436, 2.0399684599215293, 0.9762722518540725, 0.0, 1.015989832650108, 2.088404755708517, 3.103706076340474, 4.061862140715162, 5.075551016966646, 6.08133620715147, 7.047117210939, 7.977597749369465, 9.02343541545138, 9.99350649691342, 9.014796838409362, 8.055351525043363, 6.981887198782876, 6.016426564349283, 5.011072627955466, 4.950323148335966, 3.9596555654372096, 3.0120448665320767, 2.000365349406592, 1.0556666289828562, 2.0014525084921138, 2.9881125670593933, 3.9796700135333314, 5.003678030943426, 5.9708805004859675, 7.030482709722985, 7.986161178969973, 8.909692085231452, 9.975773893889366, 10.748384532974303, 9.80629101767795, 8.85896642777929, 7.927108747500766, 6.9561457293950575, 6.010995690067036, 5.878923204440123, 4.943784267745775, 3.964999253649023, 3.067520346786936, 2.0870544623497542, 2.983495571191756, 3.992746822254901, 4.983982889072652, 6.009655221440494, 6.9339425508353205, 7.929588555977727, 8.937328667846876, 9.852356724218843, 10.916085105360523, 11.681196514624766, 10.743457109305982, 9.861582477374597, 8.929332799296095, 7.990025826597812, 6.930695082973702, 6.860948459625673, 5.9179745082517865, 5.000118488827366, 4.0367203542816625, 3.1377247419513346, 3.995291671538012, 4.925960370173657, 5.861366578400503, 6.831168270313802, 7.7665637825577365, 8.719881374825489, 9.702730444608939, 10.715123754442063, 11.648676599211624, 12.66989850978642, 11.729388487490342, 10.889448739358045, 9.874926598614843, 8.92000968147172, 7.932090439715766, 7.82757988482211, 6.986882891274524, 6.031370663690011, 5.023584217217968, 4.081685737444732, 4.951230299882759, 5.863777573887896, 6.787635859499224, 7.810328019608518, 8.787156443055158, 9.669187832790103, 10.725182066922342, 11.656330065028605, 12.60329945080399, 13.528499894207455, 12.689092078212576, 11.789067058358043, 10.85058459037521, 9.852917477000958, 8.852468091390056, 8.782152979173569, 7.956378278091018, 6.969277995314645, 6.039679614267246, 5.1239271075030555, 6.023008212953509, 6.884289822621302, 7.767824841610376, 8.831831880012837, 9.77807694377073, 10.644571356316286, 11.634321160861385, 12.610733423054933, 13.584975508196234, 14.544583224820155, 13.66186591741175, 12.787312533118696, 11.851392787058264, 10.834909186978706, 9.784930302970311, 9.789353769332283, 8.834358627684711, 7.904744804965032, 6.9709769284691925, 6.1512711193724865, 7.083800604473948, 7.892646111991937, 8.837529282735666, 9.83964581485575, 10.811003709261817, 11.652624315317517, 12.650915925470274, 13.585662033723178, 14.58410210792611, 14.86482294309536, 13.946843022482497, 13.741146968841237, 12.770900385494482, 11.805914318878257, 10.76352624212643, 10.758611452739363, 9.797381703178749, 8.844201748236651, 7.943900311687976, 7.086466802809543, 8.044963246013157, 8.942219748767318, 9.849503282914936, 10.792345277803516, 11.769474077385576, 12.69482309786252, 13.698548912048578, 14.57873275761544, 14.84248183393517, 13.926024946698163, 13.009316233122638, 13.726449271557922, 13.68580899944802, 12.64481523704923, 11.702121646119384, 11.704460720286633, 10.76695297277969, 9.771404681547757, 8.906599398504689, 8.023906826817482, 9.029832898123525, 10.015596227561664, 10.859066705656014, 11.725330882144723, 12.688860327952634, 13.66666186641121, 14.648149859584608, 14.758668358613646, 13.812211626645153, 12.97417255886115, 12.028735132206956, 12.74676302447627, 13.689252440501441, 13.614070850504817, 12.742789001512262, 12.729809207544442, 11.72511995812576, 10.823380223861896, 9.832369377469536, 9.064352872917125, 10.038458454447525, 11.064849976402837, 11.821395864136543, 12.7506335725434, 13.69509032619786, 14.620440446431576, 14.676626123169124, 13.827977753365971, 12.81743626091321, 11.959125853839977, 11.09113971731792, 11.723406135704531, 12.763682253592597, 13.705660286166749, 13.695507012588225, 13.660564015063324, 12.790570830229413, 11.774089114400184, 10.790302184869013, 10.124232732313363, 10.987999989036172, 11.967694265759624, 12.883811802970984, 13.732946440728696, 14.694116058851543, 14.531661345971967, 13.672839210267488, 12.819461480680653, 11.786243257382116, 10.925975534041509, 10.099417840191297, 10.760382245865522, 11.744878553736527, 12.691350815991411, 13.616836592971865, 13.679248388090139, 13.728608448548048, 12.742576674546125, 11.72248628322803, 11.148009769958975, 12.039688847221385, 12.958475363692653, 13.853767387549812, 14.676757103939478, 14.453170084257295, 13.52201171645541, 12.601385953943897, 11.778763579988121, 10.838315223330929, 9.902229639782112, 9.050239320471494, 9.800189514556303, 10.76486215231229, 11.72566560325523, 12.725505970586727, 12.703109347456628, 13.69764494137863, 13.659938321893119, 12.72302314190967, 12.081946035010617, 13.09695649259654, 13.911018347612082, 14.866042079323195, 14.447676221066008, 13.48726141724814, 12.549929838541798, 11.665292087029943, 10.785232873497561, 9.780291204158162, 8.909489601729724, 8.114710456719605, 8.837947560969063, 9.87016003134652, 10.890846569069502, 11.82312645534292, 11.675356352781778, 12.678625950603127, 13.683351161177756, 13.655714854076868, 13.049537508412502, 14.076173632339739, 14.918644935613857, 14.41110467701385, 13.452193127854981, 12.62821492110115, 11.605346689664792, 10.701836464017132, 9.756824534224021, 8.76503440666886, 7.884257993542157, 7.085731664432519, 7.871302826011762, 8.873716434378409, 9.821669754524047, 10.799769707493128], [10.71805598101746, 9.768411467897911, 8.775069132353922, 7.815276978812351, 6.927304231081264, 6.046464711242873, 6.892950487488868, 7.8886512823087624, 8.836679120234729, 9.727998541591313, 10.715564378528564, 11.561866001712163, 12.525808674352557, 13.51580157299466, 14.200024258635576, 14.844599217275203, 14.592370557522734, 13.580178598373893, 12.582608622031143, 11.63158040574534, 9.762295995748577, 8.817211901395318, 7.916326617118347, 6.874878899824408, 5.939725495099108, 5.000509404811773, 5.9530572834109305, 6.888283014965622, 7.859759879806445, 8.735844838676064, 9.689950096684845, 10.61958310608611, 11.658307124058835, 12.639583600423586, 13.67810503711822, 14.556941780300015, 13.593981409154782, 12.636431807548579, 11.649812490508477, 10.702886101952457, 8.857262693980061, 7.816556079606506, 6.881495154426418, 5.883629797568525, 4.930621733810587, 4.012170958312468, 4.9294556119231805, 5.947495956635909, 6.88433556964654, 7.802669264131161, 8.843414404906277, 9.822822811026667, 10.822952872277597, 11.771536868350305, 12.744536758217071, 13.669919776612499, 12.612035991545039, 11.77510957462439, 10.821756114627142, 9.819154487826365, 7.848069570957524, 6.855147004767359, 5.870930337948311, 4.921119173576238, 3.9776718377459184, 2.988399532226527, 3.972019035336304, 4.946833655076017, 5.903005846369586, 6.849102913273569, 7.894976924155465, 8.8924170239613, 9.856048072624692, 10.901156641410205, 11.949270762380332, 12.727861244208702, 11.658369775278908, 10.720240153289359, 9.769808255401717, 8.832300415666525, 6.903046270692019, 5.889771276528363, 4.921928702474037, 3.8822460015947327, 2.9180391351314543, 1.9843912064229015, 2.9734428516979223, 3.9161787653207427, 4.898610251220021, 5.930110222821089, 6.985506801411776, 7.9623252694735065, 8.955293323851171, 9.980117751002153, 11.04352663617744, 11.833947088356616, 10.785760786829337, 9.758774932538905, 8.781538028000593, 7.840946874720207, 5.9560037300915285, 5.000797728594798, 4.009390714991547, 2.9814655134928714, 1.9884059553151954, 1.0507988955999994, 2.0787617268731937, 3.0338101904066765, 4.006723050842231, 4.9923749044622365, 5.926964893320031, 6.9534109711419605, 8.006918562556535, 8.978329763270692, 10.044659774685307, 10.87532565951939, 9.900551716723886, 8.874646696574413, 7.93808148607701, 6.886631840802447, 5.0951081286495405, 4.119522632467751, 3.055958292571637, 1.9922620845041805, 1.015989832650108, 0.0, 1.072414923058409, 2.087716243690366, 3.0458723080650545, 4.0595611843165385, 5.065346374501362, 6.031127378288892, 6.961607916719358, 8.007445582801271, 9.015262363100922, 9.99397202160498, 9.071341357693472, 7.997877031432984, 7.032416396999391, 6.027062460605574, 5.923916804026329, 4.933249221127573, 3.98563852222244, 2.9739590050969555, 1.9532019645689784, 0.9854626758420059, 1.9721227344092855, 2.9636801808832236, 3.987688198293319, 4.95489066783586, 6.014492877072878, 6.970171346319866, 7.893702252581344, 8.959784061239258, 9.944059135631393, 10.822280850328058, 9.874956260429398, 8.943098580150874, 7.972135562045166, 6.984589345757399, 6.852516860130486, 5.917377923436139, 4.938592909339387, 4.011330985966211, 2.984589797935876, 1.9675057385416481, 2.9767569896047936, 3.9679930564225447, 4.993665388790387, 5.917952718185214, 6.91359872332762, 7.921338835196768, 8.836366891568737, 9.900095272710416, 10.853703995700196, 11.75944694195609, 10.877572310024705, 9.945322631946205, 8.963619482288175, 7.904288738664065, 7.8345421153160375, 6.891568163942151, 5.97371214451773, 4.958879181988957, 3.9754880958329237, 2.9793018388879036, 3.909970537523549, 4.845376745750396, 5.815178437663695, 6.750573949907629, 7.703891542175382, 8.686740611958832, 9.699133921791956, 10.632686766561518, 11.707431556944757, 12.74537832014045, 11.863042395048408, 10.848520254305207, 9.893603337162084, 8.90568409540613, 8.800268629017376, 7.850106879634371, 6.869134017571599, 5.8613475710995555, 4.919449091326321, 3.935240467232651, 4.847787741237788, 5.771646026849116, 6.79433818695841, 7.771166610405051, 8.653198000139996, 9.709192234272235, 10.640340232378499, 11.587309618153883, 12.512510061557348, 13.493348006265954, 12.76175580255331, 11.823273334570477, 10.825606221196225, 9.825156835585323, 9.754841723368836, 8.819602266450865, 7.807041349196233, 6.877442968148834, 5.961690461384644, 5.007018380303401, 5.868299989971193, 6.751835008960269, 7.815842047362731, 8.762087111120623, 9.62858152366618, 10.618331328211278, 11.594743590404827, 12.568985675546127, 13.528593392170048, 14.466121845465128, 13.760001277313963, 12.824081531253531, 11.807597931173973, 10.757619047165578, 10.685047415888038, 9.672121981566299, 8.74250815884662, 7.80874028235078, 6.989034473254076, 6.06781077182384, 6.876656279341828, 7.8215394500855595, 8.823655982205644, 9.79501387661171, 10.63663448266741, 11.634926092820168, 12.569672201073072, 13.568112275276004, 13.986071676684832, 14.801837171531762, 14.636840615396991, 13.666594032050236, 12.701607965434011, 11.659219888682184, 11.59637480662095, 10.635145057060337, 9.68196510211824, 8.781663665569564, 7.924230156691133, 7.02897341336305, 7.926229916117209, 8.83351345026483, 9.77635544515341, 10.75348424473547, 11.678833265212413, 12.682559079398471, 13.562742924965333, 13.963730567524639, 13.047273680287635, 13.864310382171903, 14.606561451069123, 14.571444866096037, 13.530451103697247, 12.587757512767402, 12.542224074168221, 11.604716326661277, 10.609168035429345, 9.744362752386277, 8.861670180699072, 8.064424393175669, 8.999606394911556, 9.843076873005908, 10.709341049494617, 11.672870495302528, 12.650672033761104, 13.632160026934502, 13.879917092203115, 12.933460360234623, 12.095421292450622, 12.88372928125622, 13.62687520398747, 14.569364620012642, 14.499706717152835, 13.593866502967376, 13.56757256142603, 12.562883312007347, 11.661143577743484, 10.670132731351124, 9.902116226798714, 9.094731823033637, 10.048860143752728, 10.805406031486436, 11.734643739893293, 12.679100493547754, 13.60445061378147, 13.797874856758593, 12.94922648695544, 11.93868499450268, 11.080374587429448, 11.946133866367186, 12.603518315215732, 13.643794433103798, 14.58577246567795, 14.533270366469813, 14.498327368944912, 13.628334184111, 12.611852468281771, 11.628065538750601, 10.961996086194953, 10.044273357622284, 11.007641075020516, 11.867821970320877, 12.71695660807859, 13.678126226201437, 13.652910079561437, 12.794087943856958, 11.940710214270123, 10.907491990971586, 10.04722426763098, 10.954411989240562, 11.640494425376723, 12.624990733247728, 13.571462995502612, 14.496948772483066, 14.55936056760134, 14.566371802429636, 13.580340028427713, 12.560249637109617, 11.985773123840564, 11.095962215807496, 11.998422172953545, 12.837777554899706, 13.660767271289371, 13.574418817846764, 12.64326045004488, 11.722634687533366, 10.90001231357759, 9.959563956920398, 9.023478373371582, 9.90523346952076, 10.680301694067504, 11.64497433182349, 12.605777782766431, 13.605618150097929, 13.665064243421138, 14.65959983734314, 14.497701675774707, 13.560786495791257, 12.919709388892207, 12.153229861182652, 12.950965156872972, 13.902799787757692, 13.568924954655477, 12.60851015083761, 11.671178572131268, 10.786540820619413, 9.90648160708703, 8.901539937747632, 8.030738335319194, 8.96970460576887, 9.718059740480264, 10.750272210857721, 11.783767201300222, 12.716047087573639, 12.637311248746288, 13.640580846567637, 14.645306057142266, 14.493478207958455, 13.887300862294092, 13.222720032441762, 13.958591744874747, 13.53235341060332, 12.57344186144445, 11.74946365469062, 10.726595423254262, 9.823085197606602, 8.878073267813491, 7.88628314025833, 7.005506727131626, 7.940725813481785, 8.751415005522963, 9.75382861388961, 10.714590386754766, 11.692690339723848], [11.713863716081205, 10.764219202961655, 9.770876867417666, 8.811084713876095, 7.923111966145007, 7.014029313507492, 5.999747410585654, 6.995448205405548, 7.807144263047501, 8.698463684404086, 9.686029521341336, 10.532331144524935, 11.49627381716533, 12.486266715807432, 13.442866246662009, 14.41390207391867, 15.45240300832927, 14.575986333437635, 13.578416357094888, 12.627388140809085, 10.758103730812321, 9.813019636459062, 8.91213435218209, 7.870686634888151, 6.935533230162851, 5.996317139875517, 5.059854206507716, 5.995079938062408, 6.830225022619217, 7.706309981488836, 8.660415239497617, 9.590048248898881, 10.628772266871607, 11.610048743236359, 12.648570179930992, 13.654940061268503, 14.608198349348868, 13.632239542612322, 12.645620225572221, 11.6986938370162, 9.853070429043806, 8.812363814670249, 7.877302889490161, 6.879437532632268, 5.92642946887433, 5.007978693376212, 4.036252535019966, 4.974249460447814, 5.854800712459312, 6.773134406943933, 7.813879547719049, 8.793287953839439, 9.750537949219188, 10.699121945291896, 11.672121835158663, 12.728393815731382, 13.626252931739124, 12.789326514818475, 11.835973054821226, 10.833371428020449, 8.862286511151607, 7.850954739831102, 6.866738073012054, 5.916926908639981, 4.973479572809662, 3.984207267290271, 3.07881595843309, 3.9172987978887894, 4.873470989182358, 5.819568056086341, 6.854319356554454, 7.820002100902891, 8.783633149566283, 9.828741718351797, 10.876855839321923, 11.83386257243185, 12.672586715472994, 11.734457093483444, 10.7840251955958, 9.846517355860609, 7.9172632108861025, 6.885579011592107, 5.91773643753778, 4.878053736658476, 3.913846870195198, 2.980198941486645, 2.068763285230104, 2.886643908133515, 3.8690753940327935, 4.897627305825825, 5.913091878353367, 6.889910346415097, 7.8828784007927615, 8.907702827943744, 9.97111171311903, 10.872278336926763, 11.769564977906153, 10.772991872732991, 9.795754968194679, 8.855163814914292, 6.987527118456106, 6.032321116959376, 5.040914103356124, 4.012988901857449, 2.9842136903789394, 2.046606630663743, 1.0063468038147847, 1.9613952673482675, 2.934308127783822, 3.919959981403827, 4.854549970261622, 5.880996048083551, 6.934503639498127, 7.905914840212283, 8.972244851626897, 9.913656908089537, 10.813836441429816, 9.90617008493899, 8.969604874441588, 7.9181552291670245, 6.167523051707949, 5.19193755552616, 4.128373215630046, 3.0646770075625893, 2.088404755708517, 1.072414923058409, 0.0, 1.015301320631957, 1.9734573850066452, 2.987146261258129, 3.992931451442953, 4.958712455230483, 5.889192993660949, 6.935030659742862, 7.942847440042513, 8.921557098546572, 9.88100241191257, 9.070291954491392, 8.1048313200578, 7.099477383663983, 6.878681527576346, 5.88801394467759, 4.940403245772457, 3.9287237286469727, 2.9079666881189956, 1.9402273993920232, 0.9535673408247436, 1.9451247872986817, 2.9152732752349095, 3.8824757447774507, 4.942077954014469, 5.897756423261456, 6.821287329522934, 7.887369138180848, 8.871644212572983, 9.813737727869336, 10.761062317767996, 9.955865901059232, 8.930610381050865, 7.9393540693074165, 7.807281583680504, 6.872142646986156, 5.893357632889404, 4.966095709516228, 3.9393545214858934, 2.9222704620916655, 1.9582015960202515, 2.9494376628380023, 3.9751099952058446, 4.845537795126804, 5.84118380026921, 6.848923912138359, 7.763951968510327, 8.827680349652006, 9.781289072641785, 10.719028477960569, 11.72367700304809, 10.955353143210134, 9.918384205838192, 8.859053462214083, 8.789306838866056, 7.846332887492168, 6.928476868067747, 5.913643905538975, 4.930252819382941, 3.9340665624379207, 2.8914151439390072, 3.8268213521658536, 4.796623044079153, 5.732018556323087, 6.6853361485908405, 7.6681852183742905, 8.680578528207414, 9.614131372976976, 10.688876163360215, 11.704959856144928, 12.77893208167817, 11.803284977855228, 10.848368060712104, 9.860448818956149, 9.721924235231384, 8.77176248584838, 7.790789623785607, 6.783003177313564, 5.841104697540329, 4.774876973417116, 3.829232347653246, 4.753090633264574, 5.775782793373868, 6.752611216820509, 7.634642606555455, 8.690636840687695, 9.621784838793959, 10.568754224569343, 11.493954667972808, 12.474792612681414, 13.53044695189285, 12.744928940784485, 11.747261827410233, 10.746812441799332, 10.676497329582844, 9.741257872664873, 8.69966366026454, 7.739980886969385, 6.806708626020971, 5.819154722293768, 4.8497445963866515, 5.733279615375727, 6.797286653778189, 7.74353171753608, 8.61002613008164, 9.599775934626738, 10.576188196820286, 11.550430281961587, 12.510037998585508, 13.447566451880588, 14.405864912755208, 13.74573713746754, 12.729253537387981, 11.679274653379586, 11.577669726956344, 10.564744292634606, 9.635130469914927, 8.671278201171331, 7.826490733722521, 6.831754739446301, 5.8581008857572865, 6.802984056501018, 7.805100588621102, 8.776458483027168, 9.618079089082872, 10.61637069923563, 11.551116807488532, 12.549556881691464, 13.538942658450264, 14.391064991853979, 15.337177968865474, 14.559216343118543, 13.594230276502318, 12.55184219975049, 12.488997117689257, 11.527767368128643, 10.574587413186546, 9.644201584390114, 8.761686417159577, 7.792917380985511, 6.907674522532667, 7.814958056680288, 8.757800051568868, 9.734928851150928, 10.660277871627875, 11.664003685813933, 12.544187531380793, 13.070527490621425, 14.014838282552251, 14.860118117235647, 15.602369186132865, 15.464067177164344, 14.423073414765554, 13.480379823835708, 13.43484638523653, 12.497338637729584, 11.501790346497652, 10.606900671206827, 9.699126441167516, 8.82836836079813, 7.981051001327014, 8.824521479421366, 9.690785655910075, 10.654315101717986, 11.632116640176566, 12.613604633349963, 12.986714015299901, 12.040257283331409, 13.062985894715238, 13.879537016319965, 14.622682939051215, 15.565172355076387, 15.392329028221141, 14.486488814035685, 14.460194872494338, 13.455505623075654, 12.523681496564034, 11.532670650171674, 10.739572487267159, 9.858675790656099, 9.030304750168186, 9.786850637901894, 10.716088346308752, 11.660545099963212, 12.585895220196928, 12.768339999571365, 12.056023410052227, 11.045481917599465, 12.047939189694064, 12.94194160143093, 13.599326050279476, 14.639602168167542, 15.581580200741694, 15.42589267753812, 15.39094968001322, 14.512712322674812, 13.474390387102321, 12.49060345757115, 11.799452346663397, 10.808217325244746, 9.989085681435974, 10.849266576736335, 11.698401214494048, 12.659570832616895, 12.623375222374209, 11.76455308666973, 11.047507137366908, 10.014288914068372, 11.014788869895597, 11.950219724304306, 12.636302160440467, 13.620798468311472, 14.567270730566356, 15.49275650754681, 15.555168302665084, 15.428909721250186, 14.442877947248263, 13.422787555930167, 12.815030225218702, 11.859906183429958, 10.979866779369003, 11.819222161315164, 12.64221187770483, 12.544883960659536, 11.613725592857651, 10.693099830346139, 10.006809236674377, 9.066360880017184, 9.9910429756362, 10.901041204584503, 11.676109429131248, 12.640782066887235, 13.601585517830175, 14.601425885161673, 14.660871978484884, 15.655407572406883, 15.360239594595257, 14.423324414611807, 13.748966490270345, 12.917173828805113, 11.93240976328843, 12.88424439417315, 12.53939009746825, 11.578975293650382, 10.64164371494404, 9.757005963432185, 9.013278530183815, 8.008336860844418, 8.998302937583812, 9.965512340832614, 10.713867475544008, 11.746079945921466, 12.779574936363966, 13.711854822637383, 13.633118983810034, 14.63638858163138, 15.641113792206008, 15.356016126779005, 14.71655796367223, 13.895556433479333, 12.940036351290205, 12.502818553416091, 11.543907004257223, 10.719928797503393, 9.697060566067034, 8.793550340419374, 7.984870190910276, 6.993080063355116, 7.9730713293962445, 8.936533548545528, 9.747222740586707, 10.749636348953354, 11.71039812181851, 12.688498074787592], [12.53679492099396, 11.587150407874411, 10.593808072330422, 9.634015918788851, 8.746043171057764, 7.7593445294017656, 6.745062626479927, 6.008538884732475, 6.791842942415544, 7.683162363772127, 8.670728200709377, 9.517029823892976, 10.48097249653337, 11.470965395175472, 12.42756492603005, 13.398600753286711, 14.43710168769731, 15.398917538350391, 14.401347562007643, 13.45031934572184, 11.581034935725077, 10.635950841371818, 9.735065557094845, 8.693617839800908, 7.758464435075607, 6.819119910931561, 5.80516942240199, 5.008170617389336, 5.81492370198726, 6.691008660856879, 7.6451139188656585, 8.574746928266922, 9.613470946239648, 10.5947474226044, 11.633268859299033, 12.639638740636544, 13.602599111781776, 14.455170747525077, 13.468551430484977, 12.521625041928957, 10.676001633956561, 9.635295019583005, 8.700234094402916, 7.702368737545023, 6.749360673787086, 5.830781464432256, 4.78156775091424, 3.958948139815857, 4.839499391827355, 5.757833086311976, 6.798578227087091, 7.777986633207481, 8.735236628587232, 9.68382062465994, 10.656820514526707, 11.713092495099426, 12.688143294711313, 13.612257719731229, 12.65890425973398, 11.656302632933203, 9.685217716064361, 8.673885944743857, 7.689669277924809, 6.739858113552736, 5.796410777722417, 4.807138472203025, 3.824131174327364, 2.9019974772568324, 3.858169668550401, 4.804266735454384, 5.839018035922496, 6.8047007802709345, 7.768331828934326, 8.81344039771984, 9.861554518689966, 10.81856125179989, 11.734477078445181, 12.557388298396198, 11.606956400508555, 10.669448560773363, 8.740194415798857, 7.708510216504862, 6.740667642450535, 5.700984941571231, 4.736778075107953, 3.8031301463993996, 2.8140785011243783, 1.871342587501558, 2.8537740734008366, 3.8823259851938685, 4.89779055772141, 5.8746090257831405, 6.867577080160805, 7.892401507311788, 8.955810392487074, 9.856977016294804, 10.754263657274194, 11.595923077645745, 10.618686173107433, 9.678095019827046, 7.960589408291262, 7.0053834067945315, 6.01397639319128, 4.986051191692605, 3.957275980214095, 3.019668920498899, 1.9794090936499407, 0.9460939467163106, 1.919006807151865, 2.9046586607718705, 3.839248649629665, 4.8656947274515945, 5.91920231886617, 6.890613519580326, 7.956943530994941, 8.898355587457578, 9.798535120797856, 10.82444014094733, 9.942667164276745, 8.891217519002181, 7.182824372339907, 6.207238876158118, 5.1436745362620035, 4.079978328194547, 3.1037060763404742, 2.087716243690366, 1.015301320631957, 0.0, 0.9581560643746883, 1.9718449406261722, 2.977630130810996, 3.943411134598526, 4.873891673028992, 5.919729339110905, 6.927546119410556, 7.906255777914613, 8.865701091280611, 9.9391654175411, 9.120132640689757, 8.11477870429594, 7.863180415665641, 6.872512832766885, 5.924902133861752, 4.913222616736268, 3.8924655762082905, 2.924726287481318, 1.9380662289140385, 0.9465087824401004, 1.8999719546029525, 2.8671744241454937, 3.926776633382511, 4.882455102629499, 5.805986008890978, 6.872067817548891, 7.856342891941027, 8.79843640723738, 9.74576099713604, 10.677618677414564, 9.91510926914016, 8.923852957396711, 8.791780471769798, 7.856641535075451, 6.877856520978699, 5.950594597605523, 4.923853409575188, 3.9067693501809604, 2.9427004841095465, 2.0151890136806845, 2.9749452642912466, 3.830236474494847, 4.8258824796372535, 5.833622591506401, 6.74865064787837, 7.81237902902005, 8.76598775200983, 9.703727157328613, 10.708375682416134, 11.651806422560178, 10.902883093927485, 9.843552350303376, 9.77380572695535, 8.830831775581464, 7.912975756157042, 6.89814279362827, 5.914751707472236, 4.918565450527216, 3.875914032028302, 2.9583613802058055, 3.928163072119105, 4.80033890651898, 5.753656498786733, 6.736505568570184, 7.748898878403308, 8.68245172317287, 9.754689747171483, 10.689658535512972, 11.763630761046214, 12.603500664223418, 11.8328669488014, 10.844947707045444, 10.706423123320679, 9.756261373937674, 8.775288511874901, 7.767502065402859, 6.825603585629624, 5.759375861506411, 4.813731235742541, 3.8846306613045263, 4.90732282141382, 5.823172581177865, 6.702962956751348, 7.758957190883587, 8.69010518898985, 9.637074574765235, 10.5622750181687, 11.543112962877306, 12.598767302088742, 13.537249770071575, 12.731760715499528, 11.731311329888626, 11.660996217672139, 10.725756760754168, 9.684162548353834, 8.724479775058679, 7.7912075141102655, 6.803653610383063, 5.834243484475946, 4.864819643415679, 5.9288266818181405, 6.814093081893437, 7.678346480277531, 8.66809628482263, 9.644508547016178, 10.618750632157479, 11.5783583487814, 12.51588680207648, 13.4741852629511, 14.458732675184914, 13.713752425477276, 12.663773541468881, 12.562168615045639, 11.5492431807239, 10.619629358004222, 9.655777089260624, 8.810989621811816, 7.816253627535596, 6.842599773846581, 5.9345240845409695, 6.9366406166610535, 7.867574729248309, 8.686399439278762, 9.68469104943152, 10.619437157684423, 11.617877231887356, 12.607263008646155, 13.45938534204987, 14.405498319061365, 15.37574490240812, 14.578729164591612, 13.536341087839785, 13.473496005778552, 12.512266256217938, 11.55908630127584, 10.628700472479407, 9.746185305248872, 8.777416269074806, 7.892173410621962, 6.94649808472024, 7.889340079608821, 8.866468879190881, 9.728598221823765, 10.732324036009823, 11.612507881576684, 12.575333098524325, 13.546061005043352, 14.39691213140973, 15.3716375105692, 16.364195015275993, 15.407572302854849, 14.464878711925003, 14.419345273325824, 13.481837525818879, 12.486289234586947, 11.59139955929612, 10.683625329256811, 9.812867248887425, 8.965549889416309, 7.9560615074613175, 8.822325683950027, 9.785855129757937, 10.700436990372456, 11.681924983545853, 12.050593520259255, 12.785572499225683, 13.808301110609511, 14.695165976363423, 15.44561414396397, 16.38810355998914, 16.376827916310436, 15.47098770212498, 15.444693760583633, 14.440004511164949, 13.508180384653327, 12.517169538260967, 11.724071375356454, 10.843174678745394, 9.90101203536354, 8.918390665941846, 9.847628374348703, 10.792085128003164, 11.655923272342545, 11.75303867893941, 11.119902915011581, 11.79079713349374, 12.793254405588337, 13.757570561474388, 14.422257255192232, 15.462533373080298, 16.40451140565445, 16.410391565627418, 16.375448568102517, 15.497211210764103, 14.458889275191614, 13.475102345660444, 12.783951234752692, 11.79271621333404, 10.859792966631327, 9.980806604776287, 10.829941242534, 11.791110860656847, 11.608073901742252, 10.749251766037775, 10.081989335154603, 10.759604129962646, 11.76010408578987, 12.765848684347764, 13.459233365353223, 14.443729673224228, 15.390201935479112, 16.315687712459564, 16.37809950757784, 16.41340860933948, 15.427376835337556, 14.40728644401946, 13.761999294222646, 12.806875252433901, 11.850574064564356, 10.950762189355116, 11.773751905744781, 11.529582640027579, 10.598424272225694, 9.677798509714183, 9.033400710301592, 9.811676095911459, 10.736358191530472, 11.716670164627962, 12.499040634044004, 13.46371327179999, 14.424516722742931, 15.424357090074428, 15.48380318339764, 16.47833877731964, 16.34473848268455, 15.4078233027011, 14.695935559274288, 13.85745026129536, 12.803117048483784, 12.015784422213102, 11.52408877683629, 10.563673973018425, 9.626342394312083, 8.74170464280023, 8.038567720092107, 8.753652076738693, 9.743618153478085, 10.781141300876072, 11.536798680456764, 12.569011150834221, 13.602506141276722, 14.534786027550139, 14.45605018872279, 15.459319786544135, 16.38095796010857, 15.388762388290935, 14.355899108267822, 13.404869152223863, 12.456615252388524, 11.487517232784132, 10.528605683625264, 9.704627476871433, 8.681759245435076, 7.778249019787418, 7.010159380818567, 7.7383952792493895, 8.718386545290517, 9.759464753458285, 10.570153945499463, 11.57256755386611, 12.533329326731266, 13.511429279700348], [13.494950985368648, 12.545306472249099, 11.55196413670511, 10.592171983163539, 9.704199235432451, 8.717500593776453, 7.703218690854616, 6.958583459310544, 5.948387425763228, 6.839706847119811, 7.827272684057061, 8.67357430724066, 9.637516979881054, 10.627509878523156, 11.584109409377733, 12.555145236634395, 13.593646171044995, 14.605838130193835, 15.359503626382331, 14.408475410096528, 12.539191000099764, 11.594106905746505, 10.693221621469535, 9.651773904175595, 8.716620499450295, 7.7772759753062495, 6.7633254867766786, 5.958215191967405, 4.971468185334944, 5.8475531442045625, 6.801658402213342, 7.731291411614606, 8.770015429587332, 9.750749114577662, 10.720861714215001, 11.727231595552512, 12.690191966697745, 13.735173459755249, 14.426707494859665, 13.479781106303644, 11.634157698331249, 10.593451083957692, 9.658390158777605, 8.660524801919712, 7.7075167381617735, 6.788937528806945, 5.7397238152889285, 4.9171042041905455, 3.9960438751750385, 4.91437756965966, 5.950592007901317, 6.8618747271904335, 7.780046871028289, 8.728630867100996, 9.701630756967763, 10.757902737540482, 11.729987230336626, 12.769320057395074, 13.617060324108667, 12.61445869730789, 10.643373780439049, 9.632042009118546, 8.647825342299498, 7.6980141779274245, 6.7545668420971055, 5.765294536577714, 4.782287238702052, 3.860153541631521, 3.014714151898085, 3.9608112188020677, 4.883828278363554, 5.849511022711992, 6.813142071375384, 7.858250640160898, 8.906364761131025, 9.860405187425203, 10.776321014070493, 11.714450636060043, 12.565112464883242, 11.62760462514805, 9.698350480173545, 8.66666628087955, 7.698823706825223, 6.659141005945919, 5.694934139482641, 4.761286210774088, 3.7722345654990668, 2.8294986518762464, 1.9930697009558038, 2.927136227634926, 3.9426008001624675, 4.919419268224198, 5.912387322601862, 6.937211749752845, 8.000620634928131, 8.898820951920117, 9.796107592899506, 10.823093447189938, 11.57684223748212, 10.636251084201733, 8.918745472665952, 7.963539471169221, 6.972132457565969, 5.944207256067293, 4.915432044588783, 3.9778249848735876, 2.937565158024629, 1.904250011090999, 0.9828510320536957, 1.949468903212928, 2.8840588920707226, 3.910504969892652, 4.961046254491482, 5.932457455205638, 6.998787466620253, 7.940199523082891, 8.840379056423169, 9.866284076572642, 10.802849287070044, 9.84937358337687, 8.140980436714596, 7.165394940532806, 6.101830600636692, 5.038134392569235, 4.061862140715163, 3.0458723080650545, 1.9734573850066452, 0.9581560643746883, 0.0, 1.013688876251484, 2.019474066436308, 2.985255070223838, 3.9157356086543036, 4.961573274736217, 5.969390055035868, 6.948099713539926, 7.9075450269059235, 8.981009353166412, 9.946469987600004, 9.07293476867063, 8.82133648004033, 7.830668897141574, 6.883058198236441, 5.871378681110956, 4.850621640582979, 3.8828823518560065, 2.896222293288727, 1.9046648468147886, 0.9418158902282644, 1.9090183597708055, 2.968620569007823, 3.9242990382548113, 4.847829944516289, 5.913911753174203, 6.898186827566338, 7.840280342862691, 8.78760493276135, 9.719462613039875, 10.744718133048242, 9.8820090217714, 9.749936536144487, 8.81479759945014, 7.836012585353387, 6.9087506619802115, 5.882009473949877, 4.864925414555649, 3.900856548484235, 2.9733450780553725, 2.016789199916558, 2.8720804101201587, 3.867726415262565, 4.875466527131714, 5.790494583503682, 6.854222964645361, 7.807831687635139, 8.745571092953924, 9.750219618041445, 10.69365035818549, 11.730619295557432, 10.801708414678066, 10.731961791330038, 9.788987839956151, 8.87113182053173, 7.856298858002957, 6.872907771846924, 5.876721514901904, 4.834070096402991, 3.9165174445804936, 2.9706021676168812, 3.8421828421442914, 4.795500434412045, 5.778349504195495, 6.790742814028619, 7.72429565879818, 8.796533682796793, 9.731502471138283, 10.805474696671524, 11.64534459984873, 12.600261516991853, 11.803103771420131, 11.664579187695368, 10.714417438312363, 9.73344457624959, 8.725658129777548, 7.783759650004313, 6.7175319258811, 5.77188730011723, 4.842786725679214, 3.949761916911597, 4.865016516803177, 5.744806892376659, 6.800801126508898, 7.731949124615162, 8.678918510390547, 9.604118953794012, 10.584956898502618, 11.640611237714054, 12.579093705696888, 13.57676081907114, 12.689467394263316, 12.619152282046828, 11.683912825128857, 10.642318612728525, 9.68263583943337, 8.749363578484955, 7.761809674757752, 6.792399548850636, 5.822975707790366, 4.992472968551768, 5.855937017518748, 6.7201904159028425, 7.709940220447941, 8.686352482641489, 9.660594567782791, 10.620202284406712, 11.557730737701792, 12.516029198576412, 13.500576610810226, 14.524157382214238, 13.62192960584357, 13.52032467942033, 12.507399245098592, 11.577785422378913, 10.613933153635315, 9.769145686186505, 8.774409691910284, 7.800755838221271, 6.892680148915657, 6.000286903394681, 6.9094186648736216, 7.728243374904075, 8.726534985056832, 9.661281093309734, 10.659721167512668, 11.649106944271468, 12.501229277675183, 13.447342254686678, 14.417588838033433, 15.382574904649658, 14.494497152214477, 14.431652070153243, 13.470422320592629, 12.517242365650532, 11.586856536854098, 10.704341369623561, 9.735572333449493, 8.850329474996652, 7.904654149094927, 6.952986366342448, 7.930115165924509, 8.770442157449077, 9.774167971635135, 10.654351817201995, 11.617177034149636, 12.587904940668665, 13.438756067035042, 14.413481446194512, 15.406038950901305, 16.36572836722954, 15.423034776299694, 15.377501337700515, 14.43999359019357, 13.444445298961638, 12.54955562367081, 11.6417813936315, 10.771023313262113, 9.923705953790998, 8.914217571836005, 7.885971970683655, 8.849501416491565, 9.742280925997768, 10.723768919171166, 11.613353491945334, 12.632298882807344, 13.539757328505678, 14.419337167950724, 15.393167693276162, 16.335657109301334, 17.322004270172588, 16.42914376649967, 16.402849824958324, 15.39816057553964, 14.466336449028018, 13.475325602635658, 12.682227439731143, 11.801330743120081, 10.859168099738227, 9.876546730316534, 8.911274661082333, 9.855731414736793, 10.697767207967857, 10.909583162287094, 11.84941441523445, 12.682481604763936, 13.697990792794338, 14.713133966397905, 15.38041331956692, 16.420689437454985, 17.362667470029137, 17.36854763000211, 17.333604632477208, 16.455367275138794, 15.417045339566306, 14.433258410035135, 13.742107299127381, 12.750872277708728, 11.817949031006014, 10.848008730183903, 9.893587529267629, 10.854757147390476, 10.764618385089936, 9.905796249385459, 10.811500835377473, 11.651288601232842, 12.66484047299587, 13.721412089271281, 14.41738942972791, 15.401885737598915, 16.3483579998538, 17.27384377683425, 17.336255571952524, 17.37156467371417, 16.385532899712246, 15.365442508394151, 14.720155358597333, 13.765031316808589, 12.808730128939043, 11.817964314762731, 10.83739819247841, 10.686127123375263, 9.754968755573378, 8.834342993061867, 9.762912210524462, 10.703360567181655, 11.69451425590516, 12.67482622900265, 13.457196698418691, 14.421869336174678, 15.382672787117619, 16.382513154449114, 16.441959247772328, 17.37608979651855, 16.41491376378927, 15.477998583805817, 14.480035065017391, 13.630903806830657, 12.620786323737983, 11.666777650159295, 10.680633260183974, 9.720218456366108, 8.782886877659767, 7.898249126147913, 8.940667502298412, 9.71180814111338, 10.701774217852773, 11.73929736525076, 12.494954744831452, 13.527167215208909, 14.56066220565141, 15.492942091924826, 15.414206253097477, 16.417475850918823, 15.537502443456255, 14.54530687163862, 13.512443591615506, 12.561413635571547, 11.613159735736208, 10.644061716131816, 9.685150166972948, 8.861171960219117, 7.83830372878276, 6.934793503135102, 7.9602039553966355, 8.696551343624078, 9.676542609665205, 10.717620817832973, 11.52831000987415, 12.530723618240797, 13.491485391105954, 14.469585344075035], [14.485045715294653, 13.535401202175104, 12.542058866631114, 11.582266713089544, 10.694293965358456, 9.705409142451177, 8.69112723952934, 7.816376571239852, 6.806180537692535, 5.82633731800643, 6.813903154943679, 7.660204778127278, 8.624147450767673, 9.614140349409775, 10.570739880264352, 11.541775707521014, 12.580276641931615, 13.592468601080455, 14.640900032066535, 15.398570140022535, 13.529285730025771, 12.584201635672512, 11.68331635139554, 10.6418686341016, 9.7067152293763, 8.767370705232254, 7.751234035451404, 6.816008303896712, 5.829261297264251, 4.834183615091181, 5.788288873099961, 6.717921882501225, 7.75664590047395, 8.73706023832618, 9.707172837963517, 10.713542719301028, 11.67650309044626, 12.721484583503766, 13.708103900543868, 14.469875836229651, 12.624252428257256, 11.583545813883699, 10.64848488870361, 9.650619531845717, 8.697611468087779, 7.77903225873295, 6.7298185452149335, 5.823663302742918, 4.853836987104346, 3.9010080405462784, 4.936903131649833, 5.8481858509389495, 6.766357994776805, 7.714941990849512, 8.687941880716279, 9.744213861288998, 10.71629835408514, 11.75563118114359, 12.719646055860025, 13.604553427233894, 11.633468510365052, 10.622136739044551, 9.637920072225503, 8.68810890785343, 7.74466157202311, 6.755389266503718, 5.772381968628057, 4.849710947886237, 3.893538756592669, 2.947441689688686, 3.8701394021120703, 4.835822146460508, 5.7994531951239, 6.844561763909414, 7.89267588487954, 8.846716311173717, 9.76263213781901, 10.70076175980856, 11.698298089023892, 12.617699355074054, 10.688445210099548, 9.656761010805553, 8.688918436751226, 7.649235735871923, 6.6850288694086455, 5.751380940700092, 4.762329295425071, 3.8195933818022514, 2.9316505494835576, 1.9134473513834425, 2.9289119239109835, 3.905730391972714, 4.898698446350378, 5.923522873501361, 6.986931758676647, 7.885132075668632, 8.782418716648023, 9.809404570938455, 10.723719123342569, 11.626345814127736, 9.908840202591957, 8.953634201095227, 7.962227187491974, 6.934301985993298, 5.905526774514788, 4.967919714799592, 3.927659887950634, 2.894344741017004, 1.9214318805814496, 0.9357800269614441, 1.8703700158192387, 2.896816093641168, 3.9473573782399978, 4.918768578954154, 5.985098590368769, 6.926510646831406, 7.826690180171685, 8.852595200321158, 9.78916041081856, 10.839468313302875, 9.154669312966078, 8.179083816784289, 7.115519476888175, 6.051823268820718, 5.075551016966646, 4.059561184316538, 2.987146261258129, 1.9718449406261722, 1.013688876251484, 0.0, 1.0057851901848236, 1.9715661939723537, 2.9020467324028196, 3.947884398484733, 4.955701178784383, 5.934410837288441, 6.893856150654439, 7.967320476914926, 8.932781111348518, 9.938135047742335, 9.835025356291816, 8.844357773393059, 7.896747074487925, 6.88506755736244, 5.864310516834463, 4.89657122810749, 3.9099111695402105, 2.9183537230662724, 1.9555047664797485, 1.0166476458470626, 2.0435037323070393, 2.999182201554027, 3.834141068264805, 4.900222876922719, 5.884497951314854, 6.826591466611207, 7.773916056509867, 8.705773736788391, 9.731029256796758, 10.722285568540206, 10.763625412395973, 9.828486475701624, 8.849701461604871, 7.922439538231695, 6.895698350201361, 5.878614290807132, 4.914545424735718, 3.9700850253518443, 2.944412692984002, 1.979709696196416, 2.9753557013388225, 3.9503496904309294, 4.776805707252198, 5.840534088393877, 6.794142811383655, 7.73188221670244, 8.736530741789961, 9.679961481934004, 10.716930419305946, 11.682837780620904, 11.745650667581522, 10.802676716207635, 9.884820696783214, 8.844577919832973, 7.861186833676941, 6.86500057673192, 5.790415540604628, 4.855009332377782, 3.885207640464483, 2.9498121282205485, 3.9031297204883018, 4.885978790271752, 5.790141931781902, 6.723694776551463, 7.7828448065453095, 8.717813594886799, 9.79178582042004, 10.631655723597245, 11.586572640740368, 12.574491882496321, 12.620924631897005, 11.670762882514, 10.689790020451227, 9.682003573979184, 8.74010509420595, 7.673877370082736, 6.728232744318866, 5.781278613476503, 4.864367389759199, 3.972645802879434, 4.852436178452916, 5.9084304125851554, 6.818098547482569, 7.765067933257953, 8.690268376661418, 9.671106321370024, 10.72676066058146, 11.665243128564294, 12.616342578084634, 13.58614009788814, 13.575497726248464, 12.640258269330493, 11.59866405693016, 10.638981283635005, 9.705709022686591, 8.718155118959388, 7.748744993052272, 6.761467595587655, 5.907078441399371, 4.963566303595005, 5.8278197019791, 6.817569506524198, 7.772501905508896, 8.746743990650197, 9.706351707274118, 10.643880160569198, 11.602178621443818, 12.586726033677632, 13.610306805081644, 14.518602309468395, 14.476670123621965, 13.463744689300226, 12.534130866580547, 11.57027859783695, 10.725491130388141, 9.73075513611192, 8.757101282422907, 7.831172036712946, 6.914892376242284, 6.017047950949879, 6.835872660980332, 7.834164271133089, 8.747430516177142, 9.745870590380074, 10.735256367138874, 11.587378700542589, 12.533491677554084, 13.503738260900839, 14.468724327517064, 15.450842596416111, 15.387997514354877, 14.426767764794263, 13.473587809852166, 12.543201981055732, 11.660686813825198, 10.69191777765113, 9.806674919198286, 8.843146036892216, 7.867591839190051, 7.087857582885159, 7.878071443525334, 8.881797257711392, 9.740501240069403, 10.703326457017043, 11.67405436353607, 12.524905489902448, 13.499630869061917, 14.49218837376871, 15.476425107970687, 16.37938022050133, 16.33384678190215, 15.396339034395204, 14.400790743163272, 13.505901067872445, 12.598126837833137, 11.727368757463747, 10.880051397992633, 9.852709459633294, 8.800577443531257, 8.022960102506657, 8.849910212074025, 9.831398205247423, 10.699502914812742, 11.718448305674752, 12.625906751373083, 13.50548659081813, 14.47931711614357, 15.421806532168741, 16.408153693039996, 17.385489210701305, 17.359195269159958, 16.354506019741276, 15.422681893229653, 14.431671046837293, 13.63857288393278, 12.757676187321715, 11.77592418375055, 10.793302814328857, 9.825880133929934, 9.030466313260641, 9.805396494044114, 10.741604364183898, 11.630193520060416, 12.640735012513177, 13.640953456394257, 14.443082005707165, 15.502674004915308, 16.493201741449283, 17.360909007052655, 18.295049071298973, 18.289950076678842, 17.41171271934043, 16.373390783767938, 15.38960385423677, 14.698452743329018, 13.707217721910363, 12.734705115018338, 11.762614203031504, 10.80819300211523, 10.029492045914324, 9.751248855976556, 10.752891205844588, 11.658595791836602, 12.498383557691971, 13.511935429455, 14.568507045730412, 15.407484159653915, 16.39198046752492, 17.338452729779807, 18.263938506760258, 18.303771671756998, 17.356898386358864, 16.380857379533573, 15.465165913374078, 14.400601800955652, 13.516260966413576, 12.55995977854403, 11.686458236586015, 10.66080040404503, 9.672757594261883, 8.741599226459998, 9.681437949520996, 10.610007166983591, 11.550455523640784, 12.556828510807154, 13.551789309330317, 14.447291428344696, 15.411964066100683, 16.372767517043624, 17.37260788437512, 17.43205397769833, 16.36272026740517, 15.401544234675889, 14.464629054692438, 13.46666553590401, 12.617534277717276, 11.607416794624601, 10.653408121045914, 9.667263731070593, 8.706848927252727, 7.769517348546386, 8.745344082607042, 9.787762458757541, 10.699716689788104, 11.689682766527497, 12.727205913925484, 13.485049474757457, 14.517261945134914, 15.550756935577414, 16.48303682185083, 16.404300983023482, 15.574105873904093, 14.524132914342875, 13.53193734252524, 12.499074062502125, 11.548044106458166, 10.599790206622826, 9.630692187018436, 8.671780637859566, 7.847802431105736, 6.824934199669379, 7.781888459594231, 8.817997067325944, 9.684459892298802, 10.66445115833993, 11.707715547758978, 12.518404739800156, 13.520818348166802, 14.481580121031959, 15.45968007400104], [15.432523034412702, 14.482878521293152, 13.489536185749163, 12.529744032207592, 11.641771284476505, 10.652886461569226, 9.638604558647389, 8.7638538903579, 7.753657856810585, 6.773814637124479, 6.028512596769367, 6.806265533896783, 7.770208206537177, 8.760201105179279, 9.712435572178714, 10.683471399435376, 11.721972333845976, 12.663871052359095, 13.638700494664619, 14.483335665338672, 14.476763049143818, 13.531678954790559, 12.630793670513588, 11.589345953219649, 10.654192548494349, 9.714848024350305, 8.698711354569452, 7.763485623014761, 6.776738616382301, 5.78166093420923, 4.990376325804609, 5.863982638270729, 6.866215251836299, 7.815357579728639, 8.785470179365978, 9.791840060703489, 10.69245858151006, 11.720124261533782, 12.705904363141952, 13.554641361545789, 13.571729747375302, 12.531023133001746, 11.595962207821659, 10.598096850963765, 9.645088787205827, 8.726509577851, 7.677295864332983, 6.771140621860967, 5.8013143062223955, 4.848485359664328, 4.015200473052293, 4.92648319234141, 5.844655336179265, 6.793239332251972, 7.76623922211874, 8.822511202691459, 9.710513163900316, 10.749845990958766, 11.713860865675201, 12.6168748107341, 12.541448990731825, 11.5696140581626, 10.585397391343552, 9.635586226971478, 8.692138891141159, 7.702866585621767, 6.7198592877461065, 5.797188267004287, 4.841016075710718, 3.8949190088067356, 2.9484367435145304, 3.914119487862968, 4.87775053652636, 5.880913245781956, 6.9290273667520825, 7.840931120988895, 8.756846947634186, 9.694976569623735, 10.692512898839068, 11.63002073857426, 11.59642569046632, 10.604238329923604, 9.636395755869277, 8.596713054989973, 7.632506188526695, 6.698858259818142, 5.709806614543121, 4.767070700920301, 3.879127868601607, 2.860924670501492, 2.0072092653134437, 2.984027733375174, 3.942931822095613, 4.954304908023417, 6.008771276971823, 6.879346885483809, 7.776633526463199, 8.80361938075363, 9.717933933157745, 10.658525086438132, 10.765452976619217, 9.901111520213277, 8.909704506610025, 7.8817793051113485, 6.853004093632839, 5.9153970339176425, 4.875137207068684, 3.8418220601350535, 2.868909199699499, 1.8832573460794937, 0.9486673572216991, 1.9751134350436286, 2.941572188055174, 3.91298338876933, 4.979313400183945, 5.920725456646583, 6.820904989986861, 7.846810010136334, 8.783375220633737, 9.834824865908299, 9.864304189513549, 9.184869006969114, 8.121304667073, 7.057608459005543, 6.0813362071514705, 5.065346374501362, 3.9929314514429533, 2.9776301308109963, 2.019474066436308, 1.0057851901848236, 0.0, 0.9657810037875301, 1.896261542217996, 2.9420992082999096, 3.9499159885995603, 4.928625647103618, 5.888070960469616, 6.961535286730104, 7.926995921163697, 8.932349857557515, 10.777172920086455, 9.850142963577882, 8.902532264672748, 7.890852747547265, 6.870095707019288, 5.902356418292315, 4.915696359725035, 3.9241389132510966, 2.9612899566645723, 2.022432836031886, 1.037718542122216, 1.9933970113692039, 2.828355878079982, 3.894437686737896, 4.878712761130032, 5.820806276426385, 6.768130866325045, 7.699988546603569, 8.725244066611936, 9.716500378355384, 11.705772976190612, 10.834271665886448, 9.855486651789695, 8.92822472841652, 7.901483540386185, 6.884399480991957, 5.920330614920543, 4.975870215536667, 3.9501978831688254, 2.9854948863812396, 2.0896590405949658, 2.944564500246106, 3.7710205170673743, 4.834748898209054, 5.788357621198832, 6.726097026517616, 7.730745551605137, 8.67417629174918, 9.711145229121122, 10.677052590436082, 12.639848672401591, 11.80846190639246, 10.890605886968038, 9.850363110017797, 8.866972023861765, 7.870785766916744, 6.796200730789452, 5.860794522562606, 4.8909928306493065, 3.9555973184053723, 3.0692766698290157, 3.9459804830020797, 4.784356741597078, 5.717909586366639, 6.777059616360486, 7.712028404701975, 8.786000630235216, 9.62587053341242, 10.580787450555544, 11.568706692311498, 13.605243114271264, 12.676548072698823, 11.69557521063605, 10.687788764164008, 9.745890284390773, 8.67966256026756, 7.73401793450369, 6.787063803661327, 5.870152579944022, 4.978430993064258, 4.01858312779363, 4.976342141097352, 5.812313357297745, 6.759282743073129, 7.6844831864765935, 8.665321131185198, 9.720975470396635, 10.659457938379468, 11.61055738789981, 12.580354907703317, 14.547129272346567, 13.646043459515317, 12.604449247114983, 11.644766473819828, 10.711494212871415, 9.723940309144211, 8.754530183237096, 7.767252785772479, 6.912863631584193, 5.969351493779829, 4.9939666513198135, 5.983716455864912, 6.766716715324073, 7.740958800465374, 8.700566517089294, 9.638094970384373, 10.596393431258992, 11.580940843492806, 12.604521614896818, 13.512817119283572, 15.473278083490255, 14.46952987948505, 13.539916056765371, 12.576063788021774, 11.731276320572965, 10.736540326296744, 9.76288647260773, 8.83695722689777, 7.920677566427106, 7.0228331411347025, 6.002019610321046, 7.000311220473803, 7.741645325992317, 8.740085400195252, 9.72947117695405, 10.581593510357763, 11.527706487369258, 12.497953070716013, 13.462939137332238, 14.499105610696109, 16.3937827045397, 15.432552954979087, 14.47937300003699, 13.548987171240556, 12.666472004010021, 11.697702967835953, 10.81246010938311, 9.84893122707704, 8.873377029374872, 8.027637762126183, 7.044218392866048, 8.047944207052106, 8.734716049884577, 9.697541266832218, 10.668269173351247, 11.519120299717622, 12.493845678877092, 13.486403183583885, 14.470639917785862, 15.413333508715708, 17.33963197208697, 16.402124224580028, 15.406575933348096, 14.511686258057269, 13.60391202801796, 12.733153947648571, 11.885836588177456, 10.858494649818118, 9.806362633716079, 8.962740281747681, 8.01605716141474, 8.997545154588137, 9.693717724627916, 10.712663115489926, 11.62012156118826, 12.499701400633304, 13.473531925958742, 14.416021341983914, 15.402368502855168, 16.451615661116886, 18.25496168615793, 17.3602912099261, 16.428467083414475, 15.437456237022117, 14.644358074117603, 13.76346137750654, 12.781709373935373, 11.79908800451368, 10.831665324114756, 9.896893563618544, 8.971543443384828, 9.907751313524612, 10.62440832987559, 11.634949822328352, 12.635168266209433, 13.43729681552234, 14.49688881473048, 15.487416551264458, 16.355123816867827, 17.289263881114145, 18.423931632767008, 17.545256926160455, 16.522832633178623, 15.539045703647455, 14.566074530515627, 13.676495908970015, 12.696801632246563, 11.72726688609599, 10.772845685179716, 10.20719411164888, 9.90919568239659, 10.911538226426247, 11.662321909732569, 12.666142825859446, 13.668318586007901, 14.429018692648963, 15.4338822979636, 16.506220251120528, 17.369433287043165, 18.22082511088093, 17.44546736367136, 16.498594078273225, 15.522553071447934, 14.606861605288438, 13.542297492870015, 12.66232172218308, 11.706020534313534, 10.854692854509919, 9.829035021968934, 9.175728550962127, 9.689076545578047, 10.628915268639044, 11.55748448610164, 12.497932842758832, 13.504305829925203, 14.499266628448366, 15.394768747462745, 16.359441385218734, 17.320244836161674, 18.32008520349317, 16.51681950301447, 15.50441595931953, 14.54323992659025, 13.606324746606798, 12.608361227818373, 11.759229969631638, 10.753477550394106, 9.799468876815416, 8.813324486840095, 8.133875936626845, 8.716994667664435, 9.69282140172509, 10.73523977787559, 11.647194008906153, 12.637160085645545, 13.674683233043533, 14.432526793875505, 15.464739264252962, 16.498234254695465, 17.43051414096888, 15.48906650833962, 14.69667271920111, 13.665828606257236, 12.6736330344396, 11.640769754416487, 10.689739798372528, 9.74585096239233, 8.776752942787938, 7.817841393629069, 7.062411872931424, 7.772411518787428, 8.72936577871228, 9.76547438644399, 10.63193721141685, 11.611928477457978, 12.655192866877027, 13.465882058918204, 14.46829566728485, 15.429057440150007, 16.40715739311909], [14.501850111959577, 15.448659525080682, 14.455317189536693, 13.495525035995122, 12.607552288264035, 11.618667465356758, 10.60438556243492, 9.729634894145432, 8.719438860598116, 7.73959564091201, 6.920323775772829, 5.894837391032861, 6.858780063673255, 7.842667761456808, 8.787808473437277, 9.758844300693939, 10.79734523510454, 11.698090048571565, 12.672919490877089, 13.517554661551141, 13.529450463962139, 14.474534558315398, 13.596574674301118, 12.555126957007179, 11.619973552281879, 10.680629028137835, 9.664492358356984, 8.729266626802293, 7.742519620169832, 6.747441937996761, 5.882187504808071, 4.952554495406807, 5.941588153094864, 6.890730480987204, 7.860843080624542, 8.867212961962053, 9.72667757772253, 10.754343257746251, 11.740123359354422, 12.588860357758259, 12.60866183356671, 13.496804136789276, 12.561743211609189, 11.563877854751295, 10.610869790993357, 9.69229058163853, 8.643076868120513, 7.736921625648498, 6.7670953100099265, 5.814266363451859, 4.9809814768398235, 4.015055049477488, 4.920028237437831, 5.868612233510538, 6.841612123377304, 7.8901529359068245, 8.744732160112786, 9.784064987171236, 10.748079861887671, 11.65109380694657, 11.575667986944294, 12.53539506195013, 11.551178395131082, 10.601367230759008, 9.657919894928689, 8.668647589409296, 7.685640291533636, 6.762969270791817, 5.806797079498249, 4.8607000125942665, 3.9142177473020605, 3.0026913449990467, 3.9531234377849254, 4.915132241994426, 5.9632463629645525, 6.875150117201365, 7.791065943846656, 8.729195565836205, 9.726731895051538, 10.66423973478673, 10.63064468667879, 11.570019333711134, 10.602176759656807, 9.562494058777503, 8.598287192314224, 7.664639263605671, 6.67558761833065, 5.73285170470783, 4.844908872389137, 3.8267056742890224, 2.9729902691009737, 2.072599590511253, 2.9771508183080835, 3.988523904235887, 5.042990273184293, 5.913565881696279, 6.810852522675669, 7.837838376966101, 8.752152929370215, 9.692744082650602, 9.799671972831687, 10.754877974328418, 9.875485510397553, 8.847560308898878, 7.818785097420367, 6.881178037705171, 5.840918210856213, 4.807603063922583, 3.834690203487029, 2.849038349867024, 1.9144483610092293, 1.0505560144583248, 1.975791184267644, 2.9472023849818, 4.013532396396415, 4.954944452859053, 5.855123986199331, 6.881029006348804, 7.8175942168462065, 8.869043862120769, 8.898523185726017, 9.874108681907806, 9.08708567086053, 8.023389462793073, 7.047117210939, 6.0311273782888914, 4.958712455230483, 3.9434111345985263, 2.985255070223838, 1.9715661939723537, 0.9657810037875301, 0.0, 0.930480538430466, 1.9763182045123793, 2.9841349848120298, 3.9628446433160875, 4.922289956682086, 5.995754282942574, 6.961214917376167, 7.966568853769984, 9.811391916298923, 10.80205949919768, 9.868313268460279, 8.856633751334794, 7.835876710806818, 6.868137422079845, 5.881477363512565, 4.889919917038627, 3.9270709604521024, 2.9882138398194162, 1.9874814172513793, 1.0318029480043913, 1.8625748742924517, 2.9286566829503657, 3.9129317573425015, 4.855025272638855, 5.802349862537515, 6.734207542816039, 7.759463062824405, 8.750719374567852, 10.73999197240308, 11.736122797775387, 10.821267655577225, 9.894005732204048, 8.867264544173715, 7.850180484779487, 6.886111618708073, 5.941651219324197, 4.915978886956355, 3.9512758901687697, 3.022696629288319, 1.9829704368812937, 2.805239513279844, 3.868967894421524, 4.822576617411302, 5.760316022730086, 6.764964547817607, 7.708395287961651, 8.745364225333592, 9.71127158664855, 11.674067668614061, 12.617041619987948, 11.856386890755568, 10.815318873300894, 9.831927787144862, 8.835741530199842, 7.76115649407255, 6.825750285845704, 5.855948593932404, 4.92055308168847, 3.9672354894207174, 2.984386419637267, 3.8185757378095477, 4.752128582579109, 5.811278612572956, 6.746247400914445, 7.820219626447686, 8.66008952962489, 9.615006446768014, 10.602925688523968, 12.639462110483734, 13.58962385986674, 12.66053097391915, 11.652744527447107, 10.710846047673872, 9.64461832355066, 8.698973697786789, 7.7520195669444245, 6.83510834322712, 5.943386756347356, 4.916541947385332, 4.0147480777325395, 4.846532353510215, 5.793501739285599, 6.718702182689063, 7.699540127397668, 8.755194466609105, 9.693676934591938, 10.64477638411228, 11.614573903915787, 13.581348268559037, 14.559119246683233, 13.569405010398084, 12.609722237102929, 11.676449976154515, 10.688896072427312, 9.719485946520194, 8.732208549055578, 7.877819394867291, 6.8882196872354955, 5.891925470911515, 5.040248660937204, 5.8009357115365425, 6.775177796677844, 7.734785513301764, 8.672313966596843, 9.630612427471462, 10.615159839705276, 11.638740611109288, 12.547036115496041, 14.507497079702725, 15.43448564276815, 14.504871820048471, 13.541019551304874, 12.696232083856064, 11.701496089579843, 10.72784223589083, 9.801912990180869, 8.885633329710204, 7.941701334590368, 6.899978429912747, 6.0822666302674495, 6.775864322204787, 7.774304396407721, 8.76369017316652, 9.615812506570233, 10.561925483581728, 11.532172066928483, 12.497158133544708, 13.533324606908579, 15.438935211074629, 16.397508718262188, 15.44432876332009, 14.513942934523657, 13.63142776729312, 12.662658731119052, 11.77741587266621, 10.813886990360139, 9.838332792657972, 8.925596581717883, 7.942177212457748, 7.129899616845754, 7.768935046097047, 8.731760263044688, 9.702488169563717, 10.553339295930092, 11.528064675089562, 12.520622179796355, 13.504858913998332, 14.447552504928177, 16.3847844786219, 17.342817859161826, 16.371531696631195, 15.47664202134037, 14.56886779130106, 13.698109710931671, 12.850792351460557, 11.823450413101217, 10.77131839699918, 9.860699101339382, 8.91401598100644, 8.079500564381785, 8.727936720840386, 9.746882111702396, 10.65434055740073, 11.533920396845774, 12.507750922171212, 13.450240338196384, 14.436587499067638, 15.485834657329356, 17.2891806823704, 17.545424829328912, 16.563362258697857, 15.572351412305496, 14.682609681366591, 13.70850409983619, 12.738049219791879, 11.811153090900014, 10.84373041050109, 10.794852383210245, 9.869502262976528, 9.126921602904314, 9.65862732608806, 10.669168818540822, 11.669387262421903, 12.47151581173481, 13.53110781094295, 14.521635547476928, 15.389342813080297, 16.323482877326615, 17.499304534025573, 16.62062982741902, 15.59820553443719, 14.61441860490602, 13.64144743177419, 12.758962565247543, 11.779268288524092, 10.815838743232067, 9.861417542315793, 10.89941519313263, 10.80715450198829, 10.13070851580595, 10.696540905945039, 11.700361822071915, 12.702537582220371, 13.463237688861433, 14.46810129417607, 15.540439247332998, 16.403652283255635, 17.2550441070934, 16.520840264929923, 15.573966979531788, 14.597925972706498, 13.682234506547003, 12.617670394128577, 11.744788378460608, 10.788487190591063, 9.943264711645996, 8.917606879105012, 9.90564968888816, 10.654857549365577, 11.202161772129541, 11.74512953079805, 12.648289856123103, 13.654662843289474, 14.512416208581236, 15.428294025485288, 16.392966663241275, 17.353770114184215, 17.46511932998247, 15.55103849922694, 14.579788860578095, 13.618612827848814, 12.681697647865363, 11.683734129076935, 10.834602870890201, 9.835944206671636, 8.888040733951494, 7.901896343976174, 8.8849234674689, 9.682775671451965, 10.658602405512623, 11.701020781663122, 12.612975012693685, 13.602941089433077, 14.640464236831065, 15.398307797663035, 16.430520268040492, 17.464015258482995, 16.515227867115662, 14.52328550455209, 13.73089171541358, 12.7412015075158, 11.749005935698165, 10.71614265567505, 9.765112699631091, 8.82831761866986, 7.865324799924017, 6.906413250765148, 7.9542230519348855, 8.738192522574959, 9.695146782499812, 10.731255390231524, 11.597718215204383, 12.57770948124551, 13.620973870664557, 14.431663062705734, 15.434076671072381, 16.394838443937537, 15.542822738248859], [13.571369573529113, 14.52008990456509, 15.385797727967159, 14.426005574425588, 13.5380328266945, 12.549148003787224, 11.534866100865386, 10.660115432575898, 9.649919399028581, 8.670076179342477, 7.850804314203295, 6.825317929463328, 6.076674815044383, 6.9121872230263435, 7.857327935006814, 8.828363762263477, 9.866864696674078, 10.7676095101411, 11.742438952446623, 12.58707412312068, 12.598969925531675, 13.544054019884934, 14.522511226678116, 13.485607495437645, 12.550454090712345, 11.6111095665683, 10.59497289678745, 9.659747165232758, 8.673000158600297, 7.677922476427227, 6.812668043238538, 5.883035033837274, 5.0111076146643985, 5.9602499425567395, 6.930362542194078, 7.9367324235315895, 8.796197039292066, 9.823862719315786, 10.809642820923957, 11.658379819327795, 11.678181295136245, 12.645004676050952, 13.492223750039654, 12.494358393181761, 11.541350329423823, 10.622771120068995, 9.573557406550979, 8.667402164078963, 7.697575848440392, 6.7447469018823245, 5.91146201527029, 4.945535587907955, 3.9895476990073653, 4.938131695080073, 5.91113158494684, 6.959672397476359, 7.814251621682321, 8.85358444874077, 9.817599323457205, 10.720613268516106, 10.645187448513829, 11.683595601211806, 12.481658933561548, 11.531847769189474, 10.588400433359155, 9.599128127839762, 8.616120829964101, 7.693449809222283, 6.737277617928715, 5.791180551024732, 4.844698285732527, 3.9331718834295133, 3.0226428993544596, 3.98465170356396, 5.032765824534087, 5.944669578770898, 6.86058540541619, 7.79871502740574, 8.796251356621074, 9.733759196356266, 9.700164148248325, 10.731848347542321, 11.532657298087273, 10.492974597207969, 9.52876773074469, 8.595119802036137, 7.606068156761116, 6.663332243138296, 5.775389410819603, 4.757186212719488, 3.9034708075314395, 3.0030801289417193, 2.0466702798776173, 3.058043365805421, 4.112509734753827, 4.983085343265812, 5.880371984245203, 6.907357838535635, 7.82167239093975, 8.762263544220136, 8.869191434401223, 9.824397435897954, 10.805966048828019, 9.778040847329343, 8.749265635850833, 7.8116585761356365, 6.7713987492866785, 5.738083602353049, 4.765170741917495, 3.7795188882974897, 2.844928899439695, 1.9810365528887908, 1.0453106458371781, 2.0167218465513344, 3.083051857965949, 4.024463914428586, 4.924643447768865, 5.950548467918338, 6.887113678415741, 7.938563323690304, 7.96804264729555, 8.943628143477339, 10.007192483373453, 8.953870001223539, 7.977597749369465, 6.961607916719357, 5.889192993660949, 4.873891673028992, 3.9157356086543036, 2.9020467324028196, 1.896261542217996, 0.930480538430466, 0.0, 1.0458376660819133, 2.0536544463815636, 3.0323641048856214, 3.991809418251619, 5.0652737445121065, 6.0307343789456995, 7.036088315339517, 8.880911377868456, 9.871578960767213, 10.798793806890744, 9.78711428976526, 8.766357249237283, 7.7986179605103105, 6.811957901943031, 5.820400455469093, 4.857551498882568, 3.9186943782498824, 2.888286970931736, 1.9326085016847476, 0.9320943358619856, 1.9981761445198996, 2.9824512189120354, 3.9245447342083883, 4.871869324107048, 5.803727004385572, 6.828982524393938, 7.820238836137386, 9.809511433972613, 10.80564225934492, 11.75174819400769, 10.824486270634514, 9.79774508260418, 8.780661023209953, 7.816592157138539, 6.860169779048983, 5.834497446681141, 4.869794449893555, 3.8741484447511483, 2.834422252344123, 1.874758974849378, 2.938487355991058, 3.8920960789808365, 4.82983548429962, 5.8344840093871415, 6.777914749531186, 7.814883686903126, 8.780791048218083, 10.743587130183595, 11.686561081557482, 12.712579879083492, 11.666770688763725, 10.683379602607692, 9.687193345662672, 8.61260830953538, 7.677202101308533, 6.707400409395234, 5.7720048971513, 4.818687304883547, 3.8358382351000966, 2.8880951993790815, 3.821648044148643, 4.88079807414249, 5.815766862483979, 6.889739088017221, 7.729608991194426, 8.684525908337548, 9.672445150093502, 11.708981572053268, 12.659143321436273, 13.51198278938198, 12.504196342909937, 11.562297863136703, 10.49607013901349, 9.55042551324962, 8.603471382407253, 7.686560158689949, 6.794838571810185, 5.767993762848161, 4.847199813186013, 3.9160518150797485, 4.863021200855133, 5.788221644258598, 6.7690595889672025, 7.824713928178638, 8.763196396161472, 9.714295845681814, 10.684093365485321, 12.65086773012857, 13.628638708252767, 14.420856825860914, 13.46117405256576, 12.527901791617346, 11.540347887890142, 10.570937761983025, 9.583660364518407, 8.72927121033012, 7.739671502698325, 6.743377286374344, 5.872700396390677, 4.870455173106076, 5.844697258247378, 6.8043049748712985, 7.741833428166377, 8.700131889040996, 9.68467930127481, 10.708260072678822, 11.616555577065576, 13.57701654127226, 14.564459650936417, 15.356323635511302, 14.392471366767705, 13.547683899318894, 12.552947905042673, 11.57929405135366, 10.653364805643697, 9.737085145173033, 8.793153150053199, 7.751430245375577, 6.898578281754265, 5.84538378377432, 6.843823857977255, 7.833209634736054, 8.685331968139767, 9.631444945151262, 10.601691528498018, 11.566677595114243, 12.602844068478113, 14.508454672644163, 15.469684422204777, 16.29578057878292, 15.365394749986487, 14.48287958275595, 13.514110546581882, 12.628867688129041, 11.665338805822968, 10.6897846081208, 9.777048397180714, 8.793629027920579, 7.785855932643941, 6.83845450766658, 7.801279724614221, 8.77200763113325, 9.622858757499626, 10.597584136659096, 11.59014164136589, 12.574378375567866, 13.517071966497712, 15.454303940191433, 16.41233732073136, 16.529432495612166, 15.567640852839881, 14.792575189035768, 13.808330991263693, 12.856822430202586, 12.216902247616948, 11.622770212462006, 10.712150916802212, 9.734732274772977, 8.735456880179973, 7.797456182409919, 8.816401573271929, 9.723860018970264, 10.603439858415308, 11.577270383740746, 12.519759799765918, 13.506106960637172, 14.55535411889889, 16.35870014393993, 16.61494429089845, 15.632881720267394, 14.641870873875034, 13.752129142936125, 12.778023561405725, 11.807568681361413, 11.25457308913642, 11.774210948931557, 11.615568676976782, 10.690218556743066, 9.760906383519567, 8.728146787657593, 9.738688280110354, 10.738906723991438, 11.541035273304344, 12.600627272512485, 13.591155009046462, 14.458862274649832, 15.393002338896148, 16.56882399559511, 15.690149288988557, 14.667724996006728, 13.683938066475557, 12.710966893343727, 11.828482026817078, 10.848787750093626, 10.192157150301979, 10.791898080746261, 11.829895731563095, 11.627870795754827, 10.7235891950849, 9.766060367514571, 10.769881283641448, 11.772057043789905, 12.532757150430967, 13.537620755745603, 14.609958708902532, 15.47317174482517, 16.32456356866293, 15.590359726499461, 14.643486441101325, 13.667445434276036, 12.75175396811654, 11.687189855698115, 10.814307840030143, 9.858006652160597, 9.22220156572315, 9.84808741753548, 10.836130227318627, 11.585338087796043, 11.743218209830177, 10.814648992367582, 11.717809317692636, 12.724182304859006, 13.58193567015077, 14.497813487054822, 15.462486124810809, 16.42328957575375, 16.534638791552005, 14.620557960796479, 13.649308322147633, 12.688132289418352, 11.7512171094349, 10.753253590646473, 9.904122332459737, 8.90546366824117, 8.157179332865164, 8.83237688240664, 9.815404005899367, 10.613256209882431, 11.589082943943088, 11.809481982577067, 12.775833336865402, 13.716922342911394, 14.51746453390266, 15.460055440642062, 16.440658950695415, 16.535445637967403, 15.584747328685198, 13.592804966121628, 12.800411176983115, 11.810720969085338, 10.818525397267702, 9.785662117244588, 8.834632161200627, 7.897837080239395, 7.121289259840132, 7.8368937891956145, 8.884703590365351, 9.668673061005425, 10.625627320930278, 11.66173592866199, 12.528198753634848, 13.508190019675975, 14.551454409095022, 15.3621436011362, 16.36455720950285, 15.466268823421945, 14.612342199818396], [12.5255319074472, 13.474252238483176, 14.467594574027165, 15.427386727568736, 14.583870492776413, 13.594985669869137, 12.5807037669473, 11.705953098657812, 10.695757065110495, 9.7153285996679, 8.807205909708628, 7.78171952496866, 6.972581327883436, 5.982588429241333, 6.900289324869903, 7.871325152126566, 8.82247297187612, 9.721771844059187, 10.69660128636471, 11.541236457038764, 11.553132259449761, 12.49821635380302, 13.476673560596202, 14.531445161519557, 13.596291756794257, 12.656947232650213, 11.640810562869364, 10.705584831314672, 9.718837824682211, 8.723174896752651, 7.76906963874387, 6.8394366293426065, 5.930951004856168, 5.030651148771729, 5.973323932057167, 6.964810356022655, 7.750359373210152, 8.778025053233874, 9.763805154842045, 10.612542153245881, 10.632343629054333, 11.59916700996904, 12.634996293207514, 13.51621775023574, 12.587187995505735, 11.668608786150907, 10.61939507263289, 9.713239830160877, 8.743413514522306, 7.790584567964237, 6.8813455895336775, 5.901937183413287, 4.909391089199135, 4.008532901295062, 4.95409297480993, 5.913834731394445, 6.7684139556004075, 7.807746782658858, 8.771761657375293, 9.674775602434192, 9.599349782431915, 10.637757935129892, 11.603895961871379, 12.553707126243452, 11.634238099441067, 10.644965793921678, 9.661958496046015, 8.739287475304197, 7.783115284010628, 6.837018217106645, 5.877527670709869, 4.889573478934846, 3.9424862895462294, 2.9616726923274177, 4.009786813297544, 4.898831912688985, 5.814747739334276, 6.752877361323827, 7.750413690539159, 8.687921530274352, 8.654326482166411, 9.686010681460406, 10.653853255514733, 11.538812263289882, 10.574605396826604, 9.640957468118051, 8.65190582284303, 7.7091699092202095, 6.821227076901517, 5.803023878801401, 4.936300192508782, 3.959481724447052, 2.966513670069387, 2.035064354568879, 3.089530723517284, 3.9372476771838993, 4.834534318163289, 5.861520172453721, 6.7758347248578366, 7.716425878138223, 7.823353768319309, 8.77855976981604, 9.769966783419292, 10.797891984917968, 9.795103301932746, 8.85749624221755, 7.817236415368592, 6.783921268434963, 5.811008407999409, 4.825356554379403, 3.890766565521609, 3.026874218970704, 1.965154036028948, 0.993742835314792, 2.060072846729407, 2.9786262483466732, 3.878805781686952, 4.9047108018364245, 5.841276012333827, 6.89272565760839, 6.922204981213638, 7.897790477395427, 8.961354817291541, 9.99970766730545, 9.02343541545138, 8.007445582801271, 6.935030659742862, 5.919729339110906, 4.961573274736217, 3.9478843984847334, 2.9420992082999096, 1.9763182045123793, 1.0458376660819133, 0.0, 1.0078167802996505, 1.9865264388037085, 2.945971752169706, 4.019436078430195, 4.9848967128637875, 5.990250649257605, 7.876526781792878, 8.867194364691635, 9.814805063596769, 10.826484580722253, 9.812194915319198, 8.844455626592225, 7.857795568024945, 6.866238121551007, 5.903389164964482, 4.964532044331796, 3.9341246370136487, 2.978446167766661, 1.9779320019438988, 1.0681602295803485, 1.9780666228364572, 2.92016013813281, 3.86748472803147, 4.799342408309994, 5.82459792831836, 6.815854240061808, 8.805126837897035, 9.801257663269341, 10.767759450713715, 11.784012020809104, 10.843582748686096, 9.826498689291867, 8.862429823220452, 7.9060074451308955, 6.880335112763054, 5.915632115975468, 4.919986110833062, 3.8802599184260362, 2.9205966409312913, 2.0622584224176377, 2.9936685253860436, 3.857326229760842, 4.861974754848363, 5.801566460105324, 6.838535397477266, 7.776406452142505, 9.767238840757734, 10.710212792131621, 11.75686489949077, 12.712608354845637, 11.729217268689604, 10.733031011744584, 9.658445975617292, 8.723039767390446, 7.753238075477148, 6.817842563233214, 5.86452497096546, 4.8816759011820094, 3.933932865460995, 3.0198574449491025, 3.9823705205476974, 4.843257607945201, 5.917229833478443, 6.753260701768564, 7.708177618911686, 8.696096860667641, 10.732633282627408, 11.682795032010413, 12.663767894073185, 13.55003400899185, 12.608135529218615, 11.541907805095402, 10.596263179331531, 9.649309048489167, 8.732397824771864, 7.840676237892099, 6.813831428930075, 5.893037479267925, 4.961889481161662, 4.066256321921347, 4.934535547141742, 5.802961198667437, 6.8586155378788725, 7.797098005861707, 8.737947556255953, 9.70774507605946, 11.67451944070271, 12.652290418826906, 13.60167522569782, 14.507011718647671, 13.573739457699258, 12.586185553972054, 11.616775428064937, 10.62949803060032, 9.775108876412036, 8.785509168780239, 7.789214952456258, 6.91853806247259, 5.91629283918799, 5.0479323793135915, 5.950618877754443, 6.77573503786661, 7.73403349874123, 8.718580910975044, 9.742161682379056, 10.640207287639715, 12.600668251846399, 13.588111361510556, 14.517725184230235, 15.438309032849617, 14.593521565400806, 13.598785571124585, 12.625131717435572, 11.699202471725611, 10.782922811254949, 9.838990816135112, 8.79726791145749, 7.944415947836179, 6.891221449856234, 6.047058979043468, 6.9795235376191975, 7.71923357784, 8.665346554851494, 9.63559313819825, 10.600579204814474, 11.626495779052252, 13.542356282344395, 14.503586031905009, 15.457182127501854, 15.485948214858636, 14.791694212710636, 13.914183177291303, 13.000600115211922, 12.711176471904881, 11.735622274202715, 10.822886063262628, 9.839466694002493, 8.831693598725856, 7.884292173748494, 7.0892214571284144, 7.918321534016394, 8.65676036719986, 9.631485746359328, 10.624043251066121, 11.608279985268098, 12.550973576197944, 14.488205549891667, 15.446238930431594, 15.485040770814209, 14.523249128041924, 13.854254188702697, 12.878732197478683, 11.927223636417576, 12.822920415478626, 12.668607878543922, 11.757988582884126, 10.78056994085489, 9.781294546261886, 8.843293848491832, 8.119491664418431, 8.870173921853407, 9.637341468115542, 10.61117199344098, 11.553661409466152, 12.540008570337406, 13.589255728599124, 15.392601753640164, 15.57055256610049, 14.588489995469436, 13.597479149077076, 12.813808142603055, 11.848424767620715, 10.877969887576404, 11.860591256998097, 12.730612544436891, 12.661406343058696, 11.73605622282498, 10.80674404960148, 9.773984453739507, 9.114267030150375, 9.885220626874581, 10.574936883004577, 11.634528882212718, 12.625056618746695, 13.492763884350065, 14.426903948596381, 15.524432270797153, 14.6457575641906, 13.62333327120877, 12.6395463416776, 11.753928283206816, 10.898883233032068, 9.919188956308616, 10.901202903743533, 11.748299676251595, 12.786297327068429, 12.67370846183674, 11.769426861166814, 10.811898033596485, 10.145460033681468, 10.918370946673049, 11.566658760131201, 12.571522365445837, 13.643860318602766, 14.507073354525403, 15.358465178363165, 14.545968001701503, 13.599094716303368, 12.623053709478079, 11.707362243318583, 10.730151245561204, 9.884709046245133, 8.928407858375587, 9.944883105780582, 10.804489013040813, 11.79253182282396, 12.630590508121466, 12.78905587591209, 11.860486658449496, 11.093388067732656, 11.942116840932446, 12.615837279851004, 13.531715096755056, 14.496387734511043, 15.457191185453983, 15.488801125470092, 13.574720294714563, 12.604916597349675, 11.643740564620394, 10.706825384636943, 9.796214980509562, 8.947083722322827, 7.9758648744561595, 8.930888606167274, 9.788778477911974, 10.7718056014047, 11.658508630207855, 12.63433536426851, 12.85531964865898, 12.151412086905422, 12.934856878984833, 13.551366143602893, 14.493957050342296, 15.474560560395648, 15.489607971885487, 14.538909662603283, 12.546967300039713, 11.754573510901203, 10.76632924428738, 9.774133672469745, 8.828623507107677, 7.8775935510637165, 6.968238286454384, 7.999494713234322, 8.793295384700947, 9.841105185870685, 10.713925481330849, 11.6708797412557, 12.707573594743902, 13.166668884394724, 13.960088487172401, 14.580344935889979, 15.460601785299597, 15.43292199799696, 14.420431157340031, 13.566504533736481], [11.517715127147548, 12.466435458183525, 13.459777793727515, 14.419569947269085, 14.585949737990848, 13.911313722761504, 13.588520547246949, 12.71376987895746, 11.703573845410144, 10.723145379967551, 9.815022690008279, 8.78953630526831, 7.980398108183086, 6.990405209540983, 6.04822545755898, 7.0192612848156415, 7.8146561915764705, 8.713955063759537, 9.68878450606506, 10.533419676739115, 10.54531547915011, 11.49039957350337, 12.468856780296552, 13.527394641393183, 14.462548046118483, 13.664764012949865, 12.648627343169013, 11.713401611614321, 10.72665460498186, 9.730991677052302, 8.776886419043521, 7.847253409642257, 6.938767785155819, 6.038467929071379, 5.121260064746243, 5.956993575723004, 6.742542592910502, 7.770208272934223, 8.755988374542394, 9.60472537294623, 9.624526848754684, 10.591350229669391, 11.627179512907865, 12.50840096993609, 13.507337528835697, 12.67642556645056, 11.627211852932543, 10.721056610460526, 9.751230294821955, 8.798401348263887, 7.889162369833328, 6.909753963712938, 5.917207869498785, 5.016349681594712, 4.102029107499006, 4.906017951094794, 5.760597175300758, 6.799930002359208, 7.763944877075643, 8.666958822134541, 8.591533002132266, 9.629941154830243, 10.59607918157173, 11.545890345943803, 12.554387632771029, 11.652782574221327, 10.669775276345668, 9.747104255603846, 8.790932064310278, 7.844834997406295, 6.885344451009519, 5.897390259234497, 4.95030306984588, 3.969489472627068, 3.1577229459866203, 3.8910151323893345, 4.806930959034626, 5.745060581024177, 6.742596910239509, 7.680104749974702, 7.646509701866761, 8.678193901160757, 9.646036475215084, 10.685719176094388, 11.582422177126254, 10.648774248417702, 9.659722603142681, 8.71698668951986, 7.8290438572011665, 6.810840659101051, 5.944116972808433, 4.967298504746703, 3.9743304503690378, 3.042881134868529, 2.087594071312277, 2.929430896884249, 3.826717537863639, 4.85370339215407, 5.768017944558187, 6.708609097838573, 6.815536988019659, 7.770742989516389, 8.762150003119642, 9.790075204618317, 10.802920082232397, 9.865313022517201, 8.825053195668243, 7.791738048734613, 6.8188251882990585, 5.833173334679053, 4.898583345821258, 4.034690999270354, 2.9729708163285986, 2.0015596156144424, 1.0581361945244, 1.9708094680470227, 2.8709890013873016, 3.8968940215367747, 4.833459232034177, 5.884908877308741, 5.914388200913987, 6.889973697095776, 7.95353803699189, 9.017234245059347, 9.993506496913419, 9.015262363100922, 7.942847440042513, 6.927546119410556, 5.969390055035867, 4.955701178784383, 3.9499159885995594, 2.9841349848120293, 2.0536544463815636, 1.0078167802996505, 0.0, 0.9787096585040579, 1.9381549718700557, 3.011619298130544, 3.977079932564137, 4.982433868957954, 6.868710001493227, 7.859377584391983, 8.806988283297116, 9.8186678004226, 10.820011695618847, 9.852272406891874, 8.865612348324595, 7.874054901850656, 6.911205945264132, 5.972348824631446, 4.941941417313299, 3.986262948066311, 2.985748782243549, 1.9545249169289423, 0.9702498425368066, 1.9123433578331597, 2.859667947731819, 3.7915256280103433, 4.816781148018709, 5.808037459762157, 7.797310057597384, 8.79344088296969, 9.759942670414063, 10.776195240509452, 11.802936428539786, 10.834315469591516, 9.870246603520103, 8.913824225430547, 7.888151893062704, 6.923448896275119, 5.927802891132712, 4.888076698725687, 3.9284134212309416, 2.939460468076172, 1.9858517450863933, 2.8495094494611917, 3.854157974548713, 4.793749679805673, 5.830718617177615, 6.768589671842855, 8.759422060458084, 9.70239601183197, 10.74904811919112, 11.74539524800418, 12.690547012717916, 11.694360755772896, 10.619775719645604, 9.684369511418758, 8.71456781950546, 7.7791723072615255, 6.825854714993772, 5.843005645210322, 4.830612335377198, 3.897059490607637, 2.974553740248047, 3.835440827645551, 4.909413053178792, 5.7454439214689135, 6.700360838612036, 7.68828008036799, 9.724816502327757, 10.674978251710762, 11.655951113773535, 12.663737560245577, 13.569465273246927, 12.503237549123714, 11.557592923359843, 10.610638792517479, 9.693727568800176, 8.802005981920411, 7.775161172958387, 6.730036594127204, 5.79888859602094, 4.851919210245556, 3.9267187668420913, 4.795144418367786, 5.850798757579222, 6.789281225562056, 7.730130775956303, 8.69992829575981, 10.666702660403057, 11.644473638527256, 12.593858445398169, 13.553541218693324, 14.48681347964174, 13.547515298000366, 12.578105172093249, 11.590827774628632, 10.736438620440348, 9.741581198200945, 8.745286981876966, 7.755537177331868, 6.753291954047268, 5.833595267637801, 4.942802097454792, 5.76791825756696, 6.726216718441579, 7.710764130675393, 8.734344902079405, 9.632390507340064, 11.592851471546748, 12.580294581210905, 13.509908403930584, 14.484838532895271, 14.874826028836768, 14.180438944370712, 13.586461461463884, 12.660532215753923, 11.74425255528326, 10.795062845555819, 9.753339940878199, 8.781415062695457, 7.728220564715512, 6.8327218673676775, 5.971706757319547, 6.711416797540349, 7.657529774551843, 8.627776357898599, 9.592762424514824, 10.618678998752602, 12.534539502044744, 13.495769251605358, 14.449365347202203, 14.478131434558986, 13.939630345399712, 13.219276302831503, 14.008416895511573, 13.672506215933193, 12.638797991197798, 11.661669191615738, 10.678249822355603, 9.668692713585134, 8.721291288607773, 7.874884345452624, 6.910504753716744, 7.6489435869002085, 8.623668966059677, 9.61622647076647, 10.600463204968447, 11.543156795898293, 13.480388769592015, 14.438422150131942, 14.477223990514558, 13.515432347742273, 13.002190321391772, 12.183825323018885, 12.935040416717227, 13.830737195778276, 13.560301157045147, 12.596771711237237, 11.617569055714169, 10.618293661121164, 9.680292963351112, 8.90515455274264, 7.8623571415537565, 8.62952468781589, 9.603355213141327, 10.5458446291665, 11.532191790037754, 12.581438948299471, 14.384784973340512, 14.56273578580084, 13.580673215169785, 12.589662368777425, 11.96174427529213, 11.153517893160917, 11.885786667876054, 12.868408037297748, 13.738429324736542, 13.498405457917974, 12.573055337684258, 11.64374316446076, 10.610983568598787, 9.899929918474584, 8.87740384657493, 9.567120102704925, 10.626712101913066, 11.617239838447043, 12.484947104050413, 13.419087168296729, 14.5166154904975, 13.637940783890947, 12.615516490909119, 11.631729561377949, 10.901864415895892, 10.20397635857227, 10.927005736608267, 11.909019684043184, 12.756116456551245, 13.794114107368081, 13.510707576696019, 12.606425976026093, 11.648897148455765, 10.924106038136426, 9.910554166373398, 10.558841979831548, 11.563705585146185, 12.636043538303113, 13.49925657422575, 14.350648398063512, 13.53815122140185, 12.591277936003715, 11.615236929178426, 10.699545463018932, 9.87808737825028, 9.152287500387057, 9.936224638675238, 10.952699886080232, 11.812305793340464, 12.800348603123611, 13.638407288421117, 13.62605499077137, 12.697485773308776, 11.872034072187613, 10.934300060632797, 11.608020499551351, 12.523898316455403, 13.48857095421139, 14.44937440515433, 14.480984345170443, 12.566903514414914, 11.597099817050022, 10.635923784320742, 9.699008604337292, 8.944151113198638, 8.095019855011902, 8.98368165475581, 9.938705386466923, 10.796595258211624, 11.779622381704351, 12.666325410507506, 13.642152144568163, 13.69231876351826, 12.93005809136038, 11.927040098685184, 12.54354936330324, 13.486140270042643, 14.466743780095996, 14.481791191585836, 13.531092882303634, 11.539150519740064, 10.746756730601554, 9.75851246398773, 8.766316892170094, 7.976559639796752, 7.025529683752793, 7.976055066754034, 9.007311493533972, 9.801112165000598, 10.848921966170336, 11.7217422616305, 12.678696521555352, 13.715390375043551, 13.937293380922892, 12.952271706872752, 13.572528155590327, 14.452785004999944, 14.42510521769731, 13.41261437704038, 12.558687753436832], [10.53900546864349, 11.487725799679467, 12.481068135223456, 13.440860288765027, 13.689586850937191, 14.66898324772389, 14.567230205751008, 13.69247953746152, 12.682283503914203, 11.70185503847161, 10.793732348512338, 9.768245963772369, 8.81477541007111, 7.8247825114290075, 6.86818298057443, 6.043857675991394, 6.835946533072412, 7.735245405255478, 8.710074847561001, 9.554710018235056, 9.566605820646052, 10.51168991499931, 11.490147121792493, 12.548684982889124, 13.483838387614425, 14.461051600565227, 13.627337001673071, 12.69211127011838, 11.705364263485919, 10.70970133555636, 9.75559607754758, 8.825963068146315, 7.8651304321109645, 6.91710476785789, 5.9412175877616935, 4.978283917218947, 5.763832934406444, 6.791498614430164, 7.777278716038335, 8.626015714442172, 8.645817190250625, 9.612640571165333, 10.648469854403807, 11.529691311432032, 12.528627870331638, 13.527097488355649, 12.605921511436602, 11.699766268964584, 10.729939953326014, 9.777111006767946, 8.867872028337386, 7.888463622216995, 6.843570516453931, 5.894986520381224, 4.921986630514456, 3.927308292590737, 4.781887516796699, 5.821220343855149, 6.785235218571584, 7.688249163630482, 7.612823343628207, 8.651231496326185, 9.617369523067671, 10.567180687439745, 11.57567797426697, 12.608872638565785, 11.648484934849726, 10.725813914107905, 9.769641722814336, 8.823544655910354, 7.864054109513576, 6.876099917738554, 5.929012728349937, 4.897568817261552, 3.9776804690020704, 2.9123054738852767, 3.8282213005305676, 4.766350922520118, 5.763887251735451, 6.701395091470643, 6.6678000433627025, 7.699484242656698, 8.667326816711025, 9.707009517590329, 10.671216384053608, 11.60486431276216, 10.63843226164674, 9.695696348023919, 8.807753515705226, 7.7895503176051095, 6.92282663131249, 5.9460081632507595, 4.953040108873095, 3.9709604795030136, 2.9075515943277277, 1.950721238380191, 2.8480078793595807, 3.874993733650012, 4.789308286054128, 5.729899439334514, 5.8368273295156, 6.79203333101233, 7.783440344615582, 8.811365546114258, 9.840140757592767, 10.777747817307963, 9.803762854172302, 8.770447707238672, 7.797534846803117, 6.8118829931831115, 5.877293004325317, 5.013400657774413, 3.9516804748326564, 2.9802692741185006, 2.036845853028458, 0.9920998095429648, 1.8922793428832434, 2.9181843630327164, 3.854749573530119, 4.906199218804682, 4.93567854240993, 5.911264038591719, 6.9748283784878335, 8.03852458655529, 9.014796838409364, 9.99397202160498, 8.921557098546572, 7.906255777914614, 6.948099713539926, 5.934410837288442, 4.928625647103618, 3.962844643316088, 3.032364104885622, 1.9865264388037085, 0.9787096585040579, 0.0, 0.9594453133659978, 2.0329096396264856, 2.9983702740600786, 4.003724210453896, 5.902884855708072, 6.893552438606828, 7.841163137511961, 8.852842654637445, 9.873599695165423, 10.830982065395933, 9.844322006828653, 8.852764560354714, 7.88991560376819, 6.951058483135505, 5.920651075817357, 4.964972606570369, 3.9644584407476073, 2.9332345754330005, 1.9489595010408645, 1.015980470779502, 1.923377631188417, 2.855235311466941, 3.8804908314753073, 4.871747143218755, 6.831484911812229, 7.827615737184535, 8.794117524628907, 9.810370094724297, 10.83711128275463, 11.813025128095575, 10.848956262024162, 9.892533883934604, 8.866861551566762, 7.9021585547791755, 6.906512549636769, 5.866786357229744, 4.907123079734999, 3.8444946907160964, 2.8908859677263177, 1.9531465624075337, 2.925993680783724, 3.857459363262271, 4.894428300634212, 5.832299355299453, 7.82313174391468, 8.766105695288568, 9.812757802647717, 10.779570102219022, 11.762961188375055, 12.599394978412821, 11.524809942285529, 10.589403734058683, 9.619602042145385, 8.68420652990145, 7.730888937633697, 6.748039867850247, 5.735646558017123, 4.802093713247562, 3.8795879628879715, 2.939077940591893, 3.9821963856643454, 4.809153604925511, 5.764070522068633, 6.751989763824588, 8.788526185784354, 9.73868793516736, 10.719660797230132, 11.727447243702175, 12.66934572347541, 13.408271771763639, 12.462627145999768, 11.515673015157404, 10.5987617914401, 9.707040204560336, 8.68019539559831, 7.635070816767128, 6.703922818660865, 5.756953432885481, 4.831752989482016, 3.8987815313141287, 4.954435870525565, 5.879768058432569, 6.7938404594129, 7.763637979216407, 9.730412343859655, 10.708183321983853, 11.657568128854766, 12.617250902149921, 13.550523163098337, 14.45254952064029, 13.483139394733174, 12.495861997268557, 11.641472843080273, 10.64661542084087, 9.65032120451689, 8.660571399971792, 7.658326176687193, 6.7386294902777255, 5.847836320094717, 4.871555370513303, 5.829853831387922, 6.814401243621736, 7.8187943832324995, 8.696100190796662, 10.656561155003345, 11.644004264667503, 12.573618087387182, 13.548548216351868, 13.89942242001252, 14.885959255198431, 14.491495684103809, 13.565566438393848, 12.649286777923185, 11.700097068195744, 10.658374163518122, 9.686449285335382, 8.633254787355437, 7.737756090007602, 6.838972148412711, 5.815053910486692, 6.761166887498186, 7.731413470844941, 8.696399537461165, 9.682388682209199, 11.612366792348604, 12.573596541909218, 13.5130750306588, 13.499421776054927, 12.964226736575464, 13.924796613659222, 14.83336911771491, 14.577540438573118, 13.543832213837721, 12.566703414255661, 11.583284044995526, 10.573726936225059, 9.626325511247698, 8.67659204565132, 7.69259837582922, 6.752580699846551, 7.727306079006021, 8.719863583712812, 9.704100317914788, 10.620984086202153, 12.558216059895877, 13.516249440435804, 13.4985143320105, 12.536722689238214, 12.026786712567525, 12.889345633846604, 13.759992638920563, 14.655689417981613, 14.46533537968507, 13.50180593387716, 12.522603278354094, 11.52332788376109, 10.585327185991037, 9.69443314490731, 8.644450763666233, 7.7331618007622325, 8.706992326087672, 9.649481742112844, 10.635828902984098, 11.661651441595032, 13.488422086286857, 13.58402612729678, 12.601963556665726, 11.610952710273367, 10.986340666467882, 11.859038203988636, 12.71073889007939, 13.693360259501084, 14.660782939900008, 14.403439680557899, 13.478089560324182, 12.548777387100685, 11.516017791238712, 10.689208510639252, 9.659497468687407, 8.670757215651268, 9.73034921485941, 10.720876951393388, 11.588584216996757, 12.522724281243073, 13.537905831993442, 12.659231125386889, 11.63680683240506, 10.65301990287389, 9.926460807071644, 10.909496669399989, 11.751957958811603, 12.73397190624652, 13.688393107162794, 14.72639075797963, 14.415741799335944, 13.511460198666018, 12.55393137109569, 11.706199660248902, 10.692647788485875, 9.662479092777891, 10.667342698092526, 11.739680651249458, 12.602893687172095, 13.454285511009857, 12.559441562897792, 11.612568277499657, 10.636527270674367, 9.720835804514874, 8.902683769426032, 9.857807811214776, 10.761176860878575, 11.777652108283569, 12.765512533774421, 13.753555343557569, 14.617116946925176, 14.523145268419878, 13.594576050957283, 12.65412769430009, 11.706618411020857, 10.711657612497694, 11.627535429401744, 12.592208067157731, 13.553011518100671, 13.502274686666384, 11.588193855910855, 10.618390158545964, 9.657214125816683, 8.720298945833234, 7.96874750437439, 8.914977378027352, 9.808633876959147, 10.763657608670261, 11.749801998645582, 12.732829122138309, 13.645035069011564, 14.620861803072222, 14.589409041166768, 13.712151713472856, 12.68470962364757, 11.647186476249583, 12.589777382988984, 13.570380893042337, 13.503081533081778, 12.552383223799575, 10.560440861236005, 9.768047072097495, 8.779802805483671, 7.787607233666035, 7.0011560309725045, 7.845487206768243, 8.801007288957372, 9.832263715737309, 10.779821823504657, 11.827631624674394, 12.700451920134558, 13.65740618005941, 14.69410003354761, 14.694962905885276, 13.709941231835138, 12.67616526853667, 13.556422117946285, 13.44639555919325, 12.433904718536322, 11.579978094932773], [9.579560155277493, 10.52828048631347, 11.52162282185746, 12.48141497539903, 13.511971810230584, 14.516670125319434, 15.50252537992524, 14.645983673962357, 13.63578764041504, 12.625259795696403, 11.637693958759153, 10.611218368473, 9.647275695832606, 8.657282797190504, 7.700683266335926, 6.832921750958125, 5.876501219706414, 6.775800091889481, 7.7506295341950056, 8.59526470486906, 8.607160507280055, 9.552244601633314, 10.530701808426496, 11.589239669523128, 12.524393074248428, 13.50160628719923, 14.562632175847304, 13.645615406619218, 12.658868399986757, 11.637752370791207, 10.683647112782426, 9.754014103381161, 8.78063859488075, 7.812239310217823, 6.77371787352319, 5.7673479921856785, 4.804387621040446, 5.8320533010641675, 6.817833402672338, 7.666570401076175, 7.686371876884627, 8.653195257799336, 9.68902454103781, 10.570245998066035, 11.569182556965641, 12.567652174989652, 13.565366824802599, 12.659211582330581, 11.68938526669201, 10.736556320133943, 9.795923063572232, 8.816514657451842, 7.759078679223717, 6.81049468315101, 5.837494793284242, 4.8428164553605235, 3.8224422034307013, 4.861775030489151, 5.825789905205587, 6.728803850264485, 6.6533780302622105, 7.691786182960188, 8.657924209701674, 9.607735374073748, 10.616232660900973, 11.649427325199788, 12.607930248215723, 11.685259227473901, 10.729087036180333, 9.78298996927635, 8.822307070064264, 7.821816597480244, 6.858185548816852, 5.813076980031338, 4.8931886317718565, 3.827813636655063, 2.86877598716457, 3.8069056091541205, 4.804441938369453, 5.741949778104646, 5.708354729996706, 6.7400389292907015, 7.707881503345028, 8.747564204224332, 9.711771070687611, 10.645418999396163, 11.597877575012737, 10.655141661389916, 9.767198829071223, 8.748995630971107, 7.881079591863177, 6.904261123801446, 5.911293069423782, 4.886468642272799, 3.8230597570975133, 2.866229401149977, 1.888562565993583, 2.9155484202840145, 3.829862972688131, 4.770454125968517, 4.877382016149603, 5.832588017646334, 6.823995031249585, 7.851920232748261, 8.88069544422677, 9.818302503941966, 10.763208167538298, 9.729893020604669, 8.756980160169114, 7.771328306549109, 6.836738317691315, 5.97284597114041, 4.911125788198654, 3.9397145874844983, 2.9547951662598924, 1.9076079723127506, 0.9328340295172457, 1.9587390496667187, 2.8953042601641212, 3.9467539054386847, 3.9762332290439315, 4.951818725225721, 6.015383065121835, 7.079079273189292, 8.055351525043363, 9.071341357693472, 9.881002411912569, 8.865701091280611, 7.9075450269059235, 6.89385615065444, 5.888070960469616, 4.922289956682086, 3.9918094182516195, 2.945971752169706, 1.9381549718700557, 0.9594453133659978, 0.0, 1.073464326260488, 2.038924960694081, 3.0442788970878985, 4.943439542342073, 5.934107125240829, 6.881717824145962, 7.893397341271447, 8.914154381799424, 9.881893670526397, 10.80376732019465, 9.812209873720711, 8.849360917134188, 7.910503796501502, 6.859899941137232, 5.904221471890244, 4.903707306067481, 3.8376254974095674, 2.8533504230174316, 1.9112569077210786, 0.9639323178224191, 1.895789998100943, 2.9210455181093087, 3.9123018298527565, 5.87203959844623, 6.868170423818537, 7.834672211262909, 8.850924781358298, 9.877665969388632, 10.863936733226039, 11.780146379816708, 10.788910312998958, 9.763237980631116, 8.79853498384353, 7.802888978701123, 6.763162786294098, 5.803499508799353, 4.739771127657673, 3.7861624046678943, 2.8484229993491104, 1.9665483674177262, 2.8980140498962728, 3.934982987268214, 4.872854041933454, 6.863686430548682, 7.806660381922569, 8.853312489281718, 9.820124788853025, 10.803515875009058, 11.799702131954078, 12.420086379227106, 11.48468017100026, 10.514878479086962, 9.579482966843027, 8.626165374575274, 7.643316304791824, 6.630922994958699, 5.697370150189138, 4.774864399829548, 3.8343543775334696, 3.0227510722983473, 3.849708291559513, 4.804625208702635, 5.79254445045859, 7.829080872418357, 8.779242621801362, 9.760215483864135, 10.768001930336178, 11.709900410109412, 12.755640760298824, 13.357903582941345, 12.410949452098981, 11.494038228381678, 10.602316641501913, 9.575471832539888, 8.530347253708705, 7.599199255602441, 6.652229869827057, 5.727029426423592, 4.794057968255705, 4.041896023005512, 4.920322745066571, 5.834395146046902, 6.80419266585041, 8.770967030493658, 9.748738008617856, 10.69812281548877, 11.657805588783924, 12.59107784973234, 13.578631753459543, 14.37841583167475, 13.391138434210134, 12.53674928002185, 11.541891857782447, 10.545597641458468, 9.555847836913369, 8.553602613628769, 7.633905927219302, 6.743112757036293, 5.76683180745488, 5.0401414977661645, 5.921130941749626, 6.859349069866502, 7.736654877430665, 9.697115841637348, 10.684558951301506, 11.614172774021185, 12.589102902985871, 13.566796955796907, 14.561532950073127, 15.386772121045386, 14.460842875335425, 13.544563214864763, 12.59537350513732, 11.5536506004597, 10.581725722276959, 9.528531224297014, 8.63303252694918, 7.734248585354288, 6.710330347428269, 6.091862223292738, 6.891455320040882, 7.8564413866571075, 8.722943368843202, 10.652921478982607, 11.614151228543221, 12.553629717292804, 12.539976462688928, 13.529307939183829, 14.593717254545254, 15.629764044075946, 15.472816875514695, 14.4391086507793, 13.46197985119724, 12.478560481937105, 11.469003373166636, 10.521601948189275, 9.571868482592897, 8.587874812770798, 7.6478571367881285, 7.0580014148005725, 7.879905432908753, 8.864142167110732, 9.661538772836156, 11.59877074652988, 12.556804127069807, 12.5390690186445, 11.577277375872216, 12.637069778029625, 13.642995849335668, 14.59249292468206, 15.48818970374311, 15.36061181662665, 14.397082370818739, 13.41787971529567, 12.418604320702666, 11.480603622932614, 10.589709581848886, 9.53972720060781, 8.62843823770381, 8.037687661882224, 8.862555791216396, 9.833397780566319, 10.702206128229035, 12.624119233787688, 12.624580813930782, 11.642518243299728, 10.651507396907368, 11.702485065062502, 12.641831013058809, 13.543239175840888, 14.525860545262582, 15.493283225661505, 15.298716117499476, 14.37336599726576, 13.444053824042262, 12.411294228180289, 11.58448494758083, 10.554773905628984, 9.566033652592845, 9.061044550653962, 9.93395100049694, 10.786153094578978, 11.720293158825294, 12.578460518627445, 11.699785812020892, 10.677361519039062, 9.693574589507891, 10.693332998969336, 11.692289478470162, 12.584458244573101, 13.566472192008018, 14.520893392924291, 15.558891043741127, 15.311018236277521, 14.406736635607595, 13.449207808037267, 12.601476097190481, 11.587924225427452, 10.557755529719469, 10.024068440492972, 10.95275470035301, 11.800462564754316, 12.651854388592078, 11.599996249531795, 10.65312296413366, 9.67708195730837, 8.761390491148875, 9.691747844392763, 10.646871886181508, 11.593677146640072, 12.610152394045066, 13.598012819535917, 14.586055629319064, 15.474742864519758, 15.418421705361457, 14.489852487898862, 13.549404131241669, 12.601894847962434, 11.606934049439271, 10.98426117180219, 11.932771101777247, 12.766147777490497, 12.542829373300387, 10.628748542544859, 9.658944845179967, 8.697768812450686, 7.760853632467235, 8.757811579341121, 9.74747766378885, 10.641134162720643, 11.596157894431757, 12.582302284407078, 13.565329407899805, 14.502660986606147, 15.544266560297013, 15.484685478108347, 14.607428150414435, 13.579986060589148, 12.54246291319116, 11.94650312538943, 12.910943927661853, 12.543636219715781, 11.592937910433578, 9.600995547870008, 8.808601758731498, 7.820357492117673, 6.828161920300038, 7.790220105939236, 8.67798749252974, 9.633507574718868, 10.664764001498806, 11.622794228205288, 12.67159323492121, 13.62385667735935, 14.580810937284202, 15.628235516939691, 15.590239342826855, 14.605217668776715, 13.571441705478247, 12.913147860346731, 12.486950245827254, 11.474459405170325, 10.620532781566776], [8.575298858067526, 9.524019189103504, 10.517361524647493, 11.477153678189064, 12.4977528259063, 13.50245114099515, 14.488306395600956, 15.48400719042085, 14.66347849469383, 13.638759449350369, 12.651193612413119, 11.624718022126967, 10.660775349486572, 9.67078245084447, 8.714182919989893, 7.846421404612092, 6.890000873360381, 5.913040501564346, 6.802516233759428, 7.591003407659091, 7.602899210070088, 8.547983304423347, 9.52644051121653, 10.575020685198844, 11.510174089924144, 12.487387302874946, 13.54841319152302, 14.483638923077711, 13.686559254265546, 12.665443225069996, 11.711337967061215, 10.78170495765995, 9.807015440236542, 8.82573896387179, 7.787217527177157, 6.780847645839645, 5.817887274694413, 4.9692937107390325, 5.86972010223676, 6.662309103866208, 6.662252690864471, 7.629076071779179, 8.664905355017654, 9.546126812045879, 10.545063370945485, 11.543532988969496, 12.566364218876288, 13.584404563589016, 12.762849592952497, 11.81002064639443, 10.823613917851022, 9.844205511730632, 8.786769533502506, 7.838185537429798, 6.865185647563031, 5.870507309639311, 4.835941857084668, 3.9990154401640163, 4.877676604770009, 5.724542553054517, 5.629258844242054, 6.6676669969400315, 7.633805023681519, 8.583616188053592, 9.592113474880817, 10.625308139179634, 11.60892764228941, 12.583742262029123, 11.80255136244082, 10.856454295536837, 9.849997924343052, 8.849507451759033, 7.885876403095641, 6.840767834310127, 5.920879486050645, 4.855504490933852, 3.8822756408185364, 2.944146018828986, 3.8257287455445836, 4.737688480894678, 4.684235543976549, 5.715919743270545, 6.683762317324872, 7.723445018204176, 8.687651884667455, 9.621299813376007, 10.610351458651028, 11.553087372273849, 10.84066315533171, 9.822459957231594, 8.908770446141965, 7.931951978080235, 6.938983923702571, 5.914159496551588, 4.850750611376302, 3.8939202554287657, 2.916253420272372, 1.9826807980785326, 2.805743786667974, 3.7463349399483605, 3.853262830129446, 4.808468831626176, 5.799875845229428, 6.827801046728103, 7.856576258206613, 8.794183317921808, 9.834443144770766, 10.803357346865155, 9.8304444864296, 8.844792632809595, 7.910202643951801, 7.046310297400897, 5.984590114459142, 5.013178913744985, 3.9824860205386816, 2.9352988265915396, 1.9605248837960347, 0.9346198636465617, 1.8711850741439644, 2.922634719418528, 2.9027689027834436, 3.8783543989652327, 4.941918738861347, 6.005614946928803, 6.981887198782876, 7.997877031432984, 9.070291954491394, 9.939165417541098, 8.98100935316641, 7.967320476914926, 6.961535286730102, 5.995754282942572, 5.0652737445121065, 4.019436078430194, 3.0116192981305434, 2.0329096396264856, 1.073464326260488, 0.0, 0.965460634433593, 1.9708145708274103, 3.8699752160815857, 4.860642798980342, 5.808253497885475, 6.819933015010959, 7.8406900555389365, 8.808429344265909, 9.795089402833188, 10.786646849307127, 9.799851531090784, 8.832649061548244, 7.773046852311226, 6.817368383064238, 5.8168542172414766, 4.750772408583563, 3.7664973341914267, 2.8244038188950737, 1.8770792289964142, 0.9452215487178902, 1.9051797994793678, 2.896436111222816, 4.798575272185743, 5.794706097558049, 6.761207885002421, 7.777460455097811, 8.804201643128145, 9.79047240696555, 10.799723658028697, 11.702057224172952, 10.67638489180511, 9.711681895017524, 8.716035889875117, 7.676309697468092, 6.7166464199733475, 5.652918038831667, 4.699309315841889, 3.7615699105231055, 2.879695278591721, 1.9474456005132201, 2.9465509627084674, 3.8569883233035136, 5.805067316895855, 6.748041268269741, 7.79469337562889, 8.746660462592537, 9.73005154874857, 10.72623780569359, 11.732937205947453, 12.397827082174254, 11.428025390260956, 10.492629878017022, 9.539312285749268, 8.556463215965818, 7.544069906132694, 6.610517061363132, 5.688011311003542, 4.747501288707465, 3.9136619829196624, 2.8991398421764605, 3.854056759319583, 4.841976001075538, 6.771698742092291, 7.7218604914752955, 8.702833353538068, 9.710619800010111, 10.652518279783346, 11.682176434038336, 12.627821059802207, 13.324096363272975, 12.407185139555672, 11.515463552675907, 10.488618743713882, 9.443494164882699, 8.512346166776435, 7.565376781001051, 6.640176337597587, 5.707204879429701, 4.908236763666353, 3.9697542956835186, 4.88382669666385, 5.853624216467358, 7.726271836443751, 8.69135587829179, 9.640740685162703, 10.600423458457858, 11.533695719406271, 12.521249623133475, 13.490659749040592, 14.304285345384129, 13.449896191195844, 12.455038768956442, 11.458744552632462, 10.468994748087363, 9.466749524802763, 8.547052838393295, 7.6562596682102875, 6.679978718628874, 5.906482238427005, 4.970562492366573, 5.90878062048345, 6.7860864280476125, 8.733472626602467, 9.62717682097544, 10.556790643695118, 11.531720772659803, 12.509414825470838, 13.504150819747059, 14.477804673436072, 15.37398978650942, 14.457710126038757, 13.508520416311315, 12.466797511633693, 11.494872633450953, 10.441678135471008, 9.546179438123172, 8.647395496528283, 7.623477258602263, 6.911133454004585, 5.94088687065783, 6.905872937274055, 7.77237491946015, 9.702353029599555, 10.590199896469477, 11.496247586966737, 12.437987048406374, 13.427318524901274, 14.465313461286268, 15.50136025081696, 16.38596378668869, 15.352255561953292, 14.375126762371233, 13.391707393111098, 12.38215028434063, 11.43474885936327, 10.485015393766892, 9.501021723944792, 8.561004047962124, 7.877272645512419, 6.929336983525701, 7.913573717727679, 8.710970323453104, 10.648202297146828, 11.606235677686755, 12.164678680325615, 12.590777029526183, 13.650569431683593, 14.656495502989635, 15.605992578336027, 16.501689357397076, 16.27375872780064, 15.310229281992731, 14.331026626469665, 13.33175123187666, 12.393750534106609, 11.50285649302288, 10.452874111781805, 9.541585148877806, 8.854476757858516, 7.911987341833344, 8.882829331183265, 9.751637678845983, 11.673550784404636, 11.985799288016, 11.100195938929286, 11.665007050561336, 12.71598471871647, 13.655330666712777, 14.556738829494854, 15.539360198916548, 16.506782879315473, 16.21186302867347, 15.286512908439754, 14.357200735216257, 13.324441139354283, 12.497631858754824, 11.467920816802978, 10.47918056376684, 9.877833646630254, 8.983382551113888, 9.835584645195922, 10.769724709442238, 11.646554723636095, 10.920348415912347, 10.056685953114615, 10.707074243161859, 11.706832652623303, 12.70578913212413, 13.597957898227067, 14.579971845661984, 15.534393046578257, 16.572390697395093, 16.224165147451515, 15.31988354678159, 14.362354719211261, 13.514623008364474, 12.501071136601446, 11.470902440893465, 10.840857536469263, 10.002186250969958, 10.84989411537126, 11.701285939209022, 10.668090454540446, 9.873685568025117, 8.989372208477603, 9.774890144802843, 10.70524749804673, 11.660371539835474, 12.607176800294038, 13.623652047699032, 14.611512473189885, 15.599555282973032, 16.488242518173728, 16.33156861653545, 15.402999399072854, 14.462551042415662, 13.51504175913643, 12.520080960613267, 11.801050267778482, 10.982202652394195, 11.815579328107441, 11.538568076090419, 9.62448724533489, 8.879507449071424, 8.010059063619918, 8.774353286121203, 9.771311232995087, 10.760977317442817, 11.654633816374611, 12.609657548085725, 13.595801938061046, 14.578829061553773, 15.516160640260114, 16.55776621395098, 16.39783238928234, 15.520575061588428, 14.493132971763144, 13.455609824365157, 12.763292221365722, 11.9603754782788, 11.539374922505814, 10.58867661322361, 8.59673425066004, 7.8604884582959205, 6.978167960332719, 7.8416615739540045, 8.803719759593202, 9.691487146183707, 10.647007228372836, 11.678263655152772, 12.636293881859254, 13.685092888575175, 14.637356331013317, 15.594310590938168, 16.4383049584892, 15.446514830934042, 14.461493156883902, 13.40631222044744, 12.413291704899676, 11.482688948617287, 10.470198107960359, 9.616271484356808], [7.668232099632725, 8.616952430668702, 9.610294766212691, 10.570086919754262, 11.590686067471498, 12.595384382560349, 13.581239637166155, 14.57694043198605, 15.540238411703655, 14.53199258404332, 13.544426747106069, 12.517951156819917, 11.554008484179523, 10.56401558553742, 9.607416054682844, 8.739654539305043, 7.783234008053332, 6.806273636257298, 5.895449475324626, 6.6839366492242895, 6.695832451635287, 7.640916545988546, 8.619373752781728, 9.667953926764042, 10.603107331489342, 11.580320544440145, 12.641346433088218, 13.57657216464291, 14.56331917127537, 13.622710860312264, 12.668605602303483, 11.738972592902218, 10.700248574929493, 9.718972098564741, 8.680450661870108, 7.674080780532597, 6.711120409387364, 5.862526845431985, 4.962653343801959, 5.755242345431406, 5.755185932429669, 6.722009313344375, 7.75783859658285, 8.639060053611077, 9.637996612510683, 10.636466230534694, 11.659297460441486, 12.677337805154215, 13.614177418164843, 12.775481280828025, 11.789074552284616, 10.809666146164226, 9.7522301679361, 8.803646171863392, 7.830646281996624, 6.78705877684508, 5.72917499177762, 4.892248574856969, 3.9706098463352077, 4.817475794619716, 4.722192085807252, 5.760600238505228, 6.726738265246717, 7.67654942961879, 8.685046716446015, 9.718241380744832, 10.701860883854609, 11.676675503594321, 12.63284769488789, 11.821914929970433, 10.815458558776646, 9.814968086192625, 8.851337037529234, 7.80622846874372, 6.886340120484238, 5.820965125367445, 4.775508775511488, 3.8373791535219377, 2.918661987109782, 3.830621722459876, 3.7771687855417473, 4.8088529848357435, 5.77669555889007, 6.816378259769374, 7.780585126232652, 8.714233054941205, 9.703284700216226, 10.646020613839047, 11.628452099738325, 10.78792059166519, 9.874231080575559, 8.897412612513829, 7.904444558136164, 6.879620130985181, 5.816211245809895, 4.859380889862359, 3.881714054705965, 2.8759139327714847, 1.8986770282331724, 2.839268181513559, 2.9250243350231107, 3.8802303365198414, 4.871637350123093, 5.899562551621768, 6.928337763100278, 7.865944822815474, 8.906204649664433, 9.939519796598063, 10.795905120863196, 9.81025326724319, 8.875663278385396, 8.01177093183449, 6.9500507488927346, 5.978639548178578, 4.947946654972275, 3.9007594610251326, 2.925985518229628, 1.9000804980801547, 0.964118315709163, 1.9943962243121922, 1.9373082683498506, 2.9128937645316397, 3.9764581044277536, 5.04015431249521, 6.016426564349283, 7.032416396999391, 8.1048313200578, 9.120132640689757, 9.946469987600004, 8.93278111134852, 7.926995921163696, 6.961214917376166, 6.0307343789457, 4.984896712863787, 3.9770799325641364, 2.9983702740600786, 2.038924960694081, 0.965460634433593, 0.0, 1.0053539363938173, 2.9045145816479927, 3.895182164546749, 4.842792863451882, 5.854472380577366, 6.8752294211053435, 7.842968709832316, 8.829628768399596, 9.821186214873535, 10.765312165524376, 9.798109695981836, 8.738507486744819, 7.78282901749783, 6.782314851675069, 5.716233043017155, 4.73195796862502, 3.7898644533286667, 2.8425398634300074, 1.9106821831514833, 0.9397191650457748, 1.9309754767892229, 3.83311463775215, 4.829245463124456, 5.795747250568828, 6.811999820664218, 7.838741008694552, 8.825011772531958, 9.834263023595105, 10.825499090412855, 11.641845526238704, 10.677142529451118, 9.681496524308711, 8.641770331901686, 7.682107054406941, 6.618378673265261, 5.664769950275483, 4.7270305449566985, 3.8451559130253146, 2.912906234946813, 1.9810903282748744, 2.8915276888699206, 4.839606682462262, 5.782580633836148, 6.829232741195297, 7.781199828158944, 8.764590914314978, 9.760777171259997, 10.76747657151386, 11.702882779740706, 12.39348602469455, 11.458090512450616, 10.504772920182862, 9.521923850399412, 8.509530540566288, 7.575977695796726, 6.653471945437136, 5.712961923141058, 4.879122617353255, 3.8646004766100535, 2.929012751639503, 3.9169319933954574, 5.806238107658698, 6.7563998570417025, 7.737372719104474, 8.745159165576517, 9.687057645349752, 10.716715799604744, 11.662360425368615, 12.629152060839427, 13.372645773989266, 12.480924187109501, 11.454079378147476, 10.408954799316293, 9.47780680121003, 8.530837415434645, 7.6056369720311805, 6.6726655138632935, 5.873697398099946, 4.9352149301171115, 3.95878268898377, 4.928580208787277, 6.760811202010158, 7.725895243858196, 8.675280050729109, 9.634962824024264, 10.568235084972677, 11.55578898869988, 12.525199114606998, 13.582612006725281, 14.415356825629438, 13.420499403390036, 12.424205187066056, 11.434455382520957, 10.432210159236357, 9.512513472826889, 8.621720302643881, 7.645439353062468, 6.871942872860599, 5.9360231268001655, 4.983736612803369, 5.861042420367532, 7.768011992168874, 8.661716186541845, 9.591330009261524, 10.566260138226209, 11.543954191037244, 12.538690185313465, 13.512344039002478, 14.55379232251153, 15.42317076047235, 14.473981050744909, 13.432258146067287, 12.460333267884547, 11.407138769904602, 10.511640072556766, 9.612856130961877, 8.588937893035858, 7.876594088438177, 6.906347505091422, 6.052474007159933, 6.84733091178007, 8.777309021919475, 9.624739262035883, 10.530786952533143, 11.47252641397278, 12.46185789046768, 13.499852826852674, 14.535899616383366, 15.528882324752587, 16.317716196386886, 15.340587396804827, 14.357168027544692, 13.347610918774224, 12.400209493796863, 11.450476028200486, 10.466482358378386, 9.526464682395718, 8.84273327994601, 7.894797617959293, 7.0601747876135565, 7.785926315773024, 9.723158289466745, 10.66141547800511, 11.457989885844249, 12.419781528616534, 13.39929791447562, 14.405223985781662, 15.458087589951326, 16.50244220189903, 17.239219362234234, 16.275689916426323, 15.296487260903259, 14.297211866310255, 13.359211168540202, 12.468317127456475, 11.418334746215399, 10.5070457833114, 9.819937392292108, 8.877447976266936, 8.029430401069144, 8.826593671165902, 10.748506776724554, 11.078732529581199, 11.993429073622238, 12.558240185254288, 13.609217853409422, 14.548563801405729, 15.449971964187807, 16.4325933336095, 17.400016014008425, 17.177323663107064, 16.251973542873348, 15.32266136964985, 14.289901773787877, 13.463092493188418, 12.433381451236572, 11.444641198200435, 10.843294281063846, 9.94884318554748, 8.982185715081801, 9.875858701727637, 10.739487965201294, 10.013281657477545, 10.949919087807567, 11.600307377854811, 12.600065787316256, 13.599022266817082, 14.49119103292002, 15.473204980354936, 16.427626181271208, 17.465623832088042, 17.18962578188511, 16.285344181215184, 15.327815353644855, 14.480083642798068, 13.46653177103504, 12.436363075327058, 11.806318170902856, 10.958600464066501, 9.996495185257139, 10.80741993149442, 9.761023696105644, 8.966618809590315, 9.882605343170555, 10.668123279495795, 11.598480632739681, 12.553604674528426, 13.50040993498699, 14.516885182391984, 15.504745607882835, 16.492788417665984, 17.381475652866676, 17.297029250969043, 16.368460033506448, 15.428011676849255, 14.480502393570024, 13.485541595046861, 12.766510902212074, 11.92298384893626, 10.96218039799332, 10.631501317655617, 8.717420486900089, 7.972440690636622, 8.90329219831287, 9.667586420814155, 10.66454436768804, 11.654210452135768, 12.547866951067562, 13.502890682778675, 14.489035072753996, 15.472062196246723, 16.409393774953063, 17.450999348643933, 16.559646539327943, 15.554704869988543, 14.501255946621333, 13.463732799223346, 12.472869681422175, 11.608900045013993, 10.632308164071013, 9.681609854788809, 7.689667492225238, 6.953421699861119, 7.871401095025671, 8.734894708646957, 9.696952894286154, 10.584720280876658, 11.540240363065786, 12.571496789845725, 13.529527016552205, 14.578326023268126, 15.530589465706267, 16.48754372563112, 15.531238200054402, 14.53944807249924, 13.5544263984491, 12.499245462012638, 11.506224946464874, 10.575622190182486, 9.563131349525557, 8.709204725922007], [6.792799605538757, 7.7415199365747345, 8.734862272118724, 9.673884921094439, 10.656218982813952, 11.660917297902802, 12.646772552508608, 13.642473347328503, 14.605771327046108, 15.52337330545207, 14.549780683499888, 13.523305093213736, 12.559362420573342, 11.56936952193124, 10.612769991076663, 9.745008475698862, 8.769294306907714, 7.757102347758873, 6.7595323714161255, 5.808504155130322, 5.820399957541319, 6.765484051894578, 7.74394125868776, 8.733486842106496, 9.668640246831796, 10.645853459782598, 11.706879348430672, 12.642105079985363, 13.628852086617824, 14.53121960253682, 13.673959538697302, 12.744326529296037, 11.705602511323312, 10.72432603495856, 9.685804598263926, 8.679434716926416, 7.716474345781182, 6.813355556933559, 5.826736239893458, 4.879809851337439, 4.844730086117705, 5.811553467032412, 6.84139634305349, 7.704592968953531, 8.703529527853137, 9.701999145877148, 10.724830375783938, 11.742870720496667, 12.679710333507296, 13.598044027991918, 12.794428488678433, 11.815020082558043, 10.757584104329917, 9.809000108257209, 8.836000218390442, 7.792412713238898, 6.734528928171438, 5.897602511250787, 4.944644927326527, 3.9420433005257487, 3.8117362394952883, 4.850144392193265, 5.792271180589171, 6.7420823449612435, 7.750579631788469, 8.783774296087284, 9.76739379919706, 10.742208418936775, 11.698380610230343, 12.644477677134326, 11.820812495170463, 10.820322022586442, 9.856690973923051, 8.811582405137537, 7.891694056878055, 6.826319061761262, 5.780862711905306, 4.842733089915756, 3.8926970681011013, 2.955189228365909, 2.866712939229784, 3.8743859001781975, 4.842228474232524, 5.881911175111828, 6.846118041575106, 7.779765970283659, 8.76881761555868, 9.7115535291815, 10.693985015080779, 11.725484986681845, 10.879585016969376, 9.902766548907644, 8.90979849452998, 7.884974067378998, 6.821565182203712, 5.864734826256176, 4.887067991099783, 3.8812678691653026, 2.90403096462699, 1.963835687419592, 1.9196703986292933, 2.874876400126024, 3.8662834137292754, 4.894208615227951, 5.922983826706461, 6.860590886421657, 7.900850713270616, 8.934165860204246, 9.9070787206398, 10.815607203637008, 9.881017214779213, 9.017124868228308, 7.9554046852865525, 6.983993484572396, 5.953300591366092, 4.90611339741895, 3.931339454623445, 2.905434434473972, 1.9694722521029804, 0.9890422879183749, 0.9319543319560332, 1.9075398281378222, 2.9711041680339365, 4.034800376101393, 5.011072627955466, 6.027062460605574, 7.099477383663983, 8.11477870429594, 9.072934768670628, 9.938135047742337, 8.932349857557513, 7.966568853769983, 7.0360883153395175, 5.990250649257605, 4.982433868957954, 4.003724210453896, 3.0442788970878985, 1.9708145708274103, 1.0053539363938173, 0.0, 1.8991606452541752, 2.8898282281529313, 3.8374389270580647, 4.849118444183549, 5.869875484711526, 6.837614773438499, 7.824274832005779, 8.815832278479718, 9.85774446579378, 10.803463632375653, 9.743861423138636, 8.788182953891647, 7.787668788068886, 6.721586979410972, 5.737311905018837, 4.795218389722484, 3.8478937998238245, 2.9160361195453004, 1.9450731014395921, 1.008345304731929, 2.827760701358332, 3.8238915267306384, 4.790393314175011, 5.8066458842704005, 6.833387072300735, 7.819657836138141, 8.828909087201287, 9.820145154019038, 10.84581748638688, 11.682496465844935, 10.686850460702528, 9.647124268295503, 8.687460990800759, 7.623732609659078, 6.6701238866693, 5.732384481350516, 4.850509849419131, 3.91826017134063, 2.986444264668692, 1.9688975168126266, 3.8342527460684437, 4.77722669744233, 5.823878804801479, 6.775845891765127, 7.7592369779211605, 8.75542323486618, 9.762122635120043, 10.69752884334689, 11.667330535260188, 12.463444448844433, 11.51012685657668, 10.52727778679323, 9.514884476960106, 8.581331632190544, 7.658825881830953, 6.718315859534875, 5.8844765537470725, 4.86995441300387, 3.9343666880333203, 3.03436168140262, 4.80088417126488, 5.751045920647885, 6.732018782710656, 7.7398052291827, 8.681703708955935, 9.711361863210927, 10.657006488974798, 11.62379812444561, 12.646490284554904, 13.486278123503318, 12.459433314541293, 11.414308735710112, 10.483160737603848, 9.536191351828464, 8.610990908424998, 7.678019450257111, 6.879051334493762, 5.940568866510928, 4.964136625377587, 4.046009896794439, 5.75545726561634, 6.720541307464378, 7.66992611433529, 8.629608887630445, 9.56288114857886, 10.550435052306064, 11.519845178213181, 12.577258070331464, 13.641265108733926, 14.425853339783854, 13.429559123459875, 12.439809318914776, 11.437564095630176, 10.517867409220708, 9.627074239037698, 8.650793289456285, 7.877296809254414, 6.941377063193983, 5.989090549197186, 4.978472108374694, 6.762658055775056, 7.656362250148027, 8.585976072867705, 9.560906201832392, 10.538600254643427, 11.533336248919648, 12.506990102608661, 13.548438386117713, 14.585591444370598, 15.479334987138728, 14.437612082461108, 13.465687204278366, 12.412492706298421, 11.516994008950585, 10.618210067355694, 9.594291829429675, 8.881948024831994, 7.911701441485239, 7.007148676539058, 5.9647605997872315, 7.7734791681203195, 8.619385325642066, 9.525433016139324, 10.467172477578961, 11.456503954073861, 12.494498890458857, 13.53054567998955, 14.52352838835877, 15.538290907318366, 16.34594133319865, 15.362521963938512, 14.352964855168043, 13.405563430190682, 12.455829964594303, 11.471836294772203, 10.531818618789535, 9.848087216339827, 8.887043357108821, 7.846049594710031, 6.9033560037801855, 8.719328435667592, 9.656061541611292, 10.45263594945043, 11.414427592222715, 12.3939439780818, 13.399870049387843, 14.452733653557507, 15.497088265505209, 16.471276511659575, 17.281043852820147, 16.301841197297076, 15.302565802704073, 14.364565104934021, 13.473671063850292, 12.423688682609216, 11.512399719705217, 10.744141785062045, 9.801652369036873, 8.815305208165618, 7.944023359173064, 9.7446769229254, 10.614228526957362, 11.517118690846761, 12.340197571187563, 13.391175239342697, 14.365280820873098, 15.413854391160262, 16.396475760581954, 17.36389844098088, 18.18267759950088, 17.257327479267165, 16.32801530604367, 15.295255710181696, 14.468446429582235, 13.43873538763039, 12.449995134594252, 11.767498673833783, 10.829411028845037, 9.768060522178278, 8.993288389734799, 9.864055471107326, 10.877364553569045, 11.844326508952099, 12.586367676709193, 13.586126086170637, 14.585082565671463, 15.496544969313836, 16.478558916748753, 17.432980117665025, 18.47097776848186, 18.194979718278926, 17.290698117609004, 16.333169290038676, 15.485437579191885, 14.471885707428857, 13.441717011720876, 12.730522563672793, 11.744475271162978, 10.782369992353615, 9.924849619501583, 8.885591202011677, 9.830701705681815, 10.777012764315087, 11.654183578350176, 12.6038345691335, 13.558958610922245, 14.505763871380807, 15.522239118785802, 16.510099544276656, 17.498142354059805, 18.386829589260497, 17.373411024124735, 16.44484180666214, 15.504393450004946, 14.498020462838575, 13.503059664315412, 12.538909636349592, 11.711640376804631, 10.755909190893147, 9.75606882356165, 7.841987992806121, 8.836523586728122, 9.797699619457402, 10.653646719668536, 11.669898304081858, 12.659564388529587, 13.55322088746138, 14.508244619172494, 15.494389009147815, 16.477416132640542, 17.414747711346884, 16.555633027430794, 15.625179454670393, 14.620237785330994, 13.60505394796151, 12.567530800563523, 11.576667682762352, 10.733467550920025, 9.756875669977045, 8.806177360694841, 6.814234998131271, 7.817504595952618, 8.822229806527245, 9.720955007501338, 10.702306830679973, 11.590074217270477, 12.545594299459605, 13.576850726239542, 14.534880952946024, 15.583679959661945, 16.52197018711502, 15.592177404417981, 14.596771115396853, 13.604980987841692, 12.619959313791554, 11.603043463352815, 10.610022947805051, 9.700189696088518, 8.68769885543159, 7.83377223182804], [6.87558900017005, 7.8243093312060275, 8.817651666750017, 9.714622923886651, 10.696956985606164, 11.701655300695014, 12.68751055530082, 13.683211350120715, 14.64650932983832, 15.546342779437769, 16.431692418203465, 15.405216827917315, 14.44127415527692, 13.451281256634818, 12.494681725780241, 11.62692021040244, 10.650810165538307, 9.638618206389465, 8.641048230046717, 7.690020013760914, 5.903189352172612, 6.848273446525871, 7.826730653319053, 8.774224844898708, 9.709378249624008, 10.68659146257481, 11.747617351222884, 12.682843082777575, 13.669590089410036, 14.554189076522519, 15.5082943345313, 14.626238263999616, 13.58751424602689, 12.606237769662139, 11.567716332967505, 10.561346451629994, 9.598386080484762, 8.694871415564151, 7.70825209852405, 6.76132570996803, 4.885468088909917, 5.852291469824624, 6.882134345845702, 7.745330971745743, 8.744267530645349, 9.74273714866936, 10.758530026669678, 11.776570371382407, 12.702679807492995, 13.621013501977616, 14.661758642752732, 13.709616292682798, 12.652180314454672, 11.703596318381964, 10.730596428515197, 9.674324447942478, 8.616440662875018, 7.779514245954366, 6.826160785957119, 5.82355915915634, 3.8524742422875, 4.890882394985477, 5.833009183381383, 6.782820347753455, 7.791317634580681, 8.817473946973024, 9.801093450082801, 10.765177892922473, 11.721350084216041, 12.667447151120024, 13.702198451588139, 12.71948266784062, 11.755851619177228, 10.710743050391715, 9.790854702132231, 8.725479707015436, 7.662774446608886, 6.724644824619335, 5.7742129267316935, 4.836705086996501, 2.9074509420219954, 3.915123902970409, 4.882966477024736, 5.92264917790404, 6.886856044367318, 7.813465621169399, 8.80251726644442, 9.7345230031672, 10.716954489066477, 11.745506400859512, 12.760970973387051, 11.801927194161822, 10.808959139784157, 9.784134712633175, 8.720725827457889, 7.763895471510351, 6.786228636353958, 5.763179603868882, 4.78594269933057, 3.8453515460501837, 1.960408401421505, 2.9156144029182354, 3.907021416521487, 4.934946618020163, 5.942266250631301, 6.879873310346497, 7.885028331391132, 8.809274362381952, 9.782187222817507, 10.767839076437513, 11.702429065295307, 10.861947930757246, 9.841680817821826, 8.87026961710767, 7.852461236620267, 6.805274042673125, 5.830500099877621, 4.804595079728148, 3.8686328973571555, 2.88820293317255, 0.9672063132981419, 1.942791809479931, 2.9294292821232166, 3.9740508964818932, 4.950323148335966, 5.923916804026329, 6.878681527576347, 7.863180415665642, 8.82133648004033, 9.835025356291814, 10.777172920086452, 9.811391916298922, 8.880911377868456, 7.876526781792879, 6.868710001493228, 5.902884855708071, 4.943439542342073, 3.8699752160815857, 2.9045145816479927, 1.8991606452541752, 0.0, 0.9906675828987562, 1.9382782818038895, 2.9499577989293737, 3.970714839457351, 4.938454128184324, 5.925114186751603, 6.916671633225541, 7.958583820539604, 8.925786290082145, 9.90500967707622, 8.949331207829232, 7.94881704200647, 6.882735233348557, 5.898460158956421, 4.956366643660068, 4.009042053761409, 3.0771843734828845, 2.051928853474519, 1.0606725417310705, 0.928600056104157, 1.9247308814764634, 2.8912326689208356, 3.907485239016225, 4.93422642704656, 5.920497190883966, 6.929748441947111, 7.920984508764862, 8.946656841132704, 9.8888483404315, 10.847998714640113, 9.808272522233088, 8.848609244738343, 7.784880863596663, 6.831272140606885, 5.8935327352881, 5.011658103356716, 4.076671615633787, 3.0397026782618455, 1.980371934637736, 1.9350921008142687, 2.8780660521881556, 3.9247181595473046, 4.876685246510951, 5.860076332666985, 6.856262589612005, 7.862961989865867, 8.798368198092714, 9.768169890006012, 10.703565402249946, 11.6568829945177, 10.688426040730812, 9.676032730897688, 8.742479886128127, 7.819974135768538, 6.8794641134724595, 5.957064159512798, 4.942542018769596, 3.987625101626474, 3.0062340809043615, 2.9017235260107053, 3.8518852753937094, 4.832858137456482, 5.840644583928525, 6.782543063701761, 7.812201217956752, 8.757845843720622, 9.724637479191435, 10.747329639300728, 11.72415806274737, 12.606189452482313, 11.575456989647696, 10.644308991541433, 9.697339605766048, 8.772139162362583, 7.839167704194695, 6.863210699546641, 5.924728231563806, 4.927061118189553, 3.9266117325786523, 3.8562966203621647, 4.821380662210203, 5.770765469081115, 6.730448242376269, 7.663720503324684, 8.651274407051886, 9.620684532959004, 10.678097425077286, 11.742104463479748, 12.71507856346294, 13.581572976008497, 12.60095757285236, 11.59871234956776, 10.679015663158292, 9.788222492975283, 8.81194154339387, 7.861456174307293, 6.925536428246861, 5.909052828167302, 4.859073944158908, 4.86349741052088, 5.757201604893852, 6.6868154276135305, 7.661745556578215, 8.639439609389251, 9.634175603665472, 10.607829457354486, 11.649277740863537, 12.686430799116422, 13.65778869352249, 14.589625935009728, 13.62683545821595, 12.573640960236006, 11.67814226288817, 10.779358321293278, 9.75544008336726, 8.815290610029832, 7.845044026683078, 6.8800579600668526, 5.8376698833150265, 5.874318522866144, 6.72022468038789, 7.626272370885149, 8.568011832324785, 9.557343308819686, 10.595338245204681, 11.631385034735374, 12.624367743104592, 13.639130262064189, 14.616259061646248, 15.523670217876095, 14.514113109105628, 13.566711684128267, 12.616978218531887, 11.632984548709787, 10.69296687272712, 9.781429801537666, 8.759952640636616, 7.718958878237826, 6.7762652873079805, 6.820167790413415, 7.756900896357116, 8.553475304196255, 9.51526694696854, 10.494783332827625, 11.500709404133667, 12.553573008303331, 13.597927620251033, 14.572115866405396, 15.535645312213306, 16.462989451234662, 15.463714056641658, 14.525713358871606, 13.634819317787876, 12.5848369365468, 11.62977310400774, 10.61705106858984, 9.674561652564668, 8.688214491693413, 7.816932642700859, 7.845516277671224, 8.715067881703186, 9.617958045592584, 10.441036925933387, 11.492014594088522, 12.466120175618922, 13.514693745906087, 14.49731511532778, 15.464737795726704, 16.409194549381166, 17.334544669614882, 16.489163559981254, 15.45640396411928, 14.62959468351982, 13.599883641567974, 12.567368518896775, 11.640407957361578, 10.70232031237283, 9.64096980570607, 8.811214082715008, 8.776271085190107, 9.78051875380684, 10.661468031407255, 11.398969733332864, 12.398728142794308, 13.397684622295134, 14.377378899018586, 15.359392846453503, 16.313814047369775, 17.35181169818661, 18.272196908626643, 17.451846371546587, 16.49431754397626, 15.629213884061837, 14.61566201229881, 13.559090396023398, 12.603431847200588, 11.617384554690771, 10.655279275881409, 9.742775312481792, 9.754735354285756, 10.701608639683892, 11.687640413685815, 12.33115383169188, 13.39788864990692, 14.353012691695664, 15.30931387956521, 16.325789126970204, 17.257624710580558, 18.245667520363707, 18.434912840097798, 17.414149026916945, 16.48557980945435, 15.545131452797158, 14.538758465630787, 13.543797667107624, 12.579647639141804, 11.794429771435924, 10.90654862205613, 9.923589135347136, 9.723503851436712, 10.718039445358713, 11.679215478087993, 12.53516257829913, 13.551810038785437, 14.541476123233165, 15.435132622164959, 16.390156353876073, 17.37630074385139, 18.359327867344117, 17.489522809977725, 16.596371030223004, 15.665917457462607, 14.660975788123208, 13.645791950753722, 12.608268803355735, 11.617405685554564, 10.816256945551318, 9.839665064608338, 8.973697672480327, 8.695750856761862, 9.69902045458321, 10.703745665157838, 11.602470866131931, 12.584218565383551, 13.471985951974055, 14.427506034163184, 15.45876246094312, 16.4167926876496, 17.46559169436552, 16.544939661100717, 15.632915407210193, 14.637509118189067, 13.645718990633906, 12.660697316583766, 11.643781466145027, 10.650760950597263, 9.782979090719811, 8.770488250062883, 7.950340924630536], [7.866256583068806, 7.000587673129865, 7.993930008673854, 8.823810980478903, 9.806145042198414, 10.810843357287265, 11.731357319336606, 12.7270581141565, 13.664355775182429, 14.555675196539013, 15.543241033476264, 16.389542656659863, 15.431941738175675, 14.441948839533573, 13.485349308678996, 12.617587793301196, 11.641477748437065, 10.629285789288224, 9.631715812945474, 8.68068759665967, 6.893856935071367, 6.024551788449709, 7.00300899524289, 7.883412901490959, 8.818566306216258, 9.795779519167061, 10.79146411525867, 11.726689846813361, 12.687436534754145, 13.563521493623764, 14.517626751632545, 15.44725976103381, 14.578181828925645, 13.596905352560894, 12.55838391586626, 11.55201403452875, 10.589053663383517, 9.68553899846291, 8.698919681422808, 7.751993292866787, 5.876135671808673, 5.023895966660896, 5.991322402437953, 6.854519028337994, 7.853455587237601, 8.850577790160209, 9.76786244377092, 10.785902788483648, 11.71201222459424, 12.630345919078861, 13.671091059853977, 14.650499465974367, 13.642847897353427, 12.694263901280719, 11.721264011413952, 10.664992030841233, 9.607108245773773, 8.770181828853122, 7.816828368855876, 6.814226742055097, 4.843141825186256, 4.062486891821749, 4.942197239973634, 5.892008404345707, 6.900505691172932, 7.826806364074268, 8.810425867184044, 9.774510310023718, 10.730682501317286, 11.676779568221269, 12.711530868689382, 13.677213613037818, 12.746519202075984, 11.70141063329047, 10.781522285030986, 9.716147289914193, 8.653442029507643, 7.715312407518092, 6.7648805096304505, 5.827372669895258, 3.8981185249207524, 3.0243119595626613, 3.9921545336169877, 4.971600112915514, 5.935806979378792, 6.822798038270642, 7.811849683545663, 8.743855420268444, 9.726286906167722, 10.754838817960755, 11.770303390488294, 12.747121858550024, 11.799626722682913, 10.77480229553193, 9.711393410356644, 8.754563054409108, 7.7768962192527145, 6.753847186767639, 5.776610282229327, 4.836019128948941, 2.9510759843202616, 2.0248024595104877, 2.9710242940765488, 3.9725867425718278, 4.9515986677325445, 5.889205727447741, 6.894360748492375, 7.818606779483196, 8.79151963991875, 9.777171493538756, 10.71176148239655, 11.73820756021848, 10.832348400720583, 9.860937200006427, 8.843128819519023, 7.795941625571881, 6.821167682776377, 5.795262662626904, 4.859300480255912, 3.878870516071306, 1.9578738961968982, 1.0110619206383167, 1.9387616992244605, 2.983383313583137, 3.9596555654372096, 4.933249221127573, 5.88801394467759, 6.872512832766885, 7.830668897141574, 8.844357773393057, 9.85014296357788, 10.80205949919768, 9.871578960767215, 8.867194364691635, 7.859377584391984, 6.893552438606828, 5.93410712524083, 4.860642798980342, 3.895182164546749, 2.8898282281529313, 0.9906675828987562, 0.0, 0.9476106989051332, 1.9592902160306176, 2.9800472565585947, 3.9477865452855676, 4.934446603852847, 5.926004050326785, 6.967916237640848, 7.935118707183389, 8.994720916420407, 9.93999879072799, 8.939484624905228, 7.873402816247314, 6.8891277418551775, 5.9470342265588245, 4.999709636660165, 4.067851956381641, 3.042596436373275, 2.0513401246298266, 1.9192676390029133, 1.0729339689215855, 1.9005650860220795, 2.916817656117469, 3.9435588441478036, 4.9298296079852095, 5.939080859048355, 6.930316925866106, 7.955989258233948, 8.898180757532742, 9.893826762675149, 10.798940105131843, 9.839276827637098, 8.775548446495419, 7.82193972350564, 6.884200318186856, 6.002325686255472, 5.067339198532544, 4.030370261160602, 2.971039517536492, 2.925759683713025, 2.047124209427597, 2.935684321200423, 3.8860176636121952, 4.869408749768229, 5.865595006713249, 6.872294406967111, 7.807700615193957, 8.777502307107255, 9.71289781935119, 10.666215411618943, 11.649064481402393, 10.666700313796445, 9.733147469026884, 8.810641718667293, 7.870131696371216, 6.9477317424115554, 5.933209601668353, 4.978292684525231, 3.9969016638031176, 3.8923911089094614, 3.116032592450335, 3.993367293449452, 4.88422042796279, 5.813369745261626, 6.821533635057997, 7.767178260821867, 8.733969896292678, 9.756662056401971, 10.733490479848612, 11.615521869583556, 12.566124572546451, 11.634976574440188, 10.688007188664804, 9.762806745261338, 8.82983528709345, 7.853878282445397, 6.9153958144625625, 5.9177287010883095, 4.917279315477408, 4.846964203260921, 4.085527979266828, 4.931274625074086, 5.89095739836924, 6.824229659317655, 7.811783563044857, 8.781193688951973, 9.71415887840383, 10.778165916806293, 11.724410980564183, 12.59090539310974, 13.580655197654838, 12.589379932466516, 11.669683246057048, 10.778890075874038, 9.802609126292625, 8.85212375720605, 7.9162040111456164, 6.899720411066057, 5.849741527057663, 5.854164993419636, 5.021348921950477, 5.8667414347244735, 6.822254712571186, 7.799948765382221, 8.794684759658441, 9.768338613347455, 10.783863319529122, 11.785979851649206, 12.757337746055272, 13.598958352110973, 14.59724996226373, 13.56430854313476, 12.668809845786924, 11.770025904192034, 10.746107666266015, 9.805958192928589, 8.835711609581834, 7.870725542965609, 6.828337466213783, 6.864986105764899, 5.984371997444516, 6.806198377996092, 7.747937839435729, 8.735144448819279, 9.75584740119765, 10.791894190728343, 11.784876899097561, 12.738679314596972, 13.715808114179032, 14.641157134655975, 15.504780692004383, 14.557379267027022, 13.607645801430643, 12.623652131608543, 11.683634455625874, 10.772097384436423, 9.750620223535371, 8.709626461136581, 7.766932870206737, 7.8108353733121705, 7.021048213413742, 7.7334013113071975, 8.695192954079483, 9.672584472827218, 10.67851054413326, 11.731374148302924, 12.775728760250626, 13.671664918938179, 14.63519436474609, 15.612995903204666, 16.454381639540415, 15.516380941770361, 14.625486900686631, 13.575504519445555, 12.620440686906495, 11.607718651488595, 10.665229235463423, 9.678882074592169, 8.807600225599614, 8.836183860569978, 7.979215198759812, 8.797884052703527, 9.62096293304433, 10.671940601199465, 11.646046182729865, 12.69461975301703, 13.677241122438723, 14.644663802837647, 15.589120556492107, 16.51447067672582, 17.450678546865603, 16.447071547018034, 15.620262266418575, 14.59055122446673, 13.55803610179553, 12.631075540260333, 11.692987895271585, 10.631637388604826, 9.801881665613761, 9.76693866808886, 9.044666070863466, 9.841394038518198, 10.578895740443807, 11.578654149905251, 12.577610629406077, 13.557304906129529, 14.539318853564446, 15.49374005448072, 16.531737705297555, 17.452122915737583, 17.592994594309463, 16.635465766739134, 15.602247543440598, 14.671692416482436, 13.65389203235791, 12.649028427043275, 11.950724514784, 11.04851217671615, 10.733442895380545, 10.74540293718451, 10.091328918750698, 10.90870778315521, 11.511079838802823, 12.577814657017862, 13.532938698806607, 14.489239886676152, 15.505715134081147, 16.4375507176915, 17.42559352747465, 17.470937104992583, 16.523337083509197, 15.594767866046602, 14.65431950938941, 13.64794652222304, 12.652985723699876, 11.688835695734056, 10.970708113359763, 10.082826963979969, 10.8981147556724, 10.71417143433547, 11.08550703770439, 11.888020928012894, 12.511616697484463, 13.511750922069504, 14.584524663102828, 15.441782870595581, 16.396806602306697, 17.382950992282016, 17.43618680578531, 16.49885522707897, 15.614217475567113, 14.744888438934769, 13.73994676959537, 12.754980007345974, 11.717456859947987, 10.726593742146816, 9.992535287475157, 9.015943406532177, 9.948223292805592, 9.686418439660619, 10.689688037481968, 11.694413248056597, 12.59313844903069, 13.574886148282307, 14.46265353487281, 15.418173617061939, 16.449430043841875, 17.40111851639215, 16.57714030963832, 15.554272078201961, 14.650761852554302, 13.71648009966123, 12.724689972106068, 11.769885373176017, 10.75296952273728, 9.759949007189515, 8.95925743264365, 7.94676659198672, 8.924866544955801], [8.81386728197394, 7.942472078597602, 7.1349175666355285, 7.901768370975706, 8.884102432695219, 9.88880074778407, 10.783746620431474, 11.779447415251369, 12.716745076277295, 13.60806449763388, 14.59563033457113, 15.44193195775473, 16.37955243708081, 15.389559538438707, 14.43296000758413, 13.56519849220633, 12.589088447342196, 11.576896488193354, 10.579326511850606, 9.628298295564804, 7.841467633976501, 6.9664361939174455, 6.1041112556266865, 6.9613702919877625, 7.8965236967130625, 8.873736909663865, 9.843853416353538, 10.779079147908229, 11.739825835849011, 12.61591079471863, 13.57001605272741, 14.499649062128675, 15.52579252783078, 14.544516051466028, 13.505994614771394, 12.499624733433883, 11.53666436228865, 10.63314969736804, 9.64653038032794, 8.69960399177192, 6.823746370713807, 5.965780372128632, 5.069279792934757, 5.932476418834797, 6.931412977734404, 7.902967091255075, 8.820251744865788, 9.838292089578516, 10.764401525689106, 11.682735220173727, 12.723480360948843, 13.702888767069233, 14.59045859625856, 13.641874600185853, 12.668874710319086, 11.612602729746367, 10.554718944678907, 9.717792527758256, 8.764439067761009, 7.76183744096023, 5.79075252409139, 5.004371297289485, 4.020154630470437, 4.96996579484251, 5.9784630816697355, 6.879195665169134, 7.862815168278911, 8.826899611118584, 9.783071802412152, 10.729168869316135, 11.763920169784248, 12.729602914132684, 13.693233962796075, 12.649021332195604, 11.72913298393612, 10.663757988819327, 9.601052728412775, 8.662923106423225, 7.7124912085355835, 6.774983368800391, 4.845729223825885, 3.9719226584677942, 3.070111924113791, 4.02398941401038, 4.988196280473658, 5.8751873393655085, 6.864238984640529, 7.79624472136331, 8.778676207262588, 9.80722811905562, 10.82269269158316, 11.79951115964489, 12.747237421588046, 11.722412994437065, 10.659004109261778, 9.702173753314241, 8.724506918157847, 7.701457885672772, 6.72422098113446, 5.783629827854074, 3.8986866832253946, 2.9724131584156206, 2.0234135951714154, 3.0249760436666944, 4.003987968827411, 4.941595028542607, 5.946750049587241, 6.870996080578062, 7.843908941013616, 8.829560794633622, 9.764150783491417, 10.790596861313347, 11.779959099625717, 10.808547898911561, 9.790739518424157, 8.743552324477015, 7.76877838168151, 6.742873361532037, 5.806911179161045, 4.82648121497644, 2.905484595102031, 1.9586726195434498, 0.9911510003193272, 2.0357726146780037, 3.0120448665320763, 3.9856385222224398, 4.9404032457724565, 5.924902133861751, 6.88305819823644, 7.896747074487924, 8.902532264672747, 9.868313268460277, 10.798793806890743, 9.814805063596769, 8.806988283297118, 7.84116313751196, 6.881717824145962, 5.808253497885475, 4.842792863451882, 3.837438927058064, 1.9382782818038895, 0.9476106989051332, 0.0, 1.0116795171254844, 2.0324365576534613, 3.0001758463804338, 3.9868359049477133, 4.978393351421651, 6.020305538735714, 6.9875080082782555, 8.047110217515273, 9.002788686762262, 9.88709532381036, 8.821013515152446, 7.8367384407603105, 6.8946449254639575, 5.947320335565298, 5.015462655286774, 3.990207135278408, 2.99895082353496, 2.8668783379080462, 1.9317394012136986, 0.9529543871169462, 1.9692069572123354, 2.9959481452426697, 3.982218909080076, 4.991470160143221, 5.982706226960972, 7.008378559328814, 7.9505700586276085, 8.946216063770015, 9.953956175639163, 10.786887526542232, 9.723159145400553, 8.769550422410774, 7.831811017091989, 6.949936385160605, 6.014949897437676, 4.977980960065734, 3.918650216441625, 3.8489035930935973, 2.9059296417197107, 1.9880736222952895, 2.938406964707062, 3.9217980508630954, 4.917984307808116, 5.924683708061977, 6.860089916288823, 7.829891608202122, 8.765287120446057, 9.71860471271381, 10.70145378249726, 11.61431101270158, 10.680758167932018, 9.758252417572427, 8.817742395276348, 7.877403872825969, 6.862881732082767, 5.907964814939644, 4.92004557318369, 4.815535018290034, 3.9748380247424486, 3.0457565945443186, 3.9366097290576563, 4.865759046356493, 5.873922936152863, 6.819567561916733, 7.786359197387544, 8.809051357496838, 9.785879780943478, 10.667911170678424, 11.723905404810663, 12.582587273345322, 11.635617887569937, 10.710417444166472, 9.777445985998583, 8.777022191825969, 7.838539723843135, 6.840872610468882, 5.840423224857981, 5.770108112641494, 4.944333411558942, 3.983663926168952, 4.943346699464106, 5.876618960412521, 6.864172864139723, 7.83358299004684, 8.766548179498697, 9.830555217901159, 10.77680028165905, 11.643294694204608, 12.633044498749706, 13.53699063137165, 12.617293944962181, 11.7127937421477, 10.733566127461241, 9.775267666586622, 8.839347920526189, 7.822864320446629, 6.772885436438235, 6.777308902800209, 5.8487445585390185, 4.91913073581934, 5.874644013666052, 6.852338066477087, 7.847074060753307, 8.82072791444232, 9.836252620623988, 10.838369152744072, 11.809727047150139, 12.651347653205839, 13.649639263358596, 14.511919242039895, 13.616420544692058, 12.699133317246677, 11.675215079320658, 10.729102102309163, 9.758855518962408, 8.793869452346183, 7.751481375594356, 7.772997383593671, 6.811767634033057, 5.858587679090959, 6.800327140530595, 7.787533749914145, 8.808236702292517, 9.844283491823209, 10.837266200192428, 11.791068615691838, 12.768197415273898, 13.693546435750841, 14.6972722499369, 15.499578431432926, 14.536753214485286, 13.552759544663186, 12.612741868680517, 11.695241293816997, 10.673764132915945, 9.632770370517155, 8.69007677958731, 8.718846651140943, 7.781338903633995, 6.785790612402064, 7.747582255174349, 8.724973773922084, 9.730899845228127, 10.78376344939779, 11.828118061345492, 12.724054220033045, 13.687583665840956, 14.665385204299533, 15.64687319747293, 16.458580106176264, 15.554594313741275, 14.504611932500199, 13.543584596287069, 12.530862560869169, 11.588373144843997, 10.602025983972743, 9.730744134980188, 9.744195138398752, 8.739505888980066, 7.850273353798394, 8.673352234139196, 9.72432990229433, 10.698435483824731, 11.747009054111896, 12.729630423533589, 13.697053103932513, 14.641509857586973, 15.56685997782069, 16.503067847960473, 16.721939429921257, 15.711397937468494, 14.766298002075034, 13.723571299981336, 12.690009707379087, 12.130748472457997, 11.5547812979854, 10.709892943442535, 10.674949945917634, 9.80495676108372, 8.893783339613064, 9.631285041538673, 10.631043451000117, 11.629999930500944, 12.609694207224395, 13.591708154659312, 14.546129355575586, 15.584127006392421, 16.50451221683245, 16.670951984806266, 15.713423157235937, 14.6802049339374, 13.749649806979239, 12.731849422854712, 11.726985817540077, 11.111944772601927, 11.990396582183886, 11.641454173209318, 11.653414215013283, 10.85161960897095, 9.961097084250076, 10.56346913989769, 11.630203958112729, 12.585327999901473, 13.541629187771019, 14.558104435176013, 15.489940018786367, 16.477982828569516, 16.523326406087445, 15.601294474006, 14.672725256543405, 13.732276899886212, 12.725903912719842, 11.730943114196679, 10.766793086230859, 10.13192837117769, 11.024711369447704, 11.839999161140138, 11.661782133240603, 11.845797727924642, 10.94041022910776, 11.56400599857933, 12.56414022316437, 13.636913964197694, 14.494172171690447, 15.449195903401561, 16.435340293376882, 16.488576106880174, 15.551244528173834, 14.666606776661979, 13.797277740029637, 12.792336070690238, 11.832937397842777, 10.79541425044479, 9.804551132643619, 9.153755545293084, 9.957827811999913, 10.89010769827333, 10.634029138565753, 11.637298736387098, 11.97230133239496, 12.496697710746528, 13.530279072864111, 14.556915196791348, 15.501798759692223, 16.485085976426593, 16.453507817487015, 15.629529610733186, 14.606661379296828, 13.703151153649168, 12.768869400756097, 11.777079273200936, 10.847842763672821, 9.830926913234082, 8.837906397686318, 8.120477690461577, 8.888650997454457, 9.866750950423539], [9.825546799099422, 8.923311681365638, 7.942777798541169, 6.982985644999597, 7.96531970671911, 8.925581327059996, 9.772067103305991, 10.767767898125886, 11.70506555915181, 12.596384980508395, 13.583950817445645, 14.430252440629245, 15.394195113269639, 15.584485399200027, 14.62788586834545, 13.656850041088788, 12.618349106678188, 12.58857600531884, 11.591006028976091, 10.639977812690287, 8.853147151101984, 7.947275796685482, 7.046390512408511, 6.042587566011654, 6.977740970736954, 7.879626020628897, 8.832173899228055, 9.767399630782746, 10.728146318723526, 11.604231277593145, 12.558336535601926, 13.48796954500319, 14.526693562975916, 15.507970039340668, 14.517674131896877, 13.511304250559366, 12.548343879414134, 11.644829214493527, 10.658209897453425, 9.711283508897404, 7.83542588783929, 6.946619974896669, 6.011559049716581, 5.013693692858689, 5.989099362027307, 6.891287574129592, 7.808572227740305, 8.826612572453033, 9.752722008563621, 10.671055703048243, 11.711800843823358, 12.691209249943748, 13.648459245323497, 14.597043241396205, 13.680554227444569, 12.62428224687185, 11.56639846180439, 10.72947204488374, 9.776118584886492, 8.773516958085715, 6.802432041216873, 5.985210900057522, 5.000994233238474, 4.0511830688664014, 5.036149465962638, 5.867516148043651, 6.851135651153428, 7.8152200939931, 8.771392285286668, 9.71748935219065, 10.752240652658765, 11.717923397007201, 12.681554445670592, 13.660700849321087, 12.740812501061603, 11.67543750594481, 10.61273224553826, 9.67460262354871, 8.724170725661066, 7.786662885925875, 5.857408740951369, 4.983602175593278, 4.0519925977642, 3.0123098968848963, 3.976516763348174, 4.863507822240026, 5.8525594675150465, 6.7845652042378255, 7.766996690137105, 8.795548601930138, 9.811013174457678, 10.787831642519407, 11.780799696897072, 12.734092511562547, 11.67068362638726, 10.713853270439724, 9.736186435283331, 8.713137402798257, 7.7359004982599435, 6.795309344979557, 4.910366200350879, 3.984092675541105, 3.0350931122968996, 2.01329652654121, 2.992308451701927, 3.929915511417123, 4.935070532461758, 5.859316563452579, 6.832229423888133, 7.817881277508139, 8.752471266365934, 9.778917344187864, 10.832424935602438, 11.803836136316594, 10.80241903554964, 9.755231841602498, 8.780457898806993, 7.754552878657521, 6.818590696286529, 5.838160732101924, 3.917164112227516, 2.970352136668934, 2.0028305174448118, 1.0240930975525193, 2.000365349406592, 2.9739590050969555, 3.9287237286469727, 4.913222616736268, 5.871378681110956, 6.88506755736244, 7.890852747547264, 8.856633751334794, 9.78711428976526, 10.826484580722253, 9.818667800422602, 8.852842654637445, 7.893397341271447, 6.819933015010959, 5.854472380577366, 4.849118444183549, 2.9499577989293737, 1.9592902160306176, 1.0116795171254844, 0.0, 1.0207570405279769, 1.9884963292549496, 2.975156387822229, 3.966713834296167, 5.00862602161023, 5.975828491152771, 7.035430700389789, 7.991109169636776, 8.991623335459538, 9.83269303227793, 8.848417957885795, 7.906324442589442, 6.958999852690782, 6.027142172412258, 5.0018866524038925, 4.010630340660445, 3.878557855033531, 2.9434189183391832, 1.9646339042424308, 1.0671549973803438, 2.052144873894875, 2.970539391954592, 3.979790643017737, 4.971026709835488, 5.99669904220333, 6.938890541502124, 7.93453654664453, 8.942276658513679, 9.901939936008423, 10.734838662526037, 9.781229939536258, 8.843490534217475, 7.9616159022860895, 7.0266294145631605, 5.989660477191219, 4.93032973356711, 4.860583110219082, 3.9176091588451953, 2.9997531394207737, 2.0363550048750705, 3.019746091031104, 3.982335492300847, 4.913004190936493, 5.848410399163339, 6.818212091076639, 7.753607603320573, 8.706925195588326, 9.689774265371776, 10.7021675752049, 11.635720419974461, 10.769931934697912, 9.829421912401834, 8.889083389951454, 7.874561249208251, 6.919644332065129, 5.9317250903091745, 5.827214535415519, 4.986517541867933, 4.0423442156977085, 3.034557769225665, 3.9637070865245017, 4.938274120645595, 5.8508213946507315, 6.77467968026206, 7.797371840371354, 8.774200263817995, 9.65623165355294, 10.712225887685179, 11.643373885791442, 12.590343271566827, 11.722096961291957, 10.789125503124069, 9.788701708951452, 8.850219240968618, 7.852552127594366, 6.852102741983465, 6.781787629766979, 5.9560129286844266, 4.980251547322342, 4.050653166274943, 4.983925427223357, 5.97147933095056, 6.871333643384137, 7.754868662373212, 8.818875700775674, 9.765120764533567, 10.631615177079123, 11.621364981624222, 12.59777724381777, 13.57201932895907, 12.724473259273182, 11.745245644586724, 10.786947183712105, 9.851027437651673, 8.834543837572115, 7.78456495356372, 7.788988419925694, 6.8453321796924085, 5.91571835697273, 4.981950480476889, 5.959644533287924, 6.954380527564144, 7.879689932754772, 8.824573103498503, 9.826689635618587, 10.798047530024654, 11.639668136080356, 12.637959746233113, 13.572705854486015, 14.571145928688948, 13.710812834372161, 12.686894596446143, 11.740781619434648, 10.770535036087892, 9.805548969471667, 8.76316089271984, 8.76958500474706, 7.808355255186447, 6.8551753002443485, 5.954873863695672, 6.894840216724981, 7.915543169103354, 8.929263569530153, 9.836547103677773, 10.779389098566355, 11.756517898148415, 12.681866918625358, 13.685592732811417, 14.565776578378276, 15.528601795325917, 14.56443906178867, 13.624421385806002, 12.706920810942481, 11.68544365004143, 10.64444988764264, 9.701756296712794, 9.715434272294331, 8.777926524787386, 7.782378233555454, 6.917572950512385, 7.832280240732921, 8.838206312038963, 9.891069916208627, 10.846110526418851, 11.712374702907562, 12.675904148715473, 13.65370568717405, 14.635193680347447, 15.524778253121616, 15.759618923529638, 14.709636542288562, 13.742383988894263, 12.794583870174716, 12.600052661969482, 11.613705501098227, 10.742423652105673, 10.74078275955214, 9.736093510133456, 8.834353775869591, 7.843342929477232, 8.872726286832563, 9.846831868362964, 10.895405438650128, 11.80843968489938, 12.737677393306239, 13.6821341469607, 14.607484267194415, 15.5436921373342, 15.803156703945145, 14.792615211492384, 13.847515276098926, 12.804788574005228, 11.771226981402977, 12.811503099291043, 12.566460815110887, 11.706480564595923, 11.671537567071022, 10.80154438223711, 9.78506266640788, 8.80127573687671, 9.801034146338154, 10.79637340295161, 11.776067679675062, 12.758081627109979, 13.712502828026253, 14.681159879614382, 15.545136506206177, 15.66247438277404, 14.794640431259827, 13.76142220796129, 12.830867081003131, 11.813066696878604, 10.808203091563968, 11.792699399434973, 12.739171661689857, 12.638041794362707, 12.650001836166672, 11.739582000555744, 10.753550226553822, 9.733459835235726, 10.800194653450765, 11.75531869523951, 12.711619883109055, 13.728037211688807, 14.656313491237034, 15.644356301020181, 15.51164688896196, 14.591021126450448, 13.753942530567295, 12.813494173910103, 11.807121186743732, 10.812160388220569, 9.848010360254749, 10.812682998010736, 11.773486448953676, 12.773326816285174, 12.673461650366086, 12.632087906630098, 11.670911873900817, 10.733996693917366, 11.734130918502407, 12.80690465953573, 13.664162867028484, 14.619186598739597, 15.605330988714918, 15.476896589754691, 14.53956501104835, 13.654927259536494, 12.785598222904154, 11.780656553564755, 10.909854951136316, 9.87663152446868, 8.885768406667509, 9.917980877044966, 10.938667414767949, 11.870947301041365, 11.645708655691235, 12.648978253512585, 12.6588839779022, 11.666688406084564, 12.700269768202148, 13.726905892129384, 14.67178945503026, 15.65507667176463, 15.441828300361532, 14.617850093607702, 13.594981862171343, 12.691471636523683, 11.757189883630614, 10.765399756075453, 9.884623342948748, 8.912144187257972, 7.919123671710208, 8.921537280076855, 9.869490600222493, 10.847590553191575], [10.846303839627401, 9.931157464650047, 8.950623581825578, 7.9908314282840065, 7.1279767110148535, 7.980882606636261, 8.827368382882256, 9.82306917770215, 10.684308518623833, 11.575627939980418, 12.563193776917668, 13.409495400101267, 14.373438072741662, 14.848628163844053, 13.92220506166742, 12.951169234410758, 13.551708925687635, 13.609333045846816, 12.611763069504068, 11.660734853218266, 9.873904191629963, 8.95512157996989, 8.05423629569292, 7.050433349296063, 6.140397975032697, 6.93492730020516, 7.887475178804318, 8.82270091035901, 9.70738927819555, 10.583474237065168, 11.537579495073949, 12.467212504475214, 13.50593652244794, 14.48721299881269, 14.849170454480156, 14.016742993183204, 13.569100919942112, 12.665586255021502, 11.678966937981402, 10.732040549425381, 8.856182928367268, 7.954465758181079, 7.019404833000991, 6.021539476143098, 5.131294213744177, 5.9465888537058555, 6.863873507316568, 7.851413716024147, 8.731964968035644, 9.650298662520266, 10.691043803295381, 11.670452209415771, 12.627702204795522, 13.57628620086823, 14.549286090734997, 13.645039287399829, 12.587155502332369, 11.750229085411718, 10.796875625414469, 9.794273998613692, 7.82318908174485, 6.993056683341932, 6.008840016522884, 5.059028852150811, 4.1783443176795085, 4.922817427619915, 5.906436930729692, 6.7944630534651225, 7.750635244758691, 8.696732311662673, 9.731483612130788, 10.697166356479226, 11.660797405142617, 12.70590597392813, 13.754020094898257, 12.696194546472787, 11.633489286066236, 10.695359664076687, 9.744927766189043, 8.807419926453852, 6.878165781479346, 6.004359216121255, 5.05983838104861, 4.020155680169306, 3.1187116150650445, 3.9188091018162887, 4.90786074709131, 5.763808163709848, 6.7462396496091275, 7.77479156140216, 8.7902561339297, 9.767074601991432, 10.760042656369096, 11.784867083520078, 12.691440666915238, 11.734610310967701, 10.756943475811308, 9.733894443326234, 8.756657538787922, 7.8160663855075345, 5.931123240878856, 5.0048497160690815, 4.049067511324296, 3.0211423098256196, 2.047609731278191, 2.9852167909933867, 3.9143134919337803, 4.8385595229246015, 5.811472383360156, 6.797124236980162, 7.7317142258379565, 8.758160303659885, 9.81166789507446, 10.783079095788617, 11.823176076077617, 10.775988882130475, 9.80121493933497, 8.775309919185498, 7.839347736814506, 6.858917772629901, 4.937921152755493, 3.991109177196911, 3.0235875579727884, 2.031938880836929, 1.0556666289828562, 1.9532019645689784, 2.9079666881189956, 3.892465576208291, 4.850621640582979, 5.864310516834463, 6.870095707019287, 7.835876710806817, 8.766357249237283, 9.812194915319196, 10.820011695618847, 9.873599695165423, 8.914154381799424, 7.8406900555389365, 6.8752294211053435, 5.869875484711526, 3.970714839457351, 2.9800472565585947, 2.0324365576534613, 1.0207570405279769, 0.0, 0.9677392887269727, 1.9543993472942522, 2.9459567937681905, 3.9878689810822534, 4.955071450624795, 6.0146736598618125, 6.9703521291088, 7.970866294931563, 9.036948103589477, 9.869174998413772, 8.92708148311742, 7.9797568932187595, 7.047899212940235, 6.02264369293187, 5.031387381188422, 4.899314895561508, 3.96417595886716, 2.9853909447704075, 2.0581290213972325, 1.0313878333668978, 1.9497823514266148, 2.95903360248976, 3.9502696693075112, 4.975942001675353, 5.9181335009741485, 6.913779506116555, 7.921519617985703, 8.881182895480448, 9.944911276622127, 10.801986980064235, 9.864247574745452, 8.982372942814067, 8.047386455091138, 7.010417517719196, 5.951086774095087, 5.881340150747058, 4.938366199373172, 4.020510179948751, 3.027329028891959, 2.082058112968478, 2.96157845177287, 3.8922471504085157, 4.827653358635362, 5.7974550505486615, 6.732850562792596, 7.686168155060349, 8.669017224843799, 9.681410534676923, 10.614963379446484, 11.689708169829723, 10.850178952929811, 9.909840430479429, 8.895318289736228, 7.940401372593105, 6.952482130837151, 6.847971575943495, 5.956676896769926, 4.975704034707154, 3.9679175882351108, 3.0260191084618757, 3.9175170801176176, 4.830064354122754, 5.753922639734083, 6.776614799843377, 7.7534432232900174, 8.635474613024963, 9.691468847157202, 10.622616845263465, 11.56958623103885, 12.494786674442315, 11.809882543652046, 10.809458749479429, 9.870976281496596, 8.873309168122343, 7.872859782511442, 7.802544670294955, 6.9261722835864195, 5.9136113663317875, 4.984012985284389, 4.068260478520199, 4.989294993188367, 5.85057660285616, 6.734111621845235, 7.798118660247697, 8.74436372400559, 9.610858136551146, 10.600607941096245, 11.577020203289793, 12.551262288431094, 13.510870005055015, 12.766002685114701, 11.807704224240082, 10.87178447817965, 9.855300878100092, 8.805321994091697, 8.791617433023593, 7.778691998701854, 6.849078175982175, 5.915310299486335, 5.095604490389631, 6.050087384708807, 6.858932892226795, 7.803816062970526, 8.80593259509061, 9.777290489496677, 10.618911095552377, 11.617202705705134, 12.551948813958038, 13.55038888816097, 14.53977466491977, 13.689523609544041, 12.743410632532546, 11.773164049185791, 10.808177982569566, 9.765789905817739, 9.702944823756505, 8.741715074195891, 7.788535119253794, 6.888233682705119, 6.030800173826687, 7.011250026248017, 7.908506529002175, 8.815790063149796, 9.758632058038376, 10.735760857620436, 11.66110987809738, 12.664835692283438, 13.5450195378503, 14.50784475479794, 14.981691575681019, 14.064982862105493, 13.70954982404038, 12.678014883231592, 11.637021120832802, 10.694327529902957, 10.648794091303778, 9.711286343796832, 8.7157380525649, 7.850932769521831, 6.968240197834627, 7.974166269140669, 8.981883007796522, 9.825353485890874, 10.691617662379583, 11.655147108187494, 12.63294864664607, 13.614436639819468, 14.504021212593639, 14.86787825562801, 14.029839187844006, 13.084401761189811, 13.802429653459125, 13.592623895159644, 12.60627673428839, 11.700436520102933, 11.674142578561586, 10.669453329142902, 9.767713594879039, 8.776702748486679, 8.00868624393427, 8.98279182546467, 10.031136756637695, 10.787682644371403, 11.71692035277826, 12.66137710643272, 13.586727226666437, 14.52293509680622, 14.883644382348828, 13.873102889896067, 13.014792482822832, 12.146806346300776, 12.779072764687387, 13.819348882575452, 13.559032048301049, 12.63984038360537, 12.604897386080468, 11.734904201246556, 10.718422485417326, 9.734635555886156, 9.068566103330507, 9.932333360053317, 10.912027636776768, 11.850098583205844, 12.699233220963556, 13.660402839086403, 14.524379465678198, 14.641717342246062, 13.87512810966351, 12.841909886364974, 11.981642163024365, 11.155084469174152, 11.816048874848377, 12.800545182719382, 13.747017444974267, 13.571401613372153, 13.583361655176118, 12.67294181956519, 11.686910045563268, 10.666819654245172, 10.09234314097612, 10.984022218238529, 11.902808734709797, 12.820054167784672, 13.643043884174338, 14.631086693957485, 14.490889848433984, 13.57026408592247, 12.834430208970979, 11.893981852313786, 10.957896268764967, 10.10590594945435, 10.855856143539159, 11.820528781295145, 12.781332232238086, 13.781172599569583, 13.694218690894065, 13.565447725639544, 12.604271692910263, 11.667356512926812, 11.026279406027761, 12.041289863613684, 12.855351718629226, 13.81037545034034, 14.658754419303177, 14.456139549226714, 13.518807970520372, 12.634170219008517, 11.840899502480418, 10.83595783314102, 9.96515623071258, 9.17037708570246, 9.893614189951919, 10.925826660329376, 11.946513198052358, 12.878793084325775, 12.666465696219214, 13.66973529404056, 13.592243796911646, 12.60004822509401, 11.993870879429647, 13.020507003356883, 13.862978306631002, 14.846265523365373, 14.421071259833555, 13.597093053079725, 12.574224821643366, 11.670714595995706, 10.812491163206879, 9.820701035651718, 8.939924622525012, 8.141398293415374, 8.926969454994618, 9.929383063361264, 10.877336383506902, 11.855436336475984], [11.703518656859467, 10.753874143739917, 9.760531808195928, 8.800739654654357, 7.912766906923269, 7.031927387084879, 7.878413163330873, 8.874113958150767, 9.71656922989686, 10.607888651253445, 11.595454488190695, 12.441756111374294, 13.405698784014689, 13.958778926245794, 13.21456158279357, 13.859136541433196, 14.459676232710075, 14.565641274215897, 13.56807129787315, 12.617043081587347, 10.747758671590583, 9.802674577237324, 8.901789292960352, 7.860341575666413, 6.925188170941113, 5.985972080653779, 6.938519959252936, 7.8737456908076275, 8.739649989468576, 9.615734948338195, 10.569840206346976, 11.49947321574824, 12.538197233720966, 13.519473710085718, 14.141526975606306, 14.924710300205643, 14.536840208669084, 13.621894483390584, 12.635275166350484, 11.688348777794463, 9.823922217094239, 8.802018755448511, 7.866957830268423, 6.8690924734105305, 5.916084409652592, 4.997633634154474, 5.914918287765186, 6.883674427297174, 7.764225679308671, 8.682559373793293, 9.723304514568408, 10.702712920688798, 11.65996291606855, 12.608546912141257, 13.581546802008024, 14.6127785761268, 13.55489479105934, 12.71796837413869, 11.764614914141442, 10.762013287340665, 8.790928370471823, 7.840609680609364, 6.856393013790316, 5.906581849418243, 4.963134513587924, 3.973862208068533, 4.95748171117831, 5.82672376473815, 6.782895956031718, 7.7289930229357005, 8.763744323403815, 9.729427067752253, 10.693058116415644, 11.738166685201158, 12.786280806171284, 13.66393383519976, 12.60122857479321, 11.66309895280366, 10.712667054916016, 9.775159215180825, 7.845905070206318, 6.875233952370369, 5.907391378316042, 4.867708677436738, 3.9035018109734603, 2.9698538822649074, 3.9589055275399287, 4.7960688749828755, 5.778500360882155, 6.807052272675187, 7.8225168452027285, 8.799335313264459, 9.792303367642123, 10.817127794793105, 11.88053667996839, 12.702349599694674, 11.724682764538281, 10.701633732053207, 9.724396827514894, 8.783805674234507, 6.898862529605828, 5.972589004796054, 4.994853390833553, 3.966928189334877, 2.9738686311572016, 2.0362615714420054, 2.946574203206808, 3.8708202341976286, 4.843733094633183, 5.829384948253189, 6.763974937110984, 7.790421014932913, 8.843928606347488, 9.815339807061644, 10.881669818476258, 11.743728170857448, 10.768954228061943, 9.74304920791247, 8.80708702554148, 7.826657061356873, 5.905660441482465, 4.958848465923883, 3.991326846699761, 2.9777247603461863, 2.0014525084921138, 0.9854626758420059, 1.9402273993920232, 2.924726287481318, 3.882882351856006, 4.89657122810749, 5.902356418292314, 6.868137422079844, 7.79861796051031, 8.844455626592223, 9.852272406891874, 10.830982065395933, 9.881893670526397, 8.808429344265909, 7.8429687098323155, 6.837614773438498, 4.938454128184323, 3.9477865452855667, 3.0001758463804338, 1.9884963292549496, 0.9677392887269727, 0.0, 0.9866600585672796, 1.9782175050412176, 3.0201296923552805, 3.9873321618978217, 5.04693437113484, 6.002612840381827, 7.00312700620459, 8.069208814862504, 9.05348388925464, 9.89482077184439, 8.94749618194573, 8.015638501667206, 6.990382981658841, 5.999126669915393, 5.86705418428848, 4.931915247594132, 3.95313023349738, 3.025868310124205, 1.9991271220938704, 0.9820430626996423, 1.9912943137627874, 2.9825303805805383, 4.00820271294838, 4.950394212247176, 5.946040217389582, 6.95378032925873, 7.913443606753475, 8.977171987895154, 9.930780710884934, 10.831986863472423, 9.950112231541038, 9.01512574381811, 7.978156806446169, 6.918826062822059, 6.84907943947403, 5.906105488100144, 4.988249468675723, 3.9734165061469513, 2.9900254199909178, 1.9938391630458976, 2.924507861681543, 3.859914069908389, 4.829715761821689, 5.765111274065623, 6.718428866333376, 7.701277936116826, 8.71367124594995, 9.647224090719511, 10.72196888110275, 11.788807504152302, 10.877579719206402, 9.8630575784632, 8.908140661320077, 7.920221419564123, 7.81480595317537, 6.864644203792366, 5.8836713417295945, 4.875884895257551, 3.9339864154843154, 2.949777791390645, 3.862325065395782, 4.78618335100711, 5.808875511116404, 6.7857039345630445, 7.667735324297991, 8.723729558430229, 9.654877556536492, 10.601846942311877, 11.527047385715342, 12.507885330423948, 11.776293126711304, 10.83781065872847, 9.840143545354218, 8.839694159743317, 8.76937904752683, 7.83413959060886, 6.821578673354228, 5.89198029230683, 4.976227785542639, 4.021555704461395, 4.882837314129188, 5.766372333118262, 6.830379371520724, 7.776624435278616, 8.643118847824173, 9.632868652369272, 10.60928091456282, 11.58352299970412, 12.543130716328042, 13.480659169623122, 12.774538601471956, 11.838618855411525, 10.822135255331967, 9.772156371323572, 9.699584740046033, 8.686659305724294, 7.757045483004616, 6.823277606508776, 6.00357179741207, 5.082348095981834, 5.891193603499824, 6.836076774243553, 7.838193306363637, 8.809551200769704, 9.651171806825406, 10.649463416978163, 11.584209525231065, 12.582649599433998, 13.572035376192797, 14.424157709596512, 13.651377939554987, 12.681131356208232, 11.716145289592006, 10.67375721284018, 10.610912130778946, 9.649682381218332, 8.696502426276234, 7.796200989727559, 6.938767480849126, 6.043510737521044, 6.940767240275204, 7.848050774422823, 8.790892769311405, 9.768021568893465, 10.693370589370408, 11.697096403556467, 12.577280249123326, 13.540105466070967, 14.03273635612964, 14.84977305801391, 14.61751713106282, 13.585982190254033, 12.544988427855243, 11.602294836925397, 11.556761398326216, 10.619253650819273, 9.62370535958734, 8.758900076544272, 7.8762075048570654, 7.078961717333662, 8.014143719069551, 8.857614197163901, 9.723878373652612, 10.687407819460523, 11.6652093579191, 12.646697351092497, 13.536281923866666, 13.918923036076627, 13.080883968292627, 13.869191957098227, 14.612337879829477, 14.500591202182084, 13.51424404131083, 12.608403827125372, 12.582109885584025, 11.577420636165343, 10.67568090190148, 9.68467005550912, 8.916653550956708, 8.10926914719163, 9.063397467910724, 9.81994335564443, 10.749181064051289, 11.69363781770575, 12.618987937939465, 13.55519580807925, 13.934689162797445, 12.924147670344684, 12.065837263271453, 12.931596542209192, 13.588980991057738, 14.629257108945804, 14.466999355323487, 13.547807690627808, 13.512864693102907, 12.642871508268996, 11.626389792439767, 10.642602862908596, 9.976533410352946, 9.058810681780278, 10.022178399178511, 10.88235929447887, 11.731493932236585, 12.692663550359432, 13.556640176951227, 13.67397805351909, 12.926172890112127, 11.89295466681359, 11.032686943472985, 11.939874665082568, 12.625957101218729, 13.610453409089734, 14.556925671344619, 14.479368920394592, 14.491328962198557, 13.580909126587631, 12.594877352585709, 11.574786961267613, 11.000310447998558, 10.11049953996549, 11.01295949711154, 11.8523148790577, 12.675304595447367, 13.663347405230514, 13.52315055970701, 12.602524797195498, 11.885474989419595, 10.945026632762403, 10.008941049213588, 10.890696145362766, 11.66576436990951, 12.630437007665497, 13.591240458608437, 14.591080825939935, 14.650526919263147, 14.473415032661983, 13.512238999932702, 12.575323819949253, 11.9342467130502, 11.167767185340645, 11.965502481030967, 12.917337111915685, 13.691015130576206, 13.488400260499741, 12.5510686817934, 11.666430930281544, 10.891944282929035, 9.887002613589637, 9.0162010111612, 9.955167281610876, 10.70352241632227, 11.735734886699728, 12.769229877142228, 13.701509763415645, 13.622773924588296, 14.626043522409642, 14.500211103934086, 13.50801553211645, 12.901838186452085, 12.237257356599756, 12.973129069032742, 13.953227184940719, 13.453331971106582, 12.629353764352752, 11.606485532916393, 10.702975307268733, 9.863535943655496, 8.871745816100335, 7.990969402973632, 8.92618848932379, 9.73687768136497, 10.739291289731616, 11.700053062596773, 12.678153015565854], [12.667431056905949, 11.7177865437864, 10.72444420824241, 9.76465205470084, 8.876679306969752, 7.967596654332236, 6.953314751410398, 7.946605113646514, 8.729909171329583, 9.621228592686167, 10.608794429623417, 11.455096052807017, 12.419038725447411, 12.972118867678516, 13.919293318848407, 14.720288977828599, 15.354109486547888, 15.52955367426238, 14.531983697919632, 13.58095548163383, 11.711671071637065, 10.766586977283806, 9.865701693006836, 8.824253975712896, 7.889100570987595, 6.94988448070026, 6.01342154733246, 6.946236846303374, 7.752989930901299, 8.629074889770918, 9.583180147779698, 10.512813157180963, 11.551537175153689, 12.53281365151844, 13.571335088213074, 14.577704969550584, 15.523500267236365, 14.585806883437066, 13.599187566396965, 12.652261177840945, 10.80663776986855, 9.765931155494993, 8.830870230314906, 7.833004873457012, 6.879996809699074, 5.961546034200955, 4.98981987584471, 5.897014368729895, 6.7775656207413935, 7.695899315226015, 8.73664445600113, 9.71605286212152, 10.673302857501268, 11.621886853573976, 12.594886743440743, 13.651158724013461, 14.541554849626621, 13.70462843270597, 12.751274972708721, 11.748673345907944, 9.777588429039103, 8.804522080655847, 7.820305413836798, 6.870494249464725, 5.927046913634406, 4.9377746081150145, 4.032383299257834, 4.840063706170871, 5.79623589746444, 6.742332964368423, 7.777084264836535, 8.742767009184972, 9.706398057848363, 10.751506626633876, 11.799620747604003, 12.75662748071393, 13.587888633360489, 12.64975901137094, 11.699327113483296, 10.761819273748104, 8.832565128773599, 7.839146352416851, 6.871303778362524, 5.83162107748322, 4.867414211019942, 3.933766282311389, 3.0223306260548477, 3.8094088164155964, 4.791840302314875, 5.8203922141079065, 6.835856786635448, 7.8126752546971785, 8.805643309074844, 9.830467736225826, 10.893876621401112, 11.795043245208845, 12.692329886188235, 11.688293790620486, 10.711056886082174, 9.770465732801787, 7.8855225881731075, 6.959249063363334, 5.981513449400833, 4.9535882479021565, 3.9377810312036825, 3.0001739714884867, 1.9599141446395283, 2.884160175630349, 3.8570730360659033, 4.8427248896859085, 5.777314878543703, 6.8037609563656325, 7.857268547780208, 8.828679748494364, 9.89500975990898, 10.836421816371619, 11.736601349711897, 10.72970926647975, 9.793747084108759, 8.813317119924154, 6.8923205000497445, 5.945508524491163, 4.9779869052670405, 3.964384818913466, 2.9881125670593933, 1.9721227344092855, 0.9535673408247436, 1.9380662289140385, 2.8962222932887265, 3.9099111695402105, 4.915696359725034, 5.881477363512564, 6.81195790194303, 7.857795568024944, 8.865612348324595, 9.844322006828653, 10.803767320194652, 9.795089402833188, 8.829628768399596, 7.824274832005778, 5.925114186751602, 4.934446603852846, 3.9868359049477133, 2.975156387822229, 1.9543993472942522, 0.9866600585672796, 0.0, 0.9915574464739382, 2.033469633788001, 3.000672103330542, 4.06027431256756, 5.015952781814548, 6.01646694763731, 7.082548756295224, 8.06682383068736, 9.008917345983713, 9.93415624051301, 9.002298560234486, 7.97704304022612, 6.9857867284826725, 6.85371424285576, 5.918575306161412, 4.93979029206466, 4.012528368691485, 2.9857871806611502, 1.968703121266922, 1.0046342551955079, 1.9958703220132588, 3.0215426543811006, 3.9637341536798956, 4.959380158822302, 5.96712027069145, 6.9267835481861955, 7.990511929327875, 8.944120652317654, 9.881860057636437, 10.886508582723959, 10.00178580238539, 8.964816865013448, 7.905486121389338, 7.835739498041311, 6.892765546667424, 5.974909527243003, 4.960076564714231, 3.9766854785581978, 2.9804992216131776, 1.9378478031142636, 2.8732540113411096, 3.843055703254409, 4.778451215498343, 5.731768807766096, 6.714617877549546, 7.72701118738267, 8.660564032152232, 9.73530882253547, 10.802147445585023, 11.864239777773681, 10.84971763703048, 9.894800719887357, 8.906881478131403, 8.76835689440664, 7.818195145023635, 6.837222282960863, 5.82943583648882, 4.887537356715585, 3.8213096325923726, 2.8756650068285023, 3.7995232924398303, 4.822215452549124, 5.799043875995765, 6.681075265730711, 7.73706949986295, 8.668217497969215, 9.615186883744599, 10.540387327148064, 11.52122527185667, 12.576879611068106, 11.79136159995974, 10.793694486585489, 9.793245100974588, 9.7229299887581, 8.787690531840129, 7.746096319439796, 6.786413546144642, 5.8531412851962275, 4.865587381469025, 3.8961772555619083, 4.779712274550983, 5.843719312953445, 6.789964376711336, 7.656458789256894, 8.646208593801992, 9.622620855995542, 10.596862941136843, 11.556470657760764, 12.493999111055844, 13.452297571930464, 12.792169796642796, 11.775686196563237, 10.725707312554842, 10.624102386131602, 9.611176951809863, 8.681563129090184, 7.717710860346588, 6.872923392897778, 5.8781873986215585, 4.904533544932544, 5.8494167156762735, 6.8515332477963575, 7.822891142202423, 8.664511748258127, 9.662803358410883, 10.597549466663787, 11.59598954086672, 12.58537531762552, 13.437497651029235, 14.38361062804073, 13.6056490022938, 12.640662935677575, 11.598274858925748, 11.535429776864515, 10.5742000273039, 9.621020072361803, 8.690634243565372, 7.808119076334835, 6.8393500401607685, 5.954107181707925, 6.861390715855544, 7.804232710744125, 8.781361510326185, 9.706710530803129, 10.710436344989187, 11.590620190556049, 12.55344540750369, 13.524173314022716, 14.375024440389094, 15.349749819548563, 14.510499836339601, 13.469506073940812, 12.526812483010966, 12.481279044411785, 11.543771296904842, 10.54822300567291, 9.653333330382084, 8.745559100342774, 7.874801019973387, 7.027483660502272, 7.8709541385966215, 8.737218315085332, 9.700747760893243, 10.67854929935182, 11.660037292525217, 12.549621865299388, 12.993824624156153, 14.016553235539982, 14.83310435714471, 15.576250279875959, 15.425108848267653, 14.438761687396399, 13.53292147321094, 13.506627531669594, 12.501938282250912, 11.570114155739292, 10.579103309346932, 9.786005146442417, 8.905108449831356, 8.076737409343444, 8.83328329707715, 9.76252100548401, 10.70697775913847, 11.632327879372186, 12.56853574951197, 13.00959075087697, 11.99904925842421, 13.001506530518808, 13.895508942255676, 14.55289339110422, 15.593169508992286, 15.391517001409056, 14.472325336713377, 14.437382339188476, 13.559144981850068, 12.52082304627758, 11.537036116746409, 10.845885005838655, 9.854649984420004, 9.035518340611231, 9.895699235911591, 10.744833873669306, 11.706003491792153, 12.569980118383947, 12.687317994951812, 12.001074478191653, 10.967856254893116, 11.96835621072034, 12.903787065129052, 13.58986950126521, 14.574365809136216, 15.5208380713911, 15.40388656648016, 15.415846608284125, 14.475342380425444, 13.48931060642352, 12.469220215105425, 11.86146288439396, 10.906338842605216, 10.02629943854426, 10.86565482049042, 11.688644536880087, 12.676687346663234, 12.536490501139733, 11.61586473862822, 10.96037657749912, 10.019928220841928, 10.944610316460944, 11.85460854540925, 12.629676769955992, 13.594349407711979, 14.55515285865492, 15.554993225986417, 15.614439319309628, 15.367848286499797, 14.406672253770516, 13.469757073787065, 12.795399149445602, 11.963606487980371, 10.97884242246369, 11.930677053348406, 12.704355072008926, 12.501740201932463, 11.564408623226122, 10.679770871714267, 9.96684587100856, 8.961904201669162, 9.951870278408556, 10.91907968165736, 11.667434816368752, 12.69964728674621, 13.73314227718871, 14.665422163462127, 14.586686324634778, 15.589955922456124, 15.394644357771899, 14.402448785954263, 13.762990622847488, 12.941989092654593, 11.986469010465465, 12.96656712637344, 12.466671912539304, 11.642693705785474, 10.619825474349115, 9.716315248701456, 8.93843753173502, 7.94664740417986, 8.926638670220989, 9.890100889370274, 10.700790081411451, 11.703203689778098, 12.663965462643255, 13.642065415612336], [13.48330370343406, 12.533659190314511, 11.540316854770522, 10.580524701228951, 9.692551953497864, 8.705853311841866, 7.691571408920028, 6.955047667172575, 7.738351724855644, 8.629671146212228, 9.617236983149478, 10.463538606333078, 11.427481278973472, 12.417474177615574, 13.374073708470151, 14.345109535726813, 15.383610470137413, 16.34542632079049, 15.347856344447742, 14.396828128161939, 12.527543718165175, 11.582459623811916, 10.681574339534947, 9.640126622241008, 8.704973217515708, 7.765628693371662, 6.751678204842091, 5.954679399829436, 6.76143248442736, 7.637517443296979, 8.59162270130576, 9.521255710707024, 10.55997972867975, 11.541256205044501, 12.579777641739135, 13.586147523076646, 14.549107894221878, 15.401679529965175, 14.415060212925075, 13.468133824369055, 11.62251041639666, 10.581803802023103, 9.646742876843017, 8.648877519985124, 7.695869456227186, 6.777290246872357, 5.728076533354341, 4.905456922255957, 5.7860081742674545, 6.704341868752076, 7.745087009527191, 8.724495415647581, 9.68174541102733, 10.630329407100039, 11.603329296966805, 12.659601277539524, 13.634652077151415, 14.558766502171327, 13.605413042174078, 12.602811415373301, 10.63172649850446, 9.620394727183957, 8.636178060364909, 7.686366895992836, 6.742919560162517, 5.753647254643125, 4.770639956767464, 3.848506259696933, 4.804678450990501, 5.750775517894484, 6.785526818362596, 7.7512095627110345, 8.714840611374425, 9.75994918015994, 10.808063301130066, 11.765070034239992, 12.680985860885283, 13.503897080836296, 12.553465182948653, 11.615957343213461, 9.686703198238956, 8.65501899894496, 7.687176424890635, 6.647493724011331, 5.683286857548053, 4.7496389288395, 3.7605872835644787, 2.8178513699416583, 3.800282855840937, 4.8288347676339685, 5.84429934016151, 6.82111780822324, 7.814085862600905, 8.838910289751887, 9.902319174927172, 10.803485798734906, 11.700772439714296, 12.542431860085843, 11.56519495554753, 10.624603802267144, 8.877080034647047, 7.950806509837273, 6.96048517563138, 5.932559974132705, 4.903784762654195, 3.966177702938999, 2.9259178760900406, 1.892602729156411, 2.8655155895919653, 3.8511674432119705, 4.785757432069765, 5.812203509891694, 6.86571110130627, 7.837122302020426, 8.903452313435041, 9.84486436989768, 10.745043903237958, 11.721266712953687, 10.785304530582696, 9.804874566398091, 7.8838779465236835, 6.937065970965102, 5.969544351740979, 4.955942265387404, 3.9796700135333314, 2.9636801808832236, 1.9451247872986817, 0.9465087824401004, 1.9046648468147886, 2.9183537230662724, 3.924138913251096, 4.889919917038626, 5.820400455469092, 6.866238121551005, 7.874054901850656, 8.852764560354714, 9.812209873720713, 10.786646849307125, 9.821186214873533, 8.815832278479716, 6.916671633225541, 5.926004050326785, 4.978393351421652, 3.9667138342961676, 2.9459567937681905, 1.9782175050412176, 0.9915574464739382, 0.0, 1.0419121873140627, 2.0091146568566036, 3.068716866093621, 4.024395335340609, 5.024909501163371, 6.090991309821285, 7.075266384213421, 8.017359899509774, 8.964684489408434, 9.896542169686958, 8.96860048670006, 7.977344174956611, 7.8452716893296985, 6.910132752635351, 5.931347738538599, 5.004085815165423, 3.9773446271350883, 2.96026056774086, 1.9961917016694462, 1.0686802312405839, 2.094352563608426, 2.972176707205957, 3.9678227123483634, 4.975562824217511, 5.9352261017122565, 6.998954482853936, 7.952563205843714, 8.890302611162499, 9.89495113625002, 10.838381876394063, 9.956374311487387, 8.897043567863278, 8.82729694451525, 7.884322993141363, 6.966466973716942, 5.95163401118817, 4.968242925032136, 3.9720566680871157, 2.9294052495882017, 2.0118525977657047, 2.981654289679004, 3.9170498019229387, 4.8703673941906915, 5.853216463974142, 6.865609773807266, 7.799162618576828, 8.873907408960067, 9.876233989346858, 10.9502062148801, 11.790076118057303, 10.886358166361298, 9.898438924605344, 9.759914340880579, 8.809752591497574, 7.828779729434802, 6.820993282962759, 5.879094803189524, 4.812867079066311, 3.8672224533024404, 2.9381218788644254, 3.9608140389737194, 4.93764246242036, 5.819673852155306, 6.875668086287545, 7.806816084393809, 8.753785470169193, 9.678985913572658, 10.659823858281264, 11.7154781974927, 12.653960665475534, 11.785251933059428, 10.784802547448527, 10.714487435232039, 9.779247978314068, 8.737653765913734, 7.77797099261858, 6.8446987316701655, 5.857144827942963, 4.887734702035846, 3.918310860975578, 4.98231789937804, 5.928562963135931, 6.795057375681489, 7.784807180226588, 8.761219442420137, 9.735461527561437, 10.695069244185358, 11.632597697480438, 12.590896158355058, 13.575443570588872, 12.767243643037176, 11.717264759028781, 11.61565983260554, 10.6027343982838, 9.673120575564122, 8.709268306820526, 7.864480839371716, 6.869744845095496, 5.896090991406481, 4.988015302100869, 5.990131834220953, 6.9614897286270185, 7.803110334682722, 8.80140194483548, 9.736148053088382, 10.734588127291314, 11.723973904050114, 12.576096237453829, 13.522209214465324, 14.49245579781208, 13.632220382151512, 12.589832305399685, 12.526987223338452, 11.565757473777838, 10.61257751883574, 9.682191690039309, 8.799676522808772, 7.830907486634706, 6.945664628181862, 5.999989302280139, 6.94283129716872, 7.91996009675078, 8.845309117227723, 9.849034931413783, 10.729218776980643, 11.692043993928284, 12.66277190044731, 13.513623026813688, 14.488348405973158, 15.480905910679951, 14.461063520414749, 13.518369929484903, 13.472836490885722, 12.535328743378779, 11.539780452146847, 10.644890776856021, 9.737116546816711, 8.866358466447323, 8.019041106976209, 7.009552725021217, 7.875816901509927, 8.839346347317838, 9.817147885776414, 10.798635878949813, 11.688220451723982, 12.707165842585992, 13.614624288284324, 14.49420412772937, 15.468034653054808, 16.41052406907998, 15.430319133870336, 14.524478919684878, 14.49818497814353, 13.493495728724849, 12.561671602213229, 11.57066075582087, 10.777562592916354, 9.896665896305292, 8.954503252923438, 7.971881883501745, 8.901119591908603, 9.845576345563064, 10.77092646579678, 11.707134335936564, 12.066411697451679, 12.73730591593384, 13.739763188028439, 14.704079343914488, 15.368766037632332, 16.409042155520396, 16.383074447882993, 15.463882783187314, 15.428939785662413, 14.550702428324005, 13.512380492751516, 12.528593563220346, 11.837442452312592, 10.846207430893939, 9.913284184191225, 9.034297822336187, 9.8834324600939, 10.844602078216747, 11.708578704808541, 11.695760548477873, 11.028498117594701, 11.706112912402746, 12.706612868229971, 13.712357466787864, 14.405742147793323, 15.390238455664328, 16.336710717919214, 16.395444012954098, 16.407404054758064, 15.46689982689938, 14.480868052897458, 13.460777661579362, 12.815490511782544, 11.8603664699938, 10.904065282124254, 10.004253406915016, 10.827243123304681, 11.815285933087829, 11.544933054665794, 10.624307292154281, 9.97990949274169, 10.758184878351559, 11.682866973970572, 12.663178947068062, 13.445549416484104, 14.41022205424009, 15.371025505183031, 16.37086587251453, 16.43031196583774, 16.359405732973734, 15.398229700244453, 14.461314520261002, 13.749426776834186, 12.910941478855259, 11.856608266043683, 11.069275639773002, 11.84295365843352, 11.510182755458525, 10.572851176752183, 9.688213425240328, 8.985076502532205, 9.700160859178792, 10.690126935918185, 11.727650083316172, 12.483307462896864, 13.515519933274321, 14.549014923716822, 15.481294809990239, 15.402558971162888, 16.405828568984234, 16.386201804245836, 15.3940062324282, 14.717018250236071, 13.819754936234586, 12.864234854045458, 12.105165712798035, 11.475114466065365, 10.651136259311535, 9.628268027875176, 8.724757802227517, 7.956668163258667, 8.68490406168949, 9.664895327730617, 10.705973535898385, 11.516662727939563, 12.51907633630621, 13.479838109171366, 14.457938062140448], [14.436766875596913, 13.487122362477363, 12.493780026933374, 11.533987873391803, 10.646015125660716, 9.659316484004718, 8.64503458108288, 7.900399349538809, 6.890203315991492, 7.781522737348076, 8.769088574285325, 9.615390197468924, 10.579332870109319, 11.56932576875142, 12.525925299605998, 13.49696112686266, 14.535462061273261, 15.547654020422101, 16.301319516610597, 15.350291300324795, 13.48100689032803, 12.535922795974772, 11.6350375116978, 10.59358979440386, 9.65843638967856, 8.719091865534514, 7.705141377004943, 6.900031082195669, 5.913284075563208, 6.789369034432827, 7.743474292441607, 8.67310730184287, 9.711831319815596, 10.692565004805928, 11.662677604443267, 12.669047485780778, 13.63200785692601, 14.676989349983515, 15.368523385087931, 14.42159699653191, 12.575973588559515, 11.535266974185959, 10.60020604900587, 9.602340692147976, 8.649332628390038, 7.730753419035209, 6.681539705517193, 5.858920094418809, 4.937859765403303, 5.856193459887924, 6.892407898129582, 7.803690617418698, 8.721862761256554, 9.670446757329263, 10.64344664719603, 11.699718627768748, 12.671803120564888, 13.711135947623339, 14.55887621433693, 13.556274587536153, 11.585189670667312, 10.57385789934681, 9.589641232527763, 8.639830068155689, 7.696382732325369, 6.707110426805977, 5.724103128930317, 4.801969431859785, 3.9565300421263494, 4.902627109030332, 5.825644168591818, 6.7913269129402565, 7.754957961603648, 8.800066530389161, 9.848180651359288, 10.802221077653467, 11.718136904298758, 12.656266526288308, 13.506928355111505, 12.569420515376313, 10.640166370401808, 9.608482171107813, 8.640639597053486, 7.600956896174183, 6.636750029710905, 5.703102101002352, 4.714050455727331, 3.7713145421045104, 2.9348855911840683, 3.8689521178631905, 4.884416690390732, 5.8612351584524625, 6.854203212830127, 7.87902763998111, 8.942436525156396, 9.840636842148381, 10.737923483127771, 11.764909337418203, 12.518658127710383, 11.578066974429996, 9.860561362894217, 8.905355361397486, 7.913948347794234, 6.886023146295558, 5.857247934817048, 4.919640875101852, 3.8793810482528928, 2.846065901319263, 1.9246669222819601, 2.8912847934411925, 3.825874782298987, 4.8523208601209165, 5.902862144719746, 6.8742733454339024, 7.940603356848517, 8.882015413311155, 9.782194946651433, 10.734471394737348, 11.67103660523475, 10.791189473605135, 8.925790133837745, 7.978978158279165, 7.011456539055042, 5.979950282797499, 5.003678030943426, 3.9876881982933186, 2.9152732752349095, 1.8999719546029525, 0.9418158902282644, 1.9555047664797485, 2.9612899566645723, 3.9270709604521024, 4.857551498882568, 5.903389164964482, 6.911205945264133, 7.88991560376819, 8.849360917134188, 9.799851531090786, 10.765312165524378, 9.857744465793779, 7.958583820539604, 6.967916237640848, 6.020305538735715, 5.0086260216102305, 3.9878689810822534, 3.0201296923552805, 2.033469633788001, 1.0419121873140627, 0.0, 0.9672024695425411, 2.0268046787795586, 2.982483148026547, 3.982997313849309, 5.049079122507223, 6.033354196899358, 6.975447712195711, 7.922772302094371, 8.854629982372895, 9.879885502381262, 9.019256362270674, 8.88718387664376, 7.952044939949414, 6.973259925852662, 6.045998002479486, 5.019256814449151, 4.002172755054922, 3.0381038889835086, 2.100645642056136, 1.0749733096882939, 1.9302645198918946, 2.9259105250343014, 3.933650636903449, 4.893313914398194, 5.957042295539873, 6.910651018529651, 7.848390423848436, 8.853038948935957, 9.796469689080002, 10.833438626451944, 9.93895575517734, 9.869209131829313, 8.926235180455427, 8.008379161031005, 6.988156556757109, 6.004765470601075, 5.008579213656055, 3.9339941775287626, 2.9985879693019166, 2.028786277388617, 2.900366951916027, 3.85368454418378, 4.83653361396723, 5.848926923800354, 6.782479768569916, 7.857224558953154, 8.834321802032795, 9.908294027566036, 10.748163930743242, 11.703080847886365, 10.940351111919407, 10.764503268821139, 9.814341519438134, 8.833368657375361, 7.825582210903319, 6.883683731130084, 5.817456007006871, 4.871811381243001, 3.9248572504006374, 3.0079460266833324, 3.9232006265749124, 4.802991002148395, 5.858985236280634, 6.790133234386897, 7.737102620162282, 8.662303063565746, 9.643141008274352, 10.698795347485788, 11.637277815468622, 12.634944928842874, 11.789391475389086, 11.719076363172599, 10.783836906254628, 9.742242693854296, 8.782559920559141, 7.8492876596107255, 6.861733755883523, 5.892323629976406, 4.90504623251179, 4.050657078323503, 4.914121127290484, 5.778374525674578, 6.768124330219677, 7.744536592413225, 8.718778677554527, 9.678386394178446, 10.615914847473526, 11.574213308348146, 12.55876072058196, 13.582341491985972, 12.721853686969341, 12.620248760546101, 11.607323326224362, 10.677709503504683, 9.713857234761086, 8.869069767312276, 7.874333773036056, 6.900679919347041, 5.974750673637081, 5.058471013166416, 5.967602774645357, 6.78642748467581, 7.784719094828567, 8.71946520308147, 9.717905277284403, 10.707291054043202, 11.559413387446916, 12.505526364458412, 13.475772947805167, 14.440759014421392, 13.594421233340247, 13.531576151279014, 12.5703464017184, 11.617166446776302, 10.686780617979869, 9.804265450749332, 8.835496414575266, 7.950253556122422, 6.986724673816351, 6.0111704761141835, 6.988299275696244, 7.8286262672208125, 8.83235208140687, 9.71253592697373, 10.675361143921371, 11.646089050440398, 12.496940176806776, 13.471665555966245, 14.464223060673039, 15.448459794875015, 14.522958857425465, 14.477425418826286, 13.53991767131934, 12.544369380087408, 11.649479704796581, 10.741705474757271, 9.870947394387883, 9.023630034916769, 7.996288096557429, 6.94415608045539, 7.907685526263301, 8.800465035769504, 9.781953028942901, 10.67153760171707, 11.69048299257908, 12.597941438277411, 13.477521277722458, 14.451351803047896, 15.393841219073067, 16.38018837994432, 15.529067847625441, 15.502773906084094, 14.49808465666541, 13.566260530153789, 12.57524968376143, 11.782151520856914, 10.901254824245852, 9.919502820674685, 8.936881451252992, 7.969458770854068, 8.913915524508528, 9.755951317739592, 10.692159187879376, 11.602228206964744, 12.612769699417505, 13.612988143298585, 14.415116692611493, 15.474708691819634, 16.465236428353613, 17.33294369395698, 16.46847171112788, 16.43352871360298, 15.555291356264565, 14.516969420692076, 13.533182491160906, 12.842031380253152, 11.850796358834499, 10.878283751942472, 9.906192839955638, 8.951771639039364, 9.912941257162212, 10.693603556751354, 10.847612139613723, 11.753316725605737, 12.593104491461107, 13.606656363224136, 14.663227979499547, 15.359205319956175, 16.34370162782718, 17.290173890082066, 17.400032940894665, 17.411992982698628, 16.471488754839942, 15.485456980838018, 14.465366589519922, 13.780490079533791, 12.825366037745047, 11.869064849875501, 10.876148424534467, 9.895582302250146, 10.883625112033293, 10.696784645801642, 9.776158883290131, 10.704728100752726, 11.645176457409919, 12.636330146133425, 13.616642119230914, 14.399012588646956, 15.363685226402943, 16.324488677345883, 17.32432904467738, 17.38377513800059, 17.363994660914294, 16.402818628185013, 15.465903448201562, 14.714426344585434, 13.875941046606505, 12.821607833794928, 11.897437227354306, 10.911292837378985, 10.662034346594373, 9.724702767888031, 8.840065016376178, 9.882483392526677, 10.653624031341645, 11.643590108081037, 12.681113255479024, 13.436770635059716, 14.468983105437173, 15.502478095879674, 16.43475798215309, 16.356022143325742, 17.35929174114709, 16.47931833368452, 15.487122761866885, 14.45425948184377, 13.503229525799812, 12.554975625964472, 11.585877606360082, 10.626966057201212, 9.802987850447382, 8.780119619011025, 7.876609393363366, 8.9020198456249, 9.638367233852343, 10.61835849989347, 11.659436708061238, 12.470125900102415, 13.472539508469062, 14.433301281334218, 15.4114012343033], [15.403969345139453, 14.454324832019903, 13.460982496475914, 12.501190342934343, 11.613217595203256, 10.626518953547256, 9.612237050625419, 8.833024217086914, 7.822828183539598, 6.8429849638534925, 7.830550800790742, 8.67685242397434, 9.640795096614735, 10.630787995256837, 11.587387526111414, 12.558423353368076, 13.596924287778677, 14.609116246927517, 15.63516529530767, 16.317493769867333, 14.44820935987057, 13.50312526551731, 12.60223998124034, 11.5607922639464, 10.6256388592211, 9.686294335077056, 8.672343846547482, 7.832655949743774, 6.845908943111314, 5.850831260938244, 6.804936518947024, 7.734569528348287, 8.773293546321014, 9.753707884173242, 10.72382048381058, 11.730190365148092, 12.693150736293324, 13.738132229350828, 14.702369163785004, 15.388799466074449, 13.543176058102054, 12.502469443728497, 11.56740851854841, 10.569543161690516, 9.616535097932578, 8.69795588857775, 7.648742175059733, 6.826122563961349, 5.870484632951409, 4.917655686393341, 5.953550777496897, 6.864833496786012, 7.783005640623868, 8.731589636696576, 9.704589526563343, 10.760861507136061, 11.732945999932202, 12.772278826990652, 13.710325666318253, 14.523477057078695, 12.552392140209854, 11.541060368889351, 10.556843702070303, 9.60703253769823, 8.66358520186791, 7.674312896348518, 6.691305598472857, 5.769171901402325, 4.910186402439732, 3.964089335535749, 4.8867870479591335, 5.852469792307571, 6.816100840970963, 7.861209409756476, 8.909323530726603, 9.86336395702078, 10.779279783666071, 11.717409405655621, 12.658377807092828, 13.536622984918855, 11.60736883994435, 10.575684640650355, 9.607842066596028, 8.568159365716724, 7.603952499253445, 6.670304570544892, 5.681252925269871, 4.738517011647051, 3.9020880607266095, 2.930094997230505, 3.9455595697580463, 4.922378037819777, 5.915346092197441, 6.940170519348424, 8.003579404523709, 8.901779721515695, 9.799066362495084, 10.815329859626779, 11.638392848216219, 12.545269443972538, 10.827763832436757, 9.872557830940027, 8.881150817336774, 7.853225615838098, 6.824450404359588, 5.886843344644392, 4.846583517795434, 3.8132683708618043, 2.891869391824501, 1.9524276728085068, 2.8870176616663015, 3.913463739488231, 4.964005024087061, 5.935416224801217, 7.001746236215832, 7.9431582926784685, 8.843337826018747, 9.767268925194807, 10.70383413569221, 11.755283780966774, 9.892992603380288, 8.946180627821706, 7.978659008597583, 6.947152752340041, 5.970880500485968, 4.95489066783586, 3.8824757447774507, 2.8671744241454937, 1.9090183597708055, 1.0166476458470626, 2.022432836031886, 2.9882138398194162, 3.9186943782498824, 4.964532044331795, 5.972348824631446, 6.951058483135504, 7.9105037965015015, 8.832649061548246, 9.79810969598184, 10.803463632375657, 8.925786290082145, 7.935118707183388, 6.9875080082782555, 5.975828491152771, 4.955071450624794, 3.9873321618978212, 3.0006721033305417, 2.0091146568566036, 0.9672024695425411, 0.0, 1.0596022092370176, 2.0152806784840056, 3.0157948443067677, 4.081876652964682, 5.066151727356818, 6.008245242653171, 6.955569832551831, 7.887427512830355, 8.912683032838721, 9.90393934458217, 9.854386346186303, 8.919247409491955, 7.940462395395202, 7.013200472022026, 5.9864592839916915, 4.968744230664135, 3.9446734463225326, 2.9534373795047815, 1.9277650471369394, 0.9630620503493534, 1.95870805549176, 2.966448167360908, 3.926111444855653, 4.989839825997333, 5.943448548987111, 6.881187954305895, 7.885836479393417, 8.82926721953746, 9.866236156909402, 10.864491556662868, 10.836411601371854, 9.893437649997967, 8.87373946430568, 7.8279302739859125, 6.844539187829879, 5.848352930884858, 4.773767894757566, 3.8383616865307197, 2.8685599946174203, 1.933164482373486, 2.886482074641239, 3.8693311444246894, 4.881724454257814, 5.815277299027375, 6.890022089410614, 7.867119332490255, 8.941091558023496, 9.7809614612007, 10.735878378343823, 11.723797620099777, 11.604276986049943, 10.654115236666938, 9.673142374604165, 8.665355928132122, 7.723457448358888, 6.657229724235674, 5.711585098471804, 4.76463096762944, 3.847719743912136, 2.9559981570323712, 3.8357885326058536, 4.891782766738093, 5.822930764844356, 6.7699001506197405, 7.695100594023205, 8.67593853873181, 9.731592877943246, 10.67007534592608, 11.667742459300332, 12.62916519261789, 12.558850080401402, 11.623610623483431, 10.582016411083098, 9.622333637787943, 8.689061376839529, 7.7015074731123265, 6.73209734720521, 5.7448199497405925, 4.890430795552307, 3.946918657747943, 4.811172056132037, 5.8009218606771356, 6.777334122870684, 7.751576208011985, 8.711183924635906, 9.648712377930984, 10.607010838805603, 11.591558251039418, 12.61513902244343, 13.561627404198145, 13.460022477774903, 12.447097043453164, 11.517483220733485, 10.553630951989888, 9.70884348454108, 8.714107490264858, 7.740453636575845, 6.814524390865883, 5.89824473039522, 5.000400305102816, 5.819225015133269, 6.817516625286026, 7.752262733538928, 8.750702807741863, 9.740088584500661, 10.592210917904374, 11.53832389491587, 12.508570478262625, 13.47355654487885, 14.434194950569049, 14.371349868507815, 13.410120118947201, 12.456940164005104, 11.52655433520867, 10.644039167978136, 9.675270131804067, 8.790027273351225, 7.8264983910451535, 6.850944193342987, 6.0712099370380965, 6.86142379767827, 7.8651496118643305, 8.745333457431189, 9.70815867437883, 10.678886580897858, 11.529737707264234, 12.504463086423703, 13.497020591130497, 14.481257325332473, 15.362732574654267, 15.317199136055088, 14.379691388548142, 13.38414309731621, 12.489253422025383, 11.581479191986075, 10.710721111616685, 9.86340375214557, 8.83606181378623, 7.783929797684194, 7.006312456659595, 7.833262566226962, 8.81475055940036, 9.704335132174528, 10.723280523036538, 11.630738968734871, 12.510318808179916, 13.484149333505353, 14.426638749530525, 15.41298591040178, 16.368841564854243, 16.342547623312896, 15.337858373894212, 14.40603424738259, 13.415023400990231, 12.621925238085717, 11.741028541474654, 10.759276537903489, 9.776655168481795, 8.809232488082872, 8.01381866741358, 8.78874884819705, 9.724956718336834, 10.635025737422202, 11.645567229874963, 12.645785673756045, 13.44791422306895, 14.507506222277092, 15.49803395881107, 16.36574122441444, 17.299881288660757, 17.27330243083178, 16.395065073493367, 15.356743137920878, 14.372956208389708, 13.681805097481956, 12.6905700760633, 11.718057469171276, 10.745966557184442, 9.791545356268168, 9.012844400067262, 9.726401087208812, 10.72874363123847, 11.67293931727918, 12.676760233406057, 13.678935993554513, 14.439636100195575, 15.44449970551021, 16.51683765866714, 17.380050694589777, 18.231442518427542, 18.25176669992743, 17.31126247206874, 16.325230698066818, 15.305140306748724, 14.620263796762595, 13.66513975497385, 12.708838567104305, 11.71592214176327, 10.73535601947895, 10.044309960754015, 9.75824687230706, 10.698085595368058, 11.626654812830653, 12.567103169487845, 13.573476156654216, 14.56843695517738, 15.366215058189496, 16.330887695945485, 17.291691146888425, 18.291531514219923, 18.35097760754313, 17.37936791325223, 16.41819188052295, 15.4812767005395, 14.483313181751072, 13.634181923564338, 12.624064440471663, 11.670055766892975, 10.683911376917655, 9.72349657309979, 8.786164994393449, 9.761991728454104, 10.804410104604603, 11.620826500884183, 12.610792577623576, 13.648315725021563, 14.403973104602256, 15.436185574979714, 16.469680565422216, 17.401960451695633, 17.32322461286828, 16.590753519751154, 15.540780560189937, 14.548584988372301, 13.515721708349187, 12.564691752305228, 11.616437852469888, 10.647339832865498, 9.688428283706628, 8.864450076952798, 7.841581845516441, 8.798536105441293, 9.834644713173006, 10.605569703394881, 11.585560969436008, 12.626639177603778, 13.437328369644955, 14.439741978011602, 15.400503750876759, 16.37860370384584], [16.34834571037875, 15.51392704125692, 14.520584705712931, 13.56079255217136, 12.672819804440273, 11.686121162784275, 10.671839259862438, 9.801572432480118, 8.791376398932801, 7.8115331792466955, 7.066231138891583, 7.843984076018999, 8.807926748659392, 9.797919647301494, 10.745614905938549, 11.71665073319521, 12.736401160843645, 13.63570003302671, 14.57556308607065, 15.364050259970316, 15.375946062381312, 14.56272747475433, 13.661842190477358, 12.620394473183417, 11.685241068458117, 10.745896544314073, 9.731946055784501, 8.801204165136978, 7.814457158504517, 6.819379476331447, 6.028094867926826, 6.901701180392945, 7.899394585596133, 8.848536913488473, 9.818649513125813, 10.825019394463324, 11.664287562177677, 12.691953242201397, 13.642766954547984, 14.435355956177432, 14.435299543175695, 13.562071652965518, 12.627010727785429, 11.629145370927535, 10.676137307169595, 9.757558097814767, 8.708344384296751, 7.8088591639831835, 6.839032848344612, 5.886203901786544, 5.05291901517451, 5.964201734463626, 6.8778346699391, 7.826418666011807, 8.799418555878574, 9.847959368408093, 10.682342144567933, 11.721674971626381, 12.650723457081233, 13.497589405365742, 13.402305696553277, 12.60066257812637, 11.616445911307322, 10.666634746935248, 9.723187411104927, 8.733915105585536, 7.750907807709876, 6.828774110639344, 5.878734617832935, 4.932637550928952, 3.986155285636747, 4.9518380299851845, 5.9109298702861945, 6.872938674495696, 7.9210527954658225, 8.832956549702633, 9.7286759283018, 10.66680555029135, 11.598775597855807, 12.510735333205902, 12.457282396287773, 11.635286849887374, 10.667444275833047, 9.627761574953743, 8.663554708490464, 7.729906779781911, 6.74085513450689, 5.79811922088407, 4.9168464107238234, 3.898643212623708, 3.04492780743566, 4.0217462754973905, 4.934957250809353, 5.946330336737157, 7.000796705685563, 7.871372314197548, 8.748462507130814, 9.755727650389758, 10.578790638979198, 11.519381792259585, 11.626309682440672, 10.932160040177044, 9.940753026573791, 8.912827825075116, 7.884052613596607, 6.946445553881411, 5.906185727032452, 4.872870580098822, 3.9066277418217155, 2.92097588820171, 1.9863858993439152, 3.0128319771658445, 3.933597616768914, 4.90500881748307, 5.971338828897685, 6.912750885360322, 7.792733970654476, 8.707666715957787, 9.64423192645519, 10.695681571729754, 10.67581575509467, 10.005782837058725, 9.0382612178346, 8.006754961577059, 7.030482709722985, 6.014492877072877, 4.942077954014469, 3.926776633382511, 2.968620569007823, 2.0435037323070393, 1.037718542122216, 1.9874814172513793, 2.888286970931736, 3.934124637013649, 4.941941417313299, 5.920651075817357, 6.859899941137231, 7.773046852311226, 8.738507486744819, 9.743861423138636, 9.90500967707622, 8.994720916420407, 8.047110217515273, 7.035430700389789, 6.014673659861812, 5.046934371134839, 4.060274312567559, 3.068716866093621, 2.0268046787795586, 1.0596022092370176, 0.0, 0.955678469246988, 1.95619263506975, 3.022274443727664, 4.006549518119799, 4.948643033416152, 5.895967623314812, 6.827825303593336, 7.853080823601702, 8.84433713534515, 10.833609733180378, 9.978849618728972, 9.00006460463222, 8.072802681259043, 7.046061493228709, 6.028346439901152, 5.00427565555955, 4.0130395887417984, 2.9873672563739566, 2.022664259586371, 1.0519404984727498, 1.9068459581238901, 2.866509235618635, 3.930237616760315, 4.883846339750093, 5.821585745068877, 6.826234270156398, 7.769665010300442, 8.806633947672383, 9.804889347425847, 11.735337390952854, 10.953039859234984, 9.925450701906744, 8.879641511586977, 7.896250425430944, 6.900064168485924, 5.825479132358632, 4.890072924131786, 3.920271232218487, 2.9848757199745526, 2.0315581277067998, 2.9082619408798633, 3.8798454601483385, 4.8133983049179, 5.872548334911746, 6.807517123253236, 7.881489348786477, 8.721359251963682, 9.676276169106805, 10.66419541086276, 12.65598822365101, 11.705826474268004, 10.724853612205232, 9.717067165733189, 8.775168685959954, 7.708940961836741, 6.763296336072871, 5.816342205230507, 4.899430981513203, 4.007709394633438, 2.9808645856714144, 3.938623598975136, 4.8697715970813995, 5.816740982856784, 6.741941426260248, 7.722779370968853, 8.77843371018029, 9.716916178163123, 10.70604610645107, 11.67584362625458, 13.61056131800247, 12.675321861084498, 11.633727648684166, 10.674044875389011, 9.740772614440598, 8.753218710713394, 7.783808584806277, 6.796531187341659, 5.942142033153374, 4.952542325521578, 3.9562481091975976, 4.945997913742696, 5.824174955107727, 6.798417040249029, 7.758024756872949, 8.695553210168027, 9.653851671042647, 10.638399083276461, 11.661979854680473, 12.608305837834834, 14.511733715375971, 13.498808281054233, 12.569194458334554, 11.605342189590957, 10.760554722142146, 9.765818727865925, 8.792164874176912, 7.86623562846695, 6.949955967996287, 6.00602397287645, 4.96430106819883, 5.962592678351587, 6.7991035657759715, 7.7975436399789055, 8.786929416737705, 9.639051750141418, 10.585164727152913, 11.555411310499668, 12.520397377115893, 13.56278545386772, 15.423061106108884, 14.46183135654827, 13.508651401606173, 12.57826557280974, 11.695750405579203, 10.726981369405134, 9.841738510952293, 8.878209628646221, 7.902655430944054, 6.989919220003968, 6.0064998507438325, 7.010225664929892, 7.792174289668232, 8.754999506615873, 9.725727413134901, 10.576578539501277, 11.551303918660746, 12.54386142336754, 13.528098157569517, 14.470791748499362, 16.368910373656156, 15.431402626149211, 14.435854334917279, 13.540964659626452, 12.633190429587142, 11.762432349217754, 10.91511498974664, 9.887773051387299, 8.83564103528526, 7.925021739625467, 6.978338619292524, 7.959826612465922, 8.751175964411571, 9.77012135527358, 10.677579800971914, 11.557159640416959, 12.530990165742399, 13.47347958176757, 14.459826742638825, 15.509073900900542, 17.312419925941587, 16.389569611495283, 15.45774548498366, 14.4667346385913, 13.673636475686784, 12.792739779075722, 11.753675824971408, 10.771054455549715, 9.80363177515079, 8.85917502149633, 7.933824901262613, 8.870032771402396, 9.681866569659245, 10.692408062112007, 11.692626505993088, 12.494755055305994, 13.554347054514137, 14.544874791048114, 15.412582056651484, 16.3467221208978, 18.24317473346047, 17.446776311094435, 16.408454375521945, 15.424667445990776, 14.691107512463473, 13.692151032962647, 12.712456756239195, 11.740365844252361, 10.785944643336087, 9.858200754150014, 8.871477140274374, 9.873819684304031, 10.719780149516223, 11.7236010656431, 12.725776825791556, 13.486476932432618, 14.491340537747252, 15.563678490904184, 16.42689152682682, 17.278283350664587, 18.441137306851665, 17.513022905270894, 16.536981898445603, 15.621290432286107, 14.57547682662985, 13.700040264305294, 12.743739076435748, 11.892411396632136, 10.866753564091152, 10.213447093084342, 9.881126769790932, 10.901890582971784, 11.768368774369234, 12.671529099694288, 13.677902086860659, 14.53565545215242, 15.45153326905647, 16.416205906812458, 17.377009357755398, 18.242493741630344, 17.397534097646112, 16.5188447863172, 15.557668753587919, 14.620753573604468, 13.641540561578207, 12.792409303391473, 11.791196092516321, 10.837187418937633, 9.851043028962312, 9.17159447874906, 9.754713209786651, 10.730539943847306, 11.772958319997805, 12.680428710121202, 13.670394786860594, 14.707917934258582, 15.463575313839273, 16.49578778421673, 17.529282774659233, 18.361723465534833, 16.369781102971263, 15.633535310607144, 14.680257433254905, 13.68806186143727, 12.673949088176322, 11.722919132132363, 10.783569504514546, 9.814471484910154, 8.855559935751286, 8.10013041505364, 8.810130060909644, 9.767084320834496, 10.803192928566208, 11.6651719126319, 12.645163178673027, 13.686241386840795, 14.496930578881972, 15.499344187248619, 16.460105960113776, 17.389318336668033], [15.392667241131763, 16.34138757216774, 15.476263174959922, 14.51647102141835, 13.628498273687264, 12.641799632031265, 11.627517729109428, 10.757250901727105, 9.747054868179788, 8.767211648493683, 7.952126723777219, 6.926640339037252, 7.890583011677647, 8.84479572471109, 9.78993643669156, 10.760972263948222, 11.780722691596658, 12.680021563779723, 13.619884616823663, 14.40837179072333, 14.420267593134325, 15.365351687487584, 14.617520659724347, 13.576072942430407, 12.640919537705107, 11.701575013561063, 10.687624525031492, 9.756882634383965, 8.770135627751504, 7.7750579455784345, 6.913990452812462, 5.984357443411199, 6.943716116349146, 7.892858444241486, 8.862971043878824, 9.869340925216335, 10.70860909293069, 11.73627477295441, 12.687088485300997, 13.479677486930445, 13.479621073928708, 14.446444454843416, 13.582689197032417, 12.584823840174524, 11.631815776416586, 10.713236567061758, 9.664022853543742, 8.764537633230171, 7.7947113175916, 6.841882371033532, 6.008597484421498, 5.0468579974818795, 5.922156200692112, 6.870740196764819, 7.843740086631586, 8.892280899161106, 9.726663675320946, 10.765996502379394, 11.695044987834246, 12.541910936118756, 12.44662722730629, 13.485035380004268, 12.57212438055431, 11.622313216182237, 10.678865880351918, 9.689593574832525, 8.706586276956864, 7.784452579886333, 6.8344130870799225, 5.88831602017594, 4.941833754883735, 4.034494293003438, 4.955251401039207, 5.9172602052487075, 6.965374326218834, 7.877278080455646, 8.772997459054814, 9.711127081044364, 10.64309712860882, 11.555056863958916, 11.501603927040787, 12.533288126334782, 11.623122745080035, 10.583440044200731, 9.619233177737453, 8.6855852490289, 7.6965336037538785, 6.753797690131059, 5.872524879970811, 4.854321681870696, 4.000606276682648, 3.104402538515644, 3.979278781562365, 4.990651867490168, 6.045118236438574, 6.91569384495056, 7.792784037883827, 8.800049181142771, 9.623112169732211, 10.563703323012598, 10.670631213193685, 11.625837214690415, 10.896431495820782, 9.868506294322106, 8.839731082843596, 7.902124023128399, 6.86186419627944, 5.828549049345811, 4.862306211068703, 3.8766543574486976, 2.942064368590903, 2.082358962462716, 2.9779191475219258, 3.9493303482360815, 5.015660359650696, 5.957072416113334, 6.837055501407489, 7.7519882467108, 8.688553457208203, 9.740003102482767, 9.720137285847683, 10.695722782029472, 9.993939687081589, 8.962433430824046, 7.986161178969974, 6.970171346319866, 5.897756423261457, 4.8824551026295, 3.9242990382548113, 2.9991822015540275, 1.9933970113692039, 1.0318029480043913, 1.9326085016847476, 2.978446167766661, 3.9862629480663117, 4.964972606570369, 5.904221471890243, 6.817368383064238, 7.782829017497831, 8.78818295389165, 8.949331207829232, 9.939998790727989, 9.002788686762262, 7.991109169636777, 6.9703521291088, 6.002612840381827, 5.015952781814548, 4.02439533534061, 2.982483148026547, 2.0152806784840056, 0.955678469246988, 0.0, 1.000514165822762, 2.066595974480676, 3.050871048872812, 3.992964564169165, 4.940289154067824, 5.872146834346348, 6.897402354354714, 7.888658666098162, 9.87793126393339, 10.874062089305696, 9.955743073879209, 9.028481150506032, 8.001739962475698, 6.984024909148141, 5.959954124806538, 4.968718057988787, 3.9430457256209452, 2.978342728833359, 1.9908936812839277, 0.9511674888769023, 1.9108307663716473, 2.974559147513327, 3.928167870503106, 4.86590727582189, 5.870555800909411, 6.813986541053455, 7.850955478425396, 8.849210878178859, 10.779658921705867, 11.722632873079753, 10.829325115616271, 9.783515925296504, 8.800124839140471, 7.803938582195451, 6.729353546068158, 5.793947337841312, 4.824145645928013, 3.888750133684079, 2.935432541416326, 1.9525834716328756, 2.924166990901351, 3.8577198356709124, 4.91686986566476, 5.851838654006249, 6.92581087953949, 7.765680782716696, 8.720597699859818, 9.708516941615773, 11.74505336357554, 12.60970088797753, 11.628728025914757, 10.620941579442714, 9.67904309966948, 8.612815375546267, 7.667170749782397, 6.720216618940033, 5.803305395222728, 4.911583808342964, 3.8847389993809407, 2.982945129728148, 3.914093127834412, 4.861062513609797, 5.786262957013261, 6.767100901721866, 7.822755240933302, 8.761237708916136, 9.750367637204084, 10.720165157007592, 12.686939521650842, 13.579196274794024, 12.53760206239369, 11.577919289098535, 10.644647028150121, 9.657093124422918, 8.687682998515802, 7.700405601051186, 6.846016446862899, 5.856416739231105, 4.860122522907124, 4.008445712932812, 4.86849648586074, 5.842738571002042, 6.802346287625962, 7.73987474092104, 8.69817320179566, 9.682720614029474, 10.706301385433486, 11.652627368587847, 13.58127945741488, 14.402682694763756, 13.473068872044077, 12.50921660330048, 11.664429135851671, 10.66969314157545, 9.696039287886437, 8.770110042176476, 7.853830381705812, 6.9098983865859775, 5.868175481908357, 5.050463682263058, 5.843425096528984, 6.841865170731919, 7.831250947490718, 8.68337328089443, 9.629486257905926, 10.599732841252681, 11.564718907868906, 12.607106984620733, 14.506495985398827, 15.365705770257794, 14.412525815315696, 13.482139986519263, 12.599624819288728, 11.63085578311466, 10.745612924661817, 9.782084042355747, 8.806529844653578, 7.893793633713494, 6.910374264453358, 6.098096668841363, 6.836495820421244, 7.799321037368885, 8.770048943887915, 9.62090007025429, 10.59562544941376, 11.588182954120553, 12.57241968832253, 13.515113279252375, 15.452345252946099, 16.335277039858735, 15.339728748626802, 14.444839073335975, 13.537064843296667, 12.666306762927277, 11.818989403456163, 10.791647465096824, 9.739515448994785, 8.828896153334991, 7.882213033002049, 7.047697616377393, 7.795497495164582, 8.814442886026592, 9.721901331724927, 10.601481171169972, 11.575311696495412, 12.517801112520583, 13.504148273391838, 14.553395431653556, 16.356741456694596, 17.293444025204806, 16.361619898693185, 15.370609052300823, 14.57751088939631, 13.696614192785246, 12.657550238680932, 11.674928869259238, 10.707506188860314, 9.763049435205854, 8.837699314972138, 8.095118654899922, 8.726188100412257, 9.736729592865018, 10.736948036746101, 11.539076586059007, 12.59866858526715, 13.589196321801127, 14.456903587404497, 15.391043651650813, 17.28749626421348, 17.604007283911137, 16.581582990929306, 15.597796061398137, 14.643575395028472, 13.761090528501825, 12.781396251778373, 11.84764169123646, 10.893220490320186, 10.762075167859537, 9.7753515539839, 9.098905567801557, 9.764101680269235, 10.767922596396112, 11.770098356544569, 12.530798463185631, 13.535662068500265, 14.608000021657197, 15.471213057579835, 16.322604881417597, 17.485458837604682, 16.557344436023907, 15.581303429198616, 14.66561196303912, 13.61979835738286, 12.74691634171489, 11.790615153845344, 10.975067659650389, 9.949409827109404, 10.937452636892552, 10.785001183500457, 10.170358824125149, 10.812690305122246, 11.7158506304473, 12.72222361761367, 13.579976982905434, 14.495854799809484, 15.46052743756547, 16.42133088850841, 17.286815272383354, 16.44185562839913, 15.563166317070213, 14.601990284340932, 13.66507510435748, 12.685862092331218, 11.836730834144484, 10.838072169925917, 9.919843681955886, 8.933699291980565, 9.916726415473292, 10.710391679033638, 11.106452691039102, 11.80752329533173, 12.773874649620065, 13.714963655666057, 14.515505846657323, 15.458096753396724, 16.438700263450077, 17.480790017124367, 17.40604499628785, 15.414102633724278, 14.677856841360157, 13.724578964007918, 12.732383392190282, 11.718270618929333, 10.767240662885374, 9.830445581924142, 8.897127747928408, 7.938216198769539, 8.986025999939276, 9.765808530156631, 10.722762790081482, 11.758871397813195, 12.62085038187889, 13.600841647920017, 14.641919856087785, 15.452609048128963, 16.45502265649561, 17.287566491024595, 16.433639867421046], [14.392153075309002, 15.34087340634498, 16.317892063829145, 15.358099910287574, 14.470127162556487, 13.48124233964921, 12.466960436727373, 11.592209768437884, 10.582013734890568, 9.602170515204461, 8.782898650065281, 7.757412265325313, 7.008769150906368, 7.844281558888328, 8.789422270868798, 9.76045809812546, 10.780208525773894, 11.67950739795696, 12.619370451000902, 13.407857624900569, 13.419753427311564, 14.364837521664823, 15.343294728458005, 14.417701831299631, 13.482548426574331, 12.543203902430287, 11.527067232649436, 10.591841501094745, 9.605094494462284, 8.610016812289212, 7.744762379100523, 6.815129369699259, 5.943201950526384, 6.892344278418724, 7.862456878056062, 8.868826759393574, 9.708094927107926, 10.735760607131647, 11.686574319478236, 12.479163321107684, 12.479106908105948, 13.445930289020655, 14.42431808590164, 13.426452729043747, 12.47344466528581, 11.554865455930981, 10.505651742412965, 9.59949649994095, 8.629670184302379, 7.67684123774431, 6.843556351132277, 5.87762992376994, 4.92164203486935, 5.8702260309420575, 6.843225920808825, 7.891766733338343, 8.726149509498182, 9.765482336556632, 10.694530822011485, 11.541396770295995, 11.44611306148353, 12.484521214181507, 13.413753269423534, 12.46394210505146, 11.520494769221141, 10.531222463701749, 9.54821516582609, 8.62554414508427, 7.669371953790701, 6.723274886886718, 5.776792621594513, 4.865266219291499, 3.954737235216445, 4.916746039425946, 5.964860160396072, 6.876763914632884, 7.772483293232051, 8.710612915221601, 9.64258296278606, 10.554542698136155, 10.501089761218026, 11.53277396051202, 12.464751633949259, 11.425068933069955, 10.460862066606676, 9.527214137898124, 8.538162492623103, 7.595426579000282, 6.707483746681589, 5.689280548581474, 4.835565143393426, 3.935174464803705, 2.978764615739603, 3.9901377016674067, 5.0446040706158115, 5.915179679127798, 6.792269872061064, 7.799535015320009, 8.62259800390945, 9.563189157189838, 9.670117047370923, 10.625323048867653, 11.616730062470905, 10.71013518319133, 9.68135997171282, 8.743752911997623, 7.703493085148665, 6.670177938215035, 5.697265077779481, 4.711613224159476, 3.777023235301681, 2.9131308887507767, 1.9774049816991637, 2.94881618241332, 4.015146193827935, 4.956558250290572, 5.836541335584727, 6.7514740808880385, 7.688039291385441, 8.739488936660004, 8.71962312002492, 9.69520861620671, 10.758772956102824, 9.885964337085525, 8.909692085231452, 7.893702252581344, 6.821287329522935, 5.805986008890978, 4.847829944516289, 3.834141068264805, 2.828355878079982, 1.8625748742924517, 0.9320943358619856, 1.9779320019438988, 2.985748782243549, 3.964458440747607, 4.903707306067481, 5.8168542172414766, 6.7823148516750695, 7.787668788068887, 7.948817042006471, 8.939484624905228, 9.887095323810362, 8.991623335459538, 7.970866294931562, 7.003127006204589, 6.016466947637309, 5.024909501163371, 3.982997313849309, 3.0157948443067677, 1.95619263506975, 1.000514165822762, 0.0, 1.0660818086579138, 2.05035688305005, 2.992450398346403, 3.9397749882450626, 4.871632668523587, 5.896888188531952, 6.8881445002754, 8.877417098110628, 9.873547923482935, 10.840049710927309, 9.988827115522884, 8.96208592749255, 7.943382294346351, 6.919311510004748, 5.928075443186997, 4.902403110819155, 3.9377001140315695, 2.9420541088891627, 1.9023279164821374, 0.9426646389873925, 2.0063930201290723, 2.960001743118851, 3.897741148437635, 4.902389673525157, 5.845820413669201, 6.882789351041142, 7.848696712356098, 9.811492794321612, 10.754466745695499, 11.780485543221506, 10.734676352901738, 9.751285266745706, 8.755099009800686, 7.680513973673394, 6.745107765446548, 5.775306073533248, 4.839910561289314, 3.8865929690215615, 2.903743899238111, 1.956000863517096, 2.8895537082866576, 3.948703738280505, 4.883672526621995, 5.957644752155236, 6.797514655332441, 7.7524315724755635, 8.740350814231519, 10.776887236191286, 11.72704898557429, 12.579888453519994, 11.57210200704795, 10.630203527274716, 9.563975803151504, 8.618331177387633, 7.671377046545269, 6.754465822827964, 5.8627442359482, 4.835899426986176, 3.915105477324027, 2.983957479217763, 3.9309268649931477, 4.856127308396612, 5.836965253105218, 6.892619592316653, 7.831102060299488, 8.78220150981983, 9.751999029623338, 11.718773394266588, 12.696544372390784, 13.488762489998928, 12.529079716703773, 11.59580745575536, 10.608253552028156, 9.638843426121039, 8.651566028656422, 7.797176874468136, 6.80757716683634, 5.811282950512359, 4.940606060528691, 3.9383608372440904, 4.912602922385393, 5.872210639009313, 6.809739092304392, 7.768037553179012, 8.752584965412826, 9.776165736816838, 10.684461241203593, 12.644922205410277, 13.632365315074434, 14.424229299649316, 13.460377030905718, 12.615589563456908, 11.620853569180687, 10.647199715491674, 9.721270469781713, 8.804990809311048, 7.861058814191212, 6.819335909513591, 5.96648394589228, 4.913289447912335, 5.9117295221152695, 6.901115298874068, 7.753237632277782, 8.699350609289276, 9.669597192636031, 10.634583259252256, 11.67074973261613, 13.576360336782177, 14.53759008634279, 15.363686242920934, 14.433300414124501, 13.550785246893964, 12.582016210719896, 11.696773352267055, 10.733244469960983, 9.757690272258817, 8.844954061318727, 7.8615346920585925, 6.853761596781956, 5.906360171804595, 6.869185388752236, 7.8399132952712645, 8.690764421637642, 9.66548980079711, 10.658047305503903, 11.64228403970588, 12.584977630635725, 14.522209604329447, 15.480242984869374, 16.29088917623204, 15.395999500941214, 14.488225270901903, 13.617467190532516, 12.770149831061401, 11.74280789270206, 10.690675876600023, 9.780056580940226, 8.80263793891099, 7.803362544317986, 6.865361846547933, 7.884307237409942, 8.791765683108277, 9.671345522553324, 10.64517604787876, 11.587665463903932, 12.574012624775186, 13.623259783036904, 15.426605808077944, 16.438409970215446, 16.546225549367207, 15.55521470297485, 14.684223478798112, 13.710117897267711, 12.7396630172234, 12.186667424998406, 11.627931094769256, 10.683474341114795, 9.75812422088108, 8.82881204765758, 7.796052451795607, 8.806593944248368, 9.806812388129451, 10.608940937442359, 11.668532936650498, 12.659060673184475, 13.526767938787845, 14.460908003034161, 16.35736061559683, 16.603493118088373, 15.581068825106543, 14.597281895575373, 13.64306122920571, 12.760576362679064, 11.780882085955612, 11.124251486163965, 11.723992416608247, 11.682500073768479, 10.69577645989284, 9.791494859222913, 8.833966031652585, 9.837786947779461, 10.839962707927919, 11.600662814568983, 12.605526419883617, 13.677864373040546, 14.541077408963183, 15.392469232800945, 16.484944671781925, 15.556830270201141, 14.580789263375852, 13.665097797216356, 12.619284191560098, 11.746402175892129, 10.790100988022584, 10.154295901585137, 10.780181753397466, 11.768224563180613, 11.705426089409398, 10.81112387396819, 9.882554656505596, 10.78571498183065, 11.79208796899702, 12.649841334288785, 13.565719151192836, 14.530391788948823, 15.491195239891763, 16.356679623766702, 15.441341462576368, 14.562652151247448, 13.601476118518168, 12.664560938534716, 11.685347926508456, 10.836216668321722, 9.837558004103155, 9.08927366872715, 9.764471218268627, 10.747498341761354, 11.545350545744416, 11.747217740882144, 10.87738764671508, 11.843739001003415, 12.784828007049407, 13.585370198040675, 14.527961104780076, 15.508564614833428, 16.55065436850772, 16.40553083046509, 14.413588467901517, 13.677342675537396, 12.724064798185154, 11.731869226367518, 10.71775645310657, 9.766726497062612, 8.82993141610138, 8.053383595702117, 8.7689881250576, 9.816797926227338, 10.60076739686741, 11.55772165679226, 11.90579598598862, 12.858995798492717, 13.810059615236975, 14.61434899032776, 15.494605839737376, 16.497019448104023, 16.287052325201834, 15.433125701598286], [13.326071266651088, 14.274791597687065, 15.268133933231054, 15.402948263565884, 14.599974969846178, 13.873168893502177, 13.091841307583838, 12.658291577095797, 11.64809554354848, 10.668252323862376, 9.848980458723195, 8.823494073983227, 8.040741557463784, 7.050748658821682, 7.9684495544502525, 8.939485381706914, 9.714126717115981, 10.613425589299046, 11.553288642342988, 12.341775816242652, 12.35367161865365, 13.298755713006909, 14.27721291980009, 15.325793093782407, 14.548630235232244, 13.6092857110882, 12.593149041307349, 11.657923309752658, 10.671176303120196, 9.676098620947126, 8.810844187758438, 7.881211178357173, 6.9991112344365165, 6.098811378352078, 7.041484161637516, 7.911518492651947, 8.642013118450013, 9.669678798473733, 10.620492510820322, 11.41308151244977, 11.413025099448031, 12.379848480362739, 13.415677763601213, 14.296899220629442, 13.539526473943722, 12.620947264588894, 11.571733551070878, 10.665578308598862, 9.695751992960291, 8.742923046402224, 7.909638159790189, 6.943711732427854, 5.977551318779483, 5.0766931308754115, 6.022253204390279, 6.860542868023737, 7.660067700840268, 8.699400527898717, 9.62844901335357, 10.47531496163808, 10.380031252825615, 11.418439405523593, 12.38457743226508, 13.334388596637154, 12.586576577879054, 11.597304272359665, 10.614296974484002, 9.691625953742182, 8.735453762448614, 7.789356695544631, 6.842874430252426, 5.931348027949412, 5.010646519126578, 4.029832921907767, 5.077947042877893, 5.845540049318277, 6.706401484574137, 7.644531106563687, 8.576501154128145, 9.48846088947824, 9.435007952560111, 10.466692151854108, 11.434534725908435, 12.474217426787739, 11.52694387526459, 10.593295946556038, 9.604244301281017, 8.661508387658197, 7.773565555339503, 6.755362357239387, 5.9016469520513395, 5.001256273461618, 4.034673899649736, 3.1032245841492276, 4.042118988241219, 4.883955813813191, 5.72618806340315, 6.7334532066620945, 7.556516195251536, 8.497107348531923, 8.604035238713008, 9.559241240209738, 10.55064825381299, 11.578573455311666, 10.747441780370734, 9.809834720655537, 8.76957489380658, 7.73625974687295, 6.763346886437395, 5.777695032817389, 4.843105043959595, 3.9792126974086903, 3.033314265609296, 2.0619030648951404, 3.012661111453342, 3.9253343849759648, 4.770459526926812, 5.685392272230124, 6.6219574827275265, 7.67340712800209, 7.653541311367006, 8.629126807548795, 9.69269114744491, 10.756387355512366, 9.975773893889366, 8.959784061239258, 7.8873691381808495, 6.872067817548892, 5.913911753174204, 4.90022287692272, 3.894437686737896, 2.9286566829503657, 1.9981761445198996, 1.0681602295803485, 1.9545249169289423, 2.933234575433, 3.837625497409567, 4.750772408583562, 5.716233043017155, 6.721586979410972, 6.882735233348557, 7.873402816247313, 8.821013515152446, 9.83269303227793, 9.036948103589475, 8.069208814862503, 7.082548756295224, 6.090991309821286, 5.049079122507223, 4.081876652964682, 3.022274443727664, 2.066595974480676, 1.0660818086579138, 0.0, 0.9842750743921358, 1.9263685896884888, 2.873693179587148, 3.805550859865672, 4.830806379874038, 5.822062691617486, 7.811335289452714, 8.80746611482502, 9.773967902269392, 10.790220472364782, 10.028167736150461, 9.009464103004262, 7.985393318662661, 6.99415725184491, 5.968484919477068, 5.003781922689482, 4.008135917547076, 2.968409725140051, 2.008746447645306, 0.9940981928372891, 1.9477069158270677, 2.8635346813165206, 3.868183206404042, 4.807774911661002, 5.844743849032943, 6.7826149036981835, 8.773447292313412, 9.716421243687298, 10.763073351046447, 11.728575823635069, 10.745184737479036, 9.748998480534016, 8.674413444406724, 7.739007236179877, 6.769205544266578, 5.833810032022644, 4.8804924397548906, 3.8976433699714397, 2.8852500601383153, 1.9516972153687537, 2.9364089109887215, 3.84946605950088, 4.923438285034121, 5.759469153324242, 6.714386070467365, 7.702305312223319, 9.738841734183087, 10.689003483566092, 11.669976345628864, 12.566001477781281, 11.624102998008047, 10.557875273884834, 9.612230648120963, 8.665276517278597, 7.748365293561293, 6.856643706681529, 5.829798897719505, 4.844354673945246, 3.9132066758389823, 2.9980960923409983, 3.888573937582766, 4.809169650223115, 5.864823989434551, 6.803306457417385, 7.744156007811632, 8.71395352761514, 10.680727892258389, 11.658498870382585, 12.607883677253499, 13.522979187437102, 12.589706926488688, 11.602153022761485, 10.632742896854369, 9.64546549938975, 8.791076345201464, 7.801476637569669, 6.805182421245688, 5.8698552571499105, 4.86761003386531, 3.979772149733243, 4.904657268195467, 5.781943489422289, 6.740241950296909, 7.724789362530723, 8.748370133934735, 9.646415739195394, 11.606876703402078, 12.594319813066235, 13.523933635785914, 14.454276501639047, 13.609489034190238, 12.614753039914017, 11.641099186225004, 10.715169940515041, 9.798890280044377, 8.854958284924543, 7.813235380246921, 6.8957331425135, 5.842538644533554, 4.97889874946312, 5.933561928060222, 6.725442029395679, 7.671555006407173, 8.641801589753928, 9.606787656370154, 10.632704230607931, 12.548564733900074, 13.509794483460688, 14.463390579057533, 15.40513004049717, 14.544684717627295, 13.575915681453226, 12.690672823000384, 11.727143940694312, 10.751589742992145, 9.77598727143378, 8.792567902173644, 7.783010793403175, 6.835609368425814, 6.021061227548066, 6.8723599244574185, 7.662968818755538, 8.637694197915007, 9.6302517026218, 10.614488436823777, 11.557182027753623, 13.494414001447346, 14.452447381987273, 15.390593512368639, 15.414902873281784, 14.922414418283045, 13.946892427059032, 12.995383865997924, 12.73670736343539, 11.674619236863188, 10.711089791055278, 9.73188713553221, 8.732611740939205, 7.794611043169152, 7.051331434838083, 7.824212312294431, 8.64354991967122, 9.617380444996659, 10.55986986102183, 11.546217021893085, 12.595464180154803, 14.398810205195844, 15.410614367333343, 15.480143740709297, 14.489132894316937, 13.881968372183403, 12.916584997201063, 11.946130117156752, 12.928751486578445, 12.557180291390475, 11.612723537736015, 10.687373417502299, 9.7580612442788, 8.725301648416826, 8.046106800570026, 8.839259017315605, 9.581145334560254, 10.640737333768397, 11.631265070302375, 12.498972335905744, 13.43311240015206, 15.329565012714726, 15.53741130943046, 14.51498701644863, 13.53120008691746, 12.822088512787165, 11.967043462612416, 10.987349185888965, 11.969363133323881, 12.790074225266162, 12.611749270389698, 11.62502565651406, 10.720744055844133, 9.763215228273804, 9.07729980410112, 9.872409337114073, 10.572867211686878, 11.577730817001513, 12.650068770158445, 13.513281806081082, 14.364673629918844, 15.418862863124007, 14.490748461543228, 13.51470745471794, 12.599015988558444, 11.798311475141553, 10.952869275825481, 9.996568087955936, 11.01304333536093, 11.84626356205538, 12.834306371838528, 12.634675286030618, 11.74037307058941, 10.811803853126815, 10.025227838152308, 10.89615523137347, 11.622045731406681, 12.537923548310731, 13.502596186066718, 14.463399637009658, 15.328884020884601, 14.375259653918452, 13.496570342589536, 12.535394309860255, 11.598479129876804, 10.86437521008991, 10.015243951903177, 9.044025104036509, 9.999048835747622, 10.830553026926541, 11.813580150419268, 12.61143235440233, 12.676466937503363, 11.8066368433363, 11.083251857325074, 11.888895269425857, 12.55757459515857, 13.500165501897971, 14.480769011951324, 15.522858765625612, 15.339449021807171, 13.347506659243601, 12.61126086687948, 11.657982989527241, 10.665787417709605, 9.896783736688025, 8.945753780644067, 8.036398516034733, 9.06765494281467, 9.835069933715515, 10.882879734885252, 11.666849205525324, 12.623803465450177, 12.83504518260984, 12.098508654814376, 12.914126877613425, 13.586553387445656, 14.466810236855272, 15.469223845221919, 15.22097051654392, 14.36704389294037], [12.341796192258952, 13.29051652329493, 14.283858858838919, 14.41867318917375, 13.615699895454043, 12.941063880224698, 13.955345783146536, 13.642566651487932, 12.632370617940616, 11.652527398254511, 10.785272532545084, 9.759786147805116, 8.950647950719894, 7.960655052077791, 7.018475300095786, 7.989511127352449, 8.729851642723846, 9.629150514906913, 10.569013567950853, 11.357500741850519, 11.369396544261514, 12.314480638614773, 13.292937845407955, 14.34151801939027, 14.603278631436199, 13.987019186655798, 13.577424115699484, 12.642198384144793, 11.655451377512332, 10.660373695339262, 9.747136261580327, 8.817503252179062, 7.9090176276926245, 7.008717771608187, 6.09150990728305, 6.9272434182598115, 7.6577380440578775, 8.685403724081599, 9.636217436428186, 10.428806438057634, 10.428750025055898, 11.395573405970605, 12.43140268920908, 13.312624146237305, 14.31156070513691, 13.605222338981031, 12.556008625463015, 11.649853382990997, 10.680027067352427, 9.727198120794359, 8.859412212370135, 7.880003806249744, 6.887457712035591, 5.98659952413152, 5.0722789500358125, 5.876267793631602, 6.675792626448133, 7.715125453506583, 8.644173938961435, 9.491039887245945, 9.39575617843348, 10.434164331131457, 11.400302357872944, 12.350113522245017, 13.358610809072243, 12.581579346751798, 11.59857204887614, 10.675901028134318, 9.71972883684075, 8.773631769936767, 7.827149504644561, 6.867640101771302, 5.920552912382686, 4.939739315163876, 4.127972788523427, 4.861264974926141, 5.7221264101820015, 6.660256032171552, 7.59222607973601, 8.504185815086105, 8.450732878167976, 9.482417077461971, 10.450259651516298, 11.489942352395602, 12.45414921885888, 11.577571020948174, 10.588519375673153, 9.645783462050332, 8.75784062973164, 7.739637431631523, 6.885922026443475, 5.937548347283508, 4.944580292905844, 4.0131309774053365, 3.057843913849084, 3.8996807394210555, 4.7419129890110145, 5.749178132269959, 6.572241120859401, 7.512832274139787, 7.619760164320873, 8.574966165817603, 9.566373179420856, 10.59429838091953, 11.62307359239804, 10.794109795047673, 9.753849968198715, 8.720534821265085, 7.74762196082953, 6.761970107209525, 5.82738011835173, 4.963487771800826, 3.943220658865405, 2.9718094581512493, 2.028386037061207, 2.9410593105838294, 3.7861844525346773, 4.701117197837989, 5.637682408335391, 6.6891320536099546, 6.66926623697487, 7.64485173315666, 8.708416073052774, 9.772112281120231, 10.748384532974303, 9.944059135631393, 8.871644212572985, 7.856342891941027, 6.898186827566339, 5.884497951314855, 4.878712761130031, 3.912931757342501, 2.9824512189120354, 1.9780666228364572, 0.9702498425368066, 1.9489595010408645, 2.8533504230174316, 3.766497334191427, 4.73195796862502, 5.737311905018837, 5.898460158956421, 6.8891277418551775, 7.8367384407603105, 8.848417957885795, 9.869174998413772, 9.05348388925464, 8.06682383068736, 7.075266384213422, 6.033354196899359, 5.066151727356818, 4.0065495181198, 3.050871048872812, 2.05035688305005, 0.9842750743921358, 0.0, 0.9420935152963531, 1.8894181051950127, 2.821275785473537, 3.8465313054819026, 4.8377876172253504, 6.827060215060579, 7.823191040432885, 8.789692827877257, 9.805945397972646, 10.83268658600298, 9.9937391773964, 8.969668393054798, 7.978432326237047, 6.952759993869205, 5.988056997081619, 4.992410991939213, 3.952684799532187, 2.9930215220374423, 1.969210625539365, 1.0156019025495866, 1.879259606924385, 2.883908132011906, 3.8234998372688667, 4.8604687746408075, 5.798339829306048, 7.789172217921276, 8.732146169295163, 9.778798276654312, 10.775145405467374, 11.72029717018111, 10.72411091323609, 9.649525877108799, 8.714119668881953, 7.744317976968654, 6.80892246472472, 5.855604872456967, 4.872755802673516, 3.8603624928403915, 2.92680964807083, 2.0043038977112406, 2.865190985108744, 3.939163210641985, 4.775194078932107, 5.730110996075229, 6.718030237831184, 8.754566659790951, 9.704728409173956, 10.685701271236729, 11.693487717708772, 12.599215430710121, 11.532987706586908, 10.587343080823038, 9.640388949980673, 8.72347772626337, 7.8317561393836055, 6.804911330421581, 5.759786751590397, 4.8286387534841335, 3.8816693677087493, 2.956468924305285, 3.82489457583098, 4.880548915042415, 5.81903138302525, 6.759880933419496, 7.729678453223004, 9.696452817866252, 10.67422379599045, 11.623608602861363, 12.583291376156518, 13.516563637104934, 12.57726545546356, 11.607855329556443, 10.620577932091827, 9.766188777903542, 8.77133135566414, 7.77503713934016, 6.785287334795061, 5.783042111510461, 4.863345425100994, 3.9725522549179857, 4.797668415030154, 5.7559668759047735, 6.740514288138588, 7.7640950595425995, 8.662140664803259, 10.622601629009942, 11.6100447386741, 12.539658561393779, 13.514588690358465, 14.4922827431695, 13.589865472616092, 12.616211618927078, 11.690282373217117, 10.774002712746455, 9.824813003019013, 8.783090098341393, 7.811165220158651, 6.7579707221787055, 5.862472024830871, 5.001456914782741, 5.741166955003544, 6.687279932015038, 7.657526515361792, 8.622512581978016, 9.648429156215796, 11.564289659507937, 12.52551940906855, 13.479115504665398, 14.420854966105034, 14.909880187936519, 14.189526145368312, 13.66578525570246, 12.702256373396388, 11.668548148660989, 10.691419349078929, 9.707999979818794, 8.698442871048327, 7.751041446070966, 6.904634502915817, 5.940254911179938, 6.678693744363403, 7.653419123522872, 8.645976628229663, 9.63021336243164, 10.572906953361485, 12.510138927055209, 13.468172307595136, 14.406318437976504, 14.430627798889649, 13.97244016392858, 13.154075165555692, 13.905290259254032, 13.661855469742088, 12.590051314508338, 11.626521868700427, 10.647319213177362, 9.648043818584357, 8.710043120814305, 7.934904710205833, 6.892107299016951, 7.659274845279084, 8.633105370604524, 9.575594786629695, 10.56194194750095, 11.61118910576267, 13.414535130803706, 14.426339292941206, 14.495868666317161, 13.504857819924801, 12.931994117828937, 12.123767735697724, 12.85603651041286, 13.838657879834553, 13.472612369035627, 12.528155615381166, 11.60280549514745, 10.673493321923953, 9.64073372606198, 8.929680075937776, 7.907154004038125, 8.596870260168119, 9.656462259376262, 10.64698999591024, 11.514697261513607, 12.448837325759923, 14.345289938322589, 14.553136235038323, 13.530711942056495, 12.546925012525325, 11.872114258432699, 11.174226201109077, 11.897255579145073, 12.87926952657999, 13.72636629908805, 13.52718134803485, 12.540457734159212, 11.636176133489286, 10.678647305918957, 9.95385619559962, 8.940304323836592, 9.588592137294743, 10.593455742609379, 11.66579369576631, 12.529006731688945, 13.380398555526707, 14.434587788731873, 13.506473387151091, 12.530432380325802, 11.614740914166308, 10.848337220787087, 10.122537342923865, 10.906474481212044, 11.922949728617038, 12.78255563587727, 13.770598445660417, 13.55010736367577, 12.655805148234563, 11.727235930771968, 10.901784229650808, 9.964050218095991, 10.637770657014546, 11.553648473918598, 12.518321111674585, 13.479124562617525, 14.344608946492464, 13.390984579526318, 12.512295268197398, 11.551119235468118, 10.614204055484668, 9.914400955735445, 9.06526969754871, 9.953931497292617, 10.90895522900373, 11.76684510074843, 12.749872224241157, 13.595707428794466, 13.591899015148517, 12.722068920981453, 11.959808248823574, 10.956790256148379, 11.573299520766435, 12.515890427505838, 13.49649393755919, 14.538583691233478, 14.355173947415038, 12.363231584851468, 11.626985792487346, 10.673707915135106, 9.68151234331747, 8.94680948233356, 7.995779526289599, 8.946304909290841, 9.977561336070778, 10.771362007537403, 11.819171808707141, 12.65112427991746, 13.60807853984231, 13.750477260254993, 12.967043538386086, 11.982021864335946, 12.602278313053521, 13.482535162463138, 14.484948770829785, 14.236695442151785, 13.382768818548236], [11.399702676962598, 12.348423007998575, 13.341765343542564, 13.476579673877398, 12.67360638015769, 13.653002776944389, 14.667284679866226, 14.584660166784285, 13.574464133236969, 12.594620913550864, 11.727366047841437, 10.701879663101469, 9.830755880850612, 8.84076298220851, 7.884163451353932, 7.059838146770895, 7.787758127427493, 8.68705699961056, 9.6269200526545, 10.415407226554162, 10.42730302896516, 11.372387123318418, 12.3508443301116, 13.399424504093917, 13.661185116139846, 14.638398329090649, 14.519517630995837, 13.584291899441146, 12.597544892808685, 11.602467210635615, 10.68922977687668, 9.759596767475415, 8.851111142988977, 7.933085238637392, 6.957198058541196, 5.994264387998449, 6.7156445287615245, 7.743310208785246, 8.694123921131833, 9.48671292276128, 9.486656509759545, 10.453479890674252, 11.489309173912726, 12.370530630940952, 13.369467189840558, 14.367936807864568, 13.498102140759368, 12.59194689828735, 11.62212058264878, 10.669291636090712, 9.801505727666486, 8.822097321546096, 7.829551227331944, 6.910966991160725, 5.9379671012939585, 4.943288763370239, 5.73369911115178, 6.77303193821023, 7.702080423665082, 8.54894637194959, 8.453662663137127, 9.492070815835104, 10.45820884257659, 11.408020006948664, 12.41651729377589, 13.449711958074705, 12.540665564172492, 11.61799454343067, 10.661822352137102, 9.71572528523312, 8.769243019940914, 7.809733617067655, 6.862646427679039, 5.881832830460229, 4.993660939781573, 3.928285944664778, 4.7800328948856485, 5.718162516875199, 6.650132564439657, 7.562092299789751, 7.508639362871622, 8.540323562165618, 9.508166136219945, 10.547848837099249, 11.512055703562527, 12.44570363227108, 11.530612890969506, 10.587876977346685, 9.699934145027992, 8.681730946927877, 7.828015541739828, 6.879641862579861, 5.886673808202197, 4.9552244927016895, 3.9235320651072296, 2.966701709159693, 3.7998194737146616, 4.807084616973606, 5.630147605563048, 6.570738758843434, 6.67766664902452, 7.63287265052125, 8.624279664124503, 9.652204865623178, 10.680980077101687, 11.618587136816883, 10.695943483495068, 9.662628336561438, 8.689715476125883, 7.704063622505878, 6.769473633648083, 5.905581287097179, 4.885314174161758, 3.9139029734476023, 2.97047955235756, 2.0080802803224667, 2.8440909372383243, 3.7590236825416357, 4.695588893039038, 5.747038538313602, 5.727172721678517, 6.702758217860307, 7.766322557756421, 8.830018765823878, 9.80629101767795, 10.822280850328058, 9.813737727869338, 8.79843640723738, 7.840280342862692, 6.826591466611208, 5.820806276426384, 4.855025272638854, 3.9245447342083883, 2.92016013813281, 1.9123433578331597, 1.015980470779502, 1.9112569077210786, 2.8244038188950737, 3.7898644533286667, 4.795218389722484, 4.956366643660068, 5.9470342265588245, 6.8946449254639575, 7.906324442589442, 8.92708148311742, 9.894820771844392, 9.008917345983713, 8.017359899509774, 6.975447712195712, 6.008245242653171, 4.948643033416153, 3.992964564169165, 2.992450398346403, 1.9263685896884888, 0.9420935152963531, 0.0, 0.9473245898986595, 1.8791822701771834, 2.9044377901855496, 3.8956941019289975, 5.884966699764226, 6.881097525136532, 7.847599312580904, 8.863851882676293, 9.890593070706627, 10.876863834544034, 9.86888947209563, 8.87765340527788, 7.8519810729100366, 6.887278076122451, 5.8916320709800445, 4.851905878573019, 3.8922426010782742, 2.8285142199365945, 1.8749054969468157, 0.9371660916280319, 1.9418146167155532, 2.8814063219725132, 3.9183752593444545, 4.856246314009695, 6.847078702624923, 7.79005265399881, 8.836704761357959, 9.83305189017102, 10.816442976327053, 11.58341450763332, 10.508829471506028, 9.573423263279182, 8.603621571365883, 7.668226059121949, 6.714908466854196, 5.732059397070746, 4.719666087237621, 3.7861132424680592, 2.8636074921084695, 1.923097469812391, 2.997069695345632, 3.8331005636357536, 4.788017480778876, 5.775936722534831, 7.812473144494598, 8.762634893877603, 9.743607755940376, 10.751394202412419, 11.693292682185653, 12.392291300984137, 11.446646675220267, 10.499692544377902, 9.5827813206606, 8.691059733780834, 7.66421492481881, 6.619090345987626, 5.687942347881362, 4.740972962105978, 3.8157725187025138, 2.882801060534627, 3.9384553997460623, 4.876937867728897, 5.817787418123143, 6.787584937926651, 8.754359302569899, 9.732130280694097, 10.68151508756501, 11.641197860860165, 12.57447012180858, 13.43656904986079, 12.467158923953672, 11.479881526489056, 10.625492372300771, 9.630634950061369, 8.634340733737389, 7.64459092919229, 6.64234570590769, 5.722649019498223, 4.831855849315215, 3.8555748997338006, 4.81387336060842, 5.798420772842234, 6.822001544246246, 7.720047149506906, 9.68050811371359, 10.667951223377747, 11.597565046097426, 12.572495175062112, 13.550189227873148, 14.44916906701332, 13.475515213324307, 12.549585967614346, 11.633306307143684, 10.684116597416242, 9.642393692738622, 8.67046881455588, 7.6172743165759345, 6.7217756192281, 5.822991677633209, 4.799073439707191, 5.745186416718685, 6.715433000065439, 7.680419066681664, 8.706335640919443, 10.622196144211586, 11.5834258937722, 12.537021989369045, 13.478761450808681, 13.980207207354965, 14.940777084438725, 14.525088850099689, 13.561559967793617, 12.527851743058218, 11.550722943476158, 10.567303574216023, 9.557746465445556, 8.610345040468195, 7.660611574871818, 6.676617905049718, 5.73660022906705, 6.711325608226519, 7.70388311293331, 8.688119847135289, 9.630813438065134, 11.568045411758856, 12.526078792298783, 13.46422492268015, 13.488534283593296, 13.042767183347026, 13.905326104626106, 14.775973109700066, 14.521159064139317, 13.449354908905567, 12.485825463097656, 11.50662280757459, 10.507347412981586, 9.569346715211534, 8.678452674127808, 7.628470292886732, 6.717181329982731, 7.6910118553081706, 8.633501271333342, 9.619848432204597, 10.669095590466316, 12.472441615507353, 13.484245777644853, 13.553775151020808, 12.562764304628448, 12.002321137247383, 12.875018674768137, 13.726719360858894, 14.709340730280587, 14.331915963432856, 13.387459209778395, 12.462109089544679, 11.532796916321182, 10.500037320459208, 9.673228039859751, 8.643516997907906, 7.654776744871766, 8.71436874407991, 9.704896480613886, 10.572603746217254, 11.50674381046357, 13.403196423026236, 13.61104271974197, 12.588618426760142, 11.604831497228972, 10.942441277851145, 11.92547714017949, 12.767938429591107, 13.749952377026023, 14.668459814384404, 14.386484942432078, 13.39976132855644, 12.495479727886515, 11.537950900316186, 10.690219189469403, 9.676667317706373, 8.64649862199839, 9.651362227313026, 10.723700180469956, 11.586913216392592, 12.438305040230354, 13.492494273435517, 12.564379871854738, 11.58833886502945, 10.672647398869955, 9.918664240205533, 10.873788281994278, 11.777157331658078, 12.793632579063072, 13.724649151173622, 14.71269196095677, 14.409410958072998, 13.507164797640378, 12.578595580177783, 11.63814722352059, 10.690637940241356, 9.695677141718193, 10.611554958622245, 11.576227596378232, 12.537031047321172, 13.402515431196111, 12.448891064229962, 11.570201752901045, 10.609025720171765, 9.672110540188315, 8.984727975153891, 9.930957848806855, 10.824614347738649, 11.779638079449763, 12.708938616044783, 13.69196573953751, 14.537800944090819, 14.443258664554332, 13.573428570387268, 12.696171242693357, 11.66872915286807, 10.631206005470082, 11.573796912209485, 12.554400422262837, 13.596490175937125, 13.413080432118681, 11.421138069555111, 10.684892277190993, 9.731614399838753, 8.739418828021117, 8.017136501752006, 8.861467677547745, 9.816987759736874, 10.848244186516812, 11.713455522833756, 12.761265324003494, 13.593217795213812, 14.550172055138663, 14.601836909660808, 13.678982435105777, 12.693960761055637, 11.660184797757168, 12.540441647166785, 13.542855255533432, 13.29460192685543, 12.44067530325188], [10.452378087063938, 11.401098418099915, 12.394440753643904, 12.885353569234924, 13.62093097005635, 14.600327366843048, 15.614609269764886, 15.531984756682945, 14.521788723135629, 13.541945503449524, 12.601626276581571, 11.57515068629542, 10.611208013655025, 9.621215115012923, 8.664615584158346, 7.7968540687805445, 6.840433537528834, 7.7397324097119, 8.67959546275584, 9.468082636655502, 9.4799784390665, 10.425062533419759, 11.403519740212941, 12.452099914195257, 13.387253318920557, 14.36446653187136, 15.425492420519433, 14.531616489339806, 13.544869482707345, 12.549791800534274, 11.63655436677534, 10.706921357374075, 9.74457091270317, 8.776171628040244, 7.73765019134561, 6.731280310008098, 5.768319938862866, 6.795985618886586, 7.7467993312331735, 8.53938833286262, 8.539331919860885, 9.506155300775593, 10.541984584014067, 11.423206041042292, 12.422142599941898, 13.420612217965909, 14.4434434478727, 13.53927148818601, 12.56944517254744, 11.616616225989372, 10.748830317565146, 9.769421911444756, 8.723010997046137, 7.774427000973429, 6.801427111106661, 5.806748773182942, 4.786374521253121, 5.825707348311571, 6.754755833766422, 7.60162178205093, 7.506338073238467, 8.544746225936445, 9.510884252677931, 10.460695417050005, 11.46919270387723, 12.502387368176045, 13.486006871285822, 12.56531913332933, 11.609146942035762, 10.66304987513178, 9.716567609839574, 8.757058206966315, 7.809971017577698, 6.777009297853757, 5.857120949594275, 4.791745954477482, 3.8327083049869897, 4.77083792697654, 5.702807974540997, 6.614767709891091, 6.561314772972962, 7.592998972266958, 8.560841546321285, 9.600524247200589, 10.564731113663868, 11.49837904237242, 12.477937480868166, 11.535201567245345, 10.647258734926652, 9.629055536826536, 8.775340131638487, 7.826966452478521, 6.8339983981008565, 5.850400960095218, 4.786992074919932, 3.8301617189723958, 2.8524948838160022, 3.859760027074947, 4.682823015664388, 5.623414168944774, 5.73034205912586, 6.68554806062259, 7.676955074225842, 8.704880275724518, 9.733655487203027, 10.671262546918223, 11.643268073393727, 10.609952926460098, 9.637040066024543, 8.651388212404537, 7.716798223546743, 6.852905876995838, 5.832638764060418, 4.861227563346262, 3.9178041422562195, 2.8715402901351696, 1.8967663473396648, 2.811699092642976, 3.7482643031403784, 4.799713948414942, 4.779848131779858, 5.755433627961647, 6.8189979678577615, 7.882694175925218, 8.85896642777929, 9.874956260429398, 10.761062317767996, 9.745760997136038, 8.78760493276135, 7.773916056509868, 6.768130866325044, 5.802349862537514, 4.871869324107048, 3.86748472803147, 2.859667947731819, 1.923377631188417, 0.9639323178224191, 1.8770792289964142, 2.842539863430007, 3.847893799823824, 4.009042053761409, 4.999709636660165, 5.947320335565298, 6.958999852690782, 7.9797568932187595, 8.947496181945732, 9.934156240513012, 8.964684489408434, 7.922772302094372, 6.955569832551831, 5.895967623314813, 4.940289154067825, 3.9397749882450626, 2.8736931795871485, 1.8894181051950127, 0.9473245898986595, 0.0, 0.931857680278524, 1.9571132002868898, 2.9483695120303377, 4.937642109865566, 5.933772935237872, 6.900274722682244, 7.916527292777634, 8.943268480807967, 9.929539244645374, 10.81621406199429, 9.824977995176539, 8.799305662808697, 7.8346026660211106, 6.838956660878704, 5.799230468471679, 4.839567190976934, 3.775838809835254, 2.8222300868454755, 1.8844906815266915, 1.0026160495953071, 1.934081732073854, 2.971050669445795, 3.9089217241110354, 5.8997541127262645, 6.842728064100151, 7.8893801714593, 8.885727300272361, 9.869118386428394, 10.865304643373413, 11.456154061404687, 10.520747853177841, 9.550946161264543, 8.615550649020609, 7.662233056752855, 6.679383986969405, 5.666990677136281, 4.733437832366719, 3.8109320820071293, 2.870422059711051, 2.0588187544759284, 2.8857759737370943, 3.840692890880217, 4.828612132636172, 6.8651485545959385, 7.815310303978943, 8.796283166041714, 9.804069612513757, 10.745968092286992, 11.812195816410204, 12.393971265118926, 11.447017134276562, 10.530105910559259, 9.638384323679494, 8.61153951471747, 7.566414935886286, 6.635266937780022, 5.688297552004638, 4.7630971086011735, 3.8301256504332866, 3.077963705183093, 3.9563904272441524, 4.8704628282244835, 5.840260348027991, 7.80703471267124, 8.784805690795437, 9.734190497666349, 10.693873270961504, 11.627145531909918, 12.614699435637121, 13.414483513852332, 12.427206116387715, 11.57281696219943, 10.577959539960029, 9.581665323636049, 8.59191551909095, 7.58967029580635, 6.669973609396883, 5.779180439213874, 4.802899489632461, 4.076209179943746, 4.957198623927207, 5.895416752044083, 6.772722559608246, 8.73318352381493, 9.720626633479087, 10.650240456198766, 11.625170585163449, 12.602864637974484, 13.597600632250705, 14.422839803222967, 13.496910557513006, 12.580630897042344, 11.631441187314902, 10.589718282637282, 9.61779340445454, 8.564598906474595, 7.66910020912676, 6.770316267531869, 5.74639802960585, 5.127929905470319, 5.9275230022184635, 6.892509068834689, 7.759011051020783, 9.688989161160189, 10.650218910720803, 11.589697399470385, 12.531436860910022, 13.520768337404922, 14.558763273789914, 15.472413439998348, 14.508884557692276, 13.475176332956881, 12.498047533374821, 11.514628164114686, 10.505071055344217, 9.557669630366856, 8.607936164770479, 7.623942494948378, 6.68392481896571, 6.094069096978154, 6.915973115086334, 7.900209849288312, 8.697606455013737, 10.63483842870746, 11.592871809247388, 12.516900332781491, 12.541209693694636, 13.601002095852046, 14.606928167158088, 15.55642524250448, 15.46848365403798, 14.39667949880423, 13.43315005299632, 12.453947397473252, 11.454672002880248, 10.516671305110195, 9.625777264026468, 8.575794882785392, 7.664505919881391, 7.073755344059805, 7.898623473393977, 8.869465462743898, 9.738273810406616, 11.66018691596527, 12.551038794593458, 12.606450561122148, 11.615439714729789, 12.666417382884923, 13.60576333088123, 14.507171493663307, 15.489792863085, 15.279240553331517, 14.334783799677057, 13.40943367944334, 12.480121506219843, 11.44736191035787, 10.62055262975841, 9.590841587806565, 8.602101334770426, 8.097112232831543, 8.970018682674521, 9.822220776756556, 10.756360841002872, 12.590941723484152, 12.66371812984331, 11.641293836861482, 10.657506907330312, 11.657265316791756, 12.656221796292582, 13.54839056239552, 14.530404509830436, 15.48482571074671, 15.33380953233074, 14.347085918455102, 13.442804317785177, 12.485275490214848, 11.637543779368063, 10.623991907605033, 9.59382321189705, 9.060136122670553, 9.988822382530591, 10.836530246931893, 11.687922070769655, 12.545169683536857, 11.617055281956079, 10.64101427513079, 9.725322808971296, 10.655680162215182, 11.610804204003927, 12.557609464462491, 13.574084711867485, 14.561945137358338, 15.549987947141485, 15.35673554797166, 14.454489387539038, 13.525920170076443, 12.58547181341925, 11.637962530140015, 10.643001731616852, 10.020328853979771, 10.968838783954828, 11.802215459668075, 12.652132461735413, 11.501566474331302, 10.622877163002386, 9.661701130273105, 8.724785950289656, 9.72174389716354, 10.71140998161127, 11.605066480543064, 12.560090212254178, 13.546234602229498, 14.529261725722225, 15.466593304428567, 15.390583254452991, 14.520753160285928, 13.643495832592016, 12.616053742766729, 11.578530595368742, 10.982570807567011, 11.947011609839434, 12.869099017115866, 12.465755842220021, 10.473813479656451, 9.737567687292334, 8.784289809940093, 7.792094238122457, 8.754152423761655, 9.64191981035216, 10.597439892541288, 11.628696319321225, 12.586726546027707, 13.635525552743628, 14.540542385112472, 15.497496645037323, 15.549161499559467, 14.626307025004436, 13.641285350954297, 12.607509387655828, 11.949215542524312, 12.951629150890959, 12.34727733695677, 11.49335071335322], [9.520520406785415, 10.469240737821393, 11.462583073365382, 12.422375226906953, 13.442974374624189, 14.44767268971304, 15.433527944318845, 16.42922873913874, 15.453646403414153, 14.473803183728048, 13.533483956860094, 12.507008366573942, 11.543065693933547, 10.553072795291445, 9.596473264436868, 8.728711749059068, 7.772291217807357, 6.858262050282237, 7.747737782477317, 8.53622495637698, 8.548120758787977, 9.493204853141236, 10.471662059934419, 11.520242233916733, 12.455395638642033, 13.432608851592835, 14.493634740240909, 15.4288604717956, 14.476727162985869, 13.481649480812798, 12.568412047053863, 11.638779037652599, 10.676428592981694, 9.708029308318766, 8.669507871624132, 7.6631379902866215, 6.700177619141389, 5.914515259456923, 6.814941650954649, 7.607530652584097, 7.60747423958236, 8.574297620497067, 9.61012690373554, 10.491348360763768, 11.490284919663374, 12.488754537687385, 13.511585767594177, 14.471129168464534, 13.501302852825964, 12.548473906267896, 11.68068799784367, 10.70127959172328, 9.65486867732466, 8.706284681251953, 7.733284791385185, 6.7386064534614665, 5.718232201531644, 4.944236988881907, 5.822898153487898, 6.669764101772406, 6.574480392959943, 7.6128885456579205, 8.579026572399407, 9.52883773677148, 10.537335023598706, 11.570529687897523, 12.5541491910073, 13.497176813607854, 12.541004622314286, 11.594907555410304, 10.648425290118098, 9.688915887244839, 8.741828697856223, 7.708866978132281, 6.788978629872799, 5.723603634756006, 4.764565985265513, 3.889367567546876, 4.770950294262473, 5.682910029612567, 5.629457092694438, 6.661141291988434, 7.628983866042761, 8.668666566922065, 9.632873433385344, 10.566521362093896, 11.555573007368917, 12.467059247523869, 11.579116415205176, 10.56091321710506, 9.70719781191701, 8.758824132757045, 7.765856078379381, 6.782258640373742, 5.718849755198456, 4.76201939925092, 3.784352564094526, 2.9279023467964227, 3.750965335385864, 4.69155648866625, 4.798484378847336, 5.753690380344066, 6.745097393947318, 7.773022595445994, 8.801797806924505, 9.7394048666397, 10.779664693488659, 11.541810606738622, 10.568897746303067, 9.583245892683061, 8.648655903825267, 7.784763557274362, 6.764496444338941, 5.793085243624785, 4.849661822534743, 3.8033979704136938, 2.8286240276181887, 1.8798414123644518, 2.8164066228618543, 3.8678562681364177, 3.847990451501334, 4.823575947683123, 5.887140287579237, 6.950836495646694, 7.927108747500767, 8.943098580150874, 9.955865901059232, 10.677618677414562, 9.719462613039875, 8.705773736788391, 7.699988546603567, 6.734207542816037, 5.803727004385571, 4.799342408309993, 3.791525628010343, 2.8552353114669407, 1.895789998100943, 0.9452215487178902, 1.9106821831514833, 2.916036119545301, 3.0771843734828845, 4.067851956381641, 5.015462655286774, 6.027142172412258, 7.047899212940235, 8.015638501667208, 9.002298560234488, 9.896542169686956, 8.854629982372893, 7.887427512830353, 6.827825303593335, 5.872146834346347, 4.871632668523586, 3.805550859865672, 2.8212757854735364, 1.8791822701771834, 0.931857680278524, 0.0, 1.025255520008366, 2.016511831751814, 4.005784429587042, 5.001915254959348, 5.96841704240372, 6.9846696124991094, 8.011410800529443, 8.99768156436685, 10.006932815429996, 10.756835675455061, 9.73116334308722, 8.766460346299633, 7.770814341157227, 6.731088148750201, 5.771424871255457, 4.707696490113777, 3.754087767123999, 2.816348361805215, 1.9344737298738313, 1.0022240517953298, 2.039192989167271, 2.9770640438325118, 4.96789643244774, 5.910870383821627, 6.957522491180776, 7.953869619993836, 8.93726070614987, 9.93344696309489, 10.940146363348752, 11.452605533456364, 10.482803841543065, 9.547408329299131, 8.594090737031378, 7.611241667247928, 6.598848357414804, 5.665295512645242, 4.742789762285653, 3.8022797399895745, 2.968440434201772, 1.9539182934585702, 2.908835210601693, 3.8967544523576474, 5.933290874317414, 6.8834526237004185, 7.86442548576319, 8.872211932235233, 9.814110412008468, 10.88033813613168, 11.82598276189555, 12.378874814555084, 11.461963590837781, 10.570242003958016, 9.543397194995991, 8.49827261616481, 7.567124618058546, 6.620155232283162, 5.694954788879698, 4.76198333071181, 3.963015214948462, 3.0245327469656282, 3.9386051479459594, 4.908402667749467, 6.875177032392716, 7.852948010516912, 8.802332817387825, 9.76201559068298, 10.695287851631395, 11.682841755358599, 12.652251881265716, 13.359063796666238, 12.504674642477953, 11.509817220238553, 10.513523003914573, 9.523773199369474, 8.521527976084874, 7.601831289675407, 6.7110381194923985, 5.734757169910983, 4.961260689709114, 4.025340943648683, 4.963559071765559, 5.840864879329722, 7.8013258435364055, 8.788768953200561, 9.71838277592024, 10.693312904884927, 11.671006957695962, 12.665742951972183, 13.639396805661196, 14.428768237791529, 13.512488577320866, 12.563298867593426, 11.521575962915804, 10.549651084733064, 9.49645658675312, 8.600957889405285, 7.702173947810391, 6.678255709884373, 5.965911905286694, 4.995665321939939, 5.9606513885561645, 6.827153370742259, 8.757131480881664, 9.718361230442278, 10.657839719191859, 11.599579180631496, 12.588910657126396, 13.626905593511392, 14.662952383042084, 15.440742237970799, 14.407034013235403, 13.429905213653344, 12.446485844393209, 11.436928735622741, 10.48952731064538, 9.539793845049001, 8.555800175226901, 7.615782499244232, 6.932051096794528, 5.98411543480781, 6.968352169009788, 7.765748774735213, 9.702980748428935, 10.661014128968862, 11.585042652502965, 12.54683429527525, 13.526350681134335, 14.532276752440378, 15.585140356610042, 16.4003413343165, 15.328537179082753, 14.365007733274842, 13.385805077751776, 12.386529683158772, 11.44852898538872, 10.55763494430499, 9.507652563063914, 8.596363600159913, 7.909255209140624, 6.966765793115453, 7.937607782465374, 8.806416130128092, 10.728329235686743, 11.619181114314932, 12.045417487647176, 12.547297395008313, 13.598275063163447, 14.537621011159754, 15.43902917394183, 16.421650543363523, 16.21109823361004, 15.266641479955581, 14.341291359721865, 13.411979186498368, 12.379219590636394, 11.552410310036933, 10.522699268085088, 9.533959015048948, 8.932612097912363, 8.038161002395997, 8.890363096478033, 9.82450316072435, 11.659084043205626, 11.865569964630236, 11.001907501832505, 11.589364587608836, 12.58912299707028, 13.588079476571107, 14.480248242674042, 15.462262190108959, 16.41668339102523, 16.265667212609266, 15.278943598733626, 14.3746619980637, 13.417133170493372, 12.569401459646585, 11.555849587883555, 10.525680892175572, 9.895635987751373, 9.056964702252067, 9.904672566653371, 10.756064390491133, 11.613312003258335, 10.818907116743006, 9.934593757195493, 10.65718048924982, 11.587537842493706, 12.54266188428245, 13.489467144741013, 14.505942392146007, 15.49380281763686, 16.481845627420007, 16.288593228250182, 15.38634706781756, 14.457777850354965, 13.517329493697773, 12.569820210418538, 11.574859411895375, 10.855828719060591, 10.036981103676304, 10.870357779389552, 11.72027478145689, 10.56970879405278, 9.824728997789313, 8.955280612337809, 9.65664363056818, 10.653601577442064, 11.643267661889793, 12.536924160821586, 13.4919478925327, 14.47809228250802, 15.461119406000748, 16.39845098470709, 16.322440934731514, 15.45261084056445, 14.575353512870539, 13.547911423045251, 12.510388275647264, 11.818070672647831, 11.01515392956091, 11.937241336837344, 11.533898161941499, 9.541955799377929, 8.80571000701381, 7.92338950905061, 8.723951918400981, 9.686010104040179, 10.573777490630683, 11.52929757281981, 12.560553999599747, 13.51858422630623, 14.56738323302215, 15.472400065390996, 16.42935432531585, 16.48101917983799, 15.558164705282959, 14.573143031232819, 13.53936706793435, 12.784715407605132, 12.048431784392417, 11.415419656678248, 10.561493033074697], [8.6079512646785, 9.556671595714477, 10.550013931258466, 11.509806084800037, 12.530405232517273, 13.535103547606123, 14.52095880221193, 15.516659597031824, 16.47890192342252, 15.471711749089096, 14.484145912151845, 13.457670321865693, 12.493727649225299, 11.503734750583197, 10.54713521972862, 9.67937370435082, 8.722953173099109, 7.745992801303073, 6.835168640370401, 7.623655814270064, 7.635551616681061, 8.58063571103432, 9.559092917827503, 10.607673091809817, 11.542826496535117, 12.52003970948592, 13.581065598133993, 14.516291329688684, 15.501982682994235, 14.506905000821165, 13.59366756706223, 12.664034557660965, 11.639967739975269, 10.658691263610518, 9.620169826915884, 8.613799945578373, 7.65083957443314, 6.802246010477759, 5.9023725088477335, 6.694961510477181, 6.694905097475444, 7.661728478390152, 8.697557761628627, 9.578779218656852, 10.577715777556458, 11.576185395580469, 12.599016625487259, 13.617056970199988, 14.52655837283433, 13.573729426276262, 12.705943517852036, 11.726535111731646, 10.680124197333026, 9.731540201260318, 8.758540311393551, 7.726777941890855, 6.668894156823395, 5.831967739902744, 4.910329011380982, 5.75719495966549, 5.661911250853027, 6.7003194035510045, 7.666457430292492, 8.616268594664565, 9.62476588149179, 10.657960545790605, 11.641580048900382, 12.616394668640096, 13.566260142322653, 12.62016307541867, 11.673680810126465, 10.714171407253206, 9.76708421786459, 8.734122498140646, 7.814234149881165, 6.7488591547643715, 5.715227940557264, 4.777098318567713, 3.858381152155557, 4.770340887505651, 4.716887950587522, 5.748572149881518, 6.716414723935845, 7.756097424815149, 8.720304291278428, 9.65395221998698, 10.643003865262001, 11.585739778884822, 12.5681712647841, 11.586168737113427, 10.732453331925377, 9.784079652765412, 8.791111598387747, 7.807514160382108, 6.744105275206822, 5.787274919259286, 4.809608084102892, 3.81563309781726, 2.8383961932789474, 3.778987346559334, 3.8647435000688857, 4.819949501565616, 5.8113565151688675, 6.839281716667543, 7.868056928146053, 8.805663987861248, 9.845923814710206, 10.86120321585647, 11.594153266311434, 10.608501412691428, 9.673911423833633, 8.810019077282728, 7.789751964347308, 6.8183407636331514, 5.874917342543109, 4.8286534904220595, 3.8538795476265544, 2.8397996631259295, 1.9038374807549379, 2.934115389357967, 2.877027433395625, 3.8526129295774143, 4.916177269473528, 5.979873477540985, 6.9561457293950575, 7.972135562045166, 8.930610381050865, 9.91510926914016, 10.744718133048242, 9.731029256796758, 8.725244066611934, 7.759463062824404, 6.828982524393938, 5.82459792831836, 4.816781148018709, 3.8804908314753064, 2.9210455181093087, 1.9051797994793678, 0.9397191650457748, 1.9450731014395921, 2.051928853474519, 3.042596436373275, 3.990207135278408, 5.0018866524038925, 6.02264369293187, 6.9903829816588425, 7.977043040226122, 8.96860048670006, 9.87988550238126, 8.91268303283872, 7.853080823601702, 6.897402354354714, 5.896888188531952, 4.830806379874039, 3.8465313054819026, 2.9044377901855496, 1.9571132002868898, 1.025255520008366, 0.0, 0.9912563117434481, 2.980528909578676, 3.9766597349509825, 4.9431615223953544, 5.959414092490744, 6.9861552805210785, 7.9724260443584845, 8.98167729542163, 9.97291336223938, 10.756418863095586, 9.791715866308, 8.796069861165593, 7.756343668758568, 6.796680391263823, 5.732952010122143, 4.779343287132365, 3.8416038818135814, 2.959729249882197, 2.0274795718036955, 1.0413711632290996, 1.9518085238241456, 3.9870209542887878, 4.929994905662674, 5.976647013021823, 6.92861409998547, 7.912005186141504, 8.908191443086524, 9.914890843340386, 10.850297051567232, 11.508059361551432, 10.572663849307498, 9.619346257039744, 8.636497187256294, 7.6241038774231695, 6.690551032653608, 5.768045282294018, 4.827535259997941, 3.9587326444800524, 2.9442105037368504, 1.989293586593728, 2.977212828349683, 4.9536523794852245, 5.903814128868229, 6.884786990931, 7.892573437403044, 8.834471917176279, 9.864130071431271, 10.809774697195142, 11.776566332665952, 12.487219110846148, 11.595497523966383, 10.568652715004358, 9.523528136173175, 8.592380138066911, 7.645410752291527, 6.7202103088880625, 5.787238850720176, 4.953307425226742, 4.014824957243908, 3.019063523937995, 3.9888610437415024, 5.908225473836684, 6.873309515684722, 7.822694322555634, 8.782377095850789, 9.715649356799204, 10.703203260526408, 11.672613386433525, 12.730026278551808, 13.52993016248632, 12.535072740246918, 11.538778523922938, 10.549028719377839, 9.546783496093239, 8.627086809683771, 7.736293639500763, 6.76001268991935, 5.951552899987394, 5.015633153926963, 4.044017447757595, 4.921323255321758, 6.881784219528441, 7.809130458368371, 8.73874428108805, 9.713674410052736, 10.691368462863771, 11.686104457139992, 12.659758310829005, 13.701206594338057, 14.537744097329233, 13.588554387601791, 12.54683148292417, 11.574906604741429, 10.521712106761484, 9.626213409413648, 8.727429467818759, 7.703511229892739, 6.956204115564974, 5.98595753221822, 5.112754842114159, 5.907611746734295, 7.8375898568737, 8.77215353386241, 9.678201224359668, 10.619940685799305, 11.609272162294205, 12.647267098679201, 13.683313888209893, 14.676296596579114, 15.432289533243768, 14.455160733661709, 13.471741364401574, 12.462184255631106, 11.514782830653745, 10.565049365057368, 9.581055695235268, 8.6410380192526, 7.922343307072809, 6.974407645086091, 6.120455622567782, 6.846207150727249, 8.783439124420973, 9.7414725049609, 10.605404157670774, 11.56719580044306, 12.546712186302145, 13.552638257608187, 14.605501861777851, 15.649856473725553, 16.353792699091116, 15.390263253283207, 14.411060597760141, 13.411785203167137, 12.473784505397084, 11.582890464313357, 10.53290808307228, 9.621619120168281, 8.899547419418905, 7.957058003393733, 7.089711236023369, 7.886874506120128, 9.808787611678781, 10.69963949030697, 11.669886899067105, 12.492965779407907, 13.543943447563041, 14.518049029093442, 15.566622599380606, 16.549243968802298, 17.236353753618406, 16.291896999963946, 15.36654687973023, 14.437234706506732, 13.404475110644759, 12.5776658300453, 11.547954788093454, 10.559214535057317, 9.922904308190644, 9.028453212674277, 8.042466550036028, 8.936139536681862, 10.739542419197663, 10.953000822523322, 11.889638252853342, 12.540026542900588, 13.539784952362032, 14.538741431862858, 15.430910197965796, 16.412924145400712, 17.367345346316984, 17.29092273261763, 16.30419911874199, 15.399917518072066, 14.442388690501737, 13.59465697965495, 12.581105107891922, 11.55093641218394, 10.885928198029653, 10.018881299020729, 9.056776020211366, 9.867700766448646, 10.700742861151419, 9.90633797463609, 10.82232450821633, 11.607842444541571, 12.538199797785458, 13.493323839574202, 14.440129100032767, 15.45660434743776, 16.44446477292861, 17.43250758271176, 17.313848748258547, 16.411602587825925, 15.48303337036333, 14.542585013706137, 13.595075730426906, 12.600114931903743, 11.846120929338872, 10.983264683890487, 10.022461232947547, 10.831911157414403, 9.657139651945863, 8.912159855682397, 9.843011363358645, 10.607305585859931, 11.604263532733816, 12.593929617181544, 13.487586116113338, 14.442609847824452, 15.428754237799772, 16.411781361292498, 17.34911293999884, 17.34769645473988, 16.477866360572815, 15.600609032878904, 14.57316694305362, 13.535643795655632, 12.808362882926112, 11.961437509775093, 11.089344790395339, 10.621329019834583, 8.629386657271013, 7.8931408649068935, 8.811120260071446, 9.674613873692733, 10.63667205933193, 11.524439445922434, 12.479959528111563, 13.511215954891501, 14.469246181597981, 15.518045188313902, 16.470308630752044, 17.427262890676896, 16.470957365100173, 15.479167237545013, 14.494145563494875, 13.438964627058413, 12.445944111510649, 11.51534135522826, 10.502850514571332, 9.648923890967783], [7.801144910270686, 8.749865241306663, 9.743207576850653, 10.68223022582637, 11.664564287545883, 12.669262602634733, 13.655117857240539, 14.650818652060433, 15.614116631778039, 16.46296806083254, 15.475402223895292, 14.44892663360914, 13.484983960968746, 12.494991062326644, 11.538391531472067, 10.670630016094266, 9.714209484842556, 8.737249113046522, 7.767877676148054, 6.816849459862251, 6.828745262273248, 7.773829356626507, 8.75228656341969, 9.741832146838426, 10.676985551563726, 11.654198764514529, 12.715224653162602, 13.650450384717294, 14.637197391349755, 15.498161312564612, 14.584923878805677, 13.655290869404412, 12.631224051718716, 11.649947575353965, 10.611426138659331, 9.60505625732182, 8.642095886176588, 7.793502322221208, 6.835081544625387, 5.8881551560693675, 5.853075390849635, 6.8198987717643424, 7.84974164778542, 8.712938273685461, 9.711874832585066, 10.710344450609076, 11.733175680515867, 12.751216025228596, 13.688055638239225, 14.56498573801971, 13.697199829595483, 12.717791423475093, 11.671380509076474, 10.722796513003766, 9.749796623137, 8.718034253634304, 7.660150468566843, 6.823224051646192, 5.90158532312443, 4.950388605257677, 4.820081544227218, 5.858489696925195, 6.8006164853211, 7.750427649693173, 8.758924936520398, 9.792119600819213, 10.77573910392899, 11.750553723668704, 12.706725914962272, 13.611419387162117, 12.664937121869912, 11.705427718996653, 10.758340529608036, 9.725378809884097, 8.805490461624613, 7.74011546650782, 6.7064842523007115, 5.768354630311161, 4.849637463899005, 3.963534533097838, 3.875058243961713, 4.882731204910127, 5.850573778964454, 6.8902564798437576, 7.8544633463070355, 8.788111275015588, 9.777162920290609, 10.71989883391343, 11.702330319812708, 12.577425048856874, 11.723709643668824, 10.775335964508859, 9.782367910131194, 8.798770472125558, 7.735361586950271, 6.778531231002734, 5.800864395846341, 4.806889409560708, 3.8296525050223953, 2.9721809921515208, 2.9280157033612224, 3.883221704857953, 4.874628718461205, 5.90255391995988, 6.93132913143839, 7.868936191153586, 8.909196018002545, 9.869946904113023, 10.842859764548578, 11.599757724434875, 10.66516773557708, 9.801275389026175, 8.781008276090756, 7.809597075376599, 6.866173654286557, 5.819909802165508, 4.845135859370004, 3.8310559748693773, 2.8950937924983857, 1.997387592650304, 1.9402996366879623, 2.9158851328697515, 3.9794494727658654, 5.034723438212964, 6.010995690067037, 6.9845893457574, 7.939354069307418, 8.923852957396713, 9.8820090217714, 10.722285568540205, 9.71650037835538, 8.75071937456785, 7.820238836137385, 6.815854240061808, 5.808037459762157, 4.871747143218755, 3.9123018298527574, 2.896436111222816, 1.9309754767892229, 1.008345304731929, 1.0606725417310705, 2.0513401246298266, 2.99895082353496, 4.010630340660445, 5.031387381188422, 5.999126669915395, 6.985786728482674, 7.977344174956612, 9.019256362270674, 9.903939344582167, 8.84433713534515, 7.888658666098161, 6.888144500275399, 5.822062691617486, 4.8377876172253504, 3.8956941019289975, 2.948369512030338, 2.016511831751814, 0.9912563117434481, 0.0, 1.9892725978352275, 2.9854034232075337, 3.951905210651906, 4.968157780747295, 5.99489896877763, 6.981169732615037, 7.990420983678182, 8.981657050495933, 10.007329382863775, 10.782972178051448, 9.787326172909042, 8.747599980502017, 7.787936703007272, 6.724208321865592, 5.770599598875814, 4.832860193557029, 3.9509855616256453, 3.018735883547144, 2.0198829557048072, 0.9605522120806976, 2.995764642545339, 3.9387385939192257, 4.985390701278375, 5.937357788242021, 6.920748874398055, 7.916935131343076, 8.923634531596937, 9.859040739823783, 10.828842431737081, 11.563920161050946, 10.610602568783193, 9.627753498999743, 8.61536018916662, 7.681807344397057, 6.759301594037467, 5.8187915717413885, 4.93724443695576, 3.9227222962125583, 2.9678053790694356, 2.026016376670691, 3.9623960677417753, 4.91255781712478, 5.893530679187552, 6.901317125659595, 7.84321560543283, 8.872873759687822, 9.818518385451693, 10.785310020922504, 11.808002181031798, 12.586753835709832, 11.559909026747807, 10.514784447916623, 9.58363644981036, 8.636667064034976, 7.711466620631511, 6.778495162463624, 5.931819217702451, 4.993336749719616, 3.9975753164137027, 3.0376645920625105, 4.916969162093235, 5.882053203941274, 6.831438010812185, 7.791120784107339, 8.724393045055754, 9.711946948782957, 10.681357074690073, 11.738769966808356, 12.802777005210817, 13.526329051990366, 12.530034835666386, 11.540285031121288, 10.538039807836688, 9.61834312142722, 8.727549951244212, 7.7512690016627985, 6.9300646924631035, 5.99414494640267, 5.02010568765116, 3.9701268036427657, 5.92416995225195, 6.817874146624923, 7.7474879693446015, 8.722418098309285, 9.70011215112032, 10.694848145396541, 11.668501999085555, 12.709950282594606, 13.747103340847492, 14.57981069934524, 13.538087794667618, 12.566162916484878, 11.512968418504933, 10.617469721157097, 9.718685779562207, 8.694767541636189, 7.934036021770108, 6.963789438423354, 5.998803371807129, 4.956415295055303, 6.886393405194708, 7.780897222118961, 8.686944912616221, 9.628684374055858, 10.618015850550758, 11.65601078693575, 12.692057576466443, 13.685040284835662, 14.699802803795258, 15.446417045405157, 14.462997676145022, 13.453440567374555, 12.506039142397194, 11.556305676800816, 10.572312006978716, 9.632294330996048, 8.900175213277942, 7.878698052376892, 6.837704289978102, 5.895010699048257, 7.832242672741979, 8.790276053281906, 9.614147845927327, 10.575939488699612, 11.555455874558698, 12.56138194586474, 13.614245550034404, 14.658600161982106, 15.632788408136465, 16.381519565026654, 15.40231690950359, 14.403041514910585, 13.465040817140533, 12.574146776056805, 11.52416439481573, 10.61287543191173, 9.735796480330116, 8.793307064304944, 7.80695990343369, 6.935678054441135, 8.857591159999789, 9.748443038627975, 10.678630587323656, 11.50170946766446, 12.552687135819594, 13.526792717349995, 14.57536628763716, 15.557987657058852, 16.525410337457778, 17.283153311707395, 16.35780319147368, 15.428491018250181, 14.395731422388208, 13.568922141788748, 12.539211099836903, 11.550470846800765, 10.759153369101854, 9.821065724113108, 8.759715217446349, 7.98494308500287, 9.788345967518671, 10.813893910731629, 11.722140573138327, 12.459642275063937, 13.45940068452538, 14.458357164026207, 15.438051440749659, 16.420065388184575, 17.374486589100847, 18.28217904436108, 17.29545543048544, 16.391173829815514, 15.433645002245186, 14.585913291398398, 13.57236141963537, 12.54219272392739, 11.722177258940864, 10.736129966431049, 9.774024687621687, 8.916504314769654, 9.893936506743605, 10.839047010413744, 11.785358069047016, 12.599098756285018, 13.529456109528905, 14.48458015131765, 15.431385411776212, 16.447860659181206, 17.435721084672057, 18.423763894455206, 18.305105060001996, 17.402858899569374, 16.47428968210678, 15.533841325449586, 14.586332042170355, 13.591371243647192, 12.665185989056795, 11.700513351300808, 10.739709900357868, 9.88071470573541, 8.85033329753805, 9.84486889146005, 10.806044924189331, 11.598561897603378, 12.595519844477263, 13.585185928924991, 14.478842427856785, 15.433866159567899, 16.420010549543218, 17.403037673035943, 18.340369251742285, 17.563978332162726, 16.633524759402327, 15.628583090062927, 14.61339925269344, 13.575876105295453, 12.585012987494283, 11.741812855651954, 10.765220974708974, 9.81452266542677, 7.8225803028632, 8.825849900684547, 9.802376571814895, 10.66587018543618, 11.627928371075377, 12.515695757665881, 13.47121583985501, 14.502472266634946, 15.460502493341428, 16.509301500057347, 17.46156494249549, 16.600522709149914, 15.605116420128786, 14.613326292573625, 13.628304618523485, 12.611388768084746, 11.618368252536982, 10.708535000820447, 9.696044160163519, 8.842117536559968], [7.804189056274206, 8.752909387310183, 9.746251722854172, 10.643222979990808, 11.625557041710321, 12.630255356799172, 13.616110611404977, 14.611811406224872, 15.575109385942477, 16.474942835541924, 17.36029247430762, 16.33381688402147, 15.369874211381076, 14.379881312738974, 13.423281781884397, 12.555520266506596, 11.579410221642465, 10.567218262493624, 9.569648286150874, 8.61862006986507, 6.831789408276768, 7.776873502630027, 8.755330709423209, 9.702824901002865, 10.637978305728165, 11.615191518678968, 12.67621740732704, 13.611443138881732, 14.598190145514193, 15.482789132626676, 16.436894390635455, 15.554838320103771, 14.516114302131045, 13.534837825766294, 12.49631638907166, 11.48994650773415, 10.526986136588917, 9.62347147166831, 8.636852154628208, 7.689925766072188, 5.814068145014073, 6.780891525928781, 7.810734401949859, 8.6739310278499, 9.672867586749506, 10.671337204773517, 11.687130082773837, 12.705170427486566, 13.631279863597152, 14.549613558081774, 15.590358698856889, 14.638216348786953, 13.580780370558827, 12.632196374486119, 11.659196484619352, 10.602924504046634, 9.545040718979173, 8.708114302058522, 7.754760842061276, 6.752159215260497, 4.7810742983916565, 5.819482451089634, 6.76160923948554, 7.711420403857613, 8.719917690684838, 9.746074003077183, 10.72969350618696, 11.69377794902663, 12.649950140320199, 13.596047207224181, 14.630798507692296, 13.648082723944775, 12.684451675281384, 11.63934310649587, 10.719454758236386, 9.654079763119594, 8.591374502713043, 7.653244880723492, 6.702812982835851, 5.765305143100658, 3.8360509981261526, 4.843723959074566, 5.811566533128893, 6.851249234008197, 7.815456100471475, 8.742065677273557, 9.731117322548577, 10.663123059271356, 11.645554545170635, 12.674106456963669, 13.689571029491209, 12.730527250265977, 11.737559195888313, 10.71273476873733, 9.649325883562044, 8.692495527614508, 7.714828692458115, 6.691779659973039, 5.714542755434727, 4.773951602154341, 2.8890084575256623, 3.8442144590223926, 4.835621472625644, 5.86354667412432, 6.870866306735458, 7.808473366450654, 8.813628387495289, 9.73787441848611, 10.710787278921664, 11.69643913254167, 12.631029121399465, 11.790547986861405, 10.770280873925984, 9.798869673211827, 8.781061292724424, 7.733874098777282, 6.759100155981777, 5.733195135832304, 4.797232953461312, 3.816802989276707, 1.8958063694022989, 2.871391865584088, 3.8580293382273734, 4.90265095258605, 5.878923204440123, 6.852516860130486, 7.8072815836805045, 8.7917804717698, 9.749936536144487, 10.763625412395971, 11.70577297619061, 10.73999197240308, 9.809511433972615, 8.805126837897035, 7.797310057597385, 6.831484911812228, 5.87203959844623, 4.798575272185742, 3.833114637752149, 2.827760701358332, 0.928600056104157, 1.9192676390029133, 2.8668783379080462, 3.878557855033531, 4.899314895561508, 5.867054184288481, 6.8537142428557605, 7.8452716893296985, 8.88718387664376, 9.8543863461863, 10.83360973318038, 9.877931263933391, 8.877417098110628, 7.811335289452714, 6.827060215060579, 5.884966699764226, 4.937642109865566, 4.005784429587042, 2.9805289095786756, 1.9892725978352275, 0.0, 0.9961308253723065, 1.974915839469059, 2.991168409564448, 4.017909597594783, 5.036613230740982, 6.060684015082584, 7.051920081900335, 8.077592414268178, 9.042295411055765, 10.037941416198171, 9.010890611706182, 8.051227334211438, 6.987498953069758, 6.0338902300799795, 5.096150824761196, 4.0915022996736745, 3.14807155952963, 2.1111026221576887, 1.051771878533579, 1.0064920447101118, 1.9494659960839984, 2.9961181034431474, 3.9603684170591746, 4.943759503215208, 5.939945760160228, 6.99389756300134, 7.929303771228186, 8.899105463141485, 9.834500975385419, 10.787818567653172, 9.891044130203909, 8.878650820370785, 7.9450979756012226, 7.022592225241633, 6.082082202945555, 5.028464103408641, 4.01394196266544, 3.059025045522317, 2.0776340248002043, 1.973123469906548, 2.923285219289552, 3.904258081352324, 4.912044527824367, 5.853943007597602, 6.895884388504975, 7.841529014268845, 8.855573052326907, 9.878265212436201, 10.855093635882842, 11.737125025617786, 10.774420754647638, 9.843272756541374, 8.89630337076599, 7.971102927362525, 6.990264982653919, 5.9346106434424835, 4.996128175459649, 3.998461062085396, 2.998011676474495, 2.9276965642580075, 3.892780606106046, 4.842165412976958, 5.801848186272112, 6.735120447220527, 7.722674350947729, 8.692084476854845, 9.749497368973127, 10.81350440737559, 11.846014136598413, 12.712508549143969, 11.799921337852302, 10.797676114567702, 9.877979428158234, 8.870382193764213, 7.891154579077755, 6.932856118203135, 5.996936372142704, 4.980452772063145, 3.9304738880547503, 3.934897354416723, 4.828601548789695, 5.758215371509374, 6.733145500474058, 7.710839553285093, 8.705575547561313, 9.679229401250327, 10.720677684759378, 11.757830743012263, 12.72918863741833, 13.720561508145202, 12.825799223215892, 11.772604725235947, 10.850346631759344, 9.856721768863189, 8.83280353093717, 7.886690553925675, 6.9164439705789205, 5.951457903962695, 4.909069827210869, 4.945718466761987, 5.791624624283733, 6.697672314780993, 7.63941177622063, 8.62874325271553, 9.666738189100522, 10.702784978631215, 11.695767687000433, 12.71053020596003, 13.68765900554209, 14.614125416797268, 13.6045683080268, 12.657166883049438, 11.694341666101797, 10.710347996279697, 9.77033032029703, 8.852829745433509, 7.831352584532459, 6.790358822133669, 5.847665231203823, 5.891567734309258, 6.828300840252959, 7.624875248092098, 8.586666890864382, 9.56618327672347, 10.572109348029512, 11.624972952199176, 12.669327564146878, 13.643515810301237, 14.607045256109148, 15.553444650155834, 14.55416925556283, 13.616168557792777, 12.712182765357786, 11.66220038411671, 10.701173047903582, 9.688451012485682, 8.74596159646051, 7.759614435589256, 6.888332586596702, 6.9169162215670665, 7.786467825599029, 8.689357989488428, 9.51243686982923, 10.563414537984364, 11.537520119514765, 12.58609368980193, 13.568715059223623, 14.536137739622546, 15.480594493277007, 16.405944613510723, 15.579618758902425, 14.546859163040452, 13.70695813108973, 12.677247089137884, 11.638768462792617, 10.711807901257421, 9.773720256268675, 8.712369749601915, 7.88261402661085, 7.84767102908595, 8.851918697702683, 9.7328679753031, 10.470369677228707, 11.470128086690151, 12.469084566190977, 13.448778842914429, 14.430792790349345, 15.38521399126562, 16.423211642082453, 17.343596852522484, 16.542301570467757, 15.58477274289743, 14.700613827957682, 13.687061956194652, 12.630490339919241, 11.67483179109643, 10.688784498586616, 9.726679219777253, 8.814175256377634, 8.8261352981816, 9.773008583579735, 10.759040357581657, 11.402553775587723, 12.469288593802762, 13.424412635591507, 14.380713823461052, 15.397189070866046, 16.329024654476402, 17.31706746425955, 18.248225832061436, 17.472723475838233, 16.544154258375638, 15.603705901718445, 14.597332914552075, 13.602372116028912, 12.617840521212361, 11.653167883456375, 10.692364432513434, 9.778385647343391, 9.869738507387154, 10.767186702533428, 11.728362735262708, 12.403090634269363, 13.403224858854404, 14.475998599887728, 15.33325680738048, 16.288280539091595, 17.274424929066914, 18.25745205255964, 18.41812286608188, 17.524971086327163, 16.594517513566764, 15.589575844227364, 14.57439200685788, 13.536868859459892, 12.546005741658721, 11.744857001655474, 10.768265120712494, 9.902297728584482, 9.624350912866019, 10.627620510687368, 11.632345721261997, 12.53107092223609, 13.512818621487707, 14.40058600807821, 15.356106090267339, 16.387362517047276, 17.345392743753756, 18.394191750469677, 17.473539717204872, 16.56151546331435, 15.566109174293222, 14.574319046738061, 13.589297372687923, 12.572381522249184, 11.57936100670142, 10.711579146823967, 9.699088306167038, 8.878940980734692], [8.800319881646512, 8.07352164205145, 9.066656967849227, 9.833507772189405, 10.815841833908918, 11.820540148997768, 12.715486021645173, 13.711186816465068, 14.648484477490992, 15.539803898847577, 16.527369735784827, 17.329947709393778, 16.366005036753386, 15.376012138111282, 14.419412607256705, 13.551651091878904, 12.57554104701477, 11.563349087865928, 10.565779111523181, 9.614750895237378, 7.827920233649074, 7.097485757371294, 8.035850656840385, 8.893109693201461, 9.828263097926762, 10.805476310877564, 11.775592817567237, 12.710818549121928, 13.671565237062708, 14.547650195932327, 15.501755453941108, 16.431388463342373, 15.512245127503354, 14.530968651138602, 13.492447214443969, 12.486077333106458, 11.523116961961225, 10.619602297040615, 9.632982980000515, 8.686056591444494, 6.81019897038638, 6.096829935582481, 7.001019194148456, 7.864215820048496, 8.863152378948103, 9.834706492468774, 10.751991146079487, 11.770031490792215, 12.696140926902803, 13.614474621387425, 14.65521976216254, 15.634347174159261, 14.576911195931135, 13.628327199858427, 12.65532730999166, 11.599055329418942, 10.541171544351482, 9.70424512743083, 8.750891667433583, 7.748290040632804, 5.777205123763963, 5.135420860743334, 5.951894031684136, 6.901705196056209, 7.9102024828834345, 8.810935066382832, 9.79455456949261, 10.758639012332281, 11.71481120362585, 12.660908270529832, 13.695659570997947, 14.64421354931708, 13.680582500653689, 12.635473931868175, 11.715585583608693, 10.6502105884919, 9.58750532808535, 8.6493757060958, 7.698943808208157, 6.761435968472965, 4.832181823498459, 4.097245928484246, 5.00185132532749, 5.955728815224079, 6.919935681687357, 7.8069267405792075, 8.795978385854228, 9.727984122577007, 10.710415608476286, 11.73896752026932, 12.75443209279686, 13.726658075638282, 12.733690021260617, 11.708865594109636, 10.64545670893435, 9.688626352986814, 8.710959517830421, 7.687910485345346, 6.7106735808070335, 5.770082427526647, 3.8851392828979687, 3.0977364284320728, 3.955152996385114, 4.956715444880393, 5.93572737004111, 6.873334429756306, 7.87848945080094, 8.80273548179176, 9.775648342227315, 10.761300195847321, 11.695890184705116, 12.722336262527044, 11.76641169929829, 10.795000498584134, 9.77719211809673, 8.730004924149588, 7.755230981354083, 6.72932596120461, 5.793363778833618, 4.812933814649013, 2.8919371947746053, 2.083995889559902, 2.9228904015330257, 3.9675120158917023, 4.943784267745775, 5.917377923436138, 6.8721426469861555, 7.85664153507545, 8.814797599450138, 9.828486475701622, 10.834271665886446, 11.736122797775387, 10.805642259344921, 9.801257663269341, 8.79344088296969, 7.8276157371845345, 6.868170423818537, 5.794706097558048, 4.8292454631244555, 3.8238915267306384, 1.9247308814764634, 1.0729339689215855, 1.9317394012136986, 2.943418918339183, 3.96417595886716, 4.931915247594133, 5.918575306161412, 6.91013275263535, 7.952044939949413, 8.919247409491954, 9.97884961872897, 10.874062089305697, 9.873547923482935, 8.80746611482502, 7.823191040432884, 6.881097525136531, 5.933772935237871, 5.001915254959347, 3.9766597349509816, 2.9854034232075337, 0.9961308253723065, 0.0, 0.9787850140967524, 1.9950375841921415, 3.021778772222476, 4.040482405368675, 5.064553189710278, 6.055789256528029, 7.081461588895871, 8.046164585683456, 9.041810590825863, 10.007021437078489, 9.047358159583744, 7.983629778442064, 7.030021055452286, 6.0922816501335015, 5.08763312504598, 4.144202384901936, 3.1072334475299948, 2.0479027039058852, 1.9171641918798987, 0.9741902405060119, 2.013904249275096, 2.964237591686868, 3.9476286778429017, 4.9438149347879214, 5.997766737629034, 6.93317294585588, 7.902974637769179, 8.838370150013114, 9.791687742280867, 10.774536812064317, 9.874781645743091, 8.94122880097353, 8.01872305061394, 7.019636697145511, 5.94566447161227, 4.9311423308690685, 3.9762254137259463, 2.9883061719699917, 2.883795617076335, 2.04309862352875, 3.024071485591522, 3.9624403560374626, 4.891589673336299, 5.899753563132669, 6.845398188896539, 7.8594422269546005, 8.882134387063894, 9.858962810510535, 10.740994200245481, 11.685092901817423, 10.75394490371116, 9.806975517935776, 8.88177507453231, 7.900937129823705, 6.84528279061227, 5.906800322629436, 4.909133209255183, 3.908683823644282, 3.838368711427795, 3.0125940103452438, 3.9619788172161554, 4.9216615905113095, 5.854933851459724, 6.8424877551869265, 7.811897881094043, 8.839631209065754, 9.903638247468216, 10.849883311226106, 11.716377723771664, 12.706127528316763, 11.708348261737488, 10.78865157532802, 9.781054340934, 8.801826726247542, 7.843528265372923, 6.90760851931249, 5.891124919232931, 4.841146035224537, 4.84556950158651, 3.948414953028893, 4.878028775748572, 5.8529589047132555, 6.830652957524291, 7.825388951800511, 8.799042805489524, 9.840491088998576, 10.877644147251461, 11.849002041657528, 12.724430682772898, 13.722722292925654, 12.683276872405733, 11.761018778929131, 10.767393916032976, 9.743475678106957, 8.797362701095462, 7.827116117748708, 6.862130051132483, 5.819741974380657, 5.856390613931774, 4.91143802852293, 5.8174857190201905, 6.759225180459827, 7.748556656954728, 8.78655159333972, 9.822598382870412, 10.815581091239633, 11.830343610199229, 12.807472409781289, 13.7666294653179, 14.515240455196587, 13.567839030219226, 12.605013813271585, 11.621020143449485, 10.681002467466817, 9.763501892603296, 8.742024731702246, 7.701030969303456, 6.758337378373611, 6.8022398814790455, 5.948114244492157, 6.744688652331296, 7.706480295103581, 8.685996680962667, 9.69192275226871, 10.744786356438373, 11.789140968386075, 12.763329214540436, 13.726858660348347, 14.738468233866591, 15.464841402732617, 14.526840704962565, 13.622854912527574, 12.572872531286498, 11.61184519507337, 10.59912315965547, 9.656633743630298, 8.670286582759044, 7.799004733766489, 7.827588368736854, 6.906281229838227, 7.809171393727626, 8.632250274068427, 9.683227942223562, 10.657333523753962, 11.705907094041127, 12.68852846346282, 13.655951143861744, 14.600407897516204, 15.52575801774992, 16.461965887889704, 15.45753131021024, 14.617630278259517, 13.587919236307672, 12.549440609962405, 11.622480048427208, 10.684392403438462, 9.623041896771703, 8.793286173780638, 8.758343176255737, 7.971732101941881, 8.852681379542297, 9.590183081467904, 10.589941490929348, 11.588897970430175, 12.568592247153626, 13.550606194588543, 14.505027395504817, 15.543025046321652, 16.46341025676168, 17.452973717637548, 16.49544489006722, 15.611285975127469, 14.59773410336444, 13.541162487089029, 12.585503938266218, 11.599456645756403, 10.63735136694704, 9.724847403547422, 9.736807445351387, 9.018394949829112, 9.919995124179309, 10.52236717982692, 11.58910199804196, 12.544226039830704, 13.50052722770025, 14.517002475105244, 15.448838058715598, 16.436880868498747, 17.368039236300632, 17.5330338752197, 16.604464657757106, 15.664016301099911, 14.65764331393354, 13.662682515410378, 12.698532487444558, 12.043642082281346, 11.155760932901552, 10.689057794513179, 10.780410654556942, 10.012573068782805, 10.899308269036993, 11.52290403850856, 12.523038263093602, 13.595812004126925, 14.453070211619679, 15.408093943330792, 16.394238333306113, 17.37726545679884, 17.482983929387533, 16.598346177875676, 15.729017141243336, 14.724075471903937, 13.764676799056476, 12.727153651658488, 11.736290533857318, 11.06546925639674, 10.08887737545376, 10.898428553956789, 10.620481738238327, 11.031592059558308, 11.931199372324192, 12.455595750675759, 13.489177112793342, 14.515813236720579, 15.460696799621454, 16.443984016355824, 17.389721426517138, 17.561269011946884, 16.538400780510525, 15.634890554862865, 14.700608801969796, 13.708818674414635, 12.77958216488652, 11.762666314447781, 10.769645798900017, 10.032191401565234, 9.019700560908305, 9.875071806106998], [9.766821669090884, 8.895426465714548, 8.087871953752474, 8.854722758092652, 9.837056819812165, 10.841755134901016, 11.736701007548419, 12.732401802368313, 13.669699463394242, 14.561018884750826, 15.548584721688076, 16.394886344871676, 16.451533215387148, 15.461540316745044, 14.504940785890467, 13.533904958633805, 12.495404024223205, 12.084474404046386, 11.532280898967553, 10.58125268268175, 8.794422021093446, 7.919390581034392, 7.057065642743633, 7.914324679104709, 8.84947808383001, 9.826691296780812, 10.796807803470482, 11.732033535025174, 12.692780222965958, 13.568865181835577, 14.522970439844357, 15.452603449245622, 16.478746914947727, 15.497470438582974, 14.45894900188834, 13.45257912055083, 12.489618749405597, 11.586104084484987, 10.599484767444887, 9.652558378888866, 7.776700757830752, 6.918734759245579, 6.022234180051703, 6.885430805951744, 7.88436736485135, 8.855921478372021, 9.773206131982732, 10.791246476695461, 11.717355912806052, 12.635689607290674, 13.67643474806579, 14.65584315418618, 15.543412983375507, 14.5948289873028, 13.621829097436033, 12.565557116863314, 11.507673331795853, 10.670746914875203, 9.717393454877953, 8.714791828077177, 6.743706911208335, 5.957325684406432, 4.973109017587384, 5.922920181959457, 6.931417468786682, 7.832150052286081, 8.815769555395857, 9.77985399823553, 10.736026189529099, 11.682123256433082, 12.716874556901194, 13.68255730124963, 14.646188349913022, 13.60197571931255, 12.682087371053067, 11.616712375936274, 10.554007115529721, 9.615877493540172, 8.665445595652528, 7.727937755917337, 5.798683610942831, 4.92487704558474, 4.023066311230737, 4.976943801127327, 5.9411506675906045, 6.828141726482455, 7.817193371757476, 8.749199108480257, 9.731630594379535, 10.760182506172567, 11.775647078700107, 12.752465546761837, 13.700191808704993, 12.675367381554011, 11.611958496378724, 10.655128140431188, 9.677461305274795, 8.654412272789719, 7.6771753682514055, 6.736584214971019, 4.851641070342341, 3.9253675455325667, 2.9763679822883615, 3.9779304307836405, 4.956942355944357, 5.8945494156595535, 6.899704436704187, 7.823950467695009, 8.796863328130563, 9.782515181750568, 10.717105170608363, 11.743551248430293, 12.732913486742664, 11.761502286028508, 10.743693905541104, 9.696506711593962, 8.721732768798457, 7.695827748648983, 6.759865566277991, 5.779435602093386, 3.8584389822189777, 2.911627006660396, 1.9441053874362735, 2.98872700179495, 3.9649992536490224, 4.938592909339386, 5.893357632889403, 6.877856520978698, 7.836012585353386, 8.84970146160487, 9.855486651789693, 10.821267655577223, 11.751748194007689, 10.767759450713715, 9.759942670414064, 8.794117524628907, 7.834672211262909, 6.761207885002421, 5.795747250568828, 4.790393314175011, 2.8912326689208356, 1.9005650860220795, 0.9529543871169462, 1.9646339042424308, 2.9853909447704075, 3.9531302334973804, 4.93979029206466, 5.931347738538598, 6.973259925852661, 7.940462395395202, 9.00006460463222, 9.955743073879209, 10.840049710927307, 9.773967902269392, 8.789692827877257, 7.847599312580904, 6.900274722682244, 5.96841704240372, 4.9431615223953544, 3.951905210651906, 1.974915839469059, 0.9787850140967524, 0.0, 1.016252570095389, 2.0429937581257236, 3.061697391271923, 4.085768175613525, 5.0770042424312765, 6.102676574799118, 7.067379571586704, 8.06302557672911, 9.102751769136136, 10.026143173680497, 8.962414792538818, 8.008806069549038, 7.071066664230254, 6.0664181391427325, 5.1229873989986885, 4.086018461626747, 3.0266877180026377, 2.895949205976651, 1.9529752546027643, 1.0351192351783431, 1.9854525775901155, 2.968843663746149, 3.965029920691169, 5.018981723532281, 5.954387931759127, 6.924189623672427, 7.859585135916361, 8.812902728184113, 9.795751797967563, 10.808145107800687, 9.920013815070282, 8.997508064710692, 7.998421711242264, 6.924449485709022, 5.909927344965821, 4.955010427822699, 3.967091186066744, 3.8625806311730875, 3.0218836376255025, 2.092802207427372, 2.98365534194071, 3.9128046592395465, 4.9209685490359165, 5.866613174799786, 6.880657212857848, 7.903349372967142, 8.880177796413783, 9.762209186148727, 10.818203420280966, 11.732729917807914, 10.78576053203253, 9.860560088629065, 8.879722143920459, 7.824067804709022, 6.885585336726188, 5.887918223351935, 4.887468837741034, 4.817153725524547, 3.991379024441996, 3.0307095390520056, 3.99039231234716, 4.923664573295575, 5.911218477022778, 6.880628602929894, 7.8608461949690005, 8.924853233371461, 9.871098297129354, 10.73759270967491, 11.727342514220009, 12.687133275834242, 11.767436589424774, 10.759839355030753, 9.780611740344295, 8.822313279469675, 7.886393533409242, 6.869909933329683, 5.819931049321289, 5.824354515683263, 4.895790171422072, 3.966176348702393, 4.921689626549107, 5.899383679360142, 6.894119673636362, 7.867773527325376, 8.909221810834428, 9.932667168214374, 10.904025062620441, 11.745645668676143, 12.7439372788289, 13.662061886502487, 12.739803793025883, 11.746178930129728, 10.72226069220371, 9.776147715192215, 8.80590113184546, 7.840915065229235, 6.798526988477409, 6.820042996476724, 5.85881324691611, 4.905633291974012, 5.847372753413649, 6.834579362797198, 7.855282315175572, 8.891329104706264, 9.884311813075485, 10.885366631162142, 11.862495430744202, 12.787844451221146, 13.791570265407204, 14.546624044315978, 13.583798827368337, 12.599805157546237, 11.65978748156357, 10.742286906700048, 9.720809745798999, 8.679815983400209, 7.737122392470363, 7.765892264023996, 6.8283845165170485, 5.832836225285117, 6.794627868057402, 7.7720193868051375, 8.77794545811118, 9.830809062280844, 10.875163674228546, 11.81835223550335, 12.78188168131126, 13.759683219769837, 14.741171212943234, 15.505625719059317, 14.601639926624326, 13.55165754538325, 12.590630209170122, 11.577908173752222, 10.63541875772705, 9.649071596855796, 8.777789747863242, 8.791240751281805, 7.786551501863118, 6.897318966681447, 7.720397847022249, 8.771375515177384, 9.745481096707785, 10.794054666994949, 11.776676036416642, 12.744098716815566, 13.688555470470027, 14.613905590703743, 15.550113460843527, 16.43631632430699, 15.59641529235627, 14.566704250404424, 13.528225624059157, 12.60126506252396, 11.663177417535213, 10.601826910868454, 9.756938556325588, 9.721995558800687, 8.852002373966773, 7.940828952496117, 8.678330654421726, 9.67808906388317, 10.677045543383997, 11.656739820107449, 12.638753767542365, 13.593174968458639, 14.631172619275475, 15.551557829715504, 16.55390037374516, 16.666377544352883, 15.633159321054347, 14.702604194096185, 13.684803809971658, 12.679940204657024, 12.064899159718872, 11.613985563072825, 10.688499786092372, 10.700459827896337, 9.898665221854003, 9.00814269713313, 9.610514752780743, 10.677249570995782, 11.632373612784527, 12.588674800654072, 13.605150048059066, 14.53698563166942, 15.525028441452568, 16.456186809254454, 16.554248861122947, 15.625679643660352, 14.685231287003159, 13.678858299836788, 12.683897501313625, 11.719747473347805, 11.084882758294635, 11.977665756564651, 11.652710177058129, 11.744063037101892, 10.892843340807696, 9.987455841990814, 10.611051611462383, 11.611185836047424, 12.683959577080747, 13.541217784573501, 14.496241516284615, 15.482385906259935, 16.46541302975266, 16.504198915290782, 15.619561163778926, 14.750232127146582, 13.745290457807183, 12.785891784959723, 11.748368637561736, 10.757505519760565, 10.106709932410029, 10.91078219911686, 11.843062085390276, 11.5869835256827, 11.9118623315832, 11.019346945278013, 11.543743323629581, 12.577324685747165, 13.603960809674401, 14.548844372575276, 15.532131589309648, 16.47786899947096, 16.582483997850133, 15.559615766413774, 14.656105540766115, 13.721823787873042, 12.730033660317881, 11.800797150789768, 10.783881300351029, 9.790860784803264, 9.073432077578522, 9.841605384571404, 10.819705337540485], [10.783074239186275, 9.911679035809938, 9.009932795921511, 8.05014064237994, 9.032474704099453, 9.99273632444034, 10.839222100686333, 11.834922895506228, 12.742437540021067, 13.633756961377651, 14.621322798314901, 15.4676244214985, 15.507323300461783, 14.517330401819681, 13.560730870965104, 12.589695043708442, 11.551194109297843, 12.563386068446682, 12.548533469062942, 11.59750525277714, 9.810674591188837, 8.935643151129781, 8.073318212839023, 7.109742563391997, 8.044895968117297, 8.94678101800924, 9.899328896608397, 10.834554628163088, 11.765518299592783, 12.641603258462402, 13.595708516471182, 14.525341525872447, 15.564065543845173, 15.469267682289285, 14.48769626377784, 13.586268079109043, 12.62330770796381, 12.602356654580376, 11.615737337540276, 10.668810948984255, 8.792953327926142, 7.934987329340968, 7.038486750147093, 6.080848690239032, 7.0562543594076494, 7.958442571509934, 8.875727225120647, 9.893767569833376, 10.790093989432878, 11.708427683917499, 12.749172824692614, 13.728581230813004, 14.685831226192754, 15.611081557398188, 14.638081667531422, 13.581809686958703, 12.523925901891243, 11.686999484970592, 10.733646024973343, 9.731044398172566, 7.759959481303724, 6.973578254501821, 5.989361587682773, 5.118338066246745, 6.103304463342981, 6.9346711454239935, 7.9182906485337705, 8.852592074862356, 9.808764266155924, 10.754861333059907, 11.78961263352802, 12.755295377876458, 13.718926426539849, 14.618228289407936, 13.698339941148454, 12.632964946031661, 11.57025968562511, 10.632130063635561, 9.681698165747918, 8.744190326012726, 6.81493618103822, 5.941129615680129, 5.0393188813261265, 4.079464894265239, 5.043671760728517, 5.930662819620368, 6.919714464895389, 7.821937185107082, 8.80436867100636, 9.832920582799392, 10.848385155326932, 11.825203623388663, 12.818171677766328, 13.691619951649397, 12.628211066474112, 11.671380710526575, 10.693713875370182, 9.670664842885108, 8.693427938346796, 7.752836785066409, 5.86789364043773, 4.941620115627956, 3.992620552383751, 3.0804515239215537, 4.05946344908227, 4.997070508797466, 5.972442513331012, 6.896688544321834, 7.869601404757388, 8.855253258377394, 9.789843247235188, 10.816289325057117, 11.869796916471692, 12.777754856123897, 11.759946475636491, 10.71275928168935, 9.737985338893845, 8.712080318744372, 7.7761181363733805, 6.795688172188775, 4.874691552314367, 3.9278795767557853, 2.9603579575316625, 2.091248094932863, 3.0675203467869356, 4.011330985966211, 4.966095709516228, 5.950594597605523, 6.9087506619802115, 7.922439538231695, 8.928224728416518, 9.894005732204048, 10.824486270634514, 11.784012020809104, 10.776195240509454, 9.810370094724297, 8.850924781358298, 7.777460455097811, 6.811999820664218, 5.8066458842704005, 3.907485239016225, 2.916817656117469, 1.9692069572123354, 1.0671549973803438, 2.0581290213972325, 3.0258683101242054, 4.012528368691485, 5.004085815165423, 6.045998002479486, 7.013200472022027, 8.072802681259045, 9.028481150506034, 9.988827115522884, 10.790220472364782, 9.805945397972646, 8.863851882676293, 7.916527292777634, 6.9846696124991094, 5.959414092490744, 4.968157780747296, 2.991168409564448, 1.9950375841921415, 1.016252570095389, 0.0, 1.0267411880303345, 2.0454448211765337, 3.069515605518136, 4.060751672335887, 5.086424004703729, 6.051127001491315, 7.046773006633721, 8.086499199040746, 9.04616247653549, 9.978667362634207, 9.025058639644428, 8.087319234325644, 7.082670709238122, 6.139239969094078, 5.102271031722136, 4.042940288098027, 3.91220177607204, 2.9692278246981534, 2.0150091978144946, 0.9692000074947265, 1.95259109365076, 2.94877735059578, 4.002729153436892, 4.938135361663738, 5.9079370535770375, 6.843332565820972, 7.796650158088725, 8.779499227872176, 9.7918925377053, 10.725445382474861, 10.013760634806081, 9.014674281337653, 7.940702055804412, 6.926179915061209, 5.971262997918087, 4.9833437561621325, 4.878833201268477, 3.9561620803801363, 2.9751892183173645, 1.9674027718453209, 2.8965520891441576, 3.9047159789405277, 4.850360604704398, 5.864404642762459, 6.887096802871753, 7.863925226318393, 8.74595661605334, 9.801950850185579, 10.733098848291842, 11.680068234067226, 10.876812658724454, 9.895974714015848, 8.840320374804412, 7.901837906821577, 6.904170793447324, 5.903721407836423, 5.833406295619937, 4.92565746719663, 3.913096549941998, 2.983498168894599, 3.9167704298430137, 4.904324333570217, 5.870872853437803, 6.844593624873611, 7.908600663276073, 8.854845727033965, 9.721340139579523, 10.711089944124621, 11.68750220631817, 12.66174429145947, 11.776091925126142, 10.796864310439684, 9.838565849565065, 8.902646103504631, 7.886162503425072, 6.836183619416678, 6.791102616633804, 5.7781771823120645, 4.848563359592386, 3.9147954830965452, 4.892489535907581, 5.887225530183801, 6.860879383872815, 7.902327667381867, 8.916414598118987, 9.887772492525054, 10.729393098580754, 11.727684708733511, 12.662430816986415, 13.660870891189347, 12.712927031080271, 11.689008793154253, 10.742895816142758, 9.772649232796002, 8.807663166179777, 7.76527508942795, 7.702430007366717, 6.741200257806103, 5.7880203028640045, 4.887718866315328, 5.827685219344637, 6.848388171723011, 7.884434961253703, 8.877417669622922, 9.869114061066753, 10.846242860648813, 11.771591881125756, 12.775317695311815, 13.655501540878676, 14.55054692831888, 13.56655325849678, 12.626535582514112, 11.709035007650591, 10.677500066841803, 9.636506304443014, 8.693812713513168, 8.648279274913989, 7.710771527407041, 6.71522323617511, 5.850417953132041, 6.765125243352577, 7.771051314658619, 8.823914918828283, 9.868269530775985, 10.80209966540796, 11.76562911121587, 12.743430649674448, 13.724918642847845, 14.614503215622015, 15.564555464848302, 14.514573083607226, 13.547320530212927, 12.534598494795027, 11.592109078769855, 10.605761917898601, 9.699921703713144, 9.673627762171797, 8.668938512753112, 7.767198778489248, 6.776187932096888, 7.80557128945222, 8.77967687098262, 9.828250441269784, 10.810871810691477, 11.778294491090401, 12.722751244744861, 13.648101364978578, 14.584309235118361, 15.54519382086969, 15.859770208872728, 14.914670273479269, 13.87194357138557, 12.838381978783321, 12.61986773857802, 11.55851723191126, 10.63932556721558, 10.60438256969068, 9.734389384856765, 8.717907669027534, 7.7341207394963645, 8.733879148957808, 9.729218405571267, 10.708912682294718, 11.690926629729635, 12.645347830645909, 13.683345481462744, 14.585753603990339, 15.588096148019996, 15.861795428640171, 14.828577205341634, 13.898022078383473, 12.880221694258946, 11.875358088944312, 12.859854396815317, 12.496372573962818, 11.570886796982364, 11.58284683878633, 10.672427003175398, 9.686395229173476, 8.66630483785538, 9.733039656070419, 10.688163697859164, 11.64446488572871, 12.660882214308463, 13.58915849385669, 14.577201303639837, 15.508359671441722, 15.628393107319704, 14.82109752794764, 13.880649171290447, 12.874276184124076, 11.879315385600913, 10.915165357635093, 11.87983799539108, 12.84064144633402, 12.535097187948121, 12.626450047991884, 11.564932909249752, 10.603756876520471, 9.66684169653702, 10.666975921122061, 11.739749662155385, 12.597007869648138, 13.552031601359252, 14.538175991334573, 15.5212031148273, 15.576936991917606, 14.69229924040575, 13.852753220284496, 12.847811550945098, 11.97700994851666, 10.943786521849024, 9.952923404047853, 10.98513587442531, 11.927034769212248, 12.859314655485665, 12.603236095778088, 12.583951900025255, 11.591728980521854, 10.599533408704218, 11.633114770821802, 12.659750894749038, 13.604634457649913, 14.587921674384285, 15.533659084545599, 15.655222074476958, 14.6323538430406, 13.72884361739294, 12.824344881010957, 11.832554753455796, 10.951778340329092, 9.979299184638316, 8.986278669090552, 9.988692277457199, 10.857857954666793, 11.835957907635875], [11.809815427216607, 10.938420223840271, 9.982011415192474, 9.022219261650903, 8.159364544381752, 9.012270440003158, 9.858756216249153, 10.854457011069048, 11.715696351990733, 12.607015773347317, 13.594581610284568, 14.440883233468167, 14.807233229119255, 13.817240330477153, 12.890817228300524, 11.919781401043862, 12.520321092320737, 13.532513051469579, 13.575274657093276, 12.624246440807472, 10.83741577921917, 9.962384339160115, 9.085624129059818, 8.08182118266296, 7.171785808399597, 7.966315133572059, 8.918863012171217, 9.854088743725908, 10.738777111562449, 11.614862070432068, 12.568967328440849, 13.498600337842113, 14.537324355814839, 14.769177610946757, 13.81778262111326, 12.985355159816308, 13.592434690986705, 13.629097842610712, 12.64247852557061, 11.69555213701459, 9.819694515956474, 8.961728517371302, 8.050792666367888, 7.052927309509996, 6.162682047111076, 6.977976687072754, 7.895261340683467, 8.882801549391047, 9.763352801402544, 10.681686495887165, 11.72243163666228, 12.70184004278267, 13.659090038162418, 14.607674034235126, 14.837013578360498, 14.036330784444518, 13.550667089921575, 12.713740673000926, 11.760387213003677, 10.7577855862029, 8.786700669334058, 8.000319442532156, 7.016102775713107, 6.090416685517709, 5.209732151046407, 5.9542052609868135, 6.93782476409659, 7.825850886832022, 8.78202307812559, 9.728120145029573, 10.762871445497685, 11.728554189846122, 12.692185238509513, 13.737293807295027, 14.72508112917879, 13.659706134061997, 12.597000873655444, 11.658871251665895, 10.708439353778251, 9.77093151404306, 7.841677369068554, 6.967870803710463, 6.06606006935646, 5.0515435135362035, 4.150099448431943, 4.950196935183188, 5.939248580458209, 6.795195997076748, 7.777627482976027, 8.806179394769059, 9.821643967296598, 10.798462435358328, 11.791430489735992, 12.816254916886974, 13.654952254504447, 12.698121898556911, 11.720455063400518, 10.697406030915442, 9.72016912637713, 8.779577973096742, 6.894634828468064, 5.968361303658289, 5.019361740414085, 4.052530143192517, 3.078997564645089, 4.016604624360285, 4.9457013253006785, 5.8699473562915, 6.842860216727054, 7.82851207034706, 8.763102059204854, 9.789548137026785, 10.843055728441358, 11.814466929155515, 12.786687663666827, 11.739500469719685, 10.76472652692418, 9.738821506774707, 8.802859324403714, 7.822429360219109, 5.901432740344701, 4.954620764786119, 3.987099145561997, 3.0633267142038267, 2.0870544623497542, 2.984589797935876, 3.939354521485894, 4.923853409575189, 5.882009473949878, 6.895698350201362, 7.901483540386185, 8.867264544173715, 9.79774508260418, 10.843582748686094, 11.802936428539788, 10.837111282754632, 9.877665969388634, 8.804201643128145, 7.8387410086945515, 6.833387072300734, 4.934226427046559, 3.9435588441478027, 2.9959481452426697, 2.052144873894875, 1.0313878333668978, 1.9991271220938704, 2.9857871806611502, 3.9773446271350883, 5.019256814449151, 5.986459283991692, 7.04606149322871, 8.001739962475698, 8.962085927492549, 10.028167736150463, 10.83268658600298, 9.890593070706627, 8.943268480807967, 8.011410800529443, 6.986155280521078, 5.99489896877763, 4.017909597594782, 3.021778772222476, 2.0429937581257236, 1.0267411880303345, 0.0, 1.0187036331461992, 2.0427744174878013, 3.0340104843055524, 4.059682816673394, 5.02438581346098, 6.020031818603386, 7.059758011010412, 8.019421288505157, 9.083149669646836, 10.036758392636616, 9.114060422355976, 8.109411897268455, 7.165981157124412, 6.12901221975247, 5.069681476128361, 4.938942964102375, 3.995969012728488, 3.041750385844829, 1.995941195525061, 1.0506702796015803, 2.0304997334924546, 2.975987965406557, 3.9113941736334032, 4.881195865546703, 5.816591377790637, 6.76990897005839, 7.75275803984184, 8.765151349674964, 9.698704194444526, 10.773448984827764, 10.041415469367987, 8.967443243834746, 7.952921103091544, 6.998004185948422, 6.010084944192467, 5.875450812786032, 4.925289063403028, 3.944316201340256, 2.936529754868213, 1.994631275094978, 2.986438361837202, 3.9138051691207956, 4.837663454732124, 5.860355614841418, 6.837184038288059, 7.719215428023005, 8.775209662155245, 9.706357660261508, 10.653327046036893, 11.578527489440358, 10.892592325533402, 9.836937986321965, 8.898455518339132, 7.90078840496488, 6.900339019353979, 6.830023907137492, 5.894784450219522, 4.88222353296489, 3.9526251519174913, 3.0368726451533012, 4.024426548880504, 4.934317417854201, 5.8178524368432765, 6.881859475245738, 7.82810453900363, 8.694598951549189, 9.684348756094288, 10.660761018287836, 11.635003103429137, 12.594610820053058, 11.793481921957238, 10.835183461082618, 9.899263715022187, 8.882780114942628, 7.832801230934233, 7.760229599656696, 6.747304165334956, 5.817690342615277, 4.883922466119437, 4.064216657022733, 5.058952651298953, 5.942673707224836, 6.887556877968567, 7.889673410088651, 8.861031304494718, 9.702651910550422, 10.700943520703179, 11.635689628956081, 12.634129703159013, 13.623515479917813, 12.658135776177144, 11.712022799165648, 10.741776215818893, 9.776790149202668, 8.734402072450841, 8.671556990389607, 7.710327240828994, 6.757147285886896, 5.856845849338221, 4.99941234045979, 6.020115292838163, 6.992247344000217, 7.8995308781478375, 8.842372873036418, 9.819501672618477, 10.744850693095424, 11.748576507281483, 12.628760352848342, 13.591585569795983, 14.535680241519671, 13.595662565537003, 12.678161990673482, 11.646627049864694, 10.605633287465905, 9.662939696536059, 9.617406257936878, 8.679898510429933, 7.684350219198001, 6.819544936154934, 5.936852364467729, 6.942778435773771, 7.9956420399434345, 8.909094300888915, 9.775358477377624, 10.738887923185535, 11.716689461644116, 12.698177454817513, 13.587762027591682, 14.606707418453691, 15.061227021210906, 14.115789594556711, 13.503725477817918, 12.561236061792746, 11.574888900921492, 10.669048686736033, 10.642754745194686, 9.638065495776003, 8.736325761512141, 7.74531491511978, 6.977298410567372, 7.951403992097772, 8.999977562384936, 9.871423459369444, 10.800661167776301, 11.745117921430761, 12.670468041664478, 13.606675911804262, 14.518452632839356, 14.904490723262965, 14.046180316189732, 13.178194179667676, 13.810460598054284, 13.588994721600908, 12.52764421493415, 11.60845255023847, 11.573509552713569, 10.703516367879656, 9.687034652050428, 8.703247722519258, 8.037178269963611, 8.900945526686419, 9.88063980340987, 10.862653750844787, 11.782974035961598, 12.744143654084445, 13.60812028067624, 14.610462824705897, 14.906515943030408, 13.873297719731871, 13.013029996391264, 12.186472302541052, 12.847436708215275, 13.83193301608628, 13.465499556985707, 12.540013780005253, 12.551973821809218, 11.641553986198293, 10.65552221219637, 9.635431820878274, 9.060955307609223, 9.952634384871631, 10.8714209013429, 11.832609335423616, 12.726784699172379, 13.714827508955526, 14.617769910192797, 14.60165191928937, 13.865818042337876, 12.925369685680684, 11.989284102131865, 11.13729378282125, 11.887243976906056, 12.851916614662043, 13.812720065604983, 13.50422417097101, 13.595577031014773, 12.534059892272644, 11.572883859543364, 10.635968679559914, 9.994891572660865, 11.009902030246787, 11.823963885262327, 12.77898761697344, 13.742495234301218, 14.725522357793945, 14.550195803887272, 13.665558052375417, 12.872287335847316, 11.867345666507918, 10.996544064079478, 10.20176491906936, 10.925002023318816, 11.957214493696274, 12.953775957242582, 13.886055843515999, 13.62997728380842, 13.553078883048148, 12.560855963544748, 11.568660391727112, 10.96248304606275, 11.989119169989987, 12.831590473264102, 13.814877689998474, 14.737978327512245, 14.628480886446624, 13.605612655010265, 12.702102429362606, 11.843878996573777, 10.852088869018615, 9.97131245589191, 9.172786126782274, 9.958357288361515, 10.960770896728162, 11.884599142697127, 12.862699095666208], [12.685561719559109, 11.73591720643956, 10.74257487089557, 9.782782717354, 8.894809969622912, 8.013970449784521, 8.860456226030516, 9.856157020850409, 10.698612292596504, 11.589931713953089, 12.577497550890339, 13.423799174073938, 13.981548295466709, 12.991555396824607, 12.232518520093928, 12.877093478733554, 13.477633170010431, 14.489825129159271, 14.550114360572792, 13.59908614428699, 11.729801734290225, 10.784717639936966, 9.883832355659996, 8.842384638366056, 7.907231233640755, 6.968015143353421, 7.920563021952579, 8.85578875350727, 9.72169305216822, 10.597778011037839, 11.55188326904662, 12.481516278447884, 13.52024029642061, 13.943492677294211, 13.159483912906664, 13.942667237506, 14.5497467686764, 14.603937546090226, 13.617318229050126, 12.670391840494105, 10.805965279793881, 9.784061818148153, 8.849000892968066, 7.8511355361101725, 6.898127472352234, 5.979676696854116, 6.896961350464829, 7.865717489996817, 8.746268742008315, 9.664602436492936, 10.705347577268052, 11.684755983388442, 12.64200597876819, 13.590589974840897, 14.178714870153902, 14.99364286213421, 14.536937853758982, 13.700011436838333, 12.746657976841083, 11.744056350040307, 9.772971433171465, 8.822652743309007, 7.838436076489958, 6.888624912117885, 5.945177576287566, 4.955905270768175, 5.939524773877952, 6.808766827437793, 7.764939018731361, 8.711036085635344, 9.745787386103457, 10.711470130451893, 11.675101179115284, 12.720209747900798, 13.768323868870924, 14.645976897899404, 13.583271637492851, 12.645142015503302, 11.694710117615658, 10.757202277880467, 8.827948132905961, 7.857277015070011, 6.889434441015684, 5.84975174013638, 4.885544873673102, 3.9518969449645494, 4.940948590239571, 5.778111937682519, 6.760543423581798, 7.789095335374829, 8.80455990790237, 9.781378375964099, 10.774346430341764, 11.799170857492745, 12.862579742668032, 13.684392662394318, 12.706725827237925, 11.683676794752849, 10.706439890214536, 9.76584873693415, 7.880905592305471, 6.954632067495696, 5.976896453533195, 4.94897125203452, 3.9559116938568435, 3.0183046341416473, 3.92861726590645, 4.852863296897271, 5.825776157332825, 6.811428010952831, 7.7460179998106256, 8.772464077632556, 9.825971669047131, 10.797382869761288, 11.863712881175903, 12.725771233557092, 11.750997290761587, 10.725092270612114, 9.789130088241121, 8.808700124056516, 6.887703504182108, 5.940891528623526, 4.973369909399404, 3.9597678230458286, 2.983495571191756, 1.9675057385416481, 2.9222704620916655, 3.9067693501809604, 4.864925414555649, 5.878614290807133, 6.884399480991957, 7.850180484779487, 8.780661023209953, 9.826498689291867, 10.834315469591518, 11.813025128095576, 10.86393673322604, 9.790472406965552, 8.825011772531958, 7.819657836138141, 5.920497190883966, 4.9298296079852095, 3.9822189090800766, 2.970539391954592, 1.9497823514266148, 0.9820430626996423, 1.968703121266922, 2.96026056774086, 4.002172755054922, 4.968744230664134, 6.028346439901152, 6.98402490914814, 7.943382294346351, 9.009464103004264, 9.9937391773964, 10.876863834544034, 9.929539244645374, 8.99768156436685, 7.9724260443584845, 6.981169732615037, 5.036613230740982, 4.040482405368675, 3.061697391271923, 2.0454448211765337, 1.0187036331461992, 0.0, 1.0240707843416024, 2.0153068511593535, 3.0409791835271953, 4.005682180314781, 5.001328185457187, 6.041054377864213, 7.000717655358958, 8.064446036500637, 9.018054759490417, 9.9557941648092, 9.128115530414657, 8.184684790270612, 7.147715852898671, 6.088385109274561, 5.957646597248574, 5.014672645874687, 4.0371826337670775, 2.9913734434473094, 2.007982357291276, 1.0117961003462554, 1.957284332260358, 2.8926905404872043, 3.8624922324005038, 4.797887744644438, 5.751205336912191, 6.734054406695641, 7.746447716528765, 8.680000561298327, 9.754745351681565, 10.821583974731118, 9.986146876980944, 8.971624736237743, 8.01670781909462, 7.028788577338666, 6.832762890475728, 5.8826011410927235, 4.901628279029952, 3.8938418325579085, 2.9519433527846735, 1.9677347286910027, 2.8951015359745966, 3.818959821585925, 4.841651981695219, 5.81848040514186, 6.700511794876806, 7.756506029009045, 8.68765402711531, 9.634623412890694, 10.559823856294159, 11.540661801002765, 10.794250064011662, 9.855767596028828, 8.858100482654576, 7.857651097043675, 7.7873359848271875, 6.852096527909217, 5.839535610654585, 4.909937229607187, 3.9941847228429967, 3.0395126417617524, 3.915613784708002, 4.7991488036970775, 5.863155842099539, 6.809400905857431, 7.675895318402989, 8.665645122948087, 9.642057385141637, 10.616299470282938, 11.575907186906859, 12.513435640201939, 11.792495538772314, 10.856575792711883, 9.840092192632325, 8.79011330862393, 8.717541677346391, 7.704616243024652, 6.775002420304973, 5.841234543809133, 5.021528734712428, 4.100305033282192, 4.923970074078637, 5.868853244822368, 6.870969776942452, 7.842327671348518, 8.683948277404221, 9.682239887556978, 10.616985995809882, 11.615426070012814, 12.604811846771614, 13.45693418017533, 12.669334876855345, 11.69908829350859, 10.734102226892364, 9.691714150140537, 9.628869068079304, 8.66763931851869, 7.714459363576592, 6.8141579270279165, 5.956724418149484, 5.061467674821402, 5.973543710854018, 6.880827245001639, 7.8236692398902195, 8.80079803947228, 9.726147059949223, 10.729872874135282, 11.610056719702143, 12.572881936649784, 13.543609843168811, 14.394460969535189, 13.635474068363179, 12.60393912755439, 11.562945365155601, 10.620251774225755, 10.574718335626574, 9.637210588119629, 8.641662296887697, 7.776857013844629, 6.8941644421574235, 6.09691865463402, 7.046920189648365, 7.890390667742716, 8.756654844231427, 9.720184290039338, 10.697985828497915, 11.679473821671312, 12.569058394445483, 13.588003785307492, 14.062927030992268, 14.85123501979787, 14.461037555507614, 13.518548139482442, 12.532200978611188, 11.62636076442573, 11.600066822884383, 10.595377573465699, 9.693637839201836, 8.702626992809476, 7.934610488257067, 7.127226084491989, 8.096173938489537, 8.852719826223245, 9.781957534630104, 10.726414288284564, 11.65176440851828, 12.587972278658064, 13.499748999693157, 13.906190733044328, 13.047880325971095, 13.913639604908836, 14.57102405375738, 14.546306799290605, 13.484956292623846, 12.565764627928166, 12.530821630403265, 11.660828445569352, 10.644346729740123, 9.660559800208953, 8.994490347653304, 8.076767619080636, 9.054954869757324, 9.915135765057686, 10.7642704028154, 11.725440020938247, 12.589416647530042, 13.5917591915597, 13.908215952811771, 12.874997729513234, 12.014730006172627, 12.921917727782212, 13.608000163918371, 14.592496471789376, 14.422811634675403, 13.49732585769495, 13.509285899498915, 12.598866063887987, 11.612834289886065, 10.592743898567969, 10.018267385298916, 9.128456477265848, 10.045735967690353, 10.885091349636514, 11.708081066026182, 12.696123875809329, 13.5990662770466, 13.584567859895142, 12.86751805211924, 11.927069695462047, 10.990984111913228, 11.87273920806241, 12.647807432609152, 13.61248007036514, 14.57328352130808, 14.461536248660707, 14.55288910870447, 13.49137196996234, 12.53019593723306, 11.593280757249609, 10.952203650350558, 10.185724122641004, 10.99827895160978, 11.9501135824945, 12.723791601155021, 13.706818724647748, 13.533111744493043, 12.648473992981188, 11.873987345628679, 10.86904567628928, 9.99824407386084, 10.93721034431052, 11.685565479021912, 12.71777794939937, 13.75127293984187, 14.683552826115287, 14.604816987287938, 14.510390960737844, 13.518168041234443, 12.525972469416807, 11.919795123752444, 11.255214293900114, 12.005905539611556, 12.986003655519534, 13.719274694366048, 13.611396827052396, 12.588528595616037, 11.685018369968377, 10.84557900635514, 9.853788878799978, 8.973012465673273, 9.908231552023434, 10.718920744064611, 11.721334352431258, 12.682096125296415, 13.660196078265496], [13.672065312101457, 12.722420798981908, 11.729078463437919, 10.769286309896348, 9.88131356216526, 8.972230909527743, 7.957949006605905, 8.951239368842021, 9.73454342652509, 10.625862847881674, 11.613428684818924, 12.459730308002523, 12.957477511125106, 11.967484612483004, 12.914659063652895, 13.715654722633088, 14.349475231352379, 15.361667190501219, 15.53661795311514, 14.585589736829338, 12.716305326832574, 11.771221232479315, 10.870335948202344, 9.828888230908404, 8.893734826183104, 7.9545187358957685, 7.018055802527968, 7.9508711014988815, 8.757624186096805, 9.633709144966424, 10.587814402975205, 11.51744741237647, 12.556171430349195, 12.919421892952608, 13.841624456465631, 14.781228481405535, 15.421588830018347, 15.590441138632574, 14.603821821592474, 13.656895433036453, 11.811272025064058, 10.770565410690502, 9.835504485510414, 8.83763912865252, 7.884631064894583, 6.966180289396464, 5.994454131040218, 6.901648623925403, 7.7821998759369, 8.700533570421522, 9.741278711196637, 10.720687117317027, 11.677937112696778, 12.626521108769486, 13.599520998636253, 14.655792979208972, 15.54618910482213, 14.709262687901479, 13.75590922790423, 12.753307601103453, 10.782222684234611, 9.809156335851355, 8.824939669032307, 7.875128504660234, 6.931681168829915, 5.942408863310523, 5.0370175544533415, 5.8446979613663785, 6.800870152659947, 7.746967219563929, 8.781718520032044, 9.747401264380482, 10.711032313043873, 11.756140881829387, 12.804255002799513, 13.76126173590944, 14.592522888555997, 13.654393266566448, 12.703961368678804, 11.766453528943613, 9.837199383969107, 8.84378060761236, 7.8759380335580325, 6.8362553326787285, 5.872048466215451, 4.938400537506897, 4.026964881250356, 4.8140430716111045, 5.7964745575103835, 6.825026469303415, 7.840491041830957, 8.817309509892688, 9.810277564270352, 10.835101991421334, 11.898510876596621, 12.799677500404353, 13.668708945810291, 12.692928045815995, 11.715691141277683, 10.775099987997296, 8.890156843368617, 7.9638833185588425, 6.986147704596339, 5.958222503097664, 4.942415286399191, 4.004808226683995, 2.964548399835036, 3.888794430825857, 4.861707291261411, 5.847359144881417, 6.781949133739212, 7.808395211561141, 8.861902802975717, 9.833314003689873, 10.899644015104489, 11.841056071567127, 12.712980409333953, 11.734343521675259, 10.798381339304266, 9.81795137511966, 7.896954755245253, 6.950142779686671, 5.982621160462549, 4.9690190741089735, 3.992746822254901, 2.976756989604793, 1.9582015960202515, 2.9427004841095465, 3.900856548484235, 4.914545424735719, 5.920330614920543, 6.886111618708073, 7.816592157138539, 8.862429823220452, 9.870246603520103, 10.848956262024162, 11.780146379816708, 10.799723658028697, 9.834263023595103, 8.828909087201286, 6.929748441947111, 5.939080859048355, 4.991470160143222, 3.979790643017737, 2.95903360248976, 1.9912943137627874, 1.0046342551955079, 1.9961917016694462, 3.0381038889835086, 3.944673446322532, 5.00427565555955, 5.959954124806537, 6.919311510004747, 7.985393318662661, 8.969668393054796, 9.86888947209563, 10.81621406199429, 10.006932815429996, 8.98167729542163, 7.990420983678181, 6.060684015082584, 5.064553189710278, 4.085768175613525, 3.069515605518136, 2.0427744174878013, 1.0240707843416024, 0.0, 0.9912360668177509, 2.016908399185593, 2.9816113959731787, 3.977257401115585, 5.01698359352261, 5.976646871017355, 7.040375252159034, 7.993983975148812, 8.931723380467597, 9.936371905555118, 9.208755574612214, 8.171786637240272, 7.112455893616163, 6.981717381590176, 6.0387434302162895, 5.03318511746687, 3.9873759271471014, 3.003984840991068, 2.0077985840460477, 0.9332135479187557, 1.868619756145602, 2.8384214480589014, 3.773816960302836, 4.727134552570589, 5.70998362235404, 6.722376932187164, 7.655929776956725, 8.730674567339964, 9.797513190389516, 10.871485415922757, 9.995695520579346, 9.040778603436223, 8.05285936168027, 7.763722639211132, 6.8135608898281275, 5.832588027765356, 4.824801581293312, 3.882903101520077, 2.816675377396864, 1.8710307516329943, 2.7948890372443227, 3.8175811973536167, 4.794409620800257, 5.6764410105352034, 6.7324352446674425, 7.663583242773706, 8.61055262854909, 9.535753071952556, 10.516591016661161, 11.572245355872598, 10.786727344764232, 9.78906023138998, 8.788610845779079, 8.718295733562591, 7.783056276644621, 6.7414620642442875, 5.7817792909491335, 4.848507030000719, 3.8609531262735164, 2.8915430003663998, 3.775078019355475, 4.839085057757937, 5.785330121515829, 6.651824534061387, 7.641574338606485, 8.617986600800034, 9.592228685941334, 10.551836402565256, 11.489364855860336, 12.447663316734955, 11.787535541447287, 10.771051941367729, 9.721073057359334, 9.619468130936093, 8.606542696614355, 7.676928873894675, 6.7130766051510795, 5.868289137702269, 4.873553143426049, 3.8998992897370353, 4.844782460480766, 5.84689899260085, 6.818256887006916, 7.659877493062619, 8.658169103215377, 9.592915211468279, 10.591355285671211, 11.580741062430011, 12.432863395833726, 13.378976372845221, 12.601014747098292, 11.636028680482067, 10.59364060373024, 10.530795521669006, 9.569565772108392, 8.616385817166295, 7.685999988369863, 6.803484821139326, 5.834715784965259, 4.949472926512415, 5.856756460660036, 6.799598455548617, 7.776727255130678, 8.70207627560762, 9.70580208979368, 10.58598593536054, 11.548811152308181, 12.519539058827208, 13.370390185193585, 14.345115564353055, 13.505865581144093, 12.464871818745303, 11.522178227815457, 11.476644789216277, 10.539137041709333, 9.5435887504774, 8.648699075186576, 7.740924845147266, 6.870166764777878, 6.022849405306762, 6.866319883401114, 7.732584059889824, 8.696113505697735, 9.673915044156312, 10.65540303732971, 11.54498761010388, 12.56393300096589, 13.47139144666422, 14.350971286109267, 15.324801811434707, 14.420474593072145, 13.43412743220089, 12.528287218015432, 12.501993276474085, 11.497304027055403, 10.565479900543783, 9.574469054151423, 8.781370891246908, 7.900474194635846, 7.072103154147934, 7.828649041881643, 8.7578867502885, 9.702343503942961, 10.627693624176677, 11.563901494316461, 12.475678215351554, 13.003683513619716, 14.006140785714317, 14.900143197451184, 15.557527646299729, 15.448233252880307, 14.386882746213548, 13.467691081517868, 13.432748083992967, 12.55451072665456, 11.51618879108207, 10.5324018615509, 9.841250750643146, 8.850015729224493, 8.030884085415721, 8.891064980716084, 9.740199618473797, 10.701369236596644, 11.565345863188439, 12.567688407218096, 13.00570873338716, 11.972490510088623, 12.97299046591585, 13.90842132032456, 14.59450375646072, 15.579000064331725, 15.324738088265105, 14.399252311284652, 14.411212353088617, 13.470708125229935, 12.484676351228012, 11.464585959909916, 10.85682862919845, 9.901704587409705, 9.02166518334875, 9.861020565294913, 10.684010281684579, 11.672053091467726, 12.574995492704996, 12.620498993823727, 11.965010832694627, 11.024562476037435, 11.94924457165645, 12.859242800604758, 13.6343110251515, 14.598983662907488, 15.559787113850428, 15.363462702250409, 15.436624438444847, 14.363214031304288, 13.402037998575008, 12.465122818591556, 11.790764894250092, 10.95897223278486, 9.974208167268177, 10.9260427981529, 11.699720816813418, 12.682747940306145, 12.569042878421628, 11.684405126909773, 10.971480126204067, 9.966538456864669, 10.956504533604063, 11.923713936852868, 12.67206907156426, 13.704281541941718, 14.737776532384219, 15.670056418657635, 15.591320579830287, 15.382233022079792, 14.39001010257639, 13.397814530758755, 12.758356367651977, 11.93735483745908, 10.981834755269952, 11.961932871177932, 12.695203910024444, 12.64732796098098, 11.624459729544622, 10.720949503896962, 9.943071786930528, 8.951281659375367, 9.931272925416495, 10.894735144565782, 11.70542433660696, 12.707837944973607, 13.668599717838763, 14.646699670807845], [14.551983934674643, 13.602339421555094, 12.608997086011104, 11.649204932469534, 10.761232184738446, 9.774533543082448, 8.760251640160611, 8.02372789841316, 8.807031956096228, 9.698351377452813, 10.685917214390063, 11.532218837573662, 12.0810999263532, 12.781204480017925, 13.728378931187816, 14.6056363739766, 15.294840258185591, 16.30703221733443, 16.416536575688326, 15.465508359402524, 13.59622394940576, 12.6511398550525, 11.75025457077553, 10.70880685348159, 9.77365344875629, 8.834308924612246, 7.820358436082675, 7.02335963107002, 7.830112715667944, 8.706197674537563, 9.660302932546344, 10.589935941947608, 11.628659959920334, 12.609936436285086, 13.64845787297972, 14.65482775431723, 15.593297934039402, 16.47035976120576, 15.48374044416566, 14.53681405560964, 12.691190647637244, 11.650484033263687, 10.7154231080836, 9.717557751225707, 8.764549687467769, 7.845970478112941, 6.7967567645949245, 5.9741371534965415, 6.854688405508039, 7.7730220999926605, 8.813767240767776, 9.793175646888166, 10.736443020128648, 11.685027016201357, 12.658026906068123, 13.714298886640842, 14.611352516429658, 15.627446733411912, 14.674093273414663, 13.671491646613886, 11.700406729745044, 10.689074958424541, 9.704858291605493, 8.75504712723342, 7.811599791403101, 6.822327485883709, 5.839320188008048, 4.917186490937517, 5.8733586822310855, 6.819455749135068, 7.840224427463914, 8.805907171812352, 9.769538220475743, 10.814646789261257, 11.862760910231383, 12.804839357819883, 13.657686300163528, 14.57257731207688, 13.622145414189237, 12.684637574454046, 10.75538342947954, 9.723699230185545, 8.755856656131218, 7.716173955251914, 6.7519670887886365, 5.818319160080083, 4.829267514805062, 3.8865316011822424, 4.8689630870815215, 5.883532376735286, 6.898996949262828, 7.875815417324558, 8.868783471702223, 9.893607898853205, 10.95701678402849, 11.843255122314797, 12.67747287899254, 13.611112091326428, 12.633875186788115, 11.693284033507728, 9.881392910186367, 8.955119385376593, 7.977383771414091, 6.949458569915415, 5.933651353216941, 4.996044293501745, 3.955784466652787, 2.961282960396995, 3.9341958208325494, 4.905865052313288, 5.840455041171083, 6.866901118993012, 7.905480424886161, 8.876891625600317, 9.943221637014933, 10.884633693477571, 11.721744342516203, 12.636677087819516, 11.789617406122018, 10.809187441937413, 8.888190822063004, 7.941378846504422, 6.9738572272803, 5.960255140926725, 4.983982889072652, 3.9679930564225443, 2.9494376628380023, 2.0151890136806845, 2.973345078055373, 3.9700850253518443, 4.975870215536668, 5.941651219324198, 6.860169779048983, 7.906007445130896, 8.913824225430547, 9.892533883934606, 10.788910312998958, 11.702057224172954, 10.825499090412855, 9.820145154019038, 7.920984508764862, 6.930316925866106, 5.982706226960973, 4.971026709835488, 3.9502696693075112, 2.9825303805805383, 1.9958703220132588, 1.0686802312405839, 2.100645642056136, 2.9534373795047815, 4.013039588741799, 4.968718057988787, 5.928075443186997, 6.994157251844911, 7.978432326237046, 8.87765340527788, 9.824977995176539, 10.756835675455063, 9.972913362239382, 8.981657050495933, 7.051920081900335, 6.055789256528029, 5.0770042424312765, 4.060751672335887, 3.0340104843055524, 2.0153068511593535, 0.9912360668177509, 0.0, 1.025672332367842, 1.990375329155428, 2.986021334297835, 4.02574752670486, 4.985410804199605, 6.049139185341284, 7.002747908331062, 7.940487313649847, 8.945135838737368, 9.888566578881413, 9.163022704058024, 8.103691960433915, 7.968176203033116, 7.02520225165923, 5.978550144300081, 4.932740953980312, 3.9493498678242793, 2.953163610879259, 1.8785785747519672, 0.943172366525121, 1.9129740584384205, 2.848369570682355, 3.801687162950108, 4.784536232733558, 5.796929542566682, 6.730482387336243, 7.805227177719482, 8.872065800769034, 9.946038026302276, 10.840260820544653, 10.027237424879164, 9.039318183123209, 8.709087666044343, 7.7589259166613385, 6.777953054598567, 5.770166608126523, 4.8282681283532884, 3.762040404230076, 2.816395778466206, 1.8694416476238416, 2.8921338077331358, 3.868962231179777, 4.7509936209147225, 5.806987855046962, 6.738135853153225, 7.685105238928609, 8.610305682332074, 9.59114362704068, 10.646797966252116, 11.58528043423495, 10.734425258223192, 9.733975872612291, 9.663660760395803, 8.728421303477832, 7.686827091077499, 6.727144317782345, 5.793872056833931, 4.806318153106728, 3.8369080271996117, 2.8496306297349943, 3.913637668137456, 4.859882731895349, 5.726377144440906, 6.7161269489860045, 7.692539211179553, 8.666781296320854, 9.626389012944774, 10.563917466239854, 11.522215927114473, 12.506763339348288, 11.71641696820094, 10.666438084192546, 10.564833157769305, 9.551907723447567, 8.622293900727888, 7.658441631984291, 6.813654164535482, 5.818918170259262, 4.845264316570248, 3.919335070860285, 4.921451602980369, 5.892809497386435, 6.734430103442138, 7.732721713594895, 8.667467821847797, 9.665907896050731, 10.65529367280953, 11.507416006213244, 12.45352898322474, 13.423775566571495, 12.581393707315279, 11.539005630563452, 11.476160548502218, 10.514930798941604, 9.561750843999507, 8.631365015203075, 7.748849847972538, 6.780080811798472, 5.894837953345628, 4.931309071039555, 5.874151065928136, 6.851279865510197, 7.77662888598714, 8.780354700173199, 9.660538545740058, 10.623363762687699, 11.594091669206726, 12.444942795573104, 13.419668174732573, 14.412225679439366, 13.410236845578515, 12.46754325464867, 12.422009816049489, 11.484502068542545, 10.488953777310613, 9.594064102019788, 8.686289871980478, 7.8155317916110905, 6.968214432139975, 5.940872493780633, 6.807136670269343, 7.770666116077254, 8.748467654535832, 9.729955647709229, 10.619540220483398, 11.638485611345407, 12.545944057043739, 13.425523896488786, 14.399354421814223, 15.341843837839395, 14.379492459034102, 13.473652244848644, 13.447358303307297, 12.442669053888615, 11.510844927376995, 10.519834080984635, 9.72673591808012, 8.84583922146906, 7.885823021682854, 6.903201652261162, 7.832439360668021, 8.776896114322481, 9.702246234556197, 10.638454104695981, 11.550230825731072, 12.560772318183833, 13.560990762064913, 14.36311931137782, 15.422711310585962, 16.39359827971352, 15.33224777304676, 14.41305610835108, 14.37811311082618, 13.499875753487771, 12.461553817915282, 11.477766888384112, 10.786615777476358, 9.795380756057707, 8.844603952950642, 7.965617591095603, 8.814752228853317, 9.775921846976164, 10.639898473567959, 11.642241017597616, 12.097178348835286, 12.774793143643329, 13.775293099470552, 14.781037698028447, 15.474422379033905, 16.458918686904912, 16.270103115098316, 15.344617338117864, 15.356577379921829, 14.416073152063147, 13.430041378061224, 12.409950986743128, 11.746810280541961, 10.791686238753217, 9.835385050883671, 8.935573175674431, 9.758562892064099, 10.746605701847246, 11.649548103084516, 11.692987523394866, 11.048589723982275, 11.826865109592141, 12.751547205211155, 13.731859178308644, 14.514229647724687, 15.478902285480673, 16.439705736423612, 16.30882772908362, 16.38198946527806, 15.3085790581375, 14.34740302540822, 13.410487845424768, 12.680746545593603, 11.842261247614674, 10.787928034803098, 10.000595408532417, 10.774273427192938, 11.757300550685665, 11.641531407992767, 10.756893656480912, 10.05375673377279, 10.768841090419375, 11.758807167158768, 12.796330314556755, 13.551987694137447, 14.584200164514904, 15.617695154957405, 16.549975041230823, 16.47123920240347, 16.327598048913003, 15.335375129409602, 14.343179557591966, 13.648338018995489, 12.751074704994002, 11.795554622804874, 11.03648548155745, 11.769756520403964, 11.71981649055212, 10.69694825911576, 9.793438033468101, 9.02534839449925, 9.753584292930073, 10.7335755589712, 11.774653767138968, 12.585342959180146, 13.587756567546792, 14.548518340411949, 15.52661829338103], [15.511740185285205, 14.562095672165656, 13.568753336621667, 12.608961183080096, 11.720988435349009, 10.73428979369301, 9.720007890771173, 8.975372659227101, 7.965176625679786, 8.770750010990433, 9.758315847927683, 10.604617471111283, 11.568560143751677, 12.558553042393779, 13.515152573248356, 14.486188400505018, 15.524689334915617, 16.536881294064457, 17.37629282629889, 16.425264610013087, 14.555980200016323, 13.610896105663064, 12.710010821386092, 11.668563104092152, 10.733409699366852, 9.794065175222809, 8.780114686693237, 7.975004391883962, 6.988257385251502, 7.778596308075183, 8.732701566083964, 9.662334575485229, 10.701058593457955, 11.681472931310182, 12.65158553094752, 13.65795541228503, 14.567625601671558, 15.59529128169528, 16.443496694776222, 15.496570306220203, 13.650946898247808, 12.610240283874251, 11.675179358694162, 10.677314001836269, 9.72430593807833, 8.805726728723503, 7.756513015205487, 6.933893404107104, 6.012833075091597, 6.845420733530281, 7.881315824633836, 8.792598543922951, 9.710770687760807, 10.659354683833515, 11.632354573700281, 12.688626554273, 13.585680184061815, 14.625013011120265, 15.554061496575118, 14.63124789722445, 12.660162980355608, 11.648831209035103, 10.664614542216055, 9.714803377843982, 8.771356042013663, 7.782083736494271, 6.79907643861861, 5.8769427415480795, 5.031503351814643, 5.891854382672689, 6.814552095096072, 7.7802348394445096, 8.743865888107901, 9.788974456893415, 10.837088577863542, 11.779167025452042, 12.632013967795684, 13.570143589785234, 14.502113637349693, 13.64439382506461, 11.715139680090104, 10.683455480796107, 9.71561290674178, 8.675930205862477, 7.711723339399199, 6.778075410690645, 5.7890237654156245, 4.8462878517928045, 4.009858900872362, 4.8578600443674445, 5.873324616894985, 6.8501430849567155, 7.84311113933438, 8.867935566485363, 9.93134445166065, 10.817582789946956, 11.651800546624697, 12.659065689883644, 13.482128678473083, 12.653040284118292, 10.907065242554209, 9.98032867108578, 8.988921657482528, 7.960996455983852, 6.932221244505342, 5.994614184790146, 4.954354357941187, 3.921039211007557, 2.999640231970254, 3.880192719945446, 4.81478270880324, 5.8412287866251695, 6.879808092518319, 7.851219293232475, 8.917549304647089, 9.85896136110973, 10.69607201014836, 11.611004755451672, 12.547569965949075, 11.834859774305254, 9.913863154430846, 8.967051178872264, 7.999529559648142, 6.985927473294566, 6.009655221440494, 4.993665388790386, 3.975109995205844, 2.9749452642912466, 2.016789199916558, 2.944412692984002, 3.9501978831688254, 4.915978886956355, 5.834497446681141, 6.8803351127630545, 7.888151893062705, 8.866861551566764, 9.763237980631114, 10.67638489180511, 11.641845526238704, 10.84581748638688, 8.946656841132704, 7.955989258233948, 7.008378559328815, 5.99669904220333, 4.975942001675353, 4.00820271294838, 3.0215426543811006, 2.094352563608426, 1.0749733096882939, 1.9277650471369394, 2.987367256373957, 3.9430457256209452, 4.902403110819155, 5.968484919477069, 6.952759993869204, 7.8519810729100366, 8.799305662808695, 9.73116334308722, 10.756418863095586, 10.007329382863775, 8.077592414268178, 7.081461588895871, 6.102676574799118, 5.086424004703729, 4.059682816673394, 3.0409791835271953, 2.016908399185593, 1.025672332367842, 0.0, 0.964702996787586, 1.9603490019299925, 3.000075194337018, 3.9597384718317628, 5.023466852973442, 5.97707557596322, 6.914814981282005, 7.919463506369526, 8.86289424651357, 9.899863183885511, 9.129364292801757, 8.948618496121618, 8.005644544747732, 6.9589924373885825, 5.913183247068814, 4.929792160912781, 3.933605903967761, 2.859020867840469, 1.9236146596136225, 0.9538129677003232, 1.8892084799442577, 2.842526072212011, 3.8253751419954614, 4.837768451828586, 5.771321296598147, 6.846066086981386, 7.900746359466364, 8.974718584999605, 9.81458848817681, 10.769505405319933, 10.019760476211712, 9.689529959132846, 8.739368209749841, 7.7583953476870695, 6.750608901215026, 5.808710421441791, 4.742482697318578, 3.7968380715547076, 2.849883940712343, 1.9329727169950388, 2.90980114044168, 3.7918325301766256, 4.847826764308865, 5.778974762415128, 6.7259441481905125, 7.651144591593977, 8.631982536302582, 9.687636875514018, 10.626119343496851, 11.623786456871104, 10.714418165700794, 10.644103053484306, 9.708863596566335, 8.667269384166001, 7.707586610870847, 6.774314349922433, 5.78676044619523, 4.817350320288114, 3.8300729228234953, 2.9756837686352102, 3.9007216411572516, 4.767216053702809, 5.7569658582479075, 6.733378120441456, 7.707620205582757, 8.667227922206678, 9.604756375501756, 10.563054836376375, 11.54760224861019, 12.571183020014201, 11.646880377281049, 11.545275450857806, 10.532350016536068, 9.602736193816389, 8.638883925072793, 7.794096457623983, 6.799360463347763, 5.825706609658749, 4.899777363948786, 3.9834977034781236, 4.954203288512124, 5.775269012704041, 6.773560622856798, 7.7083067311097, 8.706746805312635, 9.696132582071433, 10.548254915475146, 11.494367892486641, 12.464614475833397, 13.429600542449622, 12.519447923651953, 12.456602841590719, 11.495373092030105, 10.542193137088008, 9.611807308291576, 8.72929214106104, 7.760523104886973, 6.875280246434129, 5.911751364128056, 4.936197166425891, 5.913325966007951, 6.817467795249042, 7.8211936094351024, 8.70137745500196, 9.664202671949601, 10.63493057846863, 11.485781704835006, 12.460507083994475, 13.453064588701269, 14.390679138667016, 13.44798554773717, 13.40245210913799, 12.464944361631046, 11.469396070399114, 10.574506395108289, 9.666732165068979, 8.79597408469959, 7.948656725228476, 6.921314786869134, 5.869182770767098, 6.8327122165750085, 7.789306563797734, 8.770794556971133, 9.6603791297453, 10.67932452060731, 11.586782966305643, 12.466362805750688, 13.440193331076127, 14.382682747101299, 15.359934752122603, 14.454094537937145, 14.427800596395798, 13.423111346977116, 12.491287220465496, 11.500276374073136, 10.707178211168621, 9.826281514557559, 8.844529510986392, 7.861908141564699, 6.894485461165775, 7.838942214820237, 8.744792845767822, 9.681000715907606, 10.591069734992974, 11.601611227445735, 12.601829671326817, 13.403958220639723, 14.463550219847866, 15.454077956381843, 16.31269006613526, 15.393498401439581, 15.35855540391468, 14.480318046576272, 13.441996111003784, 12.458209181472613, 11.76705807056486, 10.775823049146206, 9.80331044225418, 8.831219530267346, 7.876798329351072, 8.83796794747392, 9.682445084779584, 10.684787628809241, 11.628983314849952, 12.632804230976829, 13.634979991125284, 14.395680097766347, 15.40054370308098, 16.472881656237913, 17.250545408186817, 16.325059631206365, 16.33701967301033, 15.396515445151648, 14.410483671149725, 13.39039327983163, 12.705516769845499, 11.750392728056754, 10.794091540187209, 9.801175114846174, 8.820608992561853, 9.808651802345, 10.692094714296141, 10.851132192978424, 11.77970141044102, 12.720149767098212, 13.711303455821717, 14.691615428919206, 15.473985898335249, 16.438658536091236, 17.399461987034176, 17.289270022172122, 17.36243175836656, 16.289021351226, 15.32784531849672, 14.39093013851327, 13.63945303489714, 12.800967736918212, 11.746634524106636, 10.822463917666013, 9.836319527690693, 10.81934665118342, 10.713930041530388, 9.91503832606447, 10.95745670221497, 11.728597341029937, 12.71856341776933, 13.756086565167317, 14.511743944748009, 15.543956415125466, 16.577451405567967, 17.509731291841383, 17.430995453014035, 17.308040342001505, 16.315817422498103, 15.323621850680468, 14.607044508299026, 13.70978119429754, 12.754261112108411, 11.790714170060589, 10.831802620901719, 10.79221512408974, 9.769346892653381, 8.95158270305166, 9.976993155313192, 10.713340543540635, 11.693331809581762, 12.73441001774953, 13.545099209790708, 14.547512818157355, 15.508274591022511, 16.48637454399159], [16.36703139548881, 15.417386882369257, 14.424044546825268, 13.464252393283697, 12.57627964555261, 11.589581003896612, 10.575299100974775, 9.796086267436268, 8.785890233888953, 7.806047014202846, 8.793612851140097, 9.639914474323696, 10.60385714696409, 11.593850045606192, 12.55044957646077, 13.521485403717431, 14.55998633812803, 15.57217829727687, 16.51419812877695, 17.280555820216687, 15.411271410219923, 14.466187315866664, 13.565302031589693, 12.523854314295754, 11.588700909570454, 10.64935638542641, 9.635405896896838, 8.795718000093128, 7.808970993460668, 6.813893311287598, 7.7679985692963776, 8.697631578697642, 9.736355596670368, 10.716769934522596, 11.686882534159935, 12.693252415497446, 13.602922604883975, 14.630588284907695, 15.581401997254282, 16.351861516423803, 14.506238108451408, 13.465531494077851, 12.530470568897764, 11.53260521203987, 10.579597148281932, 9.661017938927104, 8.611804225409088, 7.789184614310703, 6.833546683300763, 5.880717736742695, 6.916612827846249, 7.827895547135365, 8.746067690973222, 9.69465168704593, 10.667651576912696, 11.723923557485415, 12.620977187274232, 13.66031001433268, 14.589358499787531, 15.436224448072041, 13.515454190559208, 12.504122419238705, 11.519905752419657, 10.570094588047583, 9.626647252217264, 8.637374946697872, 7.654367648822211, 6.732233951751679, 5.873248452789086, 4.927151385885103, 5.849849098308486, 6.815531842656924, 7.779162891320316, 8.824271460105829, 9.872385581075955, 10.814464028664453, 11.6673109710081, 12.605440592997649, 13.537410640562106, 14.449370375912201, 12.570430890293704, 11.538746690999709, 10.570904116945382, 9.531221416066078, 8.5670145496028, 7.633366620894246, 6.644314975619225, 5.701579061996405, 4.865150111075963, 3.8931570475798587, 4.908621620107399, 5.88544008816913, 6.878408142546794, 7.903232569697777, 8.966641454873063, 9.852879793159367, 10.687097549837112, 11.694362693096057, 12.517425681685497, 13.458016834965884, 11.79082588278611, 10.83561988128938, 9.844212867686128, 8.816287666187453, 7.787512454708942, 6.849905394993746, 5.809645568144788, 4.776330421211158, 3.854931442173855, 2.9154897231578603, 3.850079712015655, 4.876525789837585, 5.915105095730733, 6.886516296444889, 7.952846307859504, 8.894258364322141, 9.731369013360775, 10.646301758664086, 11.582866969161488, 12.634316614436052, 10.856054653729641, 9.90924267817106, 8.941721058946937, 7.910214802689393, 6.9339425508353205, 5.917952718185212, 4.845537795126804, 3.830236474494847, 2.872080410120159, 1.979709696196416, 2.9854948863812396, 3.9512758901687697, 4.869794449893555, 5.915632115975468, 6.923448896275119, 7.902158554779176, 8.79853498384353, 9.711681895017524, 10.677142529451118, 11.682496465844935, 9.8888483404315, 8.898180757532742, 7.950570058627609, 6.938890541502125, 5.918133500974148, 4.950394212247175, 3.963734153679895, 2.972176707205957, 1.9302645198918946, 0.9630620503493534, 2.022664259586371, 2.9783427288333586, 3.937700114031569, 5.003781922689483, 5.988056997081619, 6.88727807612245, 7.83460266602111, 8.766460346299633, 9.791715866308, 10.782972178051448, 9.042295411055763, 8.046164585683456, 7.067379571586704, 6.051127001491315, 5.02438581346098, 4.005682180314781, 2.9816113959731787, 1.990375329155428, 0.964702996787586, 0.0, 0.9956460051424065, 2.0353721975494317, 2.9950354750441766, 4.058763856185856, 5.012372579175635, 5.950111984494418, 6.95476050958194, 7.898191249725984, 8.935160187097924, 9.994490930722034, 9.900303472689362, 8.957329521315476, 7.910677413956327, 6.864868223636559, 5.881477137480525, 4.885290880535504, 3.8107058444082123, 2.8752996361813663, 1.9054979442680668, 0.9701024320241325, 1.9234200242918855, 2.906269094075336, 3.9186624039084603, 4.852215248678022, 5.92696003906126, 6.936043362678777, 8.010015588212019, 8.849885491389223, 9.804802408532346, 10.7927216502883, 10.641214935700589, 9.691053186317584, 8.710080324254811, 7.702293877782768, 6.760395398009534, 5.69416767388632, 4.7485230481224505, 3.801568917280087, 2.884657693562782, 1.9929361066830178, 2.8727264822565, 3.928720716388739, 4.859868714495003, 5.8068381002703875, 6.732038543673852, 7.712876488382458, 8.768530827593894, 9.707013295576727, 10.70468040895098, 11.666103142268536, 11.595788030052049, 10.660548573134077, 9.618954360733744, 8.659271587438589, 7.725999326490175, 6.738445422762973, 5.769035296855856, 4.7817578993912395, 3.9273687452029535, 2.9838566073985895, 3.8481100057826834, 4.837859810327782, 5.814272072521331, 6.788514157662632, 7.748121874286553, 8.685650327581632, 9.643948788456251, 10.628496200690066, 11.652076972094077, 12.598565353848791, 12.496960427425549, 11.48403499310381, 10.554421170384131, 9.590568901640534, 8.745781434191725, 7.751045439915505, 6.777391586226491, 5.85146234051653, 4.935182680045867, 4.037338254753463, 4.856162964783916, 5.854454574936673, 6.789200683189575, 7.787640757392509, 8.777026534151307, 9.629148867555022, 10.575261844566517, 11.545508427913273, 12.510494494529498, 13.471132900219695, 13.408287818158461, 12.447058068597848, 11.49387811365575, 10.563492284859317, 9.680977117628782, 8.712208081454715, 7.826965223001872, 6.8634363406958006, 5.887882142993634, 5.1081478866887435, 5.898361747328918, 6.9020875615149775, 7.7822714070818355, 8.745096624029477, 9.715824530548504, 10.566675656914882, 11.541401036074351, 12.533958540781144, 13.518195274983121, 14.399670524304913, 14.354137085705734, 13.416629338198788, 12.421081046966856, 11.52619137167603, 10.618417141636721, 9.747659061267335, 8.900341701796219, 7.872999763436878, 6.820867747334841, 6.043250406310242, 6.87020051587761, 7.851688509051008, 8.741273081825174, 9.760218472687184, 10.667676918385517, 11.547256757830564, 12.521087283156003, 13.463576699181175, 14.44992386005243, 15.40577951450489, 15.379485572963542, 14.374796323544858, 13.442972197033237, 12.451961350640877, 11.658863187736364, 10.777966491125303, 9.796214487554135, 8.813593118132442, 7.846170437733518, 7.050756617064227, 7.825686797847699, 8.761894667987484, 9.671963687072848, 10.68250517952561, 11.682723623406691, 12.484852172719599, 13.544444171927742, 14.534971908461719, 15.402679174065089, 16.336819238311406, 16.310240380482426, 15.432003023144013, 14.393681087571524, 13.409894158040354, 12.718743047132602, 11.72750802571395, 10.754995418821922, 9.782904506835088, 8.828483305918814, 8.04978234971791, 8.76333903685946, 9.765681580889119, 10.709877266929826, 11.713698183056703, 12.715873943205159, 13.476574049846223, 14.481437655160857, 15.553775608317789, 16.416988644240426, 17.268380468078192, 17.288704649578076, 16.34820042171939, 15.362168647717466, 14.34207825639937, 13.657201746413241, 12.702077704624497, 11.745776516754951, 10.752860091413917, 9.772293969129596, 9.081247910404663, 9.772988666376017, 10.793752479556868, 11.722321697019463, 12.66162621710789, 13.667999204274262, 14.525752569566025, 15.441630386470075, 16.406303024226062, 17.367106475169003, 18.23259085904395, 18.314116734934302, 17.240706327793742, 16.27953029506446, 15.34261511508101, 14.591138011464883, 13.752652713485956, 12.69831950067438, 11.774148894233756, 10.788004504258435, 10.123100524739945, 9.7492270447428, 10.725053778803458, 11.767472154953957, 12.583888551233539, 13.573854627972931, 14.611377775370919, 15.36703515495161, 16.399247625329068, 17.43274261577157, 18.365022502044987, 18.286286663217634, 17.553815570100507, 16.50384261053929, 15.511647038721655, 14.478783758698542, 13.527753802654583, 12.579499902819244, 11.610401883214852, 10.651490334055984, 9.827512127302153, 8.804643895865794, 9.761598155790647, 10.79770676352236, 11.568631753744237, 12.548623019785364, 13.589701227953132, 14.40039041999431, 15.402804028360956, 16.363565801226112, 17.341665754195194], [17.291334747942642, 16.413032887511662, 15.419690551967673, 14.459898398426102, 13.571925650695015, 12.585227009039016, 11.570945106117179, 10.791732272578674, 9.781536239031357, 8.801693019345253, 8.118171637364332, 8.895924574491747, 9.859867247132142, 10.78633566777749, 11.73147637975796, 12.702512207014623, 13.679390198407535, 14.578689070590602, 15.518552123634542, 16.307039297534207, 16.318935099945204, 15.461833321009072, 14.5609480367321, 13.519500319438158, 12.584346914712858, 11.645002390568814, 10.631051902039243, 9.791364005235534, 8.804616998603073, 7.809539316430004, 7.080035366399575, 7.9536416788656945, 8.885256059415545, 9.834398387307886, 10.804510986945225, 11.810880868282736, 12.607276599741567, 13.634942279765289, 14.585755992111876, 15.378344993741324, 15.378288580739586, 14.461177499220259, 13.52611657404017, 12.528251217182277, 11.575243153424337, 10.656663944069509, 9.607450230551493, 8.78483061945311, 7.829192688443169, 6.876363741885101, 6.104859513647259, 7.016142232936375, 7.863696143758512, 8.81228013983122, 9.785280029697986, 10.833820842227507, 11.625331182131823, 12.664664009190274, 13.593712494645125, 14.440578442929635, 14.34529473411717, 13.499768424381111, 12.515551757562063, 11.56574059318999, 10.622293257359669, 9.63302095184028, 8.650013653964617, 7.7278799568940855, 6.868894457931492, 5.922797391027509, 5.038095784109496, 6.003778528457934, 6.896791344105607, 7.858800148315108, 8.906914269285235, 9.818818023522047, 10.671664965865693, 11.609794587855243, 12.5417646354197, 13.453724370769795, 13.400271433851666, 12.534392696142115, 11.566550122087788, 10.526867421208484, 9.562660554745205, 8.629012626036653, 7.639960980761631, 6.697225067138811, 5.860796116218369, 4.888803052722265, 4.0968683059084094, 5.07368677397014, 5.920818724628765, 6.932191810556569, 7.986658179504975, 8.857233788016961, 9.691451544694706, 10.69871668795365, 11.52177967654309, 12.462370829823477, 12.569298720004562, 11.831265886431785, 10.839858872828533, 9.811933671329857, 8.783158459851348, 7.845551400136152, 6.805291573287194, 5.7719764263535644, 4.850577447316261, 3.9111357283002666, 3.038326397816665, 4.064772475638595, 4.919459090588326, 5.890870291302482, 6.957200302717097, 7.898612359179735, 8.735723008218368, 9.65065575352168, 10.587220964019082, 11.638670609293644, 11.61880479265856, 10.904888683313466, 9.937367064089342, 8.9058608078318, 7.929588555977727, 6.913598723327619, 5.84118380026921, 4.8258824796372535, 3.8677264152625654, 2.9753557013388225, 2.0896590405949658, 3.022696629288319, 3.8741484447511483, 4.919986110833062, 5.927802891132712, 6.90651254963677, 7.802888978701122, 8.716035889875117, 9.68149652430871, 10.686850460702527, 10.847998714640113, 9.893826762675149, 8.946216063770015, 7.934536546644531, 6.913779506116554, 5.946040217389581, 4.959380158822301, 3.9678227123483634, 2.925910525034301, 1.95870805549176, 1.0519404984727498, 1.9908936812839277, 2.9420541088891627, 4.008135917547077, 4.992410991939213, 5.891632070980044, 6.838956660878703, 7.7708143411572275, 8.796069861165593, 9.787326172909042, 10.03794141619817, 9.041810590825863, 8.06302557672911, 7.046773006633722, 6.020031818603387, 5.001328185457188, 3.977257401115586, 2.986021334297835, 1.9603490019299925, 0.9956460051424065, 0.0, 1.0397261924070254, 1.9993894699017702, 3.06311785104345, 4.016726574033228, 4.954465979352012, 5.959114504439533, 6.902545244583577, 7.939514181955518, 8.998844925579627, 10.863136262167032, 9.920162310793145, 8.873510203433996, 7.827701013114228, 6.844309926958195, 5.848123670013175, 4.773538633885883, 3.838132425659037, 2.8683307337457373, 1.9329352215018027, 0.9796176292340498, 1.9624666990175004, 2.9748600088506247, 3.9084128536201863, 4.983157644003425, 5.940397357536371, 7.0143695830696124, 7.854239486246818, 8.80915640338994, 9.797075645145895, 11.60404772517826, 10.653885975795255, 9.672913113732482, 8.66512666726044, 7.723228187487205, 6.657000463363992, 5.711355837600122, 4.7644017067577575, 3.8474904830404526, 2.955768896160688, 1.9289240871986644, 2.9849183213309036, 3.9160663194371677, 4.863035705212552, 5.788236148616017, 6.7690740933246225, 7.824728432536058, 8.763210900518892, 9.760878013893144, 10.761327399504045, 12.55862081952972, 11.623381362611749, 10.581787150211417, 9.622104376916262, 8.688832115967847, 7.701278212240644, 6.731868086333527, 5.74459068886891, 4.8902015346806245, 3.9006018270488285, 2.9043076107248478, 3.8940574152699465, 4.870469677463495, 5.844711762604797, 6.804319479228718, 7.741847932523797, 8.700146393398416, 9.68469380563223, 10.708274577036242, 11.6937896110843, 13.459793216903222, 12.446867782581483, 11.517253959861804, 10.553401691118207, 9.708614223669397, 8.713878229393176, 7.740224375704162, 6.814295129994201, 5.898015469523537, 4.954083474403701, 3.91236056972608, 4.910652179878837, 5.845398288131739, 6.843838362334674, 7.833224139093472, 8.685346472497187, 9.631459449508682, 10.601706032855438, 11.566692099471663, 12.60908017622349, 14.371120607636135, 13.40989085807552, 12.456710903133423, 11.52632507433699, 10.643809907106453, 9.675040870932385, 8.789798012479544, 7.826269130173471, 6.850714932471305, 5.937978721531217, 4.954559352271081, 5.9582851664571415, 6.8384690120239995, 7.80129422897164, 8.77202213549067, 9.622873261857047, 10.597598641016516, 11.59015614572331, 12.574392879925286, 13.517086470855132, 15.316969875183407, 14.379462127676462, 13.38391383644453, 12.489024161153703, 11.581249931114392, 10.710491850745004, 9.86317449127389, 8.835832552914548, 7.783700536812511, 6.873081241152716, 5.926398120819773, 6.907886113993172, 7.797470686767338, 8.816416077629347, 9.723874523327682, 10.603454362772728, 11.577284888098166, 12.519774304123338, 13.506121464994592, 14.55536862325631, 16.342318362441215, 15.337629113022532, 14.40580498651091, 13.41479414011855, 12.621695977214035, 11.740799280602973, 10.701735326498657, 9.719113957076964, 8.75169127667804, 7.8072345230235785, 6.881884402789862, 7.818092272929646, 8.728161292015011, 9.738702784467772, 10.738921228348856, 11.541049777661764, 12.600641776869905, 13.591169513403882, 14.458876779007252, 15.393016843253568, 17.2730731699601, 16.394835812621686, 15.356513877049197, 14.372726947518027, 13.639167013990722, 12.640210534489896, 11.660516257766444, 10.68842534577961, 9.734004144863336, 8.806260255677262, 7.819536641801623, 8.821879185831282, 9.76607487187199, 10.769895787998866, 11.772071548147323, 12.532771654788387, 13.537635260103023, 14.609973213259952, 15.47318624918259, 16.32457807302035, 18.242530881489518, 17.31103321119706, 16.325001437195137, 15.304911045877043, 14.562722585357763, 13.607598543569019, 12.651297355699473, 11.658380930358438, 10.677814808074118, 9.760344639120065, 8.82918627131818, 9.849950084499032, 10.778519301961627, 11.717823822050054, 12.724196809216425, 13.58195017450819, 14.497827991412242, 15.462500629168229, 16.42330408011117, 17.28878846398611, 18.340523135210002, 17.46183382388109, 16.50065779115181, 15.563742611168358, 14.627402035397619, 13.778270777210885, 12.779612112992316, 11.889127917410383, 10.902983527435062, 10.22353497722181, 9.801268149231792, 10.786043951412985, 11.773352292171111, 12.77584784122282, 13.716936847268812, 14.51747903826008, 15.460069944999482, 16.440673455052835, 17.482763208727125, 18.238679926852917, 17.312770140535154, 16.576524348171034, 15.623246470818795, 14.63105089900116, 13.659810561995734, 12.708780605951775, 11.77198552499054, 10.866411983382903, 9.907500434224035, 9.152070913526389, 9.8002899010082, 10.757244160933052, 11.793352768664764, 12.564277758886641, 13.544269024927768, 14.585347233095536, 15.396036425136714, 16.398450033503362, 17.359211806368517, 18.332307374231924], [16.25160855553562, 17.200328886571594, 16.427430663836823, 15.467638510295252, 14.579665762564165, 13.592967120908167, 12.57868521798633, 11.708418390604008, 10.698222357056691, 9.718379137370587, 8.903294212654123, 7.877807827914155, 8.841750500554548, 9.746609475370466, 10.691750187350936, 11.662786014607597, 12.639664006000512, 13.538962878183577, 14.478825931227517, 15.267313105127183, 15.279208907538179, 16.22429300189144, 15.568688148601248, 14.527240431307309, 13.592087026582009, 12.652742502437965, 11.638792013908393, 10.708050123260868, 9.721303116628407, 8.726225434455337, 7.865157941689365, 6.935524932288101, 7.845529867008521, 8.794672194900862, 9.7647847945382, 10.77115467587571, 11.567550407334544, 12.595216087358263, 13.54602979970485, 14.338618801334299, 14.338562388332562, 15.30538576924727, 14.533856685909319, 13.535991329051425, 12.582983265293487, 11.66440405593866, 10.615190342420643, 9.715705122107073, 8.745878806468502, 7.793049859910434, 6.9597649732984, 5.998025486358782, 6.823969951351487, 7.7725539474241945, 8.745553837290961, 9.794094649820481, 10.5856049897248, 11.624937816783248, 12.5539863022381, 13.40085225052261, 13.305568541710144, 14.343976694408122, 13.523291869431212, 12.573480705059138, 11.63003336922882, 10.640761063709427, 9.657753765833768, 8.735620068763234, 7.785580575956825, 6.839483509052842, 5.8930012437606365, 4.98566178188034, 5.857065151698582, 6.819073955908083, 7.867188076878209, 8.779091831115021, 9.631938773458668, 10.570068395448217, 11.502038443012674, 12.41399817836277, 12.36054524144464, 13.392229440738635, 12.574290233956937, 11.534607533077633, 10.570400666614354, 9.636752737905802, 8.647701092630781, 7.70496517900796, 6.823692368847714, 5.805489170747598, 4.95177376555955, 4.055570027392546, 4.88109253222174, 5.892465618149544, 6.946931987097949, 7.817507595609936, 8.65172535228768, 9.658990495546625, 10.482053484136065, 11.422644637416452, 11.529572527597539, 12.48477852909427, 11.847598984697683, 10.819673783199008, 9.790898571720497, 8.8532915120053, 7.813031685156343, 6.779716538222713, 5.813473699945606, 4.8278218463256, 3.8932318574678053, 3.0335264513396183, 3.879732898181301, 4.851144098895457, 5.917474110310072, 6.8588861667727095, 7.695996815811343, 8.610929561114654, 9.547494771612056, 10.59894441688662, 10.579078600251536, 11.554664096433326, 10.94510717595849, 9.913600919700947, 8.937328667846876, 7.921338835196767, 6.848923912138359, 5.833622591506402, 4.875466527131714, 3.9503496904309294, 2.944564500246106, 1.9829704368812937, 2.834422252344123, 3.8802599184260362, 4.888076698725687, 5.866786357229745, 6.763162786294098, 7.676309697468093, 8.641770331901686, 9.647124268295503, 9.808272522233088, 10.798940105131845, 9.953956175639163, 8.942276658513679, 7.921519617985703, 6.95378032925873, 5.96712027069145, 4.975562824217512, 3.933650636903449, 2.966448167360908, 1.9068459581238901, 0.9511674888769023, 1.9023279164821374, 2.9684097251400514, 3.952684799532187, 4.851905878573019, 5.799230468471679, 6.731088148750203, 7.756343668758569, 8.747599980502017, 9.010890611706182, 10.007021437078489, 9.102751769136136, 8.086499199040746, 7.059758011010412, 6.041054377864213, 5.01698359352261, 4.025747526704859, 3.0000751943370174, 2.0353721975494317, 1.0397261924070254, 0.0, 0.9596632774947449, 2.0233916586364247, 2.9770003816262034, 3.9147397869449874, 4.919388312032509, 5.862819052176553, 6.899787989548495, 7.959118733172604, 9.828491432828963, 10.77146538420285, 9.87815762673937, 8.832348436419602, 7.84895735026357, 6.852771093318549, 5.778186057191257, 4.842779848964411, 3.8729781570511115, 2.937582644807177, 1.9842650525394239, 1.0014159827559734, 1.9729995020244484, 2.90655234679401, 3.965702376787857, 4.900671165129347, 5.974643390662587, 6.814513293839793, 7.769430210982915, 8.75734945273887, 10.793885874698637, 11.658533399100628, 10.677560537037856, 9.669774090565813, 8.727875610792578, 7.661647886669365, 6.716003260905495, 5.769049130063132, 4.852137906345827, 3.960416319466062, 2.9335715105040383, 2.0317776408512462, 2.9629256389575103, 3.909895024732895, 4.83509546813636, 5.815933412844965, 6.8715877520564, 7.8100702200392345, 8.799200148327182, 9.76899766813069, 11.735772032773937, 12.628028785917122, 11.586434573516788, 10.626751800221633, 9.69347953927322, 8.705925635546016, 7.736515509638901, 6.749238112174284, 5.894848957985998, 4.905249250354202, 3.9089550340302215, 3.05727822405591, 3.9173289969838376, 4.8915710821251395, 5.851178798749061, 6.788707252044139, 7.747005712918758, 8.731553125152573, 9.755133896556584, 10.701459879710944, 12.630111968537976, 13.451515205886855, 12.521901383167176, 11.558049114423579, 10.71326164697477, 9.718525652698549, 8.744871799009536, 7.818942553299575, 6.902662892828911, 5.958730897709074, 4.917007993031454, 4.099296193386156, 4.892257607652082, 5.890697681855016, 6.880083458613816, 7.7322057920175284, 8.678318769029023, 9.648565352375778, 10.613551418992003, 11.65593949574383, 13.555328496521923, 14.414538281380892, 13.461358326438795, 12.530972497642361, 11.648457330411826, 10.679688294237758, 9.794445435784915, 8.830916553478845, 7.855362355776678, 6.942626144836592, 5.959206775576456, 5.14692917996446, 5.8853283315443425, 6.848153548491983, 7.818881455011013, 8.669732581377389, 9.644457960536856, 10.63701546524365, 11.621252199445626, 12.563945790375472, 14.501177764069194, 15.384109550981833, 14.3885612597499, 13.493671584459074, 12.585897354419766, 11.715139274050376, 10.867821914579261, 9.840479976219923, 8.788347960117886, 7.877728664458091, 6.931045544125148, 6.096530127500491, 6.844330006287681, 7.86327539714969, 8.770733842848026, 9.65031368229307, 10.624144207618507, 11.566633623643678, 12.552980784514933, 13.60222794277665, 15.405573967817691, 16.342276536327905, 15.410452409816282, 14.419441563423922, 13.626343400519408, 12.745446703908344, 11.70638274980403, 10.723761380382337, 9.756338699983413, 8.811881946328953, 7.886531826095237, 7.143951166023021, 7.775020611535355, 8.785562103988116, 9.7857805478692, 10.587909097182106, 11.647501096390245, 12.638028832924222, 13.505736098527592, 14.439876162773908, 16.336328775336575, 17.365831309778788, 16.361161300354567, 15.377374370823398, 14.643814437296095, 13.644857957795269, 12.665163681071817, 11.693072769084983, 10.73865156816871, 9.810907678982636, 8.824184065106998, 8.147738078924656, 8.812934191392333, 9.81675510751921, 10.818930867667667, 11.57963097430873, 12.584494579623364, 13.656832532780292, 14.52004556870293, 15.371437392540692, 17.28939020100986, 17.41628575042776, 16.44024474360247, 15.524553277442974, 14.521612108042236, 13.648730092374265, 12.69242890450472, 11.926235148527292, 10.900577315986308, 10.76499206242544, 9.833833694623555, 9.219191335248247, 9.861522816245344, 10.764683141570398, 11.771056128736769, 12.628809494028532, 13.544687310932582, 14.50935994868857, 15.47016339963151, 16.33564778350645, 17.30079694280298, 16.422107631474066, 15.460931598744786, 14.524016418761335, 13.587675842990594, 12.73854458480386, 11.739885920585293, 10.871011170832789, 9.884866780857468, 10.867893904350195, 10.805915572537167, 10.1552852021622, 10.856355806454829, 11.822707160743164, 12.763796166789156, 13.564338357780422, 14.506929264519822, 15.487532774573175, 16.529622528247465, 17.285539246373258, 16.27304394812813, 15.53679815576401, 14.583520278411772, 13.591324706594136, 12.620084369588708, 11.66905441354475, 10.732259332583517, 9.84829523680531, 8.889383687646442, 9.93719348881618, 10.716976019033535, 11.118740825175012, 11.884764145728369, 12.837963958232466, 13.789027774976724, 14.593317150067508, 15.473573999477123, 16.47598760784377, 17.4884784485007, 17.2925811818249], [15.291945278040872, 16.24066560907685, 16.447871381002166, 15.488079227460593, 14.685105933740887, 13.826436992138335, 12.909663812274788, 11.96475184308732, 11.52467837387796, 10.544835154191855, 9.725563289052673, 8.700076904312704, 7.951433789893761, 8.786946197875722, 9.732086909856191, 10.703122737112853, 11.680000728505767, 12.579299600688833, 13.519162653732772, 14.307649827632439, 14.319545630043434, 15.264629724396693, 16.243086931189875, 15.360366470287023, 14.425213065561723, 13.485868541417679, 12.469731871636828, 11.534506140082136, 10.547759133449675, 9.552681451276605, 8.687427018087915, 7.757794008686651, 6.8858665895137765, 7.835008917406117, 8.805121517043455, 9.811491398380966, 10.6078871298398, 11.635552809863519, 12.586366522210106, 13.378955523839554, 13.378899110837818, 14.345722491752525, 15.366982724889032, 14.369117368031139, 13.416109304273201, 12.497530094918373, 11.448316381400357, 10.542161138928341, 9.57233482328977, 8.619505876731703, 7.786220990119668, 6.820294562757332, 5.864306673856743, 6.81289066992945, 7.785890559796217, 8.834431372325737, 9.625941712230055, 10.665274539288504, 11.594323024743355, 12.441188973027865, 12.3459052642154, 13.384313416913377, 14.350451443654864, 13.406606744038852, 12.463159408208533, 11.47388710268914, 10.490879804813481, 9.56820878407166, 8.612036592778091, 7.665939525874109, 6.719457260581905, 5.80793085827889, 4.897401874203838, 5.859410678413338, 6.907524799383465, 7.819428553620276, 8.672275495963923, 9.610405117953473, 10.54237516551793, 11.454334900868025, 11.400881963949896, 12.43256616324389, 13.400408737298218, 12.367733572057347, 11.403526705594068, 10.469878776885515, 9.480827131610495, 8.538091217987674, 7.650148385668981, 6.631945187568865, 5.7782297823808175, 4.877839103791096, 3.9214292547269953, 4.932802340654799, 5.987268709603205, 6.85784431811519, 7.692062074792936, 8.69932721805188, 9.52239020664132, 10.462981359921708, 10.569909250102794, 11.525115251599525, 12.516522265202777, 11.652799822178721, 10.62402461070021, 9.686417550985015, 8.646157724136057, 7.612842577202427, 6.639929716766873, 5.654277863146867, 4.719687874289073, 3.8557955277381684, 2.920069620686556, 3.8914808214007124, 4.957810832815327, 5.899222889277964, 6.7363335383165985, 7.6512662836199095, 8.587831494117312, 9.639281139391876, 9.619415322756792, 10.595000818938582, 11.658565158834696, 10.828628976072917, 9.852356724218843, 8.836366891568735, 7.763951968510327, 6.74865064787837, 5.790494583503682, 4.776805707252198, 3.771020517067374, 2.8052395132798438, 1.874758974849378, 2.9205966409312913, 3.9284134212309416, 4.907123079734999, 5.803499508799352, 6.7166464199733475, 7.6821070544069405, 8.687460990800759, 8.848609244738341, 9.839276827637098, 10.786887526542232, 9.901939936008425, 8.881182895480448, 7.913443606753475, 6.9267835481861955, 5.935226101712257, 4.8933139143981945, 3.9261114448556533, 2.8665092356186355, 1.9108307663716473, 0.9426646389873925, 2.008746447645306, 2.993021522037442, 3.8922426010782742, 4.8395671909769336, 5.771424871255458, 6.796680391263823, 7.787936703007271, 8.051227334211438, 9.047358159583744, 10.026143173680497, 9.04616247653549, 8.019421288505157, 7.000717655358958, 5.976646871017356, 4.985410804199605, 3.9597384718317628, 2.995035475044177, 1.9993894699017702, 0.9596632774947449, 0.0, 1.0637283811416798, 2.0173371041314585, 2.9550765094502425, 3.959725034537764, 4.903155774681808, 5.94012471205375, 6.999455455677859, 8.868828155334219, 9.811802106708106, 10.837820904234114, 9.792011713914347, 8.808620627758314, 7.8124343708132935, 6.737849334686001, 5.802443126459155, 4.832641434545856, 3.897245922301922, 2.9439283300341685, 1.9610792602507183, 1.0133362245297035, 1.946889069299265, 3.0060390992931123, 3.9410078876346017, 5.014980113167843, 5.854850016345049, 6.809766933488171, 7.7976861752441256, 9.834222597203892, 10.784384346586897, 11.6372238145326, 10.629437368060557, 9.687538888287323, 8.62131116416411, 7.67566653840024, 6.728712407557876, 5.811801183840571, 4.920079596960807, 3.893234787998783, 2.9724408383366345, 2.0412928402303705, 2.988262226005755, 3.9134626694092196, 4.8943006141178245, 5.94995495332926, 6.888437421312094, 7.839536870832438, 8.809334390635945, 10.776108755279193, 11.75387973340339, 12.546097851011533, 11.586415077716378, 10.653142816767964, 9.66558891304076, 8.696178787133645, 7.708901389669029, 6.854512235480742, 5.864912527848947, 4.868618311524966, 3.9979414215412987, 2.995696198256698, 3.9699382833979997, 4.9295460000219204, 5.867074453316999, 6.825372914191618, 7.809920326425432, 8.833501097829444, 9.7417966022162, 11.702257566422883, 12.68970067608704, 13.48156466066192, 12.517712391918323, 11.672924924469514, 10.678188930193294, 9.70453507650428, 8.77860583079432, 7.862326170323655, 6.9183941752038205, 5.876671270526199, 5.023819306904887, 3.970624808924942, 4.969064883127877, 5.958450659886676, 6.810572993290388, 7.7566859703018824, 8.726932553648638, 9.691918620264863, 10.728085093628737, 12.633695697794783, 13.594925447355397, 14.42102160393354, 13.490635775137106, 12.60812060790657, 11.639351571732503, 10.75410871327966, 9.79057983097359, 8.815025633271421, 7.902289422331337, 6.918870053071201, 5.911096957794563, 4.963695532817202, 5.926520749764843, 6.897248656283873, 7.748099782650248, 8.722825161809716, 9.71538266651651, 10.699619400718486, 11.642312991648332, 13.579544965342055, 14.537578345881983, 15.348224537244645, 14.453334861953818, 13.54556063191451, 12.67480255154512, 11.827485192074006, 10.800143253714667, 9.748011237612628, 8.837391941952834, 7.859973299923597, 6.860697905330594, 5.922697207560541, 6.94164259842255, 7.849101044120886, 8.728680883565929, 9.702511408891368, 10.64500082491654, 11.631347985787794, 12.680595144049512, 14.483941169090553, 15.495745331228052, 16.370115687311028, 15.379104840918666, 14.586006678014153, 13.683884075889644, 12.63531050560248, 11.652689136180786, 10.685266455781862, 9.740809702127402, 8.815459581893686, 7.886147408670189, 6.853387812808215, 7.863929305260976, 8.86414774914206, 9.666276298454964, 10.725868297663107, 11.716396034197084, 12.584103299800454, 13.51824336404677, 15.414695976609435, 16.44419851105165, 16.480861027838415, 15.497074098307246, 14.585725868193103, 13.703241001666456, 12.723546724943004, 12.066916125151359, 11.667579323967159, 10.739835434781085, 9.753111820905447, 8.848830220235522, 7.891301392665193, 8.89512230879207, 9.897298068940527, 10.657998175581588, 11.662861780896222, 12.735199734053154, 13.598412769975791, 14.449804593813553, 16.36775740228272, 16.456622472933017, 15.480581466107726, 14.56488999994823, 13.561948830547491, 12.68906681487952, 11.732765627009975, 11.09696054057253, 11.722846392384858, 11.69391981822389, 10.762761450422005, 9.868459234980799, 8.939890017518204, 9.843050342843258, 10.849423330009628, 11.70717669530139, 12.62305451220544, 13.587727149961427, 14.548530600904368, 15.41401498477931, 16.341133665308238, 15.462444353979322, 14.501268321250041, 13.56435314126659, 12.62801256549585, 11.778881307309115, 10.780222643090548, 10.031938307714544, 10.707135857256018, 11.690162980748745, 11.734843328335616, 10.804553101894752, 9.934723007727689, 10.901074362016024, 11.842163368062016, 12.64270555905328, 13.58529646579268, 14.565899975846033, 15.607989729520321, 16.36390644764612, 15.313380670633387, 14.577134878269266, 13.623857000917027, 12.631661429099392, 11.660421092093964, 10.709391136050005, 9.772596055088773, 8.99604823468951, 9.711652764044992, 10.75946256521473, 11.543432035854803, 11.768008724907563, 10.963131347001228, 11.916331159505326, 12.867394976249583, 13.671684351340366, 14.551941200749981, 15.554354809116628, 16.56684564977356, 16.332917904330156], [14.228216896899193, 15.17693722793517, 15.390553864099497, 14.430761710557926, 13.62778841683822, 12.879070700664888, 12.097743114746546, 12.842567485858641, 12.588406755019639, 11.608563535333534, 10.789291670194354, 9.763805285454385, 9.01516217103544, 8.044846851658972, 8.962547747287543, 9.88835236670749, 10.616272347364088, 11.515571219547153, 12.455434272591093, 13.24392144649076, 13.255817248901755, 14.200901343255014, 15.179358550048196, 15.37115978954587, 14.615367152820376, 13.925026007095989, 13.037636318824482, 12.598234521223816, 11.611487514591355, 10.616409832418285, 9.751155399229596, 8.821522389828331, 7.949594970655456, 7.0929095711893675, 8.035582354474807, 8.822778607935044, 9.54415874869812, 10.57182442872184, 11.522638141068427, 12.315227142697875, 12.315170729696138, 13.281994110610846, 14.31782339384932, 15.199044850877545, 14.47983768541488, 13.561258476060052, 12.512044762542036, 11.60588952007002, 10.63606320443145, 9.683234257873382, 8.849949371261348, 7.884022943899012, 6.928035054998422, 6.070791323712701, 7.016351397227568, 7.771802983306834, 8.562213331088376, 9.601546158146824, 10.530594643601676, 11.377460591886186, 11.28217688307372, 12.320585035771698, 13.286723062513184, 14.236534226885258, 13.526887789350212, 12.537615483830823, 11.55460818595516, 10.63193716521334, 9.675764973919772, 8.72966790701579, 7.783185641723584, 6.871659239420571, 5.961130255345517, 5.023931114745056, 6.072045235715183, 6.756800164601374, 7.608547114822244, 8.546676736811794, 9.47864678437625, 10.390606519726346, 10.337153582808217, 11.368837782102212, 12.336680356156538, 13.376363057035842, 12.467255086735749, 11.533607158027197, 10.544555512752176, 9.601819599129355, 8.713876766810662, 7.6956735687105455, 6.841958163522498, 5.941567484932777, 4.985157635868675, 4.097322776986517, 5.027054539388448, 5.795215929096288, 6.628333693651257, 7.6355988369102015, 8.458661825499641, 9.399252978780028, 9.506180868961115, 10.461386870457845, 11.452793884061098, 12.480719085559773, 11.687752991841892, 10.750145932126696, 9.709886105277738, 8.676570958344108, 7.703658097908553, 6.7180062442885475, 5.783416255430753, 4.919523908879849, 3.983798001828236, 3.05600125773243, 3.9975966626005714, 4.836594500259062, 5.672605157174919, 6.58753790247823, 7.524103112975633, 8.575552758250197, 8.555686941615111, 9.5312724377969, 10.594836777693015, 11.658532985760472, 10.916085105360525, 9.900095272710416, 8.827680349652008, 7.81237902902005, 6.854222964645362, 5.840534088393878, 4.834748898209054, 3.868967894421524, 2.938487355991058, 2.0622584224176377, 2.9394604680761716, 3.8444946907160964, 4.739771127657673, 5.652918038831668, 6.618378673265261, 7.623732609659078, 7.784880863596662, 8.775548446495419, 9.723159145400553, 10.734838662526037, 9.944911276622127, 8.977171987895154, 7.990511929327875, 6.998954482853937, 5.957042295539874, 4.989839825997333, 3.930237616760315, 2.974559147513327, 2.0063930201290723, 0.9940981928372891, 1.969210625539365, 2.8285142199365945, 3.775838809835254, 4.707696490113778, 5.732952010122144, 6.724208321865592, 6.987498953069757, 7.983629778442063, 8.962414792538816, 9.978667362634205, 9.083149669646836, 8.064446036500637, 7.040375252159035, 6.049139185341284, 5.023466852973442, 4.058763856185856, 3.06311785104345, 2.0233916586364247, 1.0637283811416798, 0.0, 0.9536087229897786, 1.8913481283085627, 2.895996653396084, 3.839427393540128, 4.876396330912069, 5.935727074536178, 7.805099774192538, 8.748073725566424, 9.794725832925574, 10.734477630797779, 9.751086544641746, 8.754900287696726, 7.680315251569434, 6.744909043342588, 5.7751073514292885, 4.839711839185354, 3.886394246917601, 2.9035451771341507, 1.8911518673010264, 0.9575990225314648, 1.9423107181514325, 2.877279506492922, 3.951251732026163, 4.7911216352033685, 5.746038552346491, 6.733957794102445, 8.770494216062213, 9.720655965445218, 10.70162882750799, 11.571903284943991, 10.630004805170756, 9.563777081047544, 8.618132455283673, 7.671178324441309, 6.754267100724004, 5.86254551384424, 4.835700704882216, 3.8502564811079574, 2.9191084830016933, 2.003997899503709, 2.8944757447454768, 3.8369830972151577, 4.892637436426593, 5.8311199044094275, 6.775808489690758, 7.745606009494265, 9.712380374137513, 10.690151352261712, 11.639536159132625, 12.528880994599813, 11.5956087336514, 10.608054829924196, 9.638644704017079, 8.651367306552462, 7.796978152364176, 6.80737844473238, 5.811084228408399, 4.875757064312621, 3.8735118410280207, 2.9856739568959534, 3.9105590753581776, 4.809756936414331, 5.768055397288951, 6.752602809522765, 7.7761835809267765, 8.67806822107452, 10.638529185281204, 11.625972294945361, 12.55558611766504, 13.460178308801758, 12.615390841352948, 11.620654847076727, 10.647000993387714, 9.721071747677753, 8.804792087207089, 7.860860092087252, 6.819137187409631, 5.901634949676211, 4.848440451696265, 3.9848005566258307, 4.939463735222933, 5.753255476387721, 6.699368453399215, 7.669615036745969, 8.634601103362193, 9.664356712487058, 11.576378180892114, 12.537607930452728, 13.49504306093666, 14.433101692020541, 13.550586524790004, 12.581817488615936, 11.696574630163095, 10.733045747857023, 9.757491550154857, 8.78188907859649, 7.798469709336355, 6.788912600565887, 5.841511175588526, 5.026963034710777, 5.87826173162013, 6.69078226574758, 7.665507644907049, 8.65806514961384, 9.642301883815817, 10.584995474745662, 12.522227448439384, 13.480260828979311, 14.422245994247765, 15.38403763702005, 14.488026548797944, 13.617268468428556, 12.769951108957441, 11.7426091705981, 10.6805210440259, 9.716991598217989, 8.737788942694921, 7.738513548101917, 6.800512850331864, 6.057233242000793, 6.830114119457143, 7.671363366663261, 8.6451938919887, 9.587683308013872, 10.574030468885127, 11.623277627146845, 13.426623652187885, 14.438427814325381, 15.420490384956436, 15.391278524565044, 14.830835357183979, 13.910683190038355, 12.940228309994044, 12.53050477895211, 11.563082098553187, 10.618625344898726, 9.69327522466501, 8.763963051441511, 7.7312034555795375, 7.052008607732735, 7.845160824478317, 8.608958781552296, 9.66855078076044, 10.659078517294416, 11.526785782897786, 12.460925847144102, 14.357378459706768, 15.386880994148981, 15.417132646696738, 14.433345717165567, 13.77095549778774, 12.961141655449708, 11.981447378726257, 12.963461326161173, 12.545394966738483, 11.61765107755241, 10.630927463676771, 9.726645863006844, 8.769117035436516, 8.083201611263828, 8.878311144276784, 9.60068065867892, 10.605544263993554, 11.677882217150486, 12.541095253073124, 13.392487076910886, 15.310439885380054, 15.392894091791335, 14.416853084966046, 13.50116161880655, 12.747178460142129, 11.946967468662773, 10.990666280793228, 12.007141528198222, 12.786574773526539, 12.571735460995214, 11.640577093193329, 10.746274877752121, 9.817705660289526, 9.031129645315016, 9.902057038536181, 10.649859178398723, 11.565736995302773, 12.53040963305876, 13.4912130840017, 14.356697467876643, 15.277405284166559, 14.398715972837643, 13.437539940108362, 12.50062476012491, 11.813242195090487, 11.009342144740467, 10.038123296873799, 10.993147028584913, 11.7708642383977, 12.753891361890426, 12.61265897110694, 11.682368744666075, 10.812538650499011, 10.089153664487782, 10.894797076588569, 11.585388042150612, 12.527978948890013, 13.508582458943366, 14.550672212617654, 15.306588930743452, 14.249652289491708, 13.513406497127587, 12.560128619775348, 11.567933047957712, 10.845650721688601, 9.939851973481357, 9.030496708872024, 10.05977661583119, 10.775381145186673, 11.82319094635641, 12.607160416996482, 12.645824367678886, 11.84094698977255, 11.104410461977084, 11.920028684776137, 12.614366834437698, 13.494623683847314, 14.49703729221396, 15.509528132870889, 15.269189523188476], [13.274608173909414, 14.22332850494539, 14.43694514110972, 13.477152987568148, 12.674179693848442, 11.925461977675111, 12.939743880596948, 13.736495853791496, 13.542015478009416, 12.562172258323312, 11.742900393184131, 10.717414008444162, 9.96624985326948, 8.976256954627377, 8.034077202645372, 8.934743643717711, 9.662663624374309, 10.561962496557374, 11.501825549601316, 12.290312723500978, 12.302208525911976, 13.247292620265235, 14.225749827058417, 14.417551066556092, 13.661758429830599, 12.971417284106211, 13.879637084674885, 13.551843244213593, 12.565096237581132, 11.570018555408062, 10.704764122219373, 9.775131112818109, 8.903203693645233, 8.024319674157773, 7.107111809832637, 7.869169884945265, 8.59055002570834, 9.61821570573206, 10.56902941807865, 11.361618419708096, 11.361562006706357, 12.328385387621065, 13.364214670859539, 14.245436127887768, 14.67086219111912, 13.959755730605517, 13.465653485531814, 12.559498243059798, 11.589671927421227, 10.63684298086316, 9.803558094251127, 8.83763166688879, 7.8816437779882005, 7.002201426681107, 6.0878808525854, 6.818194260317055, 7.608604608098596, 8.647937435157045, 9.576985920611898, 10.423851868896406, 10.328568160083941, 11.366976312781919, 12.333114339523407, 13.28292550389548, 14.291422790722706, 13.4912242068206, 12.508216908944938, 11.585545888203118, 10.62937369690955, 9.683276630005567, 8.736794364713363, 7.825267962410349, 6.914738978335295, 5.955341217713462, 5.143574691073014, 5.803191441611594, 6.654938391832465, 7.593068013822015, 8.525038061386473, 9.436997796736566, 9.383544859818437, 10.415229059112434, 11.383071633166761, 12.422754334046065, 13.386961200509344, 12.487215881016974, 11.498164235741953, 10.555428322119132, 9.66748548980044, 8.649282291700324, 7.795566886512276, 6.895176207922555, 5.938766358858453, 5.028732879954923, 4.073445816398671, 4.8416072061065085, 5.674724970661478, 6.681990113920422, 7.505053102509863, 8.44564425579025, 8.552572145971336, 9.507778147468066, 10.499185161071319, 11.527110362569994, 12.555885574048503, 11.703754655116473, 10.663494828267515, 9.630179681333885, 8.65726682089833, 7.671614967278326, 6.737024978420531, 5.873132631869627, 4.937406724818015, 3.9874113607008357, 3.043987939610793, 3.8829857772692824, 4.71899643418514, 5.633929179488451, 6.5704943899858534, 7.621944035260417, 7.602078218625333, 8.577663714807121, 9.641228054703236, 10.704924262770692, 11.681196514624766, 10.853703995700194, 9.781289072641785, 8.765987752009828, 7.80783168763514, 6.794142811383656, 5.788357621198832, 4.822576617411302, 3.8920960789808365, 2.9936685253860436, 1.9858517450863933, 2.8908859677263177, 3.786162404667894, 4.699309315841889, 5.664769950275482, 6.670123886669299, 6.831272140606883, 7.821939723505639, 8.769550422410772, 9.781229939536257, 10.801986980064234, 9.930780710884934, 8.944120652317654, 7.952563205843716, 6.910651018529653, 5.943448548987112, 4.883846339750094, 3.928167870503106, 2.960001743118851, 1.9477069158270677, 1.0156019025495866, 1.8749054969468157, 2.822230086845475, 3.754087767123999, 4.779343287132365, 5.770599598875813, 6.0338902300799795, 7.030021055452286, 8.008806069549038, 9.025058639644428, 10.036758392636614, 9.018054759490415, 7.993983975148813, 7.002747908331062, 5.97707557596322, 5.012372579175635, 4.016726574033228, 2.9770003816262034, 2.0173371041314585, 0.9536087229897786, 0.0, 0.937739405318784, 1.9423879304063054, 2.8858186705503495, 3.9227876079222908, 4.982118351546401, 6.85149105120276, 7.794465002576646, 8.841117109935794, 9.886926300255562, 10.704695267631525, 9.708509010686505, 8.633923974559213, 7.698517766332366, 6.728716074419067, 5.793320562175133, 4.840002969907379, 3.8571539001239294, 2.844760590290805, 1.9112077455212435, 0.9887019951616538, 1.9236707835031432, 2.997643009036384, 3.83751291221359, 4.7924298293567125, 5.780349071112667, 7.816885493072434, 8.767047242455439, 9.748020104518211, 10.755806550990254, 11.583613528160535, 10.517385804037323, 9.571741178273452, 8.624787047431086, 7.707875823713782, 6.816154236834018, 5.789309427871994, 4.744184849040812, 3.8130368509345476, 2.866067465159163, 1.9408670217556983, 2.883374374225379, 3.939028713436815, 4.877511181419649, 5.8221997667009795, 6.791997286504486, 8.758771651147736, 9.736542629271932, 10.685927436142846, 11.645610209438, 12.549217456641177, 11.561663552913974, 10.592253427006858, 9.60497602954224, 8.750586875353953, 7.755729453114555, 6.759435236790575, 5.769685432245476, 4.767440208960875, 3.8477435225514074, 2.956950352368399, 3.856148213424553, 4.814446674299172, 5.7989940865329865, 6.822574857936998, 7.724459498084741, 9.684920462291425, 10.672363571955582, 11.601977394675261, 12.576907523639946, 13.554601576450981, 12.574263570066506, 11.600609716377493, 10.67468047066753, 9.758400810196866, 8.809211100469428, 7.767488195791807, 6.795563317609064, 5.742368819629119, 4.846870122281285, 3.985855012233154, 4.799646753397942, 5.7457597304094365, 6.716006313756191, 7.680992380372416, 8.710747989497278, 10.622769457902336, 11.58399920746295, 12.54143433794688, 13.483173799386517, 14.472505275881417, 13.535426211605715, 12.650183353152872, 11.6866544708468, 10.652946246111403, 9.675817446529344, 8.692398077269209, 7.68284096849874, 6.735439543521379, 5.889032600366231, 4.924653008630351, 5.737173542757802, 6.711898921917271, 7.704456426624063, 8.68869316082604, 9.631386751755885, 11.568618725449607, 12.526652105989534, 13.468637271257986, 14.430428914030271, 14.917672680293842, 14.16967706810528, 13.690608179140204, 12.646253567192502, 11.574449411958753, 10.610919966150842, 9.631717310627776, 8.632441916034772, 7.694441218264718, 6.919302807656248, 5.876505396467364, 6.717754643673484, 7.691585168998922, 8.634074585024093, 9.620421745895348, 10.669668904157067, 12.473014929198104, 13.484819091335604, 14.466881661966658, 14.437669801575264, 13.8772266341942, 13.139369638247311, 13.871638412962447, 13.424433146884965, 12.457010466486041, 11.512553712831581, 10.587203592597865, 9.657891419374366, 8.625131823512392, 7.91407817338819, 6.8915521014885375, 7.655350058562519, 8.714942057770662, 9.705469794304637, 10.573177059908005, 11.507317124154321, 13.403769736716987, 14.4332722711592, 14.463523923706958, 13.479736994175788, 12.817346774797961, 12.189828103658664, 12.91285748169466, 13.894871429129577, 13.439323334671338, 12.511579445485264, 11.524855831609626, 10.620574230939699, 9.66304540336937, 8.938254293050033, 7.924702421287005, 8.647071935689143, 9.651935541003777, 10.724273494160707, 11.587486530083343, 12.438878353921105, 14.356831162390273, 14.439285368801555, 13.463244361976265, 12.547552895816771, 11.79356973715235, 11.138139245473452, 11.922076383761631, 12.938551631166625, 13.740183496516316, 13.465663828928069, 12.534505461126184, 11.640203245684976, 10.711634028222381, 9.88618232710122, 8.948448315546404, 9.696250455408945, 10.612128272312995, 11.576800910068982, 12.537604361011923, 13.403088744886862, 14.323796561176778, 13.445107249847862, 12.483931217118581, 11.547016037135132, 10.859633472100708, 10.080871600098297, 10.969533399842204, 11.924557131553318, 12.724472961387477, 13.707500084880204, 13.506587339039795, 12.57629711259893, 11.706467018431866, 10.944206346273987, 9.941188353598791, 10.631779319160835, 11.574370225900235, 12.554973735953588, 13.597063489627876, 14.35298020775367, 13.296043566501927, 12.55979777413781, 11.606519896785569, 10.614324324967933, 9.892041998698822, 9.011381428839186, 9.961906811840429, 10.993163238620365, 11.72898986817645, 12.776799669346188, 13.56076913998626, 13.53975273561174, 12.734875357705405, 11.951441635836499, 10.96641996178636, 11.66075811144792, 12.541014960857536, 13.543428569224183, 14.555919409881112, 14.315580800198695], [12.33686876859063, 13.285589099626607, 13.499205735790937, 12.539413582249367, 11.73644028852966, 12.71583668531636, 13.730118588238197, 14.666291314118865, 14.479754883328201, 13.499911663642097, 12.66453213946947, 11.639045754729501, 10.767921972478643, 9.77792907383654, 8.821329542981964, 7.997004238398926, 8.724924219055525, 9.62422309123859, 10.564086144282532, 11.352573318182195, 11.364469120593192, 12.309553214946451, 13.288010421739633, 13.47981166123731, 12.724019024511817, 13.70123223746262, 14.670011792316133, 14.489582649532379, 13.502835642899917, 12.507757960726847, 11.626395868504712, 10.696762859103448, 9.78827723461701, 8.870251330265425, 7.894364150169228, 6.93143047962648, 7.652810620389556, 8.680476300413277, 9.631290012759866, 10.423879014389312, 10.423822601387574, 11.390645982302281, 12.426475265540756, 13.307696722568984, 13.733122785800338, 14.689570683961925, 14.4033928908506, 13.497237648378583, 12.527411332740012, 11.574582386181945, 10.738671819294519, 9.759263413174128, 8.766717318959977, 7.848133082788758, 6.87513319292199, 5.88045485499827, 6.670865202779812, 7.710198029838262, 8.639246515293115, 9.486112463577623, 9.390828754765158, 10.429236907463135, 11.395374934204623, 12.345186098576697, 13.353683385403922, 14.386878049702737, 13.445956314263725, 12.523285293521903, 11.567113102228335, 10.621016035324352, 9.674533770032147, 8.746899708695688, 7.799812519307071, 6.81899892208826, 5.9308270314096045, 4.86545203629281, 5.71719898651368, 6.655328608503231, 7.58729865606769, 8.499258391417783, 8.445805454499654, 9.47748965379365, 10.445332227847977, 11.485014928727281, 12.44922179519056, 13.382869723899113, 12.435903641060738, 11.493167727437918, 10.605224895119225, 9.58702169701911, 8.73330629183106, 7.816807954207894, 6.823839899830229, 5.89239058432972, 4.860698156735261, 3.9038678007877246, 4.736985565342693, 5.744250708601639, 6.5673136971910795, 7.507904850471466, 7.614832740652552, 8.570038742149283, 9.561445755752535, 10.58937095725121, 11.61814616872972, 12.555753228444916, 11.6012342335863, 10.56791908665267, 9.595006226217116, 8.60935437259711, 7.674764383739316, 6.810872037188411, 5.82248026578979, 4.851069065075634, 3.9076456439855916, 2.9452463719504984, 3.781257028866356, 4.696189774169667, 5.63275498466707, 6.684204629941633, 6.66433881330655, 7.63992430948834, 8.703488649384454, 9.76718485745191, 10.743457109305982, 11.75944694195609, 10.719028477960569, 9.703727157328611, 8.745571092953924, 7.731882216702441, 6.726097026517617, 5.760316022730087, 4.829835484299621, 3.857326229760842, 2.8495094494611917, 1.9531465624075337, 2.8484229993491104, 3.761569910523106, 4.727030544956699, 5.7323844813505165, 5.893532735288099, 6.884200318186855, 7.831811017091988, 8.843490534217473, 9.86424757474545, 10.831986863472423, 9.881860057636437, 8.890302611162499, 7.8483904238484365, 6.881187954305895, 5.8215857450688775, 4.86590727582189, 3.897741148437635, 2.863534681316521, 1.879259606924385, 0.9371660916280319, 1.8844906815266915, 2.8163483618052156, 3.8416038818135814, 4.832860193557029, 5.096150824761195, 6.0922816501335015, 7.071066664230254, 8.087319234325642, 9.114060422355976, 9.955794164809198, 8.931723380467597, 7.940487313649847, 6.914814981282005, 5.950111984494419, 4.954465979352013, 3.9147397869449874, 2.9550765094502425, 1.8913481283085627, 0.937739405318784, 0.0, 1.0046485250875214, 1.9480792652315655, 2.985048202603507, 4.044378946227616, 5.913751645883976, 6.856725597257863, 7.903377704617012, 8.94918689493678, 9.932577981092813, 10.646248416005287, 9.571663379877995, 8.636257171651149, 7.66645547973785, 6.731059967493916, 5.777742375226163, 4.794893305442713, 3.782499995609589, 2.8489471508400275, 1.9264414004804378, 0.9859313781843593, 2.0599036037176, 2.899773506894806, 3.8546904240379285, 4.8426096657938835, 6.87914608775365, 7.829307837136654, 8.810280699199426, 9.818067145671469, 10.759965625444703, 11.455125209356105, 10.509480583592234, 9.56252645274987, 8.645615229032567, 7.753893642152802, 6.727048833190778, 5.681924254359594, 4.750776256253331, 3.8038068704779464, 2.878606427074482, 1.945634968906595, 3.0012893081180305, 3.939771776100865, 4.884460361382195, 5.854257881185703, 7.821032245828952, 8.798803223953147, 9.74818803082406, 10.707870804119215, 11.64114306506763, 12.499402958232757, 11.52999283232564, 10.542715434861023, 9.688326280672738, 8.693468858433338, 7.697174642109357, 6.7074248375642584, 5.7051796142796585, 4.785482927870191, 3.894689757687183, 2.918408808105769, 3.8767072689803883, 4.861254681214203, 5.884835452618215, 6.7867200927659574, 8.747181056972641, 9.734624166636797, 10.664237989356476, 11.639168118321162, 12.616862171132198, 13.512002975385288, 12.538349121696275, 11.612419875986314, 10.696140215515651, 9.746950505788211, 8.70522760111059, 7.7333027229278475, 6.680108224947903, 5.784609527600068, 4.885825586005177, 3.861907348079159, 4.808020325090653, 5.778266908437407, 6.7432529750536325, 7.773008584178495, 9.685030052583553, 10.646259802144167, 11.603694932628095, 12.545434394067732, 13.534765870562632, 14.473165616924497, 13.587922758471656, 12.624393876165584, 11.590685651430189, 10.613556851848129, 9.630137482587994, 8.620580373817525, 7.673178948840163, 6.723445483243786, 5.739451813421686, 4.799434137439018, 5.774159516598488, 6.766717021305279, 7.750953755507256, 8.693647346437102, 10.630879320130823, 11.58891270067075, 12.5308978659392, 13.492689508711486, 13.979933274975057, 14.842492196254137, 14.62834758445899, 13.583992972511288, 12.512188817277538, 11.548659371469627, 10.56945671594656, 9.570181321353555, 8.632180623583501, 7.741286582499775, 6.691304201258699, 5.7800152383547, 6.753845763680139, 7.69633517970531, 8.682682340576564, 9.731929498838284, 11.53527552387932, 12.54707968601682, 13.529142256647875, 13.499930396256481, 12.939487228875414, 13.812184766396168, 14.663885452486927, 14.362172552203749, 13.394749871804825, 12.450293118150364, 11.524942997916648, 10.59563082469315, 9.562871228831176, 8.736061948231718, 7.706350906279873, 6.717610653243735, 7.777202652451878, 8.767730388985854, 9.635437654589222, 10.569577718835538, 12.466030331398203, 13.495532865840417, 13.525784518388175, 12.541997588857004, 11.879607369479176, 12.862643231807521, 13.70510452121914, 14.687118468654056, 14.377062739990121, 13.449318850804048, 12.46259523692841, 11.558313636258482, 10.600784808688154, 9.75305309784137, 8.73950122607834, 7.70933253037036, 8.714196135684995, 9.786534088841924, 10.64974712476456, 11.501138948602321, 13.41909175707149, 13.501545963482771, 12.525504956657482, 11.609813490497988, 10.855830331833564, 11.810954373622309, 12.71432342328611, 13.730798670691104, 14.661815242801655, 14.403403234246852, 13.472244866444967, 12.569998706012345, 11.64142948854975, 10.700981131892558, 9.753471848613327, 8.758511050090164, 9.674388866994214, 10.6390615047502, 11.59986495569314, 12.465349339568078, 13.386057155857994, 12.507367844529078, 11.546191811799797, 10.609276631816348, 9.921894066781922, 10.868123940434888, 11.761780439366682, 12.716804171077795, 13.646104707672816, 14.629131831165543, 14.444326744358579, 13.506092572926299, 12.636262478759235, 11.759005151065324, 10.73156306124004, 9.694039913842053, 10.636630820581454, 11.617234330634806, 12.659324084309095, 13.415240802434887, 12.358304161183144, 11.622058368819026, 10.668780491466785, 9.67658491964915, 8.954302593380037, 9.798633769175778, 10.754153851364906, 11.785410278144845, 12.65062161446179, 13.698431415631527, 14.498508545305045, 14.46954819593911, 13.664670818032775, 12.741816343477748, 11.756794669427608, 10.723018706129139, 11.603275555538755, 12.605689163905401, 13.61818000456233, 13.377841394879912], [11.454994136659245, 12.403714467695222, 12.84252967318119, 11.882737519639619, 12.74108881361718, 13.72048521040388, 14.734767113325717, 15.670939839206387, 15.484403408415723, 14.504560188729618, 13.604242326176879, 12.577766735890727, 11.613824063250332, 10.62383116460823, 9.667231633753653, 8.799470118375853, 7.843049587124141, 8.742348459307207, 9.682211512351147, 10.47069868625081, 10.482594488661807, 11.427678583015066, 12.406135789808248, 12.823135598627562, 13.728667549599336, 14.705880762550139, 15.674660317403653, 15.4942311746199, 14.507484167987439, 13.512406485814369, 12.631044393592234, 11.701411384190969, 10.747186962298477, 9.77878767763555, 8.740266240940917, 7.733896359603405, 6.770935988458173, 7.7986016684818935, 8.74941538082848, 9.542004382457927, 9.541947969456192, 10.5087713503709, 11.544600633609374, 12.425822090637599, 13.424758649537205, 14.423228267561216, 15.408041415938122, 14.501886173466104, 13.532059857827534, 12.579230911269466, 11.74332034438204, 10.76391193826165, 9.725627046641444, 8.777043050568736, 7.804043160701968, 6.8093648227782495, 5.788990570848428, 6.828323397906878, 7.75737188336173, 8.604237831646238, 8.508954122833774, 9.547362275531752, 10.513500302273238, 11.463311466645312, 12.471808753472537, 13.505003417771352, 14.450604839351247, 13.527933818609425, 12.571761627315857, 11.625664560411874, 10.679182295119668, 9.75154823378321, 8.804461044394593, 7.779625347449064, 6.8597369991895825, 5.794362004072789, 4.835324354582297, 5.773453976571847, 6.705424024136304, 7.6173837594863985, 7.5639308225682695, 8.595615021862265, 9.563457595916592, 10.603140296795896, 11.567347163259175, 12.500995091967727, 13.44055216614826, 12.497816252525439, 11.609873420206746, 10.59167022210663, 9.737954816918581, 8.821456479295415, 7.828488424917751, 6.853017009690525, 5.789608124515239, 4.832777768567703, 3.8551109334113094, 4.8623760766702535, 5.685439065259695, 6.626030218540081, 6.732958108721167, 7.6881641102178975, 8.67957112382115, 9.707496325319825, 10.736271536798334, 11.67387859651353, 12.605882758673822, 11.572567611740192, 10.599654751304637, 9.614002897684632, 8.679412908826837, 7.815520562275933, 6.827128790877311, 5.855717590163155, 4.912294169073113, 3.874156339730477, 2.899382396934972, 3.814315142238283, 4.7508803527356855, 5.802329998010249, 5.782464181375166, 6.758049677556954, 7.821614017453069, 8.885310225520525, 9.861582477374597, 10.877572310024705, 11.72367700304809, 10.708375682416133, 9.750219618041445, 8.736530741789961, 7.730745551605138, 6.764964547817608, 5.834484009387142, 4.861974754848363, 3.8541579745487127, 2.925993680783724, 1.9665483674177262, 2.8796952785917216, 3.8451559130253146, 4.850509849419132, 5.011658103356716, 6.002325686255472, 6.949936385160605, 7.9616159022860895, 8.982372942814067, 9.95011223154104, 10.886508582723959, 9.89495113625002, 8.853038948935957, 7.885836479393417, 6.826234270156399, 5.870555800909411, 4.902389673525157, 3.868183206404042, 2.883908132011906, 1.9418146167155532, 1.0026160495953071, 1.9344737298738313, 2.959729249882197, 3.950985561625645, 4.091502299673674, 5.08763312504598, 6.0664181391427325, 7.082670709238122, 8.109411897268457, 9.128115530414656, 9.936371905555118, 8.945135838737368, 7.919463506369526, 6.9547605095819405, 5.959114504439534, 4.919388312032509, 3.959725034537764, 2.895996653396084, 1.9423879304063054, 1.0046485250875214, 0.0, 0.943430740144044, 1.9803996775159853, 3.039730421140095, 4.909103120796455, 5.852077072170341, 6.89872917952949, 7.944538369849258, 8.927929456005291, 9.92411571295031, 10.576311904965516, 9.64090569673867, 8.671104004825372, 7.735708492581438, 6.782390900313684, 5.799541830530234, 4.7871485206971105, 3.853595675927549, 2.931089925567959, 1.9905799032718807, 1.0562027048806213, 1.8951249818072844, 2.850041898950407, 3.8379611407063616, 5.874497562666129, 6.824659312049133, 7.805632174111905, 8.813418620583947, 9.755317100357182, 10.821544824480394, 11.514129108679755, 10.567174977837391, 9.650263754120088, 8.758542167240323, 7.731697358278299, 6.686572779447116, 5.755424781340852, 4.808455395565468, 3.8832549521620034, 2.9502834939941165, 2.0753476555877857, 2.9657394353143425, 3.8798118362946736, 4.849609356098181, 6.81638372074143, 7.7941546988656265, 8.743539505736539, 9.703222279031694, 10.63649453998011, 11.624048443707313, 12.534641357413161, 11.547363959948544, 10.69297480576026, 9.698117383520858, 8.701823167196878, 7.71207336265178, 6.70982813936718, 5.790131452957713, 4.899338282774704, 3.9230573331932903, 3.073593130348438, 3.966547631997397, 4.904765760114273, 5.782071567678436, 7.74253253188512, 8.729975641549276, 9.659589464268954, 10.634519593233641, 11.612213646044676, 12.606949640320897, 13.542997646783796, 12.617068401073835, 11.700788740603173, 10.751599030875731, 9.709876126198111, 8.737951248015369, 7.684756750035424, 6.78925805268759, 5.890474111092699, 4.86655587316668, 4.125313855875012, 4.936872010288654, 5.901858076904879, 6.768360059090973, 8.698338169230379, 9.659567918790993, 10.599046407540573, 11.54078586898021, 12.53011734547511, 13.568112281860106, 14.592571283559177, 13.629042401253106, 12.59533417651771, 11.61820537693565, 10.634786007675515, 9.625228898905046, 8.677827473927685, 7.728094008331308, 6.744100338509208, 5.80408266252654, 5.0914530473828465, 5.9253221231565245, 6.909558857358502, 7.706955463083927, 9.64418743677765, 10.602220817317576, 11.52624934085168, 12.488040983623964, 13.46755736948305, 14.473483440789092, 15.526347044958756, 14.58864149759881, 13.51683734236506, 12.553307896557149, 11.574105241034081, 10.574829846441077, 9.636829148671024, 8.745935107587297, 7.695952726346221, 6.7846637634422216, 6.071139294464498, 6.907972481464167, 7.878814470814088, 8.747622818476806, 10.669535924035458, 11.560387802663646, 12.5424503732947, 12.618055764325096, 13.66903343248023, 14.608379380476537, 15.509787543258614, 15.36682107729127, 14.399398396892346, 13.454941643237886, 12.52959152300417, 11.600279349780672, 10.567519753918699, 9.74071047331924, 8.710999431367394, 7.722259178331257, 7.094496183236237, 7.979367690744711, 8.831569784826748, 9.765709849073064, 11.60029073155434, 12.6258386747673, 12.64390988645679, 11.660122956925619, 12.659881366387063, 13.65883784588789, 14.551006611990827, 15.533020559425744, 15.381711265077643, 14.453967375891569, 13.467243762015931, 12.562962161346006, 11.605433333775677, 10.757701622928892, 9.744149751165862, 8.71398105545788, 8.057520073075247, 8.998171390600781, 9.845879255002085, 10.697271078839847, 12.57875500064999, 12.619671331551386, 11.643630324726097, 10.727938858566603, 11.658296211810491, 12.613420253599235, 13.560225514057798, 14.576700761462792, 15.564561186953645, 15.408051759334374, 14.476893391532489, 13.574647231099867, 12.646078013637272, 11.70562965698008, 10.758120373700846, 9.763159575177683, 9.017712804384466, 9.978187792025018, 10.811564467738267, 11.661481469805604, 12.504182523926609, 11.625493212597693, 10.664317179868412, 9.727401999884963, 10.724359946758849, 11.714026031206577, 12.607682530138371, 13.562706261849485, 14.548850651824806, 15.531877775317533, 15.4489752694461, 14.51074109801382, 13.640911003846757, 12.763653676152845, 11.73621158632756, 10.698688438929572, 9.979954757971706, 10.956360617909624, 11.878448025186058, 12.611372932672413, 11.476429529251758, 10.74018373688764, 9.7869058595354, 8.794710287717765, 9.756768473356964, 10.644535859947467, 11.600055942136596, 12.631312368916532, 13.589342595623014, 14.638141602338935, 15.503157070392566, 15.474196721026631, 14.669319343120296, 13.746464868565266, 12.761443194515127, 11.727667231216659, 10.946599492929007, 11.949013101295654, 12.947624839731514, 12.495966762948527], [10.522744458580744, 11.471464789616721, 12.031767856423135, 12.718629382520415, 13.684519553761223, 14.663915950547922, 15.67819785346976, 16.61437057935043, 16.427834148559768, 15.447990928873663, 14.535708008655424, 13.509232418369272, 12.545289745728878, 11.555296847086776, 10.5986973162322, 9.730935800854398, 8.774515269602688, 7.860486102077566, 8.749961834272646, 9.53844900817231, 9.550344810583306, 10.495428904936565, 11.473886111729747, 12.522466285712062, 13.457619690437362, 14.434832903388164, 15.495858792036238, 16.43108452359093, 15.450914908131484, 14.455837225958414, 13.570636098849194, 12.64100308944793, 11.678652644777022, 10.710253360114097, 9.671731923419463, 8.665362042081952, 7.702401670936719, 6.916739311252252, 7.81716570274998, 8.609754704379426, 8.60969829137769, 9.576521672292397, 10.612350955530871, 11.493572412559097, 12.492508971458703, 13.490978589482713, 14.513809819389504, 15.44531691361015, 14.475490597971579, 13.522661651413511, 12.682912049639, 11.70350364351861, 10.65709272911999, 9.708508733047282, 8.735508843180515, 7.740830505256795, 6.720456253326974, 5.946461040677237, 6.825122205283229, 7.671988153567736, 7.576704444755272, 8.61511259745325, 9.581250624194736, 10.53106178856681, 11.539559075394035, 12.57275373969285, 13.556373242802627, 14.47136455875347, 13.515192367459901, 12.569095300555919, 11.622613035263713, 10.69113993904017, 9.744052749651553, 8.71109102992761, 7.791202681668129, 6.725827686551336, 5.766790037060843, 4.891591619342206, 5.773174346057804, 6.685134081407897, 6.631681144489768, 7.663365343783764, 8.63120791783809, 9.670890618717394, 10.635097485180673, 11.568745413889225, 12.557797059164246, 13.441246992669484, 12.553304160350791, 11.535100962250675, 10.681385557062626, 9.761048184552376, 8.768080130174711, 7.784482692169072, 6.721073806993786, 5.76424345104625, 4.786576615889856, 3.9301263985917525, 4.753189387181194, 5.69378054046158, 5.800708430642666, 6.755914432139396, 7.747321445742648, 8.775246647241323, 9.804021858719832, 10.741628918435028, 11.781888745283986, 12.515998351884237, 11.543085491448682, 10.557433637828677, 9.622843648970882, 8.758951302419977, 7.766720496134272, 6.7953092954201155, 5.8518858743300735, 4.805622022209024, 3.8308480794135185, 2.8820654641597816, 3.818630674657184, 4.8700803199317475, 4.850214503296664, 5.825799999478454, 6.889364339374568, 7.953060547442025, 8.929332799296098, 9.945322631946206, 10.955353143210134, 11.651806422560178, 10.69365035818549, 9.679961481934006, 8.674176291749182, 7.708395287961652, 6.7779147495311864, 5.801566460105324, 4.793749679805673, 3.8574593632622705, 2.8980140498962728, 1.9474456005132201, 2.912906234946813, 3.9182601713406306, 4.076671615633787, 5.067339198532543, 6.014949897437676, 7.0266294145631605, 8.047386455091138, 9.01512574381811, 10.00178580238539, 10.838381876394063, 9.79646968908, 8.82926721953746, 7.769665010300443, 6.813986541053455, 5.845820413669201, 4.807774911661003, 3.8234998372688667, 2.8814063219725137, 1.934081732073854, 1.0022240517953298, 2.0274795718036955, 3.0187358835471434, 3.1480715595296296, 4.144202384901936, 5.1229873989986885, 6.139239969094078, 7.1659811571244125, 8.184684790270612, 9.208755574612216, 9.888566578881413, 8.862894246513571, 7.8981912497259845, 6.902545244583578, 5.862819052176553, 4.903155774681808, 3.839427393540128, 2.8858186705503495, 1.9480792652315655, 0.943430740144044, 0.0, 1.0369689373719413, 2.096299680996051, 3.9656723806524097, 4.908646332026296, 5.955298439385445, 7.0011076297052135, 7.984498715861247, 8.980684972806268, 10.05527000893356, 10.584336436882715, 9.614534744969417, 8.679139232725483, 7.725821640457729, 6.742972570674279, 5.7305792608411545, 4.797026416071593, 3.8745206657120033, 2.9340106434159248, 1.9662163824064423, 0.9516942416632402, 1.9066111588063628, 2.894530400562317, 4.931066822522084, 5.881228571905088, 6.86220143396786, 7.869987880439903, 8.811886360213139, 9.878114084336351, 10.823758710100222, 11.510605717981436, 10.593694494264133, 9.701972907384368, 8.675128098422343, 7.63000351959116, 6.698855521484896, 5.751886135709512, 4.8266856923060475, 3.8937142341381605, 2.9607911631531323, 2.0223086951702984, 2.9363810961506296, 3.9061786159541367, 5.872952980597386, 6.850723958721582, 7.800108765592493, 8.759791538887647, 9.693063799836061, 10.680617703563264, 11.650027829470382, 12.49079470009259, 11.636405545904305, 10.641548123664903, 9.645253907340923, 8.655504102795824, 7.653258879511224, 6.733562193101757, 5.842769022918748, 4.866488073337335, 3.9590366379137847, 3.023116891853353, 3.961335019970229, 4.838640827534392, 6.799101791741076, 7.786544901405231, 8.71615872412491, 9.691088853089592, 10.668782905900628, 11.663518900176848, 12.637172753865862, 13.56049914121788, 12.644219480747218, 11.695029771019776, 10.653306866342156, 9.681381988159414, 8.628187490179469, 7.732688792831634, 6.833904851236743, 5.809986613310724, 4.963687853491364, 3.9934412701446096, 4.958427336760835, 5.824929318946929, 7.754907429086335, 8.716137178646948, 9.655615667396528, 10.597355128836165, 11.586686605331066, 12.624681541716058, 13.66072833124675, 14.57247314139715, 13.538764916661755, 12.561636117079695, 11.57821674781956, 10.568659639049091, 9.62125821407173, 8.671524748475353, 7.687531078653252, 6.747513402670584, 5.9298270449991985, 4.981891383012481, 5.966128117214458, 6.763524722939883, 8.700756696633606, 9.658790077173533, 10.582818600707634, 11.54461024347992, 12.524126629339005, 13.530052700645047, 14.582916304814711, 15.532072237742854, 14.460268082509105, 13.496738636701194, 12.517535981178126, 11.518260586585122, 10.58025988881507, 9.689365847731342, 8.639383466490266, 7.728094503586265, 6.907031157345295, 5.964541741320124, 6.935383730670045, 7.804192078332762, 9.726105183891415, 10.616957062519603, 11.599019633150657, 12.470380222444767, 13.521357890599901, 14.495463472130302, 15.544037042417466, 16.310251817435315, 15.342829137036391, 14.39837238338193, 13.473022263148215, 12.543710089924717, 11.510950494062744, 10.684141213463285, 9.65443017151144, 8.6656899184753, 7.930388046117034, 7.035936950600668, 7.8881390446827035, 8.82227910892902, 10.656859991410297, 11.682407934623257, 12.004131553627834, 12.591588639404167, 13.591347048865611, 14.590303528366437, 15.482472294469373, 16.46448624190429, 16.32514200522169, 15.397398116035614, 14.410674502159976, 13.50639290149005, 12.548864073919722, 11.701132363072936, 10.687580491309907, 9.657411795601924, 8.893411935956044, 8.054740650456738, 8.90244851485804, 9.753840338695804, 11.635324260505946, 11.821131168538335, 10.936817808990822, 11.65940454104515, 12.589761894289037, 13.544885936077781, 14.491691196536344, 15.508166443941338, 16.496026869432193, 16.35148249947842, 15.420324131676534, 14.518077971243912, 13.589508753781317, 12.649060397124124, 11.70155111384489, 10.706590315321726, 9.853604667265262, 9.034757051880975, 9.868133727594222, 10.718050729661561, 11.57193284584811, 10.826953049584642, 9.957504664133138, 10.65886768236351, 11.655825629237395, 12.645491713685123, 13.539148212616917, 14.49417194432803, 15.480316334303351, 16.46334345779608, 16.392406009590147, 15.454171838157865, 14.584341743990802, 13.70708441629689, 12.679642326471603, 11.642119179073616, 10.815846620852502, 10.01292987776558, 10.935017285042013, 11.66794219252837, 10.54417985117326, 9.807934058809138, 8.925613560845939, 9.726175970196312, 10.68823415583551, 11.576001542426013, 12.531521624615142, 13.562778051395078, 14.52080827810156, 15.569607284817481, 16.446587810536613, 16.417627461170678, 15.612750083264341, 14.68989560870931, 13.70487393465917, 12.671097971360702, 11.782491355809803, 11.046207732597088, 12.004194099587469, 11.563717084870028], [9.649322427907599, 10.598042758943576, 11.591385094487565, 12.551177248029136, 13.571776395746372, 14.576474710835223, 15.562329965441029, 16.558030760260923, 17.46480308593171, 16.484959866245603, 15.525517075380943, 14.499041485094791, 13.535098812454397, 12.545105913812295, 11.588506382957718, 10.720744867579917, 9.764324336328206, 8.787363964532172, 7.8765398035995, 8.665026977499164, 8.67692277991016, 9.62200687426342, 10.600464081056602, 11.649044255038916, 12.584197659764216, 13.561410872715019, 14.622436761363092, 15.557662492917784, 16.487883845503426, 15.492806163330354, 14.607605036221134, 13.67797202681987, 12.681338903204367, 11.700062426839615, 10.661540990144982, 9.65517110880747, 8.692210737662238, 7.843617173706859, 6.943743672076833, 7.73633267370628, 7.736276260704543, 8.70309964161925, 9.738928924857724, 10.620150381885951, 11.619086940785557, 12.617556558809568, 13.64038778871636, 14.658428133429089, 15.512459535343519, 14.559630588785451, 13.71988098701094, 12.74047258089055, 11.694061666491931, 10.745477670419223, 9.772477780552457, 8.768149105119955, 7.710265320052494, 6.8733389031318435, 5.951700174610082, 6.79856612289459, 6.7032824140821266, 7.741690566780104, 8.70782859352159, 9.657639757893664, 10.66613704472089, 11.699331709019706, 12.682951212129483, 13.657765831869195, 14.552161304831841, 13.606064237927859, 12.659581972635653, 11.72810887641211, 10.781021687023493, 9.748059967299552, 8.82817161904007, 7.762796623923277, 6.756599103786363, 5.818469481796813, 4.8997523153846565, 5.811712050734751, 5.758259113816622, 6.7899433131106175, 7.757785887164944, 8.797468588044248, 9.761675454507527, 10.69532338321608, 11.6843750284911, 12.627110942113921, 13.590273097722731, 12.572069899622615, 11.718354494434566, 10.798017121924316, 9.805049067546651, 8.821451629541013, 7.758042744365728, 6.801212388418191, 5.823545553261798, 4.8570042610463595, 3.879767356508047, 4.820358509788433, 4.906114663297985, 5.861320664794715, 6.852727678397967, 7.880652879896642, 8.909428091375151, 9.847035151090347, 10.887294977939305, 11.848977040643799, 12.580054428820622, 11.594402575200617, 10.659812586342822, 9.795920239791917, 8.803689433506213, 7.832278232792056, 6.888854811702014, 5.842590959580965, 4.867817016785461, 3.881170826355029, 2.9452086439840373, 3.975486552587067, 3.918398596624725, 4.893984092806514, 5.9575484327026285, 7.013753574743739, 7.990025826597812, 8.963619482288175, 9.918384205838194, 10.902883093927489, 11.73061929555743, 10.716930419305946, 9.711145229121122, 8.745364225333592, 7.814883686903126, 6.838535397477265, 5.830718617177614, 4.894428300634212, 3.9349829872682145, 2.9465509627084674, 1.9810903282748744, 2.986444264668692, 3.039702678261846, 4.030370261160602, 4.977980960065735, 5.98966047719122, 7.010417517719197, 7.97815680644617, 8.96481686501345, 9.956374311487389, 10.83343862645194, 9.8662361569094, 8.806633947672383, 7.850955478425395, 6.882789351041141, 5.844743849032943, 4.8604687746408075, 3.9183752593444545, 2.971050669445795, 2.039192989167271, 1.0413711632290996, 2.0198829557048072, 2.1111026221576887, 3.107233447529995, 4.086018461626748, 5.102271031722137, 6.129012219752472, 7.147715852898671, 8.171786637240274, 9.163022704058024, 9.899863183885511, 8.935160187097924, 7.939514181955518, 6.899787989548493, 5.940124712053748, 4.876396330912069, 3.9227876079222908, 2.985048202603507, 1.9803996775159853, 1.0369689373719413, 0.0, 1.0593307436241095, 3.006983645210676, 3.9499575965845626, 4.996609703943712, 6.04241889426348, 7.025809980419513, 8.021996237364533, 9.096581273491825, 10.031987481718671, 10.651503682341357, 9.716108170097423, 8.76279057782967, 7.779941508046219, 6.767548198213095, 5.833995353443534, 4.911489603083945, 3.970979580787866, 2.917361481250953, 1.902839340507751, 0.9479224233646284, 1.935841665120583, 3.9723780870803496, 4.922539836463354, 5.903512698526126, 6.9112991449981696, 7.853197624771404, 8.919425348894617, 9.865069974658487, 10.914574682088059, 11.630663431636073, 10.738941844756308, 9.712097035794283, 8.666972456963101, 7.735824458856838, 6.788855073081454, 5.863654629677989, 4.930683171510101, 3.911936261997643, 2.973453794014809, 1.9776923607088952, 2.9474898805124026, 4.9142642451556515, 5.892035223279848, 6.8414200301507595, 7.801102803445914, 8.734375064394328, 9.721928968121532, 10.691339094028649, 11.748751986146932, 12.673374483276245, 11.678517061036844, 10.682222844712864, 9.692473040167766, 8.690227816883166, 7.770531130473699, 6.847707812319372, 5.868480197632914, 4.910181736758295, 3.9742619906978636, 3.0026462845284945, 3.879952092092658, 5.840413056299341, 6.827856165963497, 7.757469988683176, 8.73240011764786, 9.710094170458895, 10.704830164735116, 11.678484018424129, 12.71993230193318, 13.681188418119158, 12.731998708391718, 11.690275803714098, 10.718350925531356, 9.66515642755141, 8.769657730203576, 7.8358969755323225, 6.811978737606304, 5.914832952335875, 4.94458636898912, 4.071383678885058, 4.866240583505195, 6.7962186936446, 7.757448443205214, 8.696926931954795, 9.638666393394432, 10.627997869889333, 11.665992806274325, 12.702039595805017, 13.695022304174238, 14.553848792308596, 13.576719992726536, 12.593300623466401, 11.583743514695934, 10.636342089718573, 9.673516872770932, 8.689523202948832, 7.749505526966163, 6.880972143843709, 5.933036481856991, 5.079084459338682, 5.804835987498149, 7.7420679611918715, 8.700101341731798, 9.624129865265902, 10.585921508038187, 11.565437893897272, 12.571363965203314, 13.624227569372978, 14.66858218132068, 15.475351958155946, 14.511822512348035, 13.532619856824969, 12.533344462231964, 11.595343764461912, 10.691357972026921, 9.641375590785845, 8.730086627881844, 7.858176256189805, 6.915686840164634, 6.048340072794268, 6.8455033428910275, 8.76741644844968, 9.658268327077868, 10.640330897708923, 11.511691487003034, 12.562669155158169, 13.53677473668857, 14.585348306975733, 15.567969676397427, 16.357913012683234, 15.413456259028774, 14.488106138795057, 13.55879396557156, 12.526034369709587, 11.686133337758864, 10.656422295807019, 9.66768204277088, 8.881533144961544, 7.987082049445178, 7.001095386806926, 7.894768373452761, 9.698171255968562, 10.723719199181522, 11.683840883523594, 12.46962429440251, 13.469382703863955, 14.468339183364781, 15.448033460088233, 16.43004740752315, 17.34022588086853, 16.41248199168246, 15.425758377806819, 14.521476777136893, 13.563947949566565, 12.703124487368516, 11.689572615605487, 10.659403919897503, 9.844557034800554, 8.977510135791626, 8.015404856982263, 8.826329603219545, 10.676635525064212, 10.94770913786519, 11.863695671445429, 12.649213607770669, 13.579570961014555, 14.5346950028033, 15.481500263261864, 16.49797551066686, 17.48583593615771, 17.36656637512526, 16.435408007323375, 15.520070095539491, 14.591500878076896, 13.651052521419704, 12.703543238140469, 11.708582439617306, 10.804749766109772, 9.941893520661385, 8.981090069718444, 9.790539994185302, 10.698510815174963, 9.953531018911496, 10.884382526587745, 11.648676749089029, 12.645634695962913, 13.635300780410642, 14.528957279342436, 15.48398101105355, 16.47012540102887, 17.453152524521595, 17.407489885236988, 16.456163962453445, 15.586333868286381, 14.70907654059247, 13.681634450767183, 12.644111303369195, 11.766991719697012, 10.92006634654599, 10.047973627166236, 10.74043145705211, 9.670757820500112, 8.934512028135993, 9.852491423300545, 10.71598503692183, 11.678043222561028, 12.565810609151532, 13.52133069134066, 14.552587118120599, 15.510617344827079, 16.559416351543, 17.48355674790855, 17.419619585466258, 16.61474220755992, 15.69188773300489, 14.70686605895475, 13.673090095656281, 12.733636454654313, 11.953344201377497, 11.117150441711692, 10.69029505419688], [8.761697122351384, 9.710417453387361, 10.70375978893135, 11.642782437907066, 12.625116499626579, 13.629814814715429, 14.615670069321235, 15.61137086414113, 16.574668843858735, 17.423520272913237, 16.435954435975987, 15.409478845689836, 14.445536173049442, 13.45554327440734, 12.498943743552763, 11.631182228174962, 10.674761696923252, 9.697801325127218, 8.728429888228751, 7.777401671942949, 7.789297474353946, 8.734381568707205, 9.712838775500387, 10.702384358919122, 11.637537763644422, 12.614750976595225, 13.675776865243298, 14.61100259679799, 15.59774960343045, 16.458713524645308, 15.545476090886375, 14.61584308148511, 13.591776263799412, 12.61049978743466, 11.571978350740027, 10.565608469402516, 9.602648098257283, 8.754054534301904, 7.795633756706085, 6.848707368150065, 6.813627602930331, 7.780450983845038, 8.810293859866116, 9.673490485766157, 10.672427044665763, 11.670896662689774, 12.693727892596566, 13.711768237309295, 14.648607850319923, 15.525537950100407, 14.657752041676181, 13.678343635555791, 12.63193272115717, 11.683348725084462, 10.710348835217696, 9.678586465715, 8.62070268064754, 7.783776263726889, 6.862137535205127, 5.910940817338375, 5.780633756307914, 6.819041909005891, 7.761168697401797, 8.71097986177387, 9.719477148601095, 10.752671812899912, 11.73629131600969, 12.711105935749401, 13.66727812704297, 14.571971599242815, 13.62548933395061, 12.66597993107735, 11.718892741688734, 10.685931021964793, 9.766042673705309, 8.700667678588516, 7.667036464381408, 6.728906842391858, 5.810189675979702, 4.924086745178536, 4.83561045604241, 5.843283416990824, 6.8111259910451505, 7.850808691924454, 8.815015558387733, 9.748663487096286, 10.737715132371306, 11.680451045994127, 12.662882531893406, 13.537977260937572, 12.684261855749522, 11.735888176589556, 10.742920122211892, 9.759322684206253, 8.695913799030967, 7.73908344308343, 6.761416607927037, 5.767441621641405, 4.790204717103093, 3.9327332042322185, 3.8885679154419197, 4.84377391693865, 5.835180930541902, 6.863106132040578, 7.8918813435190875, 8.829488403234283, 9.865400266028868, 10.789646297019688, 11.762559157455243, 12.560309936515573, 11.625719947657778, 10.761827601106873, 9.741560488171453, 8.770149287457297, 7.826725866367255, 6.780462014246204, 5.8056880714506995, 4.791608186950075, 3.855646004579083, 2.9579398047310015, 2.9008518487686596, 3.876437344950449, 4.909801216760952, 5.954422831119629, 6.930695082973702, 7.904288738664065, 8.859053462214083, 9.843552350303378, 10.801708414678066, 11.682837780620902, 10.677052590436078, 9.711271586648548, 8.780791048218083, 7.776406452142505, 6.768589671842855, 5.832299355299452, 4.872854041933454, 3.856988323303513, 2.89152768886992, 1.9688975168126266, 1.980371934637736, 2.971039517536492, 3.918650216441625, 4.93032973356711, 5.951086774095087, 6.91882606282206, 7.905486121389339, 8.897043567863278, 9.938955755177341, 10.864491556662864, 9.804889347425847, 8.849210878178859, 7.848696712356097, 6.7826149036981835, 5.798339829306048, 4.856246314009695, 3.9089217241110354, 2.9770640438325113, 1.9518085238241456, 0.9605522120806976, 1.051771878533579, 2.0479027039058852, 3.0266877180026377, 4.042940288098027, 5.069681476128362, 6.088385109274561, 7.112455893616163, 8.103691960433913, 9.129364292801755, 9.994490930722035, 8.998844925579629, 7.959118733172604, 6.999455455677859, 5.935727074536179, 4.982118351546401, 4.044378946227616, 3.039730421140095, 2.096299680996051, 1.0593307436241095, 0.0, 2.0582639232436906, 3.001237874617577, 4.047889981976726, 5.012140295592753, 5.995531381748787, 6.991717638693807, 8.045669441534919, 8.981075649761765, 9.950877341675064, 10.775438913721533, 9.82212132145378, 8.83927225167033, 7.826878941837205, 6.893326097067644, 5.970820346708054, 5.030310324411976, 3.9766922248750625, 2.9621700841318606, 2.007253166988738, 1.0654641645899934, 3.024895348440127, 3.975057097823131, 4.956029959885903, 5.963816406357947, 6.905714886131182, 7.947656267038554, 8.893300892802424, 9.907344930860486, 10.93003709096978, 11.798272588380419, 10.771427779418394, 9.72630320058721, 8.795155202480947, 7.848185816705563, 6.922985373302098, 5.990013915134211, 4.971267005621753, 4.032784537638919, 3.037023104333005, 2.0771123799818128, 3.9794684427915863, 4.944552484639624, 5.893937291510537, 6.853620064805691, 7.786892325754105, 8.774446229481308, 9.743856355388424, 10.801269247506706, 11.865276285909168, 12.737847804660953, 11.741553588336973, 10.751803783791875, 9.749558560507275, 8.829861874097807, 7.907038555943483, 6.927810941257025, 5.969512480382406, 5.033592734321973, 4.059553475570462, 3.009574591562068, 4.970035555768751, 5.880373427323273, 6.809987250042952, 7.784917379007637, 8.762611431818673, 9.757347426094894, 10.731001279783907, 11.772449563292959, 12.809602621545844, 13.78096051595191, 12.749606547338207, 11.777681669155465, 10.72448717117552, 9.828988473827684, 8.895227719156434, 7.871309481230415, 6.973483809689411, 6.003237226342657, 5.038251159726432, 3.9958630829746054, 5.925841193114011, 6.843396502817312, 7.749444193314571, 8.691183654754207, 9.680515131249107, 10.718510067634103, 11.754556857164795, 12.747539565534016, 13.762302084493612, 14.636050736350649, 13.652631367090514, 12.643074258320045, 11.695672833342684, 10.732847616395043, 9.748853946572943, 8.808836270590275, 7.939623001197246, 6.918145840296195, 5.877152077897406, 4.93445848696756, 6.8716904606612825, 7.829723841201209, 8.676647126625676, 9.638438769397961, 10.617955155257047, 11.623881226563089, 12.676744830732753, 13.721099442680455, 14.695287688834819, 15.571153255972147, 14.59195060044908, 13.592675205856075, 12.654674508086023, 11.750688715651032, 10.700706334409956, 9.787966303667318, 8.775244268249418, 7.832754852224246, 6.846407691352992, 5.9751258423604385, 7.897038947919091, 8.78789082654728, 9.741129868022007, 10.564208748362809, 11.615186416517943, 12.589291998048344, 13.637865568335508, 14.620486937757201, 15.587909618156125, 16.472787002652886, 15.547436882419168, 14.618124709195671, 13.585365113333697, 12.745464081382975, 11.71575303943113, 10.725561718556353, 9.798601157021157, 8.86051351203241, 7.79916300536565, 7.024390872922172, 8.827793755437973, 9.853341698650933, 10.784639853836678, 11.522141555762285, 12.52189996522373, 13.520856444724556, 14.500550721448008, 15.482564668882924, 16.436985869799198, 17.47181273530657, 16.485089121430928, 15.580807520761004, 14.623278693190676, 13.762455230992625, 12.748903359229597, 11.717283595682977, 10.761625046860166, 9.77557775435035, 8.813472475540987, 7.955952102688957, 9.806258024533623, 10.753131309931758, 11.739163083933681, 12.454325654121302, 13.521060472336341, 14.476184514125086, 15.432485701994631, 16.448960949399623, 17.38079653300998, 18.36883934279313, 17.494738750947484, 16.559516731601967, 15.630947514139372, 14.69049915748218, 13.684126170315809, 12.689165371792646, 11.704633776976095, 10.739961139220108, 9.779157688277168, 8.920162493654713, 9.810885509618748, 10.805421103540748, 11.766597136270029, 12.559114109684074, 13.556072056557959, 14.545738141005687, 15.43939463993748, 16.394418371648595, 17.380562761623914, 18.36358988511664, 18.466820628861097, 17.49561059851592, 16.625780504348857, 15.724156619547157, 14.662217382942522, 13.624694235544535, 12.666875730563335, 11.718133965104714, 10.84604124572496, 9.870053956521522, 8.783132514943897, 9.786402112765245, 10.76292878389559, 11.626422397516876, 12.588480583156073, 13.476247969746577, 14.431768051935705, 15.463024478715642, 16.421054705422122, 17.469853712138043, 18.422117154576185, 17.56107492123061, 16.56566863220948, 15.57387850465432, 14.58885683060418, 13.571940980165442, 12.578920464617678, 11.669087212901145, 10.656596372244216, 9.802669748640668], [8.810681100984318, 9.759401432020296, 10.752743767564285, 11.649715024700921, 12.632049086420434, 13.636747401509284, 14.62260265611509, 15.618303450934985, 16.565648669370894, 17.456968090727475, 18.36678451901773, 17.34030892873158, 16.37636625609119, 15.386373357449084, 14.429773826594507, 13.562012311216707, 12.585902266352576, 11.573710307203735, 10.576140330860985, 9.625112114575181, 7.83828145298688, 8.78336554734014, 9.761822754133322, 10.709316945712978, 11.644470350438278, 12.62168356338908, 13.682709452037153, 14.617935183591845, 15.588729428942608, 16.464814387812226, 17.418919645821006, 16.561330364813884, 15.522606346841156, 14.541329870476405, 13.502808433781771, 12.49643855244426, 11.533478181299028, 10.629963516378421, 9.643344199338319, 8.696417810782298, 6.820560189724186, 7.787383570638894, 8.817226446659971, 9.680423072560012, 10.679359631459619, 11.67782924948363, 12.669155337959388, 13.687195682672117, 14.613305118782703, 15.531638813267325, 16.57238395404244, 15.644708393497064, 14.587272415268938, 13.63868841919623, 12.665688529329463, 11.609416548756744, 10.551532763689284, 9.714606346768635, 8.761252886771388, 7.758651259970609, 5.787566343101769, 6.825974495799747, 7.768101284195652, 8.717912448567725, 9.72640973539495, 10.728099258262734, 11.711718761372511, 12.675803204212182, 13.63197539550575, 14.578072462409732, 15.588285415916122, 14.654574768654886, 13.690943719991495, 12.645835151205981, 11.725946802946499, 10.660571807829706, 9.597866547423154, 8.659736925433604, 7.7093050275459625, 6.77179718781077, 4.842543042836264, 5.850216003784678, 6.818058577839005, 7.857741278718309, 8.821948145181587, 9.724090932459108, 10.713142577734128, 11.645148314456907, 12.627579800356186, 13.65613171214922, 14.647057937715035, 13.726720565204786, 12.733752510827122, 11.719226813447442, 10.655817928272157, 9.69898757232462, 8.721320737168226, 7.698271704683151, 6.721034800144839, 5.780443646864453, 3.895500502235774, 4.850706503732504, 5.842113517335756, 6.870038718834431, 7.852891561921009, 8.790498621636205, 9.79565364268084, 10.71989967367166, 11.692812534107215, 12.678464387727221, 13.58851602962329, 12.724623683072386, 11.732392876786683, 10.760981676072527, 9.787553337434536, 8.740366143487394, 7.765592200691889, 6.739687180542416, 5.803724998171424, 4.823295033986819, 2.9022984141124106, 3.8778839102941998, 4.840054593412924, 5.8846762077716015, 6.860948459625674, 7.8345421153160375, 8.789306838866056, 9.77380572695535, 10.731961791330038, 11.745650667581522, 12.639848672401591, 11.674067668614061, 10.743587130183595, 9.767238840757734, 8.759422060458084, 7.82313174391468, 6.863686430548682, 5.805067316895854, 4.839606682462261, 3.8342527460684437, 1.9350921008142687, 2.925759683713025, 3.8489035930935973, 4.860583110219082, 5.881340150747059, 6.849079439474032, 7.8357394980413115, 8.82729694451525, 9.869209131829313, 10.836411601371854, 11.735337390952852, 10.779658921705863, 9.811492794321609, 8.773447292313412, 7.789172217921276, 6.847078702624923, 5.899754112726264, 4.9678964324477395, 3.987020954288787, 2.995764642545339, 1.0064920447101118, 1.9171641918798987, 2.895949205976651, 3.91220177607204, 4.938942964102375, 5.957646597248574, 6.981717381590176, 7.968176203033116, 8.948618496121618, 9.900303472689362, 10.863136262167032, 9.828491432828962, 8.868828155334217, 7.805099774192537, 6.851491051202759, 5.913751645883975, 4.909103120796454, 3.96567238065241, 3.0069836452106755, 2.0582639232436906, 0.0, 0.9429739513738867, 1.9896260587330357, 3.035435249052804, 4.018826335208837, 5.015012592153857, 6.089597628281149, 7.025003836507995, 7.994805528421295, 8.93020104066523, 9.883518632932983, 9.19000207330109, 8.177608763467966, 7.244055918698404, 6.169311128315165, 5.102472505265613, 4.028500279732372, 3.0139781389891698, 2.059061221846047, 1.0711419800900928, 0.9666314251964364, 1.9167931745794407, 2.8977660366422127, 3.9055524831142563, 4.847450962887491, 5.913678687010703, 6.859323312774573, 7.908828020204146, 8.945747595038513, 9.922576018485154, 10.823922944069764, 9.767928709937525, 8.836780711831262, 7.889811326055876, 6.964610882652412, 5.983772937943807, 4.928118598732372, 3.9896361307495374, 2.9919690173752844, 1.9915196317643833, 1.9212045195478962, 2.8862885613959346, 3.8356733682668462, 4.795356141562, 5.728628402510415, 6.716182306237617, 7.685592432144734, 8.743005324263017, 9.807012362665478, 10.880302699529073, 11.783179097687288, 10.79342929314219, 9.79118406985759, 8.871487383448121, 7.863890149054102, 6.884662534367644, 5.9263640734930245, 4.990444327432591, 3.973960727353033, 2.9239818433446385, 2.9284053097066116, 3.8221095040795836, 4.7517233267992625, 5.726653455763946, 6.7043475085749815, 7.6990835028512015, 8.672737356540216, 9.714185640049267, 10.751338698302153, 11.72269659270822, 12.78184548138681, 11.81930717850578, 10.766112680525834, 9.84385458704923, 8.850229724153076, 7.826311486227057, 6.880198509215563, 5.909951925868809, 4.944965859252584, 3.9025777825007575, 3.939226422051875, 4.785132579573622, 5.691180270070881, 6.632919731510518, 7.6222512080054186, 8.660246144390412, 9.696292933921104, 10.689275642290323, 11.704038161249919, 12.681166960831979, 13.607633372087154, 12.598076263316687, 11.650674838339325, 10.687849621391685, 9.703855951569585, 8.763838275586917, 7.846337700723398, 6.824860539822347, 5.783866777423557, 4.8411731864937115, 4.885075689599146, 5.821808795542848, 6.6183832033819865, 7.5801748461542715, 8.559691232013357, 9.5656173033194, 10.618480907489063, 11.662835519436765, 12.637023765591126, 13.600553211399037, 14.546952605445721, 13.547677210852717, 12.609676513082665, 11.705690720647674, 10.655708339406598, 9.69468100319347, 8.68195896777557, 7.739469551750398, 6.753122390879144, 5.88184054188659, 5.910424176856955, 6.779975780888918, 7.6828659447783165, 8.50594482511912, 9.556922493274254, 10.531028074804654, 11.579601645091818, 12.562223014513512, 13.529645694912436, 14.474102448566896, 15.399452568800612, 14.573126714192313, 13.54036711833034, 12.700466086379617, 11.670755044427771, 10.632276418082505, 9.705315856547308, 8.767228211558562, 7.705877704891802, 6.876121981900738, 6.841178984375838, 7.845426652992573, 8.726375930592987, 9.463877632518596, 10.46363604198004, 11.462592521480866, 12.442286798204318, 13.424300745639234, 14.378721946555508, 15.416719597372342, 16.337104807812374, 15.535809525757646, 14.578280698187317, 13.694121783247567, 12.68056991148454, 11.623998295209129, 10.668339746386318, 9.682292453876501, 8.720187175067139, 7.8076832116675225, 7.8196432534714875, 8.766516538869622, 9.752548312871545, 10.396061730877612, 11.462796549092651, 12.417920590881396, 13.374221778750941, 14.390697026155935, 15.32253260976629, 16.310575419549437, 17.241733787351322, 16.46623143112812, 15.537662213665524, 14.597213857008331, 13.59084086984196, 12.595880071318797, 11.611348476502247, 10.64667583874626, 9.68587238780332, 8.771893602633279, 8.863246462677044, 9.760694657823315, 10.721870690552596, 11.396598589559252, 12.396732814144293, 13.469506555177617, 14.326764762670368, 15.281788494381482, 16.267932884356803, 17.250960007849528, 18.18829158655587, 17.402325298042072, 16.53249520387501, 15.630871319073309, 14.568932082468674, 13.531408935070687, 12.573590430089487, 11.624848664630866, 10.752755945251112, 9.721785065500088, 9.890999457351894, 10.779713648598818, 11.753761793839795, 12.32929030172645, 13.362871663844034, 14.38950778777127, 15.334391350672144, 16.317678567406514, 17.263415977567828, 18.32242407154495, 18.455564972390423, 17.55205474674277, 16.572601219003335, 15.580811091448176, 14.595789417398036, 13.578873566959297, 12.585853051411533, 11.71807119153408, 10.70558035087715, 9.885433025444804], [9.753655052358205, 9.047711882557461, 10.040847208355238, 10.807698012695417, 11.79003207441493, 12.79473038950378, 13.689676262151188, 14.685377056971083, 15.622674717997006, 16.51399413935359, 17.50155997629084, 17.353138074567706, 16.389195401927314, 15.39920250328521, 14.442602972430633, 13.471567145173971, 12.433066210763371, 12.022136590586552, 11.11537404358879, 10.568086065949068, 8.781255404360767, 8.071675997877305, 9.010040897346396, 9.867299933707473, 10.802453338432773, 11.779666551383576, 12.749783058073252, 13.685008789627943, 14.645755477568722, 15.52184043643834, 16.47594569444712, 17.405578703848384, 16.465580298215045, 15.484303821850292, 14.445782385155658, 13.439412503818147, 12.476452132672915, 11.572937467752308, 10.586318150712206, 9.639391762156185, 7.763534141098073, 7.071020176088493, 7.9752094346544675, 8.838406060554508, 9.837342619454114, 10.80889673297479, 11.726181386585502, 12.74422173129823, 13.670331167408817, 14.588664861893438, 15.629410002668553, 16.58768234487095, 15.530246366642825, 14.581662370570116, 13.60866248070335, 12.552390500130631, 11.49450671506317, 10.657580298142522, 9.704226838145274, 8.701625211344496, 6.730540294475656, 6.109611101249346, 6.926084272190148, 7.875895436562221, 8.884392723389446, 9.785125306888848, 10.768744809998624, 11.732829252838295, 12.689001444131863, 13.635098511035846, 14.66984981150396, 15.597548720028772, 14.633917671365381, 13.588809102579868, 12.668920754320386, 11.603545759203593, 10.54084049879704, 9.60271087680749, 8.652278978919849, 7.7147711391846565, 5.785516994210151, 5.0714361689902585, 5.976041565833501, 6.929919055730092, 7.8941259221933695, 8.781116981085221, 9.770168626360242, 10.70217436308302, 11.684605848982299, 12.713157760775333, 13.728622333302873, 14.669694516578675, 13.67672646220101, 12.662200764821328, 11.598791879646043, 10.641961523698507, 9.664294688542114, 8.641245656057038, 7.664008751518725, 6.723417598238339, 4.838474453609661, 4.071926668938085, 4.929343236891126, 5.9309056853864055, 6.909917610547122, 7.8475246702623185, 8.852679691306953, 9.776925722297774, 10.749838582733329, 11.735490436353334, 12.670080425211129, 13.667597634446276, 12.675366828160572, 11.703955627446415, 10.730527288808423, 9.683340094861281, 8.708566152065776, 7.682661131916303, 6.746698949545311, 5.766268985360706, 3.8452723654862977, 3.0581861300659137, 3.897080642039038, 4.941702256397715, 5.917974508251787, 6.891568163942151, 7.846332887492169, 8.830831775581464, 9.788987839956151, 10.802676716207635, 11.80846190639246, 12.617041619987951, 11.686561081557485, 10.710212792131623, 9.702396011831972, 8.766105695288568, 7.80666038192257, 6.748041268269741, 5.782580633836148, 4.777226697442331, 2.8780660521881556, 2.047124209427597, 2.9059296417197107, 3.9176091588451953, 4.9383661993731724, 5.906105488100145, 6.892765546667425, 7.884322993141363, 8.926235180455425, 9.893437649997965, 10.953039859234982, 11.722632873079752, 10.754466745695499, 9.7164212436873, 8.732146169295165, 7.790052653998811, 6.842728064100151, 5.910870383821627, 4.929994905662674, 3.938738593919226, 1.9494659960839984, 0.9741902405060119, 1.9529752546027643, 2.9692278246981534, 3.995969012728488, 5.014672645874687, 6.0387434302162895, 7.02520225165923, 8.005644544747732, 8.957329521315474, 9.920162310793144, 10.77146538420285, 9.811802106708106, 8.748073725566426, 7.794465002576647, 6.856725597257863, 5.852077072170341, 4.908646332026297, 3.9499575965845626, 3.001237874617577, 0.9429739513738867, 0.0, 1.046652107359149, 2.092461297678917, 3.0758523838349507, 4.0720386407799705, 5.146623676907263, 6.082029885134109, 7.051831577047408, 7.987227089291342, 8.940544681559095, 9.923393751342545, 9.120582714841852, 8.18702987007229, 7.112285079689052, 6.0454464566395, 4.971474231106258, 3.956952090363057, 3.002035173219934, 2.0141159314639796, 1.9096053765703231, 1.068908383022738, 2.0498812450855097, 3.057667691557553, 3.999566171330788, 5.027977269124718, 5.973621894888588, 7.008299166232829, 8.030991326342123, 9.007819749788764, 9.889851139523708, 10.710902661311412, 9.779754663205148, 8.832785277429764, 7.907584834026299, 6.926746889317694, 5.871092550106258, 4.932610082123424, 3.934942968749171, 2.93449358313827, 2.864178470921783, 2.0384037698392317, 2.9877885767101438, 3.9474713500052983, 4.880743610953713, 5.868297514680916, 6.837707640588032, 7.895120532706316, 8.959127571108777, 9.998740250504335, 10.865234663049891, 11.736403244516076, 10.734158021231476, 9.814461334822008, 8.806864100427989, 7.827636485741531, 6.869338024866911, 5.933418278806478, 4.9169346787269195, 3.866955794718525, 3.8713792610804982, 2.974224712522881, 3.90383853524256, 4.878768664207245, 5.85646271701828, 6.8511987112945, 7.824852564983514, 8.866300848492566, 9.903453906745451, 10.874811801151518, 11.873287622051123, 12.762281129879666, 11.709086631899721, 10.786828538423118, 9.793203675526962, 8.769285437600944, 7.82317246058945, 6.852925877242695, 5.88793981062647, 4.845551733874644, 4.8822003734257615, 3.937247788016919, 4.843295478514179, 5.785034939953816, 6.774366416448716, 7.81236135283371, 8.848408142364402, 9.841390850733621, 10.856153369693217, 11.833282169275277, 12.816701538535412, 13.541050214690573, 12.593648789713212, 11.630823572765571, 10.646829902943471, 9.706812226960803, 8.789311652097284, 7.767834491196234, 6.726840728797444, 5.784147137867598, 5.828049640973033, 4.973924003986146, 5.770498411825284, 6.732290054597569, 7.711806440456655, 8.717732511762698, 9.770596115932362, 10.814950727880063, 11.789138974034424, 12.752668419842335, 13.788540307084103, 14.490651162226603, 13.552650464456551, 12.64866467202156, 11.598682290780484, 10.637654954567356, 9.624932919149456, 8.682443503124285, 7.69609634225303, 6.824814493260477, 6.853398128230841, 5.932090989332216, 6.834981153221614, 7.658060033562416, 8.70903770171755, 9.68314328324795, 10.731716853535115, 11.714338222956808, 12.681760903355732, 13.626217657010192, 14.551567777243909, 15.487775647383693, 14.483341069704226, 13.643440037753503, 12.613728995801658, 11.575250369456391, 10.648289807921195, 9.710202162932447, 8.648851656265688, 7.819095933274625, 7.7841529357497246, 6.99754186143587, 7.878491139036284, 8.615992840961892, 9.615751250423337, 10.614707729924163, 11.594402006647615, 12.576415954082531, 13.530837154998805, 14.56883480581564, 15.48922001625567, 16.478783477131532, 15.521254649561204, 14.637095734621454, 13.623543862858426, 12.566972246583015, 11.611313697760204, 10.625266405250388, 9.663161126441025, 8.750657163041408, 8.762617204845375, 8.0442047093231, 8.945804883673295, 9.548176939320909, 10.614911757535948, 11.570035799324693, 12.526336987194238, 13.542812234599232, 14.474647818209586, 15.462690627992734, 16.39384899579462, 17.409205382502005, 16.48063616503941, 15.540187808382218, 14.533814821215847, 13.538854022692684, 12.554322427876134, 11.589649790120147, 10.628846339177207, 9.714867554007165, 9.80622041405093, 9.038382828276793, 9.92511802853098, 10.548713798002549, 11.54884802258759, 12.621621763620913, 13.478879971113667, 14.43390370282478, 15.420048092800101, 16.403075216292827, 17.34040679499917, 17.57253641838169, 16.70320738174935, 15.698265712409952, 14.738867039562487, 13.7013438921645, 12.71048077436333, 12.039659496902752, 11.063067615959772, 10.664759016873974, 10.83397340872578, 10.057401819052297, 10.957009131818179, 11.481405510169747, 12.51498687228733, 13.541622996214567, 14.486506559115442, 15.469793775849814, 16.415531186011126, 17.47453927998825, 17.512591021016537, 16.60908079536888, 15.674799042475811, 14.68300891492065, 13.753772405392532, 12.736856554953793, 11.743836039406029, 11.006381642071245, 9.993890801414317, 10.828406976818691], [10.800307159717354, 9.93054570089289, 9.122991188930818, 9.889841993270995, 10.872176054990508, 11.876874370079358, 12.771820242726765, 13.76752103754666, 14.704818698572584, 15.596138119929169, 16.58370395686642, 16.380356652849198, 15.416413980208803, 14.426421081566701, 13.469821550712124, 12.498785723455462, 11.460284789044861, 11.049355168868043, 11.93471532094135, 11.614738173308218, 9.827907511719916, 8.954509816212735, 8.092184877921976, 8.949443914283052, 9.884597319008352, 10.861810531959154, 11.831927038648828, 12.76715277020352, 13.7278994581443, 14.603984417013919, 15.5580896750227, 16.487722684423964, 16.359634838401057, 15.378358362036305, 14.39678694352486, 13.495358758856062, 12.53239838771083, 11.993101959693357, 11.632970258071357, 10.686043869515336, 8.81018624845722, 7.953853994423922, 7.057353415230047, 7.920550041130087, 8.919486600029694, 9.891040713550366, 10.808325367161078, 11.826365711873807, 12.752475147984395, 13.670808842469016, 14.711553983244132, 15.690962389364522, 16.576898474001975, 15.628314477929267, 14.6553145880625, 13.599042607489782, 12.541158822422322, 11.70423240550167, 10.750878945504423, 9.748277318703646, 7.777192401834805, 6.992444919584775, 6.008228252765727, 6.9580394171378, 7.9665367039650254, 8.867269287464424, 9.850888790574201, 10.814973233413873, 11.771145424707441, 12.717242491611424, 13.751993792079539, 14.717676536427977, 15.680569778724532, 14.635461209939018, 13.715572861679535, 12.650197866562742, 11.58749260615619, 10.64936298416664, 9.698931086278998, 8.761423246543806, 6.8321691015693, 5.959996280763084, 5.058185546409081, 6.01206303630567, 6.976269902768948, 7.863260961660799, 8.85231260693582, 9.7843183436586, 10.766749829557877, 11.795301741350912, 12.810766313878451, 13.787584781940183, 14.723378569560158, 13.70885287218048, 12.645443987005192, 11.688613631057656, 10.710946795901263, 9.687897763416187, 8.710660858877874, 7.770069705597488, 5.88512656096881, 4.9604867807109105, 4.011487217466705, 5.013049665961984, 5.992061591122701, 6.929668650837897, 7.934823671882532, 8.859069702873352, 9.831982563308907, 10.817634416928913, 11.752224405786707, 12.778670483608636, 13.722018935519719, 12.750607734805563, 11.777179396167572, 10.72999220222043, 9.755218259424925, 8.729313239275452, 7.79335105690446, 6.812921092719855, 4.891924472845447, 3.9467462418387393, 2.9792246226146166, 4.023846236973293, 5.000118488827366, 5.973712144517729, 6.928476868067747, 7.912975756157042, 8.87113182053173, 9.884820696783214, 10.890605886968038, 11.856386890755568, 12.712579879083496, 11.75686489949077, 10.74904811919112, 9.812757802647717, 8.853312489281718, 7.79469337562889, 6.829232741195297, 5.82387880480148, 3.9247181595473046, 2.935684321200423, 1.9880736222952895, 2.9997531394207737, 4.020510179948751, 4.988249468675724, 5.974909527243003, 6.966466973716941, 8.008379161031003, 8.873739464305679, 9.925450701906746, 10.829325115616273, 11.78048554322151, 10.763073351046447, 9.778798276654312, 8.836704761357959, 7.889380171459299, 6.957522491180775, 5.9766470130218226, 4.985390701278375, 2.9961181034431474, 2.013904249275096, 1.0351192351783431, 2.0150091978144946, 3.0417503858448294, 4.037182633767077, 5.03318511746687, 5.978550144300081, 6.9589924373885825, 7.910677413956326, 8.873510203433996, 9.878157626739371, 10.837820904234116, 9.794725832925574, 8.841117109935794, 7.903377704617011, 6.898729179529489, 5.955298439385445, 4.996609703943712, 4.047889981976726, 1.9896260587330357, 1.046652107359149, 0.0, 1.045809190319768, 2.0292002764758013, 3.0253865334208214, 4.099971569548114, 5.0353777777749595, 6.005179469688259, 6.940574981932193, 7.893892574199946, 8.876741643983397, 9.889134953816521, 9.23368197743144, 8.1589371870482, 7.092098563998649, 6.018126338465407, 5.003604197722205, 4.048687280579083, 3.060768038823128, 2.956257483929472, 2.038655834311801, 1.057682972249029, 2.0440119546703626, 2.973161271969199, 3.981325161765569, 4.926969787529439, 5.96164705887368, 6.984339218982974, 7.961167642429615, 8.843199032164561, 9.8991932662968, 10.826406770564297, 9.879437384788913, 8.954236941385448, 7.973398996676843, 6.917744657465407, 5.979262189482573, 4.98159507610832, 3.981145690497419, 3.9108305782809314, 3.0081512211282946, 1.9955903038736629, 2.955273077168817, 3.8885453381172317, 4.876099241844434, 5.845509367751551, 6.902922259869834, 7.966929298272296, 8.952088143145186, 9.818582555690744, 10.808332360235843, 11.780810128590625, 10.861113442181157, 9.853516207787138, 8.87428859310068, 7.91599013222606, 6.980070386165627, 5.963586786086068, 4.913607902077674, 4.873596370565469, 3.8606709362437295, 2.9310571135240506, 3.886570391370763, 4.864264444181798, 5.859000438458018, 6.832654292147033, 7.874102575656083, 8.911255633908969, 9.882613528315035, 10.826635514691976, 11.824927124844733, 12.75573873925887, 11.78904564790809, 10.795420785011935, 9.771502547085916, 8.825389570074421, 7.8551429867276665, 6.890156920111441, 5.847768843359615, 5.784923761298382, 4.823694011737768, 3.8705140567956695, 4.812253518235306, 5.799460127618856, 6.820163079997228, 7.8562098695279206, 8.84919257789714, 9.863955096856735, 10.841083896438795, 11.82450326569893, 12.834060374469399, 13.595865899198184, 12.633040682250543, 11.649047012428444, 10.709029336445775, 9.791528761582255, 8.759993820773468, 7.719000058374679, 6.776306467444833, 6.730773028845653, 5.793265281338706, 4.797716990106775, 5.75950863287906, 6.736900151626795, 7.7428262229328375, 8.795689827102501, 9.840044439050203, 10.796940701197942, 11.760470147005853, 12.79634203424762, 13.783661322005429, 14.554867573941523, 13.647049218779967, 12.597066837538891, 11.629814284144592, 10.617092248726692, 9.67460283270152, 8.688255671830266, 7.782415457644808, 7.756121516103462, 6.751432266684776, 5.862199731503105, 6.6852786118439065, 7.736256279999041, 8.71036186152944, 9.758935431816605, 10.741556801238298, 11.708979481637222, 12.653436235291682, 13.578786355525398, 14.514994225665182, 15.485558179189198, 14.64182458451191, 13.610136401127326, 12.567409699033627, 11.64044913749843, 10.702361492509684, 9.641010985842925, 8.721819321147246, 8.686876323622345, 7.81688313878843, 6.905709717317775, 7.643211419243383, 8.642969828704826, 9.641926308205653, 10.621620584929104, 11.60363453236402, 12.558055733280295, 13.596053384097129, 14.51643859453716, 15.518781138566817, 16.476309966137144, 15.629255064198691, 14.615703192435662, 13.55913157616025, 12.60347302733744, 11.540971606703845, 10.578866327894483, 9.65338055091403, 9.665340592717994, 8.86354598667566, 7.973023461954787, 8.575395517602399, 9.642130335817438, 10.597254377606182, 11.553555565475728, 12.570030812880722, 13.501866396491076, 14.489909206274223, 15.421067574076108, 16.44183138725696, 16.660798878838694, 15.720350522181501, 14.71397753501513, 13.719016736491968, 12.754866708526148, 12.120001993472979, 11.544551540630664, 10.617590941879786, 10.70894380192355, 9.857724105629353, 8.952336606812471, 9.575932376284038, 10.57606660086908, 11.648840341902403, 12.506098549395155, 13.461122281106269, 14.44726667108159, 15.430293794574316, 16.367625373280656, 16.654680398957268, 15.785351362324928, 14.780409692985529, 13.821011020138066, 12.783487872740078, 11.792624754938908, 11.141829167588373, 11.945901434295202, 11.567482404746595, 11.7366967965984, 10.876743096404857, 9.98422771009967, 10.508624088451237, 11.54220545056882, 12.568841574496057, 13.51372513739693, 14.497012354131302, 15.442749764292616, 16.501757858269738, 16.594735001592117, 15.691224775944457, 14.756943023051388, 13.765152895496227, 12.83591638596811, 11.819000535529371, 10.825980019981607, 10.108551312756866, 10.876724619749746, 11.854824572718828], [11.752274246681003, 10.880879043304663, 9.979132803416238, 9.019340649874668, 10.00167471159418, 10.961936331935068, 11.808422108181059, 12.804122903000954, 13.689985736043814, 14.581305157400399, 15.568870994337649, 15.502065965607454, 14.53812329296706, 13.548130394324957, 12.59153086347038, 11.620495036213718, 10.581994101803117, 11.594186060951959, 12.642733301563831, 12.566705260271867, 10.779874598683564, 9.904843158624507, 9.042518220333749, 8.078942570886724, 9.014095975612024, 9.915981025503967, 10.868528904103123, 11.803754635657814, 12.71306649561553, 13.58915145448515, 14.54325671249393, 15.472889721895195, 15.481344151159313, 14.500067674794561, 13.518496256283116, 12.617068071614318, 11.654107700469085, 12.537932851777272, 12.584937345035003, 11.638010956478983, 9.76215333542087, 8.904187336835694, 8.00768675764182, 7.050048697733759, 8.025454366902377, 8.927642579004662, 9.844927232615373, 10.857090933444129, 11.737642185455625, 12.655975879940247, 13.696721020715362, 14.676129426835752, 15.610935914609776, 15.510727103397121, 14.537727213530355, 13.668043696242528, 12.636053118078829, 12.65619949246532, 11.70284603246807, 10.700244405667293, 8.729159488798452, 7.942778261996548, 6.9585615951775, 6.087538073741472, 7.072504470837709, 7.903871152918721, 8.887490656028497, 9.800140270885104, 10.756312462178672, 11.702409529082654, 12.714717321945043, 13.68040006629348, 14.64403111495687, 15.587428296902663, 14.667539948643181, 13.602164953526389, 12.539459693119838, 11.601330071130288, 10.650898173242645, 9.713390333507453, 7.784136188532947, 6.9103296231748566, 6.008518888820853, 5.048664901759967, 6.012871768223245, 6.899862827115095, 7.888914472390116, 8.76948538112983, 9.751916867029108, 10.758025271216416, 11.773489843743956, 12.750308311805686, 13.713440968641343, 14.660819959144124, 13.59741107396884, 12.640580718021303, 11.66291388286491, 10.639864850379835, 9.662627945841523, 8.722036792561136, 6.837093647932456, 5.910820123122683, 4.961820559878477, 4.049651531416281, 5.028663456576997, 5.966270516292194, 6.91999070935376, 7.844236740344582, 8.817149600780136, 9.780357946794418, 10.714947935652212, 11.741394013474142, 12.712081334600905, 13.683492535315061, 12.729146483131219, 11.681959289184077, 10.707185346388572, 9.681280326239099, 8.745318143868108, 7.764888179683502, 5.8438915598090935, 4.897079584250512, 3.929557965026389, 3.06044810242759, 4.0367203542816625, 4.958879181988958, 5.913643905538976, 6.898142793628271, 7.856298858002959, 8.844577919832973, 9.850363110017797, 10.815318873300896, 11.666770688763727, 12.71260835484564, 11.74539524800418, 10.779570102219024, 9.820124788853025, 8.746660462592537, 7.781199828158944, 6.775845891765127, 4.876685246510951, 3.8860176636121952, 2.938406964707062, 2.0363550048750705, 3.027329028891959, 3.9734165061469517, 4.960076564714232, 5.95163401118817, 6.988156556757109, 7.827930273985912, 8.879641511586978, 9.783515925296506, 10.73467635290174, 11.728575823635069, 10.775145405467372, 9.833051890171019, 8.88572730027236, 7.953869619993835, 6.928614099985469, 5.937357788242021, 3.9603684170591746, 2.964237591686868, 1.9854525775901155, 0.9692000074947265, 1.995941195525061, 2.9913734434473094, 3.9873759271471014, 4.932740953980313, 5.913183247068815, 6.864868223636559, 7.827701013114229, 8.832348436419604, 9.792011713914349, 10.73447763079778, 9.886926300255563, 8.94918689493678, 7.9445383698492575, 7.0011076297052135, 6.042418894263479, 5.012140295592753, 3.035435249052804, 2.092461297678917, 1.045809190319768, 0.0, 0.9833910861560334, 1.9795773431010537, 3.054162379228346, 3.9895685874551923, 4.959370279368492, 5.894765791612426, 6.848083383880179, 7.83093245366363, 8.843325763496754, 9.776878608266315, 9.204746377367968, 8.137907754318416, 7.063935528785175, 6.049413388041973, 5.094496470898851, 4.106577229142896, 3.937123822268414, 2.98696207288541, 2.005989210822638, 0.9982027643505945, 1.9273520816494312, 2.9355159714458012, 3.8811605972096714, 4.915837868553913, 5.938530028663207, 6.915358452109848, 7.797389841844794, 8.853384075977033, 9.784532074083296, 10.73150145985868, 9.935103279724391, 8.954265335015785, 7.898610995804349, 6.960128527821515, 5.962461414447262, 4.9620120288363605, 4.891696916619874, 3.9564574597019035, 2.9438965424472716, 2.0142981613998727, 2.9475704223482873, 3.93512432607549, 4.901672845943077, 5.8960268506650655, 6.960033889067527, 7.906278952825419, 8.772773365370977, 9.762523169916076, 10.738935432109624, 11.713177517250925, 10.83438254612608, 9.855154931439621, 8.896856470565002, 7.960936724504569, 6.944453124425009, 5.894474240416615, 5.8219026091390775, 4.808977174817338, 3.879363352097659, 2.945595475601819, 3.9232895284128544, 4.918025522689074, 5.891679376378089, 6.933127659887139, 7.96784782391044, 8.939205718316506, 9.78082632437221, 10.779117934524967, 11.71386404277787, 12.712304116980802, 11.743727023585544, 10.719808785659525, 9.77369580864803, 8.803449225301275, 7.83846315868505, 6.796075081933224, 6.733229999871989, 5.772000250311375, 4.818820295369278, 3.918518858820602, 4.858485211849912, 5.879188164228284, 6.915234953758977, 7.908217662128196, 8.920547286858207, 9.897676086440267, 10.823025106917212, 11.82675092110327, 12.70693476667013, 13.581346920824153, 12.597353251002053, 11.657335575019385, 10.739835000155864, 9.708300059347076, 8.667306296948286, 7.724612706018441, 7.679079267419261, 6.7415715199123145, 5.746023228680383, 4.881217945637315, 5.795925235857851, 6.8018513071638935, 7.854714911333557, 8.899069523281259, 9.853532891199414, 10.817062337007325, 11.794863875465904, 12.776351868639301, 13.66593644141347, 14.595355457353575, 13.545373076112499, 12.5781205227182, 11.5653984873003, 10.622909071275128, 9.636561910403874, 8.730721696218415, 8.70442775467707, 7.699738505258384, 6.797998770994521, 5.806987924602161, 6.836371281957494, 7.810476863487894, 8.859050433775058, 9.841671803196752, 10.809094483595675, 11.753551237250136, 12.678901357483852, 13.615109227623636, 14.596627046661144, 15.590130823085518, 14.558442639700933, 13.515715937607235, 12.588755376072038, 11.650667731083292, 10.589317224416533, 9.670125559720853, 9.635182562195952, 8.765189377362038, 7.7487076615328085, 6.764920732001638, 7.764679141463081, 8.760018398076541, 9.739712674799993, 10.72172662223491, 11.676147823151183, 12.714145473968017, 13.616553596495613, 14.61889614052527, 15.5764249680956, 15.797777212836362, 14.8672220858782, 13.849421701753673, 12.84455809643904, 12.489277845277453, 11.52717256646809, 10.601686789487637, 10.613646831291602, 9.703226995680671, 8.717195221678748, 7.6971048303606535, 8.763839648575694, 9.718963690364438, 10.675264878233984, 11.691682206813738, 12.619958486361964, 13.608001296145112, 14.539159663946997, 15.55992347712785, 15.790297535442367, 14.849849178785174, 13.843476191618803, 12.84851539309564, 11.88436536512982, 12.849038002885807, 12.492857779204272, 11.565897180453394, 11.657250040497157, 10.595732901755024, 9.634556869025744, 8.697641689042294, 9.697775913627336, 10.770549654660659, 11.62780786215341, 12.582831593864524, 13.568975983839845, 14.552003107332572, 15.489334686038914, 15.639847436428498, 14.821953227779222, 13.817011558439823, 12.946209956011387, 11.912986529343751, 10.92212341154258, 11.954335881920038, 12.896234776706974, 12.515788643320203, 12.660693413405948, 11.614751892530528, 10.622528973027128, 9.630333401209493, 10.663914763327076, 11.690550887254313, 12.635434450155186, 13.618721666889558, 14.564459077050872, 15.623467171027993, 15.579902039063347, 14.676391813415687, 13.793544888505682, 12.801754760950521, 11.92097834782382, 10.948499192133044, 9.95547867658528, 10.957892284951926, 11.827057962161518, 12.8051579151306], [12.735665332837035, 11.8642701294607, 10.962523889572273, 10.002731736030702, 9.210034823983333, 10.021952807075799, 10.868438583321792, 11.864139378141687, 12.70659464988778, 13.597914071244364, 14.585479908181615, 14.72050562215807, 13.756562949517676, 12.766570050875574, 11.840146948698942, 10.86911112144228, 11.469650812719156, 12.481842771867996, 13.530390012479868, 13.5500963464279, 11.763265684839597, 10.888234244780543, 10.025909306489782, 9.062333657042759, 8.222456088001177, 8.975997500644699, 9.928545379243856, 10.863771110798547, 11.729675409459496, 12.605760368329115, 13.559865626337896, 14.48949863573916, 14.69978380770993, 13.718507331345178, 12.767112341511679, 11.934684880214727, 12.541764411385124, 13.42558956269331, 13.568328431191036, 12.621402042635015, 10.745544421576902, 9.88757842299173, 8.991077843797852, 8.033439783889794, 7.213352326712656, 7.987659054145393, 8.904943707756106, 9.873699847288094, 10.75425109929959, 11.672584793784212, 12.713329934559328, 13.692738340679718, 14.627544828453747, 14.740625578821845, 13.786343298758917, 12.985660504842937, 13.523709828994868, 13.639590578621352, 12.686237118624103, 11.683635491823326, 9.712550574954484, 8.926169348152582, 7.941952681333533, 7.0709291598975055, 6.2604024306479875, 6.963887628059452, 7.947507131169229, 8.816749184729069, 9.772921376022637, 10.71901844292662, 11.731326235789012, 12.69700898013745, 13.660640028800842, 14.668031306171654, 14.730649460271303, 14.000663323548396, 13.52285077927587, 12.584721157286321, 11.634289259398678, 10.696781419663486, 8.76752727468898, 7.893720709330889, 6.9919099749768865, 6.032055987916, 5.200769728033523, 5.9598793022558265, 6.948930947530847, 7.786094294973795, 8.768525780873073, 9.774634185060386, 10.790098757587925, 11.766917225649657, 12.73004988248531, 13.741422968413115, 14.580802160124872, 13.623971804177335, 12.646304969020942, 11.623255936535868, 10.646019031997556, 9.705427878717169, 7.82048473408849, 6.894211209278716, 5.945211646034511, 5.033042617572314, 4.129667844246669, 5.026286991432924, 5.936599623197726, 6.860845654188547, 7.833758514624101, 8.796966860638387, 9.731556849496181, 10.75800292731811, 11.728690248444872, 12.700101449159028, 13.712537569287251, 12.66535037534011, 11.690576432544605, 10.664671412395132, 9.72870923002414, 8.748279265839535, 6.827282645965127, 5.880470670406545, 4.912949051182423, 4.043839188583624, 3.1377247419513346, 3.975488095832924, 4.930252819382941, 5.914751707472236, 6.872907771846925, 7.861186833676942, 8.866972023861765, 9.831927787144863, 10.683379602607694, 11.729217268689608, 12.69054701271792, 11.762961188375057, 10.803515875009058, 9.73005154874857, 8.764590914314978, 7.7592369779211605, 5.860076332666985, 4.869408749768229, 3.9217980508630954, 3.019746091031104, 2.082058112968478, 2.990025419990918, 3.9766854785581978, 4.968242925032136, 6.004765470601075, 6.844539187829879, 7.896250425430946, 8.800124839140471, 9.751285266745708, 10.745184737479034, 11.720297170181112, 10.816442976327053, 9.869118386428394, 8.93726070614987, 7.912005186141504, 6.920748874398056, 4.943759503215208, 3.9476286778429017, 2.9688436637461493, 1.95259109365076, 1.0506702796015803, 2.007982357291276, 3.003984840991068, 3.9493498678242798, 4.929792160912782, 5.881477137480525, 6.8443099269581955, 7.848957350263569, 8.808620627758314, 9.751086544641746, 10.704695267631525, 9.932577981092813, 8.927929456005291, 7.984498715861247, 7.025809980419513, 5.995531381748787, 4.018826335208837, 3.0758523838349503, 2.0292002764758013, 0.9833910861560334, 0.0, 0.9961862569450202, 2.0707712930723123, 3.0061775012991587, 3.975979193212458, 4.911374705456392, 5.864692297724146, 6.847541367507596, 7.8599346773407195, 8.793487522110281, 9.86823231249352, 9.12129884047445, 8.047326614941209, 7.032804474198007, 6.0778875570548845, 5.08996831529893, 4.824780533184452, 3.8746187838014476, 2.893645921738676, 1.8858594752666327, 0.9439609954933976, 1.9521248852897677, 2.897769511053638, 3.9324467823978795, 4.9551389425071735, 5.931967365953814, 6.81399875568876, 7.869992989820999, 8.801140987927264, 9.748110373702648, 10.673310817106113, 9.841922045931824, 8.786267706720388, 7.847785238737553, 6.8501181253633, 5.849668739752399, 5.779353627535912, 4.844114170617941, 3.8315532533633094, 2.901954872315911, 1.9862023655517211, 2.973756269278924, 3.9182817597870434, 4.912635764509032, 5.976642802911494, 6.922887866669385, 7.789382279214943, 8.779132083760041, 9.755544345953592, 10.729786431094892, 11.689394147718813, 10.74281164235566, 9.78451318148104, 8.848593435420607, 7.832109835341048, 6.782130951332654, 6.709559320055115, 5.696633885733376, 4.767020063013697, 3.833252186517857, 3.013546377421153, 4.008282371697373, 4.926638049157679, 5.968086332666731, 6.984456737754407, 7.955814632160473, 8.797435238216176, 9.795726848368933, 10.730472956621837, 11.728913030824769, 12.631383734501583, 11.607465496575564, 10.661352519564069, 9.691105936217314, 8.726119869601089, 7.683731792849262, 7.620886710788028, 6.659656961227414, 5.706477006285316, 4.806175569736641, 3.94874206085821, 4.969445013236583, 5.97621168593306, 6.96919439430228, 7.937156200702174, 8.914285000284234, 9.839634020761178, 10.843359834947236, 11.723543680514098, 12.686368897461739, 13.485009961918092, 12.544992285935423, 11.627491711071903, 10.595956770263115, 9.554963007864325, 8.61226941693448, 8.566735978335299, 7.629228230828352, 6.633679939596421, 5.768874656553353, 4.886182084866149, 5.89210815617219, 6.944971760341853, 7.978757817043357, 8.870141805043382, 9.833671250851292, 10.81147278930987, 11.792960782483267, 12.682545355257437, 13.701490746119447, 14.433029787028538, 13.465777233634238, 12.453055198216338, 11.510565782191167, 10.524218621319912, 9.618378407134454, 9.592084465593107, 8.587395216174423, 7.68565548191056, 6.6946446355182, 5.926628130965792, 6.900733712496192, 7.949307282783357, 8.93192865220505, 9.895444495442058, 10.839901249096519, 11.765251369330235, 12.701459239470019, 13.613235960505111, 14.623777452957873, 15.05586268326237, 14.228864459269257, 13.476412086988077, 12.538324441999329, 11.47697393533257, 10.55778227063689, 10.52283927311199, 9.652846088278077, 8.636364372448847, 7.652577442917677, 6.98650799036203, 7.85027524708484, 8.829969523808291, 9.811983471243208, 10.766404672159481, 11.804402322976316, 12.702903608341996, 13.705246152371654, 14.65114954036209, 14.88298008680451, 14.022712363463903, 13.237142582142633, 13.827949182595074, 13.37693455619349, 12.414829277384127, 11.489343500403674, 11.501303542207639, 10.590883706596712, 9.604851932594789, 8.584761541276693, 8.010285028007642, 8.901964105270052, 9.82075062174132, 10.781939055822036, 11.710215335370263, 12.69825814515341, 13.629416512955295, 14.650180326136148, 14.875500409410515, 13.935052052753322, 12.998966469204506, 12.18796406242283, 12.867756451285855, 13.832429089041842, 13.380514490120309, 12.453553891369431, 12.544906751413194, 11.483389612671065, 10.522213579941784, 9.585298399958333, 8.944221293059284, 9.959231750645207, 10.773293605660747, 11.72831733737186, 12.714461727347182, 13.697488850839909, 14.601498390868906, 14.656456350272464, 13.881969702919955, 12.877028033580556, 12.006226431152118, 11.252435198670941, 11.905514497698615, 12.937726968076072, 13.87962586286301, 13.40344535423624, 13.548350124321988, 12.502408603446568, 11.510185683943167, 10.517990112125531, 9.91181276646117, 10.938448890388406, 11.780920193662523, 12.764207410396894, 13.709944820558208, 14.76895291453533, 14.596510952907312, 13.693000727259653, 12.853561363646415, 11.861771236091254, 10.98099482296455, 10.223456406383855, 10.938869762741314, 11.94128337110796, 12.810449048317555, 13.788549001286636], [13.697357819905365, 12.747713306785815, 11.754370971241826, 10.794578817700256, 9.906606069969168, 9.025766550130776, 9.87225232637677, 10.867953121196665, 11.710408392942758, 12.601727814299343, 13.589293651236593, 13.848151257965268, 12.97125922116722, 11.981266322525117, 11.220722419747672, 11.8652973783873, 12.465837069664175, 13.478029028813015, 14.526576269424888, 14.54628260337292, 12.741597834636481, 11.796513740283222, 10.895628456006252, 9.854180738712312, 8.919027333987012, 7.979811243699676, 8.932359122298834, 9.867584853853526, 10.733489152514474, 11.609574111384093, 12.563679369392874, 13.493312378794139, 13.914480079359473, 12.933203602994721, 12.147687812560408, 12.930871137159746, 13.537950668330144, 14.421775819638329, 14.564514688136056, 13.617588299580035, 11.741730678521922, 10.79585791849441, 9.860796993314322, 8.862931636456429, 7.9099235726984904, 6.991472797200371, 7.908757450811084, 8.877513590343073, 9.75806484235457, 10.67639853683919, 11.717143677614306, 12.696552083734696, 13.631358571508724, 13.955321850471389, 13.166918769807646, 13.981846761787956, 14.519896085939887, 14.635776835566372, 13.682423375569122, 12.679821748768346, 10.708736831899504, 9.834448843655263, 8.850232176836215, 7.900421012464141, 6.956973676633822, 5.967701371114431, 6.951320874224208, 7.820562927784048, 8.776735119077616, 9.722832185981598, 10.73513997884399, 11.700822723192427, 12.664453771855818, 13.671845049226635, 14.111224931320033, 14.996849580493416, 14.51903703622089, 13.58090741423134, 12.630475516343697, 11.692967676608506, 9.763713531634, 8.869073115416267, 7.90123054136194, 6.861547840482636, 5.897340974019358, 4.963693045310805, 5.952744690585826, 6.7899080380287735, 7.772339523928053, 8.778447928115362, 9.793912500642902, 10.770730968704633, 11.733863625540291, 12.745236711468095, 13.781954827085176, 14.550116216793015, 13.642491225965962, 12.619442193480888, 11.642205288942575, 10.701614135662188, 8.81667099103351, 7.890397466223735, 6.9413979029795305, 5.960767352380775, 4.967707794203099, 4.0301007344879025, 4.940413366252706, 5.864659397243527, 6.837572257679081, 7.800780603693364, 8.735370592551158, 9.761816670373086, 10.732503991499852, 11.703915192214009, 12.7524969502973, 13.591494787955789, 12.686762689489624, 11.660857669340151, 10.72489548696916, 9.744465522784555, 7.823468902910147, 6.876656927351565, 5.909135308127443, 4.971563923392084, 3.995291671538012, 2.9793018388879036, 3.9340665624379207, 4.918565450527216, 5.876721514901904, 6.86500057673192, 7.870785766916744, 8.835741530199844, 9.687193345662674, 10.733031011744588, 11.6943607557729, 12.599394978412823, 11.799702131954078, 10.72623780569359, 9.760777171259997, 8.75542323486618, 6.856262589612005, 5.8655950067132485, 4.917984307808116, 3.982335492300847, 2.96157845177287, 1.9938391630458976, 2.980499221613177, 3.972056668087115, 5.008579213656055, 5.848352930884857, 6.900064168485924, 7.8039385821954514, 8.755099009800688, 9.748998480534015, 10.724110913236093, 11.583414507633321, 10.865304643373415, 9.933446963094891, 8.908191443086524, 7.916935131343076, 5.939945760160228, 4.9438149347879214, 3.965029920691169, 2.94877735059578, 2.0304997334924546, 1.0117961003462554, 2.0077985840460477, 2.953163610879259, 3.9336059039677607, 4.885290880535504, 5.848123670013175, 6.852771093318549, 7.812434370813294, 8.754900287696726, 9.708509010686505, 10.646248416005289, 9.92411571295031, 8.980684972806268, 8.021996237364533, 6.991717638693807, 5.015012592153857, 4.0720386407799705, 3.0253865334208214, 1.9795773431010537, 0.9961862569450202, 0.0, 1.0745850361272922, 2.009991244354138, 2.9797929362674376, 3.915188448511372, 4.868506040779125, 5.851355110562576, 6.8637484203957, 7.797301265165261, 8.8720460555485, 9.938884678598052, 9.043512871886229, 8.028990731143027, 7.074073813999904, 6.08615457224395, 5.820966790129472, 4.870805040746468, 3.8898321786836965, 2.882045732211653, 1.9401472524384178, 0.9559386283447474, 1.9015832541086173, 2.936260525452859, 3.958952685562153, 4.9357811090087935, 5.81781249874374, 6.873806732875979, 7.804954730982242, 8.751924116757626, 9.677124560161092, 10.657962504869698, 9.782453963665406, 8.843971495682572, 7.84630438230832, 6.845854996697419, 6.775539884480932, 5.840300427562962, 4.82773951030833, 3.898141129260931, 2.9823886224967415, 2.027716541415497, 2.922095502842023, 3.9164495075640113, 4.980456545966473, 5.926701609724365, 6.793196022269923, 7.782945826815022, 8.75935808900857, 9.73360017414987, 10.693207890773792, 11.630736344068872, 10.780699438426058, 9.844779692365627, 8.828296092286068, 7.778317208277674, 7.705745577000136, 6.692820142678396, 5.763206319958718, 4.829438443462877, 4.009732634366173, 3.088508932935936, 3.9304517922126583, 4.9719000757217096, 5.988270480809386, 6.959628375215452, 7.801248981271155, 8.799540591423913, 9.734286699676815, 10.732726773879747, 11.722112550638547, 12.574234884042262, 11.657538776509089, 10.687292193162333, 9.722306126546108, 8.679918049794281, 8.617072967733048, 7.655843218172434, 6.7026632632303365, 5.80236182668166, 4.94492831780323, 4.049671574475146, 4.980025428988039, 5.973008137357259, 6.940969943757153, 7.918098743339214, 8.843447763816156, 9.847173578002216, 10.727357423569076, 11.690182640516717, 12.660910547035744, 13.511761673402122, 12.623677968016922, 11.592143027208134, 10.551149264809345, 9.608455673879499, 9.562922235280318, 8.625414487773373, 7.629866196541442, 6.765060913498373, 5.882368341811169, 5.085122554287764, 6.053401907782386, 6.982571560098337, 7.87395554809836, 8.837484993906271, 9.815286532364848, 10.796774525538247, 11.686359098312415, 12.705304489174425, 13.612762934872757, 14.461963490579258, 13.449241455161358, 12.506752039136186, 11.520404878264932, 10.614564664079474, 10.588270722538127, 9.583581473119443, 8.68184173885558, 7.69083089246322, 6.922814387910813, 6.115429984145733, 7.102655656623558, 7.944900718578865, 8.899258238497037, 9.843714992151497, 10.769065112385213, 11.705272982524997, 12.61704970356009, 13.627591196012851, 14.059676426317347, 14.925435705255092, 14.472598343933097, 13.534510698944349, 12.47316019227759, 11.55396852758191, 11.519025530057009, 10.649032345223096, 9.632550629393867, 8.648763699862696, 7.982694247307051, 7.064971518734381, 8.044665795457833, 9.007316657413307, 9.881571106682333, 10.84274072480518, 11.706717351396975, 12.709059895426632, 13.654963283417068, 13.886793829859489, 13.02652610651888, 13.933713828128468, 14.619796264264627, 14.37312081313851, 13.411015534329147, 12.485529757348694, 12.497489799152659, 11.587069963541731, 10.601038189539809, 9.580947798221713, 9.006471284952662, 8.116660376919592, 9.035446893390862, 9.977272241992136, 10.825381769893115, 11.813424579676262, 12.716366980913532, 13.737130794094384, 13.879314152465493, 12.9388657958083, 12.002780212259482, 12.884535308408665, 13.659603532955408, 14.624276170711395, 14.376700747065328, 13.44974014831445, 13.541093008358214, 12.479575869616085, 11.518399836886804, 10.581484656903353, 9.940407550004304, 9.173928022294747, 9.98798987731029, 10.943013609021405, 11.841092305021954, 12.824119428514681, 13.688448858827144, 13.660270093327442, 12.885783445974933, 11.880841776635535, 11.010040174207095, 11.949006444656776, 12.697361579368168, 13.729574049745626, 14.763069040188126, 14.39963161118126, 14.544536381267008, 13.498594860391588, 12.506371940888187, 11.514176369070551, 10.90799902340619, 10.243418193553858, 10.995616465312066, 11.978903682046438, 12.83657539823298, 13.895583492210102, 13.600324695962291, 12.696814470314632, 11.857375106701394, 10.865584979146233, 9.984808566019527, 10.92002765236969, 11.730716844410868, 12.733130452777514, 13.69389222564267, 14.671992178611752], [14.605278860020213, 13.655634346900664, 12.662292011356675, 11.702499857815104, 10.814527110084017, 9.905444457446498, 8.89116255452466, 9.884452916760777, 10.667756974443845, 11.55907639580043, 12.54664223273768, 12.773566221837976, 12.024263963206351, 11.03427106456425, 11.98144551573414, 12.782441174714334, 13.416261683433623, 14.428453642582465, 15.477000883194338, 15.518803284748095, 13.649518874751331, 12.704434780398072, 11.8035494961211, 10.76210177882716, 9.82694837410186, 8.887732283814525, 7.951269350446724, 8.884084649417638, 9.690837734015561, 10.56692269288518, 11.521027950893961, 12.450660960295226, 12.967484821398605, 11.986208345033853, 12.908410908546877, 13.84801493348678, 14.488375282099591, 15.372200433407778, 15.537035369511232, 14.590108980955211, 12.744485572982816, 11.70377895860926, 10.76871803342917, 9.770852676571277, 8.817844612813339, 7.89939383731522, 6.927667678958974, 7.834862171844159, 8.715413423855656, 9.633747118340278, 10.674492259115393, 11.638601391543576, 12.556773535381431, 13.008326592510521, 13.927641865794115, 14.89899055811499, 15.470320699709335, 15.642476235820233, 14.689122775822984, 13.686521149022207, 11.715436232153365, 10.742369883770111, 9.758153216951063, 8.80834205257899, 7.864894716748671, 6.875622411229279, 5.9702311023720975, 6.7779115092851345, 7.734083700578703, 8.680180767482685, 9.660554942716699, 10.626237687065135, 11.589868735728526, 12.59726001309934, 13.645374134069467, 14.437115416170808, 15.288862366391678, 14.587606814485202, 13.637174916597559, 12.699667076862367, 10.770412931887861, 9.776994155531115, 8.809151581476788, 7.7694688805974845, 6.805262014134207, 5.871614085425653, 4.960178429169112, 5.7472566195298604, 6.7296881054291395, 7.70386289198807, 8.719327464515612, 9.696145932577341, 10.659278589412997, 11.670651675340801, 12.707369790957884, 13.475531180665723, 14.30864894522069, 13.626141593734749, 12.648904689196437, 11.70831353591605, 9.823370391287371, 8.897096866477598, 7.919361252515095, 6.89143605101642, 5.875628834317947, 4.938021774602751, 3.897761947753792, 4.822007978744613, 5.7949208391801665, 6.726195567566072, 7.660785556423867, 8.687231634245796, 9.657918955372558, 10.629330156086715, 11.677911914170007, 12.516909751828496, 13.352920408744353, 12.667557069594013, 11.731594887223022, 10.751164923038417, 8.830168303164008, 7.883356327605427, 6.915834708381305, 5.9022326220277295, 4.925960370173657, 3.909970537523549, 2.8914151439390072, 3.875914032028302, 4.83407009640299, 5.790415540604628, 6.796200730789452, 7.761156494072551, 8.61260830953538, 9.658445975617294, 10.619775719645608, 11.52480994228553, 12.420086379227108, 11.73293720594745, 10.767476571513859, 9.762122635120042, 7.862961989865867, 6.872294406967111, 5.924683708061978, 4.913004190936493, 3.892247150408516, 2.924507861681543, 1.9378478031142636, 2.9294052495882017, 3.9339941775287626, 4.773767894757565, 5.825479132358632, 6.729353546068159, 7.680513973673395, 8.674413444406722, 9.6495258771088, 10.50882947150603, 11.456154061404689, 10.940146363348752, 9.914890843340386, 8.923634531596937, 6.99389756300134, 5.997766737629034, 5.018981723532281, 4.002729153436892, 2.9759879654065573, 1.957284332260358, 0.9332135479187557, 1.8785785747519672, 2.8590208678404685, 3.8107058444082123, 4.773538633885883, 5.778186057191257, 6.737849334686002, 7.680315251569434, 8.633923974559213, 9.571663379877997, 10.576311904965518, 10.05527000893356, 9.096581273491825, 8.045669441534919, 6.089597628281149, 5.146623676907263, 4.099971569548114, 3.054162379228346, 2.0707712930723123, 1.0745850361272922, 0.0, 0.9354062082268462, 1.9052079001401454, 2.84060341238408, 3.793921004651833, 4.776770074435284, 5.789163384268408, 6.722716229037969, 7.797461019421208, 8.86429964247076, 9.938271868004001, 9.10357576727032, 8.148658850127196, 7.160739608371242, 6.830509091292376, 5.8803473419093715, 4.8993744798466, 3.8915880333745565, 2.9496895536013215, 1.8834618294781087, 0.9378172037142387, 1.8616754893255667, 2.8843676494348607, 3.861196072881502, 4.7432274626164475, 5.7992216967486865, 6.73036969485495, 7.677339080630334, 8.6025395240338, 9.583377468742405, 10.639031807953842, 9.853513796845476, 8.855846683471224, 7.855397297860323, 7.7850821856438355, 6.849842728725865, 5.808248516325532, 4.848565743030378, 3.915293482081964, 2.9277395783547613, 1.9583294524476444, 2.841864471436719, 3.905871509839181, 4.8521165735970735, 5.718610986142631, 6.708360790687729, 7.684773052881278, 8.659015138022578, 9.6186228546465, 10.55615130794158, 11.514449768816199, 10.854321993528531, 9.837838393448973, 8.787859509440578, 8.686254583017337, 7.673329148695599, 6.74371532597592, 5.779863057232324, 4.935075589783514, 3.940339595507294, 2.9666857418182797, 3.91156891256201, 4.913685444682094, 5.88504333908816, 6.726663945143863, 7.72495555529662, 8.659701663549523, 9.658141737752455, 10.647527514511255, 11.49964984791497, 12.445762824926465, 11.667801199179536, 10.70281513256331, 9.660427055811484, 9.59758197375025, 8.636352224189636, 7.683172269247539, 6.752786440451108, 5.87027127322057, 4.901502237046504, 4.01625937859366, 4.92354291274128, 5.866384907629861, 6.843513707211922, 7.768862727688864, 8.772588541874924, 9.652772387441784, 10.615597604389425, 11.586325510908452, 12.43717663727483, 13.411902016434299, 12.572652033225337, 11.531658270826547, 10.588964679896701, 10.543431241297522, 9.605923493790577, 8.610375202558645, 7.715485527267821, 6.80771129722851, 5.936953216859123, 5.089635857388007, 5.933106335482358, 6.799370511971068, 7.762899957778979, 8.740701496237556, 9.722189489410955, 10.611774062185123, 11.630719453047133, 12.538177898745465, 13.417757738190511, 14.391588263515949, 13.487261045153389, 12.500913884282134, 11.595073670096678, 11.56877972855533, 10.564090479136647, 9.632266352625027, 8.641255506232667, 7.848157343328153, 6.967260646717091, 6.138889606229179, 6.895435493962887, 7.824673202369745, 8.769129956024205, 9.694480076257921, 10.630687946397705, 11.542464667432798, 12.553006159885559, 13.553224603766639, 14.355353153079546, 15.414945152287688, 14.515019704961553, 13.453669198294794, 12.534477533599114, 12.499534536074213, 11.621297178735805, 10.582975243163315, 9.599188313632144, 8.90803720272439, 7.916802181305739, 7.097670537496966, 7.957851432797328, 8.806986070555041, 9.768155688677888, 10.632132315269683, 11.63447485929934, 12.580378247289776, 12.905704058007379, 13.906204013834603, 14.841634868243316, 15.527717304379475, 15.353629819155714, 14.391524540346351, 13.466038763365898, 13.477998805169863, 12.537494577311179, 11.551462803309256, 10.53137241199116, 9.923615081279696, 8.968491039490951, 8.088451635429994, 8.927807017376157, 9.750796733765823, 10.73883954354897, 11.64178194478624, 12.662545757967091, 12.898224380613383, 11.95777602395619, 12.882458119575205, 13.792456348523514, 14.567524573070257, 15.532197210826244, 15.357209753082532, 14.430249154331655, 14.503410890526089, 13.43000048338553, 12.46882445065625, 11.5319092706728, 10.857551346331338, 10.025758684866107, 9.040994619349423, 9.992829250234143, 10.766507268894662, 11.749534392387389, 12.613863822699852, 12.61761867482853, 11.904693674122823, 10.899752004783425, 11.889718081522817, 12.856927484771624, 13.605282619483017, 14.637495089860474, 15.670990080302975, 15.380140617198464, 15.494960995036454, 14.449019474161034, 13.456796554657634, 12.464600982839999, 11.825142819733223, 11.004141289540327, 10.048621207351198, 11.028719323259176, 11.761990362105688, 12.82099845608281, 12.557673277463378, 11.654163051815718, 10.876285334849284, 9.884495207294123, 10.86448647333525, 11.827948692484538, 12.638637884525716, 13.641051492892363, 14.601813265757519, 15.5799132187266], [15.495156301199765, 14.545511788080216, 13.552169452536226, 12.592377298994656, 11.704404551263568, 10.717705909607568, 9.703424006685731, 8.96690026493828, 9.750204322621348, 10.641523743977933, 11.629089580915183, 11.83816001361113, 11.137927559828078, 11.838032113492803, 12.785206564662694, 13.662464007451478, 14.35166789166047, 15.363859850809312, 16.412407091421187, 16.408680725927645, 14.539396315930881, 13.594312221577622, 12.693426937300652, 11.651979220006712, 10.716825815281412, 9.777481291137368, 8.763530802607795, 7.9665319975951405, 8.773285082193064, 9.649370041062683, 10.603475299071464, 11.533108308472729, 12.203494760208063, 12.789969393962407, 13.71217195747543, 14.718541838812941, 15.423781490326439, 16.307606641634628, 16.42691281069078, 15.479986422134761, 13.634363014162366, 12.59365639978881, 11.658595474608722, 10.660730117750829, 9.70772205399289, 8.789142844638063, 7.7399291311200455, 6.917309520021662, 7.797860772033159, 8.71619446651778, 9.756939607292896, 10.703195183316732, 11.621367327154587, 12.569951323227295, 13.542951213094062, 14.516712026649422, 15.307122374430964, 16.346455201489412, 15.617265639939784, 14.614664013139008, 12.643579096270166, 11.632247324949663, 10.648030658130615, 9.698219493758542, 8.754772157928222, 7.76549985240883, 6.782492554533169, 5.8603588574626375, 6.816531048756206, 7.762628115660188, 8.725148734489853, 9.690831478838291, 10.654462527501682, 11.661853804872495, 12.709967925842621, 13.501709207943962, 14.353456158164832, 15.291585780154382, 14.56531778071436, 13.627809940979168, 11.698555796004662, 10.666871596710667, 9.69902902265634, 8.659346321777036, 7.6951394553137575, 6.761491526605204, 5.772439881330183, 4.829703967707363, 5.8121354536066425, 6.768456683761224, 7.783921256288766, 8.760739724350497, 9.723872381186151, 10.735245467113955, 11.771963582731036, 12.540124972438877, 13.373242736993845, 14.380507880252791, 13.577047553313237, 12.63645640003285, 10.758776599514219, 9.832503074704444, 8.854767460741941, 7.826842259243266, 6.811035042544793, 5.873427982829597, 4.833168155980638, 3.9044553269221156, 4.8773681873576695, 5.790789359339226, 6.725379348197021, 7.75182542601895, 8.722512747145712, 9.693923947859869, 10.74250570594316, 11.58150354360165, 12.417514200517507, 13.33244694582082, 12.66700109544987, 11.686571131265264, 9.765574511390856, 8.818762535832274, 7.851240916608151, 6.837638830254575, 5.861366578400503, 4.845376745750395, 3.826821352165853, 2.958361380205805, 3.916517444580493, 4.855009332377782, 5.860794522562606, 6.825750285845705, 7.677202101308534, 8.723039767390448, 9.68436951141876, 10.589403734058685, 11.484680171000262, 12.397827082174258, 11.702882779740706, 10.69752884334689, 8.798368198092714, 7.807700615193957, 6.860089916288824, 5.848410399163339, 4.827653358635362, 3.859914069908389, 2.8732540113411096, 2.0118525977657047, 2.9985879693019166, 3.8383616865307197, 4.890072924131786, 5.793947337841313, 6.745107765446549, 7.739007236179877, 8.714119668881953, 9.573423263279183, 10.520747853177843, 11.452605533456367, 10.850297051567233, 9.859040739823785, 7.929303771228186, 6.93317294585588, 5.954387931759127, 4.938135361663738, 3.9113941736334032, 2.8926905404872043, 1.868619756145602, 0.943172366525121, 1.9236146596136225, 2.8752996361813663, 3.838132425659037, 4.842779848964411, 5.802443126459156, 6.744909043342588, 7.698517766332366, 8.63625717165115, 9.640905696738672, 10.584336436882715, 10.031987481718671, 8.981075649761765, 7.025003836507995, 6.082029885134109, 5.0353777777749595, 3.989568587455192, 3.0061775012991583, 2.009991244354138, 0.9354062082268462, 0.0, 0.9698016919132993, 1.9051972041572338, 2.858514796424987, 3.8413638662084373, 4.853757176041562, 5.787310020811123, 6.862054811194362, 7.928893434243914, 9.002865659777155, 10.017387800520357, 9.084065058354042, 8.096145816598089, 7.765915299519222, 6.815753550136218, 5.8347806880734465, 4.826994241601403, 3.885095761828168, 2.818868037704955, 1.8732234119410849, 0.9262692810987205, 1.9489614412080147, 2.925789864654656, 3.8078212543896015, 4.8638154885218405, 5.794963486628104, 6.741932872403488, 7.667133315806953, 8.647971260515558, 9.703625599726994, 10.642108067709827, 9.79125289169807, 8.790803506087169, 8.720488393870681, 7.785248936952712, 6.743654724552378, 5.783971951257224, 4.85069969030881, 3.8631457865816072, 2.8937356606744906, 1.9064582632098732, 2.970465301612335, 3.9167103653702275, 4.783204777915785, 5.772954582460883, 6.749366844654432, 7.723608929795733, 8.683216646419654, 9.620745099714732, 10.579043560589351, 11.563590972823166, 10.773244601675819, 9.723265717667424, 9.621660791244183, 8.608735356922445, 7.679121534202766, 6.71526926545917, 5.87048179801036, 4.87574580373414, 3.902091950045126, 2.976162704335164, 3.978279236455248, 4.949637130861314, 5.791257736917017, 6.789549347069774, 7.724295455322676, 8.722735529525611, 9.71212130628441, 10.564243639688122, 11.510356616699617, 12.480603200046373, 11.638221340790157, 10.59583326403833, 10.532988181977096, 9.571758432416482, 8.618578477474385, 7.688192648677954, 6.805677481447416, 5.83690844527335, 4.951665586820507, 3.9881367045144342, 4.930978699403015, 5.908107498985076, 6.833456519462018, 7.837182333648078, 8.717366179214936, 9.680191396162577, 10.650919302681606, 11.501770429047982, 12.476495808207451, 13.469053312914244, 12.467064479053393, 11.524370888123547, 11.478837449524367, 10.541329702017423, 9.54578141078549, 8.650891735494668, 7.743117505455356, 6.8723594250859685, 6.025042065614854, 4.997700127255512, 5.863964303744222, 6.827493749552133, 7.80529528801071, 8.786783281184109, 9.676367853958276, 10.695313244820285, 11.602771690518619, 12.482351529963664, 13.456182055289101, 14.398671471314273, 13.43632009250898, 12.530479878323522, 12.504185936782175, 11.499496687363493, 10.567672560851875, 9.576661714459515, 8.783563551554998, 7.902666854943937, 6.942650655157733, 5.960029285736041, 6.889266994142899, 7.83372374779736, 8.759073868031077, 9.695281738170861, 10.60705845920595, 11.617599951658711, 12.617818395539793, 13.419946944852699, 14.47953894406084, 15.450425913188397, 14.389075406521638, 13.469883741825958, 13.434940744301057, 12.556703386962653, 11.518381451390162, 10.534594521858992, 9.843443410951236, 8.852208389532585, 7.90143158642552, 7.0224452245704825, 7.871579862328195, 8.832749480451044, 9.696726107042839, 10.699068651072496, 11.644972039062928, 12.648792955189805, 13.65096871533826, 14.411668821979323, 15.416532427293959, 16.289036027382558, 15.326930748573195, 14.401444971592742, 14.413405013396707, 13.472900785538027, 12.486869011536104, 11.466778620218008, 10.80363791401684, 9.848513872228095, 8.89221268435855, 7.992400809149311, 8.815390525538977, 9.803433335322124, 10.706375736559396, 11.727139549740247, 11.991762090507397, 12.770037476117261, 13.694719571736275, 14.675031544833764, 15.457402014249809, 16.422074652005797, 16.292615961309377, 15.365655362558499, 15.438817098752937, 14.365406691612378, 13.404230658883098, 12.467315478899648, 11.737574179068481, 10.899088881089552, 9.844755668277976, 9.057423042007297, 9.831101060667816, 10.814128184160543, 11.678457614473007, 11.700066023006032, 10.996929100297912, 11.712013456944495, 12.701979533683888, 13.739502681081875, 14.495160060662569, 15.527372531040026, 16.56086752148253, 16.315546825425308, 16.4303672032633, 15.384425682387882, 14.392202762884482, 13.400007191066846, 12.705165652470367, 11.80790233846888, 10.852382256279752, 10.09331311503233, 10.826584153878843, 11.885592247855964, 11.640120625640881, 10.736610399993221, 9.968520761024372, 10.696756659455193, 11.67674792549632, 12.71782613366409, 13.528515325705268, 14.530928934071914, 15.49169070693707, 16.469790659906153], [16.464957993113064, 15.515313479993512, 14.521971144449523, 13.562178990907952, 12.674206243176865, 11.687507601520867, 10.67322569859903, 9.929185626927426, 8.91898959338011, 9.711544958470913, 10.699110795408163, 10.889565512933682, 11.853508185574077, 12.78609800162114, 13.73327245279103, 14.610529895579813, 15.32146958357377, 16.33366154272261, 17.382208783334484, 17.378482417840946, 15.509198007844182, 14.564113913490923, 13.66322862921395, 12.621780911920009, 11.686627507194709, 10.747282983050665, 9.733332494521093, 8.928817359584286, 7.942070352951825, 8.719391255555664, 9.673496513564444, 10.603129522965709, 11.641853540938435, 12.622267878790662, 13.592380478428, 14.597885959364332, 15.319266100127408, 16.346931780151127, 17.297745492497718, 16.44978811404806, 14.604164706075666, 13.56345809170211, 12.62839716652202, 11.630531809664127, 10.677523745906187, 9.75894453655136, 8.709730823033343, 7.88711121193496, 6.96664604279192, 7.786215681010761, 8.822110772114316, 9.733393491403431, 10.651565635241287, 11.600149631313995, 12.573149521180762, 13.546910334736122, 14.337320682517664, 15.376653509576112, 16.305701995030965, 15.584465705052308, 13.613380788183466, 12.602049016862962, 11.617832350043914, 10.66802118567184, 9.72457384984152, 8.735301544322128, 7.752294246446468, 6.830160549375936, 5.985316319514967, 6.832649330153169, 7.7553470425765525, 8.72102978692499, 9.684660835588382, 10.692052112959194, 11.74016623392932, 12.531907516030662, 13.383654466251532, 14.321784088241081, 15.25375413580554, 14.597611632892468, 12.668357487917962, 11.636673288623966, 10.668830714569639, 9.629148013690335, 8.664941147227056, 7.731293218518503, 6.742241573243482, 5.799505659620662, 4.9636718685726855, 5.798654991847925, 6.814119564375466, 7.790938032437197, 8.75407068927285, 9.765443775200655, 10.802161890817736, 11.570323280525576, 12.403441045080545, 13.410706188339491, 14.23376917692893, 13.60625809194615, 11.72857829142752, 10.802304766617745, 9.82456915265524, 8.796643951156565, 7.7808367344580915, 6.843229674742895, 5.802969847893937, 4.874257018835415, 3.9534531996705775, 4.820987667425927, 5.755577656283721, 6.782023734105651, 7.752711055232412, 8.724122255946568, 9.772704014029859, 10.61170185168835, 11.447712508604207, 12.36264525390752, 13.299210464404922, 12.656372823178565, 10.735376203304156, 9.788564227745574, 8.82104260852145, 7.807440522167875, 6.831168270313802, 5.815178437663694, 4.796623044079153, 3.9281630721191045, 2.9706021676168817, 3.8852076404644826, 4.8909928306493065, 5.855948593932405, 6.707400409395234, 7.753238075477148, 8.71456781950546, 9.619602042145385, 10.514878479086962, 11.428025390260958, 12.39348602469455, 11.66733053526019, 9.768169890006014, 8.777502307107257, 7.829891608202123, 6.818212091076639, 5.7974550505486615, 4.829715761821689, 3.843055703254409, 2.981654289679004, 2.028786277388617, 2.8685599946174203, 3.920271232218487, 4.824145645928014, 5.775306073533248, 6.769205544266578, 7.744317976968653, 8.603621571365883, 9.550946161264543, 10.482803841543067, 11.508059361551433, 10.828842431737085, 8.899105463141485, 7.902974637769179, 6.924189623672427, 5.9079370535770375, 4.881195865546703, 3.8624922324005033, 2.838421448058901, 1.9129740584384205, 0.9538129677003232, 1.9054979442680668, 2.8683307337457373, 3.8729781570511115, 4.832641434545856, 5.7751073514292885, 6.728716074419067, 7.66645547973785, 8.671104004825372, 9.614534744969415, 10.651503682341357, 9.950877341675064, 7.994805528421295, 7.051831577047408, 6.005179469688259, 4.959370279368491, 3.9759791932124577, 2.9797929362674376, 1.9052079001401454, 0.9698016919132993, 0.0, 0.9353955122439345, 1.8887131045116874, 2.871562174295138, 3.883955484128262, 4.817508328897824, 5.892253119281062, 6.959091742330614, 8.033063967863855, 9.047586108607057, 10.00250302575018, 9.065947508511387, 8.735716991432522, 7.785555242049517, 6.804582379986745, 5.7967959335147015, 4.854897453741467, 3.7886697296182543, 2.843025103854384, 1.8960709730120198, 0.9791597492947155, 1.9559881727413564, 2.838019562476302, 3.894013796608541, 4.825161794714805, 5.772131180490189, 6.697331623893653, 7.678169568602259, 8.733823907813695, 9.672306375796529, 10.669973489170781, 9.76060519800047, 9.690290085783982, 8.75505062886601, 7.713456416465678, 6.753773643170524, 5.820501382222109, 4.832947478494907, 3.86353735258779, 2.8762599551231722, 2.021870800934887, 2.946908673456928, 3.8134030860024852, 4.803152890547584, 5.7795651527411325, 6.753807237882434, 7.713414954506354, 8.650943407801433, 9.609241868676053, 10.593789280909867, 11.617370052313879, 10.693067409580724, 10.591462483157484, 9.578537048835745, 8.648923226116066, 7.68507095737247, 6.84028348992366, 5.84554749564744, 4.871893641958426, 3.9459643962484625, 3.0296847357778, 4.0003903208118015, 4.821456045003718, 5.819747655156474, 6.754493763409377, 7.752933837612311, 8.742319614371109, 9.594441947774824, 10.540554924786319, 11.510801508133074, 12.4757875747493, 11.56563495595163, 11.502789873890396, 10.541560124329783, 9.588380169387685, 8.657994340591253, 7.775479173360717, 6.80671013718665, 5.9214672787338065, 4.957938396427733, 3.9823841987255673, 4.959512998307628, 5.86365482754872, 6.867380641734779, 7.747564487301637, 8.710389704249279, 9.681117610768306, 10.531968737134683, 11.506694116294153, 12.499251621000946, 13.436866170966693, 12.494172580036848, 12.448639141437667, 11.511131393930723, 10.515583102698791, 9.620693427407966, 8.712919197368656, 7.842161116999269, 6.9948437575281535, 5.9675018191688105, 4.915369803066774, 5.878899248874685, 6.835493596097411, 7.816981589270809, 8.706566162044975, 9.725511552906985, 10.632969998605319, 11.512549838050365, 12.486380363375805, 13.428869779400976, 14.40612178442228, 13.500281570236822, 13.473987628695475, 12.469298379276793, 11.537474252765174, 10.546463406372814, 9.753365243468298, 8.872468546857238, 7.890716543286067, 6.908095173864375, 5.940672493465451, 6.885129247119912, 7.790979878067501, 8.727187748207285, 9.63725676729265, 10.64779825974541, 11.648016703626492, 12.4501452529394, 13.509737252147543, 14.50026498868152, 15.358877098434938, 14.439685433739259, 14.404742436214358, 13.52650507887595, 12.488183143303461, 11.50439621377229, 10.813245102864537, 9.822010081445885, 8.849497474553855, 7.87740656256702, 6.922985361650747, 7.884154979773596, 8.728632117079261, 9.73097466110892, 10.675170347149628, 11.678991263276504, 12.68116702342496, 13.441867130066024, 14.446730735380658, 15.51906868853759, 16.296732440486494, 15.371246663506042, 15.383206705310007, 14.442702477451325, 13.456670703449403, 12.436580312131307, 11.751703802145174, 10.79657976035643, 9.840278572486884, 8.847362147145848, 7.866796024861529, 8.854838834644676, 9.738281746595819, 10.75904555977667, 11.687614777239265, 12.626919297327692, 13.633292284494063, 14.491045649785827, 15.406923466689877, 16.371596104445864, 17.262417653222677, 16.3354570544718, 16.40861879066624, 15.335208383525678, 14.374032350796398, 13.437117170812947, 12.685640067196816, 11.84715476921789, 10.792821556406313, 9.868650949965689, 8.882506559990368, 9.865533683483095, 10.71036362450943, 10.868851293764793, 11.911269669915292, 12.681815148857794, 13.671781225597186, 14.709304372995174, 15.464961752575865, 16.497174222953323, 17.530669213395825, 17.28534851733861, 17.400168895176602, 16.354227374301182, 15.36200445479778, 14.369808882980145, 13.653231540598702, 12.755968226597217, 11.800448144408088, 10.836901202360263, 9.877989653201395, 10.936997747178516, 10.710141840133861, 9.905395670751982, 10.930806123013518, 11.666558351368492, 12.646549617409619, 13.687627825577387, 14.498317017618565, 15.500730625985211, 16.461492398850368, 17.43959235181945], [17.33713382751294, 16.387489314393388, 15.394146978849399, 14.434354825307828, 13.546382077576741, 12.559683435920743, 11.545401532998905, 10.7661886994604, 9.755992665913084, 8.77614944622698, 9.76371528316423, 10.610016906347829, 11.573959578988223, 12.563952477630325, 13.520552008484902, 14.491587835741564, 15.45598418654944, 16.355283058732507, 17.29514611177645, 18.083633285676115, 16.38137384224406, 15.436289747890799, 14.535404463613826, 13.493956746319885, 12.558803341594585, 11.61945881745054, 10.605508328920969, 9.76582043211726, 8.7790734254848, 7.7839957433117295, 8.73810100132051, 9.667734010721775, 10.7064580286945, 11.686872366546726, 12.656984966184066, 13.662490447120398, 14.383870587883472, 15.411536267907191, 16.362349980253782, 17.15493898188323, 15.476340540475542, 14.435633926101985, 13.500573000921896, 12.502707644064003, 11.549699580306063, 10.631120370951235, 9.581906657433219, 8.759287046334837, 7.803649115324895, 6.850820168766827, 7.886715259870382, 8.797997979159497, 9.716170122997353, 10.66475411907006, 11.637754008936827, 12.611514822492188, 13.401925170273728, 14.441257997332176, 15.37030648278703, 16.21717243107154, 14.485556622583342, 13.474224851262838, 12.49000818444379, 11.540197020071716, 10.596749684241395, 9.607477378722006, 8.624470080846343, 7.702336383775812, 6.843350884813217, 5.897253817909235, 6.819951530332618, 7.7856342746810565, 8.749265323344448, 9.75665660071526, 10.804770721685387, 11.596512003786728, 12.448258954007596, 13.386388575997145, 14.318358623561604, 15.230318358911699, 13.540533322317838, 12.508849123023841, 11.541006548969515, 10.50132384809021, 9.537116981626932, 8.60346905291838, 7.614417407643358, 6.671681494020538, 5.835252543100095, 4.8632594796039905, 5.878724052131532, 6.8555425201932625, 7.818675177028917, 8.830048262956721, 9.866766378573802, 10.634927768281642, 11.468045532836609, 12.475310676095555, 13.298373664684995, 14.238964817965382, 12.663973803671453, 11.737700278861679, 10.759964664899176, 9.7320394634005, 8.716232246702026, 7.7786251869868295, 6.7383653601378715, 5.746432853235291, 4.825033874197987, 3.8855921551819925, 4.820182144039787, 5.8466282218617165, 6.817315542988478, 7.788726743702634, 8.837308501785925, 9.676306339444416, 10.512316996360271, 11.427249741663584, 12.363814952160986, 13.415264597435549, 11.67077171554809, 10.723959739989509, 9.756438120765385, 8.742836034411809, 7.7665637825577365, 6.750573949907628, 5.732018556323087, 4.80033890651898, 3.8421828421442914, 2.9498121282205485, 3.9555973184053723, 4.920553081688471, 5.7720048971513, 6.817842563233214, 7.7791723072615255, 8.68420652990145, 9.579482966843026, 10.492629878017022, 11.458090512450614, 12.463444448844431, 10.703565402249948, 9.712897819351191, 8.765287120446057, 7.753607603320573, 6.732850562792596, 5.765111274065623, 4.778451215498343, 3.9170498019229383, 2.900366951916027, 1.933164482373486, 2.9848757199745526, 3.8887501336840793, 4.839910561289314, 5.833810032022644, 6.808922464724719, 7.668226059121948, 8.615550649020607, 9.547408329299131, 10.572663849307498, 11.563920161050946, 9.834500975385419, 8.838370150013112, 7.859585135916361, 6.843332565820972, 5.816591377790637, 4.797887744644438, 3.7738169603028355, 2.8483695706823546, 1.8892084799442577, 0.9701024320241325, 1.9329352215018027, 2.937582644807177, 3.897245922301922, 4.839711839185354, 5.793320562175133, 6.731059967493916, 7.735708492581438, 8.679139232725483, 9.716108170097424, 10.775438913721533, 8.93020104066523, 7.987227089291343, 6.940574981932194, 5.894765791612426, 4.911374705456392, 3.915188448511372, 2.84060341238408, 1.9051972041572338, 0.9353955122439345, 0.0, 0.953317592267753, 1.9361666620512035, 2.948559971884328, 3.8821128166538896, 4.9568576070371275, 6.02369623008668, 7.097668455619921, 8.112190596363122, 9.067107513506246, 10.001343020755323, 9.671112503676456, 8.720950754293451, 7.739977892230679, 6.732191445758636, 5.790292965985401, 4.7240652418621885, 3.7784206160983187, 2.8314664852559543, 1.9145552615386499, 1.0228336746588853, 1.9026240502323675, 2.9586182843646065, 3.8897662824708705, 4.836735668246255, 5.761936111649719, 6.742774056358325, 7.79842839556976, 8.736910863552595, 9.734577976926847, 10.696000710244403, 10.625685598027916, 9.690446141109945, 8.648851928709613, 7.689169155414458, 6.755896894466043, 5.768342990738841, 4.798932864831724, 3.811655467367107, 2.9572663131788213, 2.013754175374457, 2.8780075737585507, 3.8677573783036494, 4.844169640497198, 5.8184117256385, 6.77801944226242, 7.715547895557499, 8.673846356432119, 9.658393768665933, 10.681974540069945, 11.628462921824658, 11.526857995401418, 10.51393256107968, 9.58431873836, 8.620466469616403, 7.775679002167594, 6.780943007891374, 5.80728915420236, 4.8813599084923975, 3.965080248021734, 3.0672358227293297, 3.886060532759783, 4.88435214291254, 5.8190982511654425, 6.817538325368377, 7.806924102127175, 8.65904643553089, 9.605159412542385, 10.57540599588914, 11.540392062505365, 12.501030468195564, 12.43818538613433, 11.476955636573717, 10.52377568163162, 9.593389852835186, 8.71087468560465, 7.742105649430584, 6.856862790977741, 5.893333908671668, 4.917779710969501, 4.138045454664611, 4.928259315304785, 5.931985129490845, 6.812168975057703, 7.774994192005344, 8.745722098524372, 9.596573224890749, 10.571298604050218, 11.563856108757012, 12.548092842958988, 13.429568092280782, 13.384034653681603, 12.446526906174658, 11.450978614942725, 10.556088939651898, 9.64831470961259, 8.777556629243204, 7.930239269772088, 6.9028973314127455, 5.850765315310708, 5.073147974286109, 5.900098083853476, 6.881586077026875, 7.771170649801041, 8.790116040663051, 9.697574486361384, 10.577154325806431, 11.550984851131869, 12.49347426715704, 13.479821428028295, 14.435677082480758, 14.409383140939411, 13.404693891520727, 12.472869765009106, 11.481858918616746, 10.688760755712233, 9.807864059101172, 8.826112055530002, 7.843490686108309, 6.876068005709385, 6.080654185040094, 6.855584365823566, 7.791792235963349, 8.701861255048716, 9.712402747501477, 10.712621191382558, 11.514749740695466, 12.574341739903607, 13.564869476437584, 14.432576742040954, 15.36671680628727, 15.340137948458294, 14.461900591119882, 13.423578655547393, 12.439791726016223, 11.74864061510847, 10.75740559368982, 9.78489298679779, 8.812802074810955, 7.858380873894681, 7.079679917693778, 7.793236604835327, 8.795579148864984, 9.739774834905694, 10.74359575103257, 11.745771511181026, 12.50647161782209, 13.511335223136726, 14.583673176293654, 15.446886212216292, 16.298278036054054, 16.318602217553945, 15.378097989695258, 14.392066215693335, 13.37197582437524, 12.687099314389108, 11.731975272600364, 10.775674084730818, 9.782757659389784, 8.802191537105463, 8.11114547838053, 8.802886234351885, 9.823650047532738, 10.752219264995333, 11.691523785083758, 12.697896772250129, 13.555650137541893, 14.471527954445945, 15.436200592201931, 16.39700404314487, 17.26248842701981, 17.34401430291017, 16.27060389576961, 15.30942786304033, 14.372512683056879, 13.62103557944075, 12.782550281461821, 11.728217068650245, 10.804046462209623, 9.817902072234302, 9.152998092715812, 9.774968112265496, 10.759743914446691, 11.747052255204817, 12.749547804256524, 13.690636810302516, 14.491179001293782, 15.433769908033184, 16.414373418086537, 17.456463171760827, 18.21237988988662, 18.335564407420534, 17.289622886545114, 16.297399967041713, 15.305204395224077, 14.588627052842636, 13.691363738841149, 12.73584365665202, 11.772296714604199, 10.813385165445329, 10.224462156411233, 9.774746327889927, 10.731700587814778, 11.76780919554649, 12.538734185768368, 13.518725451809495, 14.559803659977263, 15.37049285201844, 16.37290646038509, 17.333668233250243, 18.311768186219325], [18.114611143816795, 17.340806906661143, 16.347464571117154, 15.387672417575583, 14.499699669844496, 13.513001028188498, 12.49871912526666, 11.719506291728154, 10.709310258180837, 9.729467038494732, 9.097789266598385, 9.862072880453578, 10.826015553093972, 11.73087452790989, 12.67601523989036, 13.647051067147022, 14.502666594281688, 15.401965466464754, 16.341828519508695, 17.13031569340836, 17.142211495819357, 16.38960734015855, 15.48872205588158, 14.44727433858764, 13.51212093386234, 12.572776409718296, 11.558825921188724, 10.719138024385014, 9.732391017752553, 8.737313335579483, 8.059652995633627, 8.919789984827524, 9.829794919547943, 10.778937247440286, 11.749049847077623, 12.709172854852644, 13.43055299561572, 14.45821867563944, 15.409032387986027, 16.201621389615475, 16.20156497661374, 15.388951518369737, 14.45389059318965, 13.456025236331756, 12.503017172573818, 11.58443796321899, 10.535224249700974, 9.71260463860259, 8.756966707592648, 7.80413776103458, 7.08447714288131, 7.982290538898206, 8.80823500389091, 9.756818999963619, 10.729818889830385, 11.658197230224435, 12.448607578005976, 13.487940405064425, 14.416988890519276, 15.263854838803786, 15.16857112999132, 14.42754244353059, 13.443325776711543, 12.49351461233947, 11.55006727650915, 10.560794970989758, 9.577787673114099, 8.655653976043565, 7.796668477080971, 6.850571410176988, 6.017713413343547, 6.9699268344197645, 7.841330204238005, 8.803339008447507, 9.851453129417633, 10.643194411518975, 11.494941361739844, 12.433070983729394, 13.36504103129385, 14.277000766643946, 14.223547829725817, 13.462166715291595, 12.494324141237268, 11.454641440357964, 10.490434573894685, 9.556786645186133, 8.567734999911112, 7.624999086288291, 6.7885701353678485, 5.816577071871744, 5.076485935142459, 6.03983507993197, 6.865357584761163, 7.876730670688968, 8.91344878630605, 9.681610176013889, 10.514727940568857, 11.521993083827802, 12.345056072417242, 13.285647225697629, 13.392575115878715, 12.691017871129432, 11.713282257166927, 10.685357055668252, 9.669549838969779, 8.731942779254583, 7.691682952405625, 6.699750445503044, 5.7783514664657405, 4.838909747449746, 4.0179440270507145, 5.017791503879042, 5.863997950720725, 6.835409151434881, 7.883990909518173, 8.722988747176663, 9.55899940409252, 10.47393214939583, 11.410497359893233, 12.461947005167797, 12.442081188532713, 11.677277332257262, 10.709755713033138, 9.69615362667956, 8.719881374825489, 7.7038915421753815, 6.6853361485908405, 5.753656498786733, 4.795500434412045, 3.9031297204883018, 3.0692766698290157, 3.9672354894207174, 4.818687304883547, 5.86452497096546, 6.825854714993772, 7.730888937633697, 8.626165374575274, 9.539312285749268, 10.504772920182862, 11.51012685657668, 11.656882994517701, 10.666215411618944, 9.71860471271381, 8.706925195588326, 7.686168155060349, 6.718428866333376, 5.731768807766096, 4.8703673941906915, 3.85368454418378, 2.886482074641239, 2.0315581277067998, 2.935432541416326, 3.886592969021561, 4.8804924397548906, 5.855604872456966, 6.714908466854195, 7.6622330567528545, 8.594090737031378, 9.619346257039744, 10.610602568783193, 10.787818567653172, 9.791687742280866, 8.812902728184113, 7.796650158088725, 6.76990897005839, 5.751205336912191, 4.727134552570589, 3.801687162950108, 2.8425260722120105, 1.9234200242918855, 0.9796176292340498, 1.9842650525394239, 2.9439283300341685, 3.886394246917601, 4.840002969907379, 5.777742375226163, 6.782390900313684, 7.7258216404577285, 8.76279057782967, 9.822121321453778, 9.883518632932983, 8.940544681559096, 7.893892574199947, 6.848083383880179, 5.864692297724146, 4.868506040779125, 3.793921004651833, 2.858514796424987, 1.8887131045116874, 0.953317592267753, 0.0, 0.9828490697834504, 1.9952423796165748, 2.9287952243861364, 4.003540014769374, 5.070378637818926, 6.144350863352168, 7.158873004095369, 8.113789921238492, 9.101709162994446, 10.62443009594421, 9.674268346561204, 8.693295484498432, 7.685509038026389, 6.743610558253154, 5.677382834129941, 4.731738208366071, 3.7847840775237076, 2.8678728538064027, 1.9761512669266383, 0.9493064579646145, 2.0053006920968537, 2.9364486902031177, 3.8834180759785024, 4.808618519381967, 5.789456464090572, 6.845110803302007, 7.7835932712848415, 8.781260384659094, 9.781709770269995, 11.57900319029567, 10.643763733377698, 9.602169520977364, 8.64248674768221, 7.709214486733796, 6.721660583006593, 5.752250457099477, 4.76497305963486, 3.910583905446574, 2.9209841978147786, 1.9246899814907978, 2.9144397860358966, 3.890852048229445, 4.865094133370747, 5.824701849994668, 6.762230303289746, 7.720528764164365, 8.70507617639818, 9.728656947802191, 10.71417198185025, 12.48017558766917, 11.46725015334743, 10.537636330627752, 9.573784061884155, 8.728996594435346, 7.734260600159126, 6.760606746470112, 5.834677500760151, 4.9183978402894875, 3.9744658451696515, 2.93274294049203, 3.931034550644787, 4.865780658897689, 5.864220733100624, 6.853606509859423, 7.7057288432631355, 8.65184182027463, 9.622088403621385, 10.58707447023761, 11.629462546989437, 13.391502978402082, 12.430273228841468, 11.47709327389937, 10.546707445102937, 9.664192277872402, 8.695423241698336, 7.810180383245492, 6.846651500939421, 5.871097303237255, 4.958361092297167, 3.974941723037032, 4.9786675372230915, 5.8588513827899495, 6.82167659973759, 7.79240450625662, 8.643255632622996, 9.617981011782463, 10.610538516489257, 11.594775250691233, 12.537468841621079, 14.337352245949354, 13.399844498442409, 12.404296207210477, 11.50940653191965, 10.601632301880342, 9.730874221510955, 8.883556862039839, 7.856214923680499, 6.8040829075784615, 5.893463611918666, 4.946780491585724, 5.928268484759122, 6.817853057533288, 7.836798448395297, 8.744256894093633, 9.623836733538678, 10.597667258864114, 11.540156674889285, 12.52650383576054, 13.575750994022258, 15.362700733207163, 14.358011483788479, 13.426187357276858, 12.435176510884498, 11.642078347979984, 10.761181651368924, 9.722117697264608, 8.739496327842915, 7.772073647443991, 6.827616893789529, 5.902266773555813, 6.838474643695597, 7.748543662780962, 8.759085155233723, 9.759303599114807, 10.561432148427713, 11.621024147635852, 12.61155188416983, 13.479259149773199, 14.413399214019515, 16.293455540726047, 15.415218183387633, 14.376896247815145, 13.393109318283974, 12.659549384756673, 11.660592905255847, 10.680898628532395, 9.70880771654556, 8.754386515629287, 7.826642626443213, 6.839919012567574, 7.842261556597232, 8.78645724263794, 9.790278158764817, 10.792453918913274, 11.553154025554337, 12.55801763086897, 13.6303555840259, 14.493568619948537, 15.344960443786299, 17.262913252255466, 16.33141558196301, 15.345383807961086, 14.32529341664299, 13.583104956123714, 12.62798091433497, 11.671679726465424, 10.67876330112439, 9.698197178840068, 8.780727009886016, 7.849568642084131, 8.870332455264982, 9.798901672727578, 10.738206192816005, 11.744579179982376, 12.60233254527414, 13.51821036217819, 14.482882999934176, 15.443686450877117, 16.309170834752056, 18.223251665507586, 17.223921488037362, 16.26274545530808, 15.32583027532463, 14.517041221175356, 13.678555923196429, 12.624222710384853, 11.700052103944229, 10.713907713968908, 9.758982098704085, 8.821650519997743, 9.806426322178936, 10.793734662937062, 11.796230211988771, 12.737319218034763, 13.537861409026029, 14.48045231576543, 15.461055825818782, 16.503145579493072, 17.259062297618865, 18.136046536409307, 17.399800744045187, 16.44652286669295, 15.454327294875313, 14.604349422128132, 13.653319466084174, 12.716524385122941, 11.832560289344734, 10.873648740185866, 10.131688542760442, 9.766233668874749, 10.7231879287996, 11.77061250845509, 12.76240263601025, 13.747424310060389, 14.566840201313115, 15.44709705072273, 16.449510659089377, 17.462001499746307, 18.282419045468657], [17.131762074033343, 17.36143053251732, 16.368088196973332, 15.40829604343176, 14.605322749712053, 13.746653808109501, 12.829880628245954, 11.884968659058487, 11.10373091979091, 10.712316108278182, 9.904710195410097, 8.879223810670128, 9.843166483310522, 10.748025458126438, 11.69316617010691, 12.664201997363572, 13.519817524498237, 14.419116396681304, 15.358979449725243, 16.147466623624908, 16.159362426035905, 17.104446520389164, 16.47157112566503, 15.430123408371088, 14.494970003645788, 13.555625479501744, 12.541674990972172, 11.701987094168464, 10.715240087536003, 9.720162405362933, 8.866573924445339, 7.936940915044074, 8.846945849764493, 9.796088177656834, 10.766200777294173, 11.726323785069194, 12.447703925832268, 13.47536960585599, 14.426183318202577, 15.218772319832025, 15.218715906830287, 16.185539287744994, 15.4367396629731, 14.438874306115206, 13.485866242357266, 12.567287033002438, 11.518073319484422, 10.69545370838604, 9.739815777376098, 8.78698683081803, 7.961180956054374, 6.999441469114755, 7.8253859341074605, 8.773969930180169, 9.746969820046935, 10.675348160440985, 11.465758508222525, 12.505091335280975, 13.434139820735826, 14.281005769020336, 14.18572206020787, 15.224130212905848, 14.426174846494993, 13.47636368212292, 12.532916346292598, 11.54364404077321, 10.560636742897547, 9.638503045827015, 8.77951754686442, 7.833420479960438, 6.894417226516611, 5.987077764636314, 6.858481134454555, 7.820489938664057, 8.868604059634183, 9.660345341735525, 10.512092291956394, 11.450221913945944, 12.3821919615104, 13.294151696860496, 13.240698759942367, 14.272382959236364, 13.477173211020718, 12.437490510141414, 11.473283643678135, 10.539635714969583, 9.550584069694562, 8.607848156071741, 7.7714192051512985, 6.799426141655194, 5.953189748315523, 5.05698601014852, 5.882508514977713, 6.893881600905518, 7.9305997165226, 8.698761106230439, 9.531878870785407, 10.539144014044352, 11.362207002633792, 12.302798155914179, 12.409726046095264, 13.364932047591994, 12.696131326950379, 11.668206125451704, 10.652398908753229, 9.714791849038033, 8.674532022189075, 7.682599515286494, 6.7612005362491905, 5.821758817233196, 4.8946478402237785, 4.0349424340955915, 4.881148880937275, 5.852560081651431, 6.901141839734723, 7.740139677393212, 8.57615033430907, 9.49108307961238, 10.427648290109783, 11.479097935384345, 11.459232118749261, 12.43481761493105, 11.692604782816588, 10.679002696463012, 9.70273044460894, 8.686740611958832, 7.6681852183742905, 6.736505568570183, 5.778349504195495, 4.885978790271752, 3.9459804830020793, 2.984386419637267, 3.8358382351000966, 4.88167590118201, 5.843005645210322, 6.748039867850247, 7.643316304791823, 8.556463215965818, 9.52192385039941, 10.527277786793228, 10.688426040730814, 11.649064481402394, 10.70145378249726, 9.689774265371776, 8.669017224843799, 7.701277936116827, 6.714617877549547, 5.8532164639741415, 4.83653361396723, 3.8693311444246894, 2.9082619408798633, 1.9525834716328756, 2.903743899238111, 3.8976433699714397, 4.872755802673516, 5.732059397070745, 6.6793839869694045, 7.611241667247929, 8.636497187256294, 9.627753498999743, 9.891044130203907, 10.774536812064317, 9.795751797967565, 8.779499227872176, 7.752758039841841, 6.734054406695642, 5.70998362235404, 4.784536232733558, 3.825375141995461, 2.906269094075336, 1.9624666990175004, 1.0014159827559734, 1.9610792602507183, 2.9035451771341507, 3.8571539001239294, 4.794893305442713, 5.799541830530234, 6.7429725706742785, 7.779941508046219, 8.839272251670328, 9.19000207330109, 9.923393751342546, 8.876741643983397, 7.830932453663629, 6.847541367507596, 5.851355110562576, 4.776770074435284, 3.8413638662084373, 2.871562174295138, 1.9361666620512035, 0.9828490697834504, 0.0, 1.0123933098331244, 1.945946154602686, 3.0206909449859243, 4.087529568035476, 5.161501793568718, 6.176023934311919, 7.130940851455041, 8.118860093210996, 9.831658942836363, 10.657117416344656, 9.676144554281883, 8.66835810780984, 7.726459628036606, 6.660231903913393, 5.714587278149523, 4.767633147307158, 3.8507219235898535, 2.9590003367100888, 1.932155527748065, 1.0303616580952728, 1.9615096562015366, 2.9084790419769213, 3.8336794853803857, 4.814517430088991, 5.870171769300426, 6.80865423728326, 7.806321350657513, 8.806770736268415, 10.773545100911665, 11.62661280316115, 10.585018590760816, 9.625335817465661, 8.692063556517247, 7.704509652790045, 6.735099526882928, 5.74782212941831, 4.893432975230025, 3.903833267598229, 2.9075390512742483, 2.0558622412999368, 2.915913014227864, 3.890155099369166, 4.849762815993087, 5.787291269288165, 6.745589730162784, 7.7301371423965985, 8.75371791380061, 9.73923294784867, 11.628695985782002, 12.450099223130882, 11.520485400411204, 10.556633131667606, 9.711845664218798, 8.717109669942577, 7.743455816253563, 6.817526570543601, 5.901246910072938, 4.957314914953102, 3.9155920102754806, 3.0978802106301826, 3.890841624896108, 4.889281699099043, 5.878667475857842, 6.730789809261554, 7.676902786273049, 8.647149369619804, 9.612135436236029, 10.654523512987856, 12.55391251376595, 13.41312229862492, 12.459942343682822, 11.529556514886389, 10.647041347655854, 9.678272311481786, 8.793029453028943, 7.829500570722871, 6.8539463730207055, 5.941210162080618, 4.957790792820482, 4.145513197208487, 4.883912348788368, 5.846737565736009, 6.817465472255039, 7.668316598621414, 8.643041977780882, 9.635599482487676, 10.619836216689652, 11.562529807619498, 13.499761781313222, 14.38269356822586, 13.387145276993929, 12.492255601703102, 11.584481371663793, 10.713723291294404, 9.866405931823289, 8.839063993463949, 7.786931977361912, 6.8763126817021165, 5.929629561369174, 5.095114144744517, 5.842914023531707, 6.861859414393716, 7.769317860092052, 8.648897699537095, 9.622728224862534, 10.565217640887706, 11.55156480175896, 12.600811960020678, 14.404157985061719, 15.34086055357193, 14.40903642706031, 13.41802558066795, 12.624927417763436, 11.744030721152372, 10.704966767048058, 9.722345397626365, 8.75492271722744, 7.810465963572979, 6.885115843339263, 6.1425351832670465, 6.773604628779381, 7.784146121232142, 8.784364565113226, 9.58649311442613, 10.646085113634273, 11.63661285016825, 12.50432011577162, 13.438460180017936, 15.334912792580601, 16.364415327022815, 15.359745317598597, 14.375958388067426, 13.642398454540123, 12.643441975039297, 11.663747698315845, 10.69165678632901, 9.737235585412737, 8.809491696226663, 7.822768082351024, 7.1463220961686815, 7.811518208636359, 8.815339124763236, 9.817514884911693, 10.578214991552754, 11.583078596867388, 12.65541655002432, 13.518629585946957, 14.37002140978472, 16.287974218253886, 17.23484750365202, 16.328232877744536, 15.308142486426442, 14.565954025907164, 13.61082998411842, 12.654528796248874, 11.66161237090784, 10.681046248623518, 9.763576079669466, 8.832417711867581, 8.217775352492273, 8.86010683348937, 9.763267158814424, 10.769640145980794, 11.627393511272556, 12.543271328176607, 13.507943965932593, 14.468747416875534, 15.334231800750477, 17.248312631506007, 17.30226114997179, 16.34108511724251, 15.40416993725906, 14.589091825746568, 13.739960567559834, 12.741301903341265, 11.872427153588763, 10.886282763613442, 10.741831168487534, 9.804499589781193, 9.153869219406227, 9.854939823698855, 10.82129117798719, 11.762380184033182, 12.562922375024446, 13.505513281763847, 14.4861167918172, 15.528206545491487, 16.284123263617285, 17.153197466625855, 16.416951674261735, 15.463673796909497, 14.471478225091861, 13.621500352344682, 12.670470396300724, 11.73367531533949, 10.849711219561286, 9.890799670402416, 10.938609471572153, 10.749082738658199, 10.117324842419038, 10.883348162972394, 11.836547975476492, 12.78761179222075, 13.591901167311532, 14.472158016721147, 15.474571625087794, 16.487062465744724, 17.307480011467078], [16.119368764200217, 16.42787749201645, 15.434535156472462, 14.474743002930891, 13.671769709211185, 12.813100767608631, 11.896327587745084, 10.951415618557615, 11.741078577749732, 11.558171378721557, 10.738899513582377, 9.713413128842408, 8.964770014423463, 9.800282422405424, 10.745423134385895, 11.716458961642557, 12.507424214665114, 13.40672308684818, 14.34658613989212, 15.135073313791786, 15.146969116202781, 16.092053210556042, 16.465341467481302, 15.415141081918835, 14.659348445193341, 13.859056074039731, 12.83622079182302, 11.951783885900754, 11.561095357979378, 10.566017675806307, 9.700763242617619, 8.771130233216354, 7.89920281404348, 8.84834514193582, 9.818457741573159, 10.713930475236069, 11.435310615999146, 12.462976296022866, 13.413790008369453, 14.206379009998901, 14.206322596997165, 15.173145977911872, 16.208975261150346, 15.382453592560843, 14.429445528802903, 13.510866319448075, 12.461652605930059, 11.555497363458043, 10.585671047819472, 9.632842101261405, 8.799557214649372, 7.833630787287036, 6.877642898386446, 7.826226894459153, 8.79922678432592, 9.662954850607859, 10.453365198389402, 11.49269802544785, 12.421746510902702, 13.268612459187212, 13.173328750374747, 14.211736903072724, 15.17787492981421, 14.419942968568556, 13.476495632738235, 12.487223327218846, 11.504216029343183, 10.581545008601363, 9.625372817307795, 8.679275750403812, 7.732793485111609, 6.821267082808594, 5.910738098733541, 6.8727469029430415, 7.920861023913168, 8.647952031902399, 9.49969898212327, 10.43782860411282, 11.369798651677277, 12.281758387027372, 12.228305450109243, 13.259989649403238, 14.227832223457565, 13.38106979658705, 12.416862930123772, 11.48321500141522, 10.494163356140199, 9.551427442517378, 8.663484610198685, 7.645281412098569, 6.7915660069105215, 5.8911753283208, 4.934765479256699, 5.946138565184502, 6.918206406689476, 7.686367796397314, 8.519485560952283, 9.526750704211228, 10.349813692800668, 11.290404846081055, 11.397332736262141, 12.352538737758872, 13.343945751362124, 12.666136046708424, 11.637360835229915, 10.699753775514719, 9.65949394866576, 8.62617880173213, 7.653265941296577, 6.667614087676571, 5.733024098818777, 4.869131752267872, 3.9334058452162597, 4.9048170459304155, 5.888748529901599, 6.727746367560088, 7.563757024475946, 8.478689769779256, 9.415254980276659, 10.466704625551223, 10.446838808916139, 11.422424305097929, 12.485988644994043, 11.691396006296138, 10.715123754442065, 9.699133921791956, 8.680578528207414, 7.748898878403308, 6.7907428140286195, 5.790141931781902, 4.784356741597078, 3.8185757378095477, 2.8880951993790815, 3.933932865460995, 4.830612335377198, 5.735646558017123, 6.630922994958699, 7.544069906132695, 8.509530540566288, 9.514884476960106, 9.67603273089769, 10.666700313796447, 11.614311012701581, 10.7021675752049, 9.681410534676923, 8.71367124594995, 7.727011187382671, 6.865609773807266, 5.848926923800355, 4.881724454257814, 3.8798454601483385, 2.924166990901351, 1.956000863517096, 2.8852500601383153, 3.860362492840392, 4.719666087237621, 5.666990677136281, 6.598848357414805, 7.62410387742317, 8.61536018916662, 8.878650820370783, 9.87478164574309, 10.808145107800689, 9.7918925377053, 8.765151349674966, 7.746447716528766, 6.722376932187164, 5.796929542566683, 4.837768451828586, 3.9186624039084608, 2.9748600088506247, 1.9729995020244484, 1.0133362245297035, 1.8911518673010264, 2.844760590290805, 3.782499995609589, 4.7871485206971105, 5.7305792608411545, 6.767548198213095, 7.8268789418372045, 8.177608763467966, 9.120582714841852, 9.88913495381652, 8.843325763496752, 7.8599346773407195, 6.8637484203957, 5.789163384268408, 4.853757176041562, 3.8839554841282626, 2.948559971884328, 1.9952423796165748, 1.0123933098331244, 0.0, 0.9335528447695617, 2.0082976351528, 3.0751362582023525, 4.149108483735594, 5.163630624478795, 6.1185475416219175, 7.106466783377872, 8.898105902335493, 9.848267651718498, 10.688537864115007, 9.680751417642965, 8.73885293786973, 7.6726252137465165, 6.726980587982647, 5.780026457140282, 4.863115233422978, 3.9713936465432136, 2.9445488375811895, 1.959104613806931, 1.027956615700667, 1.9749260014760517, 2.9001264448795165, 3.880964389588122, 4.936618728799558, 5.875101196782392, 6.872768310156645, 7.873217695767546, 9.839992060410797, 10.817763038534991, 11.597411900593942, 10.637729127298787, 9.704456866350373, 8.71690296262317, 7.747492836716052, 6.760215439251435, 5.905826285063149, 4.916226577431353, 3.9199323611073726, 2.9846051970115948, 1.9823599737269944, 2.956602058868296, 3.9162097754922174, 4.853738228787296, 5.812036689661915, 6.796584101895729, 7.820164873299741, 8.805679907347802, 10.695142945281132, 11.70806837960287, 12.53287871024433, 11.569026441500732, 10.724238974051922, 9.7295029797757, 8.755849126086687, 7.829919880376726, 6.913640219906062, 5.969708224786226, 4.927985320108605, 4.010483082375185, 2.957288584395239, 3.9557286585981735, 4.945114435356972, 5.797236768760685, 6.743349745772179, 7.713596329118934, 8.678582395735159, 9.720970472486986, 11.62035947326508, 12.581589222825693, 13.472335653515948, 12.541949824719515, 11.659434657488978, 10.69066562131491, 9.805422762862069, 8.841893880555997, 7.8663396828538295, 6.890737211295464, 5.9073178420353285, 4.89776073326486, 3.9503593082874993, 4.91318452523514, 5.883912431754169, 6.7347635581205445, 7.709488937280014, 8.702046441986806, 9.686283176188782, 10.628976767118628, 12.56620874081235, 13.524242121352277, 14.399538586827054, 13.504648911536227, 12.596874681496917, 11.72611660112753, 10.878799241656415, 9.851457303297074, 8.789369176724874, 7.825839730916963, 6.846637075393894, 5.847361680800891, 4.909360983030838, 5.9283063738928465, 6.835764819591182, 7.7153446590362265, 8.689175184361666, 9.631664600386838, 10.618011761258092, 11.66725891951981, 13.47060494456085, 14.482409106698347, 15.421429736893435, 14.430418890501075, 13.63732072759656, 12.670547851359942, 11.621974281072777, 10.639352911651084, 9.67193023125216, 8.7274734775977, 7.802123357363984, 6.872811184140485, 5.840051588278511, 6.850593080731272, 7.8508115246123555, 8.652940073925262, 9.712532073133405, 10.703059809667382, 11.570767075270751, 12.504907139517067, 14.401359752079733, 15.430862286521947, 16.37213862743172, 15.388351697900552, 14.559405968564842, 13.560449489064016, 12.580755212340565, 11.60866430035373, 10.654243099437457, 9.726499210251383, 8.739775596375745, 7.835493995705817, 6.877965168135489, 7.881786084262366, 8.883961844410823, 9.644661951051885, 10.64952555636652, 11.721863509523452, 12.58507654544609, 13.436468369283851, 15.35442117775302, 16.301294463151155, 16.308004952267073, 15.392313486107577, 14.575285055077195, 13.702403039409223, 12.746101851539677, 12.110296765102232, 11.598053762648238, 10.680583593694188, 9.749425225892303, 8.855123010451095, 7.9265537929885, 8.829714118313554, 9.836087105479924, 10.693840470771688, 11.609718287675738, 12.574390925431725, 13.535194376374665, 14.400678760249608, 16.31475959100514, 16.28986784013867, 15.328691807409388, 14.391776627425937, 13.641348790025553, 12.79221753183882, 11.79355886762025, 11.045274532244246, 11.720472081785722, 11.658838682512256, 10.721507103805914, 9.791216877365049, 8.921386783197985, 9.88773813748632, 10.828827143532312, 11.629369334523577, 12.571960241262978, 13.552563751316331, 14.59465350499062, 15.350570223116417, 16.140804156792733, 15.404558364428613, 14.451280487076374, 13.459084915258739, 12.673757316623668, 11.722727360579709, 10.785932279618475, 10.009384459219213, 10.724988988574696, 11.772798789744433, 11.66609025268292, 10.75467250037786, 9.949795122471524, 10.902994934975622, 11.85405875171988, 12.658348126810663, 13.53860497622028, 14.541018584586926, 15.553509425243854, 16.37392697096621], [15.185815919430658, 15.499350367512646, 14.506008031968657, 13.546215878427086, 12.743242584707378, 11.95619427629512, 11.140144092215083, 11.884968463327176, 12.674631422519294, 12.491724223491119, 11.672452358351938, 10.64696597361197, 9.898322859193025, 9.002445874190435, 9.920146769819006, 10.845951389238955, 11.573871369895553, 12.473170242078618, 13.413033295122558, 14.201520469022224, 14.21341627143322, 15.158500365786479, 15.536814342977499, 14.48661395741503, 13.730821320689534, 13.00214958272622, 12.08003729629302, 12.885336730670316, 12.49464820274894, 11.499570520575869, 10.63431608738718, 9.704683077985916, 8.83275565881304, 8.050508593720831, 8.99318137700627, 9.780377630466509, 10.501757771229585, 11.529423451253304, 12.480237163599892, 13.27282616522934, 13.272769752227603, 14.23959313314231, 15.275422416380785, 15.515507830567994, 14.739925081978056, 13.990488029225526, 13.10363896778077, 12.489050208227605, 11.519223892589034, 10.566394946030966, 9.733110059418934, 8.767183632056597, 7.8111957431560075, 7.028390346244165, 7.973950419759032, 8.729402005838299, 9.519812353619841, 10.55914518067829, 11.48819366613314, 12.33505961441765, 12.239775905605185, 13.278184058303163, 14.244322085044649, 15.194133249416723, 14.410048477507797, 13.420776171988408, 12.437768874112745, 11.515097853370925, 10.558925662077357, 9.612828595173374, 8.66634632988117, 7.754819927578156, 6.844290943503102, 5.98153013727652, 7.0296442582466465, 7.714399187132838, 8.566146137353709, 9.504275759343258, 10.436245806907715, 11.34820554225781, 11.294752605339681, 12.326436804633676, 13.294279378688003, 14.314622641356612, 13.350415774893333, 12.416767846184781, 11.42771620090976, 10.48498028728694, 9.597037454968246, 8.57883425686813, 7.725118851680083, 6.824728173090362, 5.86831832402626, 5.054921799517981, 5.984653561919915, 6.7528149516277525, 7.585932716182722, 8.593197859441666, 9.416260848031106, 10.356852001311493, 10.46377989149258, 11.41898589298931, 12.410392906592563, 13.438318108091238, 12.570913679999476, 11.63330662028428, 10.593046793435322, 9.559731646501692, 8.586818786066138, 7.601166932446133, 6.666576943588338, 5.802684597037434, 4.866958689985822, 4.013600280263894, 4.955195685132037, 5.794193522790526, 6.630204179706384, 7.545136925009695, 8.481702135507097, 9.533151780781662, 9.513285964146577, 10.488871460328367, 11.552435800224481, 12.616132008291938, 11.648676599211628, 10.63268676656152, 9.614131372976978, 8.68245172317287, 7.724295658798181, 6.723694776551463, 5.717909586366639, 4.752128582579109, 3.821648044148643, 3.0198574449491025, 3.897059490607637, 4.802093713247562, 5.697370150189138, 6.610517061363133, 7.575977695796726, 8.581331632190544, 8.742479886128127, 9.733147469026884, 10.680758167932018, 11.635720419974463, 10.614963379446486, 9.647224090719513, 8.660564032152234, 7.799162618576828, 6.7824797685699165, 5.815277299027375, 4.8133983049179, 3.8577198356709124, 2.8895537082866576, 1.9516972153687537, 2.9268096480708303, 3.7861132424680592, 4.733437832366719, 5.665295512645243, 6.690551032653609, 7.681807344397057, 7.945097975601222, 8.941228800973528, 9.92001381507028, 10.725445382474861, 9.698704194444527, 8.680000561298328, 7.655929776956725, 6.730482387336244, 5.771321296598147, 4.852215248678022, 3.9084128536201863, 2.90655234679401, 1.946889069299265, 0.9575990225314648, 1.9112077455212435, 2.8489471508400275, 3.853595675927549, 4.797026416071593, 5.833995353443534, 6.893326097067643, 7.244055918698403, 8.18702987007229, 9.23368197743144, 9.776878608266314, 8.793487522110281, 7.797301265165261, 6.722716229037969, 5.787310020811123, 4.817508328897824, 3.8821128166538896, 2.9287952243861364, 1.945946154602686, 0.9335528447695617, 0.0, 1.0747447903832383, 2.141583413432791, 3.215555638966032, 4.230077779709234, 5.184994696852356, 6.1729139386083105, 7.969578777831686, 8.91974052721469, 9.900713389277463, 10.614304262412526, 9.672405782639292, 8.606178058516079, 7.660533432752208, 6.713579301909844, 5.796668078192539, 4.904946491312775, 3.878101682350751, 2.8926574585764926, 1.9615094604702286, 1.0463988769722443, 1.971599320375709, 2.9524372650843143, 4.00809160429575, 4.946574072278584, 5.944241185652837, 6.944690571263738, 8.911464935906988, 9.889235914031184, 10.838620720902098, 11.571281972068348, 10.638009711119935, 9.650455807392731, 8.681045681485614, 7.693768284020996, 6.839379129832711, 5.849779422200915, 4.853485205876934, 3.9181580417811563, 2.915912818496556, 2.028074934364489, 2.9876826509884093, 3.925211104283488, 4.883509565158107, 5.868056977391921, 6.891637748795933, 7.877152782843993, 9.766615820777325, 10.779541255099064, 11.709155077818743, 12.502579286270294, 11.657791818821483, 10.663055824545262, 9.689401970856249, 8.763472725146286, 7.847193064675624, 6.903261069555787, 5.861538164878167, 4.944035927144746, 3.8908414291648006, 3.0272015340943663, 4.016587310853165, 4.868709644256878, 5.814822621268372, 6.785069204615127, 7.750055271231352, 8.792443347983179, 10.691832348761272, 11.653062098321886, 12.648612021090361, 13.475502669489076, 12.59298750225854, 11.624218466084471, 10.73897560763163, 9.775446725325557, 8.799892527623392, 7.824290056065026, 6.84087068680489, 5.831313578034422, 4.883912153057061, 4.069364012179313, 4.955385307250362, 5.806236433616737, 6.780961812776207, 7.773519317482998, 8.757756051684975, 9.70044964261482, 11.637681616308544, 12.595714996848471, 13.575814954401467, 14.438201756305789, 13.530427526266479, 12.65966944589709, 11.812352086425976, 10.785010148066634, 9.722922021494435, 8.759392575686524, 7.780189920163456, 6.780914525570452, 5.842913827800399, 5.09963421946933, 5.907237695087375, 6.786817534532419, 7.760648059857858, 8.703137475883029, 9.689484636754283, 10.738731795016001, 12.542077820057042, 13.553881982194541, 14.535944552825596, 15.363971735270637, 14.570873572366121, 13.604100696129503, 12.555527125842339, 11.572905756420646, 10.605483076021722, 9.661026322367261, 8.735676202133545, 7.806364028910046, 6.773604433048073, 6.094409585201272, 6.922284400108548, 7.724412949421454, 8.784004948629597, 9.774532685163573, 10.642239950766943, 11.576380015013259, 13.472832627575924, 14.502335162018138, 15.540657097590628, 15.390944739697032, 14.728554520319205, 13.91874067798117, 12.939046401257718, 12.542217145123292, 11.587795944207018, 10.660052055020945, 9.673328441145307, 8.76904684047538, 7.811518012905051, 7.125602588732365, 7.955434719907016, 8.716134826548078, 9.720998431862714, 10.793336385019643, 11.65654942094228, 12.507941244780042, 14.42589405324921, 15.372767338647346, 15.374452107497511, 14.458760641338015, 13.704777482673594, 12.904566491194235, 11.948265303324689, 12.964740550729683, 12.5316066074178, 11.614136438463749, 10.682978070661864, 9.788675855220657, 8.860106637758062, 8.073530622783553, 8.979180614166413, 9.765313346267881, 10.681191163171933, 11.64586380092792, 12.60666725187086, 13.4721516357458, 15.386232466501328, 15.356314995369107, 14.395138962639827, 13.458223782656376, 12.770841217621951, 11.96694116727193, 10.995722319405262, 11.950746051116376, 12.654024926555284, 12.592391527281817, 11.655059948575476, 10.72476972213461, 9.854939627967546, 9.131554641956319, 9.9719206522188, 10.70084221001977, 11.643433116759173, 12.624036626812526, 13.666126380486814, 14.422043098612608, 15.207251312023173, 14.471005519659052, 13.517727642306813, 12.525532070489177, 11.803249744220066, 10.89745099601282, 9.988095731403487, 10.942937303988774, 11.658541833344257, 12.706351634513995, 12.599643097452482, 11.688225345147421, 10.883347967241086, 10.14681143944562, 10.997152260406368, 11.729821002306856, 12.610077851716474, 13.61249146008312, 14.624982300740049, 15.445399846462399], [14.263310169071069, 14.47991607373098, 13.48657373818699, 12.52678158464542, 11.723808290925714, 10.936759982513456, 11.951041885435293, 12.747793858629844, 13.53745681782196, 13.550874253484967, 12.731602388345785, 11.706116003605816, 10.954951848431133, 9.96495894978903, 9.022779197807028, 9.923445638879365, 10.651365619535962, 11.550664491719028, 12.49052754476297, 13.279014718662633, 13.29091052107363, 14.23599461542689, 14.517380049195832, 13.467179663633363, 12.71138702690787, 11.982715288944556, 12.89093508951323, 13.748162125972984, 13.553798232742787, 12.558720550569717, 11.693466117381027, 10.763833107979762, 9.891905688806888, 9.013021669319427, 8.095813804994291, 8.857871880106918, 9.579252020869994, 10.606917700893714, 11.557731413240303, 12.350320414869751, 12.350264001868013, 13.31708738278272, 14.352916666021194, 14.496073536786328, 13.720490788196392, 12.971053735443862, 13.91453676100098, 13.548200238221453, 12.578373922582882, 11.625544976024814, 10.79226008941278, 9.826333662050443, 8.870345773149856, 7.99090342184276, 7.076582847747053, 7.8068962554787085, 8.59730660326025, 9.636639430318699, 10.565687915773552, 11.412553864058061, 11.317270155245597, 12.355678307943574, 13.321816334685062, 14.271627499057136, 14.67344068426106, 13.994825161529803, 13.496918904106593, 12.574247883364773, 11.618075692071205, 10.671978625167222, 9.725496359875017, 8.813969957572002, 7.90344097349695, 6.9440432128751155, 6.132276686234667, 6.791893436773249, 7.643640386994118, 8.581770008983668, 9.513740056548126, 10.425699791898221, 10.372246854980093, 11.40393105427409, 12.371773628328416, 13.41145632920772, 14.375663195670999, 13.47591787617863, 12.486866230903608, 11.544130317280787, 10.656187484962095, 9.637984286861979, 8.78426888167393, 7.883878203084209, 6.9274683540201085, 6.017434875116576, 5.062147811560324, 5.830309201268163, 6.663426965823131, 7.670692109082076, 8.493755097671517, 9.434346250951904, 9.54127414113299, 10.49648014262972, 11.487887156232972, 12.515812357731647, 13.544587569210158, 12.692456650278128, 11.65219682342917, 10.61888167649554, 9.645968816059986, 8.66031696243998, 7.725726973582185, 6.861834627031281, 5.926108719979669, 4.9761133558624895, 4.032689934772447, 4.871687772430937, 5.707698429346793, 6.622631174650105, 7.559196385147508, 8.610646030422071, 8.590780213786987, 9.566365709968776, 10.62993004986489, 11.693626257932348, 12.669898509786421, 11.707431556944757, 10.688876163360215, 9.754689747171483, 8.796533682796795, 7.78284480654531, 6.777059616360487, 5.8112786125729565, 4.880798074142491, 3.982370520547698, 2.974553740248047, 3.8795879628879715, 4.774864399829548, 5.688011311003543, 6.653471945437136, 7.658825881830953, 7.819974135768538, 8.810641718667295, 9.758252417572429, 10.769931934697913, 11.689708169829723, 10.72196888110275, 9.73530882253547, 8.873907408960067, 7.857224558953155, 6.890022089410614, 5.872548334911747, 4.91686986566476, 3.948703738280505, 2.9364089109887215, 2.0043038977112406, 2.8636074921084695, 3.8109320820071293, 4.742789762285653, 5.768045282294019, 6.759301594037467, 7.022592225241633, 8.01872305061394, 8.997508064710692, 10.013760634806081, 10.773448984827763, 9.754745351681564, 8.730674567339962, 7.805227177719482, 6.846066086981385, 5.92696003906126, 4.983157644003424, 3.965702376787857, 3.0060390992931123, 1.9423107181514325, 0.9887019951616538, 1.9264414004804378, 2.931089925567959, 3.8745206657120033, 4.911489603083945, 5.970820346708054, 6.169311128315165, 7.112285079689052, 8.1589371870482, 9.204746377367968, 9.868232312493518, 8.872046055548498, 7.797461019421207, 6.862054811194361, 5.892253119281062, 4.9568576070371275, 4.003540014769374, 3.0206909449859243, 2.0082976351528, 1.0747447903832383, 0.0, 1.0668386230495523, 2.1408108485827935, 3.1553329893259954, 4.110249906469118, 5.098169148225073, 6.950144484050021, 7.900306233433025, 8.881279095495797, 9.88906554196784, 10.747150573022529, 9.680922848899316, 8.735278223135445, 7.788324092293082, 6.815447440007716, 5.838619016561076, 4.811477088011397, 3.755482853879158, 2.824334855772894, 1.877365469997509, 0.9521650265940445, 1.9330029713026498, 2.9886573105140855, 3.9271397784969198, 4.924806891871173, 5.925256277482074, 7.892030642125323, 8.869801620249518, 9.819186427120432, 10.778869200415587, 11.712141461364002, 10.725200597775967, 9.75579047186885, 8.768513074404234, 7.840317794816496, 6.767027457952901, 5.77073324162892, 4.780983437083822, 3.778738213799221, 2.8590415273897536, 1.968248357206745, 2.9057768105018233, 3.864075271376443, 4.848622683610257, 5.872203455014269, 6.857718489062329, 8.747181526995659, 9.760106961317398, 10.689720784037076, 11.710166514617534, 12.687860567428569, 11.7378006149285, 10.764146761239486, 9.829020057966726, 8.791866999713841, 7.820509105307774, 6.778786200630153, 5.806861322447411, 4.753666824467466, 3.858168127119631, 2.9971530170715, 3.849275350475213, 4.795388327486707, 5.7656349108334615, 6.730620977449687, 7.773009054201513, 9.672398054979606, 10.63362780454022, 11.629177727308695, 12.570917188748332, 13.560248665243233, 12.698963256467708, 11.72764390308895, 10.73466119471973, 9.66424425094975, 8.68711545136769, 7.703696082107555, 6.694138973337087, 5.746737548359726, 4.900330605204577, 3.935951013468697, 4.786802139835072, 5.761527518994542, 6.754085023701332, 7.73832175790331, 8.681015348833155, 10.618247322526877, 11.576280703066804, 12.556380660619801, 13.518172303392086, 14.497688689251172, 13.734414236280326, 12.70190618397855, 11.65755157203085, 10.5857474167971, 9.622217970989189, 8.643015315466121, 7.643739920873117, 6.705739223103064, 5.930600812494594, 4.88780340130571, 5.767383240750753, 6.741213766076193, 7.683703182101364, 8.670050342972617, 9.719297501234337, 11.522643526275374, 12.534447688412873, 13.516510259043928, 14.443942282356934, 14.865928629355853, 14.128071633408966, 13.418352521145003, 12.43573115172331, 11.468308471324386, 10.523851717669926, 9.59850159743621, 8.669189424212712, 7.636429828350739, 6.925376178226537, 5.902850106326884, 6.704978655639788, 7.764570654847932, 8.755098391381907, 9.622805656985275, 10.55694572123159, 12.453398333794256, 13.48290086823647, 14.52122280380896, 14.468438989337441, 13.806048769959615, 13.17853009882032, 13.901559476856315, 13.405042540425956, 12.450621339509683, 11.522877450323609, 10.536153836447971, 9.631872235778046, 8.674343408207717, 7.94955229788838, 6.936000426125352, 7.696700532766413, 8.701564138081048, 9.773902091237977, 10.637115127160612, 11.488506950998374, 13.406459759467543, 14.353333044865678, 14.45194635713792, 13.536254890978425, 12.782271732314003, 12.126841240635107, 12.910778378923286, 13.92725362632828, 13.394432002720464, 12.476961833766413, 11.545803465964529, 10.651501250523323, 9.722932033060728, 8.897480331939569, 7.95974632038475, 8.745879052486217, 9.661756869390267, 10.626429507146254, 11.587232958089194, 12.452717341964131, 14.36679817271966, 14.433809245009517, 13.472633212280236, 12.535718032296785, 11.84833546726236, 11.069573595259952, 11.958235395003857, 12.913259126714971, 13.71317495654913, 13.455216922584482, 12.51788534387814, 11.587595117437276, 10.717765023270212, 9.955504351112335, 8.952486358437136, 9.681407916238106, 10.623998822977507, 11.60460233303086, 12.646692086705148, 13.40260880483094, 14.284745561663582, 13.548499769299461, 12.595221891947222, 11.603026320129587, 10.880743993860476, 10.000083424000842, 10.950608807002082, 11.98186523378202, 12.717691863338104, 13.765501664507841, 13.462468492755146, 12.551050740450087, 11.746173362543752, 10.962739640674844, 9.977717966624704, 10.710386708525192, 11.590643557934808, 12.593057166301454, 13.605548006958383, 14.425965552680731], [13.32280014677499, 13.506616693150567, 12.513274357606578, 11.553482204065007, 10.750508910345301, 11.729905307132, 12.744187210053838, 13.680359935934504, 14.470022895126622, 14.485843041826456, 13.65046351765383, 12.62497713291386, 11.753853350663002, 10.7638604520209, 9.807260921166323, 8.982935616583287, 9.710855597239885, 10.61015446942295, 11.550017522466892, 12.338504696366556, 12.350400498777551, 13.29548459313081, 13.54408066861542, 12.49388028305295, 11.738087646327457, 12.71530085927826, 13.684080414131774, 14.619306145686465, 14.488767021084277, 13.493689338911206, 12.612327246689071, 11.682694237287807, 10.774208612801369, 9.856182708449783, 8.880295528353587, 7.917361857810841, 8.638741998573916, 9.666407678597636, 10.617221390944225, 11.409810392573672, 11.409753979571935, 12.376577360486642, 13.412406643725117, 13.522774156205916, 12.74719140761598, 13.703639305777566, 14.707682085619524, 14.483169026562942, 13.513342710924372, 12.560513764366304, 11.724603197478878, 10.745194791358488, 9.752648697144336, 8.834064460973117, 7.86106457110635, 6.866386233182631, 7.656796580964172, 8.696129408022621, 9.625177893477474, 10.472043841761982, 10.376760132949517, 11.415168285647495, 12.38130631238898, 13.331117476761055, 13.700141303680647, 14.727410731863507, 14.431887692448083, 13.509216671706263, 12.553044480412694, 11.606947413508712, 10.660465148216506, 9.732831086880047, 8.78574389749143, 7.804930300272619, 6.916758409593964, 5.85138341447717, 6.7031303646980405, 7.641259986687591, 8.573230034252049, 9.485189769602142, 9.431736832684013, 10.463421031978008, 11.431263606032335, 12.470946306911639, 13.435153173374918, 14.36880110208347, 13.421835019245098, 12.479099105622277, 11.591156273303584, 10.572953075203468, 9.719237670015419, 8.802739332392253, 7.809771278014589, 6.87832196251408, 5.846629534919621, 4.889799178972084, 5.7229169435270535, 6.730182086785998, 7.553245075375439, 8.493836228655825, 8.600764118836912, 9.555970120333642, 10.547377133936894, 11.57530233543557, 12.60407754691408, 13.541684606629277, 12.58716561177066, 11.55385046483703, 10.580937604401475, 9.59528575078147, 8.660695761923675, 7.7968034153727706, 6.808411643974149, 5.837000443259993, 4.893577022169951, 3.9311777501348577, 4.767188407050716, 5.682121152354027, 6.618686362851429, 7.670136008125993, 7.650270191490908, 8.625855687672697, 9.689420027568811, 10.753116235636268, 11.72938848749034, 12.745378320140448, 11.704959856144928, 10.68965853551297, 9.731502471138283, 8.717813594886799, 7.712028404701976, 6.746247400914446, 5.81576686248398, 4.843257607945201, 3.8354408276455505, 2.939077940591893, 3.8343543775334696, 4.747501288707465, 5.712961923141058, 6.718315859534875, 6.879464113472459, 7.870131696371215, 8.817742395276348, 9.829421912401832, 10.85017895292981, 11.788807504152304, 10.802147445585025, 9.876233989346858, 8.834321802032795, 7.867119332490255, 6.807517123253237, 5.851838654006249, 4.883672526621995, 3.84946605950088, 2.865190985108744, 1.923097469812391, 2.870422059711051, 3.802279739989575, 4.827535259997941, 5.8187915717413885, 6.082082202945554, 7.01963669714551, 7.998421711242263, 9.014674281337651, 10.041415469367985, 10.82158397473112, 9.797513190389516, 8.872065800769034, 7.900746359466364, 6.936043362678778, 5.940397357536372, 4.900671165129347, 3.9410078876346017, 2.877279506492922, 1.9236707835031432, 0.9859313781843593, 1.9905799032718807, 2.9340106434159248, 3.970979580787866, 5.030310324411976, 5.102472505265612, 6.045446456639499, 7.092098563998648, 8.137907754318416, 9.121298840474449, 9.938884678598052, 8.86429964247076, 7.928893434243913, 6.959091742330614, 6.02369623008668, 5.070378637818926, 4.087529568035476, 3.0751362582023525, 2.141583413432791, 1.0668386230495523, 0.0, 1.073972225533241, 2.088494366276443, 3.0434112834195655, 4.03133052517552, 5.976845103469607, 6.927006852852611, 7.907979714915383, 8.915766161387426, 9.85766464116066, 10.74776147194887, 9.802116846185, 8.84074352367888, 7.803823948844513, 6.826995525397872, 5.799853596848194, 4.743859362715955, 3.8127113646096906, 2.865741978834306, 1.940541535430841, 0.9597035907222357, 2.0153579299336712, 2.9538403979165055, 3.9515075112907585, 4.95195689690166, 6.918731261544909, 7.896502239669105, 8.845887046540017, 9.805569819835172, 10.738842080783588, 11.726395984510791, 10.822629094918405, 9.820932505790033, 8.828694303653293, 7.755403966789698, 6.759109750465718, 5.769359945920619, 4.767114722636018, 3.8474180362265504, 2.911705044607868, 1.9324774299214096, 2.890775890796029, 3.8753233030298437, 4.8989040744338554, 5.884419108481914, 7.7738821464152466, 8.786807580736985, 9.716421403456664, 10.73686713403712, 11.714561186848155, 12.709297181124375, 11.83098538428904, 10.817396566803524, 9.780243508550639, 8.808885614144572, 7.76716270946695, 6.795237831284208, 5.742043333304262, 4.846544635956428, 3.899894207820818, 2.8759759698947995, 3.822088946906294, 4.792335530253049, 5.757321596869274, 6.7997096736211, 8.699098674399194, 9.660328423959808, 10.655878346728283, 11.59761780816792, 12.58694928466282, 13.651358600024246, 12.681245676736292, 11.688262968367072, 10.617846024597092, 9.640717225015033, 8.657297855754898, 7.647740746984429, 6.700339322007068, 5.737514105059427, 4.753520435237327, 3.813502759254659, 4.788228138414128, 5.78078564312092, 6.7650223773228975, 7.707715968252743, 9.644947941946466, 10.602981322486393, 11.583081280039389, 12.544872922811674, 13.52438930867076, 14.530315379976802, 13.655507957625893, 12.611153345678192, 11.539349190444442, 10.575819744636531, 9.596617089113463, 8.597341694520459, 7.659340996750406, 6.755355204315416, 5.70537282307434, 4.794083860170341, 5.7679143854957795, 6.71040380152095, 7.696750962392205, 8.745998120653923, 10.549344145694963, 11.561148307832463, 12.543210878463517, 13.470642901776522, 13.925418607059775, 14.79811614458053, 14.371954294792346, 13.389332925370653, 12.421910244971729, 11.477453491317268, 10.552103371083552, 9.622791197860053, 8.59003160199808, 7.750130570047358, 6.720419528095514, 5.731679275059376, 6.791271274267519, 7.781799010801494, 8.649506276404864, 9.58364634065118, 11.480098953213846, 12.50960148765606, 13.54792342322855, 13.527928967041364, 12.865538747663537, 13.848574609991882, 14.691035899403497, 14.358644314073299, 13.404223113157025, 12.476479223970951, 11.489755610095314, 10.585474009425386, 9.627945181855058, 8.767121719657009, 7.753569847893981, 6.723401152186001, 7.728264757500636, 8.800602710657564, 9.663815746580202, 10.515207570417964, 12.433160378887132, 13.380033664285268, 13.511436334841843, 12.595744868682347, 11.841761710017925, 12.79688575180667, 13.700254801470468, 14.716730048875462, 14.348033776367807, 13.430563607413756, 12.499405239611871, 11.584067327827984, 10.65549811036539, 9.715049753708197, 8.767540470428967, 7.772579671905804, 8.688457488809854, 9.653130126565841, 10.613933577508782, 11.47941796138372, 13.39349879213925, 13.49329922271344, 12.532123189984159, 11.595208010000707, 10.907825444966283, 11.854055318619247, 12.74771181755104, 13.702735549262155, 14.632036085857175, 14.408818696231824, 13.471487117525482, 12.520161194741938, 11.650331100574874, 10.773073772880963, 9.74563168305568, 8.708108535657693, 9.650699442397094, 10.631302952450447, 11.673392706124735, 12.42930942425053, 13.344235539367505, 12.607989747003383, 11.654711869651145, 10.662516297833509, 9.940233971564398, 10.784565147360137, 11.740085229549265, 12.771341656329202, 13.636552992646148, 14.684362793815886, 14.416070266402489, 13.483616817754749, 12.678739439848414, 11.755884965293387, 10.770863291243248, 9.73708732794478, 10.617344177354395, 11.619757785721042, 12.63224862637797, 13.45266617210032], [12.488960840987188, 12.779669303844557, 11.786326968300568, 10.826534814758997, 11.793720366766328, 12.773116763553027, 13.787398666474864, 14.723571392355531, 15.513234351547649, 15.559815267359697, 14.660445031057499, 13.633969440771347, 12.670026768130953, 11.68003386948885, 10.723434338634274, 9.855672823256473, 8.899252292004762, 9.798551164187828, 10.716178216679088, 11.504665390578754, 11.51656119298975, 12.461645287343009, 12.81713327930941, 11.76693289374694, 12.70208629847224, 13.679299511423043, 14.7272918705528, 15.662517602107492, 15.562739246617518, 14.567661564444448, 13.686299472222313, 12.756666462821048, 11.803389667179097, 10.834990382516171, 9.796468945821537, 8.790099064484027, 7.827138693338793, 8.854804373362514, 9.783382085156422, 10.57597108678587, 10.575914673784133, 11.542738054698841, 12.578567337937315, 12.795826766899905, 13.711190059760762, 14.667637957922349, 15.716851671440365, 15.557141252096184, 14.587314936457613, 13.634485989899545, 12.79857542301212, 11.819167016891729, 10.781829751522064, 9.833245755449356, 8.86024586558259, 7.86556752765887, 6.845193275729049, 7.884526102787499, 8.79133858768967, 9.63820453597418, 9.542920827161716, 10.581328979859693, 11.54746700660118, 12.497278170973253, 13.505775457800478, 14.538970122099293, 15.505859917981326, 14.583188897239504, 13.627016705945936, 12.680919639041953, 11.734437373749747, 10.806803312413289, 9.859716123024672, 8.835828052329685, 7.915939704070204, 6.85056470895341, 5.891527059462917, 6.829656681452468, 7.739390728464246, 8.65135046381434, 8.597897526896212, 9.629581726190207, 10.597424300244533, 11.637107001123837, 12.601313867587116, 13.534961796295669, 14.495807244778339, 13.553071331155518, 12.665128498836825, 11.64692530073671, 10.79320989554866, 9.876711557925494, 8.88374350354783, 7.9092197145711465, 6.845810829395861, 5.888980473448324, 4.91131363829193, 5.896342780998195, 6.719405769587636, 7.6599969228680225, 7.766924813049108, 8.722130814545839, 9.713537828149091, 10.741463029647766, 11.770238241126275, 12.707845300841472, 13.661137837303901, 12.627822690370271, 11.654909829934716, 10.66925797631471, 9.734667987456916, 8.870775640906011, 7.8823838695073905, 6.910972668793234, 5.967549247703192, 4.930359044611098, 3.955585101815593, 4.848281846566224, 5.784847057063627, 6.83629670233819, 6.816430885703106, 7.7920163818848955, 8.85558072178101, 9.913176487503973, 10.889448739358045, 11.86304239504841, 12.77893208167817, 11.763630761046212, 10.805474696671524, 9.79178582042004, 8.786000630235216, 7.820219626447686, 6.889739088017221, 5.917229833478443, 4.909413053178792, 3.982196385664345, 3.0227510722983473, 3.9136619829196624, 4.879122617353255, 5.8844765537470725, 5.957064159512798, 6.947731742411555, 7.877403872825969, 8.889083389951454, 9.90984043047943, 10.877579719206404, 11.864239777773683, 10.950206214880097, 9.908294027566035, 8.941091558023494, 7.881489348786477, 6.9258108795394895, 5.957644752155235, 4.923438285034121, 3.939163210641985, 2.997069695345632, 2.0588187544759284, 2.968440434201772, 3.958732644480053, 4.93724443695576, 5.028464103408641, 5.94566447161227, 6.924449485709022, 7.940702055804412, 8.967443243834746, 9.986146876980944, 10.871485415922756, 9.946038026302276, 8.974718584999605, 8.010015588212019, 7.0143695830696124, 5.974643390662587, 5.014980113167843, 3.951251732026163, 2.997643009036384, 2.0599036037176, 1.0562027048806213, 1.9662163824064423, 2.917361481250953, 3.9766922248750625, 4.028500279732372, 4.971474231106258, 6.018126338465407, 7.0639355287851755, 8.047326614941209, 9.043512871886229, 9.938271868004, 9.002865659777154, 8.033063967863855, 7.097668455619921, 6.144350863352168, 5.161501793568718, 4.149108483735594, 3.215555638966032, 2.1408108485827935, 1.073972225533241, 0.0, 1.014522140743202, 1.9694390578863246, 2.957358299642279, 4.980632124243099, 5.930793873626103, 6.911766735688875, 7.919553182160919, 8.861451661934154, 9.927679386057367, 10.873324011821238, 9.914715749212121, 8.877796174377753, 7.900967750931112, 6.873825822381433, 5.817831588249194, 4.886683590142931, 3.9397142043675464, 3.014513760964082, 2.0336758162554767, 1.0191449507071644, 1.9576274186899985, 2.955294532064251, 3.9557439176751523, 5.922518282318402, 6.900289260442597, 7.849674067313509, 8.809356840608663, 9.742629101557078, 10.730183005284282, 11.6995931311914, 10.894904731323274, 9.902666529186533, 8.829376192322938, 7.833081975998957, 6.843332171453858, 5.841086948169258, 4.921390261759791, 3.9549165010288947, 2.9756888863424362, 2.0173904254678168, 2.9584356153730527, 3.9802484558838507, 4.8882061292554075, 6.848667093462091, 7.836110203126246, 8.765724025845925, 9.74065415481061, 10.718348207621645, 11.713084201897866, 12.68673805558688, 11.891368792336763, 10.854215734083878, 9.882857839677811, 8.84113493500019, 7.8692100568174475, 6.816015558837503, 5.920516861489668, 4.943105664241845, 3.919187426315826, 3.0691111509943907, 3.9287599936643094, 4.8937460602805345, 5.874494620667945, 7.80447273080735, 8.765702480367963, 9.705180969117544, 10.64692043055718, 11.636251907052081, 12.674246843437075, 13.710293632967767, 12.731474424788098, 11.66105748101812, 10.68392868143606, 9.700509312175924, 8.690952203405455, 7.743550778428094, 6.780725561480454, 5.796731891658354, 4.8567142156756855, 4.035250342502225, 4.917210106532181, 5.901446840734158, 6.813090024660899, 8.750321998354622, 9.708355378894549, 10.63238390242865, 11.594175545200935, 12.57369193106002, 13.579618002366063, 14.632481606535727, 13.654364802099218, 12.582560646865469, 11.619031201057558, 10.63982854553449, 9.640553150941486, 8.702552453171434, 7.798566660736443, 6.7485842794953665, 5.8372953165913675, 5.0149365895838764, 5.899860464839824, 6.870702454189745, 7.853757380053778, 9.723295637492503, 10.666522364240619, 11.648584934871673, 12.519945524165783, 13.570923192320917, 14.545028773851318, 15.415165751213372, 14.43254438179168, 13.465121701392755, 12.520664947738295, 11.595314827504579, 10.666002654281082, 9.633243058419108, 8.793342026468386, 7.76363098451654, 6.7748907314804026, 6.038293478355616, 6.971255674120368, 7.823457768202403, 8.75759783244872, 10.654050445011386, 11.6835529794536, 12.692094920686344, 12.716325661806241, 13.716084071267685, 14.715040550768512, 15.60720931687145, 15.401855770494326, 14.447434569578052, 13.519690680391978, 12.53296706651634, 11.628685465846415, 10.671156638276086, 9.810333176078036, 8.796781304315008, 7.766612608607027, 7.001317368194626, 7.990059373976438, 8.83776723837774, 9.689159062215504, 11.607111870684673, 12.553985156082808, 12.699833029606719, 11.784141563447225, 12.714498916691111, 13.669622958479856, 14.61642821893842, 15.632903466343414, 15.391245232788833, 14.473775063834783, 13.542616696032898, 12.627278784249011, 11.698709566786416, 10.758261210129223, 9.810751926849994, 8.81579112832683, 7.961510099503844, 8.92618273725983, 9.803452451113921, 10.653369453181261, 12.56745028393679, 12.681695917478315, 11.720519884749034, 10.783604704765585, 11.78056265163947, 12.770228736087198, 13.663885235018991, 14.618908966730105, 15.605053356705426, 15.452030152652851, 14.514698573946509, 13.563372651162965, 12.6935425569959, 11.81628522930199, 10.788843139476707, 9.75131999207872, 8.923752053091084, 9.904355563144437, 10.870336008561713, 11.60326091604807, 12.510396233579703, 11.774150441215582, 10.843108564416022, 9.850912992598387, 10.812971178237584, 11.700738564828088, 12.656258647017216, 13.687515073797154, 14.645545300503635, 15.694344307219556, 15.459281722823516, 14.526828274175775, 13.72195089626944, 12.799096421714413, 11.814074747664275, 10.780298784365806, 9.890396788048385, 10.892810396415031, 11.90530123707196, 12.62661766389786], [11.474438700243985, 11.998678776781086, 11.080073614759895, 11.766935140857175, 12.783672337549053, 13.763068734335752, 14.77735063725759, 15.713523363138261, 16.50318632233038, 16.399685170536902, 15.487402250318665, 14.460926660032513, 13.496983987392118, 12.506991088750016, 11.55039155789544, 10.682630042517639, 9.726209511265928, 8.812180343740806, 9.701656075935887, 10.490143249835551, 10.502039052246547, 11.447123146599806, 12.110879925768737, 12.707333219845118, 13.642486624570418, 14.619699837521221, 15.680725726169294, 16.615951457723988, 16.402609149794724, 15.407531467621654, 14.522330340512433, 13.592697331111168, 12.630346886440263, 11.661947601777337, 10.623426165082703, 9.617056283745193, 8.65409591259996, 7.8684335529154925, 8.76885994441322, 9.561448946042667, 9.56139253304093, 10.528215913955638, 11.564045197194112, 12.445266654222337, 13.444203213121943, 14.442672831145954, 15.465504061052744, 16.39701115527339, 15.427184839634819, 14.474355893076751, 13.634606291302239, 12.655197885181849, 11.60878697078323, 10.660202974710522, 9.687203084843755, 8.692524746920036, 7.672150494990215, 6.898155282340477, 7.776816446946469, 8.623682395230977, 8.528398686418512, 9.56680683911649, 10.532944865857976, 11.48275603023005, 12.491253317057275, 13.52444798135609, 14.508067484465867, 15.42305880041671, 14.466886609123142, 13.520789542219159, 12.574307276926953, 11.642834180703408, 10.695746991314792, 9.66278527159085, 8.742896923331369, 7.677521928214576, 6.718484278724084, 5.843285861005446, 6.724868587721044, 7.636828323071137, 7.583375386153008, 8.615059585447003, 9.58290215950133, 10.622584860380634, 11.586791726843913, 12.520439655552465, 13.509491300827486, 14.392941234332724, 13.504998402014031, 12.486795203913916, 11.633079798725866, 10.712742426215614, 9.71977437183795, 8.736176933832311, 7.672768048657026, 6.71593769270949, 5.738270857553097, 4.881820640254993, 5.704883628844434, 6.64547478212482, 6.752402672305906, 7.707608673802636, 8.699015687405888, 9.726940888904563, 10.755716100383072, 11.693323160098268, 12.733582986947226, 13.467692593547477, 12.494779733111923, 11.509127879491917, 10.574537890634122, 9.710645544083217, 8.718414737797511, 7.747003537083356, 6.803580115993314, 5.757316263872264, 4.782542321076759, 3.833759705823022, 4.770324916320424, 5.821774561594988, 5.8019087449599045, 6.777494241141694, 7.841058581037808, 8.898654346760772, 9.874926598614845, 10.848520254305209, 11.803284977855226, 12.603500664223418, 11.64534459984873, 10.631655723597246, 9.625870533412423, 8.660089529624893, 7.729608991194427, 6.753260701768564, 5.7454439214689135, 4.809153604925511, 3.849708291559513, 2.8991398421764605, 3.8646004766100535, 4.869954413003871, 4.942542018769597, 5.933209601668353, 6.8628817320827675, 7.874561249208252, 8.89531828973623, 9.863057578463202, 10.849717637030482, 11.790076118057303, 10.74816393074324, 9.7809614612007, 8.721359251963683, 7.765680782716696, 6.797514655332441, 5.759469153324243, 4.775194078932107, 3.833100563635754, 2.8857759737370943, 1.9539182934585702, 2.9442105037368504, 3.9227222962125583, 4.01394196266544, 4.9311423308690685, 5.909927344965821, 6.92617991506121, 7.952921103091545, 8.971624736237745, 9.995695520579346, 10.840260820544653, 9.814588488176812, 8.849885491389225, 7.854239486246819, 6.814513293839793, 5.854850016345049, 4.7911216352033685, 3.83751291221359, 2.899773506894806, 1.8951249818072844, 0.9516942416632402, 1.902839340507751, 2.9621700841318606, 3.01397813898917, 3.956952090363057, 5.003604197722206, 6.049413388041974, 7.032804474198008, 8.028990731143027, 9.10357576727032, 10.017387800520355, 9.047586108607057, 8.112190596363122, 7.158873004095369, 6.176023934311919, 5.163630624478795, 4.230077779709234, 3.155332989325995, 2.088494366276443, 1.014522140743202, 0.0, 0.9549169171431225, 1.9428361588990772, 3.979372580858844, 4.929534330241848, 5.91050719230462, 6.918293638776664, 7.860192118549898, 8.926419842673111, 9.872064468436982, 10.921569175866553, 9.892318315120953, 8.915489891674312, 7.888347963124635, 6.832353728992396, 5.901205730886132, 4.954236345110748, 4.029035901707283, 3.0481979569986786, 2.009096921489892, 1.070614453507058, 1.9846868544873892, 2.954484374290897, 4.921258738934146, 5.899029717058342, 6.848414523929254, 7.808097297224408, 8.741369558172822, 9.728923461900026, 10.698333587807141, 11.755746479925424, 10.917188669929732, 9.843898333066138, 8.847604116742158, 7.85785431219706, 6.85560908891246, 5.935912402502993, 4.944868471811622, 3.965640857125164, 3.0073423962505443, 2.0714226501901125, 3.0096407783069887, 3.886946585871152, 5.847407550077835, 6.834850659741991, 7.76446448246167, 8.739394611426354, 9.717088664237389, 10.71182465851361, 11.685478512202623, 12.726926795711675, 11.868737874827078, 10.897379980421011, 9.855657075743391, 8.883732197560649, 7.830537699580704, 6.926682497920726, 5.933057635024572, 4.909139397098554, 4.011993611828124, 3.0417470284813692, 4.006733095097594, 4.873235077283689, 6.803213187423094, 7.764442936983708, 8.70392142573329, 9.645660887172927, 10.634992363667827, 11.672987300052819, 12.709034089583511, 13.70201679795273, 12.651009451800846, 11.673880652218786, 10.690461282958651, 9.680904174188184, 8.733502749210823, 7.770677532263181, 6.786683862441081, 5.846666186458413, 4.978132803335958, 4.030197141349241, 5.014433875551218, 5.811830481276643, 7.749062454970366, 8.707095835510293, 9.631124359044396, 10.59291600181668, 11.572432387675766, 12.578358458981809, 13.631222063151473, 14.644316772881945, 13.572512617648195, 12.608983171840284, 11.629780516317219, 10.630505121724214, 9.692504423954162, 8.788518631519171, 7.738536250278095, 6.827247287374094, 5.955336915682055, 5.012847499656884, 5.983689489006805, 6.852497836669522, 8.774410942228174, 9.665262820856363, 10.647325391487417, 11.518685980781528, 12.569663648936663, 13.543769230467063, 14.592342800754228, 15.422496352574408, 14.455073672175484, 13.510616918521023, 12.585266798287307, 11.65595462506381, 10.623195029201836, 9.783293997251114, 8.753582955299269, 7.764842702263129, 6.978693804453794, 6.084242708937428, 6.936444803019463, 7.870584867265779, 9.705165749747056, 10.730713692960016, 11.690835377302088, 12.476618788181005, 13.47637719764245, 14.475333677143276, 15.455027953866727, 16.391807741277052, 15.43738654036078, 14.509642651174707, 13.522919037299069, 12.618637436629143, 11.661108609058815, 10.800285146860766, 9.786733275097736, 8.756564579389753, 7.941717694292804, 7.103046408793498, 7.950754273194801, 8.802146097032564, 10.683630018842706, 11.630503304240841, 11.888512050654063, 12.61109878270839, 13.541456135952277, 14.496580177741022, 15.443385438199584, 16.45986068560458, 16.381197203571563, 15.463727034617511, 14.532568666815626, 13.617230755031741, 12.688661537569146, 11.748213180911954, 10.800703897632719, 9.805743099109556, 8.901910425602022, 8.083062810217735, 8.916439485930983, 9.766356487998321, 11.68043731875385, 11.778647291247882, 10.909198905796378, 11.61056192402675, 12.607519870900635, 13.597185955348364, 14.490842454280157, 15.445866185991271, 16.43201057596659, 16.44198212343558, 15.504650544729238, 14.553324621945695, 13.683494527778631, 12.80623720008472, 11.778795110259432, 10.741271962861445, 9.864152379189262, 9.06123563610234, 9.983323043378775, 10.71624795086513, 11.4958740928365, 10.759628300472379, 9.87730780250918, 10.677870211859553, 11.63992839749875, 12.527695784089254, 13.483215866278382, 14.514472293058319, 15.4725025197648, 16.52130152648072, 16.449233693606246, 15.516780244958506, 14.71190286705217, 13.78904839249714, 12.804026718447, 11.770250755148531, 10.830797114146563, 10.094513490933847, 11.05249985792423, 11.73960469871492], [10.597244851272226, 11.115406937203922, 11.99098190183892, 12.721852058000298, 13.738589254692176, 14.717985651478875, 15.732267554400712, 16.66844028028138, 17.458103239473502, 17.354602087680025, 16.442319167461783, 15.415843577175632, 14.451900904535238, 13.461908005893136, 12.505308475038559, 11.637546959660758, 10.681126428409048, 9.735286387896801, 8.824462226964128, 9.61294940086379, 9.624845203274788, 10.569929297628047, 11.548386504421229, 12.596966678403543, 13.532120083128843, 14.509333296079646, 15.57035918472772, 16.50558491628241, 17.357526066937847, 16.362448384764775, 15.477247257655556, 14.547614248254291, 13.585263803583384, 12.616864518920456, 11.578343082225823, 10.571973200888312, 9.60901282974308, 8.791539597071488, 7.891666095441462, 8.684255097070908, 8.68419868406917, 9.651022064983877, 10.686851348222351, 11.568072805250578, 12.567009364150184, 13.565478982174195, 14.588310212080987, 15.606350556793716, 16.382101756777942, 15.429272810219873, 14.589523208445362, 13.610114802324972, 12.563703887926351, 11.615119891853643, 10.642120001986877, 9.647441664063157, 8.627067412133336, 7.821261326496471, 6.899622597974711, 7.746488546259218, 7.651204837446754, 8.689612990144731, 9.655751016886217, 10.605562181258291, 11.614059468085516, 12.647254132384333, 13.63087363549411, 14.605688255233822, 15.421803526266263, 14.47570645936228, 13.529224194070075, 12.597751097846531, 11.650663908457915, 10.617702188733974, 9.69781384047449, 8.632438845357697, 7.673401195867205, 6.7663919051614405, 5.847674738749285, 6.759634474099379, 6.70618153718125, 7.7378657364752454, 8.705708310529571, 9.745391011408875, 10.709597877872154, 11.643245806580707, 12.632297451855727, 13.575033365478548, 14.459915319157153, 13.441712121057037, 12.587996715868988, 11.667659343358737, 10.674691288981073, 9.691093850975435, 8.627684965800148, 7.670854609852611, 6.693187774696218, 5.8049266844109875, 4.827689779872675, 5.768280933153061, 5.854037086662613, 6.809243088159343, 7.800650101762595, 8.828575303261271, 9.857350514739782, 10.794957574454978, 11.835217401303936, 12.778960895517708, 13.449696650255044, 12.464044796635038, 11.529454807777244, 10.665562461226338, 9.673331654940634, 8.701920454226478, 7.758497033136436, 6.712233181015385, 5.737459238219881, 4.788676622966144, 3.8931310673486657, 4.923408975951695, 4.866321019989353, 5.841906516171143, 6.8991158152589716, 7.943737429617649, 8.920009681471722, 9.893603337162086, 10.848368060712103, 11.832866948801398, 12.600261516991852, 11.586572640740368, 10.580787450555544, 9.615006446768014, 8.684525908337548, 7.708177618911686, 6.700360838612036, 5.764070522068633, 4.804625208702635, 3.8540567593195827, 2.929012751639503, 3.93436668803332, 3.987625101626474, 4.97829268452523, 5.907964814939644, 6.919644332065129, 7.940401372593106, 8.908140661320079, 9.894800719887359, 10.886358166361298, 11.703080847886362, 10.735878378343822, 9.676276169106805, 8.720597699859816, 7.752431572475563, 6.714386070467365, 5.730110996075229, 4.788017480778876, 3.8406928908802165, 2.9088352106016924, 1.989293586593728, 2.9678053790694356, 3.0590250455223167, 3.9762254137259454, 4.955010427822698, 5.971262997918087, 6.998004185948422, 8.016707819094622, 9.040778603436223, 10.027237424879164, 10.769505405319933, 9.804802408532346, 8.80915640338994, 7.7694302109829145, 6.80976693348817, 5.74603855234649, 4.792429829356712, 3.854690424037928, 2.8500418989504066, 1.9066111588063628, 0.9479224233646284, 2.007253166988738, 2.059061221846047, 3.0020351732199337, 4.048687280579083, 5.094496470898851, 6.0778875570548845, 7.074073813999904, 8.148658850127196, 9.084065058354042, 10.00250302575018, 9.067107513506246, 8.113789921238492, 7.130940851455042, 6.118547541621918, 5.184994696852357, 4.110249906469118, 3.0434112834195655, 1.9694390578863246, 0.9549169171431225, 0.0, 0.9879192417559546, 3.024455663715721, 3.9746174130987253, 4.955590275161497, 5.963376721633541, 6.905275201406775, 7.971502925529988, 8.917147551293858, 9.96665225872343, 10.847235232264076, 9.870406808817435, 8.843264880267757, 7.787270646135519, 6.856122648029255, 5.909153262253871, 4.9839528188504065, 4.003114874141801, 2.964013838633015, 2.0255313706501807, 1.0297699373442668, 1.9995674571477742, 3.9663418217910236, 4.944112799915219, 5.893497606786131, 6.853180380081285, 7.786452641029699, 8.774006544756903, 9.743416670664018, 10.800829562782301, 11.864836601184763, 10.79881525020926, 9.80252103388528, 8.812771229340182, 7.810526006055583, 6.890829319646116, 5.8997853889547445, 4.920557774268286, 3.9622593133936674, 3.026339567333235, 2.0547238611638665, 2.9320296687280294, 4.892490632934713, 5.879933742598868, 6.809547565318547, 7.784477694283231, 8.762171747094266, 9.756907741370487, 10.7305615950595, 11.772009878568552, 12.809162936821437, 11.852296897564134, 10.810573992886514, 9.838649114703772, 8.785454616723827, 7.881599415063849, 6.8879745521676945, 5.864056314241676, 4.966910528971247, 3.9966639456244923, 3.1234612555204304, 3.9183181601405668, 5.848296270279972, 6.809526019840586, 7.749004508590166, 8.690743970029802, 9.680075446524702, 10.718070382909696, 11.754117172440388, 12.747099880809607, 13.605926368943969, 12.62879756936191, 11.645378200101774, 10.635821091331305, 9.688419666353944, 8.725594449406303, 7.7416007795842035, 6.801583103601535, 5.933049720479081, 4.985114058492364, 4.131162035974054, 4.856913564133521, 6.7941455378272435, 7.75217891836717, 8.676207441901271, 9.637999084673556, 10.617515470532641, 11.623441541838684, 12.676305146008348, 13.72065975795605, 14.527429534791318, 13.563900088983408, 12.58469743346034, 11.585422038867335, 10.647421341097283, 9.743435548662292, 8.693453167421216, 7.782164204517217, 6.910253832825178, 5.967764416800007, 5.100417649429641, 5.8975809195263995, 7.819494025085052, 8.71034590371324, 9.692408474344294, 10.563769063638404, 11.614746731793538, 12.588852313323939, 13.637425883611103, 14.620047253032796, 15.409990589318605, 14.465533835664145, 13.540183715430429, 12.610871542206931, 11.578111946344958, 10.738210914394235, 9.70849987244239, 8.719759619406252, 7.933610721596917, 7.039159626080551, 6.053172963442299, 6.946845950088134, 8.750248832603935, 9.775796775816893, 10.735918460158965, 11.52170187103788, 12.521460280499324, 13.52041676000015, 14.500111036723602, 15.482124984158519, 16.392303457503903, 15.464559568317828, 14.47783595444219, 13.573554353772264, 12.616025526201936, 11.755202064003885, 10.741650192240858, 9.711481496532876, 8.896634611435926, 8.029587712426999, 7.067482433617637, 7.878407179854919, 9.728713101699585, 10.67558638709772, 11.661618161099643, 12.453885969396897, 13.520620787611936, 14.47574482940068, 15.432046017270226, 16.448521264675218, 17.336114120714686, 16.418643951760632, 15.487485583958748, 14.57214767217486, 13.643578454712266, 12.703130098055073, 11.755620814775842, 10.760660016252679, 9.856827342745145, 8.99397109729676, 8.033167646353819, 8.842617570820675, 10.756698401576203, 10.901453442276125, 11.832304949952373, 12.56547884116987, 13.562436788043755, 14.552102872491483, 15.445759371423277, 16.40078310313439, 17.38692749310971, 17.396899040578703, 16.45956746187236, 15.508241539088814, 14.63841144492175, 13.76115411722784, 12.733712027402555, 11.696188880004568, 10.819069296332385, 9.972143923181365, 9.10005120380161, 9.792509033687484, 10.61868024386474, 9.882434451500622, 10.800413846665174, 11.632787129002672, 12.59484531464187, 13.482612701232373, 14.438132783421501, 15.469389210201438, 16.42741943690792, 17.47621844362384, 17.40415061074937, 16.471697162101627, 15.66681978419529, 14.743965309640263, 13.758943635590123, 12.725167672291654, 11.785714031289686, 11.005421778012872, 10.169228018347066, 10.815865781537275], [9.827161286941378, 10.775881617977355, 11.769223953521344, 12.70824660249706, 13.690580664216572, 14.695278979305423, 15.681134233911228, 16.676835028731123, 17.636790649460988, 18.342521329435982, 17.43023840921774, 16.40376281893159, 15.439820146291195, 14.449827247649093, 13.493227716794516, 12.625466201416716, 11.669045670165005, 10.723205629652755, 9.793894052818745, 8.842865836532942, 8.85476163894394, 9.799845733297198, 10.77830294009038, 11.767848523509116, 12.703001928234416, 13.680215141185219, 14.741241029833292, 15.676466761387983, 16.659871409032704, 17.350367626520733, 16.46516649941151, 15.535533490010247, 14.57318304533934, 13.604783760676414, 12.56626232398178, 11.55989244264427, 10.596932071499037, 9.779458838827441, 8.861097921296079, 7.914171532740059, 7.8790917675203245, 8.845915148435033, 9.87575802445611, 10.73895465035615, 11.737891209255757, 12.736360827279768, 13.740297318049482, 14.75833766276221, 15.684447098872797, 16.41719205197583, 15.577442450201318, 14.598034044080928, 13.551623129682307, 12.603039133609599, 11.630039243742832, 10.635360905819113, 9.614986653889293, 8.809180568252426, 7.887541839730664, 6.976404981928368, 6.846097920897908, 7.884506073595885, 8.82663286199179, 9.776444026363864, 10.784941313191089, 11.799241238352828, 12.782860741462605, 13.746945184302275, 14.703117375595843, 15.463625701118238, 14.517143435826032, 13.585670339602487, 12.63858315021387, 11.605621430489927, 10.685733082230445, 9.620358087113653, 8.66132043762316, 7.754311146917395, 6.835593980505239, 5.989550909768529, 5.901074620632404, 6.908747581580817, 7.876590155635144, 8.916272856514448, 9.880479722977727, 10.795232912549201, 11.784284557824222, 12.716290294547, 13.698721780446279, 14.429631362812994, 13.575915957624945, 12.655578585114693, 11.662610530737028, 10.679013092731388, 9.615604207556103, 8.658773851608567, 7.681107016452174, 6.792845926166942, 5.81560902162863, 4.998197368822212, 4.954032080031913, 5.909238081528644, 6.900645095131895, 7.928570296630571, 8.924033542011102, 9.861640601726299, 10.866795622770933, 11.791041653761754, 12.763954514197309, 13.451964038390996, 12.5173740495332, 11.653481702982296, 10.66125089669659, 9.689839695982434, 8.74641627489239, 7.700152422771341, 6.725378479975836, 5.7765958647221, 4.88105030910462, 4.023403969320995, 3.9663160133586532, 4.941901509540442, 5.911196573503018, 6.955818187861695, 7.932090439715767, 8.905684095406132, 9.860448818956149, 10.844947707045444, 11.803103771420131, 12.574491882496325, 11.568706692311501, 10.602925688523971, 9.672445150093505, 8.696096860667641, 7.68828008036799, 6.751989763824588, 5.79254445045859, 4.841976001075538, 3.9169319933954574, 3.03436168140262, 3.0062340809043615, 3.9969016638031176, 4.920045573183691, 5.931725090309175, 6.9524821308371525, 7.920221419564125, 8.906881478131405, 9.898438924605344, 10.940351111919407, 11.723797620099777, 10.66419541086276, 9.708516941615772, 8.740350814231519, 7.70230531222332, 6.718030237831184, 5.775936722534831, 4.828612132636171, 3.8967544523576474, 2.977212828349683, 2.026016376670691, 2.0776340248002043, 2.9883061719699917, 3.967091186066744, 4.983343756162133, 6.010084944192468, 7.028788577338667, 8.05285936168027, 9.03931818312321, 10.01976047621171, 10.792721650288302, 9.797075645145895, 8.75734945273887, 7.7976861752441256, 6.733957794102445, 5.780349071112667, 4.8426096657938835, 3.8379611407063616, 2.8945304005623176, 1.935841665120583, 1.0654641645899934, 1.0711419800900928, 2.0141159314639796, 3.0607680388231286, 4.106577229142896, 5.08996831529893, 6.0861545722439505, 7.160739608371243, 8.096145816598089, 9.065947508511387, 10.001343020755321, 9.101709162994446, 8.118860093210996, 7.106466783377872, 6.1729139386083105, 5.098169148225072, 4.03133052517552, 2.957358299642279, 1.9428361588990772, 0.9879192417559546, 0.0, 2.0365364219597666, 2.9866981713427707, 3.9676710334055425, 4.975457479877586, 5.917355959650822, 6.983583683774034, 7.929228309537904, 8.978733016967476, 10.015652591801844, 10.85832605057339, 9.831184122023712, 8.775189887891473, 7.844041889785209, 6.897072504009825, 5.97187206060636, 4.991034115897755, 3.9482471823598075, 3.0097647143769732, 2.0120976010027207, 1.0116482153918196, 2.978422580035069, 3.9561935581592644, 4.905578365030176, 5.86526113832533, 6.798533399273745, 7.786087303000947, 8.755497428908065, 9.812910321026347, 10.876917359428809, 11.786734491965216, 10.790440275641236, 9.800690471096138, 8.798445247811536, 7.87874856140207, 6.884018732681538, 5.90479111799508, 4.94649265712046, 4.010572911060027, 2.9940893109804687, 1.9441104269720748, 3.904571391178758, 4.8920145008429134, 5.821628323562592, 6.796558452527276, 7.774252505338311, 8.768988499614531, 9.742642353303545, 10.784090636812596, 11.821243695065482, 12.792601589471548, 11.798493234642468, 10.826568356459726, 9.773373858479781, 8.865832758790642, 7.872207895894488, 6.848289657968469, 5.908019645099418, 4.937773061752663, 3.9727869951364383, 2.930398918384612, 4.8603770285240175, 5.8216067780846315, 6.761085266834211, 7.702824728273848, 8.692156204768748, 9.73015114115374, 10.766197930684433, 11.759180639053653, 12.77394315801325, 13.613030913088702, 12.629611543828567, 11.6200544350581, 10.672653010080738, 9.709827793133098, 8.725834123310998, 7.785816447328329, 6.874158836607252, 5.852681675706202, 4.811687913307412, 3.8689943223775662, 5.806226296071289, 6.764259676611215, 7.688288200145316, 8.6500798429176, 9.629596228776688, 10.63552230008273, 11.688385904252394, 12.732740516200096, 13.706928762354456, 14.5481334327102, 13.568930777187134, 12.56965538259413, 11.631654684824078, 10.727668892389087, 9.67768651114801, 8.722502139077324, 7.709780103659424, 6.767290687634253, 5.780943526762998, 4.909661677770445, 6.831574783329097, 7.722426661957285, 8.70448923258834, 9.575849821882448, 10.626827490037583, 11.600933071567983, 12.649506641855147, 13.63212801127684, 14.599550691675764, 15.449767179390939, 14.524417059157223, 13.595104885933726, 12.562345290071752, 11.72244425812103, 10.692733216169184, 9.66009755396636, 8.733136992431163, 7.795049347442416, 6.733698840775657, 5.958926708332179, 7.762329590847981, 8.78787753406094, 9.747999218403011, 10.533782629281925, 11.533541038743369, 12.532497518244195, 13.512191794967647, 14.494205742402563, 15.448626943318837, 16.448792912044624, 15.462069298168984, 14.557787697499059, 13.60025886992873, 12.721942919131422, 11.708391047368394, 10.651819431092983, 9.696160882270172, 8.710113589760356, 7.748008310950994, 6.890487938098963, 8.740793859943631, 9.687667145341766, 10.673698919343689, 11.465966727640941, 12.53270154585598, 13.487825587644725, 14.44412677551427, 15.460602022919264, 16.39243760652962, 17.380480416312768, 16.47171892768554, 15.494052567011975, 14.56548334954938, 13.625034992892187, 12.618662005725817, 11.623701207202654, 10.639169612386103, 9.674496974630117, 8.713693523687176, 7.854698329064719, 9.768779159820248, 10.68184526429546, 11.64302129702474, 12.466503586322581, 13.466637810907622, 14.539411551940946, 15.3966697594337, 16.351693491144815, 17.337837881120134, 18.32086500461286, 17.443800805599153, 16.430146433925927, 15.560316339758865, 14.658692454957166, 13.59675321835253, 12.559230070954543, 11.601411565973343, 10.652669800514722, 9.780577081134968, 8.804589791931528, 9.848596679533891, 10.851866277355239, 11.788333088421128, 12.62070637075863, 13.582764556397827, 14.47053194298833, 15.426052025177459, 16.457308451957395, 17.415338678663876, 18.464137685379796, 18.350556316863592, 17.39360205693874, 16.588724679032403, 15.607006500590238, 14.621984826540098, 13.561076816478408, 12.568056300930644, 11.68594765534623, 10.8060464927504, 9.827946539781319], [9.777312526180754, 10.726032857216731, 11.71937519276072, 12.616346449897357, 13.59868051161687, 14.60337882670572, 15.589234081311526, 16.58493487613142, 17.49826606573622, 18.389585487092805, 18.260867031214122, 17.234391440927972, 16.27044876828758, 15.280455869645476, 14.323856338790899, 13.352820511534237, 12.314319577123637, 11.852257827411732, 10.871054447938874, 9.930098875156405, 8.804912878183316, 9.749996972536575, 10.728454179329757, 11.675948370909413, 12.611101775634713, 13.588314988585516, 14.64934087723359, 15.58456660878828, 16.521346825307937, 17.397431784177556, 18.351537042186337, 17.52796179001032, 16.489237772037594, 15.50796129567284, 14.469439858978207, 13.463069977640696, 12.500109606495464, 11.596594941574857, 10.609975624534755, 9.663049235978734, 7.787191614920622, 8.75401499583533, 9.783857871856407, 10.647054497756448, 11.645991056656054, 12.644460674680065, 13.635786763155824, 14.653827107868553, 15.545922515148032, 16.464256209632655, 17.50500135040777, 16.611339818693498, 15.553903840465374, 14.605319844392666, 13.632319954525899, 12.57604797395318, 11.51816418888572, 10.68123777196507, 9.727884311967824, 8.725282685167045, 6.754197768298205, 7.792605920996182, 8.734732709392087, 9.684543873764161, 10.693041160591386, 11.69473068345917, 12.678350186568947, 13.60842060057751, 14.564592791871078, 15.510689858775061, 16.49106403400907, 15.621206193851322, 14.65757514518793, 13.612466576402417, 12.692578228142935, 11.627203233026142, 10.56449797261959, 9.62636835063004, 8.675936452742398, 7.738428613007206, 5.8091744680327, 6.816847428981114, 7.784690003035441, 8.824372703914744, 9.788579570378023, 10.690722357655543, 11.679774002930564, 12.577765710822236, 13.560197196721514, 14.534371983280446, 15.549836555807985, 14.692115007074461, 13.699146952696797, 12.685858238643878, 11.622449353468593, 10.665618997521056, 9.687952162364663, 8.664903129879587, 7.687666225341275, 6.7470750720608885, 4.86213192743221, 5.81733792892894, 6.808744942532192, 7.836670144030867, 8.819522987117445, 9.757130046832641, 10.728271039046168, 11.652517070036989, 12.625429930472544, 13.556704658858447, 14.491294647716241, 13.690018124942062, 12.697787318656358, 11.726376117942202, 10.754184762630972, 9.70699756868383, 8.732223625888325, 7.706318605738852, 6.77035642336786, 5.789926459183255, 3.868929839308847, 4.844515335490636, 5.806686018609361, 6.851307632968038, 7.827579884822111, 8.800268629017374, 9.721924235231384, 10.706423123320679, 11.664579187695367, 12.620924631897003, 13.605243114271268, 12.639462110483738, 11.708981572053272, 10.73263328262741, 9.724816502327759, 8.788526185784354, 7.8290808724183565, 6.7716987420922905, 5.8062381076586975, 4.80088417126488, 2.901723526010705, 3.892391108909461, 4.815535018290034, 5.827214535415519, 6.847971575943496, 7.814805953175369, 8.76835689440664, 9.759914340880579, 10.764503268821137, 11.60427698604994, 12.655988223651006, 11.745053363575538, 10.776887236191286, 9.738841734183087, 8.754566659790951, 7.812473144494597, 6.865148554595938, 5.9332908743174135, 4.953652379485224, 3.9623960677417753, 1.973123469906548, 2.883795617076335, 3.8625806311730875, 4.878833201268477, 5.875450812786032, 6.832762890475727, 7.763722639211132, 8.709087666044343, 9.689529959132843, 10.641214935700587, 11.604047725178257, 10.793885874698637, 9.834222597203892, 8.770494216062213, 7.816885493072434, 6.879146087753649, 5.874497562666128, 4.931066822522084, 3.9723780870803496, 3.0248953484401273, 0.9666314251964364, 1.9096053765703231, 2.9562574839294724, 3.937123822268414, 4.824780533184452, 5.8209667901294715, 6.830509091292376, 7.7659152995192215, 8.73571699143252, 9.671112503676454, 10.624430095944208, 9.831658942836363, 8.898105902335491, 7.969578777831685, 6.95014448405002, 5.976845103469606, 4.980632124243099, 3.979372580858844, 3.024455663715721, 2.0365364219597666, 0.0, 0.9501617493830042, 1.9311346114457761, 2.9389210579178195, 3.8808195376910546, 4.947047261814268, 5.892691887578137, 6.94219659500771, 7.979116169842077, 8.955944593288718, 9.857291518873328, 8.80129728474109, 7.870149286634825, 6.923179900859441, 5.997979457455976, 5.01714151274737, 3.961487173535935, 3.0230047055531006, 2.025337592178848, 1.024888206567947, 0.9545730943514597, 1.9196571361994978, 2.86904194307041, 3.8287247163655644, 4.761996977313979, 5.7495508810411815, 6.718961006948298, 7.776373899066582, 8.840380937469043, 9.913671274332637, 10.816547672490852, 9.826797867945753, 8.824552644661152, 7.9048559582516855, 6.897258723857664, 5.918031109171206, 4.959732648296587, 4.0238129022361555, 3.007329302156596, 1.9573504181482022, 1.961773884510175, 2.855478078883147, 3.7850919016028257, 4.7600220305675105, 5.737716083378546, 6.732452077654766, 7.70610593134378, 8.747554214852832, 9.784707273105717, 10.756065167511784, 11.815214056190374, 10.852675753309342, 9.799481255329397, 8.877223161852795, 7.88359829895664, 6.8596800610306214, 5.913567084019127, 4.943320500672373, 3.9783344340561477, 2.935946357304321, 2.972594996855438, 3.8185011543771847, 4.724548844874445, 5.666288306314081, 6.655619782808982, 7.693614719193976, 8.729661508724668, 9.722644217093887, 10.737406736053483, 11.714535535635543, 12.641001946890718, 11.63144483812025, 10.68404341314289, 9.721218196195249, 8.737224526373149, 7.797206850390481, 6.879706275526962, 5.85822911462591, 4.8172353522271205, 3.8745417612972752, 3.9184442644027095, 4.855177370346412, 5.65175177818555, 6.613543420957835, 7.593059806816921, 8.598985878122964, 9.651849482292628, 10.69620409424033, 11.67039234039469, 12.6339217862026, 13.580321180249285, 12.581045785656281, 11.643045087886229, 10.739059295451238, 9.689076914210162, 8.728049577997034, 7.715327542579133, 6.772838126553962, 5.786490965682708, 4.9152091166901535, 4.943792751660518, 5.8133443556924815, 6.71623451958188, 7.539313399922682, 8.590291068077816, 9.564396649608216, 10.61297021989538, 11.595591589317074, 12.563014269715998, 13.507471023370458, 14.432821143604174, 13.606495288995877, 12.573735693133903, 11.733834661183181, 10.704123619231336, 9.665644992886069, 8.738684431350872, 7.800596786362125, 6.739246279695366, 5.909490556704301, 5.874547559179401, 6.878795227796136, 7.75974450539655, 8.497246207322158, 9.497004616783602, 10.495961096284429, 11.47565537300788, 12.457669320442797, 13.41209052135907, 14.450088172175906, 15.370473382615936, 14.56917810056121, 13.611649272990881, 12.727490358051131, 11.713938486288104, 10.657366870012693, 9.701708321189882, 8.715661028680065, 7.753555749870704, 6.841051786471086, 6.853011828275051, 7.799885113673186, 8.785916887675109, 9.429430305681175, 10.496165123896214, 11.451289165684958, 12.407590353554504, 13.424065600959498, 14.355901184569852, 15.343943994353, 16.275102362154886, 15.499600005931685, 14.57103078846909, 13.630582431811897, 12.624209444645526, 11.629248646122363, 10.644717051305813, 9.680044413549826, 8.719240962606886, 7.805262177436842, 7.896615037480606, 8.794063232626879, 9.75523926535616, 10.429967164362814, 11.430101388947856, 12.50287512998118, 13.360133337473933, 14.315157069185046, 15.301301459160367, 16.284328582653092, 17.221660161359434, 16.435693872845636, 15.565863778678574, 14.664239893876875, 13.60230065727224, 12.564777509874252, 11.606959004893053, 10.658217239434432, 9.786124520054678, 8.75515364030365, 8.924368032155456, 9.813082223402382, 10.787130368643359, 11.362658876530013, 12.396240238647596, 13.422876362574833, 14.367759925475708, 15.35104714221008, 16.296784552371392, 17.355792646348515, 18.166243310236442, 17.39914949585845, 16.594272117952116, 15.612553939509947, 14.627532265459807, 13.566624255398118, 12.573603739850354, 11.691495094265939, 10.756610341122522, 9.77851038815344], [10.72747427556376, 10.116620265580199, 11.109755591377978, 11.876606395718156, 12.858940457437669, 13.863638772526519, 14.743057367123239, 15.738758161943133, 16.548104316353218, 17.4394237377098, 17.31070528183112, 16.28422969154497, 15.320287018904574, 14.330294120262472, 13.373694589407895, 12.402658762151233, 11.364157827740632, 10.953228207563814, 10.046465660566053, 10.787073032855762, 9.755074627566321, 9.140584380900043, 10.078949280369136, 10.936208316730212, 11.871361721455512, 12.848574934406315, 13.803164163045302, 14.738389894599994, 15.571185075924932, 16.44727003479455, 17.40137529280333, 17.226512587171023, 16.263507877096828, 15.282231400732076, 14.300659982220632, 13.399231797551833, 12.4362714264066, 11.896974998389128, 10.97926179208872, 10.613210985361741, 8.737353364303626, 8.13992855911123, 9.044117817677206, 9.907314443577247, 10.906251002476854, 11.86227783794684, 12.779562491557552, 13.71520951375353, 14.595760765765027, 15.514094460249648, 16.554839601024764, 17.51894873345295, 16.50406558984838, 15.555481593775673, 14.582481703908906, 13.526209723336187, 12.468325938268727, 11.631399521348076, 10.678046061350829, 9.675444434550052, 7.70435951768121, 7.178519484272083, 7.9949926552128865, 8.94480381958496, 9.953301106412185, 10.838506411860898, 11.822125914970675, 12.658258851194505, 13.614431042488073, 14.560528109392056, 15.540902284626071, 16.50658502897451, 15.607736894570937, 14.562628325785424, 13.64273997752594, 12.577364982409147, 11.514659722002595, 10.576530100013045, 9.626098202125403, 8.688590362390212, 6.759336217415705, 6.140344552012996, 7.04494994885624, 7.998827438752829, 8.963034305216107, 9.834498086057273, 10.823549731332294, 11.627603961439231, 12.61003544733851, 13.584210233897444, 14.599674806424984, 15.576493274486715, 14.6493087020798, 13.636019988026884, 12.572611102851598, 11.615780746904061, 10.638113911747668, 9.615064879262592, 8.63782797472428, 7.6972368214438935, 5.812293676815215, 5.140835051960822, 5.998251619913864, 6.999814068409143, 7.97882599356986, 8.90090577523437, 9.778109289663163, 10.702355320653984, 11.675268181089539, 12.606542909475445, 13.54113289833324, 14.567578976155168, 13.647949068039361, 12.676537867325205, 11.704346512013977, 10.657159318066835, 9.68238537527133, 8.656480355121857, 7.720518172750865, 6.74008820856626, 4.819091588691852, 4.127094513088652, 4.965989025061776, 6.010610639420452, 6.986882891274525, 7.850106879634371, 8.77176248584838, 9.756261373937674, 10.714417438312362, 11.670762882514001, 12.676548072698825, 13.589623859866741, 12.659143321436275, 11.682795032010413, 10.674978251710762, 9.73868793516736, 8.77924262180136, 7.7218604914752955, 6.7563998570417025, 5.7510459206478854, 3.85188527539371, 3.1160325924503356, 3.9748380247424486, 4.986517541867933, 5.956676896769926, 6.864644203792365, 7.818195145023636, 8.809752591497574, 9.814341519438136, 10.65411523666694, 11.705826474268004, 12.609700887977532, 11.727048985574289, 10.68900348356609, 9.704728409173955, 8.762634893877602, 7.815310303978942, 6.883452623700418, 5.903814128868228, 4.91255781712478, 2.9232852192895526, 2.04309862352875, 3.0218836376255025, 3.9561620803801363, 4.925289063403028, 5.8826011410927235, 6.813560889828128, 7.758925916661339, 8.739368209749841, 9.691053186317585, 10.653885975795255, 11.65853339910063, 10.784384346586895, 9.720655965445216, 8.767047242455437, 7.829307837136653, 6.824659312049132, 5.881228571905088, 4.922539836463354, 3.9750570978231314, 1.9167931745794407, 1.068908383022738, 2.038655834311801, 2.98696207288541, 3.874618783801448, 4.870805040746468, 5.880347341909372, 6.815753550136218, 7.785555242049518, 8.720950754293453, 9.674268346561206, 10.657117416344656, 9.848267651718496, 8.919740527214689, 7.900306233433024, 6.92700685285261, 5.930793873626103, 4.9295343302418475, 3.9746174130987253, 2.9866981713427707, 0.9501617493830042, 0.0, 0.9809728620627719, 1.9887593085348154, 2.9306577883080505, 3.9968855124312634, 4.942530138195133, 5.992034845624705, 7.028954420459072, 8.005782843905713, 9.032924772455392, 9.751459034124093, 8.820311036017829, 7.873341650242444, 6.948141206838979, 5.9673032621303745, 4.911648922918939, 3.9731664549361048, 2.9754993415618523, 1.9750499559509511, 1.904734843734464, 0.9694953868164937, 1.9188801936874058, 2.8785629669825603, 3.811835227930975, 4.799389131658177, 5.768799257565294, 6.8262121496835775, 7.890219188086039, 8.963509524949634, 9.959803741273614, 10.776959617328757, 9.774714394044157, 8.855017707634689, 7.847420473240669, 6.868192858554211, 5.909894397679592, 4.973974651619159, 3.9574910515396002, 2.9075121675312063, 2.9119356338931794, 1.905316329500143, 2.8349301522198216, 3.8098602811845064, 4.7875543339955415, 5.7822903282717615, 6.755944181960776, 7.797392465469827, 8.834545523722712, 9.805903418128779, 10.86505230680737, 11.802837502692347, 10.749643004712402, 9.8273849112358, 8.833760048339645, 7.809841810413626, 6.863728833402131, 5.893482250055377, 4.928496183439152, 3.8861081066873253, 3.8295691545547945, 2.868339404994181, 3.7743870954914405, 4.716126556931077, 5.705458033425978, 6.7434529698109715, 7.779499759341664, 8.772482467710883, 9.78724498667048, 10.76437378625254, 11.747793155512674, 12.581606587503256, 11.634205162525895, 10.671379945578254, 9.687386275756154, 8.747368599773486, 7.829868024909966, 6.804639214029881, 5.763645451631091, 4.820951860701245, 4.7754184221020655, 3.905015620963408, 4.701590028802546, 5.663381671574831, 6.642898057433917, 7.6488241287399585, 8.701687732909622, 9.746042344857324, 10.720230591011687, 11.683760036819598, 12.719631924061366, 13.531207535039286, 12.593206837269234, 11.689221044834243, 10.639238663593167, 9.674459677401003, 8.661737641983104, 7.719248225957932, 6.732901065086677, 5.82706085090122, 5.800766909359874, 4.863182606309478, 5.766072770198876, 6.589151650539677, 7.640129318694812, 8.614234900225211, 9.662808470512376, 10.645429839934069, 11.612852520332993, 12.557309273987453, 13.48265939422117, 14.418867264360953, 13.523897442516908, 12.683996410566186, 11.65428536861434, 10.612055092290039, 9.685094530754842, 8.747006885766096, 7.685656379099336, 6.766464714403657, 6.731521716878757, 5.928633478413133, 6.809582756013546, 7.547084457939154, 8.546842867400597, 9.545799346901424, 10.525493623624875, 11.507507571059792, 12.461928771976066, 13.4999264227929, 14.42031163323293, 15.422654177262588, 14.561811022373886, 13.673900457455101, 12.660348585692073, 11.603776969416662, 10.648118420593851, 9.585616999960257, 8.623511721150894, 7.698025944170442, 7.709985985974407, 6.975296326300364, 7.876896500650558, 8.47926855629817, 9.546003374513209, 10.501127416301953, 11.457428604171499, 12.473903851576493, 13.405739435186847, 14.393782244969994, 15.32494061277188, 16.345704425952732, 15.44098675974928, 14.500538403092087, 13.494165415925716, 12.499204617402553, 11.514673022586003, 10.550000384830016, 9.589196933887076, 8.662236335136198, 8.753589195179963, 7.969474445254057, 8.856209645508242, 9.47980541497981, 10.47993963956485, 11.552713380598174, 12.409971588090926, 13.36499531980204, 14.35113970977736, 15.334166833270087, 16.271498411976427, 17.281798292866686, 16.435819749958764, 15.534195865157065, 14.47225662855243, 13.434733481154442, 12.476914976173243, 11.528173210714622, 10.64694246199017, 9.612127798003007, 9.781342189854813, 8.98849343602956, 9.888100748795441, 10.412497127147008, 11.446078489264591, 12.472714613191828, 13.417598176092701, 14.400885392827073, 15.346622802988387, 16.40563089696551, 17.216081560853436, 17.534510393725093, 16.728180147447862, 15.736390019892701, 14.822680788415271, 13.805764937976532, 12.812744422428768, 12.075290025093983, 11.062799184437054, 10.635484545852798], [11.70844713762653, 10.988228673141922, 10.180674161179846, 10.947524965520024, 11.929859027239537, 12.915598728814475, 13.762084505060468, 14.757785299880362, 15.567131454290443, 16.458450875647028, 16.34914927088632, 15.322673680600168, 14.358731007959774, 13.368738109317672, 12.412138578463095, 11.441102751206433, 10.402601816795833, 9.991672196619016, 10.877032348692321, 11.68474466735032, 10.736047489629092, 10.012192788461766, 9.149867850171004, 10.007126886532081, 10.942280291257381, 11.869643422383374, 12.822191300982531, 13.757417032537223, 14.59021221386216, 15.466297172731778, 16.42040243074056, 16.264956576226222, 15.301951866152027, 14.320675389787276, 13.339103971275831, 12.437675786607034, 11.474715415461802, 10.93541898744433, 11.809828480214987, 11.594183847424512, 9.718326226366397, 9.011536966672953, 8.115036387479075, 8.978233013379116, 9.977169572278722, 10.881304975884069, 11.798589629494781, 12.734236651690757, 13.614787903702254, 14.533121598186876, 15.573866738961991, 16.537975871390177, 16.279918814462544, 15.331334818389836, 14.35833492852307, 13.488651411235244, 12.456660833071545, 11.905697258019345, 11.6590189234136, 10.656417296612823, 8.685332379743981, 8.050127891833805, 7.065911225014756, 8.015722389386829, 9.024219676214054, 9.857533549798127, 10.841153052907904, 11.677285989131732, 12.6334581804253, 13.579555247329283, 14.559929422563297, 15.525612166911735, 16.489243215575126, 15.543601187848195, 14.623712839588713, 13.55833784447192, 12.495632584065367, 11.557502962075818, 10.607071064188174, 9.669563224452983, 7.740309079478477, 7.017679253012112, 6.115868518658109, 7.054654112582605, 8.018860979045883, 8.8535252239945, 9.842576869269521, 10.646631099376458, 11.629062585275737, 12.60323737183467, 13.61870194436221, 14.59552041242394, 15.558653069259595, 14.616992850089655, 13.55358396491437, 12.596753608966834, 11.61908677381044, 10.596037741325365, 9.618800836787052, 8.678209683506665, 6.793266538877987, 6.018169752959938, 5.0691701897157335, 6.055640742238919, 7.023313765985345, 7.919932913171598, 8.79713642760039, 9.721382458591211, 10.694295319026766, 11.62557004741267, 12.560160036270466, 13.586606114092394, 14.557293435219156, 13.657510729387978, 12.68531937407675, 11.638132180129608, 10.663358237334103, 9.63745321718463, 8.701491034813637, 7.721061070629032, 5.800064450754624, 5.004429214087768, 4.036907594863646, 5.066437313250228, 6.03137066369001, 6.869134017571599, 7.7907896237856065, 8.775288511874901, 9.733444576249589, 10.689790020451227, 11.69557521063605, 12.660530973919148, 13.511982789381978, 12.663767894073185, 11.655951113773535, 10.719660797230132, 9.760215483864133, 8.702833353538068, 7.737372719104474, 6.732018782710657, 4.832858137456482, 3.9933672934494515, 3.045756594544318, 4.0423442156977085, 4.975704034707154, 5.883671341729594, 6.837222282960863, 7.828779729434801, 8.833368657375363, 9.673142374604165, 10.72485361220523, 11.628728025914757, 12.579888453519992, 11.669976345628863, 10.685701271236727, 9.743607755940374, 8.796283166041714, 7.86442548576319, 6.884786990931, 5.893530679187553, 3.9042580813523244, 3.024071485591522, 2.092802207427372, 2.9751892183173645, 3.944316201340256, 4.901628279029952, 5.832588027765356, 6.777953054598567, 7.758395347687069, 8.710080324254811, 9.67291311373248, 10.677560537037856, 11.6372238145326, 10.701628827507989, 9.74802010451821, 8.810280699199426, 7.805632174111905, 6.8622014339678605, 5.903512698526127, 4.956029959885903, 2.8977660366422127, 2.0498812450855097, 1.057682972249029, 2.005989210822638, 2.893645921738676, 3.889832178683696, 4.8993744798466, 5.834780688073446, 6.804582379986745, 7.739977892230679, 8.693295484498432, 9.676144554281882, 10.688537864115006, 9.900713389277461, 8.881279095495797, 7.907979714915383, 6.911766735688876, 5.91050719230462, 4.955590275161498, 3.967671033405543, 1.9311346114457761, 0.9809728620627719, 0.0, 1.0077864464720434, 1.9496849262452784, 3.0159126503684917, 3.9615572761323614, 5.011061983561934, 6.047981558396301, 7.0248099818429415, 8.051951910392619, 9.107946144524858, 9.801283898080602, 8.854314512305217, 7.929114068901752, 6.948276124193147, 5.892621784981712, 4.954139316998877, 3.9564722036246245, 2.9560228180137234, 2.885707705797236, 1.9504682488792655, 0.9379073316246338, 1.897590104919788, 2.8308623658682026, 3.818416269595405, 4.787826395502522, 5.845239287620806, 6.9092463260232675, 7.9825366628868615, 8.978830879210841, 9.96858068375594, 10.75568725610693, 9.835990569697461, 8.828393335303442, 7.849165720616984, 6.890867259742365, 5.954947513681931, 4.938463913602373, 3.8884850295939786, 3.8159133983164395, 2.8029879639947004, 1.8733741412750216, 2.828887419121734, 3.8065814719327697, 4.80131746620899, 5.774971319898004, 6.816419603407056, 7.853572661659941, 8.824930556066008, 9.884079444744598, 10.882371054897355, 11.730615866775175, 10.73136267565906, 9.737737812762905, 8.713819574836887, 7.767706597825391, 6.797460014478637, 5.832473947862412, 4.790085871110586, 4.727240789049352, 3.7660110394887383, 2.812831084546641, 3.7545705459862777, 4.741777155369826, 5.7624801077482, 6.798526897278892, 7.791509605648112, 8.806272124607709, 9.783400924189769, 10.766820293449904, 11.776377402220373, 12.538182926949155, 11.575357710001514, 10.591364040179414, 9.651346364196746, 8.733845789333225, 7.702310848524439, 6.661317086125649, 5.7186234951958035, 5.673090056596624, 4.735582309089677, 3.740034017857746, 4.701825660630031, 5.6792171793777655, 6.685143250683808, 7.738006854853471, 8.782361466801174, 9.739257728948916, 10.702787174756827, 11.738659061998595, 12.725978349756403, 13.497184601692494, 12.589366246530938, 11.539383865289862, 10.572131311895562, 9.559409276477663, 8.61691986045249, 7.630572699581236, 6.724732485395778, 6.698438543854432, 5.693749294435747, 4.804516759254076, 5.627595639594878, 6.678573307750012, 7.652678889280412, 8.701252459567577, 9.68387382898927, 10.651296509388194, 11.595753263042655, 12.52110338327637, 13.457311253416155, 14.427875206940168, 13.584141612262881, 12.552453428878296, 11.509726726784598, 10.582766165249401, 9.644678520260655, 8.583328013593896, 7.664136348898215, 7.629193351373315, 6.759200166539402, 5.848026745068746, 6.5855284469943545, 7.585286856455798, 8.584243335956623, 9.563937612680075, 10.545951560114991, 11.500372761031265, 12.5383704118481, 13.458755622288132, 14.46109816631779, 15.418626993888118, 14.571572091949662, 13.558020220186632, 12.501448603911221, 11.54579005508841, 10.483288634454816, 9.521183355645453, 8.595697578665, 8.607657620468965, 7.805863014426633, 6.915340489705758, 7.51771254535337, 8.584447363568408, 9.539571405357153, 10.495872593226698, 11.512347840631692, 12.444183424242047, 13.432226234025194, 14.363384601827079, 15.384148415007932, 16.312717632470527, 15.398210037586646, 14.391837050420275, 13.396876251897112, 12.412344657080562, 11.447672019324575, 10.486868568381635, 9.559907969630757, 9.65126082967452, 8.800041133380326, 7.8946536345634435, 8.51824940403501, 9.51838362862005, 10.591157369653374, 11.448415577146125, 12.403439308857239, 13.38958369883256, 14.372610822325287, 15.309942401031629, 16.320242281921885, 16.77561562465863, 15.770673955319232, 14.878693992387095, 13.841170844989108, 12.850307727187937, 12.1995121398374, 11.544614096484729, 10.509799432497566, 10.67901382434937, 9.819060124155829, 8.926544737850643, 9.450941116202209, 10.484522478319793, 11.51115860224703, 12.4560421651479, 13.439329381882272, 14.385066792043586, 15.444074886020708, 16.254525549908635, 16.553537531662318, 15.747207285385091, 14.75541715782993, 13.874640744703227, 12.8766835077784, 11.883662992230636, 11.166234285005894, 11.934407591998777, 11.533156180347357], [12.716233584098573, 11.879081807655258, 10.977335567766833, 10.017543414225262, 10.999877475944775, 11.907812282342432, 12.754298058588425, 13.74999885340832, 14.5593450078184, 15.450664429174985, 15.530338791543011, 14.50386320125686, 13.539920528616465, 12.549927629974363, 11.593328099119786, 10.622292271863124, 9.583791337452523, 10.595983296601364, 11.644530537213237, 12.664167007607006, 11.743833936101135, 10.903045922975101, 10.040720984684343, 9.077145335237319, 10.012298739962619, 10.861856975911332, 11.814404854510489, 12.74963058606518, 13.582425767390117, 14.458510726259735, 15.412615984268516, 15.446146096882913, 14.483141386808718, 13.501864910443967, 12.520293491932522, 11.618865307263723, 10.65590493611849, 11.539730087426678, 12.526349404466778, 12.601970293896555, 10.72611267283844, 9.902390101186288, 9.005889521992414, 8.048251462084353, 9.023657131252971, 9.873518529412026, 10.790803183022739, 11.726450205218715, 12.607001457230211, 13.525335151714833, 14.566080292489948, 15.530189424918133, 15.461108335119235, 14.512524339046527, 13.53952444917976, 12.669840931891933, 11.637850353728235, 12.510008358001693, 12.666805369885642, 11.664203743084865, 9.693118826216024, 8.940981026347142, 7.956764359528094, 7.085740838092066, 8.070707235188303, 8.849747103326084, 9.833366606435861, 10.66949954265969, 11.625671733953258, 12.57176880085724, 13.552142976091254, 14.517825720439692, 15.481456769103083, 15.531944731662273, 14.483830610692147, 13.661008038924159, 12.591516569994365, 12.56528940854786, 11.614857510660217, 10.677349670925025, 8.74809552595052, 7.908532387525451, 7.006721653171447, 6.046867666110561, 7.011074532573839, 7.845738777522458, 8.834790422797479, 9.638844652904416, 10.621276138803694, 11.595450925362627, 12.610915497890167, 13.587733965951898, 14.550866622787556, 15.56223970871536, 14.561370411386413, 13.604540055438877, 12.626873220282484, 11.603824187797407, 10.626587283259095, 9.685996129978708, 7.8010529853500294, 6.909022887473277, 5.960023324229072, 5.047854295766875, 6.015527319513302, 6.912146466699555, 7.789349981128348, 8.713596012119169, 9.686508872554723, 10.617783600940628, 11.552373589798423, 12.578819667620351, 13.549506988747117, 14.520918189461273, 13.693105820548793, 12.64591862660165, 11.671144683806146, 10.645239663656673, 9.70927748128568, 8.728847517101075, 6.8078508972266665, 5.895282348601106, 4.927760729376984, 4.058650866778184, 5.023584217217967, 5.8613475710995555, 6.783003177313564, 7.767502065402859, 8.725658129777546, 9.682003573979184, 10.687788764164008, 11.652744527447108, 12.504196342909939, 13.550034008991853, 12.663737560245577, 11.727447243702175, 10.768001930336176, 9.710619800010111, 8.745159165576517, 7.7398052291827, 5.840644583928524, 4.88422042796279, 3.9366097290576563, 3.034557769225665, 3.9679175882351108, 4.87588489525755, 5.82943583648882, 6.820993282962758, 7.8255822109033195, 8.665355928132122, 9.717067165733189, 10.620941579442716, 11.572102007047953, 12.56600147778128, 11.69348771770877, 10.751394202412417, 9.804069612513757, 8.872211932235233, 7.892573437403043, 6.901317125659595, 4.912044527824367, 3.9624403560374626, 2.98365534194071, 1.9674027718453209, 2.936529754868213, 3.893841832557908, 4.824801581293312, 5.770166608126524, 6.750608901215026, 7.702293877782769, 8.66512666726044, 9.669774090565815, 10.62943736806056, 11.571903284943991, 10.755806550990252, 9.818067145671469, 8.813418620583947, 7.869987880439903, 6.9112991449981696, 5.963816406357946, 3.905552483114256, 3.0576676915575534, 2.0440119546703626, 0.9982027643505945, 1.8858594752666327, 2.882045732211653, 3.8915880333745565, 4.826994241601403, 5.796795933514702, 6.7321914457586365, 7.68550903802639, 8.66835810780984, 9.680751417642965, 10.614304262412526, 9.88906554196784, 8.915766161387426, 7.919553182160919, 6.918293638776663, 5.963376721633541, 4.975457479877586, 2.9389210579178195, 1.9887593085348154, 1.0077864464720434, 0.0, 0.941898479773235, 2.008126203896448, 2.953770829660318, 4.003275537089889, 5.040195111924256, 6.017023535370897, 7.044165463920575, 8.100159698052813, 9.031307696159077, 9.86210095877726, 8.936900515373795, 7.95606257066519, 6.9004082314537545, 5.96192576347092, 4.964258650096667, 3.9638092644857665, 3.8934941522692794, 2.958254695351309, 1.9456937780966772, 1.0160953970492783, 1.9493676579976928, 2.9369215617248954, 3.906331687632012, 4.963744579750295, 6.027751618152757, 7.007944036086468, 8.004238252410449, 8.993988056955548, 9.985711054185405, 10.843777016169504, 9.836179781775485, 8.856952167089027, 7.898653706214407, 6.962733960153974, 5.946250360074416, 4.896271476066022, 4.823699844788483, 3.8107744104667436, 2.8811605877470647, 1.9473927112512244, 2.92508676406226, 3.9198227583384804, 4.893476612027494, 5.934924895536545, 6.97207795378943, 7.943435848195496, 9.002584736874088, 10.000876347026844, 10.96063966485365, 11.739149122131105, 10.74552425923495, 9.721606021308931, 8.775493044297436, 7.805246460950681, 6.8402603943344555, 5.797872317582629, 5.735027235521395, 4.773797485960781, 3.8206175310186836, 2.9203160944700075, 3.860282447499317, 4.88098539987769, 5.917032189408382, 6.910014897777602, 7.924777416737197, 8.901906216319258, 9.885325585579393, 10.89488269434986, 11.842284119327221, 12.583144156473558, 11.599150486651459, 10.65913281066879, 9.74163223580527, 8.710097294996482, 7.669103532597692, 6.726409941667846, 6.680876503068666, 5.74336875556172, 4.747820464329789, 3.8830151812867206, 4.797722471507256, 5.803648542813297, 6.85651214698296, 7.900866758930662, 8.857763021078405, 9.821292466886316, 10.857164354128084, 11.84448364188589, 12.80017412511859, 13.59715269300298, 12.547170311761905, 11.579917758367605, 10.567195722949705, 9.624706306924534, 8.63835914605328, 7.732518931867821, 7.706224990326475, 6.70153574090779, 5.799796006643928, 4.808785160251568, 5.838168517606899, 6.812274099137299, 7.860847669424464, 8.843469038846157, 9.810891719245081, 10.755348472899541, 11.680698593133258, 12.616906463273041, 13.649666059135015, 14.591928058734924, 13.560239875350339, 12.51751317325664, 11.590552611721444, 10.652464966732698, 9.591114460065938, 8.671922795370259, 8.636979797845358, 7.766986613011444, 6.750504897182215, 5.7667179676510445, 6.766476377112488, 7.761815633725947, 8.741509910449398, 9.723523857884315, 10.677945058800589, 11.715942709617423, 12.618350832145019, 13.620693376174676, 14.578222203745005, 15.579358538421705, 14.565806666658675, 13.509235050383264, 12.553576501560453, 11.491075080926858, 10.528969802117496, 9.603484025137043, 9.615444066941008, 8.705024231330079, 7.718992457328156, 6.69890206601006, 7.765636884225099, 8.720760926013844, 9.67706211388339, 10.693479442463143, 11.62175572201137, 12.609798531794517, 13.540956899596402, 14.561720712777255, 15.49028993023985, 15.820911528019955, 14.841678955969398, 13.846718157446235, 12.882568129480415, 12.455458465796617, 11.494655014853677, 10.5676944161028, 10.659047276146563, 9.59753013740443, 8.63635410467515, 7.6994389246917, 8.699573149276741, 9.772346890310065, 10.629605097802816, 11.58462882951393, 12.57077321948925, 13.553800342981978, 14.49113192168832, 15.497814579691209, 15.767829178186588, 14.76288750884719, 13.892085906418751, 12.911189293694346, 11.920326175893175, 12.952538646270632, 12.552400542956772, 11.517585878969609, 11.662490649055353, 10.616549128179933, 9.624326208676534, 8.632130636858898, 9.665711998976482, 10.692348122903718, 11.637231685804592, 12.620518902538963, 13.566256312700277, 14.625264406677399, 15.435715070565326, 15.545751085190274, 14.739420838913048, 13.747630711357887, 12.866854298231184, 11.946701956483638, 10.953681440935874, 11.95609504930252, 12.825260726512113, 12.5409426268194], [13.65813206387181, 12.808231124954094, 11.90648488506567, 10.946692731524099, 10.153995819476732, 10.965913802569196, 11.812399578815189, 12.808100373635083, 13.617446528045168, 14.508765949401752, 14.803020216950827, 13.776544626664675, 12.81260195402428, 11.822609055382179, 10.896185953205544, 9.925150125948882, 10.525689817225757, 11.537881776374597, 12.58642901698647, 13.606065487380238, 12.685732415874371, 11.832195240273938, 10.96987030198318, 10.006294652536155, 9.166417083494576, 9.919958496138095, 10.872506374737252, 11.807732106291944, 12.640527287616884, 13.516612246486503, 14.470717504495283, 14.718827522290729, 13.755822812216534, 12.774546335851783, 11.82315134601828, 10.990723884721328, 11.597803415891725, 12.48162856719991, 13.46824788424001, 13.543868773669791, 11.668011152611676, 10.831539418485125, 9.93503883929125, 8.97740077938319, 8.157313322206054, 8.93162004963879, 9.848904703249502, 10.784551725445482, 11.665102977456979, 12.5834366719416, 13.624181812716715, 14.588290945144896, 14.745248579401158, 13.79666458332845, 12.842382303265518, 12.041699509349538, 12.579748833501469, 13.451906837774926, 13.608703849658879, 12.606102222858102, 10.63501730598926, 9.870130343645979, 8.885913676826931, 8.014890155390903, 7.204363426141385, 7.907848623552849, 8.891468126662625, 9.727601062886457, 10.683773254180025, 11.629870321084008, 12.61024449631802, 13.575927240666456, 14.539558289329847, 14.834802585748031, 13.786688464777905, 13.056702328054998, 13.533415049767601, 13.507187888321097, 12.556755990433453, 11.619248150698262, 9.689994005723756, 8.837681704824288, 7.935870970470284, 6.976016983409398, 6.144730723526921, 6.903840297749223, 7.892891943024244, 8.696946173131183, 9.679377659030461, 10.653552445589392, 11.669017018116932, 12.645835486178662, 13.60896814301432, 14.620341228942124, 14.856817339452247, 14.018286563560084, 13.568771700055716, 12.545722667570644, 11.568485763032331, 10.627894609751944, 8.742951465123266, 7.838172204772114, 6.889172641527908, 5.977003613065712, 5.073628839740067, 5.970247986926321, 6.847451501355113, 7.771697532345935, 8.744610392781489, 9.675885121167394, 10.610475110025188, 11.636921187847118, 12.60760850897388, 13.579019709688037, 14.62760146777133, 13.587817106374883, 12.613043163579379, 11.587138143429906, 10.651175961058915, 9.67074599687431, 7.749749376999902, 6.824431665899943, 5.856910046675821, 4.987800184077021, 4.081685737444732, 4.919449091326322, 5.841104697540329, 6.825603585629624, 7.7837596500043125, 8.74010509420595, 9.745890284390773, 10.710846047673872, 11.562297863136703, 12.608135529218616, 13.56946527324693, 12.66934572347541, 11.70990041010941, 10.652518279783344, 9.687057645349752, 8.681703708955935, 6.78254306370176, 5.813369745261626, 4.8657590463564935, 3.9637070865245017, 3.0260191084618757, 3.933986415484316, 4.887537356715585, 5.879094803189523, 6.883683731130085, 7.723457448358888, 8.775168685959954, 9.679043099669482, 10.630203527274716, 11.624102998008045, 12.599215430710123, 11.693292682185652, 10.745968092286992, 9.814110412008468, 8.834471917176279, 7.84321560543283, 5.853943007597603, 4.891589673336299, 3.912804659239547, 2.8965520891441576, 1.994631275094978, 2.9519433527846735, 3.8829031015200774, 4.828268128353289, 5.808710421441791, 6.760395398009535, 7.723228187487205, 8.72787561079258, 9.687538888287325, 10.630004805170756, 11.583613528160535, 10.759965625444703, 9.755317100357182, 8.811886360213139, 7.853197624771404, 6.9057148861311815, 4.847450962887491, 3.9995661713307884, 2.9731612719691993, 1.9273520816494312, 0.9439609954933976, 1.9401472524384178, 2.949689553601322, 3.8850957618281683, 4.854897453741468, 5.790292965985402, 6.743610558253155, 7.726459628036606, 8.73885293786973, 9.672405782639292, 10.74715057302253, 9.85766464116066, 8.861451661934154, 7.860192118549898, 6.905275201406776, 5.917355959650822, 3.8808195376910546, 2.9306577883080505, 1.9496849262452784, 0.941898479773235, 0.0, 1.066227724123213, 2.011872349887083, 3.061377057316655, 4.098296632151023, 5.075125055597663, 6.102266984147342, 7.158261218279581, 8.089409216385844, 9.036378602161228, 9.878798995147031, 8.897961050438425, 7.84230671122699, 6.903824243244156, 5.906157129869903, 4.905707744259002, 4.835392632042514, 3.900153175124544, 2.8875922578699122, 1.9579938768225134, 1.0422413700583235, 2.0297952737855263, 2.999205399692643, 4.041566039427808, 5.10557307783027, 6.0660455563132345, 7.062339772637215, 8.052089577182313, 9.043812574412172, 10.018054659553473, 10.77807826154872, 9.798850646862261, 8.840552185987642, 7.9046324399272105, 6.888148839847651, 5.838169955839257, 5.765598324561718, 4.752672890239978, 3.8230590675203, 2.8892911910244594, 2.069585381927755, 3.0643213762039756, 4.007561689063278, 5.04900997257233, 6.086163030825215, 7.057520925231281, 8.070392731638448, 9.068684341791204, 10.018741185080417, 11.01718125928335, 11.687422739008184, 10.663504501082166, 9.71739152407067, 8.747144940723915, 7.78215887410769, 6.739770797355864, 6.6769257152946295, 5.715695965734016, 4.762516010791919, 3.8622145742432425, 3.004781065364812, 4.025484017743185, 5.057135325838659, 6.050118034207879, 7.0388624937729825, 8.015991293355043, 8.999410662615178, 10.008967771385645, 10.956369196363006, 11.919194413310647, 12.541048966424693, 11.601031290442025, 10.683530715578504, 9.651995774769716, 8.611002012370927, 7.668308421441081, 7.622774982841901, 6.685267235334956, 5.689718944103024, 4.824913661059956, 3.942221089372751, 4.9481471606787935, 6.0010107648484565, 7.045365376796158, 7.971848098114189, 8.9353775439221, 9.97124943116387, 10.958568718921676, 11.914259202154375, 12.933204593016384, 13.48906879153514, 12.52181623814084, 11.50909420272294, 10.566604786697768, 9.580257625826514, 8.674417411641056, 8.648123470099708, 7.6434342206810255, 6.741694486417162, 5.7506836400248025, 4.982667135472394, 5.956772717002794, 7.005346287289958, 7.987967656711651, 8.955390337110575, 9.899847090765036, 10.825197210998752, 11.761405081138536, 12.79416467700051, 13.80470616945327, 14.502138355123574, 13.459411653029875, 12.532451091494679, 11.59436344650593, 10.533012939839171, 9.613821275143492, 9.57887827761859, 8.70888509278468, 7.69240337695545, 6.708616447424279, 6.042546994868633, 6.906314251591442, 7.886008528314894, 8.868022475749811, 9.822443676666085, 10.86044132748292, 11.762849450010513, 12.76519199404017, 13.7227208216105, 14.755939044909036, 14.966673358957301, 14.181103577636032, 13.495474981333688, 12.432973560700091, 11.470868281890729, 10.545382504910275, 10.55734254671424, 9.646922711103313, 8.66089093710139, 7.640800545783295, 7.066324032514244, 7.958003109776654, 8.876789626247923, 9.83797806032864, 10.766254339876866, 11.754297149660013, 12.685455517461898, 13.70621933064275, 14.634788548105345, 14.879013048246719, 13.942927464697902, 13.131925057916229, 13.811717446779252, 13.39735694556985, 12.43655349462691, 11.509592895876033, 11.600945755919795, 10.539428617177666, 9.578252584448386, 8.641337404464934, 8.000260297565886, 9.01527075515181, 9.829332610167352, 10.784356341878466, 11.770500731853787, 12.753527855346514, 13.65753739537551, 14.642313197556703, 14.825930698413352, 13.820989029073953, 12.950187426645515, 12.19639619416434, 12.849475493192012, 13.881687963569469, 13.494299022730004, 12.459484358742841, 12.60438912882859, 11.55844760795317, 10.566224688449768, 9.574029116632133, 8.967851770967771, 9.994487894895007, 10.836959198169128, 11.8202464149035, 12.765983825064813, 13.824991919041935, 14.602120544252516, 14.60385260541704, 13.797522359139812, 12.805732231584651, 11.924955818457947, 11.167417401877254, 11.88283075823471, 12.885244366601357, 13.75441004381095, 13.482841106592632], [14.653296448250114, 13.703651935130564, 12.710309599586575, 11.750517446045004, 10.862544698313917, 9.981705178475526, 10.774624384002768, 11.767914746238887, 12.551218803921955, 13.44253822527854, 13.931753380387425, 12.905277790101273, 12.01532059282247, 11.025327694180367, 10.264783791402925, 10.942240572688512, 11.560300018149611, 12.572491977298451, 13.621039217910324, 14.640675688304093, 13.697536462981232, 12.752452368627972, 11.851567084351, 10.81011936705706, 9.87496596233176, 8.935749872044426, 9.834731179924832, 10.767546478895747, 11.574299563493671, 12.45038452236329, 13.40448978037207, 13.847560685727327, 12.958541451014723, 11.977264974649971, 11.191749184215661, 12.007814331460958, 12.63241361681558, 13.516238768123765, 14.502858085163865, 14.573526927924782, 12.697669306866668, 11.75179654683916, 10.81673562165907, 9.818870264801177, 8.865862201043239, 7.94741142554512, 8.811129508437082, 9.71832400132227, 10.598875253333766, 11.517208947818387, 12.557954088593503, 13.522063221021687, 13.947967218199347, 12.999383222126639, 12.2109801414629, 13.058789956089168, 13.614359034425323, 14.48651703869878, 14.638362003913869, 13.635760377113092, 11.66467546024425, 10.790387472000011, 9.806170805180964, 8.85635964080889, 7.912912304978571, 6.923639999459179, 7.853692931850206, 8.661373338763244, 9.617545530056812, 10.563642596960795, 11.544016772194809, 12.509699516543247, 13.473330565206638, 14.046243431094283, 13.155286302975286, 14.073792774794628, 14.568025250691456, 14.536846042576087, 13.586414144688444, 12.648906304953252, 10.719652159978747, 9.825011743761015, 8.857169169706689, 7.817486468827385, 6.853279602364107, 5.919631673655553, 6.84364025864722, 7.63071844900797, 8.613149934907248, 9.587324721466182, 10.602789293993721, 11.579607762055453, 12.542740418891107, 13.554113504818911, 14.225415177649628, 15.035377010299714, 14.598429854310709, 13.575380821825634, 12.598143917287322, 11.657552764006935, 9.772609619378256, 8.846336094568484, 7.897336531324278, 6.9167059807255225, 5.923646422547847, 4.986039362832651, 5.781223777231901, 6.705469808222722, 7.678382668658276, 8.609657397044183, 9.544247385901977, 10.570693463723906, 11.541380784850668, 12.512791985564824, 13.561373743648115, 14.400371581306604, 13.642701317834371, 12.616796297684898, 11.680834115313907, 10.700404151129302, 8.779407531254893, 7.8325955556963125, 6.86507393647219, 5.927502551736832, 4.951230299882759, 3.935240467232651, 4.774876973417117, 5.7593758615064115, 6.7175319258811, 7.673877370082738, 8.67966256026756, 9.64461832355066, 10.49607013901349, 11.541907805095404, 12.503237549123716, 13.408271771763639, 12.755640760298824, 11.682176434038336, 10.716715799604744, 9.711361863210927, 7.812201217956752, 6.821533635057996, 5.873922936152863, 4.938274120645595, 3.9175170801176176, 2.949777791390645, 3.8213096325923726, 4.812867079066311, 5.8174560070068715, 6.657229724235675, 7.708940961836742, 8.612815375546267, 9.563975803151504, 10.55787527388483, 11.532987706586908, 12.392291300984137, 11.812195816410204, 10.88033813613168, 9.864130071431271, 8.872873759687822, 6.895884388504975, 5.899753563132669, 4.9209685490359165, 3.9047159789405277, 2.9864383618372017, 1.9677347286910027, 2.8166753773968645, 3.762040404230076, 4.742482697318578, 5.694167673886321, 6.657000463363992, 7.661647886669365, 8.62131116416411, 9.563777081047542, 10.517385804037321, 11.455125209356105, 10.821544824480394, 9.878114084336351, 8.919425348894617, 7.947656267038554, 5.913678687010704, 5.027977269124718, 3.981325161765569, 2.9355159714458012, 1.9521248852897677, 0.9559386283447474, 1.8834618294781087, 2.818868037704955, 3.7886697296182543, 4.7240652418621885, 5.677382834129942, 6.660231903913392, 7.672625213746516, 8.606178058516077, 9.680922848899316, 10.747761471948868, 9.927679386057367, 8.926419842673111, 7.971502925529989, 6.983583683774034, 4.947047261814268, 3.9968855124312634, 3.0159126503684917, 2.008126203896448, 1.066227724123213, 0.0, 0.94564462576387, 1.995149333193442, 3.032068908027809, 4.00889733147445, 5.036039260024128, 6.092033494156367, 7.023181492262631, 7.970150878038015, 8.89535132144148, 9.876189266150085, 8.908534435350203, 7.970051967367369, 6.972384853993116, 5.971935468382215, 5.901620356165727, 4.966380899247757, 3.952286851041521, 2.9926040777463667, 2.059331816797952, 1.0717779130707497, 1.9661568744972757, 2.9753383153045947, 4.0393453537070565, 4.999817832190021, 5.996112048514002, 6.985861853059101, 7.977584850288959, 8.95182693543026, 9.91143465205418, 10.84896310534926, 9.906779910110856, 8.970860164050423, 7.954376563970864, 6.90439767996247, 6.830292917733328, 5.817367483411588, 4.887753660691909, 3.9239013919483128, 3.0866758286673837, 2.1325703045911886, 2.974513163867911, 4.015961447376963, 5.047159288549969, 6.018517182956035, 7.004165007515234, 8.002456617667992, 8.952513460957203, 9.950953535160137, 10.940339311918935, 11.728199094253776, 10.782086117242281, 9.811839533895526, 8.8468534672793, 7.804465390527474, 7.74162030846624, 6.780390558905626, 5.827210603963528, 4.896824775167096, 4.021871512104441, 3.093732946130398, 4.024086800643292, 5.0170695090125115, 5.999858751497737, 6.976987551079797, 7.960406920339933, 8.9699640291104, 9.917365454087761, 10.880190671035402, 11.864184340857502, 12.665725883613636, 11.748225308750115, 10.716690367941327, 9.675696605542537, 8.733003014612692, 8.687469576013513, 7.749961828506565, 6.754413537274633, 5.859523861983809, 4.95931153611238, 4.129183925943017, 5.097463279437639, 6.026632931753589, 6.932844355838943, 7.896373801646854, 8.932245688888624, 9.91956497664643, 10.87525545987913, 11.89420085074114, 12.816036728694515, 13.58651083131245, 12.57378879589455, 11.631299379869379, 10.644952218998124, 9.739112004812668, 9.712818063271321, 8.708128813852635, 7.776304687341016, 6.785293840948656, 5.999757582212023, 5.159491355800985, 6.14671702827881, 6.988962090234118, 7.956384770633042, 8.900841524287502, 9.826191644521218, 10.762399514661002, 11.795159110522976, 12.805700602975737, 13.831083433715689, 14.524106246201486, 13.59714568466629, 12.659058039677543, 11.597707533010784, 10.678515868315104, 10.643572870790203, 9.765335513451792, 8.727013577879303, 7.7432266483481325, 7.0596374416082615, 6.109032890389633, 7.088727167113086, 8.051378029068559, 8.938697638818338, 9.899867256941185, 10.76384388353298, 11.766186427562637, 12.723715255132966, 13.756933478431502, 13.98246473486363, 14.889652456473216, 14.560169574505299, 13.497668153871704, 12.535562875062341, 11.610077098081888, 11.622037139885853, 10.681532912027167, 9.695501138025245, 8.675410746707149, 8.083414479253873, 7.160721748574845, 8.079508265046114, 9.021333613647387, 9.88250830202912, 10.870551111812267, 11.773493513049537, 12.79425732623039, 13.722826543692985, 13.841237853434299, 12.958718840604233, 13.840473936753414, 14.615542161300157, 14.462051538741463, 13.501248087798523, 12.574287489047645, 12.64744922524208, 11.57403881810152, 10.61286278537224, 9.675947605388789, 9.017350744305515, 8.21798939395, 9.03205124896554, 9.987074980676654, 10.898218837157959, 11.881245960650686, 12.745575390963149, 13.730351193144344, 13.788155503600931, 12.783213834261533, 11.965978802551845, 12.904945073001524, 13.653300207712917, 14.685512678090374, 14.558993615901617, 13.524178951914454, 13.638999329752444, 12.593057808877024, 11.600834889373623, 10.608639317555987, 9.9849422177074, 9.28747956520911, 10.039677836967316, 11.022965053701688, 11.893701930368985, 12.952710024346107, 13.690158539840155, 13.537624881293828, 12.759747164327392, 11.76795703677223, 10.940747194364278, 11.875966280714438, 12.686655472755616, 13.689069081122263, 14.64983085398742, 14.547535699764245], [15.54309606373445, 14.593451550614901, 13.600109215070912, 12.640317061529341, 11.752344313798254, 10.843261661160735, 9.828979758238898, 10.822270120475016, 11.605574178158085, 12.496893599514669, 12.986108754623556, 11.959633164337404, 11.086446759492112, 10.09645386085001, 11.043628312019901, 11.844623971000095, 12.478444479719384, 13.490636438868226, 14.539183679480098, 15.558820149873867, 14.587336078465567, 13.642251984112308, 12.741366699835337, 11.699918982541398, 10.764765577816098, 9.825549487528763, 8.889086554160961, 9.821901853131877, 10.6286549377298, 11.50473989659942, 12.4588451546082, 12.901916059963458, 12.029667617684366, 11.048391141319614, 11.970593704832638, 12.910197729772541, 13.550558078385352, 14.43438322969354, 15.42100254673364, 15.519171553688652, 13.643313932630537, 12.641596162323495, 11.706535237143408, 10.708669880285514, 9.755661816527576, 8.837211041029457, 7.865484882673211, 8.772679375558399, 9.653230627569895, 10.571564322054517, 11.612309462829632, 12.576418595257815, 13.01909338486899, 12.070509388796282, 12.989824662079876, 13.961173354400751, 14.532503495995096, 15.404661500268555, 15.58400662967774, 14.581405002876963, 12.610320086008121, 11.680187087484349, 10.6959704206653, 9.746159256293227, 8.802711920462908, 7.813439614943516, 6.908048306086335, 7.715728712999374, 8.671900904292942, 9.617997971196925, 10.598372146430936, 11.564054890779374, 12.527685939442765, 13.117369597763926, 13.934130823592263, 14.97617617310621, 15.486169712261226, 15.482490668339958, 14.532058770452315, 13.594550930717123, 11.665296785742617, 10.714811359245353, 9.746968785191026, 8.707286084311722, 7.743079217848444, 6.809431289139891, 5.897995632883349, 6.6850738232441, 7.667505309143379, 8.64168009570231, 9.657144668229849, 10.63396313629158, 11.597095793127238, 12.608468879055042, 13.645186994672123, 14.413348384379962, 15.24646614893493, 14.521025447589505, 13.543788543051193, 12.603197389770806, 10.718254245142127, 9.791980720332353, 8.842981157088149, 7.829253254730658, 6.813446038032184, 5.875838978316988, 4.83557915146803, 5.759825182458852, 6.732738042894406, 7.664012771280311, 8.598602760138105, 9.625048837960033, 10.5957361590868, 11.567147359800956, 12.615729117884246, 13.454726955542736, 14.290737612458592, 13.56244092344877, 12.626478741077777, 11.646048776893172, 9.725052157018764, 8.778240181460182, 7.81071856223606, 6.840049825741968, 5.863777573887895, 4.847787741237787, 3.8292323476532455, 4.813731235742541, 5.771887300117229, 6.728232744318867, 7.734017934503691, 8.69897369778679, 9.550425513249621, 10.596263179331535, 11.557592923359847, 12.46262714599977, 13.357903582941347, 12.627821059802208, 11.662360425368615, 10.657006488974798, 8.757845843720622, 7.767178260821866, 6.819567561916733, 5.8508213946507315, 4.830064354122754, 3.8623250653957815, 2.875665006828502, 3.86722245330244, 4.871811381243001, 5.711585098471804, 6.763296336072871, 7.667170749782398, 8.618331177387635, 9.612230648120962, 10.58734308082304, 11.446646675220268, 12.393971265118928, 11.825982761895553, 10.809774697195142, 9.818518385451693, 7.841529014268845, 6.845398188896539, 5.866613174799786, 4.850360604704397, 3.9138051691207956, 2.8951015359745966, 1.8710307516329943, 2.816395778466206, 3.796838071554707, 4.748523048122451, 5.711355837600122, 6.716003260905496, 7.675666538400241, 8.618132455283673, 9.571741178273452, 10.509480583592236, 11.514129108679757, 10.823758710100222, 9.865069974658487, 8.893300892802424, 6.859323312774574, 5.973621894888588, 4.926969787529439, 3.881160597209671, 2.8977695110536374, 1.9015832541086173, 0.9378172037142387, 1.8732234119410849, 2.843025103854384, 3.7784206160983187, 4.731738208366072, 5.714587278149523, 6.726980587982647, 7.660533432752208, 8.735278223135447, 9.802116846185, 10.873324011821236, 9.872064468436982, 8.917147551293858, 7.929228309537903, 5.892691887578137, 4.942530138195133, 3.9615572761323614, 2.9537708296603182, 2.011872349887083, 0.94564462576387, 0.0, 1.049504707429572, 2.0864242822639394, 3.0632527057105805, 4.090394634260258, 5.146388868392497, 6.077536866498761, 7.024506252274145, 7.94970669567761, 8.930544640386215, 9.85417906111407, 8.915696593131237, 7.918029479756985, 6.917580094146084, 6.847264981929597, 5.912025525011627, 4.870431312611294, 3.9107485393161396, 2.977476278367725, 1.9899223746405224, 1.0205122487334057, 2.0296936895407245, 3.093700727943186, 4.054173206426152, 5.050467422750133, 6.040217227295232, 7.031940224525089, 8.00618230966639, 8.96579002629031, 9.903318479585389, 10.852424535874723, 9.916504789814292, 8.900021189734733, 7.850042305726339, 7.7484373793031, 6.7355119449813605, 5.805898122261682, 4.842045853518085, 3.997258386069276, 3.0025223917930557, 2.0288685381040414, 3.0703168216130927, 4.101514662786099, 5.072872557192165, 6.058520381751365, 7.056811991904122, 8.006868835193334, 9.005308909396266, 9.994694686155066, 10.84681701955878, 11.700230578812054, 10.729983995465298, 9.764997928849073, 8.722609852097246, 8.659764770036013, 7.698535020475399, 6.7453550655333006, 5.814969236736869, 4.932454069506333, 3.9636850333322657, 3.078442174879422, 4.071424883248642, 5.054214125733866, 6.0313429253159265, 7.014762294576062, 8.024319403346531, 8.971720828323893, 9.934546045271533, 10.918539715093633, 11.784343808918639, 12.666369770319887, 11.6348348295111, 10.59384106711231, 9.651147476182464, 9.605614037583283, 8.668106290076338, 7.672557998844406, 6.7776683235535815, 5.869894093514272, 4.999136013144884, 4.151818653673769, 5.080988305989719, 5.987199730075073, 6.950729175882984, 7.986601063124754, 8.973920350882562, 9.92961083411526, 10.94855622497727, 11.870392102930646, 12.76492490983432, 13.491933257464323, 12.549443841439151, 11.563096680567897, 10.657256466382439, 10.630962524841092, 9.626273275422408, 8.694449148910788, 7.703438302518428, 6.910340139613916, 6.029443443002853, 5.20107240251494, 6.043317464470248, 7.010740144869172, 7.955196898523633, 8.88054701875735, 9.816754888897133, 10.849514484759107, 11.860055977211868, 12.88543880795182, 13.702520324723356, 14.515290146236062, 13.577202501247314, 12.515851994580554, 11.596660329884875, 11.561717332359974, 10.683479975021566, 9.645158039449075, 8.661371109917905, 7.970219999010154, 6.978984977591501, 6.159853333782728, 7.10573340330469, 7.993053013054469, 8.954222631177316, 9.81819925776911, 10.820541801798768, 11.778070629369097, 12.811288852667634, 13.824840724430661, 14.69424220184998, 15.478314036075071, 14.415812615441475, 13.453707336632112, 12.528221559651659, 12.540181601455624, 11.59967737359694, 10.613645599595017, 9.593555208276921, 8.985797877565457, 8.030673835776712, 7.150634431715756, 8.075688987883519, 8.93686367626525, 9.924906486048398, 10.827848887285668, 11.848612700466521, 12.777181917929116, 12.895593227670428, 13.820275323289442, 14.730273552237751, 15.505341776784494, 15.380196000311233, 14.419392549368293, 13.492431950617416, 13.56559368681185, 12.492183279671291, 11.53100724694201, 10.594092066958561, 9.919734142617099, 9.087941481151868, 8.103177415635184, 9.058201147346297, 9.95257421139409, 10.935601334886817, 11.79993076519928, 12.784706567380475, 12.84251087783706, 11.837569208497662, 12.827535285237055, 13.794744688485862, 14.543099823197254, 15.575312293574711, 15.477138077471388, 14.442323413484225, 14.557143791322215, 13.511202270446795, 12.518979350943395, 11.52678377912576, 10.887325616018984, 10.066324085826087, 9.110804003636959, 10.09409122037133, 10.948057304605117, 12.007065398582238, 12.744513914076286, 12.591980255529958, 11.814102538563521, 10.82231241100836, 11.802303677049487, 12.765765896198776, 13.576455088239953, 14.5788686966066, 15.539630469471756, 15.465680161334015], [16.421425582298486, 15.471781069178935, 14.478438733634945, 13.518646580093375, 12.630673832362287, 11.64397519070629, 10.629693287784452, 9.893169546037, 10.67647360372007, 11.567793025076654, 11.938366322798561, 10.91189073251241, 10.21165827872936, 10.911762832394082, 11.858937283563973, 12.736194726352757, 13.495534105215414, 14.507726064364256, 15.556273304976129, 16.575909775369897, 15.465665597029604, 14.520581502676345, 13.619696218399373, 12.578248501105431, 11.643095096380131, 10.703750572236087, 9.689800083706515, 8.892801278693861, 9.699554363291785, 10.575639322161404, 11.529744580170185, 11.854173628138463, 11.277225479109344, 11.863700112863686, 12.78590267637671, 13.79227255771422, 14.567647703881383, 15.45147285518957, 16.43809217222967, 16.406255703233484, 14.560632295261088, 13.519925680887532, 12.584864755707443, 11.58699939884955, 10.63399133509161, 9.715412125736782, 8.666198412218765, 7.843578801120382, 8.72413005313188, 9.642463747616501, 10.683208888391617, 11.62946446441545, 12.298785394766377, 12.885818360340352, 13.805133633623948, 14.84324818234243, 15.549593121491126, 16.421751125764587, 16.543534921038507, 15.54093329423773, 13.569848377368888, 12.558516606048384, 11.574299939229336, 10.624488774857262, 9.681041439026941, 8.69176913350755, 7.70876183563189, 6.786628138561358, 7.742800329854926, 8.68889739675891, 9.651418015588574, 10.61710075993701, 11.580731808600401, 12.588123085971215, 13.636237206941342, 14.427978489042683, 15.279725439263553, 16.217855061253104, 15.491587061813082, 14.55407922207789, 12.624825077103385, 11.593140877809388, 10.625298303755061, 9.585615602875757, 8.621408736412478, 7.687760807703925, 6.698709162428904, 5.755973248806084, 6.738404734705363, 7.694725964859945, 8.710190537387486, 9.687009005449216, 10.650141662284872, 11.661514748212676, 12.698232863829759, 13.466394253537597, 14.299512018092566, 15.306777161351512, 14.50331683441196, 13.562725681131573, 11.68504588061294, 10.758772355803165, 9.781036741840662, 8.753111540341987, 7.737304323643512, 6.799697263928316, 5.759437437079358, 4.830724608020836, 5.80363746845639, 6.717058640437947, 7.6516486292957415, 8.67809470711767, 9.648782028244433, 10.62019322895859, 11.668774987041882, 12.507772824700371, 13.343783481616228, 14.25871622691954, 13.59327037654859, 12.612840412363985, 10.691843792489577, 9.745031816930995, 8.777510197706873, 7.763908111353296, 6.787635859499224, 5.771646026849115, 4.7530906332645735, 3.884630661304526, 4.842786725679214, 5.781278613476503, 6.787063803661327, 7.752019566944425, 8.603471382407255, 9.649309048489169, 10.610638792517483, 11.515673015157406, 12.410949452098983, 13.324096363272979, 12.629152060839427, 11.62379812444561, 9.724637479191435, 8.733969896292678, 7.786359197387545, 6.77467968026206, 5.753922639734083, 4.78618335100711, 3.7995232924398303, 2.9381218788644254, 3.9248572504006365, 4.76463096762944, 5.816342205230507, 6.720216618940034, 7.6713770465452695, 8.665276517278597, 9.640388949980675, 10.499692544377904, 11.447017134276564, 12.378874814555088, 11.776566332665954, 10.785310020922505, 8.855573052326907, 7.8594422269546005, 6.880657212857848, 5.864404642762459, 4.837663454732124, 3.8189598215859246, 2.7948890372443222, 1.8694416476238416, 2.849883940712343, 3.801568917280087, 4.7644017067577575, 5.769049130063132, 6.728712407557877, 7.671178324441309, 8.624787047431088, 9.562526452749871, 10.567174977837393, 11.510605717981438, 10.914574682088057, 9.907344930860486, 7.908828020204146, 7.008299166232829, 5.96164705887368, 4.915837868553912, 3.932446782397879, 2.936260525452859, 1.8616754893255667, 0.9262692810987205, 1.8960709730120198, 2.8314664852559543, 3.7847840775237076, 4.7676331473071585, 5.780026457140282, 6.713579301909844, 7.788324092293083, 8.840743523678878, 9.91471574921212, 10.921569175866551, 9.966652258723428, 8.978733016967475, 6.942196595007709, 5.992034845624705, 5.011061983561933, 4.003275537089889, 3.0613770573166548, 1.995149333193442, 1.049504707429572, 0.0, 1.0369195748343671, 2.013747998281008, 3.040889926830686, 4.096884160962925, 5.0280321590691885, 5.975001544844573, 6.900201988248037, 7.881039932956643, 8.93669427216808, 9.875176740150913, 8.967534187186557, 7.9670848015756555, 7.896769689359169, 6.9562027555611134, 5.887520938107324, 4.92783816481217, 3.994565903863755, 3.0070120001365526, 2.037601874229436, 0.9801889821111526, 2.0441960205136143, 3.0046684989965797, 4.0009627153205605, 4.990712519865659, 5.982435517095516, 6.956677602236818, 7.916285318860738, 8.853813772155817, 9.812112233030437, 10.796659645264251, 9.949525897164305, 8.89954701315591, 8.765527004799129, 7.75260157047739, 6.822987747757711, 5.859135479014116, 5.014348011565305, 4.019612017289085, 3.0459581636000714, 2.049893423236443, 3.052009955356527, 4.023367849762593, 5.009015674321793, 6.00730728447455, 6.957364127763761, 7.955804201966695, 8.945189978725493, 9.797312312129208, 10.743425289140703, 11.713671872487458, 10.782087554345102, 9.739699477593275, 9.676854395532041, 8.715624645971427, 7.76244469102933, 6.832058862232899, 5.949543695002362, 4.980774658828295, 4.054850131784933, 3.0618674234157135, 4.004709418304294, 4.981838217886355, 5.965257587146491, 6.974814695916959, 7.92221612089432, 8.885041337841962, 9.869035007664062, 10.734839101489067, 11.709564480648536, 12.651924455007128, 11.610930692608338, 10.668237101678493, 10.622703663079314, 9.685195915572368, 8.689647624340436, 7.794757949049612, 6.886983719010301, 6.016225638640914, 5.115785458104493, 4.071430846156791, 4.937695022645501, 5.901224468453412, 6.937096355695182, 7.924415643452989, 8.880106126685687, 9.899051517547697, 10.820887395501074, 11.715420202404749, 12.689250727730187, 13.56653346693518, 12.580186306063926, 11.67434609187847, 11.648052150337122, 10.643362900918438, 9.711538774406819, 8.720527928014459, 7.927429765109944, 7.046533068498882, 6.016381374059012, 5.03376000463732, 5.962997713044178, 6.907454466698639, 7.8328045869323555, 8.76901245707214, 9.801772052934114, 10.812313545386875, 11.835934100522248, 12.653015617293784, 13.712607616501925, 14.594292126743344, 13.532941620076585, 12.613749955380905, 12.578806957856004, 11.700569600517596, 10.662247664945106, 9.678460735413935, 8.953813061551077, 7.954856582050252, 6.9751623053267995, 6.096175943471762, 6.945310581229474, 7.906480199352323, 8.770456825944116, 9.772799369973775, 10.730328197544104, 11.76354642084264, 12.777098292605668, 13.644737494420408, 14.649601099735044, 15.432902240937505, 14.470796962128142, 13.545311185147689, 13.557271226951654, 12.61676699909297, 11.630735225091048, 10.610644833772952, 9.877368632918119, 8.922244591129374, 7.9659434032598275, 7.06613152805059, 7.889121244440256, 8.877164054223403, 9.780106455460674, 10.800870268641525, 11.72943948610412, 12.669887842761312, 13.676260829927683, 14.671221628450846, 15.609793831044263, 16.397285625807264, 15.436482174864324, 14.509521576113446, 14.58268331230788, 13.509272905167322, 12.548096872438041, 11.611181692454592, 10.81130489796976, 9.972819599990832, 8.918486387179255, 8.131153760908576, 8.904831779569095, 9.887858903061822, 10.752188333374285, 11.736964135555478, 11.923198381396631, 12.638282738043216, 13.628248814782609, 14.665771962180596, 15.421429341761288, 16.453641812138745, 16.494227702967418, 15.459413038980255, 15.574233416818245, 14.528291895942825, 13.536068976439426, 12.54387340462179, 11.778896371371646, 10.88163305737016, 9.92611297518103, 9.16704383393361, 9.900314872780122, 10.959322966757243, 11.696771482251291, 11.662879681091942, 10.894790042123091, 11.623025940553914, 12.603017206595041, 13.644095414762809, 14.454784606803987, 15.457198215170633, 16.41795998803579, 16.482769786830048], [17.44411774240778, 16.49447322928823, 15.50113089374424, 14.541338740202669, 13.653365992471581, 12.666667350815583, 11.652385447893746, 10.90834537622214, 9.898149342674824, 10.69070470776563, 10.93688135392512, 9.910405763638968, 10.874348436279362, 11.806938252326423, 12.754112703496315, 13.631370146285096, 14.532453680049782, 15.544645639198624, 16.5931928798105, 17.61282935020427, 16.4883577571389, 15.543273662785639, 14.642388378508667, 13.600940661214725, 12.665787256489425, 11.726442732345381, 10.71249224381581, 9.907977108879, 8.92123010224654, 9.69855100485038, 10.65265626285916, 10.852688659265022, 11.891412677237748, 12.758875532796027, 13.68107809630905, 14.687447977646562, 15.60456727871575, 16.48839243002394, 17.47501174706404, 17.42894786334278, 15.583324455370382, 14.542617840996826, 13.607556915816737, 12.609691558958843, 11.656683495200904, 10.738104285846076, 9.68889057232806, 8.866270961229677, 7.945805792086635, 8.765375430305477, 9.801270521409032, 10.712553240698147, 11.630725384536003, 12.579309380608711, 13.552309270475478, 14.526070084030838, 15.31648043181238, 16.35581325887083, 17.28486174432568, 16.563625454347022, 14.592540537478182, 13.581208766157678, 12.59699209933863, 11.647180934966556, 10.703733599136235, 9.714461293616846, 8.731453995741184, 7.809320298670652, 6.964476068809682, 7.811809079447884, 8.734506791871269, 9.700189536219707, 10.663820584883098, 11.67121186225391, 12.719325983224037, 13.511067265325378, 14.362814215546248, 15.300943837535797, 16.232913885100256, 15.576771382187184, 13.647517237212679, 12.615833037918682, 11.647990463864355, 10.608307762985051, 9.644100896521772, 8.71045296781322, 7.721401322538198, 6.778665408915378, 5.942831617867401, 6.77781474114264, 7.7932793136701815, 8.770097781731913, 9.733230438567567, 10.744603524495371, 11.781321640112452, 12.549483029820292, 13.38260079437526, 14.389865937634207, 15.212928926223647, 14.585417841240867, 12.707738040722234, 11.78146451591246, 10.803728901949956, 9.77580370045128, 8.759996483752806, 7.82238942403761, 6.782129597188652, 5.85341676813013, 4.932612948965293, 5.800147416720642, 6.734737405578437, 7.761183483400366, 8.731870804527128, 9.703282005241284, 10.751863763324575, 11.590861600983066, 12.426872257898923, 13.341805003202236, 14.278370213699638, 13.635532572473279, 11.71453595259887, 10.767723977040289, 9.800202357816165, 8.78660027146259, 7.810328019608518, 6.794338186958409, 5.7757827933738675, 4.907322821413819, 3.949761916911597, 4.864367389759198, 5.870152579944022, 6.8351083432271205, 7.68656015868995, 8.732397824771864, 9.693727568800176, 10.5987617914401, 11.494038228381678, 12.407185139555674, 13.372645773989266, 12.646490284554904, 10.747329639300728, 9.756662056401971, 8.809051357496838, 7.797371840371354, 6.776614799843377, 5.808875511116404, 4.822215452549124, 3.9608140389737194, 3.0079460266833324, 3.8477197439121356, 4.899430981513202, 5.803305395222729, 6.754465822827965, 7.748365293561293, 8.723477726263368, 9.5827813206606, 10.530105910559259, 11.461963590837783, 12.48721911084615, 11.8080021810318, 9.8782652124362, 8.882134387063893, 7.903349372967141, 6.887096802871752, 5.860355614841417, 4.841651981695218, 3.8175811973536162, 2.8921338077331358, 1.9329727169950388, 2.884657693562782, 3.8474904830404526, 4.852137906345827, 5.811801183840572, 6.754267100724004, 7.707875823713782, 8.645615229032567, 9.650263754120088, 10.593694494264131, 11.630663431636073, 10.930037090969778, 8.945747595038513, 8.030991326342123, 6.984339218982974, 5.938530028663206, 4.955138942507173, 3.958952685562153, 2.8843676494348607, 1.9489614412080147, 0.9791597492947155, 1.9145552615386499, 2.8678728538064027, 3.850721923589853, 4.8631152334229775, 5.796668078192539, 6.815447440007715, 7.803823948844513, 8.877796174377753, 9.892318315120955, 10.847235232264078, 10.015652591801842, 7.979116169842077, 7.028954420459073, 6.047981558396301, 5.040195111924257, 4.098296632151023, 3.032068908027809, 2.0864242822639394, 1.0369195748343671, 0.0, 0.976828423446641, 2.003970351996319, 3.059964586128558, 3.991112584234822, 4.938081970010207, 5.863282413413671, 6.844120358122277, 7.899774697333712, 8.838257165316547, 9.835924278690799, 9.004004376410023, 8.933689264193536, 7.99312233039548, 6.924440512941691, 5.9647577396465365, 5.031485478698122, 4.0439315749709195, 3.074521449063803, 2.01710855694552, 1.0427110516401714, 1.9677489241622126, 2.964043140486193, 3.953792945031292, 4.945515942261149, 5.919758027402452, 6.879365744026372, 7.816894197321451, 8.77519265819607, 9.759740070429885, 10.783320841833897, 9.936466587990278, 9.802446579633495, 8.789521145311756, 7.859907322592078, 6.896055053848483, 6.051267586399673, 5.056531592123453, 4.082877738434439, 3.08681299807081, 2.050524986483085, 3.0212305715170853, 3.9720960994874255, 4.970387709640183, 5.920444552929394, 6.9188846271323285, 7.908270403891127, 8.760392737294842, 9.706505714306337, 10.676752297653092, 11.641738364269317, 10.776619052427641, 10.713773970366407, 9.752544220805794, 8.799364265863698, 7.868978437067266, 6.9864632698367295, 6.017694233662663, 5.066624101570052, 4.073641393200832, 3.003224449430852, 3.980353249012912, 4.9637726182730475, 5.973329727043516, 6.913515276821654, 7.876340493769295, 8.847068400288324, 9.697919526654701, 10.67264490581417, 11.665202410520964, 12.647850267442704, 11.705156676512859, 11.659623237913678, 10.722115490406736, 9.726567199174804, 8.831677523883979, 7.923903293844669, 7.053145213475282, 6.052368820953509, 5.0080142090058075, 3.936210053772059, 4.89973949957997, 5.935611386821739, 6.922930674579546, 7.872516951564992, 8.891462342427001, 9.798920788125336, 10.678500627570383, 11.652331152895822, 12.594820568920994, 13.581167729792249, 12.711265666712833, 12.684971725171486, 11.680282475752806, 10.748458349241186, 9.757447502848827, 8.934235945808918, 7.960130364278518, 6.911556793991353, 5.92893542456966, 4.9615127441707365, 5.905969497825198, 6.831319618058914, 7.767527488198698, 8.800287084060672, 9.810828576513433, 10.81396749314651, 11.616096042459418, 12.675688041667561, 13.666215778201538, 14.533923043804908, 13.65066953021527, 13.615726532690369, 12.737489175351964, 11.699167239779474, 10.715380310248303, 9.848988481483419, 8.850032001982592, 7.87033772525914, 6.898246813272306, 5.943825612356033, 6.904995230478882, 7.7689718570706745, 8.771314401100334, 9.728843228670662, 10.762061451969199, 11.775613323732227, 12.607817919586042, 13.612681524900676, 14.685019478057608, 15.507716536962507, 14.582230759982053, 14.594190801786018, 13.653686573927338, 12.667654799925415, 11.64756440860732, 10.772544052850458, 9.817420011061714, 8.861118823192168, 7.8682023978511335, 6.887636275566814, 7.875679085349962, 8.778621486587232, 9.799385299768083, 10.727954517230678, 11.668402873887871, 12.674775861054242, 13.656996439305845, 14.572874256209895, 15.537546893965882, 16.473401749698688, 15.54644115094781, 15.619602887142248, 14.54619248000169, 13.585016447272409, 12.64810126728896, 11.7064803179021, 10.867995019923173, 9.813661807111597, 8.889491200670975, 7.903346810695654, 8.88637393418838, 9.750703364500843, 10.735479166682037, 11.722787507440163, 12.726426893060637, 13.667515899106629, 14.592525303057734, 15.535116209797135, 16.515719719850487, 17.531147277801782, 16.49633261381462, 16.611152991652613, 15.565211470777193, 14.572988551273793, 13.580792979456158, 12.674071791303986, 11.7768084773025, 10.821288395113372, 9.85774145306555, 8.89882990390668, 9.957837997883802, 10.69528651337785, 10.884555420046697, 11.90996587230823, 12.645718100663208, 13.625709366704335, 14.666787574872103, 15.47747676691328, 16.47989037527993, 17.440652148145084, 17.519689361664412], [18.359967502171827, 17.410322989052275, 16.416980653508286, 15.457188499966716, 14.569215752235628, 13.58251711057963, 12.568235207657793, 11.789022374119286, 10.77882634057197, 9.798983120885865, 10.235527757914404, 10.875640819632393, 11.839583492272787, 12.772173308319848, 13.71934775948974, 14.596605202278523, 15.509282103496423, 16.521474062645265, 17.57002130325714, 18.58965777365091, 17.40420751690294, 16.45912342254968, 15.558238138272712, 14.516790420978772, 13.581637016253472, 12.642292492109428, 11.628342003579856, 10.788654106776146, 9.801907100143685, 8.806829417970615, 9.760934675979396, 10.69056768538066, 11.729291703353386, 12.709706041205614, 13.679818640842951, 14.685324121779283, 15.406704262542359, 16.43436994256608, 17.38518365491267, 18.177772656542118, 16.499174215134424, 15.45846760076087, 14.523406675580782, 13.525541318722889, 12.57253325496495, 11.653954045610122, 10.604740332092106, 9.782120720993722, 8.82648278998378, 7.873653843425712, 8.909548934529267, 9.820831653818383, 10.739003797656238, 11.687587793728946, 12.660587683595713, 13.634348497151073, 14.424758844932615, 15.464091671991063, 16.393140157445917, 17.240006105730426, 15.508390297242226, 14.497058525921723, 13.512841859102675, 12.563030694730601, 11.619583358900282, 10.63031105338089, 9.64730375550523, 8.725170058434697, 7.866184559472103, 6.92008749256812, 7.842785204991504, 8.808467949339942, 9.772098998003333, 10.779490275374146, 11.827604396344272, 12.619345678445614, 13.471092628666483, 14.409222250656033, 15.341192298220491, 16.253152033570586, 14.563366996976722, 13.531682797682727, 12.5638402236284, 11.524157522749096, 10.559950656285817, 9.626302727577265, 8.637251082302244, 7.694515168679423, 6.858086217758981, 5.886093154262876, 6.901557726790418, 7.878376194852148, 8.841508851687802, 9.852881937615606, 10.889600053232687, 11.657761442940528, 12.490879207495496, 13.498144350754442, 14.321207339343882, 15.26179849262427, 13.684566464168876, 12.758292939359102, 11.780557325396597, 10.752632123897921, 9.736824907199448, 8.799217847484252, 7.758958020635294, 6.769266527894176, 5.847867548856873, 4.908425829840878, 5.843015818698673, 6.869461896520602, 7.8401492176473635, 8.81156041836152, 9.86014217644481, 10.699140014103302, 11.535150671019158, 12.450083416322471, 13.386648626819873, 14.438098272094436, 12.691364376045513, 11.744552400486931, 10.777030781262807, 9.76342869490923, 8.787156443055158, 7.771166610405051, 6.75261121682051, 5.823172581177865, 4.865016516803177, 3.972645802879434, 4.978430993064258, 5.943386756347356, 6.794838571810185, 7.840676237892099, 8.802005981920411, 9.707040204560336, 10.602316641501913, 11.515463552675909, 12.480924187109501, 13.486278123503318, 11.724158062747371, 10.733490479848614, 9.78587978094348, 8.774200263817995, 7.753443223290018, 6.785703934563045, 5.799043875995766, 4.937642462420361, 3.9232006265749124, 2.9559981570323712, 4.007709394633438, 4.911583808342964, 5.8627442359482, 6.856643706681529, 7.831756139383605, 8.691059733780834, 9.638384323679494, 10.570242003958018, 11.595497523966385, 12.586753835709834, 10.855093635882842, 9.858962810510535, 8.880177796413783, 7.863925226318394, 6.8371840382880595, 5.818480405141861, 4.794409620800258, 3.868962231179777, 2.9098011404416795, 1.9929361066830178, 2.9557688961606883, 3.960416319466062, 4.920079596960807, 5.86254551384424, 6.816154236834018, 7.753893642152802, 8.758542167240323, 9.701972907384366, 10.738941844756308, 11.798272588380417, 9.922576018485154, 9.007819749788766, 7.961167642429617, 6.915358452109849, 5.931967365953815, 4.935781109008794, 3.8611960728815022, 2.925789864654656, 1.9559881727413564, 1.0228336746588853, 1.9761512669266383, 2.9590003367100888, 3.971393646543213, 4.904946491312775, 5.838619016561075, 6.826995525397872, 7.9009677509311125, 8.915489891674314, 9.870406808817437, 10.858326050573393, 8.955944593288718, 8.005782843905713, 7.0248099818429415, 6.017023535370898, 5.075125055597663, 4.00889733147445, 3.06325270571058, 2.013747998281008, 0.976828423446641, 0.0, 1.0271419285496781, 2.0831361626819174, 3.0142841607881814, 3.961253546563566, 4.8864539899670305, 5.867291934675636, 6.922946273887072, 7.861428741869906, 8.859095855244158, 9.85954524085506, 9.910517687640178, 8.96995075384212, 7.901268936388331, 6.941586163093177, 6.008313902144763, 5.02075999841756, 4.0513498725104435, 2.9939369803921605, 2.0195394750868125, 0.9909205007155716, 1.9872147170395522, 2.9769645215846507, 3.9686875188145088, 4.942929603955811, 5.902537320579731, 6.8400657738748105, 7.79836423474943, 8.782911646983244, 9.806492418387256, 10.792007452435314, 10.779275003080137, 9.766349568758399, 8.83673574603872, 7.872883477295123, 7.028096009846314, 6.033360015570094, 5.0597061618810795, 4.052913100729395, 3.0157600424765105, 2.0444021480704446, 2.9952676760407844, 3.993559286193541, 4.943616129482753, 5.942056203685688, 6.931441980444486, 7.7835643138482, 8.729677290859694, 9.69992387420645, 10.664909940822675, 11.707298017574502, 11.69060239381305, 10.729372644252436, 9.776192689310339, 8.845806860513907, 7.96329169328337, 6.994522657109304, 6.031859157563478, 5.038876449194258, 3.9684595054242777, 3.1152117800057253, 4.0374664585857865, 5.041192272771846, 5.936686853375013, 6.899512070322654, 7.870239976841683, 8.72109110320806, 9.695816482367528, 10.688373987074321, 11.672610721276298, 12.615304312206144, 12.636451661360322, 11.698943913853377, 10.703395622621445, 9.80850594733062, 8.90073171729131, 8.029973636921923, 7.017603876946936, 5.973249264999234, 4.9014451097654845, 4.050314299627224, 5.009305227134478, 5.990793220307876, 6.8956885281183515, 7.9146339189803605, 8.822092364678696, 9.701672204123742, 10.675502729449178, 11.61799214547435, 12.604339306345604, 13.653586464607322, 13.66180014861813, 12.657110899199447, 11.725286772687827, 10.734275926295467, 9.899471001802343, 8.925365420271943, 7.8767918499847775, 6.894170480563085, 5.926747800164161, 5.057820510381209, 5.964791509104567, 6.900999379244351, 7.826379133366025, 8.836920625818786, 9.83713906969987, 10.639267619012777, 11.698859618220917, 12.689387354754894, 13.557094620358264, 14.49123468460458, 14.592554956137013, 13.714317598798605, 12.675995663226114, 11.692208733694944, 10.814223537476844, 9.815267057976017, 8.835572781252566, 7.863481869265731, 6.909060668349458, 6.056846243034893, 6.902443748116328, 7.904786292145986, 8.862315119716314, 9.86811362934988, 10.870289389498337, 11.630989496139401, 12.635853101454035, 13.708191054610964, 14.571404090533601, 15.422795914371363, 15.571019225232662, 14.630514997373979, 13.644483223372056, 12.62439283205396, 11.737779108843885, 10.78265506705514, 9.826353879185595, 8.833437453844558, 7.852871331560239, 7.088311803721645, 7.9120933776328854, 8.932857190813738, 9.861426408276333, 10.801874764933526, 11.808247752099897, 12.680168015859204, 13.596045832763254, 14.560718470519241, 15.521521921462181, 16.38700630533712, 16.59643131058889, 15.52302090344833, 14.56184487071905, 13.6249296907356, 12.671715373895527, 11.833230075916598, 10.778896863105022, 9.8547262566644, 8.868581866689079, 8.130164418056927, 8.884175255546497, 9.868951057727692, 10.856259398485818, 11.859898784106292, 12.800987790152284, 13.615696879611093, 14.558287786350494, 15.538891296403847, 16.580981050078137, 17.33689776820393, 17.587981415099254, 16.542039894223834, 15.549816974720434, 14.557621402902798, 13.639306847297412, 12.742043533295925, 11.786523451106797, 10.822976509058975, 9.864064959900105, 9.201628481752348, 9.828758404423503, 10.785712664348356, 11.833137244003845, 12.824927371559006, 13.809949045609144, 14.64467567189818, 15.524932521307795, 16.52734612967444, 17.539836970331372, 18.360254516053722], [18.336707621673842, 17.38706310855429, 16.3937207730103, 15.433928619468729, 14.63095532574902, 13.757159867984527, 12.806428830815099, 11.799825351946776, 10.76028754820686, 9.815524092573082, 10.047095724562999, 10.811379338418194, 11.775322011058588, 12.680180985874504, 13.625321697854975, 14.596357525111637, 15.451973052246302, 16.35127192442937, 17.291134977473313, 18.079622151372977, 18.091517953783974, 17.338913798123162, 16.43802851384619, 15.396580796552254, 14.461427391826954, 13.52208286768291, 12.508132379153338, 11.668444482349628, 10.681697475717167, 9.686619793544097, 9.00895945359824, 9.86909644279214, 10.779101377512559, 11.7282437054049, 12.698356305042239, 13.65847931281726, 14.379859453580334, 15.407525133604054, 16.358338845950644, 17.150927847580093, 17.150871434578356, 16.33825797633435, 15.403197051154264, 14.40533169429637, 13.452323630538432, 12.533744421183604, 11.484530707665588, 10.661911096567204, 9.706273165557262, 8.753444218999194, 8.033783600845924, 8.93159699686282, 9.757541461855526, 10.706125457928234, 11.679125347795, 12.60750368818905, 13.39791403597059, 14.437246863029038, 15.366295348483892, 16.2131612967684, 16.117877587955938, 15.376848901495205, 14.392632234676157, 13.442821070304083, 12.499373734473764, 11.510101428954371, 10.527094131078712, 9.604960434008179, 8.745974935045584, 7.799877868141602, 6.96701987130816, 7.919233292384379, 8.79063666220262, 9.752645466412122, 10.800759587382249, 11.59250086948359, 12.444247819704458, 13.382377441694008, 14.314347489258466, 15.226307224608561, 15.172854287690432, 14.411473173256208, 13.443630599201882, 12.403947898322578, 11.439741031859299, 10.506093103150747, 9.517041457875726, 8.574305544252905, 7.737876593332462, 6.7658835298363575, 6.025792393107073, 6.989141537896585, 7.814664042725779, 8.826037128653583, 9.862755244270664, 10.630916633978504, 11.464034398533471, 12.471299541792417, 13.294362530381857, 14.234953683662244, 14.34188157384333, 13.640324329094046, 12.662588715131545, 11.63466351363287, 10.618856296934393, 9.681249237219197, 8.640989410370238, 7.649056903467658, 6.727657924430354, 5.7882162054143595, 4.967250485015328, 5.967097961843657, 6.813304408685339, 7.784715609399496, 8.833297367482787, 9.672295205141278, 10.508305862057133, 11.423238607360446, 12.359803817857848, 13.411253463132411, 13.391387646497327, 12.626583790221876, 11.659062170997752, 10.645460084644178, 9.669187832790104, 8.653198000139996, 7.634642606555454, 6.702962956751347, 5.744806892376658, 4.8524361784529155, 4.0185831277936295, 4.9165419473853325, 5.767993762848161, 6.813831428930074, 7.775161172958387, 8.680195395598313, 9.575471832539888, 10.488618743713884, 11.454079378147476, 12.459433314541293, 12.606189452482315, 11.615521869583558, 10.667911170678424, 9.65623165355294, 8.635474613024963, 7.667735324297991, 6.681075265730711, 5.819673852155306, 4.802991002148394, 3.835788532605853, 2.980864585671414, 3.884738999380941, 4.835899426986176, 5.829798897719505, 6.8049113304215805, 7.66421492481881, 8.61153951471747, 9.543397194995993, 10.56865271500436, 11.559909026747809, 11.737125025617788, 10.740994200245481, 9.762209186148729, 8.74595661605334, 7.719215428023005, 6.700511794876806, 5.6764410105352034, 4.7509936209147225, 3.791832530176625, 2.8727264822564997, 1.9289240871986644, 2.9335715105040387, 3.8932347879987836, 4.835700704882216, 5.789309427871994, 6.7270488331907785, 7.7316973582783, 8.675128098422345, 9.712097035794287, 10.771427779418396, 10.823922944069764, 9.88985113952371, 8.843199032164561, 7.797389841844793, 6.813998755688759, 5.81781249874374, 4.7432274626164475, 3.8078212543896015, 2.838019562476302, 1.9026240502323675, 0.9493064579646145, 1.932155527748065, 2.9445488375811895, 3.878101682350751, 4.811477088011396, 5.799853596848194, 6.873825822381434, 7.888347963124636, 8.843264880267759, 9.831184122023714, 9.857291518873328, 9.032924772455392, 8.051951910392619, 7.044165463920576, 6.102266984147342, 5.036039260024128, 4.090394634260258, 3.040889926830686, 2.003970351996319, 1.0271419285496781, 0.0, 1.055994234132239, 1.987142232238503, 2.9341116180138878, 3.859312061417352, 4.840150006125958, 5.895804345337393, 6.834286813320228, 7.831953926694481, 8.832403312305381, 10.79917767694863, 9.9970926823918, 8.92841086493801, 7.968728091642856, 7.035455830694441, 6.0479019269672385, 5.078491801060122, 4.021078908941838, 3.0449680767137584, 1.971677739850164, 0.9753835235261832, 1.965133328071282, 2.9415455902648304, 3.9157876754061323, 4.875395392030053, 5.812923845325132, 6.771222306199752, 7.755769718433566, 8.779350489837578, 9.764865523885636, 11.65432856181897, 10.793491497308077, 9.863877674588398, 8.9000254058448, 8.043508471338274, 7.048772477062054, 6.07511862337304, 5.033670339863988, 3.996517281611103, 3.025159387205037, 1.9834364825274156, 2.9817280926801724, 3.9164742009330746, 4.9149142751360095, 5.904300051894808, 6.756422385298522, 7.702535362310016, 8.672781945656771, 9.637768012272996, 10.680156089024823, 12.579545089802917, 11.756514572802114, 10.803334617860017, 9.872948789063583, 8.97870415477533, 8.009935118601264, 7.01261639669807, 6.019633688328851, 4.94921674455887, 4.009054634332553, 3.025635265072417, 4.029361079258477, 4.909544924825335, 5.872370141772976, 6.8430980482920045, 7.693949174658381, 8.66867455381785, 9.661232058524643, 10.64546879272662, 11.588162383656465, 13.525394357350187, 12.726085842403055, 11.730537551171123, 10.835647875880296, 9.91614417878327, 9.045386098413882, 7.9983611160815276, 6.954006504133826, 5.882202348900077, 4.944157153954051, 3.9974740336211085, 4.978962026794507, 5.868546599568673, 6.887491990430682, 7.794950436129017, 8.674530275574062, 9.6483608008995, 10.590850216924672, 11.577197377795926, 12.626444536057644, 14.429790561098685, 13.684252827749125, 12.752428701237504, 11.761417854845144, 10.795490391117557, 9.821384809587157, 8.772811239299992, 7.790189869878299, 6.822767189479375, 5.878310435824914, 4.952960315591198, 5.889168185730981, 6.799237204816347, 7.809778697269108, 8.809997141150191, 9.612125690463097, 10.671717689671238, 11.662245426205216, 12.529952691808585, 13.464092756054901, 15.360545368617567, 14.732110201357163, 13.693788265784672, 12.710001336253502, 11.710242926792057, 10.711286447291231, 9.73159217056778, 8.759501258580945, 7.8050800576646715, 6.877336168478598, 5.890612554602958, 6.8929550986326165, 7.837150784673325, 8.840971700800202, 9.843147460948659, 10.603847567589721, 11.608711172904357, 12.681049126061286, 13.544262161983923, 14.395653985821685, 16.313606794290852, 15.648307599932537, 14.662275825930614, 13.642185434612518, 12.633798498159099, 11.678674456370354, 10.722373268500808, 9.729456843159774, 8.748890720875453, 7.8314205519214015, 6.900262184119516, 7.921025997300368, 8.849595214762962, 9.78889973485139, 10.79527272201776, 11.653026087309524, 12.568903904213576, 13.533576541969563, 14.494379992912503, 15.359864376787442, 17.273945207542972, 16.540098899069942, 15.578922866340662, 14.642007686357212, 13.56773476321074, 12.729249465231812, 11.674916252420235, 10.750745645979613, 9.764601256004292, 8.809675640739469, 7.872344062033127, 8.85711986421432, 9.844428204972447, 10.846923754024155, 11.788012760070147, 12.588554951061413, 13.531145857800816, 14.511749367854168, 15.553839121528457, 16.30975583965425, 18.30169820221782, 17.559117889845446, 16.561103170547845, 15.56890759873021, 14.535326236612626, 13.63806292261114, 12.68254284042201, 11.718995898374189, 10.760084349215319, 9.856474714118281, 8.816927210910134, 9.773881470834986, 10.821306050490476, 11.813096178045637, 12.798117852095775, 13.617533743348499, 14.497790592758117, 15.500204201124763, 16.512695041781694, 17.333112587504043], [17.2807133875416, 16.331068874422048, 15.33772653887806, 14.37793438533649, 13.574961091616782, 12.716292150014228, 11.79951897015068, 10.854607000963213, 10.073369261695635, 10.855390956796661, 10.935071853505368, 9.9095854687654, 10.873528141405794, 11.759387036212356, 12.704527748192826, 13.675563575449488, 14.40684847341512, 15.306147345598186, 16.246010398642127, 17.03449757254179, 17.04639337495279, 17.307104759102202, 16.3685328498869, 15.318332464324433, 14.562539827598938, 13.762247456445328, 12.739412174228617, 11.854975268306353, 11.05028850212392, 10.742614027676336, 9.89693558254061, 8.967302573139346, 9.85830742785041, 10.807449755742752, 11.77756235538009, 12.613354733986077, 13.334734874749152, 14.362400554772872, 15.31321426711946, 16.105803268748907, 16.10574685574717, 17.072570236661875, 16.4591912852865, 15.461325928428609, 14.508317864670671, 13.589738655315843, 12.540524941797827, 11.717905330699443, 10.7622673996895, 9.809438453131433, 8.991542614149648, 8.029803127210027, 8.836747512193377, 9.785331508266085, 10.758331398132851, 11.562379109357867, 12.352789457139409, 13.392122284197857, 14.321170769652708, 15.168036717937218, 15.072753009124753, 16.11116116182273, 15.448626468808396, 14.498815304436322, 13.555367968606003, 12.56609566308661, 11.583088365210951, 10.660954668140418, 9.801969169177823, 8.85587210227384, 7.924778884611884, 7.017439422731586, 7.869842712540471, 8.831851516749973, 9.8799656377201, 10.547376290652407, 11.399123240873276, 12.337252862862826, 13.269222910427283, 14.181182645777378, 14.127729708859249, 15.159413908153244, 14.49962483333412, 13.459942132454817, 12.495735265991538, 11.562087337282986, 10.573035692007965, 9.630299778385144, 8.793870827464703, 7.8218777639685975, 6.983551406410797, 6.087347668243792, 6.893870093063629, 7.905243178991434, 8.817630665439482, 9.585792055147321, 10.41890981970229, 11.426174962961234, 12.249237951550674, 13.18982910483106, 13.296756995012148, 14.251962996508878, 13.718582949263784, 12.690657747765108, 11.674850531066632, 10.737243471351436, 9.696983644502478, 8.705051137599897, 7.783652158562594, 6.8442104395465995, 5.925009498319052, 5.065304092190864, 5.892510459023191, 6.863921659737347, 7.788172788651605, 8.627170626310095, 9.463181283225952, 10.378114028529263, 11.314679239026665, 12.36612888430123, 12.346263067666145, 13.321848563847935, 12.71505640512999, 11.701454318776417, 10.725182066922343, 9.709192234272235, 8.690636840687693, 7.758957190883587, 6.800801126508898, 5.9084304125851554, 4.976342141097353, 4.0147480777325395, 4.847199813186013, 5.893037479267926, 6.7300365941272045, 7.635070816767129, 8.530347253708706, 9.4434941648827, 10.408954799316295, 11.414308735710112, 11.575456989647696, 12.566124572546453, 11.723905404810663, 10.712225887685179, 9.691468847157202, 8.723729558430229, 7.73706949986295, 6.875668086287545, 5.858985236280634, 4.891782766738093, 3.938623598975137, 2.9829451297281486, 3.915105477324027, 4.844354673945246, 5.759786751590398, 6.619090345987627, 7.566414935886287, 8.49827261616481, 9.523528136173177, 10.514784447916625, 10.774420754647636, 11.685092901817423, 10.818203420280968, 9.801950850185579, 8.775209662155245, 7.756506029009045, 6.7324352446674425, 5.806987855046962, 4.847826764308865, 3.9287207163887397, 2.9849183213309036, 2.0317776408512462, 2.9724408383366345, 3.8502564811079574, 4.744184849040812, 5.681924254359595, 6.686572779447117, 7.630003519591161, 8.666972456963101, 9.72630320058721, 9.767928709937525, 10.710902661311412, 9.899193266296798, 8.853384075977031, 7.869992989820998, 6.873806732875979, 5.7992216967486865, 4.8638154885218405, 3.8940137966085415, 2.958618284364607, 2.0053006920968537, 1.0303616580952728, 1.959104613806931, 2.8926574585764926, 3.7554828538791574, 4.743859362715954, 5.817831588249195, 6.832353728992397, 7.787270646135519, 8.775189887891473, 8.80129728474109, 9.751459034124094, 9.107946144524858, 8.100159698052815, 7.158261218279581, 6.092033494156367, 5.146388868392497, 4.096884160962926, 3.0599645861285585, 2.0831361626819174, 1.055994234132239, 0.0, 0.9311479981062639, 1.8781173838816485, 2.803317827285113, 3.7841557719937184, 4.839810111205154, 5.778292579187989, 6.775959692562242, 7.776409078173143, 9.743183442816392, 10.720954420940588, 9.98440509907025, 9.024722325775095, 8.091450064826681, 7.103896161099478, 6.134486035192362, 5.077073143074078, 4.084834940937338, 3.0115446040737432, 2.0152503877497625, 1.025500583204664, 1.8855513561325914, 2.8597934412738932, 3.819401157897814, 4.756929611192892, 5.715228072067512, 6.699775484301326, 7.723356255705338, 8.708871289753398, 10.598334327686729, 11.611259762008467, 10.919871908720637, 9.95601963997704, 9.083375335561852, 8.088639341285631, 7.114985487596618, 6.073537204087566, 5.036384145834682, 4.065026251428616, 3.023303346750995, 2.0675185525349096, 2.8604799668008356, 3.8589200410037705, 4.848305817762569, 5.700428151166282, 6.646541128177776, 7.61678771152453, 8.581773778140755, 9.624161854892582, 11.523550855670676, 12.48478060523129, 11.859328851992256, 10.928943023195822, 10.018571018998909, 9.04980198282484, 8.05248326092165, 7.0595005525524295, 5.989083608782449, 5.048921498556132, 4.0655021292959965, 3.1151515391132136, 3.853550690693096, 4.816375907640737, 5.7871038141597655, 6.637954940526141, 7.6126803196856105, 8.605237824392402, 9.589474558594379, 10.532168149524225, 12.469400123217948, 13.427433503757875, 12.786531785303362, 11.891642110012535, 10.956011043006848, 10.085252962637458, 9.038227980305107, 7.993873368357406, 6.922069213123656, 5.984024018177631, 5.037340897844688, 4.064752486649244, 4.812552365436434, 5.831497756298443, 6.738956201996778, 7.618536041441823, 8.59236656676726, 9.534855982792433, 10.521203143663687, 11.570450301925405, 13.373796326966445, 14.385600489103945, 13.808422935369743, 12.817412088977383, 11.835357255341137, 10.861251673810736, 9.812678103523572, 8.830056734101879, 7.862634053702955, 6.918177300048494, 5.992827179814777, 5.112173525171773, 5.743242970684108, 6.753784463136869, 7.754002907017952, 8.556131456330858, 9.615723455539, 10.606251192072977, 11.473958457676346, 12.408098521922662, 14.304551134485328, 15.334053668927542, 14.733655130008252, 13.749868200477081, 12.750109791015637, 11.75115331151481, 10.77145903479136, 9.799368122804525, 8.844946921888251, 7.917203032702178, 6.930479418826538, 6.115960438073408, 6.781156550541086, 7.7849774666679625, 8.78715322681642, 9.547853333457482, 10.552716938772118, 11.625054891929047, 12.488267927851684, 13.339659751689446, 15.257612560158615, 16.20448584555675, 15.702142690154194, 14.682052298836098, 13.673665362382678, 12.718541320593934, 11.762240132724388, 10.769323707383354, 9.788757585099033, 8.87128741614498, 7.9401290483430955, 7.187413694396999, 7.8297451753940965, 8.73290550071915, 9.739278487885521, 10.597031853177285, 11.512909670081337, 12.477582307837324, 13.438385758780264, 14.303870142655203, 16.217950973410733, 17.198663964510445, 16.61878973056424, 15.681874550580792, 14.60760162743432, 13.769116329455391, 12.714783116643815, 11.790612510203193, 10.804468120227872, 9.849542504963049, 8.912210926256707, 8.123507561310952, 8.824578165603581, 9.790929519891916, 10.732018525937908, 11.532560716929174, 12.475151623668577, 13.45575513372193, 14.497844887396218, 15.253761605522012, 17.245703968085582, 17.30398262317862, 16.35070474582638, 15.358509174008745, 14.632861930430598, 13.68183197438664, 12.745036893425407, 11.880072877656556, 10.921161328497687, 10.896341578341861, 9.856794075133713, 9.086963184323762, 9.852986504877121, 10.806186317381218, 11.757250134125476, 12.56153950921626, 13.441796358625878, 14.444209966992524, 15.456700807649453, 16.277118353371804], [16.349565389435334, 15.399920876315784, 14.406578540771795, 13.446786387230224, 12.643813093510518, 11.785144151907964, 10.868370972044417, 9.923459002856948, 10.713121962049064, 11.636730518645201, 11.766856129283044, 10.741369744543075, 9.99272663012413, 10.82823903810609, 11.773379750086562, 12.744415577343224, 13.475700475308855, 14.374999347491922, 15.314862400535862, 16.103349574435526, 16.115245376846524, 16.37595676099594, 15.437384851780637, 14.387184466218168, 13.631391829492674, 12.831099458339065, 11.808264176122353, 10.923827270200087, 11.690041202477348, 11.593974291506974, 10.728719858318286, 9.799086848917021, 8.927159429744146, 9.876301757636487, 10.846414357273826, 11.682206735879813, 12.403586876642887, 13.431252556666609, 14.382066269013196, 15.174655270642644, 15.174598857640905, 16.141422238555613, 16.413943696229026, 15.416078339371133, 14.640495590781196, 13.81943790483837, 12.831865847610104, 11.973049747773565, 11.61362766352014, 10.660798716962072, 9.82751383035004, 8.861587402987702, 7.905599514087113, 8.854183510159821, 9.827183400026588, 10.631231111251603, 11.421641459033143, 12.460974286091593, 13.390022771546445, 14.236888719830954, 14.14160501101849, 15.180013163716467, 16.146151190457957, 15.429963302542586, 14.486515966712265, 13.497243661192876, 12.514236363317213, 11.592102666246682, 10.653329433008462, 9.70723236610448, 8.760750100812276, 7.849223698509261, 6.938694714434208, 7.900703518643709, 8.948817639613836, 9.616228292546143, 10.467975242767013, 11.406104864756562, 12.33807491232102, 13.250034647671114, 13.196581710752985, 14.228265910046982, 15.196108484101309, 14.39109013056108, 13.426883264097802, 12.49323533538925, 11.504183690114228, 10.561447776491407, 9.691441225899352, 8.673238027799236, 7.8195226226111885, 6.919131944021467, 5.962722094957366, 6.97409518088517, 7.886482667333219, 8.654644057041057, 9.487761821596026, 10.49502696485497, 11.31808995344441, 12.258681106724797, 12.365608996905882, 13.320814998402613, 14.312222012005865, 13.621805745871374, 12.605998529172897, 11.668391469457701, 10.628131642608743, 9.63619913570616, 8.681222556997243, 7.695570703377238, 6.760980714519444, 5.897088367968539, 4.961362460916927, 5.932773661631083, 6.857024790545341, 7.69602262820383, 8.532033285119688, 9.446966030422999, 10.383531240920401, 11.434980886194964, 11.41511506955988, 12.39070056574167, 13.454264905637784, 12.632602316882682, 11.656330065028609, 10.6403402323785, 9.621784838793959, 8.69010518898985, 7.731949124615162, 6.818098547482569, 5.812313357297745, 4.846532353510215, 3.9160518150797485, 4.961889481161662, 5.798888596020941, 6.703922818660866, 7.599199255602442, 8.512346166776437, 9.47780680121003, 10.483160737603846, 10.644308991541433, 11.63497657444019, 12.582587273345323, 11.643373885791444, 10.622616845263467, 9.654877556536494, 8.668217497969215, 7.806816084393809, 6.790133234386897, 5.822930764844356, 4.8697715970814, 3.9140931278344127, 2.983957479217763, 3.9132066758389823, 4.828638753484134, 5.687942347881363, 6.635266937780023, 7.567124618058547, 8.592380138066913, 9.583636449810362, 9.843272756541374, 10.75394490371116, 11.732729917807912, 10.73309884829184, 9.706357660261506, 8.687654027115308, 7.663583242773706, 6.738135853153225, 5.778974762415128, 4.859868714495003, 3.9160663194371677, 2.9629256389575103, 2.0412928402303705, 2.9191084830016933, 3.8130368509345476, 4.7507762562533316, 5.755424781340853, 6.698855521484897, 7.735824458856838, 8.795155202480947, 8.836780711831262, 9.779754663205148, 10.826406770564297, 9.784532074083295, 8.801140987927262, 7.804954730982242, 6.73036969485495, 5.794963486628104, 4.825161794714805, 3.8897662824708705, 2.9364486902031177, 1.9615096562015366, 1.027956615700667, 1.9615094604702286, 2.824334855772894, 3.81271136460969, 4.8866835901429315, 5.901205730886133, 6.856122648029255, 7.84404188978521, 7.870149286634826, 8.82031103601783, 9.801283898080603, 9.031307696159079, 8.089409216385844, 7.023181492262631, 6.077536866498761, 5.028032159069189, 3.991112584234822, 3.014284160788181, 1.987142232238503, 0.9311479981062639, 0.0, 0.9469693857753846, 1.872169829178849, 2.8530077738874544, 3.90866211309889, 4.847144581081724, 5.844811694455977, 6.845261080066878, 8.812035444710126, 9.789806422834324, 10.739191229705238, 9.95587032388136, 9.022598062932946, 8.035044159205743, 7.065634033298625, 6.008221141180342, 5.015982939043601, 3.9426926021800073, 2.9463983858560265, 1.9566485813109278, 0.9544033580263275, 1.9286454431676292, 2.8882531597915495, 3.8257816130866282, 4.784080073961247, 5.7686274861950615, 6.792208257599073, 7.777723291647133, 9.667186329580465, 10.680111763902204, 11.609725586621883, 10.887167638083305, 10.014523333668116, 9.019787339391895, 8.046133485702882, 7.00468520219383, 5.967532143940946, 4.99617424953488, 3.954451344857259, 2.9825264666745173, 1.929331968694572, 2.9277720428975065, 3.9171578196563046, 4.769280153060018, 5.715393130071512, 6.685639713418267, 7.650625780034492, 8.693013856786319, 10.592402857564412, 11.553632607125026, 12.549182529893502, 11.860091021302088, 10.949719017105172, 9.93935583684675, 8.903309047316057, 7.910326338946838, 6.839909395176858, 5.862780595594797, 4.8793612263346615, 3.8698041175641933, 2.9224026925868323, 3.885227909534473, 4.855955816053502, 5.7068069424198775, 6.681532321579347, 7.674089826286139, 8.658326560488115, 9.601020151417961, 11.538252125111683, 12.49628550565161, 13.476385463204608, 12.8227901081188, 11.887159041113112, 10.930434932375322, 9.877571328205658, 8.833216716257956, 7.761412561024207, 6.797883115216296, 5.818680459693227, 4.819405065100224, 3.8814043673301706, 4.9003497581921796, 5.807808203890515, 6.6873880433355595, 7.661218568660998, 8.603707984686169, 9.590055145557423, 10.639302303819143, 12.44264832886018, 13.45445249099768, 14.436515061628734, 13.66767448534481, 12.616696817189675, 11.642591235659275, 10.59401766537211, 9.611396295950417, 8.643973615551493, 7.699516861897033, 6.774166741663317, 5.844854568439818, 4.812094972577844, 5.822636465030605, 6.8228549089116886, 7.624983458224595, 8.684575457432738, 9.675103193966713, 10.542810459570081, 11.476950523816397, 13.373403136379062, 14.402905670821276, 15.441227606393767, 14.53120776232562, 13.531449352864175, 12.53249287336335, 11.552798596639898, 10.580707684653063, 9.62628648373679, 8.698542594550716, 7.711818980675078, 6.80753738000515, 5.850008552434822, 6.853829468561699, 7.856005228710156, 8.616705335351218, 9.621568940665853, 10.693906893822783, 11.557119929745419, 12.40851175358318, 14.32646456205235, 15.273337847450485, 16.259369621452407, 15.463391860684636, 14.455004924231217, 13.499880882442472, 12.543579694572927, 11.550663269231892, 10.570097146947571, 9.65262697799352, 8.721468610191636, 7.827166394750427, 6.898597177287833, 7.801757502612887, 8.808130489779257, 9.665883855071021, 10.581761671975071, 11.546434309731058, 12.507237760673998, 13.372722144548938, 15.286802975304466, 16.26751596640418, 16.29696806805313, 15.360052888069678, 14.66930540572622, 13.820174147539486, 12.821515483320917, 12.073231147944913, 11.58580768207641, 10.630882066811589, 9.693550488105247, 8.76326026166438, 7.893430167497317, 8.859781521785653, 9.800870527831645, 10.60141271882291, 11.544003625562311, 12.524607135615664, 13.566696889289952, 14.322613607415747, 16.314555969979317, 16.372834625072354, 15.419556747720115, 14.42736117590248, 13.701713932324335, 12.750683976280376, 11.813888895319142, 11.03734107491988, 11.752945604275363, 11.677681140190401, 10.638133636982253, 9.72671588467719, 8.921838506770857, 9.875038319274955, 10.826102136019212, 11.630391511109996, 12.510648360519612, 13.513061968886259, 14.525552809543187, 15.345970355265537], [15.40259600365995, 14.4529514905404, 13.45960915499641, 12.49981700145484, 11.696843707735134, 10.909795399322876, 10.093745215242837, 10.870428388632334, 11.66009134782445, 12.583699904420586, 12.713825515058428, 11.68833913031846, 10.939696015899514, 10.04884475116268, 10.900144667804536, 11.800811108876873, 12.528731089533473, 13.428029961716538, 14.367893014760478, 15.156380188660144, 15.16827599107114, 15.428987375220556, 14.490415466005253, 13.440215080442783, 12.68442244371729, 11.955750705753976, 11.033638419320773, 11.870796655975473, 12.637010588252734, 12.540943677282359, 11.67568924409367, 10.746056234692405, 9.87412881551953, 9.096907470693075, 9.9731792749918, 10.735237350104427, 11.456617490867504, 12.484283170891224, 13.435096883237811, 14.22768588486726, 14.227629471865523, 15.19445285278023, 15.466974310453642, 14.469108953595748, 13.693526205005812, 12.944089152253282, 12.057240090808524, 12.920019133548951, 12.560597049295524, 11.607768102737456, 10.774483216125423, 9.808556788763086, 8.852568899862497, 8.074789223216408, 8.953948317744562, 9.684261725476217, 10.47467207325776, 11.514004900316209, 12.44305338577106, 13.28991933405557, 13.194635625243105, 14.233043777941083, 15.199181804682569, 15.431619577588036, 14.64647610107048, 13.967860578339224, 13.014676667395399, 12.539072052022066, 11.600298818783846, 10.654201751879864, 9.70771948658766, 8.796193084284646, 7.885664100209592, 7.027929014248764, 8.009642156232175, 8.669258906770757, 9.521005856991628, 10.459135478981178, 11.391105526545635, 12.30306526189573, 12.249612324977601, 13.281296524271596, 14.249139098325923, 15.288821799205227, 14.373852649873186, 13.440204721164633, 12.451153075889613, 11.508417162266792, 10.638410611674736, 9.62020741357462, 8.766492008386573, 7.866101329796852, 6.90969148073275, 6.101320676490225, 6.939513281557833, 7.707674671265672, 8.540792435820642, 9.548057579079586, 10.371120567669026, 11.311711720949413, 11.4186396111305, 12.37384561262723, 13.365252626230482, 14.393177827729158, 13.552967914948281, 12.615360855233085, 11.575101028384127, 10.583168521481545, 9.628191942772627, 8.642540089152622, 7.707950100294828, 6.8440577537439236, 5.908331846692311, 5.059999157236138, 5.910055404769956, 6.749053242428446, 7.585063899344304, 8.499996644647615, 9.436561855145017, 10.488011500419582, 10.468145683784497, 11.443731179966287, 12.507295519862401, 13.570991727929858, 12.603299450803993, 11.587309618153885, 10.568754224569343, 9.637074574765235, 8.678918510390547, 7.765067933257953, 6.759282743073129, 5.793501739285599, 4.863021200855133, 4.066256321921347, 4.851919210245556, 5.7569534328854814, 6.652229869827058, 7.565376781001053, 8.530837415434647, 9.536191351828464, 9.697339605766048, 10.688007188664805, 11.63561788756994, 12.590343271566828, 11.569586231038851, 10.601846942311878, 9.615186883744599, 8.753785470169195, 7.7371026201622835, 6.769900150619742, 5.816740982856785, 4.861062513609797, 3.9309268649931477, 2.998096092340998, 3.8816693677087493, 4.740972962105979, 5.688297552004639, 6.620155232283163, 7.645410752291529, 8.636667064034977, 8.89630337076599, 9.806975517935777, 10.78576053203253, 11.680068234067226, 10.653327046036893, 9.634623412890694, 8.61055262854909, 7.68510523892861, 6.725944148190513, 5.806838100270388, 4.863035705212552, 3.9098950247328945, 2.988262226005755, 2.003997899503709, 2.866067465159163, 3.803806870477947, 4.808455395565469, 5.751886135709513, 6.788855073081454, 7.848185816705563, 7.889811326055878, 8.832785277429766, 9.879437384788915, 10.73150145985868, 9.748110373702648, 8.751924116757628, 7.677339080630335, 6.741932872403489, 5.77213118049019, 4.836735668246256, 3.8834180759785024, 2.9084790419769213, 1.9749260014760517, 1.0463988769722443, 1.877365469997509, 2.8657419788343055, 3.9397142043675464, 4.954236345110749, 5.909153262253871, 6.8970725040098255, 6.9231799008594415, 7.873341650242446, 8.854314512305217, 9.86210095877726, 9.036378602161228, 7.970150878038015, 7.024506252274145, 5.975001544844574, 4.938081970010207, 3.961253546563566, 2.9341116180138878, 1.8781173838816485, 0.9469693857753846, 0.0, 0.9252004434034646, 1.90603838811207, 2.9616927273235056, 3.90017519530634, 4.897842308680593, 5.898291694291494, 7.865066058934743, 8.842837037058938, 9.792221843929852, 10.751904617225007, 9.969567448708329, 8.982013544981125, 8.01260341907401, 6.955190526955726, 5.9629523248189855, 4.8896619879553915, 3.8933677716314112, 2.9036179670863125, 1.901372743801712, 0.9816760573922446, 1.9412837740161653, 2.8788122273112435, 3.837110688185863, 4.821658100419677, 5.845238871823689, 6.830753905871749, 8.72021694380508, 9.733142378126818, 10.662756200846497, 11.683201931426954, 10.9614927194435, 9.96675672516728, 8.993102871478266, 7.951654587969214, 6.91450152971633, 5.943143635310264, 4.901420730632644, 3.9294958524499015, 2.8763013544699563, 1.9808026571221218, 2.9701884338809204, 3.822310767284633, 4.768423744296127, 5.738670327642882, 6.703656394259107, 7.746044471010933, 9.645433471789026, 10.60666322134964, 11.602213144118116, 12.543952605557752, 11.896688402880557, 10.886325222622135, 9.850278433091443, 8.857295724722222, 7.786878780952242, 6.809749981370182, 5.826330612110046, 4.8167735033395775, 3.8693720783622165, 3.022965135207068, 3.908986430278117, 4.759837556644492, 5.734562935803962, 6.7271204405107525, 7.71135717471273, 8.654050765642575, 10.591282739336297, 11.549316119876224, 12.529416077429222, 13.491207720201507, 12.834128426888496, 11.877404318150706, 10.824540713981042, 9.78018610203334, 8.70838194679959, 7.74485250099168, 6.765649845468611, 5.766374450875608, 4.828373753105555, 4.053235342497084, 4.8608388181151305, 5.740418657560173, 6.714249182885613, 7.656738598910784, 8.643085759782037, 9.692332918043757, 11.495678943084794, 12.507483105222294, 13.489545675853348, 14.416977699166354, 13.56366620296506, 12.589560621434659, 11.540987051147495, 10.558365681725801, 9.590943001326877, 8.646486247672417, 7.721136127438701, 6.791823954215202, 5.759064358353228, 5.048010708229026, 5.875885523136304, 6.6780140724492085, 7.7376060716573525, 8.728133808191327, 9.595841073794695, 10.52998113804101, 12.426433750603676, 13.45593628504589, 14.49425822061838, 15.374910506565831, 14.47841873863956, 13.479462259138733, 12.499767982415282, 11.527677070428448, 10.573255869512174, 9.6455119803261, 8.658788366450462, 7.754506765780534, 6.7969779382102065, 6.079203711760119, 6.909035842934772, 7.669735949575833, 8.674599554890468, 9.746937508047397, 10.610150543970033, 11.461542367807795, 13.379495176276963, 14.326368461675099, 15.312400235677021, 15.413620360975935, 14.659637202311512, 13.950965368166479, 12.994664180296933, 12.497632655007276, 11.517066532722955, 10.599596363768905, 9.66843799596702, 8.774135780525812, 7.845566563063217, 7.027131745811307, 7.93278173719417, 8.718914469295637, 9.634792286199687, 10.599464923955674, 11.560268374898614, 12.425752758773552, 14.33983358952908, 15.320546580628791, 15.349998682277747, 14.413083502294295, 13.72570093725987, 12.94693906525746, 12.042121196377506, 12.99714492808862, 12.532777067851795, 11.577851452586973, 10.640519873880631, 9.710229647439766, 8.840399553272702, 8.085155764984073, 8.925521775246557, 9.654443333047526, 10.597034239786927, 11.57763774984028, 12.619727503514568, 13.37564422164036, 15.36758658420393, 15.425865239296972, 14.472587361944733, 13.480391790127097, 12.758109463857984, 11.87744889399835, 11.03449460837573, 11.984310460695262, 12.699914990050747, 12.624650525965787, 11.585103022757638, 10.673685270452577, 9.868807892546242, 9.100412562473375, 9.950753383434124, 10.683422125334612, 11.563678974744228, 12.566092583110875, 13.578583423767803, 14.399000969490151], [14.477395560256486, 13.527751047136936, 12.534408711592947, 11.574616558051376, 10.77164326433167, 9.98459495591941, 10.998876858841248, 11.7956288320358, 12.585291791227915, 13.50890034782405, 13.639025958461893, 12.613539573721924, 11.86489645930298, 10.917123976383074, 9.974944224401073, 10.87561066547341, 11.603530646130007, 12.502829518313073, 13.442692571357012, 14.231179745256679, 14.243075547667674, 14.503786931817093, 13.56521502260179, 12.51501463703932, 11.759222000313827, 11.030550262350511, 11.938770062919184, 12.795997099378939, 13.562211031656199, 13.466144120685824, 12.600889687497135, 11.67125667809587, 10.799329258922995, 9.96518669591347, 9.047978831588336, 9.810036906700963, 10.53141704746404, 11.559082727487759, 12.509896439834346, 13.302485441463794, 13.302429028462058, 14.269252409376765, 14.541773867050178, 13.543908510192285, 12.768325761602348, 12.018888708849817, 12.962371734406934, 13.845219576952417, 13.485797492698989, 12.532968546140921, 11.699683659528887, 10.733757232166552, 9.777769343265962, 8.943068448436804, 8.028747874341098, 8.759061282072754, 9.549471629854295, 10.588804456912744, 11.517852942367595, 12.364718890652105, 12.26943518183964, 13.307843334537617, 14.273981361279104, 14.506419134184572, 13.721275657667016, 13.042660134935758, 13.919808310993812, 13.46427249542553, 12.525499262187312, 11.579402195283329, 10.632919929991123, 9.721393527688111, 8.810864543613057, 7.89620823946916, 7.0844417128287125, 7.744058463367293, 8.595805413588163, 9.533935035577713, 10.46590508314217, 11.377864818492265, 11.324411881574136, 12.35609608086813, 13.323938654922458, 14.363621355801762, 14.78090836028148, 14.046668460739383, 13.376353519293076, 12.433617605670255, 11.563611055078201, 10.545407856978086, 9.691692451790036, 8.791301773200317, 7.834891924136215, 6.9695999017106205, 6.014312838154369, 6.782474227862207, 7.615591992417176, 8.62285713567612, 9.44592012426556, 10.386511277545948, 10.493439167727034, 11.448645169223765, 12.440052182827017, 13.467977384325692, 14.478168358351747, 13.54056129863655, 12.500301471787592, 11.508368964885008, 10.553392386176093, 9.567740532556087, 8.633150543698292, 7.769258197147388, 6.833532290095776, 5.928278382456534, 4.984854961366492, 5.823852799024981, 6.6598634559408385, 7.574796201244149, 8.511361411741552, 9.562811057016116, 9.542945240381032, 10.518530736562822, 11.582095076458936, 12.645791284526393, 13.528499894207458, 12.51251006155735, 11.493954667972808, 10.562275018168698, 9.60411895379401, 8.690268376661416, 7.6844831864765935, 6.718702182689063, 5.788221644258598, 4.934535547141742, 3.9267187668420913, 4.831752989482016, 5.727029426423592, 6.6401763375975875, 7.6056369720311805, 8.610990908424998, 8.772139162362581, 9.762806745261338, 10.710417444166472, 11.722096961291957, 12.494786674442317, 11.527047385715344, 10.540387327148064, 9.67898591357266, 8.662303063565746, 7.695100594023206, 6.741941426260249, 5.786262957013261, 4.856127308396612, 3.8885739375827657, 2.956468924305285, 3.8157725187025138, 4.7630971086011735, 5.694954788879698, 6.720210308888063, 7.711466620631511, 7.971102927362525, 8.881775074532312, 9.860560088629065, 10.876812658724454, 11.578527489440358, 10.559823856294159, 9.535753071952556, 8.610305682332076, 7.651144591593978, 6.732038543673853, 5.788236148616017, 4.835095468136359, 3.9134626694092196, 2.8944757447454768, 1.9408670217556983, 2.878606427074482, 3.8832549521620034, 4.8266856923060475, 5.863654629677988, 6.922985373302097, 6.964610882652413, 7.9075848340262995, 8.95423694138545, 9.93510327972439, 10.673310817106112, 9.677124560161092, 8.6025395240338, 7.667133315806954, 6.697331623893654, 5.76193611164972, 4.808618519381967, 3.8336794853803857, 2.900126444879516, 1.971599320375709, 0.9521650265940445, 1.940541535430841, 3.014513760964082, 4.029035901707283, 4.983952818850406, 5.97187206060636, 5.997979457455976, 6.94814120683898, 7.929114068901752, 8.936900515373795, 9.87879899514703, 8.895351321441481, 7.949706695677611, 6.900201988248038, 5.863282413413671, 4.8864539899670305, 3.859312061417352, 2.803317827285113, 1.872169829178849, 0.9252004434034646, 0.0, 0.9808379447086053, 2.0364922839200412, 2.9749747519028755, 3.9726418652771285, 4.97309125088803, 6.9398656155312795, 7.917636593655474, 8.867021400526387, 9.826704173821541, 10.759976434769957, 9.90721398838459, 8.937803862477473, 7.880390970359191, 6.888152768222451, 5.814862431358857, 4.818568215034876, 3.8288184104897773, 2.8265731872051765, 1.9068765007957094, 1.0160833306127006, 1.9536117839077791, 2.9119102447823986, 3.8964576570162133, 4.920038428420225, 5.905553462468285, 7.795016500401616, 8.807941934723354, 9.737555757443033, 10.758001488023488, 11.735695540834524, 10.891957168570745, 9.918303314881731, 8.87685503137268, 7.839701973119795, 6.868344078713729, 5.8266211740361085, 4.8546962958533655, 3.8015017978734207, 2.9060031005255866, 2.0449879904774555, 2.8971103238811686, 3.8432233008926633, 4.813469884239418, 5.778455950855643, 6.820844027607469, 8.720233028385563, 9.681462777946177, 10.677012700714652, 11.618752162154289, 12.60808363864919, 11.811525666025597, 10.775478876494905, 9.782496168125686, 8.712079224355707, 7.734950424773646, 6.75153105551351, 5.741973946743042, 4.794572521765681, 3.948165578610533, 2.9837859868746524, 3.834637113241028, 4.809362492400497, 5.801919997107289, 6.7861567313092666, 7.728850322239112, 9.666082295932835, 10.624115676472762, 11.604215634025758, 12.566007276798043, 13.545523662657128, 12.80260476155417, 11.749741157384506, 10.705386545436804, 9.633582390203054, 8.670052944395144, 7.690850288872076, 6.691574894279072, 5.753574196509019, 4.978435785900549, 3.9356383747116657, 4.81521821415671, 5.789048739482149, 6.7315381555073195, 7.717885316378574, 8.767132474640292, 10.570478499681332, 11.582282661818832, 12.564345232449886, 13.49177725576289, 14.488866646368523, 13.514761064838122, 12.466187494550958, 11.483566125129265, 10.516143444730341, 9.57168669107588, 8.646336570842164, 7.717024397618667, 6.684264801756694, 5.9732111516324915, 4.950685079732839, 5.752813629045745, 6.812405628253888, 7.802933364787863, 8.670640630391233, 9.60478069463755, 11.501233307200215, 12.530735841642429, 13.569057777214919, 14.449710063162367, 14.75821379655366, 14.130695125414364, 13.424968425818745, 12.452877513831911, 11.498456312915637, 10.570712423729564, 9.583988809853926, 8.679707209184, 7.722178381613672, 6.997387271294335, 5.983835399531307, 6.74453550617237, 7.749399111487005, 8.821737064643933, 9.68495010056657, 10.536341924404333, 12.454294732873501, 13.401168018271637, 14.38719979227356, 14.48841991757247, 13.734436758908048, 13.079006267229152, 13.862943405517328, 13.42283309841074, 12.442266976126419, 11.524796807172368, 10.593638439370483, 9.699336223929278, 8.770767006466683, 7.945315305345524, 7.007581293790705, 7.793714025892173, 8.709591842796224, 9.67426448055221, 10.63506793149515, 11.50055231537009, 13.414633146125619, 14.39534613722533, 14.424798238874281, 13.48788305889083, 12.800500493856406, 12.021738621853997, 12.9104004215979, 13.865424153309014, 13.457977511255258, 12.503051895990437, 11.565720317284095, 10.635430090843231, 9.765599996676167, 9.00333932451829, 8.000321331843091, 8.729242889644063, 9.671833796383464, 10.652437306436816, 11.694527060111104, 12.450443778236899, 14.442386140800469, 14.500664795893506, 13.547386918541267, 12.555191346723632, 11.83290902045452, 10.952248450594887, 11.902773833596125, 12.909510904098727, 13.625115433454212, 13.549850969369249, 12.510303466161101, 11.598885713856042, 10.794008335949707, 10.010574614080799, 9.025552940030659, 9.758221681931149, 10.638478531340764, 11.640892139707411, 12.65338298036434, 13.47380052608669], [13.49655761554788, 12.54691310242833, 11.553570766884341, 10.59377861334277, 9.790805319623065, 10.770201716409764, 11.784483619331601, 12.720656345212273, 13.510319304404389, 14.454963557343202, 14.610167108376064, 13.584680723636096, 12.713556941385239, 11.723564042743137, 10.76696451188856, 9.942639207305522, 10.67055918796212, 11.569858060145185, 12.509721113189126, 13.29820828708879, 13.310104089499788, 13.522948987108487, 12.584377077893183, 11.534176692330714, 10.77838405560522, 11.755597268556023, 12.724376823409537, 13.659602554964229, 14.487238544832673, 14.44698206539443, 13.572030837411306, 12.642397828010042, 11.733912203523603, 10.815886299172018, 9.839999119075824, 8.877065448533076, 9.598445589296151, 10.626111269319871, 11.57692498166646, 12.369513983295908, 12.36945757029417, 13.336280951208877, 13.560935922341573, 12.56307056548368, 11.787487816893742, 12.74393571505533, 13.747978494897287, 14.708825032537707, 14.466635437407595, 13.513806490849527, 12.680521604237493, 11.704898382080723, 10.71235228786657, 9.793768051695352, 8.820768161828585, 7.826089823904866, 8.616500171686408, 9.655832998744856, 10.584881484199709, 11.431747432484219, 11.336463723671754, 12.374871876369731, 13.34100990311122, 13.525581189475966, 12.74043771295841, 13.76770714114127, 14.705415071484165, 14.445110440134135, 13.506337206895918, 12.560240139991935, 11.61375787469973, 10.692534677602282, 9.745447488213665, 8.764633890994855, 7.8764620003162, 6.811087005199406, 7.662833955420275, 8.600963577409825, 9.532933624974284, 10.444893360324379, 10.39144042340625, 11.423124622700247, 12.390967196754573, 13.430649897633877, 13.800070415572876, 14.733718344281428, 14.357191464001682, 13.414455550378861, 12.544448999786807, 11.526245801686692, 10.672530396498642, 9.762442923114488, 8.769474868736824, 7.8380255532363154, 6.806333125641856, 5.84950276969432, 6.682620534249288, 7.689885677508233, 8.512948666097675, 9.453539819378062, 9.560467709559147, 10.515673711055877, 11.50708072465913, 12.535005926157805, 13.563781137636315, 14.501388197351512, 13.481139416496198, 12.489206909593614, 11.534230330884698, 10.548578477264693, 9.613988488406898, 8.750096141855993, 7.768115234696385, 6.796704033982229, 5.853280612892187, 4.890881340857094, 5.726891997772951, 6.6418247430762625, 7.578389953573665, 8.629839598848228, 8.609973782213144, 9.585559278394934, 10.649123618291048, 11.712819826358505, 12.689092078212578, 13.493348006265956, 12.474792612681414, 11.543112962877304, 10.584956898502616, 9.671106321370022, 8.665321131185198, 7.699540127397668, 6.7690595889672025, 5.802961198667437, 4.795144418367786, 3.8987815313141287, 4.794057968255705, 5.707204879429701, 6.6726655138632935, 7.678019450257111, 7.839167704194695, 8.829835287093452, 9.777445985998586, 10.78912550312407, 11.809882543652048, 12.50788533042395, 11.52122527185667, 10.659823858281264, 9.643141008274352, 8.675938538731812, 7.722779370968855, 6.767100901721867, 5.836965253105217, 4.809169650223115, 3.82489457583098, 2.882801060534627, 3.8301256504332866, 4.761983330711811, 5.787238850720176, 6.778495162463624, 6.990264982653919, 7.900937129823705, 8.879722143920457, 9.895974714015846, 10.892592325533403, 11.540661801002763, 10.516591016661161, 9.59114362704068, 8.631982536302583, 7.7128764883824585, 6.7690740933246225, 5.815933412844965, 4.8943006141178245, 3.8369830972151577, 2.883374374225379, 1.945634968906595, 2.9502834939941165, 3.8937142341381605, 4.930683171510102, 5.990013915134211, 5.983772937943807, 6.926746889317694, 7.973398996676843, 8.954265335015785, 9.841922045931824, 10.657962504869698, 9.583377468742405, 8.64797126051556, 7.67816956860226, 6.742774056358326, 5.789456464090573, 4.8145174300889915, 3.8809643895881214, 2.9524372650843143, 1.9330029713026498, 0.9597035907222357, 2.0336758162554767, 3.0481979569986786, 4.003114874141801, 4.991034115897755, 5.01714151274737, 5.9673032621303745, 6.948276124193146, 7.95606257066519, 8.897961050438425, 9.876189266150087, 8.930544640386216, 7.881039932956644, 6.844120358122277, 5.867291934675636, 4.840150006125958, 3.7841557719937184, 2.8530077738874544, 1.90603838811207, 0.9808379447086053, 0.0, 1.0556543392114357, 1.9941368071942698, 2.9918039205685227, 3.992253306179424, 5.959027670822674, 6.936798648946868, 7.88618345581778, 8.845866229112934, 9.77913849006135, 10.766692393788553, 9.918641807186079, 8.861228915067796, 7.868990712931057, 6.795700376067462, 5.799406159743481, 4.809656355198382, 3.8074111319137818, 2.8877144455043147, 1.952001453885632, 0.9727738391991738, 1.9310723000737933, 2.915619712307608, 3.9392004837116197, 4.9247155177596795, 6.81417855569301, 7.827103990014749, 8.75671781273443, 9.777163543314881, 10.754857596125916, 11.749593590402137, 10.899141259590339, 9.857692976081287, 8.820539917828402, 7.849182023422335, 6.807459118744713, 5.835534240561971, 4.782339742582026, 3.886841045234192, 2.9401906170985823, 1.9162723791725635, 2.862385356184058, 3.832631939530813, 4.7976180061470375, 5.840006082898864, 7.739395083676958, 8.70062483323757, 9.696174756006048, 10.637914217445685, 11.627245693940585, 12.69165500930201, 11.721542086014058, 10.728559377644837, 9.658142433874858, 8.681013634292798, 7.697594265032662, 6.688037156262194, 5.740635731284833, 4.777810514337192, 3.7938168445150917, 2.853799168532423, 3.828524547691892, 4.821082052398684, 5.805318786600661, 6.7480123775305065, 8.68524435122423, 9.643277731764156, 10.623377689317154, 11.585169332089439, 12.564685717948525, 13.570611789254567, 12.695804366903658, 11.651449754955957, 10.579645599722207, 9.616116153914296, 8.636913498391229, 7.637638103798224, 6.699637406028171, 5.795651613593181, 4.745669232352105, 3.8343802694481046, 4.808210794773544, 5.750700210798715, 6.737047371669969, 7.786294529931688, 9.589640554972727, 10.601444717110226, 11.58350728774128, 12.510939311054287, 13.561916979209421, 14.460824274357275, 13.41225070407011, 12.429629334648418, 11.462206654249494, 10.517749900595033, 9.592399780361317, 8.663087607137818, 7.630328011275845, 6.790426979325123, 5.760715937373279, 4.77197568433714, 5.831567683545283, 6.8220954200792585, 7.689802685682627, 8.623942749928943, 10.520395362491609, 11.549897896933823, 12.588219832506311, 13.468872118453763, 13.825242338385772, 14.808278200714117, 14.371031635337898, 13.398940723351064, 12.44451952243479, 11.516775633248717, 10.530052019373079, 9.625770418703151, 8.668241591132823, 7.807418128934775, 6.7938662571717465, 5.763697561463765, 6.7685611667784, 7.840899119935329, 8.704112155857965, 9.555503979695727, 11.473456788164896, 12.420330073563031, 13.406361847564954, 13.555448459404582, 12.80146530074016, 13.756589342528905, 14.659958392192706, 14.368896307929893, 13.388330185645572, 12.470860016691521, 11.539701648889636, 10.624363737105751, 9.695794519643156, 8.755346162985964, 7.80783687970673, 6.812876081183568, 7.728753898087618, 8.693426535843605, 9.654229986786545, 10.519714370661484, 12.433795201417013, 13.414508192516724, 13.491826780706393, 12.554911600722942, 11.867529035688518, 12.813758909341484, 13.707415408273278, 14.662439139984391, 14.404040720774411, 13.44911510550959, 12.511783526803248, 11.560457604019705, 10.690627509852641, 9.81337018215873, 8.785928092333444, 7.748404944935457, 8.690995851674858, 9.67159936172821, 10.713689115402499, 11.469605833528293, 13.461548196091863, 13.567693337725618, 12.61441546037338, 11.622219888555744, 10.899937562286633, 11.744268738082374, 12.699788820271502, 13.73104524705144, 14.596256583368383, 14.495914178888402, 13.456366675680254, 12.523913227032516, 11.71903584912618, 10.796181374571152, 9.811159700521012, 8.777383737222543, 9.657640586632159, 10.660054194998805, 11.672545035655734, 12.492962581378084], [12.682224637651181, 11.76052435313739, 10.7671820175934, 9.80738986405183, 10.774575416059163, 11.753971812845862, 12.768253715767699, 13.70442644164837, 14.494089400840487, 15.4387336537793, 15.665821447587499, 14.64033506284753, 13.689171718838116, 12.699178820196014, 11.742579289341437, 10.874817773963636, 9.918397242711926, 10.817696114894991, 11.710752997425779, 12.499240171325443, 12.511135973736438, 12.736560237817546, 11.797988328602242, 10.747787943039773, 11.682941347765073, 12.660154560715876, 13.708146919845635, 14.643372651400327, 15.47100864126877, 15.502636404605866, 14.627685176622741, 13.698052167221476, 12.789566542735038, 11.854135333223335, 10.815613896528701, 9.80924401519119, 8.846283644045958, 9.873949324069677, 10.777956865903112, 11.570545867532559, 11.570489454530822, 12.53731283544553, 12.774547173050632, 11.776681816192738, 12.692045109053595, 13.648493007215182, 14.697706720733198, 15.692595128973805, 15.522289776619031, 14.569460830060963, 13.736175943448929, 12.760552721292157, 11.768006627078005, 10.849422390906788, 9.876422501040022, 8.881744163116302, 7.864338226436213, 8.903671053494662, 9.785913368436361, 10.63277931672087, 10.537495607908404, 11.575903760606382, 12.542041787347868, 12.739192440185025, 13.644995005118263, 14.672264433301123, 15.655143297320073, 15.500764779345571, 14.561991546107354, 13.615894479203371, 12.669412213911166, 11.748189016813717, 10.8011018274251, 9.820288230206291, 8.932116339527635, 7.866741344410841, 6.910672010170082, 7.848801632159632, 8.733965509210936, 9.64592524456103, 9.5924723076429, 10.624156506936895, 11.591999080991222, 12.631681781870526, 13.595888648333805, 14.529536577042357, 15.412845803213118, 14.470109889590297, 13.600103338998244, 12.581900140898128, 11.728184735710078, 10.818097262325923, 9.825129207948258, 8.893679892447752, 7.861987464853292, 6.9051571089057555, 5.930458588999095, 6.890917561744885, 7.713980550334326, 8.654571703614712, 8.761499593795799, 9.71670559529253, 10.708112608895782, 11.736037810394457, 12.764813021872968, 13.702420081588164, 14.536793755707633, 13.54486124880505, 12.589884670096135, 11.604232816476129, 10.669642827618334, 9.80575048106743, 8.82376957390782, 7.852358373193664, 6.908934952103622, 5.946535680068529, 4.974730052522757, 5.842856627312914, 6.779421837810316, 7.83087148308488, 7.8110056664497955, 8.786591162631584, 9.768173192145296, 10.812794806503973, 11.789067058358047, 12.761755802553312, 13.530446951892849, 12.59876730208874, 11.640611237714053, 10.726760660581458, 9.720975470396635, 8.755194466609105, 7.824713928178639, 6.8586155378788725, 5.850798757579222, 4.954435870525565, 4.041896023005512, 4.908236763666352, 5.873697398099945, 6.879051334493762, 6.863210699546641, 7.853878282445397, 8.777022191825969, 9.788701708951454, 10.80945874947943, 11.776293126711305, 12.576879611068104, 11.7154781974927, 10.698795347485788, 9.731592877943248, 8.778433710180291, 7.8227552409333025, 6.892619592316653, 5.8648239894345515, 4.880548915042415, 3.9384553997460623, 3.077963705183093, 3.963015214948462, 4.953307425226742, 5.931819217702451, 5.9346106434424835, 6.84528279061227, 7.824067804709022, 8.840320374804412, 9.836937986321967, 10.794250064011663, 11.572245355872596, 10.646797966252116, 9.687636875514018, 8.768530827593894, 7.824728432536058, 6.8715877520564, 5.949954953329261, 4.892637436426593, 3.9390287134368145, 3.0012893081180305, 2.0753476555877857, 2.9607911631531323, 3.911936261997643, 4.971267005621753, 4.928118598732372, 5.871092550106258, 6.917744657465407, 7.898610995804349, 8.786267706720388, 9.782453963665407, 10.63903180795384, 9.703625599726994, 8.733823907813695, 7.798428395569761, 6.845110803302008, 5.870171769300427, 4.936618728799557, 4.00809160429575, 2.9886573105140855, 2.0153579299336712, 1.0191449507071644, 2.009096921489892, 2.9640138386330146, 3.9482471823598075, 3.961487173535935, 4.911648922918939, 5.892621784981711, 6.9004082314537545, 7.842306711226989, 8.908534435350202, 9.854179061114072, 8.93669427216808, 7.899774697333712, 6.922946273887072, 5.895804345337393, 4.839810111205154, 3.9086621130988903, 2.9616927273235056, 2.0364922839200412, 1.0556543392114357, 0.0, 0.9384824679828341, 1.9361495813570868, 2.936598966967988, 4.903373331611237, 5.881144309735433, 6.830529116606344, 7.7902118899014985, 8.723484150849913, 9.711038054577116, 10.680448180484234, 9.916883254279233, 8.924645052142493, 7.851354715278898, 6.855060498954917, 5.865310694409819, 4.863065471125218, 3.94336878471575, 2.9357715503217303, 1.9565439356352718, 0.9982454747606524, 1.9392906646658885, 2.9611035051766863, 3.869061178548243, 5.829522142754927, 6.816965252419082, 7.746579075138761, 8.721509204103445, 9.69920325691448, 10.6939392511907, 11.667593104879714, 10.913347315292723, 9.876194257039838, 8.904836362633771, 7.86311345795615, 6.891188579773408, 5.837994081793462, 4.9175855764308345, 3.9239607135346803, 2.900042475608662, 2.0499662002872263, 2.9096150429571455, 3.87460110957337, 4.8553496699607805, 6.785327780100186, 7.7465575296608, 8.68603601841038, 9.627775479850017, 10.617106956344918, 11.65510189272991, 12.691148682260602, 11.712329474080933, 10.641912530310954, 9.664783730728894, 8.68136436146876, 7.671807252698291, 6.72440582772093, 5.761580610773289, 4.777586940951189, 3.837569264968521, 3.0161053917950604, 3.898065155825017, 4.882301890026993, 5.793945073953735, 7.731177047647457, 8.689210428187383, 9.613238951721486, 10.575030594493771, 11.554546980352857, 12.5604730516589, 13.613336655828563, 12.635219851392053, 11.563415696158303, 10.599886250350393, 9.620683594827327, 8.621408200234322, 7.683407502464268, 6.779421710029279, 5.729439328788203, 4.818150365884202, 3.9957916388767116, 4.8807155141326595, 5.85155750348258, 6.834612429346613, 8.704150686785338, 9.647377413533453, 10.629439984164508, 11.50080057345862, 12.551778241613754, 13.525883823144154, 14.396020800506209, 13.413399431084516, 12.445976750685592, 11.501519997031131, 10.576169876797415, 9.646857703573916, 8.614098107711943, 7.774197075761221, 6.744486033809377, 5.755745780773237, 5.019148527648451, 5.952110723413203, 6.804312817495238, 7.738452881741554, 9.63490549430422, 10.664408028746434, 11.672949969979179, 12.458733380858096, 13.45849179031954, 14.457448269820366, 15.354801731773996, 14.382710819787162, 13.428289618870888, 12.500545729684815, 11.513822115809177, 10.60954051513925, 9.65201168756892, 8.791188225370874, 7.7776363536078446, 6.747467657899862, 5.982172417487461, 6.9709144232692735, 7.818622287670576, 8.670014111508339, 10.587966919977507, 11.534840205375643, 12.520871979377565, 12.803286514154388, 13.733643867398275, 14.68876790918702, 15.635573169645582, 15.35266640436599, 14.37210028208167, 13.45463011312762, 12.523471745325734, 11.60813383354185, 10.679564616079254, 9.739116259422062, 8.791606976142829, 7.796646177619666, 6.942365148796679, 7.9070377865526655, 8.784307500406758, 9.634224502474096, 11.548305333229624, 12.529018324329336, 12.7396648354562, 11.802749655472748, 12.799707602346633, 13.789373686794361, 14.683030185726155, 15.638053917437269, 15.387810817210509, 14.432885201945687, 13.495553623239346, 12.544227700455803, 11.67439760628874, 10.797140278594828, 9.769698188769542, 8.732175041371555, 7.904607102383918, 8.885210612437271, 9.85119105785455, 10.584115965340905, 12.576058327904475, 12.76872522196227, 11.862253515123186, 10.87005794330555, 11.832116128944747, 12.719883515535251, 13.67540359772438, 14.706660024504316, 15.651910922579818, 15.479684275324502, 14.440136772116352, 13.507683323468614, 12.702805945562279, 11.779951471007248, 10.79492979695711, 9.761153833658641, 8.871251837341218, 9.873665445707864, 10.886156286364793, 11.607472713190695], [11.743742169668348, 10.928064323274027, 10.009459161252838, 10.696320687350116, 11.713057884041996, 12.692454280828695, 13.706736183750532, 14.642908909631203, 15.43257186882332, 16.37721612176213, 16.55801670382572, 15.531541113539571, 14.567598440899177, 13.577605542257075, 12.621006011402498, 11.753244496024697, 10.796823964772987, 9.882794797247865, 10.772270529442945, 11.56075770334261, 11.572653505753605, 11.904100207954183, 11.04026547226168, 11.63671876633806, 12.57187217106336, 13.549085384014163, 14.610111272662236, 15.545337004216927, 16.409491109251604, 16.4411188725887, 15.566167644605576, 14.636534635204312, 13.700961339947321, 12.732562055284395, 11.694040618589762, 10.687670737252251, 9.724710366107018, 8.939048006422551, 9.839474397920279, 10.632063399549725, 10.632006986547989, 11.598830367462696, 12.07509693495361, 12.665612639491025, 13.580975932351881, 14.537423830513468, 15.586637544031484, 16.594559481790405, 16.460772244601866, 15.507943298043797, 14.674658411431762, 13.699035189274992, 12.679401424290289, 11.73081742821758, 10.757817538350814, 9.763139200427094, 8.742764948497275, 7.968769735847536, 8.847430900453528, 9.694296848738036, 9.599013139925571, 10.637421292623548, 11.603559319365035, 12.553370483737108, 13.561867770564334, 14.595062434863149, 15.578681937972926, 16.439247247328407, 15.500474014090187, 14.554376947186205, 13.607894681893999, 12.686671484796552, 11.739584295407935, 10.73339972509791, 9.813511376838427, 8.748136381721634, 7.7890987322311425, 6.913900314512505, 7.795483041228103, 8.707442776578196, 8.653989839660067, 9.685674038954062, 10.653516613008389, 11.693199313887693, 12.657406180350971, 13.591054109059524, 14.580105754334545, 15.40859235757313, 14.538585806981077, 13.520382608880961, 12.666667203692912, 11.756579730308758, 10.763611675931093, 9.80679138733937, 8.743382502164085, 7.786552146216549, 6.8088853110601555, 5.952435093762052, 6.7754980823514925, 7.716089235631879, 7.823017125812965, 8.778223127309696, 9.769630140912948, 10.797555342411624, 11.826330553890134, 12.76393761360533, 13.75127574459927, 14.483343716787884, 13.528367138078968, 12.542715284458962, 11.608125295601168, 10.744232949050263, 9.762252041890655, 8.790840841176498, 7.847417420086456, 6.8279307173793224, 5.853156774583818, 4.9043741593300805, 5.840939369827483, 6.892389015102046, 6.872523198466962, 7.848108694648751, 8.829690724162463, 9.874312338521138, 10.85058459037521, 11.823273334570478, 12.744928940784487, 13.537249770071574, 12.579093705696886, 11.665243128564292, 10.659457938379468, 9.693676934591938, 8.763196396161472, 7.797098005861707, 6.789281225562056, 5.879768058432569, 4.920322745066572, 3.9697542956835186, 4.9352149301171115, 5.940568866510929, 5.924728231563806, 6.9153958144625625, 7.838539723843135, 8.850219240968618, 9.870976281496596, 10.837810658728472, 11.791361599959743, 12.653960665475534, 11.637277815468622, 10.670075345926081, 9.716916178163125, 8.761237708916136, 7.831102060299487, 6.803306457417385, 5.81903138302525, 4.876937867728897, 3.9563904272441524, 3.0245327469656282, 4.014824957243909, 4.993336749719616, 4.996128175459649, 5.906800322629436, 6.885585336726188, 7.901837906821577, 8.898455518339134, 9.85576759602883, 10.786727344764234, 11.58528043423495, 10.626119343496851, 9.707013295576727, 8.76321090051889, 7.810070220039234, 6.888437421312094, 5.8311199044094275, 4.877511181419649, 3.939771776100865, 2.9657394353143425, 2.0223086951702984, 2.973453794014809, 4.032784537638919, 3.989636130749537, 4.932610082123424, 5.979262189482573, 6.960128527821515, 7.847785238737553, 8.843971495682574, 9.853513796845478, 10.642108067709827, 9.672306375796529, 8.736910863552595, 7.7835932712848415, 6.80865423728326, 5.875101196782391, 4.946574072278584, 3.9271397784969198, 2.9538403979165055, 1.9576274186899985, 1.070614453507058, 2.0255313706501807, 3.0097647143769732, 3.0230047055531006, 3.9731664549361048, 4.9541393169988766, 5.96192576347092, 6.903824243244156, 7.970051967367368, 8.915696593131239, 9.875176740150915, 8.838257165316547, 7.861428741869905, 6.834286813320227, 5.778292579187988, 4.847144581081724, 3.90017519530634, 2.974974751902875, 1.9941368071942698, 0.9384824679828341, 0.0, 0.9976671133742527, 1.9981164989851539, 3.964890863628403, 4.9426618417525985, 5.89204664862351, 6.851729421918664, 7.785001682867079, 8.772555586594281, 9.741965712501397, 10.79937860461968, 9.863127520125326, 8.789837183261731, 7.793542966937751, 6.803793162392652, 5.801547939108052, 4.881851252698585, 3.8742540183045637, 2.8950264036181057, 1.9367279427434865, 1.0008081966830544, 2.0226210371938524, 2.930578710565409, 4.891039674772093, 5.8784827844362475, 6.808096607155926, 7.78302673612061, 8.760720788931646, 9.755456783207867, 10.72911063689688, 11.770558920405932, 10.814676725022672, 9.843318830616605, 8.801595925938983, 7.829671047756241, 6.776476549776296, 5.856068044413668, 4.862443181517514, 3.838524943591495, 2.941379158321066, 1.9711325749743114, 2.9361186415905363, 3.9168672019779462, 5.846845312117352, 6.8080750616779655, 7.747553550427545, 8.689293011867182, 9.678624488362082, 10.716619424747076, 11.752666214277768, 12.650811942063767, 11.580394998293787, 10.603266198711728, 9.619846829451593, 8.610289720681124, 7.662888295703763, 6.700063078756123, 5.716069408934023, 4.7760517329513545, 3.9075183498289, 2.9595826878421825, 3.94381942204416, 4.8554626059709, 6.792694579664623, 7.750727960204549, 8.674756483738651, 9.636548126510936, 10.616064512370022, 11.621990583676064, 12.674854187845728, 13.573702319374886, 12.501898164141137, 11.538368718333226, 10.559166062810158, 9.559890668217154, 8.621889970447102, 7.7179041780121125, 6.6679217967710365, 5.756632833867036, 4.884722462174996, 3.942233046149825, 4.913075035499746, 5.896129961363779, 7.765668218802504, 8.70889494555062, 9.690957516181674, 10.562318105475784, 11.613295773630918, 12.587401355161319, 13.635974925448483, 14.351881899067347, 13.384459218668423, 12.440002465013963, 11.514652344780247, 10.58534017155675, 9.552580575694776, 8.712679543744056, 7.68296850179221, 6.694228248756071, 5.9080793509467355, 5.013628255430369, 5.865830349512405, 6.799970413758721, 8.696423026321387, 9.725925560763601, 10.734467501996345, 11.52025091287526, 12.520009322336705, 13.518965801837531, 14.498660078560983, 15.321193287769994, 14.36677208685372, 13.439028197667646, 12.452304583792008, 11.548022983122083, 10.590494155551754, 9.729670693353707, 8.716118821590678, 7.685950125882695, 6.871103240785746, 6.032431955286439, 6.880139819687742, 7.731531643525505, 9.649484451994674, 10.59635773739281, 11.582389511394732, 12.452435011234277, 13.519169829449316, 14.47429387123806, 15.430595059107606, 16.29114887234882, 15.310582750064501, 14.39311258111045, 13.461954213308566, 12.546616301524683, 11.618047084062088, 10.677598727404895, 9.730089444125662, 8.735128645602499, 7.8312959720949635, 7.012448356710677, 7.845825032423924, 8.695742034491262, 10.609822865246791, 11.590535856346502, 11.979813359303437, 12.68117637753381, 13.678134324407694, 14.667800408855422, 15.561456907787216, 16.51648063949833, 16.32629328519334, 15.371367669928519, 14.434036091222177, 13.482710168438636, 12.612880074271573, 11.735622746577661, 10.708180656752376, 9.670657509354388, 8.793537925682203, 7.990621182595284, 8.912708589871716, 9.645633497358071, 11.637575859921641, 11.830242753979437, 10.947922256016238, 11.748484665366611, 12.710542851005808, 13.598310237596312, 14.55383031978544, 15.585086746565377, 16.543116973271857, 16.41816674330733, 15.378619240099184, 14.446165791451447, 13.641288413545112, 12.718433938990081, 11.733412264939943, 10.699636301641474, 9.760182660639504, 9.02389903742679, 9.981885404417172, 10.668990245207862], [10.891499634460887, 10.085636999859654, 10.96121196449465, 11.69398780072437, 12.710724997416248, 13.690121394202947, 14.704403297124784, 15.640576023005455, 16.430238982197572, 17.374883235136387, 17.472089104806052, 16.445613514519902, 15.481670841879508, 14.491677943237406, 13.535078412382829, 12.667316897005028, 11.710896365753317, 10.765056325241067, 9.854232164308394, 10.642719338208057, 10.654615140619054, 11.06167288453981, 11.992018275503492, 12.634385879712314, 13.569539284437614, 14.546752497388416, 15.60777838603649, 16.54300411759118, 17.407158222625856, 17.392218322109045, 16.507017194999822, 15.577384185598559, 14.615033740927652, 13.646634456264726, 12.608113019570093, 11.601743138232582, 10.63878276708735, 9.821309534415754, 8.921436032785728, 9.714025034415174, 9.71396862141344, 10.680792002328147, 11.716621285566621, 12.597842742594846, 13.596779301494452, 14.595248919518463, 15.618080149425253, 16.636120494137984, 17.411871694122212, 16.459042747564144, 15.61929314578963, 14.63988473966924, 13.59347382527062, 12.644889829197911, 11.671889939331145, 10.677211601407425, 9.656837349477605, 8.851031263840738, 7.929392535318977, 8.776258483603485, 8.680974774791022, 9.719382927488999, 10.685520954230485, 11.635332118602559, 12.643829405429784, 13.6770240697286, 14.660643572838376, 15.633758192756357, 16.451573463610533, 15.50547639670655, 14.558994131414345, 13.6275210351908, 12.680433845802183, 11.64747212607824, 10.727583777818758, 9.662208782701965, 8.703171133211473, 7.7961618425057075, 6.8774446760935515, 7.789404411443646, 7.735951474525517, 8.767635673819512, 9.73547824787384, 10.775160948753143, 11.739367815216422, 12.673015743924974, 13.662067389199995, 14.603103303001083, 15.489685256501422, 14.471482058401307, 13.617766653213257, 12.697429280703005, 11.704461226325341, 10.7208637883197, 9.657454903144416, 8.70062454719688, 7.722957712040486, 6.8346966217552545, 5.857459717216942, 6.798050870497328, 6.88380702400688, 7.83901302550361, 8.830420039106862, 9.858345240605537, 10.844860579296292, 11.782467639011488, 12.753608631225015, 13.677854662215836, 14.479466587599314, 13.493814733979308, 12.559224745121513, 11.695332398570608, 10.703101592284902, 9.731690391570746, 8.788266970480702, 7.742003118359653, 6.7672291755641485, 5.818446560310411, 4.922901004692933, 5.953178913295962, 5.8942674314876955, 6.869852927669484, 7.832023610788209, 8.876645225146886, 9.852917477000958, 10.825606221196225, 11.747261827410231, 12.731760715499526, 13.576760819071138, 12.616342578084637, 11.610557387899814, 10.644776384112284, 9.714295845681818, 8.737947556255953, 7.730130775956303, 6.7938404594129, 5.834395146046902, 4.883826696663849, 3.95878268898377, 4.964136625377587, 4.927061118189553, 5.9177287010883095, 6.840872610468882, 7.852552127594366, 8.873309168122343, 9.840143545354218, 10.793694486585487, 11.785251933059426, 12.634944928842874, 11.667742459300333, 10.706046106451073, 9.750367637204084, 8.782201509819831, 7.7441560078116325, 6.759880933419496, 5.817787418123143, 4.8704628282244835, 3.9386051479459594, 3.019063523937995, 3.9975753164137027, 3.998461062085396, 4.909133209255183, 5.887918223351935, 6.904170793447324, 7.90078840496488, 8.858100482654576, 9.789060231389978, 10.73442525822319, 11.623786456871104, 10.70468040895098, 9.760878013893143, 8.799200148327182, 7.839536870832438, 6.775808489690758, 5.8221997667009795, 4.884460361382195, 3.8798118362946736, 2.9363810961506296, 1.9776923607088952, 3.037023104333005, 2.9919690173752844, 3.934942968749171, 4.98159507610832, 5.962461414447262, 6.8501181253632994, 7.84630438230832, 8.855846683471222, 9.791252891698068, 10.669973489170781, 9.734577976926847, 8.781260384659094, 7.806321350657513, 6.872768310156644, 5.944241185652837, 4.924806891871173, 3.9515075112907585, 2.955294532064251, 1.9846868544873892, 1.0297699373442668, 2.0120976010027207, 2.025337592178848, 2.9754993415618523, 3.956472203624624, 4.964258650096667, 5.906157129869902, 6.972384853993114, 7.918029479756984, 8.967534187186557, 9.835924278690799, 8.859095855244158, 7.83195392669448, 6.775959692562241, 5.844811694455977, 4.897842308680593, 3.972641865277128, 2.9918039205685227, 1.9361495813570868, 0.9976671133742527, 0.0, 1.0004493856109011, 2.9672237502541505, 3.944994728378346, 4.894379535249258, 5.854062308544412, 6.787334569492827, 7.774888473220029, 8.744298599127145, 9.801711491245428, 10.860794633499578, 9.787504296635984, 8.791210080312004, 7.801460275766905, 6.799215052482305, 5.879518366072838, 4.871921131678817, 3.8926935169923587, 2.934395056117739, 1.9984753100573072, 1.0249539238195995, 1.9329115971911563, 3.8933725613978396, 4.880815671061995, 5.810429493781674, 6.785359622746358, 7.763053675557393, 8.757789669833613, 9.731443523522627, 10.772891807031678, 11.810044865284564, 10.840985943990857, 9.799263039313235, 8.827338161130495, 7.774143663150549, 6.853735157787921, 5.860110294891767, 4.836192056965748, 3.939046271695319, 2.968799688348564, 2.0936913181761634, 2.9192000886036937, 4.849178198743099, 5.8104079483037125, 6.749886437053293, 7.69162589849293, 8.68095737498783, 9.718952311372822, 10.754999100903515, 11.747981809272733, 12.57806211166804, 11.60093331208598, 10.617513942825845, 9.607956834055377, 8.660555409078016, 7.697730192130376, 6.713736522308276, 5.7737188463256075, 4.9051854632031535, 3.9572498012164354, 3.1013920986297867, 3.857795492596648, 5.79502746629037, 6.753060846830296, 7.677089370364398, 8.638881013136682, 9.61839739899577, 10.624323470301812, 11.677187074471476, 12.721541686419178, 13.499565277515389, 12.536035831707478, 11.556833176184412, 10.557557781591408, 9.619557083821356, 8.715571291386365, 7.6655889101452885, 6.7542999472412895, 5.882389575549249, 4.939900159524078, 4.070647712085373, 4.898462847989526, 6.8203759535481785, 7.711227832176366, 8.69329040280742, 9.56465099210153, 10.615628660256665, 11.589734241787065, 12.63830781207423, 13.620929181495923, 14.382126332042677, 13.437669578388217, 12.5123194581545, 11.583007284931004, 10.55024768906903, 9.710346657118308, 8.680635615166462, 7.6918953621303245, 6.9057464643209885, 6.011295368804622, 5.023403026098031, 5.947727878551261, 7.751130761067062, 8.77667870428002, 9.736800388622092, 10.522583799501007, 11.522342208962451, 12.521298688463277, 13.500992965186729, 14.483006912621645, 15.364439200227974, 14.4366953110419, 13.449971697166262, 12.545690096496337, 11.588161268926008, 10.72733780672796, 9.71378593496493, 8.683617239256948, 7.868770354159999, 6.9998177750827315, 6.037712496273369, 6.879289108318045, 8.729595030162711, 9.676468315560847, 10.66250008956277, 11.454767897860023, 12.521502716075062, 13.476626757863807, 14.432927945733352, 15.449403193138346, 16.308249863438757, 15.390779694484705, 14.45962132668282, 13.544283414898935, 12.61571419743634, 11.675265840779147, 10.727756557499914, 9.732795758976751, 8.828963085469217, 7.96420115995249, 7.00339770900955, 7.843499499283801, 9.75758033003933, 10.67064643451454, 11.63182246724382, 12.455304756541663, 13.455438981126704, 14.528212722160028, 15.38547092965278, 16.340494661363895, 17.323960398567596, 16.369034783302773, 15.431703204596431, 14.480377281812888, 13.610547187645825, 12.733289859951913, 11.705847770126628, 10.66832462272864, 9.791205039056457, 8.942373985837095, 8.070281266457343, 8.79339096215061, 10.78533332471418, 10.912204388844888, 11.83018378400944, 12.662557066346942, 13.624615251986139, 14.512382638576643, 15.467902720765771, 16.499159147545708, 17.457189374252188, 17.415833856681587, 16.37628635347344, 15.4438329048257, 14.638955526919364, 13.716101052364333, 12.731079378314195, 11.697303415015726, 10.757849774013758, 9.975651840668602, 9.139458081002799, 9.816747710000401], [9.891050248849986, 10.740577196215437, 11.659859563780456, 12.492546112249435, 13.54601281586341, 14.55071113095226, 15.564993033874098, 16.578696959726674, 17.368359918918795, 18.33750498313472, 18.44188662460956, 17.41541103432341, 16.451468361683016, 15.461475463040912, 14.504875932186335, 13.637114416808535, 12.680693885556824, 11.734853845044574, 10.805542268210564, 9.85451405192476, 9.829801084751265, 10.774885179104524, 11.753342385897707, 12.700836577477359, 13.63598998220266, 14.613203195153462, 15.674229083801535, 16.609454815356226, 17.546235031875884, 18.36201584191255, 17.476814714803332, 16.547181705402068, 15.584831260731159, 14.616431976068233, 13.5779105393736, 12.571540658036088, 11.608580286890856, 10.79110705421926, 9.872746136687898, 8.925819748131877, 8.81207982148857, 9.778903202403278, 10.808746078424353, 11.671942704324394, 12.670879263224, 13.66934888124801, 14.660674969723772, 15.6787153144365, 16.57081072171598, 17.42884026736765, 16.58909066559314, 15.609682259472748, 14.563271345074126, 13.614687349001418, 12.641687459134651, 11.647009121210932, 10.626634869281112, 9.820828783644245, 8.899190055122483, 7.988053197320188, 7.7790859748661525, 8.81749412756413, 9.759620915960033, 10.709432080332107, 11.717929367159332, 12.719618890027117, 13.703238393136894, 14.633308807145456, 15.589480998439024, 16.47527391651006, 15.528791651217851, 14.597318554994308, 13.650231365605691, 12.617269645881747, 11.697381297622265, 10.632006302505472, 9.67296865301498, 8.765959362309214, 7.847242195897058, 7.0011991251603485, 6.834062674600648, 7.841735635549061, 8.809578209603387, 9.849260910482691, 10.81346777694597, 11.715610564223491, 12.704662209498512, 13.602653917390182, 14.58508540328946, 15.441279578204814, 14.587564173016764, 13.667226800506514, 12.67425874612885, 11.690661308123207, 10.627252422947922, 9.670422067000386, 8.692755231843993, 7.804494141558761, 6.827257237020449, 6.009845584214031, 5.887020134000157, 6.842226135496888, 7.833633149100139, 8.861558350598814, 9.844411193685392, 10.782018253400588, 11.753159245614114, 12.677405276604935, 13.65031813704049, 14.463612253782815, 13.52902226492502, 12.665129918374115, 11.67289911208841, 10.701487911374254, 9.75806449028421, 8.71180063816316, 7.737026695367655, 6.788244080113919, 5.892698524496439, 5.035052184712814, 4.893818045876794, 5.869403542058583, 6.831574225177308, 7.876195839535985, 8.852468091390058, 9.825156835585323, 10.74681244179933, 11.731311329888625, 12.689467394263312, 13.586140097888144, 12.58035490770332, 11.61457390391579, 10.684093365485325, 9.707745076059462, 8.699928295759811, 7.763637979216408, 6.80419266585041, 5.853624216467357, 4.9285802087872765, 4.046009896794439, 3.9266117325786523, 4.917279315477408, 5.840423224857981, 6.852102741983465, 7.872859782511442, 8.839694159743317, 9.793245100974586, 10.784802547448525, 11.789391475389083, 12.629165192617887, 11.67584362625458, 10.72016515700759, 9.751999029623338, 8.71395352761514, 7.729678453223004, 6.787584937926651, 5.840260348027991, 4.908402667749467, 3.988861043741502, 3.0376645920625105, 2.998011676474495, 3.9086838236442816, 4.887468837741034, 5.903721407836423, 6.900339019353979, 7.857651097043674, 8.788610845779077, 9.733975872612287, 10.714418165700788, 11.666103142268533, 10.761327399504044, 9.76899766813069, 8.809334390635945, 7.7456060094942645, 6.791997286504486, 5.854257881185703, 4.849609356098181, 3.906178615954137, 2.9474898805124026, 2.0771123799818128, 1.9915196317643833, 2.93449358313827, 3.981145690497419, 4.9620120288363605, 5.849668739752398, 6.845854996697419, 7.855397297860321, 8.790803506087167, 9.760605198000466, 10.6960007102444, 9.781709770269995, 8.806770736268414, 7.873217695767544, 6.944690571263737, 5.925256277482073, 4.95195689690166, 3.9557439176751523, 2.954484374290897, 1.9995674571477742, 1.0116482153918196, 1.024888206567947, 1.9750499559509511, 2.956022818013723, 3.963809264485766, 4.905707744259001, 5.971935468382213, 6.917580094146083, 7.9670848015756555, 9.004004376410023, 9.85954524085506, 8.832403312305381, 7.776409078173141, 6.845261080066877, 5.898291694291493, 4.973091250888029, 3.992253306179424, 2.936598966967988, 1.9981164989851539, 1.0004493856109011, 0.0, 1.9667743646432494, 2.944545342767445, 3.893930149638357, 4.853612922933511, 5.7868851838819255, 6.774439087609128, 7.743849213516245, 8.801262105634528, 9.86526914403699, 10.787953682246883, 9.791659465922903, 8.801909661377804, 7.799664438093205, 6.879967751683738, 5.872370517289718, 4.89314290260326, 3.9348444417286403, 2.998924695668208, 1.9824410955886493, 0.9324622115802552, 2.8929231757869385, 3.8803662854510943, 4.809980108170773, 5.784910237135457, 6.762604289946492, 7.757340284222712, 8.730994137911726, 9.772442421420777, 10.809595479673662, 11.78095337407973, 10.799712424924135, 9.827787546741394, 8.77459304876145, 7.854184543398822, 6.860559680502668, 5.836641442576649, 4.896371429707599, 3.926124846360844, 2.961138779744619, 1.9187507029927926, 3.8487288131321975, 4.809958562692811, 5.749437051442392, 6.691176512882029, 7.680507989376929, 8.718502925761921, 9.754549715292613, 10.747532423661834, 11.76229494262143, 12.601382697696883, 11.617963328436748, 10.608406219666279, 9.661004794688917, 8.698179577741277, 7.714185907919177, 6.774168231936509, 5.862510621215433, 4.841033460314382, 3.8000396979155924, 2.8573461069857466, 4.794578080679469, 5.752611461219395, 6.676639984753497, 7.638431627525782, 8.617948013384868, 9.623874084690911, 10.676737688860575, 11.721092300808277, 12.695280546962637, 13.536485217318381, 12.557282561795313, 11.558007167202309, 10.620006469432257, 9.716020676997266, 8.66603829575619, 7.710853923685505, 6.698131888267604, 5.7556424722424335, 4.769295311371179, 3.8980134623786253, 5.819926567937277, 6.710778446565465, 7.69284101719652, 8.564201606490629, 9.615179274645763, 10.589284856176164, 11.637858426463328, 12.620479795885021, 13.587902476283945, 14.438118963999118, 13.512768843765402, 12.583456670541905, 11.550697074679931, 10.710796042729209, 9.681085000777363, 8.64844933857454, 7.721488777039344, 6.783401132050597, 5.7220506253838375, 4.9472784929403595, 6.7506813754561605, 7.776229318669119, 8.73635100301119, 9.522134413890106, 10.52189282335155, 11.520849302852376, 12.500543579575828, 13.482557527010744, 14.436978727927018, 15.437144696652801, 14.450421082777163, 13.546139482107238, 12.58861065453691, 11.710294703739603, 10.696742831976575, 9.640171215701164, 8.684512666878353, 7.698465374368538, 6.736360095559175, 5.878839722707144, 7.72914564455181, 8.676018929949946, 9.662050703951868, 10.454318512249122, 11.521053330464161, 12.476177372252906, 13.432478560122451, 14.448953807527445, 15.3807893911378, 16.36883220092095, 15.46007071229372, 14.482404351620154, 13.55383513415756, 12.613386777500367, 11.607013790333996, 10.612052991810833, 9.627521396994283, 8.662848759238296, 7.702045308295356, 6.8430501136729, 8.757130944428429, 9.670197048903638, 10.631373081632919, 11.454855370930762, 12.454989595515803, 13.527763336549127, 14.38502154404188, 15.340045275752994, 16.326189665728315, 17.30921678922104, 16.432152590207334, 15.418498218534108, 14.548668124367044, 13.647044239565345, 12.58510500296071, 11.547581855562722, 10.589763350581523, 9.641021585122902, 8.768928865743149, 7.792941576539709, 9.78488393910328, 10.689216039679142, 11.663264184920118, 12.38754708309796, 13.421128445215544, 14.44776456914278, 15.392648132043655, 16.375935348778025, 17.32167275893934, 18.37845560467992, 17.338908101471773, 16.38195384154692, 15.577076463640584, 14.595358285198415, 13.610336611148277, 12.549428601086587, 11.556408085538823, 10.674299439954408, 9.794398277358582, 8.8162983243895], [9.898689218262469, 10.74821616562792, 11.722482123740525, 12.555168672209504, 13.608635375823479, 14.613333690912329, 15.627615593834166, 16.641319519686743, 17.430982478878864, 18.314728627563742, 17.410755466878477, 16.384279876592327, 15.420337203951933, 14.43034430530983, 13.473744774455254, 12.502708947198592, 11.46420801278799, 10.897684733060272, 9.916481353587415, 8.975525780804945, 9.759485972534778, 10.704570066888037, 11.683027273681219, 12.630521465260871, 13.565674869986172, 14.542888082936974, 15.603913971585047, 16.53913970313974, 17.475919919659397, 18.352004878529012, 18.256195781619645, 17.32656277221838, 16.363558062144186, 15.382281585779435, 14.40071016726799, 13.499281982599191, 12.536321611453959, 11.835896802150181, 10.84927748511008, 9.904220084597828, 8.741764709272083, 9.70858809018679, 10.738430966207865, 11.601627592107906, 12.600564151007513, 13.599033769031523, 14.590359857507284, 15.608400202220013, 16.50049560949949, 17.41882930398411, 18.459574444759227, 17.565912913044958, 16.508476934816834, 15.559892938744126, 14.586893048877359, 13.53062106830464, 12.47273728323718, 11.63581086631653, 10.682457406319283, 9.679855779518507, 7.708770862649665, 8.747179015347642, 9.689305803743546, 10.63911696811562, 11.647614254942845, 12.64930377781063, 13.632923280920407, 14.56299369492897, 15.519165886222538, 16.46526295312652, 17.44563712836053, 16.564092919637556, 15.61214823953939, 14.567039670753877, 13.647151322494395, 12.581776327377602, 11.51907106697105, 10.5809414449815, 9.630509547093858, 8.693001707358667, 6.76374756238416, 7.771420523332574, 8.7392630973869, 9.778945798266204, 10.743152664729482, 11.645295452007003, 12.634347097282024, 13.532338805173696, 14.514770291072974, 15.488945077631906, 16.504409650159445, 15.634001165149762, 14.641033110772097, 13.640431332995337, 12.577022447820053, 11.620192091872516, 10.642525256716123, 9.619476224231047, 8.642239319692735, 7.701648166412348, 5.81670502178367, 6.7719110232804, 7.763318036883652, 8.791243238382327, 9.774096081468905, 10.7117031411841, 11.682844133397628, 12.607090164388449, 13.580003024824004, 14.511277753209907, 15.445867742067701, 14.631904283017365, 13.639673476731659, 12.668262276017503, 11.708757856982432, 10.66157066303529, 9.686796720239785, 8.660891700090312, 7.72492951771932, 6.744499553534715, 4.823502933660307, 5.7990884298420955, 6.761259112960821, 7.805880727319498, 8.78215297917357, 9.754841723368838, 10.676497329582844, 11.660996217672139, 12.619152282046826, 13.575497726248463, 14.54712927234657, 13.58134826855904, 12.650867730128574, 11.67451944070271, 10.66670266040306, 9.730412343859658, 8.77096703049366, 7.72627183644375, 6.760811202010157, 5.75545726561634, 3.8562966203621647, 4.846964203260921, 5.770108112641494, 6.781787629766979, 7.802544670294956, 8.769379047526831, 9.7229299887581, 10.714487435232039, 11.719076363172597, 12.5588500804014, 13.610561318002466, 12.68693952165084, 11.718773394266588, 10.680727892258387, 9.696452817866252, 8.754359302569899, 7.80703471267124, 6.875177032392716, 5.908225473836683, 4.916969162093235, 2.927696564258008, 3.838368711427795, 4.817153725524547, 5.833406295619937, 6.830023907137493, 7.787335984827188, 8.718295733562591, 9.663660760395803, 10.644103053484303, 11.595788030052047, 12.558620819529716, 11.735772032773939, 10.776108755279195, 9.712380374137515, 8.758771651147736, 7.821032245828952, 6.81638372074143, 5.872952980597386, 4.9142642451556515, 3.979468442791587, 1.9212045195478962, 2.864178470921783, 3.910830578280932, 4.891696916619874, 5.7793536275359125, 6.775539884480933, 7.7850821856438355, 8.720488393870681, 9.69029008578398, 10.625685598027914, 11.579003190295667, 10.773545100911665, 9.839992060410795, 8.911464935906988, 7.892030642125323, 6.918731261544909, 5.922518282318402, 4.921258738934146, 3.9663418217910236, 2.978422580035069, 0.9545730943514597, 1.904734843734464, 2.885707705797236, 3.8934941522692794, 4.835392632042515, 5.901620356165727, 6.847264981929597, 7.89676968935917, 8.933689264193537, 9.910517687640178, 10.79917767694863, 9.743183442816392, 8.812035444710128, 7.865066058934743, 6.939865615531279, 5.959027670822673, 4.903373331611237, 3.964890863628403, 2.9672237502541505, 1.9667743646432494, 0.0, 1.0695455718638514, 2.138227389317641, 3.0979101626127954, 4.03118242356121, 5.018736327288413, 5.9881464531955295, 7.045559345313813, 8.109566383716274, 9.182856720579869, 10.160421769970222, 9.170671965425123, 8.097171796899271, 7.05067309045671, 6.0299452962702915, 5.0507176815838335, 4.092419220709214, 3.1078718084754, 2.084291037071388, 1.0343121530629942, 1.0072007901587154, 2.0053665145475006, 2.9349803372671794, 3.9875649094222423, 4.9652589622332775, 5.959994956509497, 6.933648810198512, 7.9750970937075625, 9.012250151960448, 9.983608046366514, 11.007896739644705, 10.009605129491948, 8.956410631512004, 7.922650067501334, 6.92902520460518, 5.905106966679162, 4.958993989667667, 3.9887474063209125, 3.023761339704688, 1.9813732629528613, 2.0180219025039787, 2.9683895900415385, 3.8744372805387988, 4.816176741978436, 5.805508218473336, 6.8699175338347604, 7.905964323365453, 8.898947031734671, 9.964949614908214, 10.942078414490274, 11.686428852539258, 10.67687174376879, 9.72947031879143, 8.766645101843789, 7.782651432021689, 6.842633756039021, 5.925133181175502, 4.90365602027445, 3.862662257875661, 2.9199686669458154, 2.96387117005125, 3.9219045505911767, 4.801640213849904, 5.763431856622189, 6.742948242481275, 7.748874313787317, 8.80173791795698, 9.846092529904682, 10.89793521924942, 11.861464665057332, 12.625748085897825, 11.626472691304821, 10.688471993534769, 9.784486201099778, 8.734503819858702, 7.773476483645574, 6.760754448227673, 5.818265032202502, 4.831917871331248, 3.960636022338694, 3.9892196573090586, 4.880071535937247, 5.862134106568302, 6.689201835587036, 7.74017950374217, 8.71428508527257, 9.762858655559734, 10.745480024981427, 11.712902705380351, 12.657359459034812, 13.581234367867914, 12.651922194644417, 11.619162598782443, 10.779261566831721, 9.749550524879876, 8.711071898534609, 7.784111336999413, 6.846023692010665, 5.784673185343906, 4.954917462352842, 4.919974464827941, 5.945522408040901, 6.905644092382972, 7.647134642986512, 8.646893052447956, 9.645849531948782, 10.625543808672234, 11.60755775610715, 12.561978957023424, 13.599976607840258, 14.518886606879676, 13.61460500620975, 12.657076178639421, 11.772917263699672, 10.759365391936644, 9.702793775661233, 8.747135226838422, 7.761087934328606, 6.798982655519244, 5.886478692119627, 5.898438733923591, 6.845312019321726, 7.83134379332365, 8.579318741345528, 9.646053559560567, 10.601177601349312, 11.557478789218857, 12.573954036623851, 13.505789620234205, 14.493832430017353, 15.424990797819238, 14.545026911580223, 13.616457694117628, 12.676009337460435, 11.669636350294065, 10.674675551770902, 9.690143956954351, 8.725471319198364, 7.764667868255425, 6.850689083085383, 6.942041943129146, 7.839490138275419, 8.8006661710047, 9.579855600027168, 10.579989824612209, 11.652763565645532, 12.510021773138284, 13.465045504849398, 14.451189894824719, 15.434217018317446, 16.371548597023786, 15.481120778494176, 14.611290684327113, 13.709666799525413, 12.647727562920778, 11.61020441552279, 10.652385910541591, 9.70364414508297, 8.831551425703218, 7.800580545952192, 7.9697949378039965, 8.858509129050923, 9.832557274291899, 10.512547312194366, 11.54612867431195, 12.572764798239186, 13.51764836114006, 14.500935577874431, 15.446672988035745, 16.505681082012867, 17.316131745900794, 16.44457640150699, 15.639699023600652, 14.657980845158484, 13.672959171108346, 12.612051161046656, 11.619030645498892, 10.736921999914477, 9.802037246771064, 8.823937293801983], [10.74074108349679, 11.086115652396693, 12.07925097819447, 12.846101782534648, 13.82843584425416, 14.833134159343011, 15.712552753939732, 16.70825354875963, 17.51759970316971, 17.24518305569989, 16.341209895014625, 15.314734304728475, 14.35079163208808, 13.360798733445979, 12.404199202591402, 11.43316337533474, 10.394662440924138, 9.983732820747322, 9.07697027374956, 9.817577646039267, 10.724570014382815, 10.110079767716536, 11.048444667185628, 11.905703703546704, 12.840857108272004, 13.818070321222807, 14.772659549861796, 15.707885281416488, 16.540680462741427, 17.416765421611046, 17.186650209755793, 16.25701720035453, 15.294012490280334, 14.312736013915583, 13.331164595404138, 12.42973641073534, 11.466776039590107, 10.927479611572636, 10.009766405272225, 10.746271949832149, 9.70684875112012, 9.109423945927723, 10.013613204493698, 10.87680983039374, 11.875746389293345, 12.831773224763333, 13.749057878374046, 14.684704900570026, 15.565256152581522, 16.483589847066145, 17.52433498784126, 17.194516646283848, 16.27197943859085, 15.323395442518143, 14.350395552651376, 13.480712035363549, 12.44872145719985, 11.897757882147651, 11.001809902738977, 10.644939821366544, 8.673854904497702, 8.148014871088577, 8.964488042029378, 9.914299206401452, 10.922796493228677, 11.808001798677392, 12.791621301787169, 13.627754238011, 14.583926429304569, 15.530023496208551, 16.51039767144256, 17.476080415791, 16.577232281387428, 15.532123712601914, 14.612235364342432, 13.546860369225639, 12.484155108819088, 11.546025486829539, 10.595593588941895, 9.658085749206704, 7.728831604232198, 7.10983993882949, 8.014445335672733, 8.968322825569324, 9.932529692032602, 10.803993472873767, 11.793045118148788, 12.597099348255727, 13.579530834155005, 14.553705620713936, 15.569170193241476, 16.545988661303205, 15.618804088896294, 14.605515374843375, 13.54210648966809, 12.585276133720553, 11.60760929856416, 10.584560266079086, 9.607323361540773, 8.666732208260386, 6.781789063631708, 6.110330438777316, 6.967747006730358, 7.969309455225638, 8.948321380386353, 9.870401162050864, 10.747604676479659, 11.67185070747048, 12.644763567906034, 13.576038296291937, 14.510628285149732, 15.537074362971662, 14.617444454855855, 13.646033254141699, 12.673841898830469, 11.626654704883327, 10.651880762087822, 9.62597574193835, 8.690013559567358, 7.709583595382753, 5.788586975508345, 5.096589899905146, 5.93548441187827, 6.980106026236947, 7.9563782780910195, 8.819602266450865, 9.741257872664875, 10.72575676075417, 11.683912825128857, 12.640258269330493, 13.646043459515317, 14.559119246683235, 13.628638708252769, 12.652290418826906, 11.644473638527256, 10.708183321983853, 9.748738008617854, 8.691355878291787, 7.725895243858195, 6.720541307464378, 4.821380662210203, 4.085527979266829, 4.944333411558943, 5.956012928684427, 6.92617228358642, 7.834139590608859, 8.78769053184013, 9.77924797831407, 10.783836906254628, 11.623610623483431, 12.675321861084496, 13.579196274794024, 12.696544372390782, 11.658498870382584, 10.674223795990448, 9.732130280694095, 8.784805690795435, 7.852948010516911, 6.8733095156847215, 5.882053203941274, 3.892780606106046, 3.0125940103452438, 3.991379024441996, 4.92565746719663, 5.894784450219523, 6.852096527909217, 7.783056276644622, 8.728421303477834, 9.708863596566333, 10.660548573134077, 11.623381362611747, 12.628028785917122, 11.753879733403389, 10.69015135226171, 9.73654262927193, 8.798803223953147, 7.794154698865626, 6.850723958721582, 5.892035223279848, 4.944552484639625, 2.886288561395934, 2.0384037698392317, 3.0081512211282946, 3.9564574597019035, 4.844114170617942, 5.840300427562962, 6.849842728725866, 7.785248936952712, 8.75505062886601, 9.690446141109945, 10.643763733377698, 11.626612803161148, 10.81776303853499, 9.889235914031183, 8.869801620249518, 7.896502239669104, 6.900289260442597, 5.899029717058341, 4.944112799915219, 3.9561935581592644, 1.9196571361994978, 0.9694953868164937, 1.9504682488792655, 2.958254695351309, 3.900153175124544, 4.966380899247757, 5.912025525011627, 6.9562027555611134, 7.99312233039548, 8.969950753842122, 9.9970926823918, 10.720954420940586, 9.789806422834323, 8.842837037058938, 7.917636593655473, 6.936798648946868, 5.881144309735433, 4.9426618417525985, 3.944994728378346, 2.944545342767445, 1.0695455718638514, 0.0, 1.0686818174537898, 2.0283645907489443, 2.961636851697359, 3.9491907554245613, 4.9186008813316775, 5.976013773449961, 7.040020811852423, 8.113311148716017, 9.109605365039997, 10.099355169585095, 9.166717368763123, 8.120218662320562, 7.099490868134143, 6.120263253447685, 5.161964792573065, 4.177417380339251, 3.153836608935239, 2.1038577249268453, 1.9487463770053886, 0.9358209426836492, 1.865434765403328, 2.918019337558391, 3.8957133903694263, 4.890449384645646, 5.8641032383346605, 6.905551521843712, 7.942704580096597, 8.914062474502664, 9.973211363181255, 10.951150716338622, 9.897956218358678, 8.864195654348007, 7.870570791451853, 6.846652553525835, 5.9005395765143405, 4.930292993167586, 3.965306926551361, 2.9229188497995344, 2.860073767738301, 1.898844018177687, 2.804891708674947, 3.746631170114584, 4.735962646609485, 5.800371961970909, 6.8364187515016015, 7.829401459870821, 8.895404043044365, 9.872532842626425, 10.85595221188656, 11.618417330615465, 10.671015905638104, 9.708190688690463, 8.724197018868363, 7.784179342885694, 6.866678768022175, 5.835143827213387, 4.794150064814597, 3.8514564738847517, 3.805923035285572, 2.9355202341469138, 3.7320946419860523, 4.693886284758337, 5.673402670617424, 6.679328741923467, 7.73219234609313, 8.776546958040832, 9.828389647385572, 10.791919093193483, 11.827790980435251, 12.568018278151495, 11.630017580381443, 10.722199225219885, 9.67221684397881, 8.70496429058451, 7.692242255166609, 6.749752839141438, 5.763405678270184, 4.857565464084727, 4.83127152254338, 3.893687219492984, 4.796577383382383, 5.619656263723184, 6.670633931878318, 7.644739513408718, 8.693313083695882, 9.675934453117575, 10.6433571335165, 11.58781388717096, 12.513164007404676, 13.44937187754446, 12.560708185629117, 11.716974590951828, 10.685286407567244, 9.642559705473545, 8.715599143938348, 7.777511498949601, 6.716160992282842, 5.796969327587163, 5.762026330062263, 4.959138091596638, 5.840087369197053, 6.57758907112266, 7.577347480584104, 8.57630396008493, 9.555998236808382, 10.538012184243298, 11.492433385159572, 12.530431035976406, 13.450816246416437, 14.453158790446095, 13.598621765486095, 12.704405070638607, 11.69085319887558, 10.634281582600169, 9.678623033777358, 8.616121613143763, 7.6540163343344005, 6.728530557353948, 6.740490599157913, 6.005800939483869, 6.907401113834065, 7.509773169481676, 8.576507987696715, 9.53163202948546, 10.487933217355005, 11.50440846476, 12.436244048370353, 13.4242868581535, 14.355445225955386, 15.376209039136238, 14.471491372932785, 13.531043016275593, 12.524670029109222, 11.52970923058606, 10.545177635769509, 9.580504998013522, 8.619701547070582, 7.692740948319704, 7.784093808363468, 6.999979058437562, 7.88671425869175, 8.510310028163316, 9.510444252748357, 10.58321799378168, 11.440476201274432, 12.395499932985546, 13.381644322960867, 14.364671446453594, 15.302003025159935, 16.312302906050192, 15.46632436314227, 14.564700478340571, 13.502761241735936, 12.465238094337948, 11.507419589356749, 10.558677823898128, 9.677447075173676, 8.642632411186513, 8.811846803038318, 8.018998049213065, 8.91860536197895, 9.443001740330514, 10.476583102448098, 11.503219226375334, 12.448102789276208, 13.431390006010579, 14.377127416171893, 15.436135510149015, 16.246586174036942, 17.203540433961795, 16.49473270241581, 15.513014523973641, 14.527992849923503, 13.467084839861814, 12.47406432431405, 11.591955678729635, 10.644089112005386, 9.665989159036304], [11.670000773183208, 11.926136004766555, 11.11858149280448, 11.885432297144659, 12.867766358864172, 13.853506060439107, 14.69941107085019, 15.692701433086308, 16.476005490769378, 16.31521509994695, 15.411241939261688, 14.384766348975536, 13.420823676335141, 12.43083077769304, 11.474231246838462, 10.5031954195818, 9.464694485171199, 9.053764864994381, 9.939125017067688, 10.746837335725685, 11.673954821253728, 10.950100120086399, 10.087775181795639, 10.945034218156716, 11.880187622882016, 12.807550754008007, 13.759517866772253, 14.692333165743168, 15.499086250341092, 16.37517120921071, 16.256682254002854, 15.32704924460159, 14.364044534527395, 13.382768058162643, 12.401196639651198, 11.4997684549824, 10.536808083837167, 9.997511655819695, 10.871921148590355, 11.675531639518567, 10.656233557991033, 9.949444298297585, 9.052943719103709, 9.91614034500375, 10.915076903903357, 11.819212307508701, 12.735916195284503, 13.64311068816969, 14.523661940181187, 15.441995634665808, 16.482740775440924, 16.26454869053091, 15.342011482837911, 14.393427486765203, 13.420427596898437, 12.55074407961061, 11.518753501446911, 10.96778992639471, 11.863964646057106, 11.594324628237457, 9.623239711368615, 8.988035223458438, 8.00381855663939, 8.953629721011463, 9.962127007838689, 10.79544088142276, 11.778479618697627, 12.586160025610665, 13.542332216904233, 14.488429283808216, 15.468803459042231, 16.43448620339067, 16.308916282490816, 15.41284787938095, 14.364733758410823, 13.541911186642835, 12.472419717713041, 12.022659347729741, 11.544978395812809, 10.607470556077617, 8.678216411103111, 7.955586584636746, 7.053775850282743, 7.992561444207238, 8.956768310670517, 9.791432555619135, 10.768426945494642, 11.555505135855391, 12.53793662175467, 13.512111408313604, 14.527575980841144, 15.504394448902875, 16.46752710573853, 15.554900181714288, 14.491491296539003, 13.534660940591467, 12.556994105435074, 11.533945072949999, 10.556708168411687, 9.6161170151313, 7.73117387050262, 6.956077084584573, 6.007077521340367, 6.993548073863552, 7.961221097609979, 8.857840244796233, 9.706010464079323, 10.630256495070144, 11.603169355505699, 12.534444083891605, 13.4690340727494, 14.495480150571328, 15.46616747169809, 14.595418061012612, 13.623226705701382, 12.57603951175424, 11.601265568958736, 10.575360548809263, 9.639398366438272, 8.658968402253667, 6.737971782379257, 5.9423365457124016, 4.974814926488279, 6.004344644874862, 6.969277995314644, 7.807041349196233, 8.69966366026454, 9.684162548353834, 10.642318612728522, 11.598664056930161, 12.604449247114985, 13.569405010398082, 14.420856825860913, 13.60167522569782, 12.593858445398169, 11.657568128854766, 10.698122815488768, 9.6407406851627, 8.675280050729109, 7.669926114335291, 5.770765469081115, 4.931274625074085, 3.983663926168952, 4.980251547322342, 5.9136113663317875, 6.821578673354227, 7.746096319439796, 8.737653765913734, 9.742242693854296, 10.5820164110831, 11.633727648684165, 12.537602062393692, 13.488762489998926, 12.607883677253497, 11.623608602861362, 10.681515087565009, 9.734190497666349, 8.802332817387825, 7.822694322555633, 6.831438010812185, 4.842165412976958, 3.9619788172161554, 3.030709539052006, 3.913096549941998, 4.88222353296489, 5.839535610654585, 6.741462064244288, 7.686827091077499, 8.667269384166001, 9.618954360733746, 10.581787150211415, 11.58643457351679, 12.546097851011535, 11.639536159132623, 10.685927436142844, 9.74818803082406, 8.743539505736539, 7.800108765592494, 6.8414200301507595, 5.893937291510537, 3.8356733682668462, 2.9877885767101438, 1.9955903038736629, 2.9438965424472716, 3.83155325336331, 4.82773951030833, 5.808248516325532, 6.743654724552378, 7.713456416465678, 8.648851928709613, 9.602169520977366, 10.585018590760816, 11.59741190059394, 10.838620720902096, 9.819186427120432, 8.845887046540016, 7.84967406731351, 6.848414523929254, 5.8934976067861315, 4.905578365030177, 2.86904194307041, 1.9188801936874058, 0.9379073316246338, 1.9456937780966772, 2.8875922578699122, 3.952286851041521, 4.870431312611294, 5.887520938107324, 6.924440512941691, 7.901268936388331, 8.928410864938009, 9.984405099070248, 10.739191229705236, 9.792221843929852, 8.867021400526387, 7.886183455817781, 6.830529116606345, 5.892046648623511, 4.894379535249258, 3.893930149638357, 2.138227389317641, 1.0686818174537898, 0.0, 0.9596827732951544, 1.892955034243569, 2.8805089379707716, 3.849919063877888, 4.907331955996171, 5.971338994398633, 7.044629331262227, 8.040923547586207, 9.030673352131306, 10.104173520657158, 9.188900479774352, 8.168172685587933, 7.188945070901474, 6.230646610026855, 5.246099197793041, 4.222518426389029, 3.172539542380635, 2.878006066691806, 1.8650806323700664, 0.9354668096503876, 1.8909800874971006, 2.868674140308136, 3.8634101345843566, 4.83706398827337, 5.878512271782421, 6.915665330035306, 7.887023224441372, 8.946172113119964, 9.94446372327272, 10.827215908045096, 9.793455344034426, 8.79983048113827, 7.775912243212252, 6.829799266200758, 5.859552682854003, 4.894566616237778, 3.852178539485952, 3.7893334574247177, 2.8281037078641043, 1.8749237529220069, 2.8166632143616437, 3.803869823745193, 4.824572776123566, 5.860619565654258, 6.853602274023478, 7.868364792983074, 8.845493592565134, 9.828912961825269, 10.838470070595736, 11.60027559532452, 10.63745037837688, 9.65345670855478, 8.713439032572111, 7.795938457708592, 6.7644035168998045, 5.723409754501015, 4.780716163571169, 4.735182724971989, 3.797674977465044, 2.802126686233112, 3.7639183290053966, 4.741309847753132, 5.7472359190591735, 6.800099523228837, 7.844454135176538, 8.801350397324281, 9.764879843132192, 10.80075173037396, 11.788071018131767, 12.55927727006786, 11.651458914906303, 10.601476533665227, 9.634223980270928, 8.621501944853028, 7.679012528827856, 6.692665367956602, 5.786825153771144, 5.760531212229798, 4.755841962811114, 3.866609427629442, 4.689688307970243, 5.740665976125378, 6.714771557655777, 7.763345127942943, 8.745966497364636, 9.71338917776356, 10.65784593141802, 11.583196051651736, 12.51940392179152, 13.489967875315534, 12.646234280638247, 11.614546097253662, 10.571819395159963, 9.644858833624767, 8.70677118863602, 7.64542068196926, 6.726229017273581, 6.691286019748681, 5.821292834914768, 4.910119413444113, 5.64762111536972, 6.647379524831163, 7.64633600433199, 8.626030281055442, 9.608044228490359, 10.562465429406632, 11.600463080223467, 12.520848290663498, 13.523190834693155, 14.480719662263484, 13.633664760325026, 12.620112888561998, 11.563541272286587, 10.607882723463776, 9.545381302830181, 8.583276024020819, 7.657790247040365, 7.66975028884433, 6.867955682801999, 5.977433158081125, 6.5798052137287355, 7.646540031943775, 8.60166407373252, 9.557965261602066, 10.57444050900706, 11.506276092617414, 12.494318902400561, 13.425477270202446, 14.446241083383299, 15.374810300845894, 14.460302705962011, 13.45392971879564, 12.458968920272477, 11.474437325455927, 10.50976468769994, 9.548961236757, 8.622000638006122, 8.713353498049885, 7.862133801755692, 6.95674630293881, 7.580342072410376, 8.580476296995418, 9.653250038028741, 10.510508245521493, 11.465531977232606, 12.451676367207927, 13.434703490700654, 14.372035069406996, 15.382334950297253, 16.36964329105538, 15.49396016802699, 14.432020931422354, 13.394497784024367, 12.436679279043167, 11.487937513584546, 10.606706764860094, 9.571892100872931, 9.741106492724736, 8.881152792531195, 7.988637406226009, 8.513033784577575, 9.546615146695158, 10.573251270622395, 11.518134833523268, 12.50142205025764, 13.447159460418954, 14.506167554396075, 15.316618218284002, 16.273572478208855, 16.684533851174812, 15.692743723619651, 14.81254807632786, 13.814590839403035, 12.821570323855271, 12.104141616630528, 11.573348801691804, 10.595248848722722], [12.629683546478363, 12.885818778061708, 11.993430964816111, 11.03363881127454, 12.015972872994054, 12.923907679391709, 13.739728297555036, 14.733018659791153, 15.516322717474221, 15.418216555178997, 14.51424339449373, 13.487767804207579, 12.523825131567184, 11.533832232925082, 10.577232702070505, 9.606196874813843, 8.567695940403242, 9.579887899552084, 10.628435140163957, 11.648071610557725, 12.633637594548881, 11.909782893381552, 11.047457955090792, 10.093240732286597, 11.028394137011897, 11.877952372960609, 12.7998350934771, 13.732650392448013, 14.539403477045937, 15.415488435915556, 15.359683709234897, 14.430050699833632, 13.467045989759438, 12.485769513394686, 11.504198094883241, 10.602769910214443, 9.63980953906921, 10.523634690377397, 11.510254007417497, 12.457180395973518, 11.615916331286186, 10.909127071592739, 10.012626492398862, 9.064346859133632, 10.03975252830225, 10.889613926461303, 11.77623342198935, 12.683427914874535, 13.563979166886032, 14.482312861370653, 15.523058002145769, 15.367550145762952, 14.445012938069954, 13.496428941997246, 12.52342905213048, 11.653745534842653, 10.621754956678954, 11.493912960952413, 12.457927835668848, 12.55400740153261, 10.582922484663769, 9.94771799675359, 8.963501329934543, 8.101836235141345, 9.086802632237582, 9.865842500375361, 10.818796845402474, 11.62647725231551, 12.582649443609078, 13.528746510513061, 14.509120685747074, 15.474803430095513, 15.41191773772286, 14.515849334612993, 13.467735213642866, 12.644912641874878, 11.575421172945084, 12.513550794934634, 12.504661169107962, 11.56715332937277, 9.637899184398265, 8.915269357931901, 8.013458623577897, 7.062963063159839, 8.027169929623117, 8.861834174571737, 9.808744172199487, 10.595822362560236, 11.578253848459514, 12.552428635018448, 13.567893207545987, 14.544711675607719, 15.507844332443373, 15.442457672371532, 14.537864088317209, 13.606496877379964, 12.555634594116071, 12.493627846245152, 11.51639094170684, 10.575799788426453, 8.690856643797774, 7.915759857879728, 6.966760294635522, 6.063949692816153, 7.03162271656258, 7.928241863748834, 8.746327690784168, 9.67057372177499, 10.643486582210544, 11.574761310596449, 12.509351299454243, 13.535797377276172, 14.506484698402934, 15.47789589911709, 14.582909478996536, 13.535722285049394, 12.560948342253889, 11.535043322104416, 10.599081139733425, 9.61865117554882, 7.697654555674411, 6.9020193190075565, 5.934497699783434, 5.074746263827462, 6.0396796142672455, 6.877442968148834, 7.739980886969384, 8.724479775058679, 9.682635839433367, 10.638981283635005, 11.644766473819828, 12.609722237102925, 13.461174052565756, 14.50701171864767, 13.553541218693322, 12.61725090214992, 11.657805588783921, 10.600423458457854, 9.634962824024262, 8.629608887630445, 6.730448242376269, 5.89095739836924, 4.943346699464107, 4.050653166274943, 4.984012985284389, 5.891980292306829, 6.786413546144641, 7.777970992618579, 8.782559920559141, 9.622333637787943, 10.674044875389008, 11.577919289098535, 12.52907971670377, 13.522979187437098, 12.583291376156515, 11.641197860860162, 10.693873270961502, 9.762015590682978, 8.782377095850789, 7.79112078410734, 5.801848186272112, 4.9216615905113095, 3.9903923123471605, 2.983498168894599, 3.9526251519174913, 4.909937229607187, 5.7817792909491335, 6.7271443177823445, 7.707586610870846, 8.659271587438589, 9.622104376916258, 10.626751800221633, 11.586415077716378, 12.52888099459981, 11.645610209437997, 10.707870804119214, 9.703222279031692, 8.759791538887647, 7.801102803445913, 6.853620064805691, 4.795356141562, 3.947471350005298, 2.955273077168817, 2.0142981613998727, 2.901954872315911, 3.898141129260931, 4.8485657430303775, 5.783971951257223, 6.753773643170523, 7.689169155414457, 8.64248674768221, 9.62533581746566, 10.637729127298783, 11.571281972068345, 10.778869200415587, 9.80556981983517, 8.809356840608665, 7.808097297224407, 6.853180380081285, 5.86526113832533, 3.828724716365564, 2.87856296698256, 1.897590104919788, 1.0160953970492783, 1.9579938768225134, 2.9926040777463667, 3.910748539316139, 4.92783816481217, 5.9647577396465365, 6.941586163093177, 7.968728091642856, 9.024722325775095, 9.955870323881358, 10.751904617225007, 9.826704173821541, 8.845866229112936, 7.790211889901499, 6.851729421918665, 5.854062308544412, 4.853612922933511, 3.097910162612796, 2.0283645907489443, 0.9596827732951544, 0.0, 0.9332722609484145, 1.920826164675617, 2.8902362905827337, 3.947649182701017, 5.011656221103479, 6.084946557967074, 7.081240774291055, 8.070990578836152, 9.144490747362005, 10.148583253069505, 9.127855458883086, 8.148627844196628, 7.19032938332201, 6.205781971088196, 5.182201199684184, 4.13222231567579, 3.83768883998696, 2.824763405665221, 1.895149582945542, 0.9312973142019461, 1.9089913670129814, 2.9037273612892016, 3.8773812149782154, 4.918829498487266, 5.955982556740151, 6.927340451146217, 7.986489339824808, 8.984780949977566, 10.03797544795751, 10.75313811732958, 9.759513254433426, 8.735595016507407, 7.789482039495912, 6.8192354561491575, 5.854249389532932, 4.811861312781106, 4.749016230719873, 3.7877864811592588, 2.8346065262171614, 1.9042206974207292, 2.8441870504500386, 3.864890002828411, 4.900936792359103, 5.893919500728323, 6.908682019687919, 7.885810819269979, 8.869230188530114, 9.878787297300583, 10.826188722277944, 11.597133151672034, 10.613139481849934, 9.673121805867266, 8.755621231003746, 7.724086290194959, 6.68309252779617, 5.740398936866324, 5.694865498267144, 4.757357750760198, 3.7618094595282665, 2.8669197842374423, 3.781627074457978, 4.78755314576402, 5.840416749933683, 6.884771361881385, 7.841667624029125, 8.805197069837035, 9.841068957078805, 10.828388244836614, 11.784078728069312, 12.611141688201458, 11.561159306960382, 10.593906753566083, 9.581184718148183, 8.638695302123011, 7.652348141251757, 6.746507927066299, 6.7202139855249525, 5.715524736106268, 4.783700609594649, 3.792689763202289, 4.822073120557621, 5.796178702088021, 6.844752272375185, 7.827373641796878, 8.794796322195802, 9.739253075850263, 10.664603196083979, 11.600811066223763, 12.633570662085736, 13.605917053933402, 12.574228870548817, 11.531502168455118, 10.604541606919922, 9.666453961931175, 8.605103455264416, 7.685911790568736, 7.650968793043836, 6.772731435705426, 5.734409500132936, 4.750622570601766, 5.750380980063209, 6.745720236676669, 7.725414513400121, 8.707428460835038, 9.661849661751312, 10.699847312568146, 11.60225543509574, 12.604597979125398, 13.562126806695726, 14.593347533620182, 13.579795661857153, 12.523224045581742, 11.567565496758931, 10.505064076125336, 9.542958797315974, 8.61747302033552, 8.629433062139485, 7.688928834280801, 6.702897060278877, 5.682806668960781, 6.74954148717582, 7.704665528964565, 8.66096671683411, 9.677384045413866, 10.605660324962093, 11.59370313474524, 12.524861502547125, 13.545625315727978, 14.474194533190573, 15.414642889847766, 14.413612492090795, 13.418651693567632, 12.434120098751082, 11.469447460995095, 10.508644010052155, 9.581683411301277, 9.654845147495712, 8.581434740355153, 7.620258707625871, 6.683343527642421, 7.683477752227462, 8.756251493260786, 9.61350970075354, 10.568533432464653, 11.554677822439974, 12.5377049459327, 13.475036524639043, 14.481719182641932, 15.469027523400058, 15.7483177478138, 14.908181303468028, 13.927284690743624, 12.936421572942454, 12.447620286879701, 11.56638953815525, 10.531574874168086, 10.646395252006077, 9.600453731130656, 8.608230811627253, 7.6160352398096185, 8.649616601927201, 9.676252725854438, 10.621136288755315, 11.604423505489686, 12.550160915651, 13.609169009628122, 14.41961967351605, 15.376573933440902, 15.72485107787966, 14.733060950324498, 13.88294969528046, 12.962797353532917, 11.969776837985153, 12.9721904463518, 12.533031574986959, 11.554931622017877], [13.562955807426777, 13.819091039010122, 12.926703225764525, 11.966911072222954, 11.196237189535054, 12.00815517262752, 12.806456036606622, 13.79974639884274, 14.583050456525807, 14.55847605585714, 13.760778846892503, 12.734303256606351, 11.770360583965957, 10.780367685323855, 9.853944583147221, 8.88290875589056, 9.50096820135166, 10.513160160500501, 11.561707401112374, 12.581343871506142, 13.566909855497295, 12.843055154329965, 11.980730216039207, 11.026512993235011, 10.208658453552898, 10.96219986619642, 11.866562832528686, 12.7993781314996, 13.606131216097523, 14.482216174967142, 14.60621916163367, 13.676586152232405, 12.71358144215821, 11.732304965793459, 10.780909975959958, 9.948482514663006, 10.573081800017627, 11.456906951325815, 12.443526268365915, 13.390452656921935, 12.5491885922346, 11.842399332541152, 10.945898753347278, 9.997619120082046, 9.199554692264376, 9.973861419697114, 10.842961161040936, 11.750155653926122, 12.630706905937618, 13.54904060042224, 14.589785741197355, 14.614085598161724, 13.703007209342834, 12.754423213270126, 11.800140933207196, 10.999458139291216, 11.555027217627371, 12.42718522190083, 13.391200096617265, 13.487279662481026, 11.516194745612184, 10.880990257702006, 9.896773590882958, 9.035108496089759, 8.246604796199708, 8.950089993611172, 9.88552458445406, 10.693204991367097, 11.649377182660665, 12.595474249564647, 13.57584842479866, 14.541531169147099, 14.66991200899574, 13.792561215689709, 12.744447094719582, 12.014460957996675, 12.508693433893502, 13.446823055883051, 13.437933430056377, 12.500425590321186, 10.57117144534668, 9.848541618880315, 8.946730884526312, 7.9962353241082536, 7.186972093585244, 7.946081667807546, 8.875471911251074, 9.662550101611822, 10.6449815875111, 11.619156374070034, 12.634620946597574, 13.611439414659305, 14.574572071494963, 14.719169553448248, 13.814575969393925, 12.976045193501761, 13.488906855064489, 13.426900107193568, 12.449663202655255, 11.509072049374868, 9.62412890474619, 8.849032118828141, 7.900032555583937, 6.9972219537645675, 6.11587020979839, 7.012489356984643, 7.813055429835755, 8.737301460826576, 9.71021432126213, 10.641489049648035, 11.57607903850583, 12.602525116327758, 13.573212437454524, 14.54462363816868, 14.844033846181802, 13.934666622338987, 13.494220603202306, 12.468315583052833, 11.53235340068184, 10.551923436497235, 8.630926816622827, 7.835291579955971, 6.867769960731849, 6.008018524775877, 5.1239271075030555, 5.961690461384644, 6.806708626020971, 7.7912075141102655, 8.749363578484953, 9.705709022686591, 10.711494212871415, 11.676449976154515, 12.527901791617346, 13.57373945769926, 14.486813479641736, 13.550523163098333, 12.591077849732335, 11.533695719406271, 10.568235084972677, 9.56288114857886, 7.663720503324685, 6.824229659317655, 5.876618960412522, 4.983925427223357, 4.068260478520199, 4.976227785542639, 5.853141285196227, 6.844698731670165, 7.849287659610726, 8.689061376839529, 9.740772614440596, 10.644647028150123, 11.59580745575536, 12.589706926488686, 13.516563637104928, 12.574470121808575, 11.627145531909916, 10.695287851631392, 9.715649356799204, 8.724393045055756, 6.7351204472205275, 5.854933851459725, 4.923664573295575, 3.9167704298430137, 3.0368726451533012, 3.9941847228429967, 4.848507030000719, 5.793872056833931, 6.774314349922433, 7.725999326490176, 8.688832115967847, 9.693479539273222, 10.653142816767966, 11.595608733651398, 12.549217456641177, 11.641143065067627, 10.636494539980106, 9.693063799836063, 8.734375064394328, 7.786892325754106, 5.728628402510416, 4.880743610953713, 3.888545338117232, 2.9475704223482873, 1.9862023655517211, 2.9823886224967415, 3.9152934820819634, 4.85069969030881, 5.820501382222109, 6.755896894466043, 7.709214486733797, 8.692063556517247, 9.704456866350371, 10.638009711119933, 11.712141461364002, 10.738842080783586, 9.742629101557078, 8.741369558172822, 7.7864526410297, 6.798533399273746, 4.761996977313979, 3.811835227930975, 2.830862365868203, 1.9493676579976928, 1.0422413700583235, 2.059331816797952, 2.9774762783677247, 3.994565903863755, 5.031485478698122, 6.008313902144763, 7.035455830694441, 8.091450064826681, 9.022598062932945, 9.969567448708329, 10.759976434769957, 9.779138490061351, 8.723484150849915, 7.7850016828670805, 6.7873345694928275, 5.786885183881926, 4.03118242356121, 2.961636851697359, 1.892955034243569, 0.9332722609484145, 0.0, 0.9875539037272026, 1.9569640296343191, 3.0143769217526026, 4.078383960155064, 5.151674297018658, 6.147968513342639, 7.137718317887738, 8.211218486413589, 9.25771719285615, 10.061127719831502, 9.081900105145044, 8.123601644270424, 7.13905423203661, 6.1154734606325984, 5.0654945766242045, 4.7709611009353745, 3.7580356666136354, 2.8284218438939566, 1.8645695751503606, 1.0273440118694315, 2.022080006145652, 2.9653203190049546, 4.006768602514006, 5.043921660766891, 6.015279555172957, 7.074428443851548, 8.072720054004305, 9.12591455198425, 10.15967511599492, 10.692785515381841, 9.668867277455822, 8.722754300444327, 7.752507717097572, 6.787521650481347, 5.745133573729521, 5.682288491668287, 4.721058742107673, 3.767878787165576, 2.8374929583691437, 1.9625396953064884, 2.983242647684862, 4.014893955780336, 5.007876664149555, 5.996621123714658, 6.973749923296719, 7.957169292556855, 8.966726401327323, 9.914127826304684, 10.876953043252325, 11.54641174279835, 10.606394066815682, 9.688893491952161, 8.657358551143375, 7.616364788744584, 6.6736711978147385, 6.628137759215559, 5.690630011708612, 4.695081720476681, 3.800192045185857, 2.8999797193144277, 3.9059057906204697, 4.958769394790133, 6.003124006737835, 6.929606728055865, 7.893136173863776, 8.929008061105547, 9.916327348863353, 10.872017832096052, 11.890963222958062, 12.494431567908796, 11.527179014514497, 10.514456979096597, 9.571967563071425, 8.58562040220017, 7.679780188014713, 7.653486246473367, 6.648796997054682, 5.716972870543064, 4.725962024150704, 3.940425765414071, 4.914531346944471, 5.963104917231636, 6.945726286653328, 7.913148967052252, 8.857605720706713, 9.78295584094043, 10.719163711080213, 11.751923306942187, 12.762464799394948, 13.50750113149723, 12.464774429403532, 11.537813867868335, 10.599726222879589, 9.53837571621283, 8.61918405151715, 8.58424105399225, 7.70600369665384, 6.667681761081351, 5.68389483155018, 5.000305624810309, 5.864072881533119, 6.843767158256571, 7.825781105691488, 8.78020230660776, 9.818199957424596, 10.720608079952191, 11.722950623981848, 12.680479451552177, 13.713697674850714, 14.513067922805567, 13.456496306530155, 12.500837757707345, 11.43833633707375, 10.476231058264387, 9.550745281283934, 9.562705323087899, 8.622201095229215, 7.636169321227292, 6.616078929909196, 6.024082662455921, 6.915761739718331, 7.834548256189599, 8.795736690270315, 9.724012969818542, 10.71205577960169, 11.643214147403574, 12.663977960584425, 13.59254717804702, 14.532995534704213, 14.985168834756227, 14.174166427974551, 13.367392359699496, 12.402719721943509, 11.441916271000569, 10.514955672249691, 10.588117408444125, 9.514707001303567, 8.553530968574286, 7.6166157885908365, 6.958018927507563, 7.973029385093487, 8.787091240109028, 9.742114971820142, 10.728259361795462, 11.71128648528819, 12.615296025317186, 13.600071827498379, 14.587380168256505, 14.815045486865387, 13.99242879670384, 13.238637564222662, 13.869693833890867, 13.380892547828115, 12.499661799103663, 11.4648471351165, 11.57966751295449, 10.53372599207907, 9.54150307257567, 8.549307500758035, 7.925610400909449, 8.952246524836685, 9.794717828110803, 10.778005044845175, 11.723742455006489, 12.78275054898361, 13.559879174194192, 14.516833434119043, 14.791578816931246, 13.799788689376085, 12.967197188516272, 12.209658771935576, 12.903049098933566, 13.905462707300213, 13.466303835935372, 12.48820388296629], [14.55050971115398, 14.775429848201313, 13.782087512657323, 12.822295359115753, 11.934322611384665, 11.053483091546275, 11.818902132879419, 12.81219249511554, 13.595496552798608, 13.692008672912946, 12.933960942678267, 11.907485352392115, 10.94354267975172, 9.953549781109619, 9.193005878332176, 9.870462659617761, 10.48852210507886, 11.5007140642277, 12.549261304839574, 13.568897775233342, 14.554463759224499, 13.82423028169872, 12.923344997421749, 11.88189728012781, 10.94674387540251, 10.007527785115174, 10.879008928801483, 11.8118242277724, 12.618577312370324, 13.494662271239942, 13.779401257419433, 12.849768248018169, 11.886763537943974, 10.905487061579223, 10.119971271144912, 10.936036418390207, 11.560635703744829, 12.444460855053014, 13.431080172093115, 14.378006560649135, 13.536742495961803, 12.823574459909906, 11.88851353472982, 10.890648177871926, 9.937640114113988, 9.019189338615869, 9.855407257313733, 10.762601750198922, 11.643153002210418, 12.56148669669504, 13.602231837470155, 13.787267693947488, 12.876189305128596, 11.927605309055888, 11.13920222839215, 11.987012043018417, 12.542581121354573, 13.41473912562803, 14.378754000344465, 14.474833566208227, 12.503748649339386, 11.86216538507076, 10.877948718251712, 9.928137553879639, 8.98469021804932, 7.995417912529928, 8.897970680726857, 9.705651087639897, 10.661823278933465, 11.607920345837448, 12.58829452107146, 13.553977265419896, 13.843094104781501, 12.974465518023532, 12.083508389904537, 13.002014861723877, 13.496247337620705, 14.434376959610255, 14.425487333783579, 13.487979494048387, 11.558725349073882, 10.836095522607518, 9.928947082777437, 8.889264381898133, 7.9250575154348555, 6.991409586726302, 7.887918007523872, 8.674996197884623, 9.6574276837839, 10.631602470342832, 11.647067042870372, 12.623885510932102, 13.58701816776776, 13.901073855782071, 13.15363726457888, 13.963599097228963, 14.476460758791692, 14.41445401092077, 13.437217106382457, 12.49662595310207, 10.611682808473391, 9.836586022555345, 8.887586459311139, 7.98477585749177, 6.995424335618596, 6.0578172759034, 6.825501526108553, 7.749747557099375, 8.722660417534929, 9.653935145920833, 10.588525134778628, 11.614971212600558, 12.58565853372732, 13.557069734441477, 14.183095141366756, 14.922220526066189, 14.481774506929506, 13.455869486780033, 12.519907304409042, 11.539477340224437, 9.618480720350028, 8.822845483683174, 7.855323864459051, 6.995572428503079, 6.023008212953508, 5.0070183803034, 5.819154722293769, 6.803653610383064, 7.761809674757752, 8.71815511895939, 9.723940309144213, 10.688896072427312, 11.540347887890142, 12.586185553972056, 13.547515298000368, 14.452549520640291, 13.578631753459538, 12.521249623133471, 11.555788988699879, 10.550435052306062, 8.651274407051886, 7.811783563044857, 6.864172864139724, 5.97147933095056, 4.989294993188367, 4.021555704461394, 4.865587381469025, 5.857144827942963, 6.861733755883524, 7.701507473112327, 8.753218710713394, 9.65709312442292, 10.608253552028156, 11.602153022761483, 12.57726545546356, 13.43656904986079, 12.61469943563712, 11.682841755358595, 10.703203260526406, 9.711946948782957, 7.72267435094773, 6.8424877551869265, 5.911218477022778, 4.904324333570216, 4.024426548880504, 3.0395126417617524, 3.860953126273517, 4.806318153106728, 5.78676044619523, 6.7384454227629735, 7.701278212240644, 8.705925635546018, 9.665588913040763, 10.608054829924194, 11.561663552913974, 12.499402958232757, 11.62404844370731, 10.680617703563264, 9.72192896812153, 8.77444622948131, 6.716182306237618, 5.868297514680915, 4.876099241844434, 3.93512432607549, 2.973756269278924, 2.027716541415497, 2.9277395783547613, 3.8631457865816072, 4.832947478494907, 5.768342990738841, 6.721660583006594, 7.704509652790044, 8.716902962623168, 9.65045580739273, 10.725200597775968, 11.726395984510786, 10.730183005284278, 9.728923461900024, 8.774006544756901, 7.786087303000947, 5.7495508810411815, 4.799389131658177, 3.8184162695954056, 2.9369215617248954, 2.0297952737855263, 1.0717779130707497, 1.9899223746405224, 3.0070120001365526, 4.0439315749709195, 5.02075999841756, 6.0479019269672385, 7.1038961610994775, 8.035044159205741, 8.982013544981125, 9.90721398838459, 10.766692393788551, 9.711038054577115, 8.772555586594281, 7.774888473220029, 6.774439087609128, 5.018736327288413, 3.9491907554245613, 2.8805089379707716, 1.920826164675617, 0.9875539037272026, 0.0, 0.9694101259071166, 2.0268230180254, 3.090830056427862, 4.164120393291457, 5.1604146096154375, 6.150164414160536, 7.223664582686388, 8.270163289128948, 9.290891083315367, 10.069454008872247, 9.111155547997628, 8.126608135763814, 7.103027364359801, 6.053048480351407, 5.758515004662578, 4.745589570340838, 3.815975747621159, 2.852123478877563, 2.014897915596634, 1.060792391520439, 1.977766415277752, 3.0192146987868034, 4.056367757039688, 5.027725651445754, 6.086874540124344, 7.085166150277101, 8.138360648257047, 9.172121212267717, 10.165746075163872, 10.656421181183026, 9.71030820417153, 8.740061620824775, 7.77507555420855, 6.732687477456724, 6.66984239539549, 5.708612645834876, 4.755432690892778, 3.8250468620963463, 2.950093599033691, 2.0219550330596485, 3.0273400520531326, 4.020322760422353, 5.009067219987455, 5.986196019569515, 6.969615388829651, 7.9791724976001195, 8.92657392257748, 9.889399139525121, 10.873392809347221, 11.593947970542885, 10.676447395679364, 9.644912454870576, 8.603918692471787, 7.661225101541941, 7.615691662942761, 6.678183915435815, 5.682635624203884, 4.787745948913059, 3.88753362304163, 3.057406012872267, 4.100716530847479, 5.0298861831634305, 5.942052824328662, 6.9055822701365726, 7.941454157378343, 8.92877344513615, 9.884463928368849, 10.903409319230859, 11.825245197184234, 12.5147329182417, 11.5020108828238, 10.559521466798628, 9.573174305927374, 8.667334091741916, 8.64104015020057, 7.636350900781885, 6.704526774270266, 5.713515927877906, 4.927979669141274, 4.0877134427302355, 5.1362870130174, 5.992215341643959, 6.959638022042883, 7.904094775697344, 8.829444895931061, 9.765652766070845, 10.798412361932819, 11.80895385438558, 12.840291902205408, 13.452328333130735, 12.525367771595539, 11.587280126606792, 10.525929619940033, 9.606737955244354, 9.571794957719453, 8.693557600381043, 7.655235664808553, 6.671448735277383, 5.987859528537512, 5.0372549773188835, 6.016949254042336, 6.9989632014772525, 7.9419508902281795, 8.903120508351028, 9.767097134942823, 10.76943967897248, 11.726968506542809, 12.760186729841346, 13.773738601604375, 14.444050210257359, 13.488391661434548, 12.425890240800953, 11.46378496199159, 10.538299185011137, 10.550259226815102, 9.609754998956417, 8.623723224954494, 7.603632833636398, 7.011636566183123, 6.088943835504096, 7.007730351975364, 7.968918786056081, 8.885761553438961, 9.873804363222108, 10.77674676445938, 11.797510577640232, 12.726079795102827, 13.66652815176002, 14.030496753674981, 14.912251849824163, 14.354946263426699, 13.390273625670712, 12.429470174727772, 11.502509575976894, 11.575671312171329, 10.50226090503077, 9.54108487230149, 8.604169692318038, 7.945572831234765, 7.146211480879252, 7.960273335894792, 8.915297067605906, 9.901441457581226, 10.884468581073953, 11.748828642372992, 12.733604444554185, 13.720912785312311, 13.827491583138183, 13.037756715622594, 13.976722986072273, 14.725078120783666, 14.368446451555318, 13.487215702830866, 12.452401038843703, 12.567221416681694, 11.521279895806273, 10.529056976302872, 9.536861404485236, 8.91316430463665, 8.215701652138362, 8.967899923896567, 9.951187140630939, 10.896924550792253, 11.955932644769375, 12.693411791249998, 13.65036605117485, 13.804024913204042, 12.812234785648881, 12.012525107435026, 12.947744193785187, 13.758433385826365, 14.760846994193011, 14.453857739662576, 13.475757786693494], [15.519919837061098, 15.613963799348305, 14.620621463804316, 13.660829310262745, 12.772856562531658, 11.86377390989414, 10.849492006972303, 11.842782369208422, 12.62608642689149, 12.722598547005827, 11.965596505890149, 10.939120915603997, 10.065934510758707, 9.075941612116605, 10.023116063286496, 10.82411172226669, 11.457932230985978, 12.470124190134818, 13.518671430746691, 14.53830790114046, 15.523873885131616, 14.662764232845715, 13.761878948568743, 12.720431231274802, 11.785277826549502, 10.84606173626217, 9.909598802894367, 10.842414101865282, 11.649167186463206, 12.525252145332825, 12.811036820631315, 11.88140381123005, 11.00915536895096, 10.027878892586209, 10.950081456099232, 11.889685481039136, 12.530045829651947, 13.413870980960132, 14.400490298000232, 15.347416686556253, 14.506152621868921, 13.662108411056902, 12.727047485876813, 11.72918212901892, 10.77617406526098, 9.857723289762864, 8.885997131406617, 9.793191624291804, 10.6737428763033, 11.592076570787922, 12.632821711563038, 12.81890325715937, 11.998581136135583, 11.049997140062874, 11.96931241334647, 12.940661105667346, 13.51199124726169, 14.384149251535147, 15.348164126251582, 15.444243692115345, 13.473158775246503, 12.700699336217754, 11.716482669398706, 10.766671505026633, 9.823224169196312, 8.833951863676923, 7.92856055481974, 8.73624096173278, 9.692413153026347, 10.63851021993033, 11.618884395164343, 12.584567139512782, 12.965485935788488, 12.096857349030518, 12.913618574858857, 13.955663924372805, 14.465657463527823, 15.403787085517372, 15.394897459690696, 14.457389619955505, 12.528135474981, 11.735323607978758, 10.767481033924431, 9.727798333045127, 8.763591466581849, 7.829943537873296, 6.918507881616755, 7.705586071977505, 8.688017557876783, 9.662192344435717, 10.677656916963256, 11.654475385024988, 12.617608041860642, 13.023465686789057, 13.9837474495332, 14.917248159877891, 15.44587088469881, 15.383864136827887, 14.406627232289575, 13.466036079009188, 11.581092934380509, 10.805996148462462, 9.856996585218258, 8.849765503464065, 7.83395828676559, 6.896351227050394, 5.856091400201436, 6.780337431192257, 7.753250291627811, 8.684525020013718, 9.619115008871512, 10.64556108669344, 11.616248407820203, 12.58765960853436, 13.636241366617652, 14.475239204276141, 15.311249861191998, 14.42527961268715, 13.48931743031616, 12.508887466131554, 10.587890846257146, 9.792255609590292, 8.82473399036617, 7.860562074475374, 6.884289822621302, 5.868299989971193, 4.8497445963866515, 5.834243484475946, 6.792399548850635, 7.748744993052273, 8.754530183237096, 9.719485946520194, 10.570937761983025, 11.616775428064939, 12.578105172093252, 13.483139394733175, 14.378415831674753, 13.490659749040589, 12.525199114606997, 11.51984517821318, 9.620684532959004, 8.781193688951975, 7.833582990046842, 6.871333643384138, 5.850576602856161, 4.882837314129188, 3.8961772555619083, 4.887734702035846, 5.892323629976407, 6.73209734720521, 7.783808584806277, 8.687682998515804, 9.638843426121039, 10.632742896854367, 11.607855329556445, 12.467158923953674, 13.414483513852334, 12.652251881265713, 11.672613386433524, 10.681357074690075, 8.692084476854847, 7.811897881094044, 6.880628602929895, 5.870872853437803, 4.934317417854202, 3.9156137847080026, 2.8915430003664, 3.8369080271996117, 4.817350320288114, 5.769035296855857, 6.731868086333527, 7.7365155096389016, 8.696178787133647, 9.638644704017079, 10.592253427006858, 11.529992832325641, 12.534641357413163, 11.650027829470382, 10.691339094028647, 9.743856355388425, 7.685592432144735, 6.837707640588032, 5.845509367751552, 4.901672845943077, 3.9182817597870434, 2.9220955028420232, 1.9583294524476444, 2.8937356606744906, 3.86353735258779, 4.798932864831724, 5.7522504570994775, 6.735099526882928, 7.747492836716052, 8.681045681485614, 9.755790471868853, 10.822629094918405, 11.699593131191396, 10.698333587807141, 9.743416670664018, 8.755497428908065, 6.718961006948298, 5.768799257565294, 4.787826395502522, 3.906331687632012, 2.9992053996926424, 1.9661568744972757, 1.0205122487334057, 2.037601874229436, 3.074521449063803, 4.0513498725104435, 5.078491801060122, 6.134486035192361, 7.0656340332986245, 8.01260341907401, 8.937803862477475, 9.91864180718608, 10.680448180484232, 9.741965712501399, 8.744298599127147, 7.7438492135162456, 5.988146453195529, 4.9186008813316775, 3.849919063877888, 2.8902362905827337, 1.9569640296343191, 0.9694101259071166, 0.0, 1.0574128921182833, 2.121419930520745, 3.1947102673843393, 4.19100448370832, 5.180754288253419, 6.254254456779271, 7.300753163221832, 8.321480957408252, 9.30070857209471, 10.080565673904744, 9.09601826167093, 8.072437490266918, 7.022458606258523, 6.7279251305696945, 5.714999696247955, 4.785385873528276, 3.8215336047846797, 2.9767461373358697, 1.9820101430596495, 1.0083562893706355, 2.0498045728796868, 3.0869576311325715, 4.058315525538638, 5.1174644142172285, 6.115756024369985, 7.168950522349931, 8.202711086360601, 9.196335949256756, 10.220254187182775, 10.679718330078648, 9.709471746731893, 8.744485680115668, 7.702097603363841, 7.639252521302607, 6.678022771741993, 5.724842816799895, 4.794456988003463, 3.9119418207729266, 2.9431727845988593, 2.057929926146016, 3.0509126345152358, 4.039657094080338, 5.016785893662399, 6.000205262922535, 7.009762371693003, 7.957163796670364, 8.919989013618006, 9.903982683440105, 10.844000359422774, 11.645857521586482, 10.614322580777694, 9.573328818378904, 8.630635227449059, 8.58510178884988, 7.6475940413429315, 6.652045750111, 5.757156074820176, 4.849381844780866, 3.978623764411478, 3.1313064049403625, 4.060476057256313, 4.972642698421545, 5.936172144229456, 6.972044031471226, 7.959363319229033, 8.915053802461731, 9.933999193323741, 10.855835071277118, 11.823087624671418, 12.471421008730918, 11.528931592705746, 10.542584431834491, 9.636744217649035, 9.610450276107688, 8.605761026689002, 7.673936900177383, 6.682926053785023, 5.889827890880509, 5.008931194269446, 4.180560153781534, 5.022805215736842, 5.990227896135766, 6.934684649790227, 7.860034770023943, 8.796242640163726, 9.8290022360257, 10.83954372847846, 11.870881776298292, 12.760683039560453, 13.494777897502656, 12.55669025251391, 11.49533974584715, 10.576148081151471, 10.54120508362657, 9.662967726288159, 8.62464579071567, 7.640858861184499, 6.9497077502767475, 5.958472728858094, 5.139341085049321, 6.085221154571283, 6.972540764321062, 7.933710382443911, 8.797687009035704, 9.800029553065361, 10.75755838063569, 11.790776603934226, 12.804328475697254, 13.752404916687077, 14.457801787341666, 13.39530036670807, 12.433195087898708, 11.507709310918255, 11.51966935272222, 10.579165124863534, 9.593133350861612, 8.573042959543516, 7.965285628832051, 7.0101615870433065, 6.130122182982349, 7.055176739150111, 7.916351427531843, 8.90439423731499, 9.807336638552261, 10.828100451733114, 11.756669669195709, 12.697118025852902, 13.703491013019272, 14.698451811542435, 15.324356389333817, 14.35968375157783, 13.39888030063489, 12.471919701884012, 12.545081438078446, 11.471671030937888, 10.510494998208607, 9.573579818225156, 8.899221893883693, 8.067429232418462, 7.082665166901777, 8.037688898612892, 8.932061962660683, 9.91508908615341, 10.779418516465872, 11.764194318647068, 12.751502659405194, 12.858081457231068, 13.84804753397046, 14.815256937219266, 15.563612071930658, 15.337856577462436, 14.456625828737984, 13.421811164750821, 13.536631542588811, 12.490690021713391, 11.49846710220999, 10.506271530392354, 9.866813367285578, 9.045811837092682, 8.090291754903554, 9.073578971637925, 9.92754505587171, 10.986553149848831, 11.724001665342879, 12.680955925267732, 12.834614787296927, 11.842824659741765, 12.822815925782892, 13.78627814493218, 14.596967336973357, 15.599380945340004, 15.423267865569693, 14.445167912600612], [16.577332729179382, 16.45197005129009, 15.4586277157461, 14.49883556220453, 13.610862814473442, 12.624164172817444, 11.609882269895607, 10.873358528148154, 11.656662585831223, 11.715179381803088, 10.95817734068741, 9.931701750401258, 9.231469296618204, 9.93157385028293, 10.878748301452822, 11.756005744241605, 12.515345123104263, 13.527537082253104, 14.576084322864977, 15.595720793258746, 16.445854579140757, 15.500770484787497, 14.599885200510526, 13.558437483216586, 12.623284078491286, 11.683939554347242, 10.66998906581767, 9.872990260805015, 10.679743345402938, 11.555828304272557, 11.803617655428576, 10.873984646027312, 10.297036496998189, 10.883511130752535, 11.805713694265558, 12.812083575603069, 13.587458721770231, 14.471283873078418, 15.457903190118518, 16.404829578674537, 15.54082127737224, 14.500114662998683, 13.565053737818596, 12.567188380960703, 11.614180317202765, 10.695601107847937, 9.64638739432992, 8.823767783231537, 9.704319035243033, 10.622652729727655, 11.66339787050277, 11.81148409195663, 11.318596412655221, 11.9056293782292, 12.824944651512796, 13.863059200231278, 14.569404139379975, 15.441562143653433, 16.40557701836987, 16.501656584233626, 14.530571667364784, 13.538705588159537, 12.55448892134049, 11.604677756968416, 10.661230421138097, 9.671958115618704, 8.688950817743043, 7.766817120672512, 8.72298931196608, 9.669086378870063, 10.631606997699725, 11.597289742048162, 12.285501212308127, 12.952489587196844, 13.769250813025183, 14.84342401936588, 15.523070355646105, 16.461199977635655, 16.45231035180898, 15.514802512073786, 13.58554836709928, 12.573329859920541, 11.605487285866214, 10.56580458498691, 9.601597718523632, 8.66794978981508, 7.6788981445400575, 6.7361622309172375, 7.718593716816517, 8.674914946971098, 9.690379519498638, 10.667197987560368, 11.630330644396025, 12.64170373032383, 13.67842184594091, 14.446583235648749, 15.279701000203717, 16.286966143462664, 15.464040124407855, 14.523448971127468, 12.63850582649879, 11.738961337914319, 10.761225723951814, 9.733300522453138, 8.717493305754665, 7.779886246039469, 6.739626419190511, 5.81091359013199, 6.783826450567544, 7.6972476225491, 8.631837611406894, 9.658283689228824, 10.628971010355587, 11.600382211069743, 12.648963969153034, 13.487961806811523, 14.32397246372738, 15.238905209030692, 14.54673032243444, 13.566300358249835, 11.645303738375427, 10.725220799042148, 9.757699179818024, 8.744097093464449, 7.767824841610376, 6.751835008960268, 5.733279615375727, 4.864819643415679, 5.822975707790367, 6.761467595587656, 7.76725278577248, 8.732208549055578, 9.583660364518408, 10.629498030600322, 11.590827774628634, 12.495861997268557, 13.391138434210134, 14.30428534538413, 13.582612006725277, 12.57725807033146, 10.678097425077285, 9.71415887840383, 8.766548179498697, 7.754868662373212, 6.734111621845235, 5.766372333118262, 4.779712274550983, 3.918310860975578, 4.90504623251179, 5.744819949740593, 6.79653118734166, 7.700405601051186, 8.651566028656422, 9.645465499389749, 10.620577932091827, 11.479881526489056, 12.427206116387715, 13.35906379666624, 12.730026278551804, 11.738769966808356, 9.749497368973127, 8.839631209065754, 7.8608461949690005, 6.844593624873611, 5.8178524368432765, 4.7991488036970775, 3.7750780193554747, 2.8496306297349943, 3.8300729228234958, 4.7817578993912395, 5.74459068886891, 6.749238112174283, 7.708901389669029, 8.65136730655246, 9.60497602954224, 10.542715434861023, 11.547363959948544, 12.49079470009259, 11.74875198614693, 10.801269247506706, 8.743005324263017, 7.895120532706315, 6.902922259869834, 5.8960268506650655, 4.912635764509032, 3.9164495075640113, 2.841864471436719, 1.9064582632098732, 2.8762599551231727, 3.8116554673671073, 4.76497305963486, 5.74782212941831, 6.760215439251434, 7.6937682840209956, 8.768513074404234, 9.820932505790031, 10.894904731323273, 11.755746479925424, 10.800829562782301, 9.812910321026347, 7.776373899066581, 6.826212149683577, 5.845239287620805, 4.963744579750296, 4.041566039427808, 2.9753383153045947, 2.0296936895407245, 0.9801889821111526, 2.01710855694552, 2.993936980392161, 4.021078908941839, 5.077073143074078, 6.008221141180342, 6.955190526955726, 7.880390970359191, 8.861228915067796, 9.916883254279233, 10.799378604619681, 9.80171149124543, 8.801262105634528, 7.045559345313812, 5.976013773449961, 4.907331955996171, 3.947649182701017, 3.0143769217526026, 2.0268230180254, 1.0574128921182833, 0.0, 1.0640070384024616, 2.137297375266056, 3.1335915915900365, 4.123341396135135, 5.196841564660987, 6.243340271103548, 7.264068065289967, 8.243295679976425, 9.201594140851045, 10.153431153789214, 9.129850382385202, 8.079871498376807, 7.785338022687977, 6.772412588366238, 5.842798765646559, 4.878946496902963, 4.034159029454153, 3.0394230351779328, 2.0657691814889185, 1.0697044411252905, 2.0718209732453747, 3.0431788676514406, 4.102327756330031, 5.100619366482788, 6.153813864462734, 7.187574428473404, 8.181199291369559, 9.186794219949816, 10.13290719696131, 10.766884638850176, 9.80189857223395, 8.759510495482123, 8.69666541342089, 7.735435663860276, 6.782255708918178, 5.851869880121747, 4.96935471289121, 4.000585676717143, 3.074661149673781, 2.081678441304561, 3.024520436193142, 4.0016492357752025, 4.985068605035338, 5.9946257138058066, 6.942027138783168, 7.904852355730808, 8.888846025552908, 9.828863701535576, 10.861354722161186, 11.671735472895977, 10.630741710497187, 9.688048119567341, 9.642514680968162, 8.705006933461215, 7.709458642229283, 6.8145689669384595, 5.906794736899149, 5.036036656529761, 4.13559647599334, 3.0912418640456387, 3.9575060405343487, 4.92103548634226, 5.95690737358403, 6.944226661341837, 7.899917144574535, 8.918862535436544, 9.840698413389921, 10.80795096678422, 11.82067300220212, 12.586344484824028, 11.599997323952774, 10.694157109767318, 10.66786316822597, 9.663173918807285, 8.731349792295667, 7.740338945903306, 6.947240782998793, 6.06634408638773, 5.03619239194786, 4.053571022526167, 4.9828087309330265, 5.927265484587488, 6.852615604821204, 7.788823474960988, 8.821583070822962, 9.832124563275723, 10.855745118411095, 11.745546381673256, 12.81799888511204, 13.614103144632193, 12.552752637965433, 11.633560973269754, 11.598617975744853, 10.720380618406445, 9.682058682833954, 8.698271753302784, 7.973624079439926, 6.9746675999390995, 5.994973323215647, 5.115986961360608, 5.965121599118323, 6.926291217241172, 7.7902678438329644, 8.792610387862624, 9.750139215432952, 10.783357438731489, 11.796909310494517, 12.73726825879988, 13.742131864114516, 14.452713258826353, 13.490607980016991, 12.565122203036537, 12.577082244840502, 11.636578016981819, 10.650546242979896, 9.6304558516618, 8.897179650806967, 7.9420556090182215, 6.985754421148675, 6.085942545939437, 6.908932262329104, 7.896975072112252, 8.799917473349522, 9.820681286530373, 10.749250503992968, 11.68969886065016, 12.696071847816532, 13.691032646339695, 14.675564241156245, 15.417096643696112, 14.456293192753172, 13.529332594002295, 13.602494330196729, 12.52908392305617, 11.56790789032689, 10.63099271034344, 9.831115915858609, 8.992630617879678, 7.938297405068103, 7.150964778797423, 7.924642797457944, 8.90766992095067, 9.771999351263133, 10.756775153444327, 11.744083494202453, 12.747722879822927, 13.688811885868919, 14.626561510091584, 15.617424627892754, 16.395269469580718, 15.514038720856266, 14.479224056869104, 14.594044434707094, 13.548102913831674, 12.555879994328274, 11.563684422510638, 10.798707389260494, 9.901444075259008, 8.94592399306988, 8.186854851822456, 8.92012589066897, 9.979133984646092, 10.71658250014014, 11.67353676006499, 11.874979024234246, 12.60321492266507, 13.583206188706196, 14.624284396873964, 15.434973588915142, 16.43738719728179, 16.480680757687974, 15.502580804718894], [17.641339767581844, 17.51597708969255, 16.522634754148562, 15.562842600606992, 14.674869852875904, 13.688171211219906, 12.673889308298069, 11.937365566550616, 10.940860394314996, 10.651172343400626, 9.894170302284946, 8.867694711998794, 9.831637384639189, 10.764227200686252, 11.711401651856143, 12.588659094644925, 13.579352161506725, 14.591544120655566, 15.640091361267439, 16.659727831661208, 17.509861617543216, 16.564777523189957, 15.663892238912988, 14.622444521619048, 13.687291116893748, 12.747946592749704, 11.733996104220132, 10.936997299207476, 9.963941153886712, 10.74126205649055, 10.739610617026113, 9.809977607624848, 10.848701625597574, 11.716164481155856, 12.638367044668879, 13.64473692600639, 14.607697297151622, 15.53529091148088, 16.52191022852098, 17.468836617077, 16.604828315774704, 15.564121701401145, 14.629060776221058, 13.631195419363165, 12.678187355605226, 11.759608146250399, 10.710394432732382, 9.887774821633998, 8.988516843726806, 9.808086481945647, 10.843981573049204, 10.747477053554167, 11.804913031782293, 12.738282728632523, 13.657598001916117, 14.6957125506346, 15.589642714761366, 16.505569182055897, 17.469584056772334, 17.565663622636087, 15.594578705767246, 14.602712626561999, 13.618495959742951, 12.668684795370877, 11.725237459540558, 10.735965154021166, 9.752957856145507, 8.830824159074973, 8.007187120449853, 8.854520131088055, 9.77721784351144, 10.742900587859879, 11.70653163652327, 12.713922913894082, 13.762037034864209, 14.55377831696555, 15.40552526718642, 16.34365488917597, 17.275624936740428, 16.578809550476247, 14.649555405501742, 13.637336898323003, 12.669494324268676, 11.629811623389372, 10.665604756926093, 9.731956828217541, 8.74290518294252, 7.800169269319699, 6.985542669507573, 7.820525792782812, 8.835990365310353, 9.812808833372085, 10.775941490207739, 11.787314576135543, 12.824032691752626, 13.592194081460464, 14.425311846015433, 15.432576989274379, 16.25563997786382, 15.58745600952993, 13.702512864901252, 12.80296837631678, 11.825232762354275, 10.7973075608556, 9.781500344157127, 8.843893284441931, 7.803633457592973, 6.8749206285344515, 5.975324000605465, 6.842858468360814, 7.7774484572186084, 8.803894535040538, 9.7745818561673, 10.745993056881456, 11.794574814964749, 12.633572652623238, 13.469583309539095, 14.384516054842408, 15.32108126533981, 14.630307396652297, 12.709310776777889, 11.78922783744461, 10.821706218220486, 9.808104131866909, 8.831831880012837, 7.81584204736273, 6.797286653778189, 5.9288266818181405, 4.992472968551769, 5.90707844139937, 6.912863631584194, 7.877819394867292, 8.729271210330122, 9.775108876412036, 10.73643862044035, 11.641472843080273, 12.53674928002185, 13.449896191195846, 14.415356825629438, 13.641265108733922, 11.742104463479746, 10.778165916806293, 9.830555217901159, 8.818875700775674, 7.798118660247697, 6.830379371520724, 5.843719312953445, 4.98231789937804, 4.050657078323504, 4.890430795552307, 5.942142033153374, 6.846016446862901, 7.7971768744681365, 8.791076345201464, 9.766188777903542, 10.625492372300771, 11.57281696219943, 12.504674642477955, 13.529930162486322, 12.802777005210817, 10.81350440737559, 9.903638247468214, 8.924853233371461, 7.908600663276073, 6.881859475245738, 5.863155842099539, 4.839085057757937, 3.913637668137456, 2.9756837686352102, 3.927368745202954, 4.8902015346806245, 5.894848957985999, 6.854512235480744, 7.796978152364176, 8.750586875353955, 9.688326280672738, 10.69297480576026, 11.636405545904303, 12.673374483276245, 11.865276285909168, 9.807012362665478, 8.959127571108777, 7.966929298272296, 6.960033889067527, 5.976642802911494, 4.980456545966473, 3.905871509839181, 2.970465301612335, 2.021870800934887, 2.9572663131788217, 3.9105839054465745, 4.893432975230025, 5.905826285063149, 6.839379129832711, 7.840317794816494, 8.82869430365329, 9.902666529186531, 10.917188669929732, 11.864836601184763, 10.876917359428809, 8.840380937469043, 7.890219188086038, 6.909246326023267, 6.027751618152758, 5.10557307783027, 4.0393453537070565, 3.0937007279431863, 2.0441960205136143, 1.0427110516401714, 2.0195394750868125, 3.0449680767137584, 4.084834940937338, 5.015982939043601, 5.9629523248189855, 6.88815276822245, 7.868990712931055, 8.924645052142491, 9.863127520125325, 10.860794633499577, 9.86526914403699, 8.109566383716274, 7.040020811852423, 5.971338994398633, 5.011656221103479, 4.078383960155064, 3.0908300564278615, 2.121419930520745, 1.0640070384024616, 0.0, 1.0732903368635944, 2.069584553187575, 3.059334357732674, 4.1328345262585255, 5.179333232701087, 6.200061026887505, 7.179288641573963, 8.137587102448583, 9.122134514682397, 10.145715286086409, 9.143878536779269, 8.849345061090439, 7.836419626768699, 6.906805804049021, 5.942953535305425, 5.054805124570083, 4.060069130293863, 3.0864152766048494, 2.044966993095798, 1.0078139348429132, 1.9791718292489793, 3.03832071792757, 4.036612328080327, 5.089806826060272, 6.123567390070942, 7.117192252967096, 8.122787181547354, 9.068900158558849, 10.039146741905604, 10.865905610636412, 9.823517533884585, 9.760672451823352, 8.799442702262738, 7.846262747320639, 6.915876918524209, 5.9900008080071405, 5.021231771833073, 4.02391304992988, 3.0309303415606603, 1.9605133977906803, 2.9376421973727407, 3.921061566632876, 4.930618675403345, 5.878020100380706, 6.8408453173283466, 7.8248389871504465, 8.764856663133115, 9.797347683758725, 10.862593905918201, 11.694748748899649, 10.752055157969803, 10.706521719370624, 9.769013971863677, 8.773465680631745, 7.878576005340921, 6.92744083201508, 6.056682751645692, 5.009657769313337, 3.965303157365636, 2.893499002131887, 3.857028447939798, 4.892900335181568, 5.880219622939375, 6.835910106172073, 7.854855497034082, 8.77669137498746, 9.743943928381759, 10.756665963799659, 11.69915537982483, 12.664004362355236, 11.75816414816978, 11.731870206628432, 10.727180957209747, 9.795356830698129, 8.804345984305769, 7.891524894168746, 6.917419312638346, 5.868845742351181, 4.8862243729294885, 3.918801692530564, 4.863258446185025, 5.788608566418741, 6.724816436558525, 7.7575760324204985, 8.76811752487326, 9.791738080008633, 10.681539343270794, 11.753991846709578, 12.770550589105374, 13.616759676367895, 12.697568011672216, 12.662625014147315, 11.784387656808907, 10.746065721236416, 9.762278791705246, 8.806277429843247, 7.807320950342421, 6.827626673618968, 5.855535761632134, 4.901114560715861, 5.862284178838709, 6.726260805430503, 7.72860334946016, 8.686132177030489, 9.719350400329025, 10.732902272092055, 11.673261220397418, 12.678124825712054, 13.75128562706966, 14.554615018419453, 13.629129241439, 13.641089283242964, 12.70058505538428, 11.714553281382358, 10.694462890064262, 9.729833001210286, 8.774708959421542, 7.818407771551996, 6.825491346210962, 5.8449252239266425, 6.83296803370979, 7.73591043494706, 8.756674248127911, 9.685243465590506, 10.625691822247699, 11.63206480941407, 12.627025607937233, 13.611557202753783, 14.57622984050977, 15.520300231155634, 14.593339632404756, 14.66650136859919, 13.593090961458632, 12.631914928729351, 11.694999748745902, 10.663769266261928, 9.825283968283001, 8.770950755471425, 7.846780149030802, 6.860635759055482, 7.843662882548209, 8.707992312860672, 9.692768115041865, 10.680076455799991, 11.683715841420465, 12.624804847466457, 13.562554471689122, 14.553417589490293, 15.554402666394376, 16.57804575925873, 15.543231095271565, 15.658051473109555, 14.612109952234135, 13.619887032730736, 12.6276914609131, 11.631360739663814, 10.734097425662329, 9.7785773434732, 8.815030401425377, 7.8561188522665075, 8.91512694624363, 9.652575461737678, 10.609529721662529, 11.656954301318018, 12.64874442887318, 13.633766102923317, 14.591533263976208, 15.520062324447593, 16.522475932814242, 17.534966773471172, 16.566587843121358], [18.525774371134467, 17.576129858014916, 16.582787522470927, 15.622995368929354, 14.782768875871175, 13.778070560782325, 12.827339523612897, 11.820736044744574, 10.781198241004658, 9.83643478537088, 9.244607257198833, 9.884720318916822, 10.848662991557216, 11.781252807604277, 12.728427258774168, 13.60568470156295, 14.633628409293047, 15.645820368441889, 16.694367609053764, 17.714004079447534, 18.39512801761851, 17.450043923265252, 16.54915863898828, 15.507710921694343, 14.572557516969043, 13.633212992825, 12.619262504295428, 11.779574607491718, 10.792827600859257, 9.797749918686186, 10.282743528163591, 10.827003214542875, 11.865727232515601, 12.733190088073881, 13.655392651586904, 14.661762532924415, 15.624722904069648, 16.589567159267204, 17.576186476307306, 18.523112864863325, 17.49009471585, 16.44938810147644, 15.514327176296353, 14.51646181943846, 13.563453755680522, 12.644874546325694, 11.595660832807678, 10.773041221709294, 9.817403290699351, 8.864574344141284, 9.900469435244839, 10.811752154533954, 11.729219201705689, 12.677803197778397, 13.650803087645164, 14.57392371343161, 15.36433406121315, 16.403666888271598, 17.332715373726455, 18.17958132201096, 16.499310797957797, 15.487979026637294, 14.503762359818246, 13.553951195446173, 12.610503859615854, 11.621231554096461, 10.638224256220802, 9.716090559150269, 8.857105060187674, 7.911007993283691, 8.833705705707075, 9.799388450055513, 10.762314402052784, 11.724323206262286, 12.772437327232412, 13.55892089472615, 14.41066784494702, 15.348797466936569, 16.28076751450103, 17.19272724985112, 15.554287497692293, 14.522603298398298, 13.554760724343971, 12.515078023464667, 11.550871157001389, 10.617223228292836, 9.628171583017815, 8.685435669394995, 7.849006718474552, 6.877013654978447, 7.892478227505989, 8.86929669556772, 9.786341782575942, 10.797714868503746, 11.829175269513225, 12.597336659221064, 13.430454423776032, 14.437719567034978, 15.260782555624418, 16.201373708904804, 14.675486964884447, 13.749213440074673, 12.771477826112172, 11.743552624613496, 10.72774540791502, 9.790138348199823, 8.749878521350865, 7.760187028609748, 6.838788049572444, 5.899346330556449, 6.833936319414244, 7.860382397236173, 8.784982148535503, 9.75639334924966, 10.799717392725348, 11.638715230383838, 12.474725887299694, 13.389658632603007, 14.32622384310041, 15.377673488374974, 13.682284876761084, 12.735472901202503, 11.767951281978378, 10.754349195624805, 9.778076943770731, 8.762087111120623, 7.743531717536081, 6.814093081893437, 5.855937017518748, 4.963566303595005, 5.969351493779829, 6.888219687235496, 7.739671502698325, 8.785509168780239, 9.741581198200949, 10.646615420840872, 11.54189185778245, 12.455038768956445, 13.420499403390039, 14.425853339783856, 12.715078563462942, 11.724410980564185, 10.776800281659051, 9.765120764533567, 8.74436372400559, 7.776624435278617, 6.789964376711337, 5.928562963135932, 4.914121127290484, 3.946918657747943, 4.952542325521579, 5.856416739231105, 6.80757716683634, 7.801476637569669, 8.771331355664142, 9.63063495006137, 10.57795953996003, 11.509817220238554, 12.535072740246921, 13.52632905199037, 11.846014136598413, 10.849883311226106, 9.871098297129354, 8.854845727033965, 7.828104539003631, 6.809400905857432, 5.7853301215158295, 4.859882731895349, 3.900721641157251, 2.9838566073985895, 3.9006018270488285, 4.905249250354203, 5.864912527848947, 6.80737844473238, 7.755729453114554, 8.693468858433338, 9.69811738352086, 10.641548123664904, 11.678517061036846, 12.737847804660955, 10.880302699529073, 9.998740250504337, 8.952088143145188, 7.90627895282542, 6.922887866669386, 5.926701609724366, 4.8521165735970735, 3.9167103653702275, 2.946908673456928, 2.013754175374457, 2.9209841978147786, 3.903833267598229, 4.916226577431353, 5.849779422200915, 6.7670274579529, 7.7554039667896975, 8.829376192322938, 9.84389833306614, 10.798815250209262, 11.786734491965216, 9.913671274332637, 8.963509524949632, 7.982536662886861, 7.007944036086469, 6.0660455563132345, 4.999817832190021, 4.054173206426151, 3.0046684989965797, 1.9677489241622126, 0.9909205007155716, 1.971677739850164, 3.0115446040737432, 3.9426926021800073, 4.8896619879553915, 5.814862431358856, 6.795700376067462, 7.851354715278897, 8.789837183261731, 9.787504296635984, 10.787953682246885, 9.182856720579869, 8.113311148716017, 7.044629331262227, 6.084946557967073, 5.151674297018658, 4.164120393291456, 3.1947102673843393, 2.137297375266056, 1.0732903368635944, 0.0, 0.9962942163239806, 1.9860440208690793, 3.059544189394931, 4.106042895837492, 5.1267706900239105, 6.1059983047103685, 7.064296765584988, 8.048844177818802, 9.072424949222814, 10.122403833231209, 9.922635397954032, 8.909709963632293, 7.9800961409126145, 7.016243872169019, 6.0718307314881095, 5.0770947372118895, 4.103440883522875, 3.061992600013824, 2.0248395417609393, 1.053481647354873, 2.004347175325213, 3.00263878547797, 4.034472800063176, 5.068233364073846, 6.06185822697, 7.049496844683758, 7.995609821695252, 8.965856405042008, 9.930842471658233, 10.896807870748178, 10.833962788686945, 9.87273303912633, 8.919553084184233, 7.989167255387803, 7.007026414925166, 6.0382573787511, 5.040938656847906, 4.047955948478687, 2.9775390047087065, 2.124291279290154, 3.0465459578702148, 4.050271772056274, 4.997673197033635, 5.960498413981276, 6.944492083803376, 7.884509759786044, 8.917000780411653, 9.95430651790988, 10.938543252111856, 11.825345494833396, 11.779812056234217, 10.842304308727272, 9.84675601749534, 8.951866342204516, 7.944466438933105, 7.073708358563718, 6.0266833762313645, 4.982328764283663, 3.9105246090499133, 3.0593937989116524, 4.0183847264189065, 4.999872719592305, 5.955563202825003, 6.974508593687012, 7.89634447164039, 8.86359702503469, 9.87631906045259, 10.818808476477761, 11.805155637349015, 12.831454485033372, 12.805160543492025, 11.800471294073342, 10.868647167561724, 9.877636321169364, 8.908550501086772, 7.9344449195563715, 6.885871349269206, 5.903249979847514, 4.93582729944859, 4.066900009665638, 4.973871008388996, 5.91007887852878, 6.886253808072677, 7.896795300525438, 8.911391176661564, 9.801192439923724, 10.873644943362509, 11.890203685758305, 12.757910951361673, 13.692051015607989, 13.735915351010908, 12.845170311326378, 11.806848375753887, 10.823061446222717, 9.823303036761272, 8.824346557260446, 7.844652280536994, 6.872561368550159, 5.9181401676338865, 5.065925742319322, 5.911523247400757, 6.913865791430415, 7.871394619000743, 8.90461284229928, 9.918164714062307, 10.792914317050348, 11.797777922364983, 12.870938723722588, 13.77222042153701, 14.623612245374773, 14.708240995299887, 13.761367709901752, 12.775335935899829, 11.755245544581733, 10.746858608128312, 9.791734566339567, 8.835433378470022, 7.842516953128987, 6.861950830844668, 6.097391303006074, 6.921172876917314, 7.941936690098166, 8.87050590756076, 9.810954264217953, 10.817327251384324, 11.812288049907487, 12.757970653674201, 13.722643291430188, 14.683446742373128, 15.58782263634053, 15.726569416179716, 14.653159009039157, 13.691982976309877, 12.755067796326426, 11.680794873179954, 10.842309575201027, 9.78797636238945, 8.863805755948828, 7.877661365973507, 7.139243917341355, 7.8932547548309255, 8.878030557012119, 9.865338897770245, 10.86897828339072, 11.810067289436711, 12.747816913659376, 13.720212607261441, 14.700816117314794, 15.742905870989082, 16.53771409920734, 16.71811952069008, 15.67217799981466, 14.674163280517059, 13.681967708699423, 12.64838634658184, 11.751123032580354, 10.795602950391226, 9.832056008343404, 8.873144459184534, 8.210707981036776, 8.837837903707932, 9.794792163632785, 10.842216743288274, 11.834006870843435, 12.819028544893573, 13.776795705946462, 14.686857342218742, 15.689270950585389, 16.70176179124232, 17.56107084705713], [17.529480154810482, 16.57983564169093, 15.586493306146943, 14.626701152605373, 13.786474659547194, 12.781776344458343, 11.831045307288916, 10.824441828420593, 9.784904024680676, 8.8401405690469, 9.82770640598415, 10.796276685421425, 11.76021935806182, 12.692809174108879, 13.63998362527877, 14.517241068067554, 15.545184775797651, 16.55737673494649, 17.605923975558365, 18.539093088447874, 18.500955620724344, 17.555871526371085, 16.617299617155783, 15.567099231593316, 14.722035104894989, 13.744821891944186, 12.683796003296113, 11.748570271741421, 10.76182326510896, 9.83229427196215, 9.984342977124424, 10.844479966318321, 11.754484901038742, 12.703627228931083, 13.673739828568422, 14.62860512173584, 15.349985262498915, 16.377650942522635, 17.328464654869226, 18.121053656498674, 18.120997243496937, 17.313641499860534, 16.378580574680445, 15.380715217822553, 14.427707154064615, 13.509127944709787, 12.459914231191771, 11.637294620093387, 10.681656689083445, 9.728827742525377, 9.009167124372107, 9.906980520389002, 10.73292498538171, 11.681508981454417, 12.654508871321184, 13.57762949710763, 14.368039844889172, 15.40737267194762, 16.336421157402473, 17.183287105686983, 17.08800339687452, 16.352232425021388, 15.36801575820234, 14.418204593830266, 13.474757257999947, 12.485484952480554, 11.502477654604895, 10.580343957534362, 9.721358458571768, 8.775261391667785, 7.9424033948343435, 8.894616815910561, 9.766020185728804, 10.728028989938306, 11.776143110908432, 12.56262667840217, 13.41437362862304, 14.352503250612589, 15.284473298177048, 16.196433033527143, 16.142980096609016, 15.386856696782392, 14.419014122728065, 13.379331421848761, 12.415124555385482, 11.48147662667693, 10.492424981401909, 9.549689067779088, 8.713260116858647, 7.741267053362542, 7.001175916633257, 7.964525061422768, 8.790047566251962, 9.801420652179766, 10.832881053189244, 11.601042442897084, 12.434160207452052, 13.441425350710999, 14.264488339300438, 15.205079492580825, 15.31200738276191, 14.615707852620229, 13.637972238657728, 12.610047037159053, 11.594239820460576, 10.65663276074538, 9.616372933896422, 8.624440426993841, 7.703041447956538, 6.763599728940544, 5.942634008541512, 6.94248148536984, 7.7886879322115234, 8.76009913292568, 9.803423176401367, 10.642421014059858, 11.478431670975715, 12.393364416279027, 13.32992962677643, 14.381379272050992, 14.361513455415908, 13.601967313748059, 12.634445694523935, 11.620843608170361, 10.644571356316288, 9.62858152366618, 8.610026130081637, 7.678346480277531, 6.7201904159028425, 5.8278197019791, 4.9939666513198135, 5.891925470911516, 6.743377286374345, 7.789214952456259, 8.745286981876967, 9.650321204516892, 10.54559764145847, 11.458744552632465, 12.424205187066057, 13.429559123459875, 13.581572976008498, 12.590905393109741, 11.643294694204608, 10.631615177079123, 9.610858136551146, 8.643118847824173, 7.656458789256894, 6.795057375681489, 5.778374525674578, 4.811172056132037, 3.9562481091975976, 4.860122522907124, 5.81128295051236, 6.805182421245688, 7.775037139340161, 8.63434073373739, 9.58166532363605, 10.513523003914575, 11.538778523922941, 12.53003483566639, 12.71250854914397, 11.716377723771664, 10.737592709674912, 9.721340139579523, 8.694598951549189, 7.675895318402989, 6.651824534061387, 5.726377144440906, 4.767216053702809, 3.848110005782684, 2.9043076107248478, 3.908955034030222, 4.868618311524967, 5.811084228408399, 6.759435236790575, 7.697174642109358, 8.70182316719688, 9.645253907340923, 10.682222844712864, 11.741553588336973, 11.783179097687288, 10.865234663049891, 9.818582555690742, 8.772773365370975, 7.7893822792149425, 6.793196022269923, 5.718610986142631, 4.783204777915785, 3.8134030860024857, 2.878007573758551, 1.9246899814907978, 2.9075390512742483, 3.9199323611073726, 4.853485205876934, 5.77073324162892, 6.759109750465718, 7.833081975998958, 8.84760411674216, 9.802521033885283, 10.790440275641238, 10.816547672490852, 9.959803741273616, 8.978830879210843, 8.00423825241045, 7.062339772637216, 5.996112048514003, 5.050467422750133, 4.0009627153205605, 2.964043140486193, 1.9872147170395522, 0.9753835235261832, 2.0152503877497625, 2.9463983858560265, 3.8933677716314112, 4.818568215034876, 5.799406159743482, 6.855060498954917, 7.793542966937752, 8.791210080312004, 9.791659465922905, 10.160421769970224, 9.109605365039998, 8.040923547586209, 7.081240774291054, 6.147968513342639, 5.160414609615437, 4.19100448370832, 3.1335915915900365, 2.069584553187575, 0.9962942163239806, 0.0, 0.9897498045450986, 2.0632499730709504, 3.1097486795135114, 4.130476473699931, 5.109704088386389, 6.068002549261008, 7.052549961494822, 8.076130732898834, 9.126109616907229, 10.918929614278014, 9.906004179956275, 8.976390357236596, 8.012538088492999, 7.068124947812091, 6.073388953535871, 5.099735099846857, 4.058286816337805, 3.02113375808492, 2.0497758636788537, 1.0080529590012324, 2.006344569153989, 3.038178583739195, 4.071939147749864, 5.0655640106460185, 6.053202628359778, 6.999315605371272, 7.969562188718027, 8.934548255334251, 9.976936332086078, 11.830257005010926, 10.869027255450312, 9.915847300508215, 8.985461471711782, 8.003320631249148, 7.034551595075081, 6.037232873171887, 5.044250164802667, 3.973833221032687, 3.0336711108063694, 2.050251741546234, 3.0539775557322937, 4.001378980709655, 4.9642041976572955, 5.948197867479395, 6.8882155434620636, 7.9207065640876735, 8.958012301585898, 9.942249035787874, 10.88494262671772, 12.776106272558199, 11.838598525051253, 10.843050233819321, 9.948160558528494, 8.940760655257087, 8.070002574887699, 7.022977592555344, 5.978622980607643, 4.906818825373894, 3.968773630427868, 3.0220905100949254, 4.003578503268324, 4.959268986501022, 5.978214377363031, 6.900050255316408, 7.867302808710708, 8.880024844128608, 9.82251426015378, 10.808861421025034, 11.858108579286753, 13.66145460432779, 12.796765510397323, 11.862095382138868, 10.871084535746508, 9.820106867591374, 8.846001286060973, 7.797427715773809, 6.814806346352117, 5.847383665953193, 4.902926912298732, 3.977576792065015, 4.913784662204799, 5.8899595917486955, 6.900501084201457, 7.915096960337582, 8.804898223599743, 9.877350727038527, 10.893909469434323, 11.761616735037691, 12.695756799284007, 14.592209411846673, 13.75672667783098, 12.718404742258489, 11.734617812727318, 10.734859403265874, 9.735902923765048, 8.756208647041596, 7.784117735054763, 6.82969653413849, 5.901952644952416, 4.915229031076776, 5.917571575106434, 6.875100402676762, 7.908318625975299, 8.921870497738327, 9.796620100726367, 10.801483706041001, 11.874644507398607, 12.775926205213029, 13.627318029050791, 15.54527083751996, 14.672924076406353, 13.68689230240443, 12.666801911086335, 11.658414974632915, 10.70329093284417, 9.746989744974625, 8.75407331963359, 7.7735071973492715, 6.856037028395218, 5.924878660593333, 6.945642473774185, 7.874211691236779, 8.814660047893971, 9.821033035060342, 10.815993833583505, 11.76167643735022, 12.726349075106206, 13.687152526049147, 14.591528420016548, 16.50560925077208, 15.56471537554376, 14.603539342814479, 13.66662416283103, 12.592351239684557, 11.753865941705628, 10.699532728894052, 9.775362122453432, 8.789217732478111, 7.834292117213286, 6.896960538506944, 7.881736340688137, 8.869044681446264, 9.872684067066738, 10.81377307311273, 11.751522697335394, 12.72391839093746, 13.704521900990812, 14.7466116546651, 15.541419882883357, 17.533362245446927, 16.583734366319263, 15.585719647021662, 14.593524075204027, 13.559942713086443, 12.662679399084956, 11.707159316895828, 10.743612374848006, 9.784700825689137, 8.8810911905921, 7.841543687383951, 8.798497947308803, 9.845922526964292, 10.837712654519454, 11.822734328569592, 12.78050148962248, 13.69056312589476, 14.692976734261407, 15.705467574918336, 16.56477663073315], [16.56515355498674, 15.61550904186719, 14.6221667063232, 13.66237455278163, 12.859401259061924, 11.898682171255071, 10.981908991391524, 10.036997022204059, 9.047868678490973, 9.829890373591999, 10.817456210529249, 10.935086051970064, 11.899028724610458, 12.78488761941702, 13.73002833139749, 14.701064158654152, 15.432349056619781, 16.331647928802848, 17.27151098184679, 17.57476648862413, 17.536629020900605, 16.591544926547346, 15.652973017332043, 14.602772631769573, 13.84697999504408, 12.944637477686172, 11.92180219546946, 11.011534925551718, 10.024787918919257, 10.822044076507249, 10.922436165745275, 9.99280315634401, 10.883808011055073, 11.832950338947416, 12.803062938584754, 13.63885531719074, 14.360235457953813, 15.387901137977535, 16.338714850324124, 17.13130385195357, 17.131247438951835, 17.592200748336158, 16.629531861780432, 15.631666504922539, 14.856083756332602, 13.932975924185477, 12.94540386695721, 11.970038544717733, 11.000212229079162, 10.718577547070476, 9.998916928917206, 9.055303710414691, 9.86224809539804, 10.810832091470749, 11.783831981337515, 12.587879692562531, 13.37829004034407, 14.41762286740252, 15.346671352857372, 16.19353730114188, 16.098253592329417, 17.136661745027393, 16.35776556274744, 15.407954398375365, 14.464507062545046, 13.475234757025653, 12.492227459149994, 11.57009376207946, 10.711108263116866, 9.765011196212884, 8.932153199379442, 8.04294000593625, 8.895343295745135, 9.857352099954637, 10.905466220924763, 11.572876873857071, 12.424623824077939, 13.362753446067488, 14.294723493631947, 15.206683228982042, 15.153230292063913, 16.184914491357908, 15.408763927273164, 14.36908122639386, 13.40487435993058, 12.471226431222028, 11.482174785947008, 10.539438872324187, 9.703009921403746, 8.73101685790764, 7.990925721178355, 7.112848251448456, 7.919370676268294, 8.930743762196098, 9.843131248644145, 10.611292638351985, 11.444410402906952, 12.451675546165898, 13.274738534755338, 14.215329688035725, 14.322257578216812, 15.277463579713542, 14.627722043202827, 13.599796841704151, 12.583989625005676, 11.64638256529048, 10.606122738441522, 9.61419023153894, 8.692791252501637, 7.753349533485642, 6.93238381308661, 6.090804675395528, 6.918011042227854, 7.88942224294201, 8.813673371856268, 9.652671209514759, 10.488681866430614, 11.403614611733927, 12.34017982223133, 13.391629467505894, 13.37176365087081, 14.347349147052599, 13.624195499069035, 12.61059341271546, 11.634321160861388, 10.61833132821128, 9.599775934626738, 8.66809628482263, 7.709940220447941, 6.817569506524198, 5.983716455864911, 5.040248660937204, 5.872700396390676, 6.918538062472589, 7.755537177331869, 8.660571399971793, 9.555847836913369, 10.468994748087365, 11.434455382520959, 12.439809318914776, 12.60095757285236, 13.580655197654842, 12.633044498749708, 11.621364981624223, 10.600607941096246, 9.632868652369273, 8.646208593801994, 7.784807180226588, 6.768124330219677, 5.8009218606771356, 4.945997913742696, 4.008445712932812, 4.94060606052869, 5.8698552571499105, 6.785287334795062, 7.644590929192291, 8.59191551909095, 9.523773199369474, 10.54902871937784, 11.54028503112129, 11.7999213378523, 12.706127528316763, 11.72734251422001, 10.711089944124621, 9.684348756094288, 8.665645122948089, 7.641574338606485, 6.7161269489860045, 5.7569658582479075, 4.837859810327783, 3.8940574152699465, 3.05727822405591, 3.9979414215412983, 4.875757064312621, 5.769685432245476, 6.707424837564259, 7.712073362651781, 8.655504102795824, 9.692473040167766, 10.751803783791875, 10.79342929314219, 11.736403244516076, 10.808332360235841, 9.762523169916074, 8.779132083760041, 7.782945826815022, 6.708360790687729, 5.772954582460883, 4.803152890547584, 3.86775737830365, 2.9144397860358966, 2.0558622412999368, 2.9846051970115948, 3.9181580417811563, 4.780983437083822, 5.769359945920619, 6.843332171453859, 7.857854312197061, 8.812771229340184, 9.80069047109614, 9.826797867945753, 10.776959617328759, 9.968580683755942, 8.99398805695555, 8.052089577182315, 6.9858618530591015, 6.040217227295232, 4.990712519865659, 3.953792945031292, 2.9769645215846507, 1.965133328071282, 1.025500583204664, 1.9566485813109278, 2.9036179670863125, 3.8288184104897773, 4.809656355198383, 5.865310694409819, 6.803793162392653, 7.801460275766906, 8.801909661377806, 9.170671965425125, 10.099355169585097, 9.030673352131307, 8.070990578836152, 7.137718317887738, 6.150164414160535, 5.180754288253419, 4.123341396135135, 3.0593343577326735, 1.9860440208690793, 0.9897498045450986, 0.0, 1.0735001685258518, 2.119998874968413, 3.140726669154832, 4.11995428384129, 5.078252744715909, 6.062800156949724, 7.086380928353735, 8.13635981236213, 9.961359000335126, 10.895753984501374, 9.966140161781695, 9.002287893038098, 8.057874752357188, 7.063138758080968, 6.089484904391954, 5.048036620882902, 4.010883562630018, 3.039525668223952, 1.9978027635463311, 1.0420179693302456, 2.0484287791940963, 3.082189343204766, 4.075814206100921, 5.063452823814679, 6.009565800826174, 6.979812384172928, 7.944798450789153, 8.98718652754098, 10.886575528319074, 11.847805277879688, 10.905597105053314, 9.97521127625688, 8.993070435794245, 8.024301399620178, 7.026982677716985, 6.033999969347765, 4.963583025577785, 4.023420915351468, 3.0400015460913328, 2.08965095590855, 3.037052380885911, 3.999877597833552, 4.983871267655652, 5.92388894363832, 6.956379964263929, 7.968262497040799, 8.952499231242777, 9.895192822172623, 11.832424795866345, 12.790458176406272, 11.83280003836442, 10.937910363073593, 9.930510459802184, 9.059752379432798, 8.012727397100443, 6.9683727851527415, 5.896568629918992, 4.9585234349729665, 4.0118403146400246, 3.03925190344458, 3.994942386677278, 5.013887777539288, 5.935723655492666, 6.902976208886965, 7.915698244304865, 8.858187660330037, 9.844534821201291, 10.89378197946301, 12.697128004504048, 13.748625161752342, 12.851845186683967, 11.860834340291607, 10.809856672136473, 9.835751090606072, 8.787177520318908, 7.804556150897215, 6.837133470498292, 5.89267671684383, 4.967326596610114, 4.08667294196711, 4.925632991924952, 5.936174484377713, 6.95077036051384, 7.840571623776, 8.913024127214785, 9.92958286961058, 10.797290135213949, 11.731430199460265, 13.62788281202293, 14.657385346465144, 13.708154546803588, 12.724367617272417, 11.724609207810973, 10.725652728310147, 9.745958451586695, 8.773867539599863, 7.819446338683589, 6.891702449497514, 5.9049788356218755, 5.090459854868745, 5.963546571781931, 6.967367487908806, 7.980919359671835, 8.832293500902624, 9.837157106217258, 10.910317907574864, 11.811599605389286, 12.662991429227048, 14.580944237696217, 15.527817523094352, 14.67664210694953, 13.656551715631434, 12.648164779178014, 11.69304073738927, 10.736739549519724, 9.743823124178691, 8.76325700189437, 7.845786832940319, 6.914628465138433, 6.1619131111923355, 7.012135196634942, 7.915295521959994, 8.921668509126365, 9.881472020622427, 10.797349837526477, 11.762022475282464, 12.722825926225404, 13.627201820192806, 15.541282650948334, 16.521995642048047, 15.593289147359577, 14.656373967376128, 13.582101044229656, 12.743615746250727, 11.689282533439151, 10.76511192699853, 9.77896753702321, 8.824041921758386, 7.886710343052044, 7.098006978106288, 8.006968186844427, 8.97331954113276, 9.914408547178752, 10.817000884374316, 11.759591791113717, 12.74019530116707, 13.782285054841358, 14.577093283059614, 16.569035645623185, 17.54101463282355, 16.57546945156676, 15.583273879749125, 14.549692517631541, 13.652429203630055, 12.696909121440926, 11.733362179393104, 10.774450630234236, 9.8708409951372, 8.83129349192905, 8.0614626011191, 9.035376526117966, 9.988576338622062, 10.93964015536632, 11.845979676661402, 12.726236526071018, 13.728650134437665, 14.741140975094593, 15.600450030909405], [15.496100508661335, 14.546455995541786, 13.553113659997797, 12.593321506456226, 11.79034821273652, 10.830740793881636, 9.91396761401809, 8.969055644830622, 9.758718604022738, 10.682327160618874, 11.669892997556124, 11.695773102569401, 10.947129988150458, 11.78264239613242, 12.72778310811289, 13.698818935369552, 14.430103833335181, 15.329402705518248, 16.269265758562188, 16.505713442298724, 16.4675759745752, 15.522491880221942, 14.583919971006639, 13.53371958544417, 12.777926948718676, 11.876696100312737, 10.853860818096026, 9.969423912173761, 10.735637844451022, 11.674480863534123, 11.683123216344612, 10.753490206943347, 9.881562787770473, 10.830705115662816, 11.800817715300154, 12.636610093906139, 13.357990234669213, 14.385655914692935, 15.336469627039522, 16.12905862866897, 16.12900221566723, 16.523147702010753, 15.560478815455028, 14.562613458597134, 13.787030710007198, 12.865034546812042, 11.877462489583776, 11.01864638974724, 11.711062154610927, 11.6152020749884, 10.781917188376365, 9.815990761014028, 8.86000287211344, 9.808586868186149, 10.781586758052915, 11.58563446927793, 12.37604481705947, 13.41537764411792, 14.34442612957277, 15.19129207785728, 15.096008369044815, 16.134416521742793, 16.474935246961493, 15.525124082589421, 14.739980606071866, 13.81851856928043, 12.834899066170653, 12.075597052306264, 11.60773279103479, 10.661635724130807, 9.715153458838602, 8.803627056535587, 7.8930980724605355, 8.855106876670035, 9.903220997640162, 10.57063165057247, 11.422378600793339, 12.360508222782888, 13.292478270347345, 14.20443800569744, 14.150985068779312, 15.182669268073308, 16.150511842127635, 15.345493488587406, 14.381286622124128, 13.447638693415575, 12.458587048140554, 11.515851134517733, 10.64584458392568, 9.627641385825564, 8.773925980637514, 7.873535302047794, 6.917125452983694, 7.928498538911497, 8.840886025359545, 9.609047415067383, 10.442165179622352, 11.449430322881296, 12.272493311470736, 13.213084464751123, 13.320012354932208, 14.275218356428939, 15.266625370032191, 14.5762091038977, 13.560401887199225, 12.622794827484029, 11.58253500063507, 10.590602493732487, 9.63562591502357, 8.649974061403565, 7.7153840725457705, 6.851491725994866, 5.915765818943254, 6.88717701965741, 7.811428148571667, 8.650425986230157, 9.486436643146014, 10.401369388449325, 11.337934598946728, 12.38938424422129, 12.369518427586206, 13.345103923767995, 14.40866826366411, 13.587005674909008, 12.610733423054937, 11.594743590404828, 10.576188196820286, 9.644508547016176, 8.686352482641489, 7.7725019055088955, 6.766716715324072, 5.800935711536542, 4.870455173106076, 5.916292839187989, 6.753291954047267, 7.658326176687192, 8.553602613628769, 9.466749524802763, 10.432210159236355, 11.437564095630172, 11.598712349567759, 12.589379932466516, 13.53699063137165, 12.597777243817772, 11.577020203289795, 10.609280914562822, 9.622620855995542, 8.761219442420137, 7.744536592413225, 6.777334122870684, 5.824174955107727, 4.86849648586074, 3.9383608372440904, 4.86761003386531, 5.78304211151046, 6.642345705907689, 7.589670295806349, 8.521527976084872, 9.546783496093239, 10.538039807836688, 10.7976761145677, 11.708348261737488, 12.68713327583424, 11.68750220631817, 10.660761018287836, 9.642057385141637, 8.617986600800034, 7.692539211179553, 6.733378120441456, 5.814272072521331, 4.870469677463495, 3.917328996983837, 2.995696198256698, 3.8735118410280207, 4.767440208960874, 5.705179614279658, 6.709828139367179, 7.653258879511223, 8.690227816883164, 9.749558560507273, 9.79118406985759, 10.734158021231476, 11.780810128590625, 10.738935432109622, 9.75554434595359, 8.75935808900857, 7.684773052881278, 6.749366844654432, 5.7795651527411325, 4.844169640497198, 3.890852048229445, 2.915913014227864, 1.9823599737269944, 2.915912818496556, 3.7787382137992207, 4.767114722636017, 5.8410869481692576, 6.855609088912459, 7.810526006055581, 8.798445247811536, 8.824552644661154, 9.774714394044159, 10.755687256106931, 9.985711054185407, 9.043812574412172, 7.977584850288959, 7.031940224525089, 5.982435517095516, 4.945515942261149, 3.9686875188145088, 2.9415455902648304, 1.8855513561325914, 0.9544033580263275, 1.901372743801712, 2.8265731872051765, 3.8074111319137818, 4.863065471125218, 5.801547939108052, 6.799215052482305, 7.799664438093206, 8.097171796899271, 9.166717368763123, 10.104173520657161, 9.144490747362006, 8.21121848641359, 7.2236645826863874, 6.254254456779271, 5.196841564660987, 4.1328345262585255, 3.059544189394931, 2.0632499730709504, 1.0735001685258518, 0.0, 1.046498706442561, 2.06722650062898, 3.046454115315438, 4.004752576190057, 4.989299988423872, 6.012880759827883, 7.062859643836277, 8.887858831809273, 9.900784266131012, 10.830398088850691, 10.075788061563951, 9.103912691612774, 8.109176697336553, 7.135522843647539, 6.094074560138488, 5.056921501885603, 4.085563607479537, 3.0264147188009467, 2.02812310864819, 0.9749286106682444, 2.0086891746789144, 3.0023140375750685, 3.9899526552888274, 4.936065632300322, 5.906312215647076, 6.871298282263301, 7.913686359015127, 9.81307535979322, 10.774305109353834, 11.76985503212231, 11.02843985154473, 10.03910837504983, 8.984952478820423, 7.94890568928973, 6.95592298092051, 5.88550603715053, 4.9083772375684696, 3.924957868308334, 2.915400759537866, 1.967999334560505, 2.930824551508146, 3.9148182213302465, 4.854835897312915, 5.887326917938525, 6.894762328514947, 7.878999062716924, 8.82169265364677, 10.758924627340491, 11.716958007880418, 12.697057965433416, 11.991138938361443, 10.97654839905777, 9.976031574348994, 8.92316797017933, 7.878813358231628, 6.807009202997879, 5.843479757189968, 4.8642771016669, 3.8650017070738962, 2.927001009303843, 3.9459464001658526, 4.86667060916726, 5.833923162561559, 6.846645197979459, 7.78913461400463, 8.775481774875884, 9.824728933137603, 11.62807495817864, 12.675124993226488, 13.657187563857542, 12.713271127318484, 11.66229345916335, 10.688187877632949, 9.639614307345784, 8.656992937924091, 7.689570257525167, 6.745113503870706, 5.81976338363699, 4.890451210413492, 3.857691614551517, 4.868233107004278, 5.881717314188434, 6.771518577450594, 7.843971080889378, 8.860529823285173, 9.728237088888541, 10.662377153134857, 12.558829765697523, 13.588332300139736, 14.560591333830464, 13.576804404299294, 12.57704599483785, 11.578089515337023, 10.598395238613572, 9.626304326626737, 8.671883125710464, 7.74413923652439, 6.75741562264875, 5.853134021978824, 4.895605194408496, 5.899426110535371, 6.9129779822984, 7.763240454577219, 8.768104059891854, 9.84126486124946, 10.742546559063879, 11.59393838290164, 13.51189119137081, 14.458764476768945, 15.444796250770867, 14.50898850265831, 13.50060156620489, 12.545477524416146, 11.5891763365466, 10.596259911205566, 9.615693788921245, 8.698223619967193, 7.767065252165308, 6.872763036724101, 5.944193819261507, 6.847354144586559, 7.85372713175293, 8.812418974297023, 9.728296791201073, 10.69296942895706, 11.6537728799, 12.558148773867398, 14.472229604622926, 15.452942595722638, 16.41411862845192, 15.508810754403004, 14.434537831256533, 13.596052533277605, 12.54171932046603, 11.617548714025405, 10.631404324050084, 9.676478708785261, 8.73914713007892, 7.808856903638054, 6.939026809470991, 7.905378163759324, 8.846467169805317, 9.747947838048912, 10.690538744788313, 11.671142254841666, 12.713232008515954, 13.508040236734207, 15.499982599297777, 16.47196158649814, 16.37396010574644, 15.381764533928806, 14.656117290350663, 13.705087334306704, 12.768292253345471, 11.991744432946206, 11.626887417261111, 10.723277782164075, 9.683730278955926, 8.772312526650865, 7.9674351487445305, 8.920634961248627, 9.871698777992885, 10.776926630335998, 11.657183479745614, 12.65959708811226, 13.672087928769189, 14.531396984583997], [14.512831746354317, 13.563187233234768, 12.569844897690778, 11.610052744149208, 10.807079450429502, 9.932358428067987, 9.112069157850593, 10.005170605032578, 10.794833564224696, 11.718442120820834, 12.706007957758084, 12.670015187710705, 11.92137207329176, 11.030520808554922, 11.881820725196782, 12.782487166269119, 13.510407146925715, 14.409706019108782, 15.349569072152722, 15.494460608766515, 15.484307212268183, 14.539223117914924, 13.60065120869962, 12.550450823137151, 11.794658186411658, 10.978313734499087, 10.05196236192853, 10.987188093483221, 11.77175280465298, 12.710595823736083, 12.657365301485916, 11.727732292084651, 10.855804872911776, 10.078583528085318, 10.954855332384046, 11.716913407496673, 12.438293548259747, 13.465959228283468, 14.416772940630056, 15.209361942259504, 15.209305529257765, 15.539878939703737, 14.57721005314801, 13.579344696290116, 12.80376194770018, 11.966652180998393, 11.07556403341628, 12.036410571056699, 12.747177114812885, 12.589444160129702, 11.756159273517667, 10.790232846155332, 9.834244957254743, 9.056465280608652, 9.935624375136808, 10.665937782868463, 11.456348130650003, 12.495680957708453, 13.424729443163304, 14.271595391447814, 14.17631168263535, 15.214719835333327, 15.491666484654477, 14.541855320282403, 13.756711843764847, 12.990423607084335, 12.033000610003157, 13.032085409522931, 12.581974876176092, 11.63587780927211, 10.689395543979904, 9.777869141676891, 8.867340157601838, 8.009605071641008, 8.991318213624421, 9.650934964163003, 10.502681914383873, 11.440811536373422, 12.37278158393788, 13.284741319287974, 13.231288382369845, 14.262972581663842, 15.230815155718169, 15.580728492263908, 14.816344546379312, 13.99443193288796, 13.043053283206142, 12.490093219659036, 11.620086669066982, 10.601883470966866, 9.748168065778817, 8.847777387189097, 7.891367538124996, 7.08299673388247, 7.921189338950079, 8.689350728657917, 9.522468493212886, 10.52973363647183, 11.35279662506127, 12.293387778341657, 12.400315668522742, 13.355521670019472, 14.346928683622725, 15.3748538851214, 14.534643972340527, 13.597036912625331, 12.556777085776373, 11.564844578873789, 10.609868000164873, 9.624216146544867, 8.689626157687073, 7.8257338111361685, 6.890007904084556, 6.041675214628383, 6.891731462162201, 7.73072929982069, 8.566739956736548, 9.481672702039859, 10.418237912537261, 11.469687557811824, 11.44982174117674, 12.42540723735853, 13.488971577254643, 14.5526677853221, 13.584975508196239, 12.56898567554613, 11.550430281961589, 10.618750632157479, 9.660594567782791, 8.746743990650197, 7.740958800465374, 6.775177796677844, 5.844697258247378, 5.0479323793135915, 5.833595267637801, 6.7386294902777255, 7.633905927219302, 8.547052838393297, 9.512513472826889, 10.517867409220706, 10.679015663158292, 11.66968324605705, 12.617293944962183, 13.572019328959074, 12.551262288431097, 11.583522999704124, 10.596862941136845, 9.735461527561439, 8.718778677554527, 7.751576208011986, 6.79841704024903, 5.842738571002042, 4.912602922385393, 3.979772149733243, 4.863345425100994, 5.722649019498223, 6.669973609396883, 7.601831289675407, 8.627086809683773, 9.618343121427221, 9.877979428158234, 10.78865157532802, 11.767436589424772, 12.661744291459472, 11.635003103429138, 10.61629947028294, 9.592228685941336, 8.666781296320854, 7.707620205582757, 6.788514157662632, 5.844711762604796, 4.8915710821251395, 3.9699382833979997, 2.985673956895954, 3.8477435225514074, 4.785482927870191, 5.790131452957713, 6.733562193101757, 7.770531130473698, 8.829861874097807, 8.871487383448121, 9.814461334822008, 10.861113442181157, 11.713177517250925, 10.729786431094892, 9.733600174149872, 8.65901513802258, 7.723608929795733, 6.753807237882434, 5.8184117256385, 4.8650941333707465, 3.8901550993691663, 2.956602058868296, 2.028074934364489, 2.8590415273897536, 3.8474180362265504, 4.921390261759791, 5.935912402502993, 6.890829319646115, 7.87874856140207, 7.9048559582516855, 8.85501770763469, 9.835990569697463, 10.843777016169506, 10.018054659553473, 8.95182693543026, 8.00618230966639, 6.956677602236818, 5.919758027402451, 4.94292960395581, 3.9157876754061323, 2.8597934412738932, 1.9286454431676292, 0.9816760573922446, 1.9068765007957094, 2.8877144455043147, 3.9433687847157506, 4.881851252698585, 5.879518366072838, 6.879967751683739, 7.050673090456711, 8.120218662320562, 9.188900479774352, 10.148583253069507, 9.257717192856152, 8.270163289128948, 7.300753163221832, 6.243340271103548, 5.179333232701087, 4.106042895837493, 3.109748679513512, 2.119998874968413, 1.046498706442561, 0.0, 1.020727794186419, 1.9999554088728773, 2.9582538697474967, 3.9428012819813114, 4.966382053385323, 6.016360937393717, 7.841360125366714, 8.854285559688453, 9.783899382408132, 10.836483954563194, 10.150411398055335, 9.155675403779114, 8.1820215500901, 7.140573266581049, 6.103420208328164, 5.132062313922098, 4.072913425243508, 3.0746218150907505, 2.0214273171108053, 0.9991265997298772, 1.9927514626260314, 2.943453948846267, 3.889566925857762, 4.859813509204517, 5.824799575820742, 6.867187652572568, 8.766576653350661, 9.727806402911275, 10.72335632567975, 11.665095787119387, 11.085476754383809, 10.021067439022383, 8.985020649491691, 7.9920379411224705, 6.92162099735249, 5.94449219777043, 4.961072828510294, 3.9515157197398256, 3.0041142947624646, 2.0412890778148234, 2.9315494590232283, 3.871567135005897, 4.855706117365596, 5.848263622072388, 6.832500356274365, 7.775193947204211, 9.712425920897932, 10.670459301437859, 11.650559258990857, 12.612350901763142, 12.018072605856997, 11.012146534550954, 9.95928293038129, 8.914928318433589, 7.843124163199839, 6.879594717391928, 5.9003920618688595, 4.901116667275856, 3.963115969505803, 3.07155928510484, 3.8834018468602416, 4.850654400254541, 5.835392364447247, 6.777881780472418, 7.7642289413436725, 8.813476099605392, 10.61682212464643, 11.628626286783929, 12.610688857414983, 13.53812088072799, 12.698408419365308, 11.724302837834907, 10.675729267547743, 9.69310789812605, 8.725685217727126, 7.781228464072665, 6.855878343838949, 5.92656617061545, 4.8938065747534765, 4.066334650836782, 4.898448551881415, 5.788249815143576, 6.858749253218987, 7.849276989752962, 8.71698425535633, 9.651124319602646, 11.547576932165311, 12.577079466607525, 13.615401402180016, 14.496053688127466, 13.613160955039808, 12.614204475538981, 11.63451019881553, 10.662419286828696, 9.707998085912422, 8.780254196726348, 7.79353058285071, 6.889248982180782, 5.9317201546104545, 5.097527654367875, 5.931598871679883, 6.779971692270201, 7.784835297584836, 8.857996098942442, 9.731293725531668, 10.58268554936943, 12.500638357838598, 13.447511643236734, 14.433543417238656, 15.428237786486482, 14.536716526406849, 13.581592484618104, 12.625291296748559, 11.632374871407524, 10.651808749123203, 9.734338580169153, 8.803180212367268, 7.908877996926059, 6.980308779463465, 6.045455688419063, 6.955344765939281, 7.8291502119900045, 8.745028028894055, 9.709700666650042, 10.670504117592982, 11.546895940335187, 13.460976771090715, 14.441689762190427, 15.402865794919707, 15.394759559686538, 14.707376994652115, 13.928615122649706, 13.023797253769748, 12.653663674227364, 11.667519284252043, 10.712593668987221, 9.77526209028088, 8.844971863840012, 7.975141769672949, 7.103479707591828, 7.948084803991668, 8.764679075741894, 9.707269982481295, 10.687873492534647, 11.729963246208936, 12.496787403201996, 14.488729765765566, 15.46070875296593, 15.454263419336975, 14.46206784751934, 13.73978552125023, 12.859124951390596, 12.016170665767973, 12.965986518087508, 12.66300237746307, 11.759392742366035, 10.719845239157886, 9.808427486852823, 9.003550108946488, 8.11873650508113, 8.973316412179235, 9.79365786802898, 10.673914717438596, 11.676328325805242, 12.68881916646217, 13.520144151051786], [13.503011391035166, 12.553366877915616, 11.560024542371627, 10.600232388830056, 9.79725909511035, 8.96851162530671, 9.982793528228548, 10.894542156959133, 11.684205116151249, 12.628849369090062, 13.616415206027312, 13.629622904334624, 12.88097978991568, 11.933207306995776, 10.991027555013773, 11.891693996086108, 12.619613976742706, 13.518912848925773, 14.458775901969712, 14.473732814580096, 14.474486856949031, 13.529402762595772, 12.590830853380469, 11.540630467818, 10.784837831092506, 10.014466931737811, 10.922686732306484, 11.857912463861176, 12.661124356579533, 13.621003072005312, 13.616973018109835, 12.68734000870857, 11.815412589535695, 10.981270026526172, 10.064062162201036, 10.826120237313662, 11.547500378076737, 12.575166058100459, 13.525979770447046, 14.318568772076494, 14.318512359074756, 14.530058584384586, 13.567389697828858, 12.569524340970965, 11.793941592381028, 11.002805378237117, 11.946288403794235, 12.907134941434654, 13.636548666739438, 13.549051876753623, 12.715766990141589, 11.749840562779251, 10.793852673878662, 9.959151779049504, 9.044831204953798, 9.775144612685452, 10.565554960466994, 11.604887787525444, 12.533936272980295, 13.380802221264805, 13.28551851245234, 14.323926665150317, 14.481846129335326, 13.532034964963252, 12.746891488445696, 12.026576804323058, 12.90372498038111, 13.902809779900885, 13.541582592800014, 12.59548552589603, 11.649003260603825, 10.737476858300811, 9.826947874225757, 8.91229157008186, 8.100525043441412, 8.760141793979992, 9.611888744200863, 10.550018366190413, 11.48198841375487, 12.393948149104965, 12.340495212186836, 13.372179411480833, 14.34002198553516, 14.570908136944757, 13.80652419106016, 13.030585130126685, 13.913777653584095, 13.449700936282957, 12.579694385690903, 11.561491187590788, 10.707775782402738, 9.807385103813017, 8.850975254748915, 7.985683232323321, 7.030396168767069, 7.798557558474907, 8.631675323029876, 9.63894046628882, 10.46200345487826, 11.402594608158648, 11.509522498339733, 12.464728499836463, 13.456135513439715, 14.48406071493839, 14.877626074847013, 13.964177440949587, 13.516384802400292, 12.52445229549771, 11.569475716788794, 10.583823863168789, 9.649233874310994, 8.785341527760089, 7.849615620708477, 6.9443617130692346, 6.0009382919791925, 6.839936129637681, 7.6759467865535385, 8.59087953185685, 9.527444742354252, 10.578894387628814, 10.559028570993732, 11.534614067175522, 12.598178407071636, 13.661874615139093, 14.544583224820158, 13.52859339217005, 12.510037998585508, 11.5783583487814, 10.620202284406712, 9.706351707274118, 8.700566517089294, 7.734785513301764, 6.8043049748712985, 5.950618877754443, 4.942802097454792, 5.847836320094716, 6.743112757036293, 7.656259668210288, 8.621720302643881, 9.627074239037698, 9.788222492975283, 10.77889007587404, 11.7127937421477, 12.724473259273184, 13.510870005055017, 12.543130716328044, 11.556470657760764, 10.695069244185358, 9.678386394178448, 8.711183924635908, 7.75802475687295, 6.802346287625962, 5.872210639009313, 4.904657268195467, 3.9725522549179857, 4.831855849315215, 5.779180439213874, 6.7110381194923985, 7.736293639500764, 8.727549951244212, 8.870382193764213, 9.781054340934, 10.759839355030753, 11.776091925126142, 12.594610820053056, 11.575907186906857, 10.551836402565256, 9.626389012944774, 8.667227922206678, 7.748121874286554, 6.804319479228718, 5.85117879874906, 4.9295460000219204, 3.9105590753581776, 2.956950352368399, 3.894689757687183, 4.899338282774704, 5.842769022918748, 6.847707812319372, 7.9070385559434815, 7.863890149054101, 8.806864100427989, 9.853516207787138, 10.834382546126077, 11.689394147718811, 10.693207890773792, 9.6186228546465, 8.683216646419654, 7.713414954506355, 6.778019442262421, 5.824701849994668, 4.849762815993087, 3.916209775492217, 2.9876826509884093, 1.968248357206745, 2.9117050446078676, 3.9549165010288942, 4.944868471811622, 5.8997853889547445, 6.884018732681538, 6.897258723857664, 7.8474204732406685, 8.82839333530344, 9.836179781775483, 10.778078261548718, 9.911434652054181, 8.96579002629031, 7.916285318860739, 6.879365744026372, 5.902537320579731, 4.875395392030053, 3.819401157897814, 2.88825315979155, 1.9412837740161653, 1.0160833306127006, 1.952001453885632, 2.93577155032173, 3.8742540183045637, 4.871921131678817, 5.872370517289718, 6.029945296270292, 7.0994908681341435, 8.168172685587933, 9.127855458883088, 10.061127719831504, 9.290891083315366, 8.32148095740825, 7.264068065289967, 6.200061026887505, 5.126770690023911, 4.130476473699931, 3.140726669154832, 2.06722650062898, 1.020727794186419, 0.0, 0.9792276146864582, 1.9375260755610775, 2.922073487794892, 3.9456542591989043, 4.995633143207298, 6.8206323311802945, 7.833557765502034, 8.763171588221713, 9.815756160376775, 10.79345021318781, 10.176403197965532, 9.20274934427652, 8.161301060767467, 7.124148002514583, 6.152790108108517, 5.0936412194299265, 4.09534960927717, 3.042155111297224, 2.019854393916296, 1.028904659864755, 1.922726154659848, 2.8688391316713426, 3.8390857150180975, 4.804071781634322, 5.846459858386148, 7.7458488591642425, 8.707078608724856, 9.702628531493332, 10.644367992932969, 11.633699469427869, 10.93147468729161, 9.895427897760918, 8.902445189391699, 7.832028245621719, 6.854899446039658, 5.871480076779522, 4.861922968009054, 3.914521543031693, 2.9516963260840523, 1.967702656261952, 2.8602529440197073, 3.8349783231791768, 4.827535827885969, 5.8117725620879455, 6.754466153017791, 8.691698126711515, 9.649731507251442, 10.629831464804438, 11.591623107576723, 12.571139493435808, 11.922553782820183, 10.869690178650519, 9.825335566702817, 8.753531411469067, 7.7900019656611565, 6.810799310138088, 5.811523915545084, 4.873523217775031, 3.9695374253400413, 2.9195550440989653, 3.840834044935389, 4.8146645702608275, 5.757153986285998, 6.743501147157253, 7.7927483054189715, 9.59609433046001, 10.607898492597512, 11.589961063228566, 12.51739308654157, 13.568370754696705, 12.634710086104135, 11.586136515816971, 10.603515146395278, 9.636092465996354, 8.691635712341894, 7.7662855921081775, 6.8369734188846785, 5.804213823022705, 4.9643127910719835, 3.934601749120139, 4.778429459824425, 5.838021459032567, 6.828549195566542, 7.696256461169911, 8.630396525416227, 10.526849137978893, 11.556351672421107, 12.594673607993595, 13.475325893941047, 14.475084303402491, 13.52461172380821, 12.544917447084758, 11.572826535097924, 10.61840533418165, 9.690661444995577, 8.703937831119939, 7.799656230450011, 6.842127402879683, 5.981303940681635, 4.967752068918607, 5.7701513369510495, 6.775014942265685, 7.847352895422612, 8.710565931345249, 9.56195775518301, 11.47991056365218, 12.426783849050315, 13.412815623052238, 14.407509992300064, 14.750520089520746, 14.095089597841852, 13.535698545017787, 12.542782119676753, 11.562215997392432, 10.644745828438381, 9.713587460636496, 8.798249548852612, 7.869680331390017, 6.929231974732824, 5.991497963178005, 6.819329856670853, 7.735207673574903, 8.69988031133089, 9.66068376227383, 10.526168146148768, 12.440248976904297, 13.420961968004008, 14.382138000733288, 14.503966389503528, 13.816583824469104, 13.037821952466697, 13.926483752210602, 13.564070922496592, 12.577926532521271, 11.62300091725645, 10.685669338550108, 9.734343415766565, 8.864513321599501, 7.987255993905589, 6.984238001230391, 7.754858720422742, 8.697449627162143, 9.678053137215496, 10.720142890889784, 11.476059609015577, 13.468001971579147, 14.439980958779511, 14.563470249153966, 13.57127467733633, 12.848992351067219, 11.968331781207587, 12.918857164208827, 13.92559423471143, 13.573409625732298, 12.669799990635262, 11.630252487427114, 10.697799038779376, 9.892921660873041, 8.994491283468097, 8.009469609417959, 8.783837512709828, 9.664094362119444, 10.66650797048609, 11.67899881114302, 12.499416356865368], [12.523783776348704, 11.574139263229155, 10.580796927685165, 9.621004774143595, 8.81803148042389, 9.79742787721059, 10.811709780132427, 11.747882506013099, 12.537545465205215, 13.482189718144028, 14.469755555081278, 14.55745456283527, 13.686330780584413, 12.696337881942311, 11.739738351087734, 10.915413046504696, 11.643333027161294, 12.542631899344359, 13.482494952388299, 13.494505199893638, 13.49525924226257, 12.55017514790931, 11.611603238694007, 10.561402853131538, 9.805610216406047, 10.78282342935685, 11.751602984210363, 12.686828715765055, 13.514464705633499, 14.474343421059277, 14.54480467661048, 13.615171667209216, 12.706686042722778, 11.788660138371192, 10.812772958274998, 9.84983928773225, 10.571219428495326, 11.598885108519045, 12.549698820865633, 13.34228782249508, 13.342231409493344, 13.550830969698124, 12.588162083142397, 11.590296726284503, 10.814713977694568, 11.771161875856155, 12.775204655698113, 13.736051193338533, 14.489889015793404, 14.486580330048701, 13.653295443436667, 12.677672221279897, 11.685126127065745, 10.766541890894526, 9.79354200102776, 8.79886366310404, 9.589274010885582, 10.62860683794403, 11.557655323398881, 12.404521271683391, 12.309237562870926, 13.347645715568904, 13.502618514648864, 12.55280735027679, 11.767663873759236, 12.794933301942097, 13.73264123228499, 14.731726031804765, 14.479111046095092, 13.533013979191109, 12.586531713898903, 11.665308516801456, 10.71822132741284, 9.737407730194029, 8.849235839515373, 7.783860844398579, 8.63560779461945, 9.573737416609, 10.505707464173456, 11.417667199523551, 11.364214262605422, 12.395898461899417, 13.363741035953744, 13.591680522258295, 12.827296576373701, 13.760944505082254, 14.742693905487975, 14.387229389578035, 13.517222838985981, 12.499019640885866, 11.645304235697816, 10.735216762313662, 9.742248707935998, 8.81079939243549, 7.77910696484103, 6.822276608893493, 7.655394373448463, 8.662659516707407, 9.485722505296847, 10.426313658577234, 10.53324154875832, 11.488447550255051, 12.479854563858304, 13.507779765356979, 13.898398460160555, 14.694536815905156, 14.45391325569537, 13.461980748792788, 12.507004170083873, 11.521352316463867, 10.586762327606072, 9.722869981055167, 8.74088907389556, 7.769477873181403, 6.826054452091361, 5.863655180056267, 6.699665836972125, 7.614598582275436, 8.551163792772838, 9.602613438047403, 9.582747621412318, 10.558333117594108, 11.621897457490222, 12.685593665557679, 13.661865917411752, 14.466121845465128, 13.447566451880586, 12.515886802076478, 11.55773073770179, 10.643880160569196, 9.638094970384373, 8.672313966596843, 7.741833428166377, 6.775735037866611, 5.7679182575669605, 4.871555370513303, 5.766831807454879, 6.679978718628874, 7.645439353062467, 8.650793289456285, 8.811941543393868, 9.802609126292625, 10.733566127461241, 11.745245644586726, 12.766002685114703, 13.480659169623122, 12.493999111055842, 11.632597697480438, 10.615914847473526, 9.648712377930986, 8.695553210168029, 7.73987474092104, 6.809739092304391, 5.781943489422289, 4.797668415030154, 3.8555748997338006, 4.80289948963246, 5.734757169910984, 6.76001268991935, 7.751269001662798, 7.891154579077755, 8.801826726247542, 9.780611740344295, 10.796864310439684, 11.793481921957238, 12.513435640201937, 11.489364855860334, 10.563917466239854, 9.604756375501756, 8.685650327581632, 7.741847932523796, 6.788707252044138, 5.867074453316999, 4.809756936414331, 3.856148213424553, 2.918408808105769, 3.9230573331932903, 4.866488073337335, 5.868480197632914, 6.9278109412570235, 6.884662534367643, 7.82763648574153, 8.87428859310068, 9.85515493143962, 10.742811642355658, 11.63073634406887, 10.556151307941578, 9.620745099714732, 8.650943407801433, 7.715547895557499, 6.762230303289746, 5.787291269288165, 4.853738228787295, 3.9252111042834876, 2.9057768105018233, 1.9324774299214096, 2.9756888863424362, 3.965640857125164, 4.920557774268286, 5.90479111799508, 5.918031109171206, 6.8681928585542105, 7.849165720616982, 8.856952167089025, 9.79885064686226, 10.84896310534926, 9.903318479585389, 8.853813772155817, 7.81689419732145, 6.84006577387481, 5.812923845325131, 4.756929611192892, 3.8257816130866282, 2.8788122273112435, 1.9536117839077791, 0.9727738391991738, 1.9565439356352718, 2.8950264036181057, 3.8926935169923587, 4.89314290260326, 5.050717681583834, 6.1202632534476855, 7.188945070901475, 8.14862784419663, 9.081900105145046, 10.069454008872249, 9.300708572094708, 8.243295679976425, 7.179288641573963, 6.105998304710369, 5.109704088386389, 4.11995428384129, 3.0464541153154383, 1.9999554088728773, 0.9792276146864582, 0.0, 0.9582984608746193, 1.942845873108434, 2.966426644512446, 4.01640552852084, 5.8414047164938365, 6.854330150815576, 7.783943973535255, 8.836528545690317, 9.814222598501352, 10.808958592777573, 10.155396437785528, 9.113948154276477, 8.076795096023591, 7.105437201617525, 6.046288312938934, 5.047996702786177, 3.9948022048062324, 2.9610416407955626, 1.9674167778994083, 0.9434985399733897, 1.8896115169848842, 2.859858100331639, 3.8248441669478637, 4.86723224369969, 6.7666212444777845, 7.727850994038398, 8.723400916806874, 9.66514037824651, 10.654471854741411, 11.718881170102836, 10.748768246814883, 9.755785538445664, 8.685368594675685, 7.708239795093625, 6.724820425833489, 5.7152633170630205, 4.7678618920856595, 3.8050366751380182, 2.821043005315918, 1.8810253293332493, 2.8557507084927183, 3.8483082131995103, 4.832544947401487, 5.775238538331333, 7.712470512025056, 8.670503892564982, 9.65060385011798, 10.612395492890265, 11.59191187874935, 12.597837950055393, 11.723030527704484, 10.678675915756783, 9.606871760523033, 8.643342314715122, 7.664139659192054, 6.664864264599051, 5.726863566828998, 4.822877774394008, 3.772895393152931, 2.861606430248931, 3.8354369555743695, 4.77792637159954, 5.764273532470795, 6.813520690732513, 8.616866715773552, 9.628670877911052, 10.610733448542106, 11.538165471855113, 12.589143140010247, 13.488050435158101, 12.439476864870937, 11.456855495449243, 10.48943281505032, 9.54497606139586, 8.619625941162143, 7.690313767938646, 6.657554172076672, 5.81765314012595, 4.7879420981741045, 3.7992018451379663, 4.858793844346109, 5.849321580880084, 6.717028846483453, 7.651168910729769, 9.547621523292435, 10.577124057734649, 11.615445993307137, 12.49609827925459, 13.495856688716033, 14.377952072862175, 13.398257796138724, 12.42616688415189, 11.471745683235616, 10.544001794049542, 9.557278180173904, 8.652996579503979, 7.69546775193365, 6.834644289735601, 5.821092417972572, 4.790923722264591, 5.795787327579226, 6.868125280736154, 7.731338316658791, 8.582730140496553, 10.500682948965721, 11.447556234363857, 12.43358800836578, 13.428282377613606, 13.774239139939334, 14.729363181728079, 14.389038894071753, 13.396122468730718, 12.415556346446397, 11.498086177492347, 10.566927809690462, 9.651589897906577, 8.723020680443982, 7.782572323786789, 6.835063040507555, 5.840102241984393, 6.7559800588884436, 7.72065269664443, 8.68145614758737, 9.54694053146231, 11.461021362217839, 12.44173435331755, 13.40291038604683, 13.527685439922116, 12.840302874887692, 13.786532748540658, 14.680189247472452, 14.417411271550558, 13.431266881575237, 12.476341266310415, 11.539009687604073, 10.58768376482053, 9.717853670653467, 8.840596342959556, 7.813154253134269, 6.775631105736283, 7.718222012475683, 8.698825522529036, 9.740915276203324, 10.496831994329119, 12.488774356892689, 13.460753344093053, 13.587189299572554, 12.594993727754918, 11.872711401485807, 12.717042577281548, 13.672562659470676, 14.703819086250615, 14.426749974786263, 13.523140339689228, 12.48359283648108, 11.551139387833341, 10.746262009927007, 9.823407535371977, 8.838385861321838, 7.804609898023369, 8.684866747432983, 9.68728035579963, 10.699771196456558, 11.52018874217891], [11.711923391496288, 10.762278878376739, 9.76893654283275, 8.809144389291179, 9.77632994129851, 10.755726338085209, 11.770008241007046, 12.706180966887718, 13.495843926079834, 14.440488179018647, 15.428054015955897, 15.51575302370989, 14.644629241459032, 13.65463634281693, 12.698036811962353, 11.873063248724288, 10.916642717472577, 11.815941589655644, 12.70899847218643, 12.62704591847335, 12.683398857410154, 11.738314763056895, 10.799742853841591, 9.749542468279122, 10.684695873004422, 11.661909085955225, 12.709901445084983, 13.645127176639674, 14.472763166508118, 15.432641881933897, 15.5031031374851, 14.573470128083835, 13.664984503597397, 12.746958599245811, 11.771071419149617, 10.807489489951841, 9.844529118806609, 10.87219479883033, 11.776202340663763, 12.568791342293212, 12.568734929291473, 12.738970584845708, 11.77630169828998, 10.778436341432087, 11.693799634292944, 12.65024753245453, 13.699461245972547, 14.694349654213152, 15.448187476668023, 15.44487879092332, 14.611593904311286, 13.635970682154516, 12.643424587940364, 11.724840351769146, 10.751840461902379, 9.757162123978658, 8.862583701196865, 9.901916528255315, 10.784158843197012, 11.631024791481522, 11.535741082669057, 12.574149235367035, 12.690758129796448, 11.740946965424374, 12.646749530357612, 13.674018958540472, 14.656897822559422, 15.655982622079197, 15.437409506969711, 14.491312440065728, 13.544830174773523, 12.623606977676076, 11.67651978828746, 10.695706191068648, 9.807534300389992, 8.742159305273198, 7.908917484930734, 8.847047106920284, 9.732210983971587, 10.644170719321682, 10.590717782403553, 11.62240198169755, 12.590244555751877, 12.77982013740588, 13.706382232972075, 14.640030161680627, 15.629081806955648, 15.345527850452653, 14.4755212998606, 13.457318101760485, 12.603602696572436, 11.693515223188282, 10.700547168810617, 9.76909785331011, 8.73740542571565, 7.780575069768113, 6.9287040637597475, 7.889163036505538, 8.712226025094978, 9.652817178375365, 9.75974506855645, 10.71495107005318, 11.706358083656433, 12.734283285155108, 13.763058496633619, 14.700665556348815, 15.412211716569988, 14.420279209667406, 13.465302630958492, 12.479650777338486, 11.545060788480692, 10.681168441929787, 9.699187534770179, 8.727776334056022, 7.78435291296598, 6.821953640930887, 5.97297552728341, 6.841102102073567, 7.777667312570969, 8.829116957845532, 8.809251141210447, 9.784836637392237, 10.766418666905949, 11.811040281264626, 12.787312533118698, 13.760001277313963, 14.405864912755204, 13.474185262951096, 12.516029198576408, 11.602178621443816, 10.596393431258992, 9.630612427471462, 8.700131889040996, 7.734033498741231, 6.72621671844158, 5.829853831387922, 5.0401414977661645, 5.906482238427005, 6.871942872860598, 7.877296809254415, 7.861456174307293, 8.85212375720605, 9.775267666586622, 10.786947183712106, 11.807704224240084, 12.774538601471956, 13.45229757193046, 12.590896158355054, 11.574213308348144, 10.607010838805603, 9.653851671042647, 8.698173201795658, 7.768037553179011, 6.740241950296909, 5.7559668759047735, 4.8138733606084205, 4.076209179943746, 4.961260689709115, 5.951552899987395, 6.9300646924631035, 6.932856118203135, 7.843528265372922, 8.822313279469675, 9.838565849565065, 10.835183461082618, 11.792495538772314, 12.447663316734952, 11.52221592711447, 10.563054836376374, 9.64394878845625, 8.700146393398414, 7.747005712918757, 6.825372914191618, 5.768055397288951, 4.814446674299172, 3.8767072689803883, 3.073593130348438, 3.959036637913785, 4.910181736758296, 5.969512480382406, 5.926364073493024, 6.86933802486691, 7.915990132226059, 8.896856470565002, 9.784513181481039, 10.780699438426058, 11.514449768816196, 10.57904356058935, 9.609241868676051, 8.673846356432117, 7.7205287641643645, 6.745589730162783, 5.812036689661914, 4.883509565158107, 3.864075271376443, 2.890775890796029, 2.0173904254678168, 3.007342396250545, 3.9622593133936674, 4.94649265712046, 4.959732648296587, 5.909894397679591, 6.890867259742363, 7.898653706214406, 8.840552185987642, 9.906779910110854, 10.852424535874725, 9.812112233030437, 8.775192658196069, 7.798364234749428, 6.77122230619975, 5.715228072067511, 4.784080073961247, 3.837110688185863, 2.9119102447823986, 1.9310723000737933, 0.9982454747606524, 1.9367279427434865, 2.934395056117739, 3.9348444417286403, 4.092419220709215, 5.161964792573066, 6.230646610026856, 7.19032938332201, 8.123601644270424, 9.111155547997628, 10.080565673904744, 9.201594140851045, 8.137587102448583, 7.064296765584989, 6.068002549261008, 5.078252744715909, 4.004752576190057, 2.9582538697474963, 1.9375260755610775, 0.9582984608746193, 0.0, 0.9845474122338146, 2.0081281836378264, 3.0581070676462208, 4.9364184066872685, 5.949343841009008, 6.878957663728687, 7.93154223588375, 8.909236288694785, 9.903972282971006, 10.87762613666002, 10.072246615151096, 9.035093556898211, 8.063735662492144, 7.004586773813553, 6.006295163660797, 4.953100665680852, 3.9193401016701817, 2.9257152387740275, 1.901797000848009, 1.051720725526574, 1.9548717905250714, 2.919857857141296, 3.962245933893122, 5.861634934671216, 6.82286468423183, 7.818414607000306, 8.760154068439942, 9.749485544934842, 10.813894860296266, 11.707066707689503, 10.714083999320282, 9.643667055550303, 8.666538255968243, 7.683118886708107, 6.673561777937639, 5.726160352960278, 4.763335136012637, 3.779341466190537, 2.8393237902078683, 2.017859917034408, 2.9433219033929428, 3.9275586375949194, 4.870252228524765, 6.807484202218488, 7.765517582758414, 8.745617540311411, 9.707409183083696, 10.686925568942781, 11.692851640248824, 12.681328988579104, 11.636974376631402, 10.565170221397652, 9.601640775589741, 8.622438120066674, 7.623162725473669, 6.685162027703616, 5.781176235268626, 4.73119385402755, 3.81990489112355, 2.9975461641160592, 3.9259722617005854, 4.896814251050506, 5.910919583917644, 7.749407434353263, 8.723684568104485, 9.70574713873554, 10.633179162048544, 11.684156830203678, 12.658262411734079, 13.397775325745556, 12.415153956323863, 11.447731275924939, 10.503274522270479, 9.577924402036762, 8.648612228813263, 7.61585263295129, 6.7759516010005685, 5.746240559048724, 4.757500306012585, 4.020903052887799, 4.997367470981129, 5.849569565063164, 6.78370962930948, 8.680162241872146, 9.70966477631436, 10.747986711886849, 11.59111196944802, 12.590870378909464, 13.58982685841029, 14.356556257013343, 13.38446534502651, 12.430044144110235, 11.502300254924162, 10.515576641048524, 9.611295040378597, 8.653766212808268, 7.79294275061022, 6.779390878847192, 5.74922218313921, 4.983926942726809, 6.016171170837199, 6.863879035238502, 7.715270859076265, 9.633223667545433, 10.580096952943569, 11.566128726945491, 12.523296067807037, 13.590030886022076, 14.54515492781082, 15.347337354946372, 14.354420929605338, 13.373854807321017, 12.456384638366966, 11.525226270565081, 10.609888358781197, 9.681319141318601, 8.740870784661409, 7.793361501382175, 6.798400702859013, 5.944119674036028, 6.9087923117920145, 7.829564247974683, 8.679481250042022, 10.59356208079755, 11.574275071897262, 12.535451104626542, 12.8009951302334, 13.797953077107284, 14.744831209415278, 15.638487708347071, 15.375709732425177, 14.389565342449856, 13.434639727185035, 12.497308148478693, 11.54598222569515, 10.676152131528086, 9.798894803834175, 8.77145271400889, 7.733929566610902, 6.906361627623267, 7.886965137676621, 8.896447805422476, 9.62937271290883, 11.6213150754724, 12.593294062672765, 12.860498989883837, 11.868303418066201, 12.830361603705398, 13.675341038156168, 14.630861120345296, 15.662117547125234, 15.385048435660883, 14.481438800563847, 13.4418912973557, 12.509437848707961, 11.704560470801626, 10.781705996246597, 9.796684322196457, 8.762908358897988, 7.8730063625805675, 8.875419970947215, 9.887910811604144, 10.652729460758621], [10.742933972985293, 9.927256126590972, 9.008650964569783, 9.695512490667062, 10.748979194281036, 11.740273750319025, 12.754555653240862, 13.69072837912153, 14.480391338313648, 15.425035591252461, 16.41260142818971, 16.500300435943704, 15.56840663758223, 14.578413738940128, 13.621814208085551, 12.75405269270775, 11.79763216145604, 10.883602993930918, 11.773078726125998, 11.642498506239535, 11.715333620982731, 10.903292011271128, 10.039457275578625, 10.635910569655005, 11.571063974380305, 12.548277187331108, 13.60930307597918, 14.544528807533872, 15.457310578741932, 16.41718929416771, 16.487650549718914, 15.55801754031765, 14.649531915831211, 13.731506011479627, 12.694848815272815, 11.688478933935304, 10.725518562790072, 9.939856203105604, 10.840282594603332, 11.63287159623278, 11.632815183231042, 11.903947833059942, 11.074288738270555, 11.66480444280797, 12.580167735668827, 13.536615633830413, 14.58582934734843, 15.59375128510735, 16.432734888901837, 16.42942620315714, 15.596141316545102, 14.62051809438833, 13.627972000174179, 12.70938776400296, 11.736387874136193, 10.741709536212474, 9.743573145180328, 8.969577932530589, 9.848239097136581, 10.69510504542109, 10.599821336608626, 11.638229489306603, 12.123413900734874, 12.627315066800257, 13.533117631733495, 14.560387059916355, 15.543265923935305, 16.54235072345508, 16.421956919203527, 15.475859852299545, 14.529377587007339, 13.60815438990989, 12.661067200521273, 11.680253603302463, 10.792081712623807, 9.726706717507014, 8.789906928914196, 7.914708511195558, 8.796291237911156, 9.70825097326125, 9.654798036343122, 10.686482235637119, 11.654324809691445, 12.69400751057075, 13.658214377034028, 14.59186230574258, 15.580913951017601, 16.33007526268647, 15.460068712094417, 14.441865513994301, 13.588150108806252, 12.678062635422096, 11.685094581044432, 10.753645265543923, 9.721952837949464, 8.765122482001928, 7.809693507743209, 6.953243290445105, 7.7763062790345465, 8.716897432314934, 8.823825322496019, 9.779031323992749, 10.770438337596001, 11.798363539094677, 12.827138750573187, 13.764745810288384, 14.752083941282326, 15.404826621901222, 14.449850043192308, 13.464198189572302, 12.529608200714508, 11.665715854163603, 10.683734947003993, 9.712323746289837, 8.768900325199795, 7.806501053164701, 6.853964971266871, 5.9051823560131345, 6.841747566510537, 7.8931972117851, 7.873331395150016, 8.848916891331806, 9.830498920845516, 10.875120535204193, 11.851392787058266, 12.824081531253531, 13.745737137467541, 14.458732675184912, 13.500576610810224, 12.586726033677632, 11.580940843492808, 10.615159839705278, 9.684679301274812, 8.718580910975044, 7.710764130675394, 6.814401243621736, 5.921130941749626, 4.9705624923665725, 5.9360231268001655, 6.941377063193983, 6.925536428246861, 7.916204011145617, 8.839347920526189, 9.851027437651673, 10.87178447817965, 11.838618855411525, 12.792169796642797, 13.57544357058887, 12.55876072058196, 11.59155825103942, 10.638399083276463, 9.682720614029474, 8.752584965412826, 7.724789362530723, 6.740514288138588, 5.798420772842235, 4.957198623927207, 4.025340943648683, 5.015633153926963, 5.99414494640267, 5.996936372142704, 6.9076085193124905, 7.886393533409243, 8.902646103504631, 9.899263715022187, 10.856575792711883, 11.787535541447289, 12.506763339348286, 11.54760224861019, 10.628496200690066, 9.684693805632229, 8.731553125152573, 7.809920326425432, 6.752602809522766, 5.798994086532987, 4.861254681214203, 3.966547631997397, 3.023116891853353, 3.9742619906978636, 5.033592734321973, 4.990444327432592, 5.933418278806479, 6.980070386165628, 7.9609367245045695, 8.848593435420607, 9.844779692365627, 10.854321993528533, 11.563590972823166, 10.593789280909867, 9.658393768665933, 8.70507617639818, 7.7301371423965985, 6.796584101895729, 5.868056977391922, 4.848622683610258, 3.8753233030298437, 2.9584356153730527, 2.0714226501901125, 3.026339567333235, 4.010572911060027, 4.0238129022361555, 4.97397465161916, 5.954947513681931, 6.962733960153975, 7.9046324399272105, 8.970860164050423, 9.916504789814294, 10.796659645264251, 9.759740070429883, 8.782911646983242, 7.755769718433565, 6.699775484301326, 5.768627486195062, 4.821658100419678, 3.8964576570162133, 2.915619712307608, 1.9392906646658885, 1.0008081966830544, 1.9984753100573072, 2.998924695668208, 3.1078718084754002, 4.177417380339252, 5.246099197793042, 6.205781971088196, 7.13905423203661, 8.126608135763814, 9.096018261670931, 10.153431153789214, 9.122134514682399, 8.048844177818804, 7.052549961494823, 6.0628001569497245, 4.9892999884238725, 3.9428012819813114, 2.922073487794892, 1.942845873108434, 0.9845474122338146, 0.0, 1.023580771404012, 2.073559655412406, 3.951870994453454, 4.964796428775193, 5.894410251494872, 6.946994823649935, 7.92468887646097, 8.91942487073719, 9.893078724426204, 10.934527007935255, 10.019640969132025, 9.048283074725958, 7.989134186047368, 6.990842575894611, 5.937648077914666, 4.903887513903997, 3.910262651007842, 2.8863444130818237, 1.9405709616380116, 0.970324378291257, 1.9353104449074818, 2.977698521659308, 4.877087522437402, 5.838317271998016, 6.833867194766491, 7.7756066562061275, 8.764938132701028, 9.829347448062453, 10.865394237593145, 11.698631411554095, 10.628214467784115, 9.651085668202056, 8.66766629894192, 7.658109190171453, 6.710707765194092, 5.7478825482464515, 4.763888878424352, 3.823871202441683, 2.9067101531458457, 1.9587744911591283, 2.943011225361105, 3.885704816290951, 5.822936789984674, 6.7809701705246, 7.761070128077596, 8.72286177084988, 9.702378156708967, 10.70830422801501, 11.761167832184674, 12.621521788865214, 11.549717633631465, 10.586188187823554, 9.606985532300488, 8.607710137707484, 7.669709439937431, 6.7657236475024405, 5.7157412662613645, 4.8044523033573645, 3.883914265491942, 2.941424849466771, 3.912266838816692, 4.92637217168383, 6.76486002211945, 7.73913715587067, 8.721199726501725, 9.648631749814728, 10.699609417969862, 11.673714999500262, 12.722288569787427, 13.399701368557677, 12.432278688158753, 11.487821934504293, 10.562471814270577, 9.633159641047078, 8.600400045185104, 7.760499013234383, 6.730787971282538, 5.7420477182464005, 4.9072711542636815, 4.012820058747315, 4.865022152829351, 5.799162217075667, 7.695614829638333, 8.725117364080546, 9.763439299653037, 10.606564557214204, 11.606322966675648, 12.605279446176475, 13.584973722899926, 14.369012757260323, 13.41459155634405, 12.486847667157976, 11.500124053282338, 10.59584245261241, 9.638313625042082, 8.777490162844035, 7.763938291081006, 6.733769595373025, 5.870295044102692, 5.031623758603385, 5.879331623004688, 6.730723446842451, 8.648676255311619, 9.595549540709754, 10.581581314711677, 11.53874865557322, 12.60548347378826, 13.560607515577004, 14.51690870344655, 15.338968341839152, 14.358402219554831, 13.44093205060078, 12.509773682798896, 11.59443577101501, 10.665866553552416, 9.725418196895223, 8.777908913615992, 7.782948115092829, 6.83048777541191, 6.011640160027623, 6.84501683574087, 7.6949338378082075, 9.609014668563736, 10.589727659663447, 11.550903692392728, 12.487818872376177, 13.539419738839902, 14.612193479873225, 15.469451687365979, 16.36025714465899, 15.37411275468367, 14.419187139418849, 13.481855560712507, 12.530529637928964, 11.6606995437619, 10.78344221606799, 9.756000126242705, 8.718476978844718, 7.7927297289991495, 6.98981298591223, 7.911900393188661, 8.644825300675016, 10.636767663238587, 11.60874665043895, 11.94873045269929, 12.749292862049664, 13.711351047688861, 14.599118434279365, 15.554638516468493, 16.58589494324843, 16.369595847894697, 15.465986212797663, 14.426438709589513, 13.493985260941775, 12.68910788303544, 11.766253408480413, 10.781231734430273, 9.747455771131804, 8.75937446395645, 8.023090840743736, 8.981077207734117, 9.668182048524807], [9.876360922434374, 9.060683076040053, 9.936258040675051, 10.719093262071075, 11.77255996568505, 12.763854521723037, 13.778136424644874, 14.71430915052554, 15.503972109717658, 16.448616362656473, 17.436182199593723, 17.4705674383395, 16.506624765699108, 15.516631867057004, 14.560032336202427, 13.692270820824627, 12.735850289572916, 11.790010249060668, 10.879186088127994, 10.775925455688617, 10.848760570431812, 10.03671896072021, 10.967064351683893, 11.659491341059018, 12.594644745784318, 13.571857958735121, 14.632883847383194, 15.568109578937886, 16.480891350145942, 17.440770065571723, 17.511231321122928, 16.581598311721663, 15.63998766474725, 14.671588380084325, 13.633066943389691, 12.62669706205218, 11.663736690906948, 10.846263458235354, 9.946389956605328, 10.738978958234775, 10.738922545233038, 11.037374782509023, 12.001895814375823, 12.688385214211984, 13.60374850707284, 14.560196405234427, 15.609410118752443, 16.617332056511366, 17.456315660305847, 17.45300697456115, 16.61972208794911, 15.644098865792344, 14.618427749090218, 13.66984375301751, 12.696843863150743, 11.702165525227024, 10.681791273297204, 9.875985187660339, 8.954346459138577, 9.801212407423085, 9.70592869861062, 10.744336851308598, 11.710474878050084, 12.660286042422157, 13.668783329249383, 14.701977993548198, 15.685597496657975, 16.61574990273411, 17.445537690607537, 16.499440623703556, 15.552958358411349, 14.631735161313904, 13.684647971925287, 12.672426049897838, 11.752537701638357, 10.687162706521564, 9.728125057031072, 8.821115766325308, 7.902398599913152, 8.814358335263245, 8.760905398345116, 9.792589597639111, 10.760432171693438, 11.800114872572742, 12.76432173903602, 13.697969667744573, 14.687021313019594, 15.585095012978833, 16.483649483498425, 15.465446285398311, 14.611730880210262, 13.70164340682611, 12.708675352448445, 11.7458177121393, 10.682408826964014, 9.725578471016478, 8.747911635860085, 7.859650545574854, 6.882413641036542, 7.823004794316928, 7.869461229588806, 8.824667231085536, 9.816074244688789, 10.843999446187464, 11.82685228927404, 12.764459348989236, 13.735600341202765, 14.659846372193586, 15.473430814596318, 14.487778960976312, 13.553188972118518, 12.689296625567613, 11.707315718408006, 10.73590451769385, 9.792481096603806, 8.766957042179252, 7.792183099383747, 6.843400484130011, 5.947854928512532, 6.978132837115561, 6.876259141465443, 7.851844637647233, 8.814015320765957, 9.858636935124634, 10.834909186978706, 11.807597931173973, 12.729253537387981, 13.713752425477276, 14.524157382214234, 13.610306805081642, 12.604521614896818, 11.638740611109288, 10.708260072678822, 9.742161682379058, 8.734344902079407, 7.8187943832324995, 6.859349069866502, 5.908780620483449, 4.983736612803369, 5.989090549197186, 5.909052828167301, 6.899720411066057, 7.82286432044663, 8.834543837572115, 9.855300878100092, 10.822135255331967, 11.775686196563237, 12.767243643037176, 13.58234149198597, 12.61513902244343, 11.661979854680474, 10.706301385433486, 9.776165736816836, 8.748370133934735, 7.7640950595425995, 6.8220015442462465, 5.895416752044083, 4.963559071765559, 4.044017447757595, 5.02010568765116, 4.980452772063144, 5.891124919232931, 6.869909933329684, 7.886162503425073, 8.882780114942628, 9.840092192632325, 10.771051941367729, 11.716416968200939, 12.5711830200142, 11.652076972094076, 10.708274577036239, 9.755133896556584, 8.833501097829444, 7.776183580926777, 6.822574857936999, 5.884835452618215, 4.904765760114273, 3.9613350199702295, 3.002646284528495, 4.059553475570462, 3.9739607273530324, 4.9169346787269195, 5.9635867860860685, 6.94445312442501, 7.832109835341048, 8.828296092286068, 9.837838393448973, 10.773244601675819, 11.617370052313877, 10.681974540069943, 9.72865694780219, 8.75371791380061, 7.820164873299741, 6.891637748795934, 5.87220345501427, 4.8989040744338554, 3.980248455883851, 3.009640778306989, 2.0547238611638665, 2.9940893109804687, 3.007329302156596, 3.9574910515396002, 4.938463913602372, 5.946250360074416, 6.88814883984765, 7.954376563970863, 8.900021189734733, 9.949525897164305, 10.783320841833895, 9.806492418387254, 8.779350489837576, 7.723356255705338, 6.792208257599074, 5.84523887182369, 4.920038428420225, 3.9392004837116197, 2.9611035051766867, 2.0226210371938524, 1.0249539238195995, 1.9824410955886493, 2.084291037071388, 3.153836608935239, 4.222518426389029, 5.182201199684183, 6.115473460632598, 7.1030273643598, 8.072437490266918, 9.1298503823852, 10.145715286086409, 9.072424949222814, 8.076130732898834, 7.086380928353736, 6.012880759827884, 4.966382053385323, 3.9456542591989043, 2.966426644512446, 2.0081281836378264, 1.023580771404012, 0.0, 1.0499788840083941, 3.010439848215077, 4.023365282536816, 4.952979105256495, 6.005563677411558, 6.9832577302225936, 7.9779937244988135, 8.951647578187828, 9.99309586169688, 11.030248919949765, 10.07186384612997, 9.01271495745138, 8.014423347298623, 6.961228849318678, 5.9274682853080085, 4.933843422411854, 3.909925184485836, 2.9641517330420237, 1.9939051496952689, 1.0687373943565637, 2.0362673754209313, 3.966245485560336, 4.92747523512095, 5.892436048528114, 6.834175509967751, 7.823506986462651, 8.887916301824076, 9.923963091354768, 10.916945799723987, 11.651795239188129, 10.674666439606069, 9.691247070345934, 8.681689961575465, 7.734288536598104, 6.771463319650463, 5.787469649828363, 4.847451973845695, 3.930290924549858, 2.98235526256314, 2.076438174810187, 2.9748627794138853, 4.912094753107608, 5.870128133647534, 6.819638981839219, 7.781430624611504, 8.76094701047059, 9.766873081776632, 10.819736685946296, 11.864091297893998, 12.573298405035478, 11.609768959227567, 10.6305663037045, 9.631290909111495, 8.693290211341443, 7.789304418906452, 6.739322037665376, 5.828033074761377, 4.907495036895954, 3.965005620870783, 3.045693788265774, 4.015530134806764, 5.898286971568532, 6.828295118993604, 7.810357689624659, 8.707200603576352, 9.758178271731486, 10.732283853261887, 11.780857423549051, 12.763478792970744, 13.455859459562765, 12.511402705908305, 11.586052585674588, 10.656740412451091, 9.623980816589118, 8.784079784638395, 7.75436874268655, 6.765628489650412, 5.930851925667693, 5.036400830151327, 3.9984491022784323, 4.932589166524749, 6.829041779087415, 7.858544313529628, 8.85386767543933, 9.665133410975828, 10.664891820437273, 11.663848299938099, 12.64354257666155, 13.625556524096467, 14.438172327748061, 13.510428438561988, 12.52370482468635, 11.619423224016424, 10.661894396446096, 9.801070934248045, 8.787519062485018, 7.757350366777037, 6.8938758155067035, 5.974863851263132, 5.0127585724537695, 5.864150396291533, 7.7821032047607, 8.728976490158836, 9.715008264160758, 10.597317509334845, 11.664052327549884, 12.619176369338629, 13.575477557208174, 14.591952804613168, 15.381982990958843, 14.464512822004792, 13.533354454202907, 12.61801654241902, 11.689447324956426, 10.748998968299233, 9.801489685020004, 8.80652888649684, 7.854068546815922, 6.93924723613289, 5.978443785189951, 6.82836078725729, 8.742441618012817, 9.723154609112528, 10.68433064184181, 11.597854368016485, 12.597988592601526, 13.67076233363485, 14.528020541127603, 15.483044272838717, 16.397693526087682, 15.44276791082286, 14.505436332116519, 13.554110409332974, 12.68428031516591, 11.807022987472, 10.779580897646717, 9.74205775024873, 8.816310500403162, 7.917420062017497, 7.0453273426377425, 7.778252250124098, 9.770194612687668, 10.742173599888032, 11.716221745129008, 12.530546080183683, 13.564127442301267, 14.590763566228503, 15.535647129129378, 16.518934345863748, 17.393176619298707, 16.489566984201673, 15.450019480993525, 14.517566032345785, 13.71268865443945, 12.789834179884423, 11.804812505834285, 10.771036542535816, 9.782955235360463, 8.950697916849004, 8.114504157183198, 8.801608997973888], [8.958588037269731, 9.808114984635182, 10.727397352200201, 11.56008390066918, 12.613550604283155, 13.618248919372006, 14.632530822293843, 15.64623474814642, 16.435897707338537, 17.405042771554463, 18.3787753508594, 17.35229976057325, 16.388357087932857, 15.398364189290753, 14.441764658436176, 13.470728831179514, 12.432227896768913, 11.795929432108236, 10.814726052635379, 9.858152570523973, 9.93098768526717, 10.784150869315338, 11.758203663209043, 12.500481979657124, 13.435635384382424, 14.412848597333227, 15.4738744859813, 16.409100217535993, 17.395847224168453, 18.397196474469713, 18.409276926383587, 17.479643916982322, 16.517293472311415, 15.548894187648488, 14.510372750953854, 13.504002869616343, 12.54104249847111, 11.723569265799517, 10.805208348268154, 9.858281959712134, 9.744542033068825, 10.711365413983533, 11.741208290004607, 12.604404915904649, 13.603341474804255, 14.601811092828266, 15.593137181304026, 16.611177526016753, 17.503272933296234, 18.361302478947906, 17.521552877173395, 16.542144471053003, 15.49573355665438, 14.547149560581673, 13.574149670714906, 12.579471332791186, 11.559097080861367, 10.753290995224502, 9.83165226670274, 8.920515408900444, 8.711548186446407, 9.749956339144385, 10.692083127540288, 11.641894291912362, 12.650391578739587, 13.652081101607372, 14.63570060471715, 15.565771018725712, 16.52194321001928, 17.407736128090313, 16.461253862798106, 15.529780766574563, 14.582693577185946, 13.549731857462001, 12.62984350920252, 11.564468514085727, 10.605430864595235, 9.69842157388947, 8.779704407477315, 7.933661336740604, 7.766524886180902, 8.774197847129315, 9.742040421183642, 10.781723122062946, 11.745929988526225, 12.648072775803746, 13.637124421078767, 14.535116128970438, 15.517547614869716, 16.37374178978507, 15.520026384597019, 14.599689012086769, 13.606720957709104, 12.623123519703462, 11.559714634528177, 10.60288427858064, 9.625217443424248, 8.736956353139018, 7.759719448600705, 6.942307795794287, 6.819482345580412, 7.774688347077142, 8.766095360680394, 9.79402056217907, 10.776873405265647, 11.714480464980843, 12.68562145719437, 13.609867488185191, 14.582780348620746, 15.39607446536307, 14.461484476505275, 13.59759212995437, 12.605361323668665, 11.63395012295451, 10.690526701864465, 9.644262849743415, 8.66948890694791, 7.7207062916941736, 6.825160736076695, 5.96751439629307, 5.826280257457049, 6.801865753638838, 7.764036436757563, 8.80865805111624, 9.784930302970313, 10.75761904716558, 11.679274653379586, 12.663773541468881, 13.621929605843569, 14.518602309468399, 13.512817119283575, 12.547036115496045, 11.61655557706558, 10.640207287639717, 9.632390507340066, 8.696100190796663, 7.736654877430665, 6.786086428047612, 5.861042420367532, 4.978472108374695, 4.859073944158907, 5.849741527057663, 6.772885436438236, 7.784564953563721, 8.805321994091697, 9.772156371323574, 10.725707312554842, 11.717264759028781, 12.72185368696934, 13.561627404198143, 12.608305837834834, 11.652627368587845, 10.684461241203593, 9.646415739195394, 8.662140664803259, 7.720047149506906, 6.772722559608246, 5.840864879329722, 4.921323255321758, 3.970126803642766, 3.9304738880547503, 4.841146035224537, 5.81993104932129, 6.836183619416679, 7.832801230934235, 8.790113308623932, 9.721073057359334, 10.666438084192546, 11.646880377281045, 12.59856535384879, 11.693789611084298, 10.701459879710944, 9.7417966022162, 8.67806822107452, 7.724459498084741, 6.7867200927659574, 5.782071567678436, 4.838640827534392, 3.879952092092658, 3.0095745915620684, 2.9239818433446385, 3.866955794718525, 4.913607902077674, 5.894474240416616, 6.782130951332655, 7.7783172082776755, 8.787859509440578, 9.723265717667424, 10.693067409580722, 11.628462921824656, 10.71417198185025, 9.73923294784867, 8.805679907347798, 7.877152782843992, 6.857718489062328, 5.884419108481914, 4.8882061292554075, 3.886946585871152, 2.9320296687280294, 1.9441104269720748, 1.9573504181482022, 2.9075121675312063, 3.888485029593978, 4.896271476066022, 5.838169955839257, 6.90439767996247, 7.8500423057263395, 8.899547013155912, 9.93646658799028, 10.792007452435314, 9.764865523885636, 8.708871289753397, 7.777723291647132, 6.830753905871748, 5.9055534624682835, 4.924715517759679, 3.869061178548243, 2.930578710565409, 1.9329115971911563, 0.9324622115802552, 1.0343121530629942, 2.1038577249268453, 3.172539542380635, 4.132222315675789, 5.065494576624204, 6.053048480351406, 7.022458606258523, 8.079871498376805, 9.143878536779267, 10.122403833231209, 9.126109616907229, 8.13635981236213, 7.062859643836278, 6.016360937393717, 4.995633143207298, 4.01640552852084, 3.0581070676462208, 2.073559655412406, 1.0499788840083941, 0.0, 1.9604609642066833, 2.9733863985284223, 3.903000221248101, 4.9555847934031645, 5.9332788462142, 6.92801484049042, 7.901668694179434, 8.943116977688485, 9.98027003594137, 10.951627930347437, 10.012811968104382, 9.014520357951625, 7.96132585997168, 6.92756529596101, 5.933940433064856, 4.910022195138837, 3.963909218127343, 2.993662634780588, 2.0286765681643635, 0.9862884914125373, 2.9162666015519423, 3.8774963511125558, 4.84245716451972, 5.784196625959357, 6.773528102454257, 7.837937417815682, 8.873984207346375, 9.866966915715594, 10.932969498889136, 11.67476345025907, 10.691344080998935, 9.681786972228467, 8.734385547251106, 7.771560330303465, 6.787566660481365, 5.8475489844986965, 4.9300484096351775, 3.908571248734127, 2.867577486335337, 1.9248838954054914, 3.8621158690992137, 4.82014924963914, 5.769660097830825, 6.73145174060311, 7.7109681264621965, 8.716894197768239, 9.769757801937903, 10.814112413885605, 11.865955103230343, 12.609865969880568, 11.630663314357502, 10.631387919764498, 9.693387221994445, 8.789401429559454, 7.7394190483183785, 6.778391712105249, 5.765669676687349, 4.823180260662178, 3.836833099790924, 2.96555125079837, 4.887464356357022, 5.77831623498521, 6.7603788056162655, 7.657221719567957, 8.708199387723091, 9.682304969253492, 10.730878539540656, 11.71349990896235, 12.680922589361273, 13.511499716561307, 12.58614959632759, 11.656837423104093, 10.62407782724212, 9.784176795291398, 8.754465753339552, 7.715987126994284, 6.789026565459088, 5.850938920470341, 4.789588413803582, 4.014816281360105, 5.818219163875905, 6.843767107088865, 7.803888791430936, 8.615154526967434, 9.614912936428878, 10.613869415929704, 11.593563692653156, 12.575577640088072, 13.529998841004346, 14.51052544921499, 13.523801835339352, 12.619520234669427, 11.661991407099098, 10.777832492159348, 9.764280620396319, 8.707709004120908, 7.752050455298098, 6.766003162788282, 5.8038978839789195, 4.946377511126889, 6.796683432971554, 7.74355671836969, 8.729588492371613, 9.54733862532645, 10.61407344354149, 11.569197485330234, 12.52549867319978, 13.541973920604773, 14.473809504215128, 15.461852313998275, 14.53345146485591, 13.5499421400399, 12.621372922577304, 11.680924565920112, 10.674551578753741, 9.679590780230578, 8.695059185414028, 7.73038654765804, 6.769583096715101, 5.9105879020926455, 7.824668732848174, 8.737734837323384, 9.698910870052664, 10.54787548400809, 11.548009708593131, 12.620783449626455, 13.478041657119206, 14.43306538883032, 15.41920977880564, 16.402236902298366, 15.505533342769521, 14.486036006953853, 13.61620591278679, 12.71458202798509, 11.652642791380455, 10.615119643982467, 9.657301139001268, 8.708559373542647, 7.8364666541628925, 6.860479364959454, 8.852421727523025, 9.756753828098887, 10.730801973339863, 11.480567196175288, 12.514148558292872, 13.540784682220108, 14.485668245120982, 15.468955461855353, 16.414692872016666, 17.445993393099663, 16.406445889891515, 15.449491629966664, 14.644614252060329, 13.66289607361816, 12.677874399568022, 11.616966389506333, 10.623945873958569, 9.741837228374154, 8.861936065778327, 7.883836112809245], [8.891488428103752, 9.741015375469203, 10.71528133358181, 11.54796788205079, 12.601434585664764, 13.606132900753614, 14.620414803675452, 15.63411872952803, 16.423781688720148, 17.322287547337982, 16.418314386652714, 15.391838796366564, 14.42789612372617, 13.437903225084067, 12.48130369422949, 11.510267866972828, 10.471766932562229, 9.890483942901557, 8.9092805634287, 7.96832499064623, 9.837609400642993, 10.71705126014936, 11.695508466942542, 12.488365961038733, 13.423519365764033, 14.400732578714836, 15.461758467362909, 16.3969841989176, 17.38373120555006, 18.217859959402663, 17.263754701393882, 16.334121691992618, 15.371116981918423, 14.389840505553671, 13.408269087042227, 12.50684090237343, 11.543880531228197, 10.828696011991468, 9.842076694951366, 8.897019294439113, 9.748965499430795, 10.715788880345503, 11.745631756366581, 12.608828382266623, 13.607764941166229, 14.60623455919024, 15.597560647666, 16.5211167548615, 17.401668006872995, 18.320001701357615, 18.238930554146197, 17.271621137921937, 16.34908393022894, 15.400499934156231, 14.427500044289465, 13.55781652700164, 12.52582594883794, 11.798135067134552, 10.834120192418117, 9.834785845250803, 8.71597165280838, 9.754379805506357, 10.696506593902262, 11.646317758274336, 12.65481504510156, 13.656504567969346, 14.640124071079123, 15.464166092302474, 16.420338283596042, 17.366435350500023, 18.346809525734034, 17.490241730781246, 16.54315454139263, 15.510192821668687, 14.590304473409203, 13.52492947829241, 12.526271857129766, 11.588142235140216, 10.637710337252573, 9.700202497517381, 7.7709483525428755, 8.77862131349129, 9.746463887545616, 10.78614658842492, 11.750353454888199, 12.65249624216572, 13.64154788744074, 14.4335112025472, 15.415942688446478, 16.390117475005407, 17.40558204753295, 16.560149976293452, 15.567181921915788, 14.583584483910148, 13.52017559873486, 12.563345242787324, 11.585678407630931, 10.626677014389763, 9.64944010985145, 8.708848956571064, 6.823905811942385, 7.7791118134391155, 8.770518827042368, 9.798444028541043, 10.781296871627621, 11.718903931342817, 12.584016530771132, 13.508262561761953, 14.481175422197508, 15.41245015058341, 16.347040139441205, 15.558053094161052, 14.56582228787535, 13.594411087161193, 12.650987666071149, 11.604723813950098, 10.629949871154594, 9.668092490249029, 8.732130307878036, 7.751700343693431, 5.830703723819022, 6.806289220000812, 7.7684599031195365, 8.813081517478214, 9.789353769332287, 10.685047415888041, 11.577669726956348, 12.562168615045643, 13.52032467942033, 14.476670123621966, 15.473278083490257, 14.507497079702727, 13.577016541272261, 12.6006682518464, 11.59285147154675, 10.656561155003347, 9.697115841637348, 8.733472626602467, 7.768011992168873, 6.762658055775056, 4.86349741052088, 5.854164993419636, 6.777308902800209, 7.788988419925694, 8.791617433023594, 9.699584740046035, 10.624102386131604, 11.615659832605543, 12.620248760546101, 13.460022477774904, 14.51173371537597, 13.581279457414878, 12.644922205410275, 11.606876703402078, 10.622601629009942, 9.68050811371359, 8.73318352381493, 7.8013258435364055, 6.881784219528441, 5.924169952251951, 3.9348973544167234, 4.84556950158651, 5.824354515683263, 6.791102616633804, 7.760229599656697, 8.717541677346393, 9.619468130936095, 10.564833157769307, 11.545275450857806, 12.49696042742555, 13.45979321690322, 12.630111968537976, 11.702257566422883, 10.638529185281204, 9.684920462291425, 8.747181056972641, 7.74253253188512, 6.799101791741076, 5.840413056299342, 4.970035555768751, 2.9284053097066116, 3.8713792610804982, 4.873596370565469, 5.8219026091390775, 6.709559320055116, 7.705745577000137, 8.68625458301734, 9.621660791244185, 10.591462483157484, 11.526857995401418, 12.480175587669171, 11.628695985782002, 10.695142945281132, 9.766615820777325, 8.74718152699566, 7.773882146415246, 6.848667093462091, 5.847407550077835, 4.892490632934713, 3.904571391178758, 1.961773884510175, 2.9119356338931794, 3.8159133983164395, 4.823699844788483, 5.765598324561719, 6.830292917733328, 7.7484373793031, 8.76552700479913, 9.802446579633498, 10.779275003080139, 11.654328561818968, 10.598334327686729, 9.667186329580465, 8.720216943805081, 7.795016500401616, 6.81417855569301, 5.829522142754927, 4.891039674772093, 3.8933725613978396, 2.8929231757869385, 1.0072007901587154, 1.9487463770053886, 2.878006066691806, 3.8376888399869604, 4.770961100935375, 5.758515004662578, 6.7279251305696945, 7.785338022687978, 8.849345061090439, 9.922635397954034, 10.918929614278014, 9.961359000335126, 8.887858831809273, 7.8413601253667125, 6.820632331180294, 5.841404716493836, 4.9364184066872685, 3.9518709944534542, 3.0104398482150776, 1.9604609642066833, 0.0, 1.0129254343217393, 1.9425392570414182, 2.9951238291964812, 3.972817882007517, 4.967553876283737, 5.941207729972751, 6.982656013481803, 8.019809071734688, 8.991166966140755, 10.00069594948599, 9.002404339333234, 7.949209841353289, 6.915449277342619, 5.921824414446465, 4.897906176520446, 3.951793199508952, 2.981546616162197, 2.0165605495459724, 0.974172472794146, 1.0108211123452633, 1.9720508619058768, 2.8819962003130373, 3.823735661752674, 4.8130671382475745, 5.877476453608999, 6.913523243139691, 7.906505951508911, 8.972508534682454, 9.949637334264514, 10.679228062380545, 9.669670953610076, 8.722269528632715, 7.7594443116850735, 6.775450641862974, 5.8354329658803055, 4.9179323910167865, 3.8964552301157354, 2.8554614677169456, 1.9127678767871001, 1.9566703798925347, 2.9147037604324613, 3.8091991336241424, 4.770990776396427, 5.750507162255514, 6.756433233561555, 7.809296837731218, 8.853651449678921, 9.905494139023661, 10.869023584831572, 11.618547295739111, 10.619271901146107, 9.681271203376054, 8.777285410941063, 7.727303029699987, 6.7662756934868575, 5.753553658068958, 4.811064242043787, 3.8247170811725324, 2.953435232179979, 2.982018867150343, 3.8728707457785316, 4.8549333164095865, 5.696760755361274, 6.747738423516409, 7.721844005046808, 8.770417575333973, 9.753038944755666, 10.72046162515459, 11.66491837880905, 12.5740335777092, 11.644721404485702, 10.611961808623729, 9.772060776673007, 8.742349734721161, 7.703871108375893, 6.776910546840697, 5.83882290185195, 4.777472395185191, 3.947716672194127, 3.912773674669226, 4.938321617882186, 5.898443302224257, 6.654693562760751, 7.654451972222194, 8.65340845172302, 9.633102728446472, 10.615116675881389, 11.569537876797662, 12.607535527614498, 13.511685816720961, 12.607404216051036, 11.649875388480707, 10.765716473540955, 9.752164601777928, 8.695592985502516, 7.739934436679707, 6.753887144169891, 5.791781865360528, 4.879277901960911, 4.891237943764875, 5.838111229163011, 6.824143003164934, 7.586877661119766, 8.653612479334805, 9.60873652112355, 10.565037708993096, 11.58151295639809, 12.513348540008444, 13.501391349791591, 14.432549717593476, 13.537826121421508, 12.609256903958913, 11.66880854730172, 10.66243556013535, 9.667474761612187, 8.682943166795637, 7.718270529039649, 6.75746707809671, 5.843488292926668, 5.934841152970431, 6.832289348116704, 7.793465380845985, 8.587414519801406, 9.587548744386448, 10.660322485419771, 11.517580692912524, 12.472604424623638, 13.458748814598959, 14.441775938091686, 15.379107516798028, 14.473919988335462, 13.604089894168398, 12.702466009366699, 11.640526772762064, 10.603003625364076, 9.645185120382877, 8.696443354924256, 7.824350635544501, 6.793379755793476, 6.962594147645281, 7.851308338892207, 8.825356484133184, 9.520106231968605, 10.553687594086188, 11.580323718013425, 12.5252072809143, 13.508494497648671, 14.454231907809985, 15.513240001787107, 16.323690665675034, 15.437375611348273, 14.632498233441938, 13.650780054999771, 12.665758380949631, 11.604850370887942, 10.611829855340178, 9.729721209755763, 8.794836456612348, 7.816736503643266], [9.80492014081314, 10.65444708817859, 11.641694859872032, 12.474381408341012, 13.527848111954986, 14.532546427043837, 15.546828329965674, 16.560532255818252, 17.25412556865002, 16.309362113016242, 15.405388952330979, 14.378913362044827, 13.414970689404432, 12.42497779076233, 11.468378259907754, 10.497342432651092, 9.45884149824049, 9.047911878063672, 8.14114933106591, 8.881756703355618, 10.75104111335238, 11.045900710400188, 11.952855814165705, 12.810114850526782, 13.745268255252082, 14.672631386378077, 15.624598499142323, 16.557413798113238, 17.36416688271116, 17.204934525080926, 16.250829267072145, 15.32119625767088, 14.358191547596686, 13.376915071231934, 12.39534365272049, 11.493915468051691, 10.530955096906458, 9.991658668888986, 9.073945462588576, 9.810451007148501, 10.642669693803768, 10.045244888611375, 10.918024351473775, 11.781220977373817, 12.780157536273423, 13.684292939878771, 14.600996827654573, 15.508191320539758, 16.388742572551255, 17.307076267035875, 17.22600511982446, 16.2586957036002, 15.336158495907203, 14.387574499834495, 13.414574609967728, 12.5448910926799, 11.512900514516202, 10.961936939464001, 10.065988960055327, 10.74821755796019, 9.609675847181352, 9.083835813772227, 9.868899189009456, 10.81871035338153, 11.827207640208755, 12.66052151379283, 13.643560251067697, 14.451240657980733, 15.407412849274301, 16.353509916178282, 17.333884091412294, 17.2666943442235, 16.303063295560108, 15.406994892450241, 14.358880771480115, 13.536058199712127, 12.466566730782333, 12.016806360799032, 11.117936819280752, 10.593906691890353, 8.664652546915848, 8.04566088151314, 8.91885648265281, 9.857642076577305, 10.821848943040584, 11.656513187989203, 12.63350757786471, 13.42058576822546, 14.403017254124737, 15.377192040683669, 16.39265661321121, 17.369475081272938, 16.554625031579942, 15.541336317527026, 14.477927432351741, 13.521097076404205, 12.543430241247812, 11.520381208762736, 10.543144304224423, 9.602553150944036, 7.717610006315358, 7.046151381460966, 7.8721581537104335, 8.858628706233619, 9.826301729980043, 10.7229208771663, 11.571091096449392, 12.495337127440212, 13.468249987875767, 14.39952471626167, 15.334114705119465, 16.360560782941395, 15.553265397539503, 14.581854196825347, 13.60966284151412, 12.562475647566979, 11.587701704771474, 10.561796684622001, 9.625834502251008, 8.645404538066403, 6.724407918191995, 6.032410842588795, 6.839895558858346, 7.869425277244928, 8.83435862768471, 9.6721219815663, 10.564744292634607, 11.549243180723902, 12.50739924509859, 13.463744689300226, 14.46952987948505, 15.434485642768148, 14.564459650936417, 13.588111361510554, 12.580294581210904, 11.644004264667501, 10.684558951301502, 9.62717682097544, 8.661716186541845, 7.656362250148028, 5.757201604893853, 5.021348921950478, 5.8487445585390185, 6.8453321796924085, 7.778691998701854, 8.686659305724294, 9.611176951809863, 10.602734398283802, 11.60732332622436, 12.447097043453164, 13.49880828105423, 14.402682694763756, 13.63236531507443, 12.594319813066232, 11.610044738674096, 10.667951223377743, 9.720626633479084, 8.78876895320056, 7.809130458368371, 6.8178741466249235, 4.828601548789695, 3.948414953028893, 4.895790171422072, 5.7781771823120645, 6.747304165334956, 7.704616243024652, 8.606542696614355, 9.551907723447567, 10.532350016536066, 11.48403499310381, 12.44686778258148, 13.451515205886855, 12.689700676087037, 11.625972294945358, 10.672363571955579, 9.734624166636795, 8.729975641549274, 7.786544901405231, 6.827856165963496, 5.880373427323274, 3.8221095040795836, 2.974224712522881, 3.860670936243729, 4.808977174817338, 5.696633885733376, 6.692820142678396, 7.673329148695599, 8.608735356922445, 9.578537048835743, 10.513932561079677, 11.46725015334743, 12.45009922313088, 11.70806837960287, 10.779541255099064, 9.7601069613174, 8.786807580736983, 7.836110203126247, 6.83485065974199, 5.879933742598868, 4.8920145008429134, 2.8554780788831473, 1.905316329500143, 2.8029879639947, 3.8107744104667436, 4.752672890239978, 5.817367483411588, 6.7355119449813605, 7.752601570477391, 8.789521145311758, 9.766349568758399, 10.793491497308077, 11.611259762008467, 10.680111763902204, 9.73314237812682, 8.807941934723354, 7.8271039900147485, 6.816965252419083, 5.878482784436248, 4.880815671061995, 3.8803662854510943, 2.0053665145475006, 0.9358209426836492, 1.8650806323700664, 2.824763405665221, 3.7580356666136354, 4.745589570340838, 5.714999696247955, 6.7724125883662385, 7.8364196267687, 8.909709963632295, 9.906004179956275, 10.895753984501374, 9.900784266131014, 8.854285559688453, 7.833557765502033, 6.854330150815575, 5.949343841009008, 4.964796428775194, 4.023365282536817, 2.973386398528423, 1.0129254343217393, 0.0, 0.9296138227196789, 1.982198394874742, 2.9598924476857773, 3.9546284419619977, 4.9282822956510115, 5.969730579160062, 7.0068836374129475, 7.978241531819013, 9.037390420497605, 10.015329773654972, 8.962135275675028, 7.928374711664358, 6.934749848768204, 5.910831610842186, 4.9647186338306915, 3.9944720504839366, 3.029485983867712, 1.9870979071158854, 1.9242528250546513, 0.9630230754940379, 1.869070765991298, 2.8108102274309346, 3.8001417039258354, 4.86455101928726, 5.9005978088179525, 6.893580517187172, 7.959583100360715, 8.936711899942775, 9.92013126920291, 10.682596387931815, 9.735194962954454, 8.772369746006813, 7.788376076184713, 6.848358400202045, 5.930857825338526, 4.899322884529738, 3.858329122130948, 2.915635531201102, 2.8701020926019227, 1.9996992914632647, 2.7962736993024033, 3.758065342074688, 4.737581727933774, 5.743507799239817, 6.79637140340948, 7.840726015357181, 8.892568704701922, 9.856098150509833, 10.891970037751602, 11.632197335467845, 10.694196637697793, 9.786378282536235, 8.73639590129516, 7.76914334790086, 6.75642131248296, 5.813931896457789, 4.827584735586535, 3.9217445214010773, 3.895450579859731, 2.957866276809335, 3.8607564406987334, 4.683835321039535, 5.734812989194669, 6.708918570725069, 7.757492141012234, 8.740113510433927, 9.707536190832851, 10.651992944487311, 11.577343064721028, 12.513550934860811, 11.624887242945467, 10.781153648268178, 9.749465464883594, 8.706738762789895, 7.779778201254699, 6.841690556265952, 5.780340049599193, 4.861148384903514, 4.826205387378614, 4.023317148912989, 4.904266426513404, 5.641768128439011, 6.641526537900455, 7.640483017401281, 8.620177294124733, 9.60219124155965, 10.556612442475924, 11.594610093292758, 12.514995303732789, 13.517337847762446, 12.662800822802446, 11.76858412795496, 10.75503225619193, 9.698460639916519, 8.74280209109371, 7.680300670460114, 6.7181953916507515, 5.792709614670299, 5.804669656474264, 5.06997999680022, 5.971580171150416, 6.573952226798027, 7.640687045013066, 8.595811086801811, 9.552112274671357, 10.568587522076351, 11.500423105686705, 12.488465915469853, 13.419624283271737, 14.44038809645259, 13.535670430249136, 12.595222073591943, 11.588849086425572, 10.59388828790241, 9.609356693085859, 8.644684055329872, 7.683880604386933, 6.756920005636055, 6.848272865679819, 6.064158115753913, 6.950893316008101, 7.574489085479668, 8.574623310064709, 9.647397051098032, 10.504655258590784, 11.459678990301898, 12.445823380277218, 13.428850503769945, 14.366182082476287, 15.376481963366544, 14.53050342045862, 13.628879535656921, 12.566940299052286, 11.529417151654298, 10.571598646673099, 9.622856881214478, 8.741626132490026, 7.706811468502863, 7.87602586035467, 7.0831771065294165, 7.9827844192953, 8.507180797646866, 9.54076215976445, 10.567398283691686, 11.51228184659256, 12.495569063326931, 13.441306473488245, 14.500314567465367, 15.310765231353294, 16.267719491278147, 15.55891175973216, 14.577193581289993, 13.592171907239853, 12.531263897178164, 11.5382433816304, 10.656134736045985, 9.708268169321736, 8.730168216352654], [10.734533963532819, 11.58406091089827, 12.054048302454868, 12.820899106795046, 13.80323316851456, 14.788972870089497, 15.634877880500579, 16.6281682427367, 16.324511745930344, 15.379748290296565, 14.475775129611298, 13.449299539325146, 12.485356866684752, 11.49536396804265, 10.538764437188073, 9.567728609931411, 8.52922767552081, 8.118298055343994, 9.0036582074173, 9.811370526075297, 11.680654936072061, 11.885566929736784, 11.023241991446026, 11.880501027807103, 12.815654432532403, 13.743017563658396, 14.694984676422642, 15.627799975393557, 16.43455305999148, 16.275320702361245, 15.321215444352465, 14.3915824349512, 13.428577724877005, 12.447301248512254, 11.465729830000809, 10.56430164533201, 9.601341274186778, 9.062044846169307, 9.936454338939967, 10.740064829868182, 11.572283516523449, 10.884911107947971, 9.988410528754097, 10.851607154654138, 11.850543713553744, 12.75467911715909, 13.671383004934892, 14.57857749782008, 15.459128749831576, 16.377462444316198, 16.29639129710478, 15.32908188088052, 14.406544673187522, 13.457960677114814, 12.484960787248047, 11.61527726996022, 10.583286691796522, 10.032323116744323, 10.928497836406718, 11.677831380679871, 10.53928966990103, 9.923502033108825, 8.939285366289777, 9.88909653066185, 10.897593817489076, 11.73090769107315, 12.713946428348017, 13.521626835261054, 14.477799026554623, 15.423896093458605, 16.404270268692617, 16.337080521503818, 15.373449472840427, 14.47738106973056, 13.429266948760434, 12.606444376992446, 11.536952908062652, 11.087192538079353, 11.980445695632143, 11.523520514610032, 9.594266369635527, 8.891053394287134, 7.989242659933131, 8.928028253857626, 9.892235120320905, 10.726899365269523, 11.703893755145032, 12.49097194550578, 13.473403431405059, 14.44757821796399, 15.46304279049153, 16.43986125855326, 16.34942209231727, 15.4039894074891, 14.499395823434776, 13.568028612497532, 12.517166329233639, 12.048657758829806, 11.472758126944102, 10.532166973663715, 8.647223829035037, 7.89154389423496, 6.9425443309907555, 7.92901488351394, 8.896687907260366, 9.79330705444662, 10.641477273729713, 11.565723304720533, 12.538636165156088, 13.469910893541991, 14.404500882399786, 15.430946960221714, 16.40163428134848, 15.511468019545028, 14.539276664233798, 13.492089470286656, 12.517315527491151, 11.491410507341678, 10.555448324970687, 9.575018360786082, 7.6540217409116735, 6.87780335536279, 5.910281736138668, 6.939811454525249, 7.904744804965032, 8.74250815884662, 9.635130469914928, 10.619629358004223, 11.577785422378911, 12.534130866580547, 13.539916056765371, 14.504871820048468, 15.356323635511298, 14.517725184230235, 13.509908403930584, 12.573618087387182, 11.614172774021183, 10.556790643695116, 9.591330009261524, 8.585976072867707, 6.686815427613531, 5.8667414347244735, 4.919130735819341, 5.91571835697273, 6.849078175982176, 7.757045483004615, 8.681563129090184, 9.673120575564123, 10.677709503504682, 11.517483220733485, 12.56919445833455, 13.473068872044077, 14.424229299649312, 13.523933635785912, 12.539658561393777, 11.597565046097424, 10.650240456198764, 9.71838277592024, 8.738744281088051, 7.747487969344602, 5.758215371509374, 4.878028775748572, 3.966176348702394, 4.848563359592386, 5.817690342615278, 6.775002420304973, 7.676928873894676, 8.622293900727886, 9.602736193816387, 10.554421170384131, 11.517253959861801, 12.521901383167176, 13.48156466066192, 12.555586117665039, 11.60197739467526, 10.664237989356476, 9.659589464268954, 8.71615872412491, 7.757469988683175, 6.809987250042953, 4.7517233267992625, 3.9038385352425595, 2.9310571135240506, 3.879363352097659, 4.767020063013698, 5.763206319958718, 6.74371532597592, 7.679121534202766, 8.648923226116064, 9.584318738359999, 10.537636330627752, 11.520485400411202, 12.532878710244326, 11.709155077818743, 10.689720784037078, 9.716421403456662, 8.765724025845927, 7.764464482461669, 6.809547565318547, 5.821628323562592, 3.7850919016028257, 2.8349301522198216, 1.8733741412750216, 2.8811605877470647, 3.8230590675203, 4.887753660691908, 5.805898122261681, 6.822987747757711, 7.859907322592078, 8.83673574603872, 9.863877674588398, 10.919871908720637, 11.609725586621883, 10.662756200846498, 9.737555757443033, 8.756717812734427, 7.7465790751387615, 6.808096607155927, 5.810429493781674, 4.809980108170773, 2.9349803372671794, 1.865434765403328, 0.9354668096503876, 1.895149582945542, 2.8284218438939566, 3.815975747621159, 4.785385873528275, 5.842798765646559, 6.906805804049021, 7.9800961409126145, 8.976390357236594, 9.966140161781693, 10.830398088850693, 9.783899382408132, 8.763171588221713, 7.783943973535254, 6.878957663728687, 5.894410251494873, 4.952979105256496, 3.9030002212481016, 1.9425392570414182, 0.9296138227196789, 0.0, 1.052584572155063, 2.0302786249660985, 3.025014619242319, 3.9986684729313327, 5.0401167564403835, 6.077269814693269, 7.048627709099335, 8.107776597777924, 9.106068207930681, 9.891749098394708, 8.857988534384038, 7.864363671487883, 6.8404454335618645, 5.89433245655037, 4.924085873203616, 3.959099806587391, 2.9167117298355643, 2.85386664777433, 1.8926368982137167, 0.9394569432716191, 1.8811964047112557, 2.8705278812061565, 3.934937196567581, 4.970983986098274, 5.963966694467493, 7.029969277641036, 8.007098077223096, 8.990517446483231, 10.0000745552537, 10.664808785674133, 9.701983568726492, 8.717989898904392, 7.777972222921724, 6.860471648058205, 5.828936707249416, 4.787942944850626, 3.845249353920781, 3.7997159153216016, 2.8622081678146563, 1.8666598765827245, 2.828451519355009, 3.8079679052140953, 4.813893976520138, 5.866757580689801, 6.9111121926375025, 7.962954881982243, 8.926484327790153, 9.962356215031923, 10.94967550278973, 11.623810460417472, 10.715992105255914, 9.666009724014838, 8.698757170620539, 7.686035135202638, 6.743545719177467, 5.757198558306213, 4.851358344120756, 4.82506440257941, 3.8203751531607266, 2.9311426179790545, 3.754221498319856, 4.80519916647499, 5.77930474800539, 6.827878318292555, 7.810499687714247, 8.777922368113172, 9.722379121767633, 10.647729242001349, 11.583937112141133, 12.554501065665146, 11.710767470987857, 10.679079287603273, 9.636352585509574, 8.709392023974377, 7.77130437898563, 6.709953872318871, 5.790762207623193, 5.755819210098293, 4.885826025264381, 3.974652603793725, 4.7121543057193325, 5.711912715180776, 6.710869194681602, 7.690563471405055, 8.672577418839971, 9.626998619756245, 10.66499627057308, 11.58538148101311, 12.587724025042768, 13.545252852613096, 12.698197950674636, 11.684646078911609, 10.628074462636198, 9.672415913813387, 8.609914493179792, 7.64780921437043, 6.722323437389978, 6.734283479193943, 5.932488873151612, 5.041966348430737, 5.644338404078348, 6.711073222293387, 7.666197264082132, 8.622498451951678, 9.638973699356672, 10.570809282967026, 11.558852092750174, 12.490010460552059, 13.51077427373291, 14.439343491195505, 13.524835896311624, 12.518462909145253, 11.52350211062209, 10.53897051580554, 9.574297878049553, 8.613494427106613, 7.686533828355734, 7.777886688399498, 6.926666992105305, 6.021279493288422, 6.644875262759989, 7.645009487345029, 8.717783228378353, 9.575041435871107, 10.53006516758222, 11.516209557557541, 12.499236681050268, 13.43656825975661, 14.446868140646863, 15.43417648140499, 14.558493358376602, 13.496554121771966, 12.459030974373979, 11.50121246939278, 10.552470703934159, 9.671239955209705, 8.636425291222542, 8.805639683074348, 7.945685982880808, 7.0531705965756215, 7.577566974927186, 8.611148337044769, 9.637784460972005, 10.582668023872882, 11.565955240607254, 12.511692650768568, 13.57070074474569, 14.381151408633617, 15.33810566855847, 16.385530248213957, 15.506807404009674, 14.521785729959534, 13.460877719897844, 12.46785720435008, 11.585748558765665, 10.637881992041414, 9.659782039072333], [11.706247358157487, 12.555774305522938, 12.924728279018057, 11.964936125476486, 12.947270187195999, 13.855204993593654, 14.671025611756981, 15.6643159739931, 15.43168269661083, 14.486919240977052, 13.582946080291785, 12.556470490005633, 11.592527817365239, 10.602534918723137, 9.64593538786856, 8.674899560611898, 7.636398626201297, 8.648590585350139, 9.697137825962011, 10.71677429635578, 12.466473187975453, 12.841080207583497, 11.978755269292739, 11.024538046488543, 11.959691451213843, 12.809249687162554, 13.731132407679045, 14.66394770664996, 15.470700791247884, 15.382491653041733, 14.428386395032952, 13.498753385631687, 12.535748675557493, 11.554472199192741, 10.572900780681296, 9.671472596012498, 8.708512224867265, 9.592337376175452, 10.578956693215552, 11.525883081771573, 12.547213645488132, 11.840424385794684, 10.943923806600809, 9.995644173335577, 10.971049842504195, 11.820911240663248, 12.707530736191295, 13.614725229076482, 14.495276481087979, 15.4136101755726, 15.403562247785269, 14.436252831561006, 13.51371562386801, 12.565131627795301, 11.592131737928534, 10.722448220640707, 9.690457642477009, 10.562615646750467, 11.526630521466902, 12.463649632583262, 11.514219798865716, 10.879015310955538, 9.89479864413649, 9.03313354934329, 10.018099946439527, 10.797139814577307, 11.75009415960442, 12.557774566517457, 13.513946757811025, 14.460043824715008, 15.440417999949023, 15.444251472184305, 14.480620423520914, 13.584552020411047, 12.536437899440921, 11.713615327672933, 10.64412385874314, 11.582253480732689, 12.578578380692328, 12.498450643574717, 10.569196498600212, 9.846566672133847, 8.944755937779844, 7.994260377361785, 8.958467243825064, 9.793131488773682, 10.740041486401434, 11.527119676762183, 12.509551162661461, 13.483725949220396, 14.499190521747936, 15.476008989809667, 15.456593042997756, 14.511160358169587, 13.606566774115263, 12.675199563178019, 11.624337279914126, 12.543718701483142, 12.447688255908787, 11.5070971026284, 9.622153957999721, 8.847057172081673, 7.898057608837468, 6.995247007018099, 7.9629200307645265, 8.85953917795078, 9.677625004986115, 10.601871035976936, 11.574783896412491, 12.506058624798397, 13.440648613656192, 14.46709469147812, 15.437782012604883, 15.552481877423673, 14.60202695313311, 13.554839759185969, 12.580065816390464, 12.466340636306365, 11.530378453935372, 10.549948489750767, 8.628951869876358, 7.8333166332095026, 6.86579501398538, 6.006043578029408, 6.970976928469192, 7.808740282350779, 8.671278201171331, 9.655777089260626, 10.613933153635314, 11.570278597836953, 12.576063788021777, 13.541019551304874, 14.392471366767705, 15.438309032849618, 14.484838532895267, 13.548548216351865, 12.589102902985866, 11.531720772659803, 10.566260138226209, 9.560906201832392, 7.661745556578216, 6.822254712571186, 5.874644013666053, 4.981950480476889, 5.915310299486335, 6.823277606508774, 7.717710860346588, 8.709268306820526, 9.713857234761088, 10.553630951989891, 11.605342189590957, 12.509216603300484, 13.460377030905718, 14.454276501639047, 13.51458869035846, 12.572495175062107, 11.625170585163447, 10.693312904884923, 9.713674410052736, 8.722418098309287, 6.733145500474059, 5.852958904713256, 4.921689626549107, 3.9147954830965452, 4.883922466119437, 5.841234543809132, 6.71307660515108, 7.658441631984291, 8.638883925072793, 9.590568901640538, 10.553401691118207, 11.558049114423582, 12.517712391918327, 13.460178308801758, 12.576907523639942, 11.639168118321159, 10.634519593233637, 9.691088853089594, 8.73240011764786, 7.784917379007638, 5.726653455763947, 4.878768664207245, 3.8865703913707637, 2.945595475601819, 3.833252186517857, 4.829438443462877, 5.779863057232324, 6.71526926545917, 7.68507095737247, 8.620466469616405, 9.573784061884158, 10.556633131667608, 11.569026441500732, 12.502579286270294, 11.710166514617534, 10.736867134037118, 9.74065415481061, 8.739394611426354, 7.784477694283232, 6.796558452527277, 4.7600220305675105, 3.8098602811845064, 2.8288874191217346, 1.9473927112512244, 2.8892911910244594, 3.9239013919483128, 4.842045853518085, 5.859135479014116, 6.896055053848483, 7.872883477295123, 8.9000254058448, 9.95601963997704, 10.887167638083303, 11.683201931426954, 10.758001488023488, 9.777163543314883, 8.721509204103446, 7.783026736120612, 6.785359622746359, 5.784910237135458, 3.9875649094222423, 2.918019337558391, 1.8909800874971006, 0.9312973142019461, 1.8645695751503606, 2.852123478877563, 3.8215336047846797, 4.878946496902963, 5.942953535305425, 7.016243872169019, 8.012538088492999, 9.002287893038098, 10.07578806156395, 10.836483954563194, 9.815756160376775, 8.836528545690317, 7.931542235883749, 6.946994823649935, 6.005563677411558, 4.9555847934031645, 2.9951238291964812, 1.982198394874742, 1.052584572155063, 0.0, 0.9776940528110354, 1.9724300470872556, 2.9460839007762694, 3.9875321842853206, 5.024685242538205, 5.996043136944271, 7.055192025622862, 8.053483635775619, 9.106678133755564, 9.9105731065391, 8.916948243642945, 7.893030005716927, 6.946917028705433, 5.976670445358678, 5.011684378742453, 3.969296301990627, 3.906451219929393, 2.9452214703687796, 1.91466284465842, 0.9729233832187832, 1.9128897362480923, 2.933592688626465, 3.9696394781571573, 4.962622186526377, 5.977384705485973, 6.954513505068033, 7.937932874328169, 8.947489983098638, 9.894891408075999, 10.754568140881554, 9.770574471059454, 8.830556795076786, 7.913056220213267, 6.881521279404479, 5.84052751700569, 4.897833926075844, 4.795447449741383, 3.837414069201457, 2.841865777969525, 1.9356224700354963, 2.8503297602560314, 3.8562558315620734, 4.9091194357317365, 5.953474047679438, 6.910370309827179, 7.87389975563509, 8.90977164287686, 9.897090930634668, 10.852781413867367, 11.768576677410978, 10.718594296169902, 9.751341742775603, 8.738619707357703, 7.796130291332531, 6.809783130461277, 5.847089878540538, 5.8207959369991915, 4.795581054547527, 3.852403295392703, 2.861392449000343, 3.8907758063556743, 4.864881387886074, 5.913454958173238, 6.896076327594931, 7.8634990079938545, 8.807955761648316, 9.733305881882032, 10.669513752021816, 11.70227334788379, 12.71281484033655, 11.731663859758337, 10.688937157664638, 9.761976596129442, 8.78198431295605, 7.720633806289291, 6.786493742042975, 6.751550744518075, 5.84143412150348, 4.80311218593099, 3.8193252563998197, 4.819083665861263, 5.814422922474722, 6.794117199198174, 7.776131146633091, 8.730552347549365, 9.7685499983662, 10.670958120893793, 11.67330066492345, 12.63082949249378, 13.664047715792316, 12.737230651066673, 11.680659034791262, 10.67880682895718, 9.605646027599574, 8.643540748790212, 7.718054971809759, 7.70450480547699, 6.757631520078855, 5.771599746076931, 4.751509354758835, 5.818244172973874, 6.773368214762619, 7.729669402632165, 8.74608673121192, 9.674363010760146, 10.662405820543293, 11.593564188345178, 12.61432800152603, 13.542897218988625, 14.483345575645817, 13.514194443565033, 12.51923364504187, 11.53470205022532, 10.570029412469333, 9.609225961526393, 8.658247222980402, 8.723547833293766, 7.650137426153208, 6.688961393423926, 5.752046213440476, 6.752180438025516, 7.824954179058841, 8.682212386551594, 9.637236118262708, 10.623380508238029, 11.606407631730756, 12.543739210437097, 13.550421868439983, 14.53773020919811, 15.541369594818583, 14.492285656191747, 13.45476250879376, 12.49694400381256, 11.548202238353939, 10.642953349834373, 9.60813868584721, 9.715097937804131, 8.669156416928711, 7.676933497425309, 6.684737925607673, 7.718319287725256, 8.744955411652493, 9.68983897455337, 10.673126191287741, 11.618863601449055, 12.677871695426177, 13.488322359314104, 14.445276619238957, 15.492701198894446, 15.664358264526443, 14.814247009482406, 13.894094667734862, 12.901074152187098, 12.581480093185446, 11.609595386666083, 10.631495433697001], [12.657851134870661, 13.507378082236112, 13.902422331829092, 12.942630178287521, 12.223581201404485, 13.03549918449695, 13.82623814430817, 14.81952850654429, 14.475895499621485, 13.531132043987709, 12.73343483502307, 11.706959244736918, 10.743016572096524, 9.753023673454422, 8.826600571277789, 7.855564744021127, 8.588002402914471, 9.600194362063313, 10.648741602675186, 11.668378073068954, 13.418076964688627, 13.818774260394536, 12.956449322103776, 12.002232099299578, 11.23600246542233, 11.98954387806585, 12.886344940230234, 13.81916023920115, 14.625913323799073, 14.523285746902959, 13.578875149764237, 12.649242140362972, 11.686237430288777, 10.704960953924026, 9.753565964090525, 8.921138502793573, 9.66011600158044, 10.543941152888626, 11.530560469928727, 12.477486858484747, 13.524907698299167, 12.818118438605723, 11.921617859411846, 10.973338226146613, 10.226898704133808, 11.001205431566545, 11.862743268742484, 12.769937761627672, 13.650489013639168, 14.56882270812379, 14.554051002516553, 13.586741586292291, 12.6756631974734, 11.727079201400691, 10.772796921337763, 9.972114127421783, 10.642061419190183, 11.514219423463642, 12.478234298180077, 13.415253409296437, 12.49191385167675, 11.856709363766575, 10.872492696947527, 10.010827602154325, 9.27394880806914, 9.977434005480603, 10.905306692155609, 11.712987099068647, 12.669159290362215, 13.615256357266198, 14.595630532500211, 14.599105290770732, 13.642567997126305, 12.765217203820276, 11.71710308285015, 10.987116946127243, 11.595727635456313, 12.533857257445863, 13.530182157405502, 13.476144696385752, 11.546890551411247, 10.824260724944883, 9.92244999059088, 8.97195443017282, 8.214316105454676, 8.973425679676978, 9.895254018952624, 10.682332209313373, 11.66476369521265, 12.638938481771584, 13.654403054299124, 14.631221522360853, 14.618540616603147, 13.691825541578815, 12.787231957524492, 11.948701181632329, 12.5759410566273, 13.495322478196316, 13.425382308719822, 12.484791155439435, 10.599848010810756, 9.82475122489271, 8.875751661648504, 7.972941059829135, 7.143214221667822, 8.039833368854076, 8.832837537537305, 9.757083568528126, 10.72999642896368, 11.661271157349585, 12.59586114620738, 13.62230722402931, 14.592994545156072, 14.733147060832902, 13.816689834312369, 12.907322610469555, 13.531669593103638, 13.4440346891174, 12.508072506746407, 11.527642542561802, 9.606645922687393, 8.81101068602054, 7.843489066796416, 6.983737630840444, 6.151271119372487, 6.989034473254076, 7.826490733722521, 8.810989621811816, 9.769145686186503, 10.725491130388141, 11.731276320572965, 12.696232083856064, 13.547683899318894, 14.593521565400808, 14.874826028836768, 13.89942242001252, 13.566796955796905, 12.509414825470838, 11.543954191037244, 10.538600254643427, 8.639439609389251, 7.799948765382222, 6.852338066477089, 5.959644533287925, 5.095604490389631, 6.003571797412071, 6.8729233928977775, 7.864480839371716, 8.869069767312277, 9.70884348454108, 10.760554722142144, 11.664429135851671, 12.615589563456908, 13.609489034190235, 14.492282743169499, 13.550189227873146, 12.602864637974486, 11.671006957695962, 10.691368462863771, 9.700112151120322, 7.710839553285094, 6.830652957524292, 5.899383679360143, 4.892489535907581, 4.064216657022733, 5.021528734712429, 5.86828913770227, 6.813654164535481, 7.794096457623983, 8.745781434191725, 9.708614223669395, 10.71326164697477, 11.672924924469514, 12.615390841352946, 13.554601576450981, 12.616862171132198, 11.612213646044676, 10.668782905900631, 9.710094170458897, 8.762611431818673, 6.704347508574982, 5.85646271701828, 4.864264444181799, 3.9232895284128544, 3.013546377421153, 4.009732634366173, 4.935075589783514, 5.87048179801036, 6.840283489923659, 7.7756790021675934, 8.728996594435346, 9.711845664218796, 10.72423897405192, 11.657791818821481, 12.687860567428567, 11.714561186848151, 10.718348207621645, 9.71708866423739, 8.762171747094268, 7.774252505338312, 5.737716083378546, 4.7875543339955415, 3.8065814719327697, 2.92508676406226, 2.069585381927755, 3.0866758286673837, 3.9972583860692756, 5.014348011565305, 6.051267586399672, 7.028096009846313, 8.043508471338274, 9.083375335561852, 10.014523333668116, 10.9614927194435, 11.735695540834522, 10.754857596125916, 9.69920325691448, 8.760720788931646, 7.763053675557394, 6.762604289946493, 4.9652589622332775, 3.8957133903694263, 2.8686741403081357, 1.9089913670129814, 1.0273440118694315, 2.014897915596634, 2.9767461373358697, 4.034159029454153, 5.054805124570083, 6.0718307314881095, 7.06812494781209, 8.057874752357188, 9.103912691612774, 10.150411398055335, 10.793450213187812, 9.814222598501354, 8.909236288694785, 7.924688876460971, 6.983257730222594, 5.9332788462142005, 3.972817882007517, 2.9598924476857773, 2.0302786249660985, 0.9776940528110354, 0.0, 0.9947359942762203, 1.9683898479652342, 3.0098381314742855, 4.04699118972717, 5.018349084133236, 6.077497972811827, 7.075789582964584, 8.128984080944528, 9.162744644955199, 9.894642296453982, 8.870724058527964, 7.924611081516469, 6.954364498169714, 5.989378431553489, 4.946990354801663, 4.864662709446607, 3.9034329598859934, 2.8662666213715946, 1.9245271599319578, 0.935195683437057, 1.95589863581543, 2.991945425346122, 3.984928133715342, 4.999690652674937, 5.976819452256998, 6.960238821517134, 7.969795930287602, 8.917197355264964, 9.880022572212605, 10.748268523870491, 9.808250847887823, 8.890750273024302, 7.839732768921694, 6.798739006522904, 5.856045415593059, 5.747051226454557, 4.789017845914631, 3.7934695546826998, 2.887226246748671, 1.872635707444996, 2.8785617787510382, 3.9314253829207013, 4.975779994868403, 5.932676257016144, 6.896205702824055, 7.932077590065825, 8.919396877823633, 9.875087361056332, 10.894032751918342, 11.676805785687117, 10.709553232292818, 9.696831196874918, 8.754341780849746, 7.7679946199784915, 6.798693655253712, 6.772399713712366, 5.747184831260701, 4.804007072105877, 3.8129962257135177, 2.913081753544639, 3.887187335075039, 4.935760905362204, 5.918382274783896, 6.88580495518282, 7.8302617088372815, 8.755611829070997, 9.69181969921078, 10.724579295072754, 11.735120787525515, 12.689875349275551, 11.647148647181853, 10.720188085646656, 9.733588089669224, 8.672237583002465, 7.738097518756149, 7.703154521231249, 6.793037898216655, 5.754715962644165, 4.770929033112995, 3.9729616129408774, 4.836728869663687, 5.816423146387139, 6.798437093822056, 7.752858294738329, 8.790855945555164, 9.693264068082758, 10.695606612112416, 11.653135439682744, 12.686353662981281, 13.6918458272604, 12.635274210984988, 11.630410605670354, 10.557249804312749, 9.595144525503386, 8.669658748522933, 8.656108582190164, 7.70923529679203, 6.723203522790106, 5.70311313147201, 4.996738650586488, 5.888417727848899, 6.807204244320167, 7.768392678400884, 8.696668957949111, 9.684711767732258, 10.615870135534143, 11.636633948714994, 12.56520316617759, 13.505651522834782, 14.465798220278208, 13.470837421755045, 12.486305826938494, 11.521633189182507, 10.560829738239567, 9.609850999693576, 9.67515161000694, 8.601741202866382, 7.6405651701371005, 6.70364999015365, 5.93067491563813, 6.945685373224055, 7.759747228239595, 8.714770959950709, 9.70091534992603, 10.683942473418757, 11.587952013447754, 12.572727815628948, 13.560036156387074, 14.563675542007548, 15.01977280857327, 14.265981576092093, 13.448547780525734, 12.499806015067113, 11.594557126547548, 10.559742462560385, 10.666701714517306, 9.620760193641885, 8.628537274138482, 7.6363417023208475, 6.898266389040016, 7.924902512967252, 8.76737381624137, 9.750661032975742, 10.696398443137056, 11.755406537114178, 12.532535162324761, 13.489489422249612, 14.536914001905101, 14.819570797077633, 13.994541200385703, 13.237002783805007, 13.878768204998133, 13.53308386989862, 12.561199163379257, 11.583099210410175], [13.652587129146882, 14.502114076512333, 14.84287990417776, 13.88308775063619, 12.995115002905102, 12.114275483066715, 12.831502150031952, 13.82479251226807, 13.60664150756349, 12.661878051929714, 11.873168551157827, 10.846692960871675, 9.88275028823128, 8.892757389589178, 8.132213486811736, 8.84210157920704, 9.582738397190694, 10.594930356339535, 11.643477596951408, 12.663114067345177, 14.41281295896485, 14.813510254670755, 13.951185316379995, 12.942689671648246, 12.007536266922946, 11.068320176635615, 11.891608945954015, 12.82442424492493, 13.631177329522854, 13.654031754844963, 12.718608865898993, 11.788975856497729, 10.825971146423534, 9.844694670058782, 9.059178879624472, 9.907675337979486, 10.654851995856662, 11.538677147164849, 12.52529646420495, 13.47222285276097, 14.519643692575386, 13.812854432881942, 12.916353853688065, 11.951440569392364, 10.998432505634424, 10.079981730136309, 10.868007274466265, 11.775201767351453, 12.65575301936295, 13.57408671384757, 13.69378471865131, 12.726475302427048, 11.815396913608156, 10.866812917535448, 10.07840983687171, 10.958650962607695, 11.636797413466406, 12.508955417739864, 13.4729702924563, 14.40998940357266, 13.48664984595297, 12.851445358042794, 11.867228691223746, 10.988929945400077, 10.045482609569756, 9.056210304050367, 9.91057069787939, 10.718251104792428, 11.674423296085996, 12.620520362989978, 13.600894538223992, 13.738839006905488, 12.782301713261061, 11.913673126503092, 11.022715998384097, 11.973653781313155, 12.590463629732536, 13.528593251722086, 14.524918151681725, 14.470880690661971, 12.541626545687466, 11.818996719221103, 10.9171859848671, 9.950056773418572, 8.985849906955293, 8.05220197824674, 8.900518024676405, 9.687596215037154, 10.670027700936432, 11.644202487495365, 12.659667060022905, 13.636485528084634, 13.758274332737903, 12.840281464261631, 12.09284487305844, 12.935238016818241, 13.570677050903523, 14.490058472472539, 14.420118302996041, 13.479527149715654, 11.594584005086976, 10.819487219168929, 9.870487655924725, 8.967677054105355, 8.056216727139034, 7.118609667423838, 7.838101543261086, 8.762347574251907, 9.735260434687461, 10.666535163073366, 11.60112515193116, 12.62757122975309, 13.598258550879853, 13.881602983515718, 13.122302749846316, 13.893859445655467, 14.52640558737986, 14.438770683393619, 13.502808501022626, 12.522378536838021, 10.601381916963613, 9.805746680296759, 8.838225061072636, 7.978473625116664, 7.083800604473947, 6.067810771823839, 6.831754739446302, 7.8162536275355965, 8.774409691910284, 9.730755136111922, 10.736540326296746, 11.701496089579845, 12.552947905042675, 13.598785571124589, 14.180438944370716, 14.885959255198433, 14.561532950073124, 13.504150819747057, 12.538690185313463, 11.533336248919646, 9.63417560366547, 8.794684759658441, 7.847074060753308, 6.954380527564145, 6.050087384708807, 5.082348095981834, 5.878187398621558, 6.869744845095496, 7.8743337730360565, 8.71410749026486, 9.765818727865925, 10.669693141575452, 11.620853569180689, 12.614753039914016, 13.589865472616093, 14.449169067013322, 13.597600632250705, 12.665742951972181, 11.68610445713999, 10.694848145396541, 8.705575547561313, 7.825388951800511, 6.894119673636362, 5.887225530183801, 5.058952651298953, 4.100305033282192, 4.87355314342605, 5.818918170259261, 6.799360463347763, 7.751045439915506, 8.713878229393176, 9.71852565269855, 10.678188930193295, 11.620654847076727, 12.574263570066506, 13.51200297538529, 12.606949640320895, 11.66351890017685, 10.704830164735116, 9.757347426094892, 7.699083502851202, 6.851198711294499, 5.859000438458018, 4.918025522689074, 4.008282371697373, 3.088508932935936, 3.940339595507294, 4.87574580373414, 5.845547495647439, 6.7809430078913735, 7.734260600159127, 8.717109669942577, 9.7295029797757, 10.663055824545262, 11.737800614928501, 12.70929718112437, 11.713084201897864, 10.71182465851361, 9.756907741370487, 8.768988499614531, 6.732452077654766, 5.7822903282717615, 4.80131746620899, 3.91982275833848, 3.064321376203975, 2.1325703045911886, 3.0025223917930552, 4.019612017289085, 5.056531592123452, 6.033360015570093, 7.048772477062053, 8.088639341285631, 9.019787339391895, 9.96675672516728, 10.891957168570745, 11.749593590402135, 10.693939251190699, 9.755456783207865, 8.757789669833613, 7.757340284222712, 5.959994956509497, 4.890449384645646, 3.863410134584356, 2.9037273612892016, 2.022080006145652, 1.060792391520439, 1.9820101430596495, 3.0394230351779328, 4.060069130293863, 5.077094737211889, 6.073388953535869, 7.063138758080968, 8.109176697336554, 9.155675403779115, 10.176403197965534, 10.808958592777575, 9.903972282971006, 8.919424870737192, 7.977993724498814, 6.9280148404904205, 4.967553876283737, 3.9546284419619973, 3.0250146192423184, 1.9724300470872556, 0.9947359942762203, 0.0, 0.973653853689014, 2.015102137198065, 3.05225519545095, 4.023613089857016, 5.082761978535607, 6.081053588688364, 7.134248086668309, 8.16800865067898, 9.161633513575135, 9.865460052804185, 8.91934707579269, 7.949100492445934, 6.984114425829709, 5.941726349077883, 5.859398703722828, 4.898168954162214, 3.861002615647815, 2.919263154208178, 1.9299316777132773, 0.9611626415392098, 1.9972094310699022, 2.990192139439122, 4.004954658398717, 4.982083457980777, 5.965502827240913, 6.975059936011381, 7.922461360988742, 8.885286577936384, 9.869280247758484, 10.802986842164044, 9.885486267300523, 8.834468763197915, 7.793475000799125, 6.850781409869279, 6.741787220730778, 5.783753840190852, 4.788205548958921, 3.8819622410248913, 2.8673717017212166, 1.9966136213518284, 3.0494772255214917, 3.9997555621801997, 4.937940262739923, 5.901469708547834, 6.937341595789604, 7.9246608835474115, 8.88035136678011, 9.89929675764212, 10.821132635595497, 11.704289226569038, 10.691567191151139, 9.749077775125967, 8.762730614254712, 7.793429649529933, 7.7671357079885865, 6.741920825536922, 5.798743066382098, 4.807732219989738, 3.90781774782086, 3.026921051209797, 4.075494621496961, 4.962084720660728, 5.929507401059652, 6.8739641547141135, 7.79931427494783, 8.735522145087614, 9.768281740949588, 10.778823233402349, 11.83617934061667, 12.641884641458073, 11.714924079922877, 10.728324083945445, 9.666973577278686, 8.73283351303237, 8.697890515507469, 7.787773892492875, 6.749451956920385, 5.765665027389215, 4.967697607217098, 3.9764625857984446, 4.956156862521897, 5.938170809956813, 6.892592010873086, 7.8729898873677975, 8.73696651395959, 9.73930905798925, 10.696837885559578, 11.730056108858115, 12.743607980621142, 13.630010205261211, 12.625146599946575, 11.55198579858897, 10.589880519779607, 9.664394742799153, 9.650844576466385, 8.70397129106825, 7.717939517066326, 6.69784912574823, 5.983275485772401, 5.028151443983656, 5.946937960454925, 6.908126394535641, 7.8364026740838675, 8.824445483867015, 9.746616143476148, 10.767379956656999, 11.695949174119594, 12.636397530776787, 13.642770517943157, 14.465573416031265, 13.481041821214715, 12.516369183458728, 11.555565732515788, 10.604586993969797, 10.66988760428316, 9.596477197142601, 8.63530116441332, 7.698385984429871, 6.917211750824043, 6.085419089358813, 6.8994809443743526, 7.854504676085467, 8.840649066060788, 9.823676189553515, 10.71869802138976, 11.703473823570953, 12.690782164329079, 13.694421549949553, 14.098549107143034, 15.03751537759271, 14.443283774801955, 13.494542009343334, 12.589293120823768, 11.554478456836605, 11.661437708793525, 10.615496187918104, 9.623273268414705, 8.63107769659707, 7.884803224225928, 7.154909260617923, 7.907107532376128, 8.8903947491105, 9.836132159271815, 10.895140253248936, 11.663281170266766, 12.620235430191617, 13.667660009847106, 13.824834802801414, 13.073317498955467, 14.008536585305624, 14.819225777346801, 14.527819864174841, 13.555935157655478, 12.577835204686396], [14.626240982835894, 15.475767930201345, 15.62897775317495, 14.66918559963338, 13.781212851902293, 12.872130199264774, 11.857848296342937, 12.851138658579057, 12.65900571326897, 11.714242257635192, 10.957240216519514, 9.930764626233362, 9.057578221388072, 8.06758532274597, 9.014759773915861, 9.815755432896054, 10.556392250879707, 11.568584210028547, 12.61713145064042, 13.636767921034188, 15.386466812653861, 15.67112052221635, 14.770235237939378, 13.728787520645437, 12.793634115920137, 11.854418025632805, 10.917955092265, 11.850770391235917, 12.657523475833841, 12.706395960550442, 11.80268053126068, 10.873047521859416, 10.000799079580325, 9.019522603215574, 9.941725166728597, 10.8813291916685, 11.628505849545675, 12.51233100085386, 13.49895031789396, 14.445876706449981, 15.493297546264401, 14.670464700427537, 13.735403775247448, 12.737538418389555, 11.784530354631615, 10.8660795791335, 9.89435342077725, 10.80154791366244, 11.682099165673936, 12.600432860158557, 12.777856384012997, 11.810546967788735, 10.990224846764947, 10.04164085069224, 10.960956123975835, 11.93230481629671, 12.610451267155419, 13.482609271428876, 14.44662414614531, 15.38364325726167, 14.460303699641985, 13.70905562558839, 12.724838958769341, 11.775027794397268, 10.831580458566947, 9.842308153047558, 8.936916844190375, 9.744597251103414, 10.700769442396982, 11.646866509300965, 12.627240684534978, 12.822910672267176, 11.957129646417853, 11.088501059659883, 11.905262285488222, 12.94730763500217, 13.564117483421551, 14.5022471054111, 15.498572005370736, 15.444534544350986, 13.515280399376481, 12.743679897349393, 11.775837323295066, 10.736154622415762, 9.771947755952484, 8.838299827243931, 7.92686417098739, 8.71394236134814, 9.696373847247418, 10.670548633806352, 11.686013206333891, 12.662831674395623, 12.933102265894695, 12.015109397418422, 12.975391160162564, 13.908891870507256, 14.544330904592538, 15.463712326161554, 15.393772156685056, 14.45318100340467, 12.56823785877599, 11.793141072857942, 10.844141509613737, 9.858121792834702, 8.842314576136225, 7.904707516421029, 6.864447689572071, 7.788693720562892, 8.761606580998446, 9.692881309384353, 10.627471298242147, 11.653917376064076, 12.624604697190838, 13.05643091667251, 14.004849036950441, 14.867513299344482, 15.500059441068876, 15.412424537082634, 14.476462354711641, 13.496032390527036, 11.575035770652628, 10.779400533985772, 9.811878914761648, 8.86891836384601, 7.892646111991937, 6.876656279341828, 5.8581008857572865, 6.842599773846581, 7.80075583822127, 8.757101282422909, 9.762886472607732, 10.72784223589083, 11.57929405135366, 12.625131717435574, 13.586461461463887, 14.49149568410381, 15.386772121045388, 14.477804673436072, 13.512344039002478, 12.506990102608661, 10.607829457354486, 9.768338613347455, 8.82072791444232, 7.879689932754773, 6.858932892226796, 5.891193603499823, 4.904533544932543, 5.896090991406481, 6.900679919347043, 7.740453636575847, 8.792164874176914, 9.696039287886439, 10.647199715491674, 11.641099186225002, 12.61621161892708, 13.475515213324309, 14.422839803222969, 13.639396805661193, 12.659758310829005, 11.668501999085557, 9.679229401250328, 8.799042805489524, 7.867773527325375, 6.860879383872814, 5.942673707224837, 4.923970074078638, 3.8998992897370357, 4.845264316570248, 5.8257066096587495, 6.777391586226493, 7.740224375704163, 8.744871799009537, 9.704535076504282, 10.647000993387714, 11.600609716377493, 12.538349121696276, 13.542997646783798, 12.637172753865862, 11.678484018424127, 10.731001279783907, 8.672737356540216, 7.824852564983512, 6.832654292147032, 5.891679376378088, 4.926638049157679, 3.9304517922126587, 2.96668574181828, 3.9020919500451265, 4.871893641958426, 5.80728915420236, 6.760606746470113, 7.743455816253563, 8.755849126086687, 9.689401970856249, 10.764146761239488, 11.83098538428904, 12.686738055586876, 11.685478512202621, 10.730561595059498, 9.742642353303545, 7.706105931343779, 6.755944181960775, 5.774971319898003, 4.893476612027493, 4.007561689063278, 2.974513163867911, 2.0288685381040414, 3.045958163600071, 4.082877738434438, 5.059706161881079, 6.075118623373039, 7.114985487596619, 8.046133485702883, 8.993102871478268, 9.918303314881733, 10.899141259590339, 11.667593104879712, 10.729110636896879, 9.731443523522627, 8.730994137911726, 6.933648810198512, 5.8641032383346605, 4.8370639882733695, 3.8773812149782154, 2.9653203190049546, 1.977766415277752, 1.0083562893706355, 2.0657691814889185, 3.086415276604849, 4.103440883522875, 5.099735099846856, 6.089484904391955, 7.135522843647538, 8.182021550090099, 9.202749344276517, 10.155396437785528, 10.87762613666002, 9.893078724426205, 8.95164757818783, 7.901668694179435, 5.941207729972751, 4.9282822956510115, 3.9986684729313327, 2.9460839007762694, 1.9683898479652342, 0.973653853689014, 0.0, 1.0414482835090513, 2.078601341761936, 3.049959236168002, 4.109108124846593, 5.107399734999349, 6.160594232979294, 7.194354796989964, 8.18797965988612, 9.211897897812138, 9.893000929481703, 8.922754346134948, 7.9577682795187235, 6.915380202766897, 6.8330525574118415, 5.871822807851228, 4.834656469336829, 3.892917007897192, 2.903585531402291, 1.9348164952282239, 1.0495736367753805, 2.0425563451446003, 3.031300804709703, 4.008429604291764, 4.9918489735519, 6.001406082322368, 6.948807507299729, 7.91163272424737, 8.89562639406947, 9.835644070052139, 10.859140120989537, 9.808122616886928, 8.767128854488139, 7.824435263558293, 7.715441074419791, 6.757407693879865, 5.761859402647934, 4.855616094713905, 3.84102555541023, 2.9702674750408424, 2.1229501155697275, 3.052119767885678, 3.96428640905091, 4.927815854858821, 5.963687742100591, 6.951007029858398, 7.906697513091096, 8.925642903953106, 9.847478781906483, 10.814731335300783, 11.665221044840152, 10.72273162881498, 9.736384467943726, 8.767083503218945, 8.7407895616776, 7.715574679225935, 6.772396920071111, 5.7813860736787515, 4.881471601509873, 4.000574904898811, 3.172203864410899, 4.014448926366207, 4.9818716067651305, 5.926328360419592, 6.851678480653308, 7.787886350793092, 8.820645946655066, 9.831187439107827, 10.862525486927657, 11.752326750189818, 12.68857793361189, 11.701977937634458, 10.6406274309677, 9.706487366721383, 9.671544369196482, 8.761427746181887, 7.723105810609399, 6.739318881078228, 5.9413514609061115, 4.950116439487459, 4.130984795678686, 5.076864865200648, 5.964184474950427, 6.925354093073276, 7.7893307196650685, 8.791673263694726, 9.749202091265055, 10.782420314563591, 11.795972186326619, 12.744048627316442, 13.598800453635588, 12.525639652277983, 11.56353437346862, 10.638048596488167, 10.624498430155397, 9.677625144757261, 8.691593370755339, 7.671502979437244, 6.956929339461416, 6.0018052976726715, 5.121765893611714, 6.046820449779476, 6.907995138161208, 7.896037947944356, 8.798980349181626, 9.819744162362479, 10.748313379825074, 11.688761736482267, 12.695134723648637, 13.6900955221718, 14.454695674903729, 13.490023037147742, 12.529219586204801, 11.578240847658808, 11.643541457972175, 10.570131050831616, 9.608955018102336, 8.672039838118884, 7.890865604513058, 7.059072943047828, 6.074308877531142, 7.029332609242257, 7.923705673290048, 8.906732796782775, 9.771062227095237, 10.755838029276433, 11.743146370034559, 12.746785755655033, 13.687874761701025, 14.62562438592369, 15.416937628490968, 14.468195863032348, 13.56294697451278, 12.528132310525617, 12.63509156248254, 11.58915004160712, 10.596927122103718, 9.604731550286083, 8.858457077914943, 8.037455547722047, 7.081935465532918, 8.06522268226729, 8.919188766501074, 9.978196860478196, 10.715645375972244, 11.672599635897097, 12.720024215552586, 12.851180949112399, 13.831172215153526, 14.794634434302814, 15.605323626343992, 15.501473717863854, 14.52958901134449, 13.551489058375408], [15.667689266344945, 16.517216213710395, 16.52833215687139, 15.568540003329819, 14.680567255598731, 13.693868613942733, 12.679586711020896, 11.943062969273445, 11.625274922444374, 10.680511466810598, 9.923509425694919, 8.897033835408767, 8.161764855492915, 8.861869409157638, 9.809043860327531, 10.686301303116315, 11.597840534388757, 12.610032493537599, 13.658579734149471, 14.67821620454324, 16.427915096162913, 16.570474925912787, 15.669589641635817, 14.628141924341875, 13.692988519616575, 12.753643995472531, 11.73969350694296, 10.942694701930305, 11.74944778652823, 11.672665169725848, 10.768949740436085, 9.83931673103482, 9.2273320558729, 9.813806689627242, 10.736009253140267, 11.742379134477778, 12.669954133054725, 13.553779284362912, 14.540398601403012, 15.487324989959033, 16.534745829773453, 15.569819104123976, 14.634758178943887, 13.636892822085994, 12.683884758328054, 11.765305548973226, 10.71609183545521, 9.893472224356827, 10.774023476368324, 11.692357170852945, 11.744125593188402, 10.77681617696414, 10.248891971529932, 10.835924937103908, 11.755240210387505, 12.793354759105988, 13.651899550664469, 14.524057554937928, 15.488072429654363, 16.425091540770723, 15.501751983151037, 14.608410029284828, 13.62419336246578, 12.674382198093706, 11.730934862263386, 10.741662556743997, 9.758655258868334, 8.836521561797802, 9.79269375309137, 10.738790819995353, 11.701311438825018, 11.78917988144258, 11.215796771182838, 11.882785146071551, 12.699546371899892, 13.773719578240591, 14.6055657669306, 15.543695388920149, 16.540020288879788, 16.485982827860038, 14.556728682885533, 13.643034301045832, 12.675191726991505, 11.635509026112201, 10.671302159648922, 9.73765423094037, 8.748602585665349, 7.805866672042528, 8.788298157941806, 9.74461938809639, 10.76008396062393, 11.73690242868566, 12.19176939065968, 12.80939348383009, 13.769675246574234, 14.72650560252177, 15.585779188101586, 16.505160609670604, 16.435220440194108, 15.494629286913721, 13.609686142285042, 12.80866577903961, 11.830930165077106, 10.80300496357843, 9.787197746879956, 8.84959068716476, 7.809330860315802, 6.88061803125728, 7.853530891692834, 8.766952063674392, 9.701542052532186, 10.727988130354117, 11.698675451480876, 12.670086652195032, 13.718668410278324, 14.557666247936814, 15.39367690485267, 16.308609650155983, 15.517910638220693, 14.537480674036088, 12.61648405416168, 11.794925240167439, 10.827403620943315, 9.81380153458974, 8.837529282735666, 7.821539450085559, 6.802984056501018, 5.9345240845409695, 6.892680148915658, 7.831172036712947, 8.83695722689777, 9.801912990180867, 10.653364805643697, 11.699202471725611, 12.660532215753925, 13.565566438393848, 14.460842875335425, 15.373989786509421, 14.55379232251153, 13.548438386117713, 11.649277740863537, 10.783863319529122, 9.836252620623988, 8.824573103498503, 7.803816062970526, 6.836076774243553, 5.8494167156762735, 4.988015302100869, 5.974750673637081, 6.814524390865884, 7.866235628466951, 8.770110042176476, 9.721270469781711, 10.71516994051504, 11.690282373217117, 12.549585967614346, 13.496910557513006, 14.42876823779153, 13.701206594338057, 12.709950282594608, 10.72067768475938, 9.840491088998576, 8.909221810834426, 7.902327667381866, 6.887556877968567, 5.868853244822368, 4.844782460480766, 3.919335070860285, 4.899777363948787, 5.85146234051653, 6.814295129994201, 7.818942553299574, 8.77860583079432, 9.721071747677751, 10.67468047066753, 11.612419875986314, 12.617068401073835, 13.560499141217878, 12.719932301933182, 11.772449563292959, 9.714185640049267, 8.866300848492564, 7.874102575656083, 6.933127659887139, 5.968086332666729, 4.9719000757217096, 3.91156891256201, 2.976162704335164, 3.9459643962484634, 4.8813599084923975, 5.834677500760151, 6.817526570543601, 7.829919880376725, 8.763472725146286, 9.829020057966725, 10.81739656680352, 11.891368792336761, 12.726926795711677, 11.772009878568554, 10.784090636812598, 8.747554214852832, 7.797392465469827, 6.816419603407055, 5.934924895536545, 5.049009972572329, 4.015961447376962, 3.0703168216130923, 2.049893423236443, 3.08681299807081, 4.052913100729396, 5.0336703398639875, 6.073537204087567, 7.004685202193831, 7.951654587969215, 8.87685503137268, 9.857692976081285, 10.913347315292722, 11.770558920405932, 10.77289180703168, 9.772442421420779, 7.975097093707563, 6.905551521843712, 5.878512271782421, 4.918829498487267, 4.006768602514006, 3.0192146987868034, 2.0498045728796868, 1.0697044411252905, 2.044966993095798, 3.061992600013824, 4.058286816337804, 5.048036620882903, 6.0940745601384885, 7.1405732665810495, 8.16130106076747, 9.113948154276478, 10.072246615151098, 10.934527007935259, 9.993095861696881, 8.943116977688486, 6.982656013481803, 5.969730579160063, 5.040116756440384, 3.987532184285321, 3.0098381314742855, 2.015102137198065, 1.0414482835090513, 0.0, 1.0371530582528847, 2.008510952658951, 3.0676598413375418, 4.065951451490299, 5.119145949470244, 6.152906513480914, 7.146531376377069, 8.170449614303088, 9.116562591314583, 9.964202629644001, 8.999216563027776, 7.956828486275949, 7.874500840920892, 6.913271091360278, 5.87610475284588, 4.934365291406243, 3.9450338149113424, 2.976264778737275, 2.00495670854849, 1.0119740001792705, 1.989852521200652, 2.966981320782712, 3.9504006900428474, 4.959957798813315, 5.907359223790676, 6.870184440738317, 7.854178110560417, 8.794195786543085, 9.826686807168695, 10.849570900395978, 9.808577137997188, 8.865883547067343, 8.756889357928843, 7.798855977388916, 6.803307686156985, 5.8970643782229555, 4.882473838919282, 4.011715758549894, 3.0658920348680496, 2.021537422920348, 2.9228381255418587, 3.886367571349769, 4.922239458591539, 5.9095587463493455, 6.8652492295820435, 7.8841946204440525, 8.80603049839743, 9.77328305179173, 10.78600508720963, 11.728494503234801, 10.777832751452776, 9.808531786727997, 9.782237845186652, 8.757022962734986, 7.813845203580162, 6.822834357187802, 5.922919885018925, 5.015061521109734, 3.966487950822569, 2.9838665814008767, 3.948140815940536, 4.892597569594997, 5.8179476898287135, 6.754155559968497, 7.786915155830471, 8.797456648283232, 9.821077203418604, 10.710878466680764, 11.783330970119549, 12.74342622114351, 11.68207571447675, 10.747935650230435, 10.712992652705534, 9.802876029690939, 8.764554094118449, 7.780767164587279, 6.903919638314635, 5.904963158813809, 4.925268882090356, 4.046282520235318, 4.930453684125833, 5.891623302248681, 6.755599928840475, 7.757942472870132, 8.715471300440461, 9.748689523738998, 10.762241395502027, 11.702600343807388, 12.707463949122022, 13.567087935787034, 12.604982656977672, 11.679496879997219, 11.665946713664448, 10.719073428266313, 9.73304165426439, 8.712951262946294, 7.827475209681675, 6.872351167892931, 5.916049980023384, 5.016238104814146, 5.874264347336615, 6.862307157119762, 7.7652495583570325, 8.786013371537884, 9.714582589000479, 10.655030945657671, 11.661403932824042, 12.656364731347205, 13.640896326163755, 14.531471320656793, 13.570667869713853, 12.61968913116786, 12.684989741481223, 11.611579334340664, 10.650403301611384, 9.713488121627934, 8.761411474733318, 7.9229261767543875, 6.868592963942812, 6.081260337672132, 6.889974882465454, 7.873002005958181, 8.737331436270644, 9.722107238451837, 10.709415579209963, 11.713054964830437, 12.65414397087643, 13.591893595099094, 14.582756712900265, 15.5096441465414, 14.604395258021832, 13.569580594034669, 13.676539845991588, 12.630598325116168, 11.638375405612768, 10.646179833795133, 9.729002948135204, 8.831739634133717, 7.876219551944588, 7.117150410697166, 7.88545797567648, 8.944466069653602, 9.68191458514765, 10.638868845072501, 11.68629342472799, 12.678083552283152, 13.66310522633329, 14.62087238738618, 15.549401447857566, 16.542922001372904, 15.571037294853541, 14.59293734188446], [16.685144006219446, 17.401520905400854, 16.408178569856865, 15.448386416315293, 14.589692499058009, 13.584994183969158, 12.63426314679973, 11.627659667931407, 10.588121864191491, 9.643358408557713, 8.886356367442033, 7.859880777155881, 8.823823449796276, 9.756413265843339, 10.70358771701323, 11.580845159802013, 12.60878886753211, 13.620980826680952, 14.669528067292825, 15.689164537686594, 17.438863429306267, 17.57259145803287, 16.6717061737559, 15.63025845646196, 14.69510505173666, 13.755760527592615, 12.741810039063044, 11.94481123405039, 10.971755088729626, 10.635512111472963, 9.7317966821832, 8.802163672781935, 9.840887690754661, 10.708350546312943, 11.630553109825966, 12.636922991163477, 13.59988336230871, 14.564727617506266, 15.551346934546366, 16.498273323102385, 17.57189888802634, 16.57193563624406, 15.636874711063971, 14.639009354206078, 13.686001290448138, 12.76742208109331, 11.718208367575293, 10.895588756476911, 9.996330778569721, 10.81590041678856, 10.706972534935517, 9.739663118711254, 10.79709909693938, 11.730468793789608, 12.649784067073204, 13.687898615791687, 14.581828779918453, 15.535005888081281, 16.499020762797716, 17.436039873914076, 16.538905041403922, 15.610526561404912, 14.626309894585864, 13.67649873021379, 12.73305139438347, 11.74377908886408, 10.760771790988418, 9.838638093917886, 9.015001055292768, 9.862334065930968, 10.785031778354352, 10.752026823189695, 11.715657871853086, 12.7607664406386, 13.594090228585591, 14.668263434926288, 15.535494996184585, 16.473624618174135, 17.471160947389468, 17.52313588611292, 15.593881741138416, 14.645150833165916, 13.677308259111589, 12.637625558232285, 11.673418691769006, 10.739770763060454, 9.750719117785433, 8.807983204162612, 7.993356604350486, 8.828339727625725, 9.843804300153264, 10.820622768214996, 11.783755425050654, 12.795128510978458, 13.831846626595539, 14.600008016303377, 15.433125780858346, 16.440390924117292, 17.263453912706733, 16.531782345166604, 14.646839200537926, 13.810782311159693, 12.83304669719719, 11.805121495698515, 10.78931427900004, 9.851707219284844, 8.811447392435886, 7.8827345633773644, 6.983137935448378, 7.850672403203727, 8.78526239206152, 9.811708469883449, 10.782395791010215, 11.753806991724371, 12.802388749807662, 13.641386587466151, 14.477397244382008, 15.39232998968532, 16.328895200182725, 15.574633732288971, 13.653637112414563, 12.797041772287523, 11.829520153063399, 10.815918066709823, 9.839645814855752, 8.823655982205644, 7.805100588621102, 6.9366406166610535, 6.000286903394682, 6.914892376242283, 7.9206775664271065, 8.885633329710206, 9.737085145173037, 10.78292281125495, 11.744252555283262, 12.649286777923185, 13.544563214864763, 14.457710126038759, 15.423170760472352, 14.585591444370596, 12.68643079911642, 11.785979851649206, 10.838369152744072, 9.826689635618587, 8.80593259509061, 7.838193306363637, 6.8515332477963575, 5.990131834220953, 5.058471013166417, 5.89824473039522, 6.949955967996287, 7.853830381705814, 8.80499080931105, 9.798890280044377, 10.774002712746455, 11.633306307143684, 12.580630897042344, 13.512488577320868, 14.537744097329234, 13.747103340847492, 11.757830743012263, 10.877644147251461, 9.932667168214374, 8.916414598118985, 7.889673410088651, 6.870969776942452, 5.84689899260085, 4.921451602980369, 3.983497703478123, 4.935182680045867, 5.898015469523537, 6.9026628928289115, 7.862326170323657, 8.804792087207089, 9.758400810196868, 10.696140215515651, 11.700788740603173, 12.644219480747218, 13.68118841811916, 12.809602621545842, 10.751338698302153, 9.90345390674545, 8.911255633908969, 7.96784782391044, 6.984456737754407, 5.988270480809386, 4.913685444682094, 3.978279236455248, 3.0296847357778, 3.9650802480217346, 4.9183978402894875, 5.901246910072938, 6.913640219906062, 7.847193064675624, 8.79186699971384, 9.780243508550635, 10.854215734083876, 11.868737874827078, 12.809162936821437, 11.821243695065483, 9.784707273105717, 8.834545523722712, 7.853572661659939, 6.97207795378943, 6.0861630308252135, 5.047159288549969, 4.1015146627861, 3.052009955356527, 2.050524986483085, 3.015760042476511, 3.996517281611103, 5.036384145834683, 5.9675321439409466, 6.914501529716331, 7.839701973119795, 8.8205399178284, 9.876194257039836, 10.81467672502267, 11.810044865284565, 10.809595479673664, 9.012250151960448, 7.9427045800965965, 6.9156653300353055, 5.955982556740151, 5.04392166076689, 4.056367757039688, 3.0869576311325715, 2.0718209732453747, 1.0078139348429132, 2.0248395417609393, 3.02113375808492, 4.010883562630019, 5.056921501885603, 6.103420208328164, 7.124148002514583, 8.076795096023591, 9.035093556898211, 10.019640969132025, 11.030248919949765, 9.98027003594137, 8.019809071734686, 7.0068836374129475, 6.077269814693269, 5.024685242538205, 4.04699118972717, 3.0522551954509503, 2.078601341761936, 1.0371530582528847, 0.0, 0.9713578944060661, 2.0305067830846566, 3.0287983932374134, 4.081992891217359, 5.115753455228029, 6.109378318124183, 7.133296556050202, 8.079409533061696, 9.049656116408451, 10.014642183024677, 8.993981544528832, 8.911653899173777, 7.950424149613164, 6.913257811098765, 5.971518349659128, 4.982186873164228, 4.01341783699016, 3.016099115086967, 2.0231164067177474, 0.9526994629477672, 1.9298282625298273, 2.9132476317899627, 3.922804740560431, 4.870206165537792, 5.833031382485433, 6.817025052307533, 7.757042728290201, 8.78953374891581, 9.854779971075287, 10.845730196250074, 9.903036605320228, 9.794042416181728, 8.836009035641801, 7.84046074440987, 6.934217436475841, 5.919626897172167, 5.048868816802779, 4.001843834470424, 2.957489222522723, 1.885685067288974, 2.849214513096885, 3.885086400338654, 4.872405688096461, 5.828096171329159, 6.847041562191168, 7.768877440144546, 8.736129993538846, 9.748852028956746, 10.691341444981918, 11.677688605853172, 10.845684844980884, 10.819390903439537, 9.794176020987871, 8.850998261833048, 7.8599874154406875, 6.883710959325833, 5.909605377795433, 4.861031807508268, 3.8784104380865756, 2.9109877576876513, 3.855444511342112, 4.780794631575828, 5.717002501715612, 6.749762097577586, 7.760303590030347, 8.78392414516572, 9.673725408427881, 10.746177911866665, 11.762736654262461, 12.63044391986583, 11.78508870848332, 11.750145710958419, 10.820330769565437, 9.782008833992949, 8.798221904461778, 7.798463495000334, 6.799507015499508, 5.819812738776055, 4.847721826789221, 3.893300625872948, 4.854470243995796, 5.71844687058759, 6.720789414617247, 7.678318242187575, 8.711536465486112, 9.72508833724914, 10.665447285554505, 11.670310890869139, 12.743471692226745, 13.642135715230557, 12.716649938250104, 12.683401453538949, 11.736528168140813, 10.75049639413889, 9.730406002820795, 8.722019066367375, 7.76689502457863, 6.810593836709083, 5.817677411368049, 4.83711128908373, 5.825154098866877, 6.728096500104147, 7.748860313284999, 8.677429530747593, 9.617877887404786, 10.624250874571157, 11.61921167309432, 12.60374326791087, 13.568415905666857, 14.529219356609797, 13.63714387104236, 13.70172987441878, 12.62831946727822, 11.66714343454894, 10.730228254565489, 9.655955331419017, 8.817470033440086, 7.763136820628511, 6.838966214187889, 5.852821824212569, 6.835848947705296, 7.700178378017759, 8.684954180198952, 9.672262520957078, 10.675901906577552, 11.616990912623544, 12.554740536846209, 13.54560365464738, 14.546588731551463, 15.588678485225751, 14.587035333909169, 14.693279978929144, 13.647338458053724, 12.649323738756122, 11.657128166938486, 10.623546804820903, 9.726283490819416, 8.770763408630287, 7.807216466582464, 6.848304917423595, 7.907313011400717, 8.644761526894765, 9.601715786819618, 10.649140366475107, 11.640930494030268, 12.625952168080406, 13.583719329133295, 14.51224838960468, 15.514661997971327, 16.527152838628258, 15.61039208175896], [17.509139269489054, 16.559494756369503, 15.566152420825516, 14.606360267283945, 13.74766635002666, 12.74296803493781, 11.792236997768383, 10.78563351890006, 9.746095715160143, 8.801332259526367, 8.19112560984396, 8.831238671561948, 9.795181344202343, 10.727771160249404, 11.674945611419295, 12.552203054208078, 13.580146761938176, 14.592338721087017, 15.64088596169889, 16.66052243209266, 18.41022132371233, 17.535530641049657, 16.596958731834356, 15.546758346271888, 14.683226795374456, 13.706013582423653, 12.64498769377558, 11.709761962220888, 10.723014955588427, 9.793485962441617, 9.229261880808718, 9.773521567188002, 10.812245585160728, 11.679708440719008, 12.601911004232031, 13.608280885569542, 14.571241256714774, 15.536085511912331, 16.52270482895243, 17.46963121750845, 18.543256782432408, 17.502869748831316, 16.567808823651227, 15.569943466793333, 14.616935403035393, 13.698356193680565, 12.64914248016255, 11.826522869064167, 10.870884938054225, 9.918055991496157, 10.204437733561035, 10.711021013117321, 11.768456991345447, 12.701826688195673, 13.62114196147927, 14.659256510197752, 15.553186674324518, 16.506363782487348, 17.470378657203785, 18.40739776832014, 17.51026293580999, 16.54146067399217, 15.55724400717312, 14.607432842801046, 13.663985506970725, 12.674713201451336, 11.691705903575674, 10.769572206505142, 9.910586707542548, 8.964489640638565, 9.88718735306195, 10.852870097410388, 11.815796049407657, 12.777804853617159, 13.825918974587285, 14.612402542081021, 15.46414949230189, 16.402279114291442, 17.3342491618559, 18.246208897205996, 16.565239635544486, 15.576084945753172, 14.608242371698845, 13.56855967081954, 12.604352804356262, 11.67070487564771, 10.681653230372689, 9.738917316749868, 8.902488365829427, 7.930495302333322, 8.945959874860863, 9.922778342922594, 10.839823429930815, 11.85119651585862, 12.882656916868097, 13.650818306575935, 14.483936071130904, 15.49120121438985, 16.31426420297929, 17.25485535625968, 15.618197094943994, 14.78214020556576, 13.804404591603259, 12.776479390104583, 11.760672173406105, 10.823065113690909, 9.78280528684195, 8.813668675964621, 7.892269696927318, 6.952827977911324, 7.887417966769118, 8.913864044591048, 9.838463795890377, 10.809874996604533, 11.85319904008022, 12.69219687773871, 13.528207534654566, 14.443140279957879, 15.379705490455281, 16.431155135729846, 14.624995006820631, 13.76839966669359, 12.800878047469466, 11.787275961115892, 10.811003709261819, 9.79501387661171, 8.776458483027167, 7.867574729248311, 6.909418664873622, 6.0170479509498795, 7.022833141134703, 7.941701334590369, 8.793153150053199, 9.838990816135112, 10.79506284555582, 11.700097068195744, 12.59537350513732, 13.508520416311317, 14.47398105074491, 15.479334987138728, 13.65778869352249, 12.757337746055272, 11.809727047150139, 10.798047530024654, 9.777290489496677, 8.809551200769704, 7.822891142202423, 6.9614897286270185, 5.967602774645358, 5.000400305102817, 6.00602397287645, 6.9098983865859775, 7.861058814191213, 8.85495828492454, 9.824813003019013, 10.684116597416242, 11.631441187314902, 12.563298867593426, 13.588554387601793, 14.579810699345241, 12.729188637418332, 11.849002041657528, 10.904025062620441, 9.887772492525052, 8.861031304494718, 7.842327671348518, 6.818256887006916, 5.892809497386435, 4.954203288512125, 4.037338254753463, 4.954083474403701, 5.958730897709075, 6.9183941752038205, 7.860860092087252, 8.809211100469426, 9.74695050578821, 10.751599030875731, 11.695029771019776, 12.731998708391718, 13.78096051595191, 11.72269659270822, 10.874811801151516, 9.882613528315035, 8.939205718316504, 7.955814632160472, 6.959628375215452, 5.88504333908816, 4.949637130861314, 4.0003903208118015, 3.06723582272933, 3.9744658451696515, 4.957314914953102, 5.969708224786226, 6.903261069555787, 7.820509105307773, 8.808885614144568, 9.88285783967781, 10.897379980421011, 11.852296897564134, 12.79260158947155, 10.756065167511784, 9.805903418128779, 8.824930556066006, 7.943435848195495, 7.05752092523128, 6.018517182956034, 5.072872557192165, 4.023367849762593, 3.0212305715170857, 2.0444021480704446, 3.025159387205037, 4.065026251428616, 4.99617424953488, 5.943143635310264, 6.868344078713728, 7.849182023422333, 8.90483636263377, 9.843318830616603, 10.840985943990855, 11.780953374079731, 9.983608046366514, 8.914062474502662, 7.887023224441371, 6.927340451146217, 6.015279555172957, 5.0277256514457545, 4.058315525538638, 3.0431788676514406, 1.9791718292489793, 1.053481647354873, 2.0497758636788537, 3.0395256682239524, 4.085563607479537, 5.132062313922098, 6.152790108108517, 7.105437201617525, 8.063735662492144, 9.048283074725958, 10.07186384612997, 10.951627930347437, 8.991166966140753, 7.978241531819013, 7.048627709099335, 5.996043136944271, 5.018349084133236, 4.023613089857016, 3.0499592361680024, 2.008510952658951, 0.9713578944060661, 0.0, 1.0591488886785907, 2.0574404988313475, 3.1106349968112927, 4.1443955608219625, 5.138020423718117, 6.161938661644135, 7.108051638655629, 8.078298222002385, 9.04328428861861, 9.9653394389349, 9.883011793579843, 8.92178204401923, 7.88461570550483, 6.942876244065193, 5.953544767570293, 4.984775731396226, 3.987457009493033, 2.9944743011238133, 1.9240573573538333, 1.070809631935281, 2.0542290011954165, 3.0637861099658847, 4.011187534943246, 4.9740127518908865, 5.9580064217129864, 6.898024097695655, 7.930515118321264, 8.99576134048074, 10.03675510287953, 10.874394499726295, 10.765400310587795, 9.807366930047868, 8.811818638815936, 7.905575330881906, 6.890984791578232, 6.020226711208845, 4.973201728876491, 3.928847116928789, 2.85704296169504, 2.005912151556779, 3.026067769744108, 4.013387057501915, 4.969077540734613, 5.988022931596622, 6.90985880955, 7.8771113629443, 8.8898333983622, 9.832322814387371, 10.818669975258626, 11.817042739386949, 11.790748797845604, 10.765533915393938, 9.822356156239113, 8.831345309846753, 7.855068853731898, 6.880963272201498, 5.832389701914334, 4.8497683324926415, 3.882345652093717, 3.013418362310764, 3.9387684825444804, 4.874976352684264, 5.8997681459822875, 6.910309638435049, 7.924905514571174, 8.814706777833335, 9.887159281272119, 10.903718023667915, 11.771425289271285, 12.705565353517601, 12.721503605364486, 11.791688663971502, 10.753366728399014, 9.769579798867843, 8.769821389406399, 7.7708649099055735, 6.791170633182121, 5.819079721195287, 4.864658520279014, 4.012444094964448, 4.876420721556242, 5.878763265585899, 6.836292093156227, 7.869510316454764, 8.883062188217792, 9.806428654959959, 10.811292260274595, 11.8844530616322, 12.785734759446623, 13.637126583284385, 13.654759347945014, 12.707886062546878, 11.721854288544955, 10.70176389722686, 9.69337696077344, 8.738252918984696, 7.781951731115149, 6.7890353057741155, 5.8084691834897955, 5.0439096556512, 5.886070351072799, 6.9068341642536515, 7.835403381716246, 8.775851738373438, 9.782224725539809, 10.777185524062972, 11.761717118879522, 12.726389756635509, 13.68719320757845, 14.601336974250142, 14.673087768824844, 13.599677361684286, 12.638501328955005, 11.701586148971554, 10.627313225825082, 9.788827927846153, 8.734494715034577, 7.810324108593955, 6.824179718618635, 6.085762269986482, 6.858152228986411, 7.842928031167604, 8.83023637192573, 9.833875757546204, 10.774964763592196, 11.712714387814861, 12.703577505616032, 13.704562582520115, 14.746652336194403, 15.55122843711695, 15.66463787333521, 14.61869635245979, 13.620681633162187, 12.628486061344551, 11.594904699226968, 10.69764138522548, 9.742121303036352, 8.778574360988529, 7.8196628118296605, 7.157226333681903, 7.802735377863418, 8.75968963778827, 9.80711421744376, 10.79890434499892, 11.783926019049058, 12.741693180101947, 13.670222240573333, 14.67263584893998, 15.685126689596908, 16.574585184966743], [16.521427195809252, 15.571782682689703, 14.578440347145714, 13.618648193604143, 12.778421700545964, 11.773723385457114, 10.822992348287684, 9.816388869419361, 8.776851065679445, 7.832087610045669, 8.819653446982919, 9.788223726420192, 10.752166399060586, 11.684756215107646, 12.631930666277537, 13.50918810906632, 14.537131816796418, 15.549323775945258, 16.597871016557132, 17.531040129446644, 17.492902661723118, 16.54781856736986, 15.609246658154555, 14.559046272592086, 13.713982145893757, 12.736768932942955, 11.675743044294881, 10.74051731274019, 9.753770306107729, 8.824241312960918, 9.778346570969699, 10.707979580370964, 11.74670359834369, 12.63669349557725, 13.558896059090273, 14.565265940427784, 15.528226311573016, 16.493070566770573, 17.479689883810675, 18.426616272366694, 18.51062392498581, 17.54847438915867, 16.585805502602945, 15.587940145745051, 14.723085907182279, 13.72510737944226, 12.698112494415188, 11.68007214970246, 10.710245834063889, 9.757416887505821, 10.01722008337334, 10.915033479390235, 11.74097794438294, 12.689561940455649, 13.662561830322415, 14.585682456108861, 15.376092803890401, 16.41542563094885, 17.344474116403706, 18.191340064688212, 18.09605635587575, 17.36028538402262, 16.376068717203573, 15.4262575528315, 14.48281021700118, 13.493537911481788, 12.510530613606129, 11.588396916535595, 10.729411417573, 9.783314350669018, 8.950456353835577, 9.902669774911795, 10.774073144730036, 11.736081948939537, 12.784196069909664, 13.570679637403401, 14.42242658762427, 15.36055620961382, 16.29252625717828, 17.204485992528372, 17.151033055610245, 16.394909655783625, 15.427067081729298, 14.387384380849994, 13.423177514386715, 12.489529585678163, 11.500477940403142, 10.557742026780321, 9.72131307585988, 8.749320012363775, 8.00922887563449, 8.972578020424, 9.798100525253194, 10.809473611180998, 11.840934012190477, 12.609095401898315, 13.442213166453284, 14.44947830971223, 15.27254129830167, 16.213132451582055, 16.320060341763146, 15.623760811621462, 14.646025197658961, 13.618099996160286, 12.60229277946181, 11.664685719746613, 10.624425892897655, 9.632493385995074, 8.711094406957772, 7.771652687941777, 6.950686967542745, 7.950534444371073, 8.796740891212755, 9.768152091926911, 10.8114761354026, 11.65047397306109, 12.486484629976946, 13.401417375280259, 14.337982585777661, 15.389432231052226, 15.369566414417141, 14.610020272749292, 13.642498653525168, 12.628896567171594, 11.65262431531752, 10.636634482667413, 9.61807908908287, 8.686399439278764, 7.728243374904076, 6.835872660980333, 6.002019610321046, 6.899978429912748, 7.751430245375577, 8.79726791145749, 9.7533399408782, 10.658374163518124, 11.5536506004597, 12.466797511633697, 13.43225814606729, 14.437612082461108, 14.589625935009732, 13.598958352110975, 12.65134765320584, 11.639668136080356, 10.618911095552379, 9.651171806825406, 8.664511748258127, 7.803110334682722, 6.786427484675811, 5.81922501513327, 4.96430106819883, 5.868175481908357, 6.819335909513591, 7.813235380246921, 8.783090098341393, 9.642393692738622, 10.589718282637282, 11.521575962915806, 12.546831482924173, 13.538087794667621, 13.720561508145202, 12.724430682772896, 11.745645668676143, 10.729393098580754, 9.70265191055042, 8.683948277404221, 7.659877493062619, 6.734430103442138, 5.775269012704041, 4.856162964783916, 3.91236056972608, 4.917007993031454, 5.876671270526199, 6.819137187409631, 7.767488195791806, 8.70522760111059, 9.709876126198111, 10.653306866342156, 11.690275803714098, 12.749606547338207, 12.78184548138681, 11.873287622051125, 10.826635514691976, 9.780826324372208, 8.797435238216176, 7.801248981271155, 6.726663945143863, 5.791257736917017, 4.821456045003718, 3.8860605327597835, 2.93274294049203, 3.9155920102754806, 4.927985320108605, 5.861538164878167, 6.778786200630153, 7.767162709466949, 8.84113493500019, 9.855657075743391, 10.810573992886514, 11.798493234642468, 11.815214056190374, 10.86505230680737, 9.884079444744597, 9.002584736874086, 8.070392731638448, 7.004165007515234, 6.058520381751364, 5.009015674321793, 3.972096099487426, 2.995267676040785, 1.9834364825274156, 3.0233033467509953, 3.9544513448572594, 4.901420730632644, 5.8266211740361085, 6.807459118744713, 7.863113457956149, 8.801595925938983, 9.799263039313235, 10.799712424924136, 11.007896739644707, 9.973211363181253, 8.946172113119962, 7.986489339824808, 7.074428443851547, 6.086874540124344, 5.117464414217228, 4.102327756330031, 3.0383207179275695, 2.004347175325213, 1.0080529590012324, 1.9978027635463311, 3.0264147188009467, 4.072913425243508, 5.0936412194299265, 6.046288312938935, 7.004586773813554, 7.989134186047369, 9.012714957451381, 10.012811968104383, 10.000695949485992, 9.037390420497603, 8.107776597777924, 7.055192025622862, 6.077497972811827, 5.082761978535607, 4.109108124846593, 3.0676598413375413, 2.0305067830846566, 1.0591488886785907, 0.0, 0.998291610152757, 2.0514861081327025, 3.0852466721433722, 4.078871535039527, 5.102789772965545, 6.04890274997704, 7.019149333323794, 7.984135399940019, 9.026523476691846, 10.92591247746994, 9.98093093269782, 8.94376459418342, 8.002025132743784, 7.012693656248883, 6.043924620074817, 5.046605898171624, 4.053623189802404, 2.983206246032424, 2.025618151805137, 1.0421987825450016, 2.0459245967310613, 2.9933260217084223, 3.956151238656063, 4.940144908478163, 5.880162584460831, 6.91265360508644, 7.977899827245917, 8.991836180393642, 9.934529771323488, 11.824549199266386, 10.866515818726459, 9.870967527494527, 8.964724219560496, 7.9501336802568225, 7.0793755998874355, 6.032350617555082, 4.98799600560738, 3.9161918503736306, 2.9607206714266354, 2.014037551093693, 2.9955255442670916, 3.9512160274997896, 4.970161418361799, 5.891997296315177, 6.859249849709476, 7.871971885127376, 8.814461301152548, 9.800808462023802, 10.85005562028552, 12.65340164532656, 11.824682804072529, 10.854042423137635, 9.863031576745275, 8.81205390859014, 7.83794832705974, 6.789374756772576, 5.806753387350883, 4.8393307069519595, 3.8948739532974987, 2.9695238330637825, 3.9057317032035663, 4.881906632747464, 5.892448125200225, 6.9070440013363505, 7.796845264598511, 8.869297768037296, 9.885856510433092, 10.753563776036462, 11.687703840282778, 13.584156452845443, 12.748673718829746, 11.710351783257256, 10.726564853726085, 9.726806444264641, 8.727849964763815, 7.748155688040363, 6.77606477605353, 5.821643575137257, 4.893899685951182, 3.9071760720755435, 4.909518616105201, 5.867047443675529, 6.900265666974065, 7.913817538737094, 8.788567141725135, 9.793430747039771, 10.866591548397377, 11.7678732462118, 12.619265070049561, 14.53721787851873, 13.66487111740512, 12.678839343403197, 11.658748952085102, 10.650362015631682, 9.695237973842938, 8.738936785973392, 7.746020360632357, 6.765454238348038, 5.847984069393987, 4.916825701592101, 5.937589514772953, 6.866158732235547, 7.806607088892741, 8.812980076059112, 9.807940874582275, 10.75362347834899, 11.718296116104977, 12.679099567047917, 13.583475461015318, 15.497556291770847, 14.556662416542526, 13.595486383813245, 12.658571203829796, 11.584298280683324, 10.745812982704395, 9.691479769892819, 8.767309163452198, 7.781164773476878, 6.826239158212054, 5.888907579505712, 6.873683381686906, 7.860991722445031, 8.864631108065506, 9.8057201141115, 10.743469738334165, 11.71586543193623, 12.696468941989583, 13.73855869566387, 14.533366923882127, 16.525309286445697, 15.57568140731803, 14.577666688020429, 13.585471116202793, 12.55188975408521, 11.654626440083723, 10.699106357894594, 9.735559415846772, 8.776647866687904, 7.8730382315908685, 6.83349072838272, 7.790444988307572, 8.837869567963061, 9.829659695518222, 10.814681369568362, 11.77244853062125, 12.68251016689353, 13.684923775260177, 14.697414615917106, 15.556723671731918], [15.523135585656496, 14.573491072536946, 13.580148736992957, 12.620356583451386, 11.81738328973168, 10.856664201924827, 9.93989102206128, 8.994979052873811, 8.005850709160727, 8.814559387659314, 9.802125224596564, 10.770695504033839, 11.734638176674233, 12.667227992721292, 13.614402443891183, 14.491659886679967, 15.519603594410064, 16.531795553558904, 17.552384989687656, 16.532748519293886, 16.494611051570363, 15.549526957217102, 14.610955048001799, 13.56075466243933, 12.804962025713836, 11.902619508355928, 10.879784226139217, 9.969516956221472, 8.982769949589011, 9.806713090574563, 10.760818348583344, 11.034821125674256, 11.909685896418663, 12.858828224311004, 13.828940823948344, 14.664733202554329, 15.386113343317405, 16.413779023341124, 17.364592735687715, 17.435201157774245, 17.512332314833056, 16.550182779005915, 15.587513892450188, 14.589648535592294, 13.814065787002358, 12.890957954855233, 11.903385897626967, 10.928020575387487, 9.958194259748916, 10.739888665119466, 11.015511693526097, 10.097321679744937, 10.88812598076163, 11.836709976834339, 12.809709866701105, 13.613757577926119, 14.404167925707661, 15.44350075276611, 16.372549238220962, 17.219415186505472, 17.12413147769301, 17.486186990775703, 16.501970323956655, 15.552159159584582, 14.767015683067026, 13.844441977323621, 12.860822474213844, 11.895696174319438, 10.93952398302587, 10.781605960821777, 9.948747963988334, 9.084957975266496, 9.921221181108725, 10.883229985318227, 11.931344106288353, 12.59875475922066, 13.450501709441529, 14.388631331431078, 15.320601378995537, 16.232561114345632, 16.179108177427505, 17.2107923767215, 16.425358691882053, 15.38567599100275, 14.42146912453947, 13.487821195830918, 12.498769550555897, 11.556033636933076, 10.719604686012635, 9.747611622516533, 9.007520485787246, 8.154866220778702, 8.945248561631884, 9.956621647559688, 10.869009134007733, 11.637170523715573, 12.470288288270542, 13.477553431529488, 14.300616420118928, 15.241207573399315, 15.3481354635804, 16.303341465077132, 15.644316807811716, 14.61639160631304, 13.600584389614566, 12.66297732989937, 11.622717503050412, 10.63078499614783, 9.709386017110527, 8.769944298094535, 7.9489785776955015, 7.132822644725774, 7.943888927591445, 8.915300128305601, 9.839551257219856, 10.678549094878347, 11.514559751794204, 12.429492497097517, 13.36605770759492, 14.417507352869482, 14.397641536234397, 15.373227032416187, 14.640790263677925, 13.62718817732435, 12.650915925470278, 11.63492609282017, 10.616370699235627, 9.68469104943152, 8.726534985056832, 7.83416427113309, 7.000311220473803, 6.0822666302674495, 6.898578281754267, 7.94441594783618, 8.781415062695457, 9.686449285335382, 10.581725722276959, 11.494872633450955, 12.460333267884547, 13.465687204278364, 13.62683545821595, 14.597249962263732, 13.649639263358598, 12.637959746233113, 11.617202705705136, 10.649463416978163, 9.662803358410883, 8.80140194483548, 7.784719094828568, 6.817516625286027, 5.962592678351587, 5.050463682263058, 5.966483945892281, 6.8957331425135004, 7.81116522015865, 8.67046881455588, 9.61779340445454, 10.549651084733064, 11.57490660474143, 12.56616291648488, 12.825799223215888, 13.722722292925653, 12.7439372788289, 11.727684708733511, 10.700943520703177, 9.682239887556978, 8.658169103215375, 7.732721713594895, 6.773560622856798, 5.854454574936673, 4.910652179878837, 4.099296193386156, 5.023819306904889, 5.901634949676211, 6.795563317609064, 7.7333027229278475, 8.737951248015369, 9.681381988159412, 10.718350925531354, 11.777681669155463, 11.819307178505778, 12.762281129879664, 11.824927124844733, 10.779117934524965, 9.795726848368933, 8.799540591423913, 7.72495555529662, 6.789549347069774, 5.819747655156474, 4.88435214291254, 3.931034550644787, 3.0978802106301826, 4.010483082375185, 4.944035927144746, 5.806861322447411, 6.795237831284207, 7.8692100568174475, 8.883732197560649, 9.838649114703772, 10.826568356459727, 10.852675753309342, 11.802837502692347, 10.882371054897355, 10.000876347026844, 9.068684341791204, 8.002456617667992, 7.056811991904121, 6.00730728447455, 4.970387709640183, 3.9935592861935416, 2.9817280926801724, 2.0675185525349096, 2.9825264666745173, 3.929495852449902, 4.854696295853366, 5.835534240561971, 6.891188579773407, 7.829671047756241, 8.827338161130493, 9.827787546741394, 10.009605129491948, 10.951150716338622, 9.94446372327272, 8.984780949977566, 8.072720054004304, 7.085166150277101, 6.1157560243699844, 5.100619366482788, 4.036612328080326, 3.00263878547797, 2.006344569153989, 1.0420179693302456, 2.02812310864819, 3.074621815090751, 4.09534960927717, 5.047996702786177, 6.006295163660797, 6.990842575894611, 8.014423347298623, 9.014520357951625, 9.002404339333234, 10.015329773654972, 9.106068207930681, 8.053483635775619, 7.075789582964584, 6.081053588688364, 5.107399734999349, 4.065951451490298, 3.0287983932374134, 2.0574404988313475, 0.998291610152757, 0.0, 1.0531944979799452, 2.086955061990615, 3.080579924886769, 4.104498162812788, 5.050611139824282, 6.020857723171036, 6.985843789787261, 8.028231866539087, 9.92762086731718, 10.888850616877795, 9.942056204336177, 9.00031674289654, 8.01098526640164, 7.042216230227574, 6.0448975083243806, 5.051914799955161, 3.9814978561851806, 3.0239097619578943, 2.040490392697759, 1.0476329865783043, 1.9950344115556653, 2.9578596285033063, 3.9418532983254067, 4.881870974308075, 5.914361994933685, 6.979608217093162, 7.993544570240885, 8.93623816117073, 10.873470134864451, 11.831503515404378, 10.869259137647283, 9.963015829713253, 8.94842529040958, 8.077667210040193, 7.030642227707839, 5.986287615760137, 4.914483460526387, 3.9590122815793922, 2.9965093287073388, 1.9972339341143348, 2.952924417347033, 3.971869808209042, 4.89370568616242, 5.8609582395567195, 6.873680274974619, 7.81616969099979, 8.802516851871044, 9.851764010132761, 11.655110035173802, 12.72281232686241, 11.836514200751282, 10.845503354358922, 9.794525686203787, 8.820420104673387, 7.771846534386222, 6.78922516496453, 5.821802484565606, 4.877345730911145, 3.9519956106774283, 3.0446549726368644, 3.883615022594707, 4.894156515047468, 5.908752391183594, 6.7985536544457545, 7.871006157884538, 8.887564900280335, 9.755272165883703, 10.689412230130019, 12.585864842692684, 13.615367377134898, 12.692823560870902, 11.709036631339732, 10.709278221878288, 9.710321742377461, 8.73062746565401, 7.758536553667176, 6.8041153527509035, 5.876371463564829, 4.889647849689189, 4.0484418855385, 4.921528602451685, 5.925349518578562, 6.938901390341591, 7.790275531572379, 8.795139136887014, 9.86829993824462, 10.76958163605904, 11.620973459896803, 13.538926268365971, 14.485799553764107, 13.661311121016844, 12.641220729698748, 11.632833793245329, 10.677709751456584, 9.721408563587039, 8.728492138246004, 7.747926015961685, 6.830455847007632, 5.899297479205746, 5.119895141862091, 5.970117227304696, 6.87327755262975, 7.8796505397961205, 8.839454051292183, 9.755331868196233, 10.72000450595222, 11.68080795689516, 12.58518385086256, 14.499264681618088, 15.4799776727178, 14.577958161426892, 13.641042981443443, 12.56677005829697, 11.728284760318042, 10.673951547506466, 9.749780941065845, 8.763636551090524, 7.808710935825699, 6.871379357119357, 6.055989008776043, 6.96495021751418, 7.931301571802515, 8.872390577848508, 9.774982915044072, 10.717573821783473, 11.698177331836826, 12.740267085511114, 13.535075313729369, 15.527017676292939, 16.4989966634933, 15.560138465634076, 14.56794289381644, 13.534361531698856, 12.63709821769737, 11.681578135508241, 10.718031193460419, 9.75911964430155, 8.855510009204513, 7.815962505996365, 7.019444631788854, 7.99335855678772, 8.946558369291818, 9.897622186036076, 10.803961707331158, 11.684218556740774, 12.68663216510742, 13.69912300576435, 14.55843206157916], [14.52117189799309, 13.57152738487354, 12.578185049329552, 11.61839289578798, 10.815419602068275, 9.855812183213393, 8.939039003349846, 7.994127034162378, 8.783789993354494, 9.707398549950629, 10.694964386887879, 11.663534666325154, 11.922058598818703, 12.757571006800664, 13.702711718781135, 14.673747546037797, 15.405032444003425, 16.30433131618649, 16.55042130202425, 15.530784831630482, 15.492647363906956, 14.547563269553697, 13.608991360338393, 12.558790974775924, 11.80299833805043, 10.901767489644493, 9.878932207427782, 8.994495301505518, 9.760709233782778, 10.699552252865878, 11.653657510874659, 11.728418817611594, 10.856491398438719, 11.80563372633106, 12.775746325968399, 13.611538704574384, 14.332918845337456, 15.360584525361178, 16.311398237707767, 16.433237470110836, 16.51036862716965, 15.54821909134251, 14.585550204786783, 13.58768484792889, 12.812102099338952, 11.890105936143799, 10.902533878915532, 10.043717779078996, 10.736133543942683, 11.63272782741078, 11.75684579904461, 10.790919371682275, 9.834931482781686, 10.783515478854394, 11.75651536872116, 12.560563079946174, 13.350973427727713, 14.390306254786163, 15.319354740241016, 16.166220688525524, 16.07093697971306, 16.484223303112298, 15.50000663629325, 14.550195471921176, 13.76505199540362, 12.843589958612187, 11.85997045550241, 11.100668441638021, 11.717463267219637, 11.636564334799052, 10.690082069506847, 9.778555667203834, 8.86802668312878, 9.830035487338282, 10.878149608308409, 11.545560261240714, 12.397307211461582, 13.335436833451132, 14.26740688101559, 15.179366616365686, 15.125913679447557, 16.15759787874155, 16.450049342649898, 15.589068643902682, 14.781246213124366, 13.847598284415813, 12.870023128705395, 12.131323331393295, 11.620773194593925, 10.60256999649381, 9.74885459130576, 8.84846391271604, 7.892054063651939, 8.903427149579743, 9.815814636027788, 10.583976025735629, 11.417093790290595, 12.424358933549541, 13.247421922138981, 14.188013075419368, 14.294940965600455, 15.250146967097185, 16.241553980700438, 15.551137714565947, 14.53533049786747, 13.597723438152274, 12.557463611303316, 11.565531104400732, 10.610554525691816, 9.62490267207181, 8.690312683214016, 7.826420336663111, 6.890694429611499, 7.862105630325655, 8.786356759239911, 9.625354596898402, 10.461365253814257, 11.37629799911757, 12.312863209614973, 13.364312854889537, 13.344447038254453, 14.320032534436242, 15.383596874332357, 14.561934285577255, 13.585662033723182, 12.569672201073073, 11.551116807488532, 10.619437157684422, 9.661281093309734, 8.74743051617714, 7.741645325992317, 6.775864322204787, 5.845383783774321, 6.891221449856234, 7.728220564715512, 8.633254787355437, 9.528531224297012, 10.441678135471008, 11.407138769904602, 12.41249270629842, 12.573640960236004, 13.56430854313476, 14.511919242039895, 13.572705854486017, 12.55194881395804, 11.584209525231067, 10.597549466663787, 9.736148053088382, 8.71946520308147, 7.752262733538929, 6.799103565775972, 5.843425096528985, 4.9132894479123355, 5.842538644533555, 6.7579707221787055, 7.6172743165759345, 8.564598906474593, 9.496456586753117, 10.521712106761484, 11.512968418504933, 11.772604725235944, 12.683276872405731, 13.662061886502483, 12.662430816986413, 11.63568962895608, 10.61698599580988, 9.592915211468279, 8.667467821847797, 7.7083067311097, 6.789200683189575, 5.845398288131739, 4.892257607652082, 3.9706248089249425, 4.848440451696265, 5.742368819629119, 6.680108224947903, 7.684756750035424, 8.628187490179467, 9.665156427551409, 10.724487171175518, 10.766112680525833, 11.70908663189972, 12.755738739258868, 11.713864042777868, 10.730472956621835, 9.734286699676815, 8.659701663549523, 7.724295455322676, 6.754493763409377, 5.8190982511654425, 4.865780658897689, 3.890841624896109, 2.957288584395239, 3.8908414291648006, 4.753666824467466, 5.742043333304262, 6.816015558837503, 7.830537699580704, 8.785454616723827, 9.773373858479783, 9.799481255329397, 10.749643004712402, 11.730615866775175, 10.96063966485365, 10.018741185080415, 8.952513460957203, 8.006868835193332, 6.957364127763761, 5.920444552929394, 4.943616129482753, 3.916474200933075, 2.860479966800836, 1.929331968694572, 2.8763013544699567, 3.8015017978734216, 4.782339742582026, 5.837994081793462, 6.776476549776296, 7.774143663150549, 8.77459304876145, 8.956410631512005, 9.89795621835868, 10.827215908045096, 10.03797544795751, 9.125914551984252, 8.138360648257049, 7.168950522349931, 6.153813864462734, 5.089806826060272, 4.034472800063176, 3.038178583739195, 2.0484287791940963, 0.9749286106682444, 2.0214273171108053, 3.042155111297224, 3.9948022048062324, 4.953100665680852, 5.937648077914666, 6.961228849318678, 7.961325859971681, 7.94920984135329, 8.96213527567503, 9.891749098394708, 9.106678133755565, 8.12898408094453, 7.13424808666831, 6.160594232979296, 5.119145949470244, 4.081992891217359, 3.110634996811293, 2.0514861081327025, 1.0531944979799452, 0.0, 1.0337605640106697, 2.0273854269068243, 3.051303664832843, 3.9974166418443375, 4.967663225191092, 5.9326492918073175, 6.975037368559144, 8.874426369337238, 9.835656118897852, 10.831206041666327, 10.053511240876487, 9.064179764381587, 8.010023868152178, 6.973977078621485, 5.980994370252265, 4.910577426482285, 3.933448626900225, 2.9500292576400895, 1.9404721488696213, 0.9930707238922604, 1.9558959408399015, 2.939889610662002, 3.8799072866446704, 4.91239830727028, 5.956113338058964, 6.940350072260941, 7.8830436631907865, 9.82027563688451, 10.778309017424437, 11.758408974977433, 11.0162103276932, 10.001619788389526, 9.001102963680749, 7.948239359511085, 6.903884747563383, 5.832080592329634, 4.868551146521723, 3.8893484909986555, 2.8900730964056516, 1.9520723986355988, 2.971017789497608, 3.891741998499015, 4.858994551893314, 5.871716587311214, 6.814206003336385, 7.800553164207639, 8.849800322469358, 10.653146347510397, 11.720848639199005, 12.70291120983006, 11.738342516650238, 10.687364848495104, 9.713259266964704, 8.66468569667754, 7.682064327255846, 6.714641646856922, 5.770184893202461, 4.844834772968745, 3.915522599745247, 2.882763003883273, 3.893304496336034, 4.9067887035201885, 5.796589966782349, 6.869042470221133, 7.885601212616929, 8.753308478220298, 9.687448542466614, 11.58390115502928, 12.613403689471493, 13.58566272316222, 12.601875793631049, 11.602117384169604, 10.603160904668778, 9.623466627945326, 8.651375715958492, 7.6969545150422185, 6.769210625856145, 5.782487011980505, 4.87820541131058, 3.9206765837402515, 4.924497499867128, 5.938049371630156, 6.788311843908974, 7.793175449223609, 8.866336250581215, 9.767617948395635, 10.619009772233397, 12.536962580702566, 13.483835866100701, 14.469867640102624, 13.534059891990065, 12.525672955536646, 11.570548913747901, 10.614247725878355, 9.62133130053732, 8.640765178253, 7.7232950092989485, 6.792136641497063, 5.897834426055857, 4.969265208593263, 5.872425533918316, 6.878798521084686, 7.837490363628778, 8.753368180532828, 9.718040818288815, 10.678844269231755, 11.583220163199154, 13.497300993954683, 14.478013985054394, 15.439190017783675, 14.53388214373476, 13.459609220588288, 12.621123922609359, 11.566790709797782, 10.64262010335716, 9.65647571338184, 8.701550098117016, 7.764218519410674, 6.8339282929698095, 5.964098198802747, 6.930449553091081, 7.871538559137074, 8.773019227380667, 9.715610134120068, 10.69621364417342, 11.738303397847709, 12.533111626065963, 14.525053988629534, 15.497032975829898, 16.452977627925392, 15.460782056107757, 14.427200693990173, 13.529937379988686, 12.574417297799558, 11.610870355751736, 10.651958806592866, 9.748349171495828, 8.70880166828768, 7.797383915982621, 6.992506538076286, 7.945706350580384, 8.896770167324641, 9.801998019667753, 10.682254869077369, 11.684668477444015, 12.697159318100944, 13.556468373915754], [13.51370514662444, 12.56406063350489, 11.570718297960902, 10.61092614441933, 9.807952850699625, 8.93323182833811, 8.112942558120716, 9.006044005302702, 9.79570696449482, 10.719315521090957, 11.706881358028207, 12.675451637465482, 12.920498673021637, 12.029647408284802, 12.880947324926659, 13.781613765998996, 14.509533746655592, 15.408832618838659, 15.542954550655601, 14.523318080261832, 14.485180612538306, 13.540096518185047, 12.601524608969743, 11.551324223407274, 10.795531586681781, 9.97918713476921, 9.052835762198653, 9.988061493753344, 10.772626204923103, 11.711469224006207, 12.665574482014987, 12.726858891814528, 11.854931472641653, 11.077710127815198, 11.953981932113923, 12.71604000722655, 13.437420147989624, 14.465085828013345, 15.415899540359932, 15.425770718742186, 15.502901875801001, 14.54075233997386, 13.578083453418133, 12.58021809656024, 11.804635347970303, 10.967525581268516, 10.076437433686403, 11.037283971326822, 11.748050515083008, 12.64464479855111, 12.755285873247546, 11.789359445885209, 10.83337155698462, 10.05559188033853, 10.934750974866684, 11.66506438259834, 12.45547473037988, 13.49480755743833, 14.423856042893181, 15.270721991177691, 15.175438282365226, 15.476756551743648, 14.4925398849246, 13.542728720552526, 12.75758524403497, 11.991297007354458, 11.03387401027328, 12.032958809793055, 12.729380238359962, 12.635004409001988, 11.688522143709783, 10.776995741406768, 9.866466757331715, 9.008731671370887, 9.990444813354298, 10.65006156389288, 11.50180851411375, 12.439938136103299, 13.371908183667756, 14.283867919017851, 14.230414982099722, 15.262099181393719, 15.442582591281246, 14.581601892534032, 13.817217946649436, 12.995305333158083, 12.043926683476265, 12.986662597099086, 12.61921326879686, 11.601010070696745, 10.747294665508695, 9.846903986918974, 8.890494137854873, 8.082123333612348, 8.920315938679956, 9.688477328387794, 10.521595092942762, 11.528860236201707, 12.351923224791147, 13.292514378071534, 13.399442268252619, 14.35464826974935, 15.346055283352602, 15.580615262877718, 14.866504703696181, 13.928897643980985, 13.106343164891584, 12.563971178603666, 11.608994599894752, 10.623342746274746, 9.688752757416951, 8.824860410866046, 7.889134503814433, 7.04080181435826, 7.890858061892078, 8.729855899550568, 9.565866556466425, 10.480799301769736, 11.417364512267138, 12.4688141575417, 12.448948340906616, 13.424533837088406, 14.48809817698452, 15.551794385051977, 14.584102107926116, 13.568112275276007, 12.549556881691466, 11.617877231887356, 10.659721167512668, 9.745870590380076, 8.740085400195252, 7.774304396407721, 6.843823857977255, 6.047058979043468, 6.8327218673676775, 7.737756090007602, 8.63303252694918, 9.546179438123174, 10.511640072556766, 11.516994008950583, 11.67814226288817, 12.668809845786926, 13.61642054469206, 14.571145928688951, 13.550388888160974, 12.582649599434001, 11.595989540866722, 10.734588127291318, 9.717905277284403, 8.750702807741863, 7.797543639978906, 6.841865170731919, 5.9117295221152695, 4.97889874946312, 5.862472024830871, 6.7217756192281, 7.66910020912676, 8.600957889405283, 9.62621340941365, 10.617469721157098, 10.850346631759344, 11.76101877892913, 12.739803793025882, 13.660870891189349, 12.634129703159015, 11.615426070012816, 10.591355285671213, 9.665907896050733, 8.706746805312635, 7.78764075739251, 6.843838362334674, 5.890697681855016, 4.969064883127877, 3.9848005566258307, 4.846870122281285, 5.784609527600068, 6.78925805268759, 7.732688792831634, 8.769657730203575, 9.828988473827684, 9.84385458704923, 10.786828538423118, 11.78904564790809, 12.712304116980802, 11.728913030824769, 10.73272677387975, 9.658141737752457, 8.722735529525611, 7.752933837612312, 6.8175383253683774, 5.864220733100624, 4.889281699099043, 3.9557286585981735, 3.027201534094366, 3.8581681271196304, 4.846544635956427, 5.920516861489668, 6.926682497920726, 7.881599415063849, 8.865832758790642, 8.877223161852795, 9.8273849112358, 10.73136267565906, 11.739149122131103, 11.017181259283351, 9.950953535160139, 9.005308909396268, 7.9558042019666955, 6.9188846271323285, 5.942056203685688, 4.9149142751360095, 3.8589200410037705, 2.9277720428975065, 1.9808026571221218, 2.906003100525586, 3.8868410452341915, 4.9175855764308345, 5.856068044413669, 6.853735157787922, 7.854184543398823, 7.922650067501335, 8.86419565434801, 9.793455344034426, 10.75313811732958, 10.159675115994919, 9.172121212267715, 8.2027110863606, 7.187574428473403, 6.123567390070941, 5.068233364073846, 4.071939147749865, 3.0821893432047665, 2.0086891746789144, 0.9991265997298772, 2.019854393916296, 2.961041640795562, 3.9193401016701817, 4.903887513903996, 5.927468285308008, 6.927565295961011, 6.91544927734262, 7.928374711664359, 8.857988534384038, 9.9105731065391, 9.162744644955199, 8.168008650678978, 7.194354796989964, 6.152906513480913, 5.115753455228028, 4.1443955608219625, 3.085246672143372, 2.086955061990615, 1.0337605640106697, 0.0, 0.9936248628961544, 2.0175431008221727, 2.9636560778336674, 3.933902661180422, 4.898888727796647, 5.941276804548473, 7.840665805326568, 8.801895554887182, 9.797445477655657, 10.739184939095294, 10.086350154653928, 9.021940839292505, 7.9858940497618125, 6.992911341392593, 5.9224943976226125, 4.945365598040552, 3.9619462287804166, 2.9523891200099484, 2.0049876950325873, 1.0421624780849463, 1.9324228592933514, 2.87244053527602, 3.9049315559016295, 4.922352774048294, 5.906589508250271, 6.849283099180116, 8.78651507287384, 9.744548453413767, 10.724648410966763, 11.686440053739048, 11.018946006127118, 10.013019934821076, 8.960156330651412, 7.91580171870371, 6.843997563469961, 5.88046811766205, 4.901265462138983, 3.9019900675459787, 2.9639893697759256, 2.072432685374963, 2.8842752471303648, 3.8515278005246643, 4.864249835942564, 5.806739251967735, 6.793086412838989, 7.842333571100708, 9.645679596141747, 10.702715438759837, 11.684778009390891, 12.612210032703896, 11.699281819635432, 10.725176238105032, 9.676602667817868, 8.693981298396174, 7.72655861799725, 6.782101864342788, 5.856751744109072, 4.927439570885573, 3.8946799750235996, 3.0672080511069053, 3.8993219521515385, 4.789123215413699, 5.861575718852483, 6.878134461248279, 7.745841726851648, 8.679981791097964, 10.57643440366063, 11.605936938102843, 12.644258873675334, 13.570142840103372, 12.614034355309933, 11.615077875809106, 10.635383599085655, 9.66329268709882, 8.708871486182547, 7.781127596996472, 6.794403983120834, 5.8901223824509055, 4.932593554880578, 4.098401054637998, 4.932472271950006, 5.780845092540324, 6.785708697854959, 7.858869499212565, 8.760151197026985, 9.611543020864747, 11.529495829333916, 12.476369114732051, 13.462400888733974, 14.48249128005207, 13.537589926676974, 12.58246588488823, 11.626164697018684, 10.63324827167765, 9.652682149393328, 8.735211980439276, 7.804053612637391, 6.909751397196183, 5.9811821797335885, 5.046329088689186, 5.956218166209404, 6.830023612260128, 7.745901429164178, 8.710574066920165, 9.671377517863105, 10.575753411830505, 12.489834242586033, 13.470547233685744, 14.431723266415025, 15.368638446398474, 14.471526191728616, 13.633040893749689, 12.578707680938113, 11.654537074497489, 10.668392684522168, 9.713467069257344, 8.776135490551003, 7.845845264110135, 6.976015169943072, 6.104353107861951, 6.948958204261791, 7.765552476012017, 8.708143382751418, 9.68874689280477, 10.730836646479059, 11.525644874697313, 13.517587237260884, 14.489566224461248, 15.463614369702224, 15.461194447249216, 14.738912120980107, 13.858251551120473, 13.015297265497853, 12.622787326892063, 11.663875777733194, 10.760266142636159, 9.720718639428009, 8.809300887122946, 8.004423509216611, 7.119609905351254, 7.974189812449358, 8.794531268299103, 9.674788117708719, 10.677201726075365, 11.689692566732294, 12.549001622547104], [12.520080283728284, 11.570435770608734, 10.577093435064745, 9.617301281523174, 8.81432798780347, 7.939606965441958, 8.953888868363796, 9.865637497094376, 10.655300456286493, 11.599944709225307, 12.587510546162557, 13.556080825599832, 13.909884449780435, 12.96211196686053, 12.019932214878528, 12.882829824404105, 13.610749805060703, 14.510048677243768, 14.549329687759448, 13.52969321736568, 13.49155574964215, 12.54647165528889, 11.607899746073587, 10.557699360511117, 9.801906723785626, 8.985562271873057, 9.893782072441732, 10.829007803996424, 11.632219696714778, 12.592098412140556, 13.546203670149337, 13.716244668573326, 12.84431724940045, 12.010174686390926, 11.092966822065792, 11.817256065631659, 12.538636206394735, 13.566301886418454, 14.517115598765042, 14.432145855846029, 14.509277012904844, 13.547127477077703, 12.584458590521976, 11.586593233664082, 10.811010485074148, 9.973900718372363, 10.917383743929483, 11.878230281569902, 12.607644006874683, 13.525273986685459, 13.744671650006344, 12.778745222644007, 11.822757333743418, 10.98805643891426, 10.073735864818554, 10.766280441003449, 11.55669078878499, 12.596023615843439, 13.52507210129829, 14.3719380495828, 14.276654340770335, 14.483131688847491, 13.498915022028443, 12.54910385765637, 11.763960381138816, 10.997672144458305, 11.87482032051636, 12.873905120036135, 13.588973730151636, 13.624390185760786, 12.67790792046858, 11.766381518165566, 10.855852534090513, 9.941196229946616, 9.129429703306167, 9.751277622297989, 10.603024572518859, 11.541154194508408, 12.473124242072865, 13.38508397742296, 13.331631040504831, 14.363315239798826, 14.44895772838509, 13.587977029637875, 12.82359308375328, 12.001680470261931, 12.884872993719345, 13.827608907342166, 13.608599045555659, 12.590395847455543, 11.736680442267494, 10.836289763677772, 9.87987991461367, 9.014587892188077, 8.059300828631825, 8.789693386792903, 9.622811151347872, 10.630076294606816, 11.453139283196256, 12.393730436476643, 12.50065832665773, 13.45586432815446, 14.447271341757713, 14.58699039998156, 13.87287984080003, 12.935272781084834, 13.947289475134664, 13.553356955362464, 12.59838037665355, 11.612728523033544, 10.67813853417575, 9.814246187624844, 8.878520280573232, 7.973266372933989, 7.029842951843947, 7.831071957955676, 8.667082614871534, 9.582015360174845, 10.518580570672247, 11.570030215946812, 11.550164399311727, 12.525749895493517, 13.589314235389631, 14.653010443457088, 14.864822943095364, 13.986071676684833, 13.538942658450264, 12.607263008646154, 11.649106944271466, 10.735256367138874, 9.72947117695405, 8.76369017316652, 7.833209634736054, 6.9795235376191975, 5.971706757319547, 6.8389721484127115, 7.734248585354288, 8.647395496528283, 9.612856130961877, 10.618210067355694, 10.779358321293278, 11.770025904192035, 12.699133317246675, 13.71081283437216, 14.539774664919772, 13.5720353761928, 12.58537531762552, 11.723973904050116, 10.707291054043202, 9.740088584500661, 8.786929416737705, 7.831250947490717, 6.9011152988740685, 5.933561928060222, 5.00145691478274, 5.822991677633209, 6.770316267531869, 7.702173947810393, 8.727429467818759, 9.718685779562207, 9.856721768863189, 10.767393916032976, 11.746178930129728, 12.71292703108027, 13.623515479917813, 12.604811846771614, 11.580741062430011, 10.655293672809531, 9.696132582071433, 8.777026534151307, 7.833224139093472, 6.880083458613814, 5.958450659886676, 4.939463735222932, 3.9858550122331535, 4.885825586005177, 5.890474111092699, 6.833904851236743, 7.835896975532322, 8.89522771915643, 8.850229724153078, 9.793203675526964, 10.795420785011936, 11.743727023585544, 12.631383734501583, 11.722112550638547, 10.647527514511255, 9.71212130628441, 8.74231961437111, 7.806924102127176, 6.853606509859422, 5.878667475857841, 4.945114435356972, 4.016587310853164, 2.9971530170714997, 3.899894207820818, 4.943105664241845, 5.933057635024571, 6.887974552167694, 7.872207895894487, 7.883598298956641, 8.833760048339645, 9.737737812762907, 10.74552425923495, 11.687422739008184, 10.940339311918937, 9.994694686155066, 8.945189978725494, 7.908270403891127, 6.931441980444486, 5.904300051894808, 4.848305817762569, 3.9171578196563046, 2.97018843388092, 2.0449879904774555, 2.9401906170985823, 3.92396071353468, 4.862443181517514, 5.860110294891767, 6.860559680502668, 6.929025204605181, 7.870570791451854, 8.799830481138272, 9.759513254433427, 10.692785515381843, 10.16574607516387, 9.196335949256754, 8.181199291369557, 7.117192252967096, 6.06185822697, 5.065564010646019, 4.075814206100921, 3.0023140375750685, 1.9927514626260314, 1.028904659864755, 1.9674167778994083, 2.9257152387740275, 3.910262651007842, 4.933843422411854, 5.933940433064857, 5.921824414446466, 6.934749848768205, 7.864363671487884, 8.916948243642947, 9.894642296453982, 9.161633513575133, 8.18797965988612, 7.146531376377068, 6.109378318124183, 5.1380204237181175, 4.078871535039527, 3.0805799248867696, 2.0273854269068243, 0.9936248628961544, 0.0, 1.0239182379260185, 1.9700312149375132, 2.940277798284268, 3.9052638649004927, 4.947651941652319, 6.8470409424304135, 7.808270691991027, 8.803820614759504, 9.74556007619914, 10.734891552694041, 9.902570027426856, 8.866523237896164, 7.873540529526944, 6.803123585756964, 5.8259947861749035, 4.842575416914768, 3.8330183081442994, 2.8856168831669384, 1.9227916662192972, 0.938797996397197, 1.8788156723798655, 2.911306693005475, 3.9287279111521394, 4.9129646453541165, 5.855658236283962, 7.792890209977685, 8.750923590517612, 9.73102354807061, 10.692815190842895, 11.67233157670198, 10.893649122955427, 9.840785518785763, 8.796430906838062, 7.724626751604313, 6.761097305796402, 5.781894650273333, 4.78261925568033, 3.8446185579102767, 2.9406327654752866, 1.8906503842342102, 2.8579029376285097, 3.87062497304641, 4.813114389071581, 5.799461549942835, 6.848708708204554, 8.652054733245594, 9.709090575863682, 10.691153146494736, 11.618585169807742, 12.579911007769782, 11.605805426239382, 10.557231855952217, 9.574610486530524, 8.6071878061316, 7.662731052477139, 6.737380932243423, 5.808068759019925, 4.775309163157951, 3.935408131207229, 2.9056970892553835, 3.795498352517545, 4.8679508559563285, 5.884509598352125, 6.752216863955494, 7.68635692820181, 9.582809540764476, 10.61231207520669, 11.650634010779179, 12.576517977207219, 13.494663543444283, 12.495707063943456, 11.516012787220005, 10.54392187523317, 9.589500674316897, 8.661756785130823, 7.675033171255183, 6.770751570585257, 5.813222743014929, 4.952399280816881, 3.9388474090538517, 4.78722022964417, 5.792083834958805, 6.865244636316412, 7.766526334130831, 8.617918157968594, 10.535870966437763, 11.482744251835898, 12.46877602583782, 13.488866417155917, 14.418219114811324, 13.46309507302258, 12.506793885153034, 11.513877459811999, 10.533311337527678, 9.615841168573626, 8.684682800771741, 7.769344888987856, 6.840775671525262, 5.900327314868068, 4.96259330331325, 5.836398749363973, 6.752276566268023, 7.71694920402401, 8.67775265496695, 9.582128548934351, 11.49620937968988, 12.476922370789591, 13.438098403518872, 14.375013583502323, 14.807719652787101, 14.066726612331452, 13.459336869072462, 12.535166262631838, 11.549021872656517, 10.594096257391694, 9.656764678685352, 8.70543875590181, 7.835608661734746, 6.958351334040834, 5.9553333413656375, 6.771927613115862, 7.714518519855262, 8.695122029908616, 9.737211783582904, 10.53202001180116, 12.52396237436473, 13.495941361565094, 14.46998950680607, 14.562410505654327, 13.840128179385216, 12.997236441072342, 13.94776182407358, 13.503416515026412, 12.544504965867544, 11.640895330770508, 10.601347827562359, 9.66889437891462, 8.864017001008285, 7.965586623603344, 6.980564949553205, 7.800906405402948, 8.681163254812562, 9.683576863179209, 10.696067703836137, 11.555376759650951], [11.580285236375316, 10.630640723255766, 9.637298387711777, 8.677506234170206, 7.874532940450501, 8.8539293372372, 9.868211240159038, 10.804383966039708, 11.594046925231826, 12.538691178170637, 13.526257015107888, 14.494827294545162, 14.629829320557803, 13.639836421915701, 12.683236891061124, 11.858911586478085, 12.586831567134684, 13.48613043931775, 13.570643130314018, 12.55100665992025, 12.551760702289181, 11.606676607935922, 10.668104698720619, 9.61790431315815, 8.862111676432658, 9.83932488938346, 10.808104444236974, 11.743330175791666, 12.57096616566011, 13.530844881085887, 14.484950139094668, 14.558670207182606, 13.650184582696168, 12.732158678344582, 11.756271498248388, 10.793337827705638, 11.514717968468716, 12.542383648492436, 13.493197360839023, 13.479700963713132, 13.569481965551876, 12.607332429724735, 11.644663543169008, 10.646798186311115, 9.87121543772118, 10.827663335882766, 11.831706115724725, 12.792552653365144, 13.546390475820015, 14.46402045563079, 14.596793983410056, 13.621170761253287, 12.628624667039135, 11.710040430867917, 10.73704054100115, 9.742362203077429, 10.532772550858972, 11.57210537791742, 12.501153863372272, 13.348019811656782, 13.252736102844317, 13.543336641494523, 12.559119974675475, 11.609308810303402, 10.824165333785848, 11.851434761968708, 12.7891426923116, 13.788227491831375, 14.527720199096969, 14.476512519164498, 13.530030253872292, 12.608807056774847, 11.66171986738623, 10.68090627016742, 9.792734379488763, 8.727359384371969, 9.57910633459284, 10.51723595658239, 11.449206004146847, 12.361165739496942, 12.307712802578813, 13.339397001872808, 13.509162681032121, 12.648181982284907, 11.88379803640031, 12.817445965108863, 13.799195365514585, 14.741931279137406, 14.46072137895937, 13.442518180859254, 12.588802775671205, 11.678715302287053, 10.685747247909388, 9.75429793240888, 8.722605504814421, 7.765775148866884, 8.598892913421853, 9.606158056680798, 10.429221045270237, 11.369812198550624, 11.476740088731711, 12.431946090228442, 13.423353103831694, 13.647195352628593, 12.954899920187165, 13.751038275931766, 14.791298102780724, 14.405479288766177, 13.450502710057261, 12.464850856437256, 11.530260867579461, 10.666368521028556, 9.68438761386895, 8.712976413154793, 7.76955299206475, 6.807153720029658, 7.643164376945515, 8.558097122248826, 9.494662332746229, 10.546111978020793, 10.526246161385709, 11.501831657567498, 12.565395997463613, 13.62909220553107, 13.946843022482499, 14.801837171531766, 14.391064991853975, 13.459385342049867, 12.50122927767518, 11.587378700542585, 10.581593510357761, 9.615812506570231, 8.685331968139765, 7.719233577840001, 6.71141679754035, 5.815053910486693, 6.710330347428269, 7.623477258602264, 8.588937893035858, 9.594291829429675, 9.75544008336726, 10.746107666266017, 11.675215079320656, 12.686894596446141, 13.689523609544038, 14.42415770959651, 13.437497651029231, 12.576096237453825, 11.559413387446915, 10.592210917904374, 9.639051750141418, 8.683373280894429, 7.75323763227778, 6.72544202939568, 5.741166955003544, 4.799073439707191, 5.74639802960585, 6.6782557098843744, 7.70351122989274, 8.694767541636189, 8.83280353093717, 9.743475678106957, 10.72226069220371, 11.689008793154251, 12.65813577617714, 13.456934180175324, 12.432863395833722, 11.50741600621324, 10.548254915475145, 9.62914886755502, 8.685346472497184, 7.732205792017527, 6.810572993290387, 5.753255476387721, 4.799646753397942, 3.8619073480791584, 4.86655587316668, 5.809986613310724, 6.811978737606303, 7.871309481230412, 7.826311486227059, 8.769285437600946, 9.771502547085916, 10.719808785659524, 11.60746549657556, 12.574234884042259, 11.499649847914966, 10.56424363968812, 9.594441947774822, 8.659046435530888, 7.705728843263135, 6.7307898092615535, 5.797236768760684, 4.868709644256877, 3.849275350475213, 2.875975969894799, 3.9191874263158257, 4.909139397098553, 5.864056314241675, 6.8482896579684684, 6.859680061030622, 7.8098418104136265, 8.713819574836887, 9.72160602130893, 10.663504501082164, 11.728199094253775, 10.84681701955878, 9.797312312129208, 8.76039273729484, 7.783564313848198, 6.75642238529852, 5.700428151166281, 4.769280153060017, 3.822310767284633, 2.8971103238811686, 1.9162723791725635, 2.9000424756086614, 3.838524943591495, 4.836192056965748, 5.836641442576649, 5.9051069666791625, 6.846652553525836, 7.775912243212253, 8.735595016507407, 9.66886727745582, 10.656421181183024, 10.220254187182773, 9.186794219949816, 8.122787181547354, 7.04949684468376, 6.053202628359779, 5.06345282381468, 3.9899526552888283, 2.943453948846267, 1.922726154659848, 0.9434985399733897, 1.901797000848009, 2.8863444130818237, 3.909925184485836, 4.910022195138838, 4.897906176520447, 5.910831610842187, 6.840445433561865, 7.893030005716929, 8.870724058527964, 9.865460052804185, 9.211897897812138, 8.170449614303086, 7.133296556050201, 6.161938661644135, 5.1027897729655445, 4.104498162812788, 3.0513036648328424, 2.0175431008221727, 1.0239182379260185, 0.0, 0.9461129770114945, 1.9163595603582493, 2.881345626974474, 3.9237337037263007, 5.823122704504395, 6.784352454065009, 7.779902376833484, 8.72164183827312, 9.71097331476802, 10.775382630129446, 9.805269706841493, 8.812286998472274, 7.741870054702295, 6.764741255120234, 5.781321885860098, 4.77176477708963, 3.824363352112269, 2.8615381351646283, 1.877544465342528, 0.9375267893598594, 1.9122521685193288, 2.9048096732261204, 3.889046407428098, 4.831739998357944, 6.768971972051666, 7.7270053525915925, 8.70710531014459, 9.668896952916874, 10.64841333877596, 11.654339410082002, 10.779531987731094, 9.735177375783392, 8.663373220549643, 7.6998437747417325, 6.720641119218664, 5.72136572462566, 4.783365026855607, 3.8793792344206173, 2.8293968531795413, 1.9181078902755408, 2.89193841560098, 3.834427831626151, 4.820774992497405, 5.870022150759124, 7.673368175800163, 8.685172337937663, 9.667234908568718, 10.594666931881722, 11.645644600036857, 12.544551895184712, 11.495978324897548, 10.513356955475855, 9.545934275076931, 8.60147752142247, 7.6761274011887535, 6.746815227965255, 5.714055632103282, 4.8741546001525595, 3.844443558200715, 2.8557033051645764, 3.9152953043727194, 4.905823040906695, 5.773530306510064, 6.70767037075638, 8.604122983319046, 9.63362551776126, 10.67194745333375, 11.552599739281199, 12.552358148742643, 13.434453532888787, 12.454759256165335, 11.482668344178501, 10.528247143262227, 9.600503254076154, 8.613779640200514, 7.709498039530588, 6.75196921196026, 5.891145749762212, 4.877593877999184, 3.847425182291201, 4.852288787605836, 5.924626740762765, 6.787839776685401, 7.639231600523164, 9.557184408992333, 10.504057694390468, 11.49008946839239, 12.484783837640215, 13.551518655855254, 14.40184154196791, 13.445540354098364, 12.45262392875733, 11.472057806473009, 10.554587637518956, 9.623429269717072, 8.708091357933188, 7.779522140470594, 6.839073783813401, 5.891564500534167, 4.896603702011005, 5.812481518915055, 6.777154156671042, 7.737957607613981, 8.603441991488921, 10.51752282224445, 11.498235813344161, 12.459411846073442, 13.396327026056891, 13.783801414861081, 14.730031288514049, 14.398083338017791, 13.473912731577169, 12.487768341601848, 11.532842726337025, 10.595511147630683, 9.644185224847142, 8.774355130680078, 7.897097802986166, 6.86965571316088, 5.832132565762894, 6.774723472502294, 7.755326982555649, 8.797416736229938, 9.55333345435573, 11.5452758169193, 12.517254804119665, 13.491302949360641, 13.538492267728309, 12.816209941459196, 13.660541117254938, 14.616061199444067, 14.442162983971745, 13.483251434812875, 12.579641799715837, 11.54009429650769, 10.607640847859953, 9.802763469953618, 8.879908995398587, 7.894887321348449, 6.86111135804998, 7.741368207459595, 8.743781815826242, 9.756272656483171, 10.576690202205521], [10.660202665969713, 9.710558152850163, 8.717215817306174, 7.7574236637646035, 8.810890367378578, 9.800042314248694, 10.814324217170531, 11.750496943051203, 12.54015990224332, 13.484804155182132, 14.472369992119383, 15.440940271556656, 15.575942297569297, 14.585949398927195, 13.629349868072618, 12.80502456348958, 11.968363442999152, 12.82417395556893, 12.624530153302521, 11.604893682908752, 11.631678131883579, 10.68659403753032, 9.748022128315016, 8.697821742752547, 9.632975147477847, 10.61018836042865, 11.671214249076723, 12.606439980631414, 13.517079142671603, 14.476957858097382, 15.431063116106163, 15.5047831841941, 14.596297559707661, 13.678271655356077, 12.702384475259882, 11.739450804717134, 10.896249844333184, 11.880427164743617, 12.780853556241343, 12.533587986701637, 12.649399395146274, 11.687249859319133, 10.724580972763405, 9.726715615905512, 10.642078908766369, 11.598526806927955, 12.647740520445971, 13.655662458204892, 14.492503452831508, 15.410133432642285, 15.542906960421552, 14.56728373826478, 13.574737644050629, 12.65615340787941, 11.683153518012643, 10.688475180088924, 9.91430442672344, 10.910148894168602, 11.788810058774592, 12.635676007059102, 12.540392298246637, 12.62325407108892, 11.639037404269873, 10.689226239897799, 11.595028804831037, 12.622298233013897, 13.605177097032847, 14.604261896552622, 15.473833176108462, 15.422625496175995, 14.476143230883789, 13.55492003378634, 12.607832844397723, 11.627019247178913, 10.738847356500257, 9.673472361383464, 8.960638210457308, 9.85527947283357, 10.736862199549167, 11.648821934899262, 11.595368997981133, 12.627053197275128, 12.589080110626519, 11.728099411879304, 12.6546615074455, 13.588309436154052, 14.577361081429073, 15.520096995051894, 15.406834355970867, 14.388631157870751, 13.534915752682702, 12.624828279298546, 11.631860224920882, 10.700410909420373, 9.668718481825914, 8.711888125878378, 7.980424789286321, 8.893814252083118, 9.716877240672558, 10.657468393952945, 10.764396284134031, 11.719602285630762, 12.711009299234014, 12.72711278222299, 13.725763391232354, 14.521901746976955, 15.562161573825913, 15.351592265777672, 14.396615687068758, 13.410963833448752, 12.476373844590958, 11.612481498040053, 10.630500590880443, 9.659089390166287, 8.715665969076245, 7.753266697041151, 7.024696252809983, 7.8457533176511465, 8.782318528148549, 9.833768173423113, 9.782496923327974, 10.758082419509764, 11.720253102628488, 12.764874716987165, 13.741146968841239, 14.63684061539699, 15.33717796886547, 14.405498319061362, 13.447342254686674, 12.533491677554082, 11.527706487369258, 10.561925483581728, 9.631444945151262, 8.665346554851494, 7.657529774551844, 6.761166887498186, 6.091862223292738, 6.911133454004585, 7.8765940884381775, 8.881948024831996, 8.815290610029832, 9.805958192928589, 10.729102102309161, 11.740781619434646, 12.743410632532543, 13.651377939554983, 14.383610628040726, 13.52220921446532, 12.50552636445841, 11.53832389491587, 10.585164727152913, 9.629486257905924, 8.699350609289276, 7.671555006407173, 6.687279932015038, 5.745186416718685, 5.127929905470319, 5.965911905286695, 6.956204115564974, 7.934036021770108, 7.886690553925675, 8.797362701095462, 9.776147715192215, 10.742895816142756, 11.712022799165645, 12.669334876855341, 13.378976372845218, 12.453528983224736, 11.49436789248664, 10.575261844566516, 9.631459449508679, 8.678318769029023, 7.7566859703018824, 6.699368453399216, 5.745759730409437, 4.808020325090653, 4.125313855875012, 4.963687853491365, 5.914832952335875, 6.9734838096894105, 6.880198509215563, 7.82317246058945, 8.82538957007442, 9.773695808648029, 10.661352519564065, 11.657538776509085, 12.445762824926462, 11.510356616699616, 10.540554924786317, 9.605159412542383, 8.65184182027463, 7.676902786273049, 6.743349745772179, 5.814822621268372, 4.795388327486708, 3.8220889469062937, 3.0691111509943907, 4.0119936118281245, 4.966910528971247, 5.908019645099417, 5.913567084019126, 6.8637288334021305, 7.7677065978253905, 8.775493044297434, 9.717391524070669, 10.78208611724228, 11.700230578812052, 10.743425289140701, 9.706505714306333, 8.729677290859692, 7.702535362310015, 6.646541128177776, 5.715393130071512, 4.768423744296128, 3.8432233008926633, 2.862385356184058, 2.0499662002872263, 2.941379158321066, 3.939046271695319, 4.896371429707598, 4.9589939896676665, 5.90053957651434, 6.829799266200757, 7.789482039495911, 8.722754300444326, 9.710308204171529, 10.679718330078646, 10.13290719696131, 9.068900158558849, 7.995609821695254, 6.999315605371273, 6.0095658008261745, 4.9360656323003225, 3.8895669258577614, 2.8688391316713426, 1.8896115169848842, 1.051720725526574, 1.9405709616380116, 2.9641517330420237, 3.963909218127343, 3.9517931995089515, 4.964718633830691, 5.894332456550369, 6.946917028705433, 7.924611081516468, 8.919347075792688, 9.893000929481701, 9.116562591314581, 8.079409533061696, 7.10805163865563, 6.04890274997704, 5.050611139824283, 3.9974166418443375, 2.963656077833668, 1.9700312149375132, 0.9461129770114945, 0.0, 0.9702465833467547, 1.9352326499629795, 2.9776207267148056, 4.8770097274929, 5.838239477053514, 6.833789399821988, 7.775528861261625, 8.764860337756526, 9.82926965311795, 10.751382683852988, 9.75839997548377, 8.68798303171379, 7.710854232131729, 6.727434862871593, 5.717877754101125, 4.770476329123764, 3.807651112176123, 2.8236574423540226, 1.883639766371354, 0.9661391915078342, 1.9586966962146262, 2.942933430416603, 3.8856270213464486, 5.822858995040171, 6.780892375580097, 7.7609923331330934, 8.722783975905378, 9.702300361764465, 10.708226433070507, 11.725644964742589, 10.681290352794887, 9.609486197561138, 8.645956751753227, 7.666754096230159, 6.6674787016371555, 5.7294780038671025, 4.825492211432112, 3.775509830191036, 2.8642208672870355, 1.9458254385894853, 2.888314854614656, 3.87466201548591, 4.923909173747629, 6.727255198788668, 7.739059360926167, 8.721121931557223, 9.648553954870225, 10.69953162302536, 11.67363720455576, 12.442091301909041, 11.459469932487348, 10.492047252088424, 9.547590498433964, 8.622240378200248, 7.6929282049767505, 6.660168609114777, 5.820267577164055, 4.790556535212209, 3.801816282176071, 2.9691823273612243, 3.9597100638952, 4.8274173294985685, 5.7615573937448845, 7.658010006307551, 8.687512540749765, 9.725834476322255, 10.606486762269702, 11.606245171731146, 12.605201651231972, 13.400872233176829, 12.428781321189994, 11.47436012027372, 10.546616231087647, 9.55989261721201, 8.655611016542084, 7.698082188971755, 6.8372587267737055, 5.823706855010677, 4.793538159302695, 3.9322062172002346, 4.97851376375127, 5.841726799673906, 6.693118623511669, 8.611071431980836, 9.557944717378971, 10.543976491380894, 11.538670860628718, 12.605405678843757, 13.560529720632502, 14.391653331109858, 13.398736905768823, 12.418170783484502, 11.500700614530452, 10.569542246728567, 9.654204334944682, 8.725635117482087, 7.785186760824894, 6.83767747754566, 5.842716679022498, 4.892398948509452, 5.857071586265439, 6.807412012410087, 7.657329014477425, 9.571409845232953, 10.552122836332664, 11.513298869061945, 12.450214049045396, 13.524486972191868, 14.597260713225191, 15.344196315029286, 14.420025708588662, 13.433881318613341, 12.47895570334852, 11.541624124642178, 10.590298201858635, 9.720468107691572, 8.84321077999766, 7.815768690172374, 6.778245542774387, 5.854640902096691, 6.835244412150046, 7.874295569857879, 8.607220477344233, 10.599162839907804, 11.571141827108168, 12.545189972349144, 12.920024143592777, 13.76232291847069, 14.606654094266432, 15.56217417645556, 15.388275960983236, 14.429364411824368, 13.525754776727332, 12.486207273519184, 11.553753824871446, 10.748876446965111, 9.826021972410082, 8.841000298359942, 7.807224335061473, 6.821285637053992, 7.82369924542064, 8.836190086077568, 9.630577225194024], [9.772609594694035, 8.956931748299715, 8.038326586278526, 8.725188112375804, 9.778654815989778, 10.77028889759545, 11.784570800517287, 12.720743526397957, 13.510406485590075, 14.455050738528888, 15.442616575466138, 16.41118685490341, 16.538731015873488, 15.548738117231384, 14.592138586376807, 13.724377070999006, 12.767956539747296, 11.853927372222175, 11.691810598342046, 10.672174127948278, 10.745009242691474, 9.93296763297987, 9.069132897287368, 9.665586191363747, 10.600739596089047, 11.57795280903985, 12.638978697687923, 13.574204429242615, 14.487325726018359, 15.447204441444137, 16.401309699452916, 16.475029767540853, 15.566544143054417, 14.648518238702831, 13.66517319356407, 12.65880331222656, 11.695842941081327, 10.910180581396862, 11.810606972894588, 11.600868431741162, 11.762730505954169, 10.933623454768684, 10.103964359979297, 10.694480064516712, 11.609843357377569, 12.566291255539156, 13.615504969057172, 14.623426906816093, 15.462750036178264, 16.38038001598904, 16.513153543768304, 15.537530321611536, 14.544984227397384, 13.626399991226165, 12.653400101359399, 11.658721763435679, 10.713897523471584, 9.939902310821846, 10.818563475427837, 11.665429423712347, 11.570145714899882, 11.895032529607832, 11.153089522443617, 11.656990688509, 12.562793253442237, 13.590062681625097, 14.57294154564405, 15.572026345163824, 16.444079759455217, 16.39287207952275, 15.446389814230542, 14.525166617133095, 13.578079427744479, 12.597265830525668, 11.709093939847012, 10.64371894473022, 9.760231307205453, 8.885032889486816, 9.766615616202412, 10.678575351552507, 10.625122414634378, 11.656806613928374, 12.103132228800263, 12.695863860490505, 13.622425956056702, 14.556073884765254, 15.545125530040275, 16.487861443663096, 16.37708093931762, 15.358877741217505, 14.505162336029455, 13.595074862645301, 12.602106808267637, 11.670657492767129, 10.63896506517267, 9.682134709225133, 8.780017886034466, 7.9235676687363625, 8.746630657325802, 9.68722181060619, 9.794149700787274, 10.749355702284005, 11.740762715887257, 12.768687917385932, 13.762843487789816, 14.700450547505012, 15.565563146933327, 16.321838849124426, 15.366862270415512, 14.381210416795506, 13.446620427937711, 12.582728081386806, 11.600747174227198, 10.629335973513042, 9.685912552422998, 8.723513280387907, 7.8242893495581285, 6.875506734304391, 7.812071944801794, 8.863521590076356, 8.812250339981219, 9.787835836163008, 10.750006519281733, 11.79462813364041, 12.770900385494482, 13.666594032050236, 14.559216343118543, 15.375744902408115, 14.417588838033428, 13.503738260900835, 12.497953070716012, 11.532172066928482, 10.601691528498016, 9.63559313819825, 8.627776357898599, 7.731413470844942, 6.891455320040882, 5.940886870657829, 6.906347505091422, 7.911701441485239, 7.845044026683078, 8.835711609581834, 9.758855518962406, 10.77053503608789, 11.77316404918579, 12.68113135620823, 13.605649002293799, 14.492455797812074, 13.475772947805163, 12.508570478262623, 11.555411310499668, 10.59973284125268, 9.66959719263603, 8.641801589753928, 7.657526515361792, 6.715433000065439, 5.9275230022184635, 4.995665321939939, 5.98595753221822, 6.963789438423355, 6.9164439705789205, 7.827116117748707, 8.80590113184546, 9.772649232796002, 10.741776215818891, 11.699088293508588, 12.60101474709829, 13.42377556657149, 12.464614475833393, 11.54550842791327, 10.601706032855432, 9.648565352375778, 8.726932553648638, 7.669615036745969, 6.716006313756191, 5.778266908437407, 4.936872010288654, 3.9934412701446096, 4.94458636898912, 6.003237226342657, 5.909951925868809, 6.852925877242695, 7.855142986727666, 8.803449225301275, 9.691105936217312, 10.687292193162332, 11.667801199179534, 12.48060320004637, 11.51080150813307, 10.575405995889136, 9.622088403621383, 8.647149369619804, 7.713596329118934, 6.785069204615127, 5.765634910833462, 4.792335530253048, 3.92875999366431, 3.0417470284813692, 3.996663945624492, 4.937773061752663, 4.943320500672372, 5.893482250055376, 6.797460014478636, 7.80524646095068, 8.747144940723915, 9.811839533895522, 10.729983995465295, 11.713671872487456, 10.676752297653088, 9.699923874206448, 8.67278194565677, 7.61678771152453, 6.685639713418267, 5.7386703276428825, 4.813469884239418, 3.832631939530813, 2.9096150429571455, 1.9711325749743114, 2.968799688348564, 3.926124846360844, 3.9887474063209125, 4.930292993167585, 5.8595526828540025, 6.819235456149157, 7.752507717097571, 8.740061620824774, 9.70947174673189, 10.766884638850172, 10.039146741905602, 8.965856405042008, 7.969562188718028, 6.979812384172929, 5.906312215647077, 4.859813509204516, 3.839085715018097, 2.859858100331639, 1.9548717905250714, 0.970324378291257, 1.9939051496952689, 2.9936626347805886, 2.981546616162197, 3.994472050483936, 4.924085873203615, 5.976670445358678, 6.9543644981697135, 7.949100492445933, 8.922754346134948, 9.964202629644, 9.049656116408451, 8.078298222002385, 7.019149333323794, 6.020857723171037, 4.967663225191092, 3.933902661180422, 2.940277798284268, 1.9163595603582493, 0.9702465833467547, 0.0, 0.9649860666162248, 2.007374143368051, 3.906763144146145, 4.8679928937067585, 5.863542816475234, 6.805282277914871, 7.794613754409771, 8.859023069771196, 9.895069859301888, 10.728646558830523, 9.658229615060543, 8.681100815478484, 7.697681446218348, 6.68812433744788, 5.740722912470519, 4.777897695522878, 3.7939040257007774, 2.853886349718109, 1.936385774854589, 0.9884501128678713, 1.9726868470698484, 2.915380437999694, 4.852612411693416, 5.810645792233342, 6.790745749786339, 7.752537392558624, 8.73205377841771, 9.737979849723752, 10.790843453893416, 11.651536936141643, 10.579732780907893, 9.616203335099982, 8.637000679576914, 7.63772528498391, 6.699724587213857, 5.795738794778867, 4.745756413537791, 3.8344674506337904, 2.913589887200685, 1.971100471175514, 2.941942460525435, 3.956047793392573, 5.794535643828193, 6.768812777579412, 7.750875348210467, 8.678307371523472, 9.729285039678606, 10.703390621209007, 11.751964191496171, 12.429716515834103, 11.46229383543518, 10.51783708178072, 9.592486961547003, 8.663174788323504, 7.63041519246153, 6.790514160510809, 5.7608031185589645, 4.772062865522826, 3.936946775972424, 3.042495680456058, 3.8946977745380935, 4.82883783878441, 6.725290451347076, 7.754792985789289, 8.793114921361779, 9.636240178922948, 10.635998588384393, 11.634955067885219, 12.61464934460867, 13.39902790453675, 12.444606703620476, 11.516862814434402, 10.530139200558764, 9.625857599888837, 8.668328772318509, 7.807505310120461, 6.793953438357432, 5.763784742649451, 4.899970665811434, 4.061299380312128, 4.909007244713431, 5.7603990685511945, 7.678351877020361, 8.625225162418497, 9.61125693642042, 10.568424277281965, 11.635159095497004, 12.590283137285748, 13.546584325155294, 14.368983489115578, 13.388417366831257, 12.470947197877207, 11.539788830075322, 10.624450918291437, 9.695881700828842, 8.75543334417165, 7.807924060892415, 6.812963262369253, 5.860163397120653, 5.041315781736365, 5.874692457449612, 6.724609459516951, 8.638690290272478, 9.61940328137219, 10.58057931410147, 11.517494494084922, 12.569095360548646, 13.64186910158197, 14.499127309074723, 15.390272291935418, 14.404127901960097, 13.449202286695275, 12.511870707988933, 11.56054478520539, 10.690714691038327, 9.813457363344416, 8.78601527351913, 7.748492126121143, 6.822405350707892, 6.019488607620972, 6.941576014897404, 7.674500922383759, 9.666443284947329, 10.638422272147693, 11.61247041738867, 12.45018620625212, 13.483767568369704, 14.51040369229694, 15.465923774486068, 16.358522544329993, 15.399610995171123, 14.49600136007409, 13.45645385686594, 12.524000408218201, 11.719123030311867, 10.796268555756836, 9.811246881706698, 8.777470918408229, 7.789050085665193, 7.052766462452478, 8.01075282944286, 8.69785767023355], [8.80762352807781, 7.99194568168349, 8.867520646318487, 9.690174178992029, 10.743640882606003, 11.735274964211674, 12.749556867133512, 13.68572959301418, 14.475392552206298, 15.420036805145113, 16.407602642082363, 17.356932704033852, 16.39299003139346, 15.402997132751356, 14.446397601896779, 13.475361774640117, 12.436860840229517, 11.712611809540817, 10.726824531725821, 9.707188061332053, 9.780023176075249, 8.967981566363646, 9.89832695732733, 10.630572257979972, 11.565725662705272, 12.542938875656075, 13.603964764304148, 14.53919049585884, 15.452311792634582, 16.412190508060363, 17.366295766069143, 17.440015834157084, 16.531530209670645, 15.613504305319058, 14.630159260180298, 13.623789378842787, 12.660829007697554, 11.875166648013087, 11.015127350961892, 10.635882365124935, 10.797744439337944, 9.968637388152459, 10.933158420019259, 11.659466131132938, 12.574829423993794, 13.53127732215538, 14.580491035673397, 15.588412973432318, 16.427736102794487, 17.345366082605263, 17.47813961038453, 16.502516388227765, 15.50997029401361, 14.59138605784239, 13.618386167975624, 12.623707830051904, 11.67888359008781, 10.904888377438072, 10.023083853495141, 10.869949801779649, 10.732532202354353, 10.930046462991605, 11.914263129810653, 12.621976755125225, 13.527779320058462, 14.555048748241322, 15.537927612260273, 16.537012411780047, 17.40906582607144, 17.357858146138977, 16.41137588084677, 15.490152683749322, 14.543065494360706, 13.562251897141895, 12.674080006463237, 11.608705011346444, 10.725217373821678, 9.85001895610304, 8.971135994269716, 9.883095729619809, 9.787508902088849, 10.795181863037262, 11.76302443709159, 12.802707137970893, 13.766914004434172, 14.669056791711691, 15.658108436986712, 16.450071752093173, 17.342067005933846, 16.32386380783373, 15.470148402645682, 14.560060929261528, 13.567092874883864, 12.635643559383356, 11.603951131788895, 10.647120775841358, 9.745003952650691, 8.888553735352588, 7.951151035393106, 8.891742188673492, 8.840466361488359, 9.795672362985089, 10.787079376588341, 11.815004578087017, 12.797857421173592, 13.735464480888789, 14.600577080317104, 15.524823111307924, 16.331848337031737, 15.346196483411733, 14.411606494553938, 13.547714148003033, 12.565733240843425, 11.594322040129269, 10.650898619039225, 9.688499347004132, 8.789275416174354, 7.840492800920616, 7.016592322869096, 7.996190964457433, 7.8472642733649955, 8.822849769546785, 9.785020452665508, 10.829642067024185, 11.805914318878258, 12.701607965434013, 13.59423027650232, 14.578729164591614, 15.382574904649655, 14.468724327517062, 13.462939137332238, 12.497158133544708, 11.566677595114243, 10.600579204814476, 9.592762424514826, 8.696399537461167, 7.8564413866571075, 6.905872937274054, 6.052474007159933, 7.0071486765390585, 6.880057960066853, 7.8707255429656096, 8.793869452346181, 9.805548969471666, 10.808177982569566, 11.716145289592006, 12.640662935677575, 13.632220382151514, 14.44075901442139, 13.47355654487885, 12.520397377115895, 11.564718907868906, 10.634583259252256, 9.606787656370154, 8.622512581978018, 7.680419066681665, 6.892509068834689, 5.9606513885561645, 5.112754842114159, 5.99880337180713, 5.951457903962696, 6.862130051132483, 7.840915065229235, 8.807663166179776, 9.776790149202668, 10.734102226892364, 11.636028680482067, 12.581393707315279, 13.42960054244962, 12.510494494529496, 11.566692099471659, 10.613551418992005, 9.691918620264863, 8.634601103362197, 7.680992380372418, 6.743252975053633, 5.901858076904879, 4.958427336760835, 4.071383678885059, 5.038251159726432, 4.9449658592525845, 5.887939810626471, 6.8901569201114405, 7.83846315868505, 8.726119869601089, 9.722306126546108, 10.70281513256331, 11.638221340790157, 12.475787574749297, 11.540392062505363, 10.58707447023761, 9.61213543623603, 8.678582395735159, 7.750055271231353, 6.730620977449688, 5.757321596869274, 4.8937460602805345, 4.006733095097594, 3.1234612555204304, 3.9727869951364383, 3.9783344340561477, 4.928496183439152, 5.832473947862412, 6.8402603943344555, 7.78215887410769, 8.846853467279299, 9.764997928849072, 10.782087554345102, 11.641738364269315, 10.664909940822675, 9.637768012272996, 8.581773778140757, 7.650625780034493, 6.7036563942591085, 5.778455950855644, 4.797618006147038, 3.87460110957337, 2.9361186415905363, 2.0936913181761634, 2.9611387797446187, 3.023761339704688, 3.965306926551361, 4.894566616237778, 5.854249389532932, 6.787521650481347, 7.7750755542085495, 8.744485680115666, 9.801898572233949, 10.86590561063641, 9.930842471658233, 8.934548255334253, 7.944798450789154, 6.871298282263302, 5.824799575820741, 4.804071781634322, 3.824844166947864, 2.9198578571412965, 1.9353104449074818, 1.0687373943565637, 2.0286765681643635, 2.0165605495459724, 3.029485983867712, 3.959099806587391, 5.011684378742454, 5.989378431553489, 6.984114425829709, 7.9577682795187235, 8.999216563027774, 10.014642183024677, 9.04328428861861, 7.984135399940019, 6.985843789787262, 5.9326492918073175, 4.898888727796647, 3.9052638649004927, 2.881345626974474, 1.9352326499629795, 0.9649860666162248, 0.0, 1.0423880767518263, 2.94177707752992, 3.9030068270905334, 4.89855674985901, 5.8402962112986465, 6.829627687793547, 7.894037003154971, 8.930083792685664, 9.923066501054883, 10.623215681676767, 9.646086882094707, 8.662667512834572, 7.653110404064104, 6.705708979086743, 5.742883762139102, 4.758890092317002, 3.8188724163343335, 2.9013718414708136, 1.953436179484096, 1.0077007804536235, 1.950394371383469, 3.8876263450771913, 4.845659725617118, 5.825759683170115, 6.7875513259424, 7.767067711801486, 8.772993783107529, 9.825857387277193, 10.870211999224894, 11.544718847524116, 10.581189401716205, 9.60198674619314, 8.602711351600135, 7.664710653830081, 6.760724861395092, 5.710742480154016, 4.799453517250015, 3.8785759538169096, 2.9360865377917387, 1.9769563939092103, 2.9910617267763477, 4.829549577211968, 5.803826710963188, 6.785889281594243, 7.713321304907247, 8.764298973062381, 9.738404554592782, 10.786978124879946, 11.769599494301639, 12.427279902051405, 11.482823148396944, 10.557473028163228, 9.628160854939729, 8.595401259077756, 7.755500227127034, 6.72578918517519, 5.73704893213905, 4.901932842588649, 3.991062214588628, 2.929711707921869, 3.863851772168185, 5.760304384730851, 6.789806919173064, 7.828128854745554, 8.671254112306723, 9.671012521768168, 10.669969001268994, 11.649663277992445, 12.631677225427362, 13.409592770236701, 12.481848881050627, 11.49512526717499, 10.590843666505062, 9.633314838934734, 8.772491376736685, 7.758939504973657, 6.728770809265675, 5.864956732427659, 4.906126456906569, 3.9440211780972065, 4.795413001934969, 6.713365810404136, 7.660239095802272, 8.646270869804194, 9.60343821066574, 10.670173028880779, 11.625297070669523, 12.581598258539069, 13.598073505944063, 14.353403433447482, 13.435933264493432, 12.504774896691547, 11.58943698490766, 10.660867767445065, 9.720419410787873, 8.772910127508641, 7.777949328985478, 6.825149463736878, 5.870509841776327, 4.909706390833388, 5.759623392900726, 7.673704223656253, 8.654417214755965, 9.615593247485245, 10.552508427468695, 11.60410929393242, 12.676883034965744, 13.534141242458496, 14.48916497416961, 15.369113968576322, 14.4141883533115, 13.476856774605158, 12.525530851821614, 11.65570075765455, 10.778443429960639, 9.751001340135355, 8.713478192737368, 7.787391417324117, 6.848682667660934, 5.9765899482811795, 6.709514855767534, 8.701457218331104, 9.673436205531468, 10.647484350772444, 11.485200139635893, 12.518781501753477, 13.545417625680713, 14.500937707869841, 15.525055047194643, 16.364597061787347, 15.460987426690313, 14.421439923482165, 13.488986474834425, 12.68410909692809, 11.761254622373063, 10.776232948322923, 9.742456985024454, 8.754036152281417, 7.88196052249244, 7.045766762826635, 7.732871603617324], [7.972299545857194, 8.821826493222645, 9.741108860787664, 10.573795409256642, 11.627262112870616, 12.631960427959466, 13.646242330881304, 14.659946256733882, 15.449609215925998, 16.418754280141926, 17.392486859446862, 16.366011269160712, 15.402068596520317, 14.412075697878215, 13.455476167023638, 12.484440339766977, 11.445939405356375, 10.809640940695699, 9.828437561222842, 8.871864079111436, 8.944699193854632, 9.797862377902801, 10.771915171796506, 11.514193488244585, 12.449346892969885, 13.426560105920688, 14.48758599456876, 15.422811726123452, 16.40955873275591, 17.410907983057175, 18.23792717418803, 17.308294164786766, 16.34528945471257, 15.36401297834782, 14.382441559836375, 13.481013375167576, 12.518053004022343, 11.734104088500441, 10.747484771460341, 9.80055838290432, 9.962420457117327, 10.798518199691614, 11.806746634488436, 12.54308736139755, 13.458450654258407, 14.414898552419993, 15.46411226593801, 16.472034203696932, 17.384983042915817, 18.337811989473884, 18.507841368585932, 17.52843296246554, 16.482022048066916, 15.53343805199421, 14.560438162127443, 13.565759824203724, 12.545385572273904, 11.739579486637037, 10.817940758115276, 9.906803900312982, 9.690144125602526, 10.728552278300503, 11.670679066696408, 12.620490231068482, 13.628987517895707, 14.63067704076349, 15.614296543873268, 16.438338565096622, 17.39451075639019, 18.34060782329417, 17.447542354210643, 16.5160692579871, 15.568982068598483, 14.536020348874539, 13.616132000615057, 12.550757005498264, 11.591719356007772, 10.684710065302006, 9.76599289888985, 8.919949828153142, 8.745120825337022, 9.752793786285435, 10.720636360339762, 11.760319061219066, 12.724525927682345, 13.626668714959864, 14.615720360234885, 15.407683675341346, 16.390115161240626, 17.360030281197602, 16.506314876009558, 15.585977503499306, 14.593009449121642, 13.609412011116, 12.546003125940715, 11.589172769993178, 10.611505934836785, 9.723244844551553, 8.746007940013241, 7.928596287206824, 7.7980782847365315, 8.753284286233262, 9.744691299836514, 10.77261650133519, 11.755469344421765, 12.693076404136962, 13.558189003565278, 14.482435034556099, 15.455347894991654, 16.382362956775605, 15.447772967917812, 14.583880621366907, 13.591649815081203, 12.620238614367047, 11.676815193277003, 10.630551341155952, 9.655777398360447, 8.70699478310671, 7.811449227489232, 6.953802887705607, 6.804876196613169, 7.780461692794958, 8.742632375913683, 9.787253990272358, 10.763526242126431, 11.659219888682188, 12.551842199750494, 13.536341087839789, 14.494497152214477, 15.450842596416113, 14.499105610696112, 13.533324606908582, 12.602844068478117, 11.626495779052254, 10.618678998752603, 9.6823886822092, 8.722943368843202, 7.772374919460149, 6.84733091178007, 5.964760599787232, 5.8376698833150265, 6.828337466213783, 7.751481375594355, 8.763160892719839, 9.76578990581774, 10.673757212840181, 11.59827485892575, 12.589832305399689, 13.594421233340247, 14.43419495056905, 13.56278545386772, 12.607106984620732, 11.67074973261613, 10.632704230607931, 9.648429156215796, 8.706335640919443, 7.759011051020783, 6.827153370742259, 5.907611746734295, 4.9564152950553035, 4.909069827210869, 5.819741974380656, 6.798526988477408, 7.76527508942795, 8.734402072450843, 9.69171415014054, 10.593640603730242, 11.539005630563452, 12.519447923651953, 13.471132900219697, 12.609080176223484, 11.65593949574383, 10.728085093628737, 9.664356712487058, 8.710747989497278, 7.773008584178495, 6.768360059090973, 5.824929318946929, 4.866240583505196, 3.995863082974606, 3.902577782500757, 4.845551733874644, 5.847768843359615, 6.796075081933224, 7.6837317928492626, 8.679918049794283, 9.660427055811486, 10.595833264038331, 11.56563495595163, 12.501030468195564, 11.629462546989435, 10.654523512987856, 9.720970472486986, 8.792443347983179, 7.773009054201514, 6.799709673621099, 5.874494620667945, 4.873235077283689, 3.9183181601405668, 2.930398918384612, 2.9359463573043207, 3.886108106687325, 4.790085871110586, 5.797872317582629, 6.739770797355865, 7.804465390527473, 8.722609852097246, 9.739699477593277, 10.776619052427645, 11.7072980175745, 10.680156089024821, 9.624161854892582, 8.693013856786319, 7.746044471010934, 6.820844027607469, 5.840006082898864, 4.8553496699607805, 3.9168672019779462, 2.9192000886036937, 1.9187507029927926, 1.9813732629528613, 2.922918849799535, 3.852178539485952, 4.811861312781106, 5.745133573729521, 6.732687477456723, 7.70209760336384, 8.759510495482123, 9.823517533884585, 10.89680787074818, 9.976936332086078, 8.98718652754098, 7.913686359015128, 6.867187652572567, 5.846459858386148, 4.86723224369969, 3.9622459338931226, 2.977698521659308, 2.0362673754209313, 0.9862884914125373, 0.974172472794146, 1.9870979071158854, 2.9167117298355643, 3.969296301990627, 4.946990354801662, 5.941726349077882, 6.9153802027668965, 7.956828486275947, 8.993981544528832, 9.9653394389349, 9.026523476691844, 8.028231866539087, 6.975037368559143, 5.941276804548473, 4.947651941652319, 3.9237337037263007, 2.977620726714806, 2.007374143368051, 1.0423880767518263, 0.0, 1.9299781101394051, 2.891207859700019, 3.8561686731071836, 4.79790813454682, 5.787239611041721, 6.851648926403145, 7.8876957159338374, 8.880678424303056, 9.946681007476599, 10.688474958846532, 9.705055589586397, 8.69549848081593, 7.748097055838569, 6.785271838890928, 5.801278169068828, 4.86126049308616, 3.94375991822264, 2.9222827573215895, 1.8812889949227998, 0.9385954039929542, 2.8758273776866767, 3.833860758226603, 4.783371606418289, 5.745163249190574, 6.72467963504966, 7.730605706355702, 8.783469310525366, 9.827823922473067, 10.879666611817806, 11.62357747846803, 10.644374822944965, 9.64509942835196, 8.707098730581908, 7.803112938146917, 6.753130556905841, 5.792103220692711, 4.779381185274811, 3.8368917692496405, 2.8505446083783865, 1.9792627593858327, 3.901175864944485, 4.792027743572673, 5.774090314203728, 6.670933228155421, 7.721910896310555, 8.696016477840955, 9.744590048128119, 10.727211417549812, 11.694634097948736, 12.52521122514877, 11.599861104915053, 10.670548931691556, 9.637789335829583, 8.79788830387886, 7.768177261927015, 6.729698635581746, 5.802738074046551, 4.8646504290578045, 3.803299922391045, 3.028527789947567, 4.831930672463368, 5.857478615676327, 6.817600300018398, 7.628866035554897, 8.62862444501634, 9.627580924517167, 10.607275201240618, 11.589289148675535, 12.543710349591809, 13.524236957802453, 12.537513343926815, 11.63323174325689, 10.67570291568656, 9.79154400074681, 8.777992128983781, 7.721420512708371, 6.765761963885561, 5.779714671375745, 4.817609392566382, 3.9600890197143515, 5.810394941559018, 6.757268226957153, 7.743300000959077, 8.561050133913913, 9.627784952128952, 10.582908993917696, 11.539210181787242, 12.555685429192236, 13.48752101280259, 14.475563822585737, 13.547162973443372, 12.56365364862736, 11.635084431164765, 10.694636074507573, 9.688263087341202, 8.693302288818039, 7.7087706940014895, 6.744098056245503, 5.783294605302563, 4.924299410680108, 6.838380241435637, 7.751446345910846, 8.712622378640127, 9.561586992595553, 10.561721217180594, 11.634494958213917, 12.491753165706669, 13.446776897417783, 14.432921287393103, 15.41594841088583, 14.519244851356984, 13.499747515541314, 12.62991742137425, 11.72829353657255, 10.666354299967916, 9.628831152569928, 8.671012647588729, 7.722270882130109, 6.850178162750355, 5.874190873546917, 7.866133236110487, 8.77046533668635, 9.744513481927326, 10.49427870476275, 11.527860066880335, 12.554496190807571, 13.499379753708444, 14.482666970442816, 15.42840438060413, 16.459704901687125, 15.420157398478977, 14.463203138554125, 13.65832576064779, 12.676607582205623, 11.691585908155483, 10.630677898093793, 9.63765738254603, 8.755548736961616, 7.875647574365789, 6.897547621396708], [7.88066731575849, 8.730194263123941, 9.717442034817383, 10.55012858328636, 11.603595286900335, 12.608293601989185, 13.622575504911023, 14.6362794307636, 15.425942389955717, 16.395087454171644, 15.508546192347703, 14.482070602061551, 13.518127929421157, 12.528135030779055, 11.571535499924478, 10.600499672667816, 9.561998738257216, 8.879662830556294, 7.898459451083437, 6.957503878300967, 8.826788288297731, 9.706230147804098, 10.68468735459728, 11.490526662274304, 12.425680066999604, 13.402893279950407, 14.46391916859848, 15.399144900153171, 16.38589190678563, 17.30809176509765, 16.35398650708887, 15.424353497687605, 14.46134878761341, 13.480072311248659, 12.498500892737214, 11.597072708068417, 10.634112336923184, 9.817874899646206, 8.831255582606104, 7.8861981820938505, 9.807971371481678, 10.70688596959291, 11.71951881728921, 12.519420535427269, 13.434783828288126, 14.391231726449712, 15.440445439967728, 16.44836737772665, 17.361316216945536, 18.24126733964255, 17.329162359841185, 16.361852943616924, 15.439315735923927, 14.490731739851219, 13.517731849984452, 12.648048332696627, 11.616057754532928, 10.78731395478929, 9.823299080072855, 8.82396473290554, 9.726792765153643, 10.76520091785162, 11.707327706247526, 12.6571388706196, 13.665636157446825, 14.584774338847481, 15.567813076122349, 16.375493483035385, 17.331665674328953, 18.277762741232934, 18.395926089378946, 17.369851584240223, 16.406220535576832, 15.510152132466965, 14.462038011496839, 13.639215439728854, 12.56972397079906, 11.745862974015905, 10.748326644800573, 9.81081880506538, 8.78176946488814, 9.789442425836553, 10.75728499989088, 11.781894901631954, 12.746101768095233, 13.580766013043855, 14.557760402919362, 15.34483859328011, 16.32727007917939, 17.30144486573832, 18.31690943826586, 17.50183800679145, 16.508869952413782, 15.539390121255405, 14.47598123608012, 13.519150880132583, 12.54148404497619, 11.637498126735027, 10.660261222196715, 9.719670068916328, 7.834726924287649, 8.78993292578438, 9.781339939387632, 10.782881531288268, 11.750554555034695, 12.647173702220952, 13.495343921504043, 14.419589952494864, 15.392502812930418, 16.32377754131632, 17.258367530174116, 16.489491225532955, 15.507510318373344, 14.536099117659187, 13.592675696569144, 12.560529451295357, 11.585755508499853, 10.636972893246117, 9.741427337628636, 8.762521456038694, 6.841524836164286, 7.8171103323460756, 8.764148383912998, 9.793678102299578, 10.75861145273936, 11.596374806620952, 12.488997117689259, 13.473496005778554, 14.431652070153241, 15.387997514354877, 16.3937827045397, 15.438935211074629, 14.508454672644163, 13.542356282344395, 12.534539502044744, 11.612366792348606, 10.652921478982607, 9.702353029599555, 8.777309021919473, 7.7734791681203195, 5.874318522866144, 6.8649861057649, 7.77299738359367, 8.769585004747059, 9.702944823756505, 10.610912130778946, 11.535429776864515, 12.526987223338454, 13.531576151279012, 14.371349868507815, 15.42306110610888, 14.506495985398825, 13.576360336782177, 12.548564733900072, 11.564289659507937, 10.622196144211584, 9.688989161160189, 8.757131480881664, 7.837589856873699, 6.886393405194708, 4.945718466761987, 5.856390613931773, 6.820042996476723, 7.702430007366716, 8.671556990389607, 9.628869068079304, 10.530795521669006, 11.476160548502218, 12.456602841590717, 13.408287818158461, 14.371120607636131, 13.555328496521923, 12.633695697794783, 11.576378180892114, 10.622769457902335, 9.685030052583551, 8.698338169230379, 7.754907429086334, 6.796218693644599, 5.92584119311401, 3.9392264220518745, 4.8822003734257615, 5.78492376129838, 6.733229999871989, 7.620886710788027, 8.617072967733048, 9.59758197375025, 10.532988181977096, 11.502789873890395, 12.438185386134329, 13.391502978402082, 12.55391251376595, 11.62035947326508, 10.691832348761272, 9.672398054979608, 8.699098674399192, 7.80447273080735, 6.8032131874230934, 5.848296270279971, 4.860377028524017, 2.972594996855438, 3.829569154554794, 4.727240789049351, 5.735027235521395, 6.6769257152946295, 7.7416203084662385, 8.659764770036011, 9.676854395532041, 10.71377397036641, 11.69060239381305, 12.579545089802915, 11.523550855670676, 10.592402857564412, 9.645433471789028, 8.720233028385563, 7.739395083676957, 6.785327780100186, 5.846845312117352, 4.849178198743099, 3.8487288131321975, 2.0180219025039787, 2.8600737677383004, 3.7893334574247177, 4.749016230719872, 5.682288491668286, 6.669842395395489, 7.6392525213026055, 8.696665413420888, 9.76067245182335, 10.833962788686945, 11.830257005010925, 10.886575528319074, 9.813075359793222, 8.766576653350661, 7.745848859164242, 6.766621244477784, 5.861634934671216, 4.877087522437402, 3.9662454855603366, 2.9162666015519423, 1.0108211123452633, 1.9242528250546513, 2.85386664777433, 3.9064512199293935, 4.864662709446607, 5.859398703722827, 6.8330525574118415, 7.874500840920893, 8.911653899173778, 9.883011793579845, 10.925912477469938, 9.92762086731718, 8.874426369337236, 7.840665805326567, 6.847040942430413, 5.823122704504394, 4.8770097274929, 3.906763144146145, 2.9417770775299203, 1.9299781101394051, 0.0, 0.9612297495606136, 1.9983960880750127, 2.9401355495146495, 3.9294670260095503, 4.993876341370974, 6.0299231309016665, 7.022905839270886, 8.093322783040866, 9.070451582622926, 9.91660239876041, 8.907045289989943, 7.959643865012582, 6.9968186480649415, 6.012824978242842, 5.072807302260173, 4.0403162816345635, 2.9750700594750863, 1.9340762970762966, 0.991382706146451, 0.9458492675472714, 1.9038826480871978, 2.8994309393191293, 3.861222582091414, 4.866907050017489, 5.872833121323531, 6.925696725493194, 7.9700513374408954, 9.026308387382073, 9.989837833189984, 10.836036726169297, 9.836761331576293, 8.881070848343594, 7.862125457481584, 6.812143076240508, 5.8448905228462085, 4.832168487428309, 3.8896790714031373, 2.9033319105318833, 1.997491696346426, 1.9711977548050799, 2.862049633433268, 3.844112204064323, 4.786992561056261, 5.837970229211395, 6.812075810741795, 7.86064938102896, 8.843270750450653, 9.810693430849577, 10.755150184504037, 11.680500304737754, 10.844521049453242, 9.811761453591268, 8.856900823213527, 7.825212639828942, 6.7824859377352436, 5.855525376200048, 4.917437731211301, 3.8560872245445417, 2.9368955598488635, 2.9019525623239626, 3.927500505536922, 4.887622189878994, 5.744925368455737, 6.744683777917181, 7.743640257418007, 8.72333453414146, 9.705348481576376, 10.65976968249265, 11.697767333309486, 12.618152543749515, 11.807203861018575, 10.849675033448246, 9.844331302900308, 8.830779431137278, 7.774207814861868, 6.818549266039058, 5.7560478454054635, 4.793942566596101, 3.868456789615648, 3.8804168314196126, 4.827290116817748, 5.8133218908196715, 6.677109466814753, 7.743844285029792, 8.698968326818537, 9.655269514688083, 10.671744762093077, 11.603580345703431, 12.591623155486579, 13.522781523288463, 12.53998682265708, 11.611417605194484, 10.670969248537292, 9.66459626137092, 8.669635462847758, 7.6851038680312085, 6.720431230275222, 5.759627779332282, 4.832667180581405, 4.924020040625168, 5.821468235771441, 6.782644268500722, 7.677646325496394, 8.677780550081435, 9.750554291114758, 10.607812498607512, 11.562836230318625, 12.548980620293946, 13.532007743786673, 14.469339322493015, 13.476080689571033, 12.606250595403969, 11.70462671060227, 10.642687473997634, 9.605164326599647, 8.647345821618448, 7.698604056159828, 6.817373307435377, 5.782558643448214, 5.951773035300018, 6.840487226546944, 7.814535371787922, 8.610338037663592, 9.643919399781176, 10.670555523708412, 11.615439086609287, 12.598726303343659, 13.544463713504973, 14.603471807482094, 15.396490572508696, 14.439536312583844, 13.634658934677509, 12.652940756235342, 11.667919082185202, 10.607011072123512, 9.613990556575748, 8.731881910991335, 7.784015344267086, 6.805915391298004], [8.841897065319102, 9.691424012684553, 10.678671784377995, 11.511358332846974, 12.564825036460949, 13.5695233515498, 14.583805254471637, 15.597509180324213, 16.38717213951633, 15.477457685539342, 14.573484524854075, 13.547008934567923, 12.583066261927529, 11.593073363285427, 10.63647383243085, 9.665438005174188, 8.626937070763589, 8.15932963504473, 7.178126255571872, 7.91873362786158, 9.788018037858343, 10.66745989736471, 11.645917104157892, 12.451756411834918, 13.386909816560218, 14.36412302951102, 15.425148918159094, 16.360374649713783, 17.347121656346243, 16.373030097604023, 15.418924839595242, 14.489291830193977, 13.526287120119783, 12.545010643755031, 11.563439225243586, 10.66201104057479, 9.699050669429557, 9.097541704134638, 8.110922387094538, 8.847427931654464, 10.76920112104229, 11.00826796410541, 11.881047426967815, 12.744244052867856, 13.743180611767462, 14.64731601537281, 15.564019903148608, 16.471214396033794, 17.351765648045294, 17.306205672148923, 16.394100692347557, 15.426791276123296, 14.5042540684303, 13.555670072357591, 12.582670182490824, 11.712986665203, 10.6809960870393, 10.066980759277724, 9.10296588456129, 9.785194482466153, 10.572698922675391, 10.046858889266264, 10.831922264503495, 11.781733428875569, 12.790230715702794, 13.623544589286869, 14.606583326561733, 15.41426373347477, 16.37043592476834, 17.31653299167232, 17.46086442188532, 16.434789916746595, 15.471158868083204, 14.575090464973337, 13.526976344003211, 12.704153772235227, 11.634662303305433, 11.121850180612755, 10.154913743786715, 10.772048554625993, 9.627675622409887, 9.008683957007177, 9.88187955814685, 10.820665152071342, 11.784872018534621, 12.619536263483242, 13.596530653358748, 14.383608843719497, 15.366040329618775, 16.340215116177706, 17.355679688705244, 17.36488167123439, 16.447131487560046, 15.501698802731877, 14.597105218677553, 13.665738007740313, 12.61487572447642, 12.083315401363208, 11.174898702663324, 10.565576226438075, 8.680633081809397, 8.009174456955003, 8.835181229204473, 9.821651781727656, 10.789324805474083, 11.68594395266034, 12.534114171943429, 13.45836020293425, 14.431273063369805, 15.362547791755707, 16.2971377806135, 17.32358385843543, 16.468740067933958, 15.497328867219801, 14.553905446129757, 13.52175920085597, 12.546985258060465, 11.524819760116037, 10.588857577745046, 9.60842761356044, 7.687430993686033, 6.995433918082833, 7.802918634352385, 8.832448352738966, 9.797381703178749, 10.63514505706034, 11.527767368128645, 12.51226625621794, 13.470422320592627, 14.426767764794263, 15.432552954979087, 16.397508718262184, 15.469684422204775, 14.503586031905009, 13.495769251605358, 12.573596541909218, 11.61415122854322, 10.590199896469475, 9.624739262035883, 8.619385325642066, 6.720224680387891, 5.984371997444517, 6.811767634033058, 7.808355255186447, 8.741715074195893, 9.649682381218334, 10.5742000273039, 11.56575747377784, 12.570346401718398, 13.410120118947201, 14.461831356548267, 15.365705770257794, 14.537590086342789, 13.509794483460686, 12.52551940906855, 11.583425893772198, 10.6502189107208, 9.718361230442277, 8.77215353386241, 7.780897222118961, 5.791624624283734, 4.911438028522931, 5.858813246916111, 6.741200257806103, 7.710327240828995, 8.667639318518692, 9.569565772108392, 10.514930798941602, 11.495373092030103, 12.447058068597848, 13.409890858075517, 14.414538281380892, 13.594925447355397, 12.537607930452728, 11.583999207462949, 10.646259802144165, 9.65956791879099, 8.716137178646948, 7.757448443205213, 6.8433965028173125, 4.785132579573622, 3.937247788016919, 4.823694011737768, 5.772000250311376, 6.659656961227415, 7.655843218172436, 8.636352224189636, 9.571758432416482, 10.54156012432978, 11.476955636573715, 12.430273228841468, 13.413122298624918, 12.581589222825693, 11.653062098321886, 10.633627804540222, 9.660328423959806, 8.765702480367963, 7.764442936983707, 6.809526019840585, 5.821606778084631, 3.818501154377185, 2.868339404994181, 3.7660110394887383, 4.773797485960782, 5.715695965734017, 6.7803905589056255, 7.698535020475398, 8.71562464597143, 9.752544220805797, 10.729372644252438, 11.756514572802116, 12.48478060523129, 11.553632607125026, 10.606663221349642, 9.681462777946177, 8.70062483323757, 7.7465575296608, 6.8080750616779655, 5.8104079483037125, 4.809958562692811, 2.9683895900415385, 1.898844018177687, 2.8281037078641043, 3.7877864811592588, 4.721058742107673, 5.708612645834876, 6.678022771741992, 7.735435663860276, 8.799442702262738, 9.872733039126333, 10.869027255450312, 11.847805277879687, 10.774305109353834, 9.727806402911273, 8.707078608724855, 7.727850994038397, 6.8228646842318295, 5.838317271998015, 4.9274752351209505, 3.877496351112556, 1.9720508619058768, 0.9630230754940379, 1.8926368982137167, 2.9452214703687796, 3.9034329598859934, 4.898168954162213, 5.871822807851228, 6.913271091360279, 7.9504241496131645, 8.921782044019231, 9.980930932697822, 10.888850616877795, 9.83565611889785, 8.80189555488718, 7.808270691991026, 6.784352454065007, 5.838239477053513, 4.8679928937067585, 3.9030068270905334, 2.891207859700019, 0.9612297495606136, 0.0, 1.037166338514399, 1.9789057999540356, 2.9682372764489364, 4.0326465918103604, 5.068693381341053, 6.061676089710272, 7.132093033480253, 8.109221833062312, 9.092641202322447, 9.868275039550557, 8.920873614573196, 7.958048397625555, 6.9740547278034555, 6.034037051820787, 5.001546031195177, 3.9362998090356998, 2.89530604663691, 1.9526124557070645, 1.9070790171078849, 1.0366762159692269, 1.9643692718255044, 2.926160914597789, 3.9056773004568752, 4.911603371762917, 5.96446697593258, 7.0088215878802815, 8.06507863782146, 9.02860808362937, 10.064479970871139, 10.797991081136907, 9.842300597904208, 8.823355207042198, 7.773372825801122, 6.806120272406822, 5.793398236988922, 4.850908820963751, 3.864561660092497, 2.9587214459070394, 2.9324275043656933, 1.9948432013152972, 2.9769057719463525, 3.8519308935626357, 4.90290856171777, 5.87701414324817, 6.925587713535334, 7.908209082957026, 8.875631763355951, 9.820088517010412, 10.745438637244128, 11.681646507383912, 10.772991203151882, 9.818130572774141, 8.786442389389556, 7.7437156872958575, 6.816755125760661, 5.878667480771915, 4.817316974105156, 3.898125309409477, 3.863182311884576, 3.0602940734189517, 4.020415757761023, 4.809863700962112, 5.809622110423556, 6.808578589924382, 7.7882728666478345, 8.770286814082752, 9.724708014999026, 10.762705665815862, 11.68309087625589, 12.685433420285547, 11.81090478300886, 10.80556105246092, 9.792009180697892, 8.735437564422481, 7.779779015599671, 6.717277594966077, 5.755172316156714, 4.829686539176262, 4.841646580980226, 4.106956921306183, 5.087729502398035, 5.742047799321128, 6.808782617536167, 7.7639066593249115, 8.720207847194457, 9.736683094599451, 10.668518678209807, 11.656561487992954, 12.58771985579484, 13.501216572217693, 12.572647354755098, 11.632198998097905, 10.625826010931535, 9.630865212408372, 8.646333617591822, 7.681660979835835, 6.720857528892895, 5.793896930142018, 5.885249790185781, 5.101135040259876, 6.062311072989157, 6.742584658002768, 7.742718882587809, 8.815492623621132, 9.672750831113884, 10.627774562824998, 11.613918952800319, 12.596946076293046, 13.534277654999388, 14.437310439131647, 13.567480344964583, 12.665856460162884, 11.603917223558248, 10.566394076160261, 9.608575571179061, 8.65983380572044, 7.778603056995989, 6.743788393008826, 6.913002784860631, 6.120154031035379, 7.094202176276356, 7.675276370169965, 8.708857732287548, 9.735493856214784, 10.68037741911566, 11.663664635850031, 12.609402046011345, 13.668410139988467, 14.478860803876394, 15.400766062144458, 14.595888684238123, 13.614170505795954, 12.629148831745816, 11.568240821684126, 10.575220306136362, 9.693111660551947, 8.745245093827698, 7.7671451408586165], [9.815602653294182, 10.665129600659633, 11.652377372353074, 12.485063920822054, 13.538530624436028, 14.543228939524878, 15.557510842446716, 16.42459260639864, 15.385054802658724, 14.440291347024946, 13.53631818633968, 12.509842596053527, 11.545899923413133, 10.555907024771031, 9.599307493916454, 8.628271666659792, 7.589770732249191, 7.178841112072375, 8.064201264145682, 8.892439215836658, 10.76172362583342, 11.641165485339789, 11.962698934717645, 12.819957971078722, 13.755111375804022, 14.682474506930019, 15.634441619694261, 16.567256918665176, 16.356979788285177, 15.335863759089627, 14.381758501080846, 13.452125491679581, 12.489120781605386, 11.507844305240635, 10.52627288672919, 9.624844702060392, 8.661884330915159, 8.122587902897688, 8.996997395668348, 9.82113351962954, 11.742906709017367, 11.82436805121959, 10.927867472025715, 11.791064097925757, 12.790000656825363, 13.694136060430713, 14.610839948206511, 15.518034441091698, 16.398585693103197, 16.269039333634527, 15.356934353833163, 14.3896249376089, 13.467087729915903, 12.518503733843195, 11.545503843976428, 10.675820326688601, 9.643829748524903, 9.092866173472704, 9.9890408931351, 10.75890007044123, 11.47874661317265, 10.862958976380444, 9.878742309561396, 10.82855347393347, 11.837050760760695, 12.670364634344772, 13.653403371619635, 14.461083778532673, 15.417255969826241, 16.363353036730224, 16.423698083370926, 15.3976235782322, 14.433992529568808, 13.537924126458941, 12.489810005488815, 11.666987433720827, 10.597495964791033, 10.147735594807735, 11.040988752360525, 11.74575414260107, 10.533723312907146, 9.830510337558753, 8.92869960320475, 9.867485197129245, 10.831692063592524, 11.666356308541145, 12.64335069841665, 13.4304288887774, 14.412860374676677, 15.387035161235609, 16.40249973376315, 16.327715332719993, 15.40996514904565, 14.46453246421748, 13.559938880163157, 12.628571669225913, 11.57770938596202, 11.109200815558188, 12.060973711237134, 11.471623916935334, 9.586680772306655, 8.83100083750658, 7.882001274262374, 8.868471826785559, 9.836144850531985, 10.732763997718243, 11.580934217001332, 12.505180247992152, 13.478093108427707, 14.40936783681361, 15.343957825671405, 16.370403903493333, 16.41132478308609, 15.505853983471567, 14.555399059181005, 13.508211865233863, 12.533437922438358, 12.157261749990159, 11.494905268242306, 10.5144753040577, 8.593478684183292, 7.817260298634409, 6.849738679410287, 7.879268397796869, 8.844201748236651, 9.681965102118243, 10.574587413186547, 11.559086301275842, 12.51724236565053, 13.473587809852166, 14.47937300003699, 15.444328763320087, 16.295780578782917, 15.457182127501854, 14.449365347202203, 13.5130750306588, 12.553629717292802, 11.496247586966735, 10.530786952533143, 9.525433016139326, 7.626272370885151, 6.806198377996092, 5.8585876790909595, 6.855175300244349, 7.788535119253796, 8.696502426276236, 9.621020072361803, 10.612577518835742, 11.6171664467763, 12.456940164005104, 13.50865140160617, 14.412525815315696, 15.36368624292093, 14.463390579057531, 13.479115504665396, 12.537021989369043, 11.589697399470383, 10.657839719191859, 9.67820122435967, 8.686944912616221, 6.697672314780994, 5.8174857190201905, 4.905633291974013, 5.788020302864005, 6.757147285886898, 7.7144593635765935, 8.616385817166295, 9.561750843999505, 10.542193137088006, 11.49387811365575, 12.45671090313342, 13.461358326438795, 14.42102160393354, 13.495043060936657, 12.541434337946878, 11.603694932628095, 10.599046407540573, 9.655615667396528, 8.696926931954794, 7.749444193314573, 5.691180270070882, 4.843295478514179, 3.87051405679567, 4.818820295369279, 5.706477006285318, 6.702663263230338, 7.683172269247539, 8.618578477474385, 9.588380169387683, 10.523775681631617, 11.47709327389937, 12.45994234368282, 13.472335653515945, 12.648612021090363, 11.629177727308699, 10.655878346728283, 9.705180969117546, 8.703921425733288, 7.749004508590166, 6.761085266834211, 4.7245488448744455, 3.774387095491441, 2.812831084546641, 3.8206175310186845, 4.76251601079192, 5.827210603963528, 6.7453550655333006, 7.762444691029331, 8.799364265863698, 9.776192689310339, 10.803334617860017, 11.859328851992256, 12.549182529893503, 11.602213144118119, 10.677012700714654, 9.696174756006048, 8.68603601841038, 7.747553550427546, 6.749886437053293, 5.749437051442392, 3.8744372805387988, 2.804891708674947, 1.8749237529220069, 2.8346065262171614, 3.767878787165576, 4.755432690892778, 5.724842816799895, 6.7822557089181785, 7.84626274732064, 8.919553084184235, 9.915847300508215, 10.905597105053314, 11.769855032122312, 10.72335632567975, 9.702628531493332, 8.723400916806874, 7.818414607000306, 6.8338671947664915, 5.892436048528114, 4.84245716451972, 2.8819962003130373, 1.869070765991298, 0.9394569432716191, 1.91466284465842, 2.8662666213715946, 3.861002615647815, 4.834656469336829, 5.87610475284588, 6.913257811098765, 7.884615705504831, 8.94376459418342, 9.942056204336177, 10.831206041666327, 9.797445477655657, 8.803820614759502, 7.779902376833483, 6.833789399821989, 5.863542816475235, 4.89855674985901, 3.856168673107183, 1.9983960880750127, 1.037166338514399, 0.0, 0.9417394614396367, 1.9310709379345374, 2.9954802532959617, 4.031527042826654, 5.024509751195874, 6.094926694965854, 7.072055494547914, 8.05547486380805, 9.065031972578517, 9.958039953087594, 8.995214736139953, 8.011221066317853, 7.071203390335185, 6.038712369709575, 4.9734661475500985, 3.9324723851513093, 2.9897787942214635, 2.8807846050829635, 1.922751224543037, 0.9272029333111053, 1.8889945760833902, 2.8685109619424765, 3.8744370332485185, 4.927300637418182, 5.971655249365884, 7.027912299307061, 7.9914417451149715, 9.02731363235674, 10.014632920114547, 10.879466936418607, 9.860521545556598, 8.810539164315522, 7.843286610921222, 6.830564575503321, 5.88807515947815, 4.901727998606896, 3.932427033882118, 3.906133092340772, 2.8809182098891073, 1.9916856747074352, 2.814764555048237, 3.8657422232033714, 4.839847804733771, 5.888421375020936, 6.8710427444426285, 7.838465424841552, 8.782922178496014, 9.70827229872973, 10.644480168869514, 11.677239764731487, 10.85529691128854, 9.823608727903956, 8.780882025810257, 7.853921464275061, 6.8673214682976305, 5.805970961630871, 4.871830897384555, 4.836887899859655, 3.9463690819927617, 3.0351956605221053, 3.7726973624477136, 4.772455771909157, 5.771412251409983, 6.751106528133436, 7.733120475568352, 8.687541676484626, 9.725539327301462, 10.645924537741491, 11.648267081771149, 12.605795909341477, 11.839131077651835, 10.825579205888806, 9.769007589613395, 8.76414398429876, 7.690983182941155, 6.728877904131792, 5.80339212715134, 5.815352168955305, 4.993031929879993, 4.102509405159117, 4.704881460806729, 5.771616279021768, 6.726740320810513, 7.683041508680059, 8.699516756085053, 9.631352339695407, 10.619395149478555, 11.55055351728044, 12.57131733046129, 13.499886547923886, 12.605904586072985, 11.599531598906614, 10.604570800383451, 9.6200392055669, 8.655366567810914, 7.694563116867974, 6.767602518117096, 6.85895537816086, 5.987210048833686, 5.081822550016803, 5.70541831948837, 6.70555254407341, 7.7783262851067345, 8.635584492599488, 9.590608224310602, 10.576752614285923, 11.55977973777865, 12.497111316484991, 13.507411197375244, 14.49471953813337, 13.639562048137963, 12.577622811533328, 11.54009966413534, 10.58228115915414, 9.63353939369552, 8.752308644971068, 7.717493980983905, 7.88670837283571, 7.006229039609189, 6.113713653304002, 6.638110031655567, 7.67169139377315, 8.698327517700386, 9.643211080601263, 10.626498297335635, 11.572235707496949, 12.63124380147407, 13.441694465361998, 14.39864872528685, 15.44607330494234, 14.587876093771033, 13.602854419720895, 12.541946409659205, 11.548925894111441, 10.666817248527027, 9.718950681802777, 8.740850728833696], [10.733323974938703, 11.582850922304154, 12.576193257848143, 12.937859508695269, 13.920193570414781, 14.828128376812439, 15.643948994975766, 15.498297117131962, 14.458759313392045, 13.51399585775827, 12.610022697073003, 11.58354710678685, 10.619604434146456, 9.629611535504354, 8.673012004649777, 7.701976177393115, 6.663475242982514, 7.675667202131355, 8.724214442743229, 9.743850913136997, 11.493549804756672, 12.43863389910993, 12.904438396157282, 11.997461429707325, 12.932614834432625, 13.782173070381338, 14.70405579089783, 15.636871089868745, 15.4306842990185, 14.40956826982295, 13.45546301181417, 12.525830002412905, 11.56282529233871, 10.581548815973958, 9.599977397462514, 8.698549212793715, 7.735588841648482, 8.61941399295667, 9.606033309996771, 10.552959698552792, 12.474732887940618, 12.766107512659229, 11.869606933465352, 10.96856755655436, 11.94397322572298, 12.793834623882033, 13.68045411941008, 14.587648612295267, 15.468199864306763, 15.342743844367853, 14.430638864566486, 13.463329448342224, 12.540792240649226, 11.592208244576518, 10.619208354709752, 9.749524837421925, 8.717534259258226, 9.589692263531685, 10.55370713824812, 11.490726249364482, 12.420486074612286, 11.80469843782008, 10.820481771001033, 10.006056932562073, 10.991023329658312, 11.770063197796091, 12.723017542823204, 13.530697949736242, 14.48687014102981, 15.432967207933793, 15.49740259410425, 14.471328088965523, 13.507697040302132, 12.611628637192265, 11.563514516222138, 10.740691944454152, 9.671200475524358, 10.609330097513908, 11.605654997473545, 12.477580321524322, 11.475462774346783, 10.77224979899839, 9.870439064644387, 8.967183760580568, 9.931390627043847, 10.766054871992464, 11.712964869620219, 12.500043059980968, 13.482474545880246, 14.456649332439177, 15.472113904966717, 15.401419843453317, 14.483669659778974, 13.538236974950804, 12.63364339089648, 11.702276179959238, 10.651413896695345, 11.570795318264361, 12.548032222802673, 12.41336337837497, 10.528420233746292, 9.772740298946216, 8.82374073570201, 7.968170390236883, 8.935843413983308, 9.832462561169562, 10.6505483882049, 11.57479441919572, 12.547707279631275, 13.478982008017178, 14.413571996874973, 15.440018074696901, 15.485029293819412, 14.57955849420489, 13.62910356991433, 12.581916375967188, 11.607142433171683, 12.618856252696332, 12.436644729681943, 11.456214765497338, 9.53521814562293, 8.758999760074046, 7.7914781408499225, 6.978966961248192, 7.943900311687974, 8.781663665569562, 9.644201584390116, 10.62870047247941, 11.586856536854098, 12.543201981055734, 13.548987171240558, 14.513942934523655, 15.365394749986486, 15.485948214858636, 14.478131434558986, 13.499421776054927, 12.539976462688928, 12.437987048406374, 11.47252641397278, 10.467172477578963, 8.568011832324787, 7.747937839435728, 6.800327140530595, 5.954873863695672, 6.888233682705118, 7.796200989727557, 8.690634243565372, 9.68219169003931, 10.686780617979869, 11.526554335208672, 12.578265572809737, 13.482139986519265, 14.4333004141245, 15.40513004049717, 14.420854966105034, 13.478761450808681, 12.531436860910022, 11.599579180631498, 10.619940685799307, 9.628684374055858, 7.63941177622063, 6.759225180459827, 5.847372753413649, 4.887718866315328, 5.85684584933822, 6.814157927027915, 7.685999988369863, 8.631365015203073, 9.611807308291574, 10.563492284859318, 11.526325074336988, 12.530972497642363, 13.490635775137108, 14.43310169202054, 13.483173799386517, 12.545434394067733, 11.540785868980212, 10.597355128836167, 9.638666393394432, 8.691183654754209, 6.632919731510518, 5.785034939953816, 4.8122535182353054, 3.918518858820602, 4.80617556973664, 5.8023618266816595, 6.752786440451107, 7.688192648677953, 8.657994340591252, 9.593389852835186, 10.546707445102939, 11.529556514886389, 12.541949824719513, 13.475502669489074, 12.570917188748336, 11.59761780816792, 10.64692043055718, 9.645660887172927, 8.690743970029803, 7.702824728273848, 5.666288306314081, 4.716126556931077, 3.754570545986277, 2.9203160944700075, 3.8622145742432425, 4.8968247751670955, 5.814969236736868, 6.832058862232898, 7.868978437067265, 8.845806860513907, 9.872948789063585, 10.928943023195824, 11.860091021302088, 12.543952605557756, 11.61875216215429, 10.637914217445685, 9.627775479850015, 8.689293011867182, 7.69162589849293, 6.691176512882029, 4.816176741978435, 3.7466311701145836, 2.8166632143616432, 1.9042206974207292, 2.8374929583691437, 3.8250468620963463, 4.794456988003462, 5.851869880121746, 6.915876918524208, 7.989167255387802, 8.985461471711782, 9.97521127625688, 11.028439851544732, 11.665095787119387, 10.644367992932969, 9.66514037824651, 8.760154068439943, 7.775606656206128, 6.834175509967752, 5.784196625959358, 3.823735661752674, 2.8108102274309346, 1.8811964047112557, 0.9729233832187832, 1.9245271599319578, 2.919263154208178, 3.892917007897192, 4.934365291406243, 5.971518349659128, 6.942876244065194, 8.002025132743785, 9.000316742896542, 10.053511240876487, 10.739184939095294, 9.745560076199139, 8.72164183827312, 7.775528861261626, 6.805282277914872, 5.8402962112986465, 4.79790813454682, 2.940135549514649, 1.9789057999540356, 0.9417394614396367, 0.0, 0.9893314764949007, 2.0537407918563253, 3.089787581387018, 4.082770289756238, 5.153187233526218, 6.130316033108278, 7.113735402368414, 8.123292511138882, 9.070693936116243, 9.93695419757959, 8.95296052775749, 8.012942851774822, 6.980451831149212, 5.915205608989735, 4.874211846590946, 3.9315182556611, 3.8225240665225995, 2.8644906859826733, 1.868942394750742, 0.962699086816713, 1.9267715005028396, 2.9326975718088817, 3.985561175978545, 5.029915787926247, 6.086172837867425, 7.049702283675336, 8.085574170917106, 9.072893458674912, 10.02858394190761, 10.802261006996234, 9.752278625755158, 8.785026072360859, 7.772304036942958, 6.829814620917787, 5.843467460046533, 4.874166495321754, 4.847872553780408, 3.8226576713287437, 2.87947991217392, 1.88846906578156, 2.9394467339366948, 3.913552315467095, 4.96212588575426, 5.944747255175952, 6.912169935574876, 7.856626689229337, 8.781976809463053, 9.718184679602837, 10.75094427546481, 11.761485767917572, 10.765348189343593, 9.722621487249894, 8.795660925714698, 7.809060929737266, 6.747710423070507, 5.813570358824191, 5.778627361299291, 4.868510738284696, 3.8301888027122066, 2.8464018731810365, 3.8461602826424803, 4.845116762143307, 5.824811038866759, 6.806824986301676, 7.761246187217949, 8.799243838034783, 9.719629048474815, 10.721971592504472, 11.6795004200748, 12.712718643373337, 11.767318667328441, 10.71074705105303, 9.705883445738396, 8.63272264438079, 7.670617365571428, 6.745131588590976, 6.731581422258207, 5.784708136860072, 4.798676362858148, 3.7785859715400525, 4.845320789755092, 5.800444831543836, 6.756746019413383, 7.773221266818377, 8.705056850428731, 9.693099660211878, 10.624258028013763, 11.645021841194616, 12.573591058657211, 13.514039415314404, 12.54127106034625, 11.546310261823088, 10.561778667006537, 9.59710602925055, 8.63630257830761, 7.685323839761618, 7.750624450074984, 6.677214042934425, 5.716038010205144, 4.779122830221693, 5.779257054806734, 6.852030795840058, 7.7092890033328105, 8.664312735043925, 9.650457125019246, 10.633484248511973, 11.570815827218315, 12.58111570810857, 13.568424048866696, 14.57206343448717, 13.519362272972964, 12.481839125574977, 11.524020620593777, 10.575278855135156, 9.670029966615589, 8.635215302628426, 8.742174554585349, 7.6962330337099285, 6.704010114206526, 5.711814542388891, 6.7453959045064735, 7.77203202843371, 8.716915591334587, 9.700202808068958, 10.645940218230272, 11.704948312207394, 12.515398976095321, 13.472353236020172, 14.519777815675662, 15.511567943230823, 14.544593881160532, 13.483685871098842, 12.490665355551078, 11.608556709966663, 10.636672003447298, 9.658572050478217], [11.722655451433605, 12.572182398799056, 13.565524734343045, 13.87782586172458, 13.158776884841544, 13.970694867934009, 14.761433827745229, 14.580237619924343, 13.540699816184427, 12.59593636055065, 11.798239151586012, 10.77176356129986, 9.807820888659466, 8.817827990017364, 7.891404887840732, 6.92036906058407, 7.6528067194774145, 8.664998678626255, 9.713545919238127, 10.733182389631896, 12.482881281251569, 13.427965375604828, 13.891645005540834, 12.937427782736636, 12.171198148859387, 12.924739561502909, 13.821540623667293, 14.754355922638208, 14.51761905661271, 13.5880900634659, 12.643679466327178, 11.714046456925914, 10.751041746851719, 9.769765270486968, 8.818370280653468, 7.9859428193565165, 8.724920318143383, 9.608745469451568, 10.595364786491668, 11.542291175047689, 13.464064364435515, 13.75331412204278, 12.856813542848904, 11.90853390958367, 11.162094387570866, 11.936401115003603, 12.797938952179543, 13.70513344506473, 14.585684697076227, 14.521265638010803, 13.618855319079495, 12.651545902855233, 11.740467514036341, 10.791883517963633, 9.837601237900707, 9.036918443984726, 9.706865735753127, 10.579023740026583, 11.543038614743018, 12.480057725859378, 13.409817551107187, 12.791905047203633, 11.807688380384585, 10.946023285591384, 10.209144491506198, 10.912629688917661, 11.840502375592667, 12.648182782505705, 13.604354973799273, 14.550452040703256, 14.685619048617259, 13.663909607333673, 12.707372313689246, 11.83002152038322, 10.781907399413093, 10.051921262690186, 10.660531952019259, 11.598661574008808, 12.594986473968444, 13.466911798019218, 12.464794250841683, 11.75945640838194, 10.857645674027939, 9.907150113609879, 9.149511788891733, 9.908621363114035, 10.830449702389682, 11.61752789275043, 12.599959378649709, 13.574134165208644, 14.589598737736184, 14.594001361821467, 13.683344933166088, 12.756629858141759, 11.852036274087435, 11.013505498195272, 11.640745373190246, 12.560126794759261, 13.537363699297574, 13.402694854869871, 11.517751710241193, 10.759946908329766, 9.810947345085562, 8.908136743266192, 8.078409905104879, 8.975029052291132, 9.768033220974363, 10.692279251965184, 11.665192112400739, 12.596466840786645, 13.53105682964444, 14.557502907466368, 14.684704567206527, 13.797951377395846, 12.881494150875312, 11.972126927032498, 12.596473909666583, 13.608187729191233, 13.425976206176843, 12.445546241992238, 10.52454962211783, 9.746206369457596, 8.778684750233474, 7.918933314277502, 7.086466802809544, 7.924230156691133, 8.761686417159579, 9.746185305248874, 10.704341369623561, 11.660686813825201, 12.666472004010025, 13.631427767293122, 14.482879582755952, 14.791694212710638, 13.939630345399712, 12.964226736575464, 13.529307939183829, 13.427318524901274, 12.46185789046768, 11.456503954073863, 9.557343308819688, 8.735144448819279, 7.787533749914146, 6.894840216724982, 6.030800173826687, 6.938767480849127, 7.808119076334836, 8.799676522808774, 9.804265450749336, 10.64403916797814, 11.695750405579204, 12.599624819288731, 13.550785246893966, 14.544684717627295, 14.909880187936519, 13.980207207354965, 13.520768337404922, 12.588910657126398, 11.609272162294207, 10.618015850550758, 8.62874325271553, 7.748556656954728, 6.834579362797199, 5.827685219344638, 4.99941234045979, 5.956724418149485, 6.803484821139328, 7.748849847972539, 8.729292141061041, 9.680977117628785, 10.643809907106455, 11.64845733041183, 12.608120607906574, 13.550586524790006, 14.472505275881417, 13.534765870562634, 12.530117345475112, 11.586686605331067, 10.627997869889333, 9.68051513124911, 7.622251208005419, 6.774366416448716, 5.799460127618856, 4.858485211849912, 3.9487420608582093, 4.94492831780323, 5.870271273220572, 6.805677481447418, 7.775479173360718, 8.710874685604653, 9.664192277872406, 10.647041347655856, 11.65943465748898, 12.592987502258541, 13.560248665243238, 12.586949284662822, 11.636251907052081, 10.634992363667827, 9.680075446524704, 8.692156204768748, 6.655619782808983, 5.705458033425979, 4.741777155369827, 3.860282447499317, 3.0047810653648117, 4.021871512104441, 4.932454069506333, 5.949543695002363, 6.9864632698367295, 7.96329169328337, 8.978704154775329, 10.018571018998909, 10.949719017105172, 11.896688402880557, 12.608083638649193, 11.627245693940587, 10.617106956344916, 9.678624488362082, 8.68095737498783, 7.680507989376929, 5.805508218473336, 4.735962646609485, 3.803869823745193, 2.8441870504500386, 1.9625396953064884, 2.950093599033691, 3.911941820772927, 4.96935471289121, 5.9900008080071405, 7.007026414925166, 8.003320631249146, 8.993070435794245, 10.039108375049832, 11.085476754383807, 11.63369946942787, 10.654471854741413, 9.749485544934844, 8.76493813270103, 7.823506986462652, 6.773528102454258, 4.8130671382475745, 3.8001417039258354, 2.8705278812061565, 1.9128897362480923, 0.935195683437057, 1.9299316777132773, 2.9035855314022916, 3.945033814911343, 4.982186873164228, 5.9535447675702935, 7.012693656248884, 8.010985266401642, 9.064179764381587, 10.08635015465393, 10.734891552694041, 9.710973314768022, 8.764860337756527, 7.794613754409772, 6.829627687793547, 5.787239611041721, 3.92946702600955, 2.9682372764489364, 1.9310709379345374, 0.9893314764949007, 0.0, 1.0644093153614245, 2.1004561048921166, 3.0934388132613364, 4.163855757031317, 5.140984556613377, 6.124403925873513, 7.133961034643981, 8.081362459621342, 9.044187676568983, 9.942292004252392, 9.002274328269724, 7.969783307644114, 6.904537085484637, 5.863543323085847, 4.920849732156001, 4.811855543017501, 3.8538221624775746, 2.858273871245643, 1.9520305633116137, 0.937440024007939, 1.943366095313981, 2.9962296994836444, 4.0405843114313456, 5.096841361372523, 6.060370807180434, 7.096242694422204, 8.083561982180012, 9.03925246541271, 10.05819785627472, 10.741610102250059, 9.77435754885576, 8.76163551343786, 7.819146097412688, 6.832798936541433, 5.863497971816655, 5.837204030275309, 4.8119891478236445, 3.8688113886688207, 2.8778005422764608, 1.9778860701075822, 2.9519916516379823, 4.000565221925147, 4.983186591346839, 5.950609271745763, 6.895066025400224, 7.82041614563394, 8.756624015773724, 9.789383611635698, 10.799925104088459, 11.754679665838493, 10.711952963744794, 9.784992402209598, 8.798392406232168, 7.737041899565408, 6.802901835319092, 6.767958837794192, 5.857842214779597, 4.819520279207108, 3.8357333496759374, 3.0377659295038204, 3.90153318622663, 4.881227462950082, 5.863241410384998, 6.817662611301271, 7.855660262118106, 8.758068384645702, 9.760410928675359, 10.717939756245688, 11.751157979544224, 12.756650143823345, 11.700078527547934, 10.695214922233298, 9.622054120875692, 8.65994884206633, 7.734463065085877, 7.720912898753108, 6.774039613354972, 5.788007839353049, 4.767917448034953, 4.061542967149432, 4.9532220444118416, 5.87200856088311, 6.833196994963826, 7.761473274512053, 8.7495160842952, 9.680674452097085, 10.701438265277936, 11.630007482740531, 12.570455839397724, 13.530602536841151, 12.535641738317988, 11.551110143501438, 10.586437505745451, 9.62563405480251, 8.67465531625652, 8.739955926569884, 7.6665455194293255, 6.705369486700044, 5.768454306716594, 4.995479232201074, 6.010489689786998, 6.824551544802538, 7.779575276513652, 8.765719666488973, 9.7487467899817, 10.652756330010696, 11.63753213219189, 12.624840472950016, 13.62847985857049, 14.508693749467865, 13.471170602069877, 12.513352097088678, 11.564610331630057, 10.659361443110491, 9.624546779123328, 9.731506031080249, 8.685564510204829, 7.693341590701427, 6.701146018883791, 5.963070705602959, 6.989706829530196, 7.832178132804313, 8.815465349538686, 9.7612027597, 10.820210853677121, 11.597339478887703, 12.554293738812554, 13.601718318468043, 14.593508446023204, 14.92973688382276, 14.172198467242065, 13.479996832045979, 12.597888186461564, 11.6260034799422, 10.647903526973119], [12.787064766795028, 13.63659171416048, 14.629934049704469, 14.8442503921754, 13.956277644444313, 13.075438124605922, 13.792664791571163, 13.685016669764199, 12.645478866024282, 11.700715410390504, 10.912005909618617, 9.885530319332466, 8.921587646692071, 7.931594748049969, 7.171050845272526, 7.880938937667829, 8.717216034838838, 9.729407993987678, 10.77795523459955, 11.79759170499332, 13.547290596612992, 14.492374690966251, 14.912347957919202, 13.903852313187457, 12.968698908462157, 12.029482818174822, 12.852771587493226, 13.78558688646414, 13.622398106452566, 12.692869113305754, 11.757446224359784, 10.82781321495852, 9.864808504884325, 8.883532028519573, 8.098016238085261, 8.946512696440276, 9.789329633504806, 10.673154784812992, 11.659774101853092, 12.606700490409112, 14.528473679796939, 14.774017074421149, 13.877516495227272, 12.912603210931573, 11.959595147173635, 11.041144371675516, 11.829169916005476, 12.736364408890662, 13.616915660902158, 13.626044687850657, 12.7326220771121, 11.765312660887838, 10.854234272068949, 9.90565027599624, 9.1172471953325, 9.997488321068486, 10.77127505111455, 11.643433055388007, 12.607447930104442, 13.544467041220802, 14.44781248749218, 13.812607999582001, 12.828391332762953, 11.950092586939286, 11.006645251108967, 10.017372945589575, 10.8717333394186, 11.679413746331637, 12.635585937625205, 13.581683004529188, 13.799385806649864, 12.777676365366279, 11.821139071721854, 10.952510484963884, 10.061553356844886, 11.012491139773946, 11.724941267380682, 12.663070889370232, 13.659395789329867, 14.531321113380642, 13.502789187226677, 12.780159360760312, 11.878348626406307, 10.911219414957781, 9.947012548494502, 9.01336461978595, 9.861680666215614, 10.648758856576363, 11.63119034247564, 12.605365129034574, 13.620829701562114, 13.707768119854073, 12.797111691198696, 11.879118822722424, 11.131682231519228, 11.974075375279032, 12.70515468855167, 13.624536110120685, 14.601773014658997, 14.440689791254865, 12.555746646626186, 11.780649860708138, 10.831650297463932, 9.928839695644562, 9.017379368678244, 8.079772308963047, 8.799264184800295, 9.723510215791116, 10.69642307622667, 11.627697804612575, 12.56228779347037, 13.588733871292298, 13.798471325239134, 12.92044034197651, 12.161140108307105, 12.932696804116258, 13.660883225028007, 14.672597044552656, 14.463971142561837, 13.483541178377232, 11.562544558502823, 10.766909321835968, 9.799387702611844, 8.939636266655873, 8.044963246013156, 7.028973413363048, 7.792917380985511, 8.777416269074806, 9.735572333449493, 10.691917777651131, 11.697702967835955, 12.662658731119052, 13.514110546581882, 13.914183177291303, 13.219276302831505, 13.924796613659224, 14.593717254545252, 14.465313461286268, 13.499852826852674, 12.494498890458857, 10.595338245204681, 9.75584740119765, 8.808236702292517, 7.915543169103354, 7.011250026248016, 6.043510737521043, 6.839350040160768, 7.830907486634706, 8.835496414575267, 9.67527013180407, 10.726981369405134, 11.630855783114662, 12.582016210719896, 13.575915681453225, 14.189526145368312, 14.940777084438725, 14.558763273789912, 13.626905593511388, 12.647267098679201, 11.656010786935752, 9.666738189100524, 8.78655159333972, 7.855282315175571, 6.84838817172301, 6.020115292838163, 5.061467674821401, 5.83471578496526, 6.780080811798471, 7.760523104886973, 8.712208081454715, 9.675040870932385, 10.67968829423776, 11.639351571732504, 12.581817488615936, 13.535426211605715, 14.473165616924499, 13.568112281860103, 12.624681541716058, 11.665992806274323, 10.718510067634103, 8.660246144390412, 7.812361352833708, 6.8201630799972275, 5.8791881642282835, 4.969445013236583, 4.049671574475146, 4.901502237046504, 5.83690844527335, 6.806710137186649, 7.7421056494305835, 8.695423241698336, 9.678272311481786, 10.69066562131491, 11.624218466084471, 12.69896325646771, 13.651358600024247, 12.674246843437071, 11.672987300052817, 10.718070382909694, 9.73015114115374, 7.693614719193975, 6.743452969810971, 5.762480107748199, 4.880985399877689, 4.025484017743185, 3.093732946130398, 3.963685033332265, 4.980774658828295, 6.017694233662662, 6.994522657109303, 8.009935118601263, 9.04980198282484, 9.939355836846751, 10.886325222622135, 11.8115256660256, 12.691655009302012, 11.655101892729908, 10.716619424747075, 9.718952311372822, 8.718502925761921, 6.8699175338347604, 5.800371961970909, 4.824572776123565, 3.864890002828411, 2.9832426476848615, 2.0219550330596485, 2.9431727845988593, 4.000585676717143, 5.021231771833072, 6.038257378751098, 7.0345515950750785, 8.024301399620176, 8.984952478820423, 10.021067439022382, 10.931474687291612, 11.718881170102838, 10.81389486029627, 9.829347448062455, 8.887916301824077, 7.8379374178156835, 5.877476453609, 4.86455101928726, 3.9349371965675815, 2.933592688626465, 1.95589863581543, 0.9611626415392098, 1.9348164952282239, 2.976264778737275, 4.013417836990159, 4.984775731396225, 6.043924620074816, 7.042216230227573, 8.010023868152178, 9.021940839292505, 9.902570027426856, 10.775382630129448, 9.829269653117953, 8.859023069771197, 7.894037003154972, 6.851648926403146, 4.993876341370975, 4.032646591810361, 2.995480253295962, 2.0537407918563253, 1.0644093153614245, 0.0, 1.0360467895306924, 2.029029497899912, 3.099446441669892, 4.076575241251953, 5.0599946105120885, 6.069551719282557, 7.016953144259918, 7.979778361207559, 8.96377203102966, 9.903789707012328, 9.03419262300554, 7.968946400846062, 6.927952638447272, 5.9852590475174265, 5.876264858378925, 4.918231477838999, 3.9226831866070673, 3.0164398786730384, 2.0018493393693637, 1.0354509798126186, 2.0883145839822816, 3.0385929206409896, 4.032432046011099, 4.99596149181901, 6.03183337906078, 7.019152666818587, 7.974843150051285, 8.993788540913295, 9.915624418866672, 10.838766864217185, 9.826044828799285, 8.883555412774113, 7.897208251902859, 6.92790728717808, 6.901613345636734, 5.876398463185069, 4.933220704030245, 3.9422098576378852, 3.039863991200987, 2.065758409670587, 3.114331979957752, 4.000922079121518, 4.968344759520442, 5.912801513174903, 6.83815163340862, 7.774359503548403, 8.807119099410377, 9.817660591863138, 10.880508311375744, 11.77636227910622, 10.849401717571023, 9.862801721593593, 8.801451214926834, 7.867311150680517, 7.832368153155617, 6.922251530141022, 5.883929594568532, 4.900142665037362, 4.01425642376006, 3.0152999442592345, 3.9949942209826865, 4.977008168417603, 5.931429369333876, 6.911827245828587, 7.775803872420381, 8.778146416450038, 9.735675244020367, 10.768893467318904, 11.782445339081931, 12.764487842909357, 11.759624237594723, 10.686463436237117, 9.724358157427755, 8.798872380447301, 8.785322214114531, 7.838448928716397, 6.852417154714473, 5.832326763396377, 5.022112844233191, 4.066988802444446, 4.985775318915715, 5.946963752996432, 6.875240032544657, 7.863282842327805, 8.785453501936939, 9.806217315117792, 10.734786532580387, 11.67523488923758, 12.68160787640395, 13.600051053679413, 12.615519458862863, 11.650846821106876, 10.690043370163936, 9.739064631617943, 9.804365241931308, 8.730954834790749, 7.7697788020614675, 6.832863622078017, 5.956049109284833, 5.124256447819603, 5.9383183028351425, 6.893342034546257, 7.879486424521577, 8.862513548014304, 9.75753537985055, 10.742311182031745, 11.729619522789871, 12.733258908410345, 13.674347914456337, 14.535579917431303, 13.577761412450103, 12.629019646991482, 11.723770758471915, 10.688956094484752, 10.795915346441673, 9.749973825566252, 8.75775090606285, 7.765555334245215, 6.923640582686718, 6.193746619078713, 6.945944890836918, 7.92923210757129, 8.874969517732604, 9.933977611709725, 10.702118528727556, 11.65907278865241, 12.706497368307899, 13.69828749586306, 14.034480140494674, 14.969699226844835, 14.544406147407404, 13.662297501822989, 12.690412795303624, 11.712312842334542], [13.82311155632572, 14.672638503691172, 15.66598083923516, 15.718759236408761, 14.830786488677674, 13.921703836040155, 12.907421933118318, 12.648969880233505, 11.609432076493588, 10.664668620859812, 9.907666579744133, 8.88119098945798, 8.00800458461269, 7.018011685970588, 7.9651861371404795, 8.842443579929263, 9.753262824369532, 10.765454783518372, 11.814002024130245, 12.833638494524013, 14.583337386143686, 15.528421480496945, 15.81980887471476, 14.778361157420818, 13.843207752695518, 12.903991662408187, 11.967528729040382, 12.900344028011297, 12.586351316921872, 11.656822323775062, 10.753106894485299, 9.823473885084034, 8.951225442804944, 7.969948966440192, 8.892151529953216, 9.898521411290726, 10.8253764230355, 11.709201574343686, 12.695820891383786, 13.642747279939806, 15.564520469327633, 15.720038337202919, 14.78497741202283, 13.787112055164936, 12.834103991406996, 11.91565321590888, 10.943927057552632, 11.851121550437819, 12.731672802449316, 12.589997898319965, 11.728282747237616, 10.760973331013354, 9.940651209989566, 8.992067213916858, 9.911382487200454, 10.949497035918936, 11.807321840645244, 12.679479844918701, 13.643494719635136, 14.580513830751496, 15.483859277022871, 14.75862926236377, 13.774412595544723, 12.824601431172649, 11.881154095342328, 10.89188178982294, 9.986490480965756, 10.794170887878794, 11.750343079172362, 12.696440146076345, 12.79504647677538, 11.773337035491794, 10.907556009642471, 10.038927422884502, 10.85568864871284, 11.929861855053538, 12.760988056911376, 13.699117678900926, 14.695442578860561, 15.567367902911336, 14.538835976757367, 13.793253534124775, 12.825410960070448, 11.785728259191144, 10.821521392727865, 9.887873464019313, 8.976437807762771, 9.76351599812352, 10.745947484022798, 11.720122270581731, 12.735586843109271, 12.703428789979588, 11.883528629119313, 10.965535760643041, 11.925817523387183, 12.88264787933472, 13.741201478082363, 14.660582899651379, 15.637819804189691, 15.476736580785555, 13.591793436156877, 12.816696650238832, 11.867697086994626, 10.907695429610083, 9.891888212911606, 8.95428115319641, 7.914021326347452, 8.838267357338273, 9.811180217773828, 10.742454946159732, 11.677044935017527, 12.703491012839457, 12.884888263159752, 12.006857279897128, 12.95527540017506, 13.841269308171945, 14.696930014558701, 15.70864383408335, 15.500017932092527, 14.519587967907922, 12.598591348033514, 11.802956111366662, 10.835434492142538, 9.918492000621391, 8.942219748767318, 7.92622991611721, 6.907674522532668, 7.892173410621963, 8.85032947499665, 9.806674919198288, 10.812460109383112, 11.77741587266621, 12.628867688129041, 13.00060011521192, 14.008416895511571, 14.833369117714911, 15.629764044075946, 15.501360250816958, 14.535899616383364, 13.530545679989547, 11.631385034735372, 10.791894190728344, 9.84428349182321, 8.929263569530153, 7.908506529002177, 6.940767240275204, 5.954107181707925, 6.945664628181863, 7.950253556122424, 8.790027273351226, 9.841738510952293, 10.74561292466182, 11.696773352267055, 12.690672823000384, 13.665785255702461, 14.52508885009969, 15.47241343999835, 14.662952383042082, 13.683313888209891, 12.692057576466443, 10.702784978631215, 9.822598382870414, 8.891329104706264, 7.884434961253704, 6.992247344000218, 5.9735437108540195, 4.949472926512417, 5.894837953345628, 6.87528024643413, 7.826965223001873, 8.789798012479544, 9.794445435784919, 10.754108713279663, 11.696574630163095, 12.650183353152874, 13.587922758471658, 14.59257128355918, 13.660728331246752, 12.702039595805017, 11.754556857164793, 9.696292933921104, 8.848408142364402, 7.856209869527921, 6.9152349537589775, 5.976211685933059, 4.980025428988039, 4.016259378593661, 4.951665586820507, 5.9214672787338065, 6.856862790977741, 7.810180383245494, 8.793029453028945, 9.805422762862069, 10.73897560763163, 11.727643903088952, 12.681245676736292, 13.710293632967765, 12.709034089583511, 11.754117172440388, 10.766197930684434, 8.729661508724668, 7.779499759341664, 6.798526897278892, 5.917032189408383, 5.057135325838659, 4.024086800643292, 3.078442174879422, 4.054850131784933, 5.066624101570051, 6.031859157563478, 7.01261639669807, 8.05248326092165, 8.903309047316057, 9.850278433091441, 10.775478876494907, 11.721542086014058, 12.691148682260602, 11.752666214277768, 10.754999100903516, 9.754549715292615, 7.905964323365452, 6.836418751501601, 5.860619565654258, 4.900936792359104, 4.014893955780336, 3.0273400520531326, 2.057929926146016, 3.074661149673781, 4.02391304992988, 5.040938656847906, 6.037232873171887, 7.026982677716986, 7.948905689289729, 8.98502064949169, 9.895427897760918, 10.748768246814883, 11.707066707689503, 10.865394237593147, 9.92396309135477, 8.873984207346375, 6.913523243139691, 5.900597808817952, 4.970983986098273, 3.9696394781571582, 2.9919454253461226, 1.9972094310699022, 1.0495736367753805, 2.00495670854849, 3.016099115086967, 3.987457009493033, 5.046605898171624, 6.0448975083243806, 6.973977078621485, 7.985894049761812, 8.866523237896162, 9.805269706841493, 10.751382683852988, 9.89506985930189, 8.930083792685664, 7.8876957159338374, 6.0299231309016665, 5.068693381341053, 4.031527042826654, 3.0897875813870175, 2.1004561048921166, 1.0360467895306924, 0.0, 0.9929827083692198, 2.0633996521392, 3.04052845172126, 4.0239478209813955, 5.033504929751864, 5.980906354729225, 6.9437315716768655, 7.927725241498965, 8.867742917481634, 9.900233938107244, 9.004993190376753, 7.963999427977964, 7.021305837048118, 6.9123116479096165, 5.95427826736969, 4.958729976137759, 4.052486668203731, 3.037896128900056, 2.0714977693433108, 1.0733764787943467, 2.0025461311102974, 2.9963852564804068, 3.9599147022883177, 4.995786589530087, 5.983105877287894, 6.938796360520592, 7.957741751382601, 8.879577629335978, 9.846830182730278, 10.859552218148178, 9.919602202304805, 8.93325504143355, 7.963954076708771, 7.937660135167425, 6.91244525271576, 5.969267493560937, 4.978256647168577, 4.075910780731679, 3.101805199201279, 2.1226302276355185, 2.964875289590826, 3.9322979699897505, 4.876754723644211, 5.8021048438779275, 6.738312714017711, 7.771072309879685, 8.781613802332446, 9.844461521845052, 10.784425597619313, 11.856878101058097, 10.898848511124283, 9.837498004457524, 8.903357940211208, 8.868414942686307, 7.958298319671714, 6.9199763840992246, 5.936189454568054, 5.0503032132907535, 4.051346733789927, 3.0814111589033057, 4.027291228425268, 4.914610838175047, 5.875780456297895, 6.739757082889689, 7.742099626919346, 8.699628454489675, 9.732846677788212, 10.746398549551241, 11.776147474745937, 12.781011080060573, 11.722510225767808, 10.760404946958445, 9.834919169977992, 9.821369003645223, 8.874495718247088, 7.888463944245165, 6.8683735529270695, 5.983617486494625, 5.02849344470588, 4.072192256836334, 4.997246813004097, 5.858421501385829, 6.846464311168976, 7.7494067124062465, 8.770170525587098, 9.698739743049693, 10.639188099706885, 11.645561086873256, 12.640521885396419, 13.62505348021297, 12.686893610637567, 11.726090159694627, 10.775111421148635, 10.840412031462, 9.767001624321441, 8.80582559159216, 7.868910411608709, 6.917553751546267, 6.079068453567337, 5.024735240755762, 5.979758972466876, 6.874132036514668, 7.857159160007395, 8.721488590319858, 9.706264392501051, 10.693572733259177, 11.697212118879651, 12.638301124925643, 13.576050749148308, 14.566913866949479, 13.665066436522173, 12.759817548002607, 11.725002884015444, 11.831962135972365, 10.786020615096945, 9.793797695593543, 8.801602123775908, 7.885145224948152, 6.987881910946666, 6.032361828757537, 7.01564904549191, 7.869615129725694, 8.928623223702816, 9.666071739196864, 10.623025999121715, 11.670450578777205, 12.662240706332366, 13.647262380382504, 14.605029541435394, 15.53355860190678, 14.69834429135368, 13.726459584834316, 12.748359631865235], [14.778626149354475, 15.628153096719926, 16.436506073789744, 15.476713920248171, 14.618020002990887, 13.613321687902037, 12.662590650732609, 11.655987171864286, 10.61644936812437, 9.671685912490592, 8.914683871374912, 7.888208281088761, 7.149790855313644, 7.849895408978369, 8.79706986014826, 9.674327302937042, 10.70227101066714, 11.71446296981598, 12.763010210427852, 13.782646680821621, 15.532345572441294, 16.477429666794553, 16.68156364181509, 15.640115924521147, 14.704962519795847, 13.765617995651803, 12.751667507122232, 11.954668702109576, 11.593368608552653, 10.663839615405841, 9.760124186116078, 8.830491176714814, 8.215358055693628, 8.801832689447973, 9.724035252960997, 10.730405134298508, 11.69336550544374, 12.658209760641293, 13.644829077681393, 14.591755466237414, 16.51352865562524, 16.581793104303244, 15.646732179123157, 14.648866822265264, 13.695858758507326, 12.777279549152498, 11.728065835634482, 10.905446224536098, 11.785997476547594, 11.597015189950744, 10.735300038868395, 9.767990622644133, 9.23691797135066, 9.82395093692464, 10.743266210208235, 11.781380758926717, 12.675310923053484, 13.628488031216309, 14.592502905932744, 15.529522017049104, 16.476841985392095, 15.620384029464098, 14.63616736264505, 13.686356198272977, 12.742908862442658, 11.753636556923265, 10.770629259047606, 9.848495561977073, 10.80466775327064, 11.750764820174624, 11.802063768406159, 10.780354327122573, 10.203822771003566, 10.870811145892283, 11.687572371720622, 12.76174557806132, 13.628977139319616, 14.567106761309166, 15.564643090524498, 16.502150930259692, 15.53181868512659, 14.655008301225102, 13.687165727170775, 12.647483026291471, 11.683276159828193, 10.74962823111964, 9.76057658584462, 8.817840672221799, 9.800272158121077, 10.75659338827566, 11.772057960803199, 11.710446081610367, 11.179795390480407, 11.797419483650822, 12.757701246394964, 13.7145316023425, 14.609190560490603, 15.528571982059619, 16.505808886597933, 16.469719289154778, 14.5847761445261, 13.80967935860805, 12.842904165256378, 11.814978963757703, 10.799171747059226, 9.86156468734403, 8.821304860495072, 7.892592031436551, 8.865504891872105, 9.77892606385366, 10.713516052711455, 11.739962130533385, 12.181155024520846, 12.838741002904909, 13.78715912318284, 14.673153031179726, 15.56491909696694, 16.57663291649159, 16.49300064046175, 15.512570676277145, 13.591574056402736, 12.79593881973588, 11.828417200511756, 10.825775534769011, 9.849503282914938, 8.83351345026483, 7.814958056680288, 6.94649808472024, 7.904654149094928, 8.843146036892216, 9.84893122707704, 10.813886990360139, 11.66533880582297, 12.711176471904883, 13.672506215933195, 14.577540438573118, 15.472816875514695, 16.38596378668869, 15.528882324752587, 14.52352838835877, 12.624367743104594, 11.784876899097563, 10.83726620019243, 9.836547103677773, 8.815790063149796, 7.848050774422823, 6.861390715855544, 5.999989302280139, 6.986724673816351, 7.826498391045154, 8.878209628646221, 9.782084042355747, 10.733244469960983, 11.72714394069431, 12.702256373396388, 13.561559967793617, 14.508884557692276, 15.4407422379708, 14.676296596579114, 13.685040284835665, 11.695767687000437, 10.815581091239633, 9.884311813075483, 8.877417669622922, 7.8995308781478375, 6.880827245001639, 5.856756460660036, 4.931309071039555, 5.911751364128057, 6.8634363406958006, 7.826269130173471, 8.830916553478845, 9.79057983097359, 10.733045747857021, 11.6866544708468, 12.624393876165584, 13.629042401253106, 14.57247314139715, 13.69502230417424, 12.747539565534016, 10.689275642290324, 9.841390850733621, 8.84919257789714, 7.908217662128196, 6.96919439430228, 5.973008137357259, 4.92354291274128, 3.9881367045144342, 4.957938396427734, 5.893333908671668, 6.846651500939421, 7.829500570722871, 8.841893880555995, 9.775446725325557, 10.734661194719733, 11.688262968367074, 12.7314744247881, 13.702016797952734, 12.74709988080961, 11.759180639053655, 9.722644217093888, 8.772482467710883, 7.791509605648112, 6.910014897777602, 6.050118034207879, 5.0170695090125115, 4.071424883248642, 3.0618674234157135, 4.073641393200832, 5.038876449194257, 6.01963368832885, 7.0595005525524295, 7.910326338946837, 8.857295724722222, 9.782496168125688, 10.728559377644839, 11.712329474080937, 12.65081194206377, 11.747981809272737, 10.747532423661836, 8.898947031734671, 7.82940145987082, 6.853602274023478, 5.893919500728324, 5.007876664149555, 4.020322760422353, 3.0509126345152358, 2.081678441304561, 3.0309303415606603, 4.047955948478686, 5.0442501648026665, 6.033999969347765, 6.955922980920509, 7.992037941122469, 8.902445189391697, 9.755785538445664, 10.714083999320284, 11.698631411554098, 10.916945799723988, 9.866966915715594, 7.906505951508911, 6.893580517187171, 5.9639666944674925, 4.962622186526378, 3.9849281337153424, 2.990192139439122, 2.0425563451446003, 1.0119740001792705, 2.0231164067177474, 2.9944743011238133, 4.053623189802404, 5.051914799955161, 5.980994370252265, 6.992911341392592, 7.8735405295269425, 8.812286998472274, 9.75839997548377, 10.728646558830524, 9.923066501054883, 8.880678424303056, 7.022905839270886, 6.061676089710272, 5.024509751195874, 4.082770289756237, 3.0934388132613364, 2.029029497899912, 0.9929827083692198, 0.0, 1.07041694376998, 2.0475457433520403, 3.0309651126121757, 4.040522221382644, 4.987923646360005, 5.950748863307646, 6.934742533129746, 7.874760209112414, 8.907251229738023, 9.9724974518975, 8.956982136347182, 8.014288545417337, 7.905294356278836, 6.94726097573891, 5.951712684506979, 5.0454693765729495, 4.030878837269276, 3.0644804777125305, 2.0539180346887793, 1.0095634227410775, 2.003402548111187, 2.966931993919098, 4.002803881160867, 4.990123168918674, 5.945813652151372, 6.964759043013381, 7.886594920966759, 8.853847474361059, 9.866569509778959, 10.80905892580413, 9.92623774980277, 8.95693678507799, 8.930642843536646, 7.90542796108498, 6.962250201930156, 5.971239355537796, 4.9771931024608635, 4.003087520930464, 2.9545139506432987, 1.9718925812216064, 2.9393152616205307, 3.8837720152749915, 4.809122135508708, 5.7453300056484915, 6.778089601510466, 7.788631093963227, 8.851478813475833, 9.791442889250094, 10.863895392688878, 11.880454135084674, 10.830480712826745, 9.896340648580429, 9.861397651055528, 8.913812912700468, 7.875490977127979, 6.891704047596808, 5.891945638135365, 4.892989158634538, 3.913294881911086, 3.034308520056048, 3.9216281298058275, 4.8827977479286755, 5.746774374520468, 6.7491169185501265, 7.706645746120454, 8.739863969418991, 9.753415841182019, 10.783164766376718, 11.788028371691354, 12.715492934137028, 11.753387655327666, 10.827901878347213, 10.776883596673978, 9.830010311275842, 8.84397853727392, 7.823888145955824, 6.815501209502405, 5.8603771677136605, 4.904075979844114, 4.004264104634876, 4.865438793016609, 5.853481602799756, 6.756424004037026, 7.777187817217878, 8.705757034680472, 9.646205391337665, 10.652578378504035, 11.647539177027198, 12.632070771843749, 13.596743409599735, 12.719072868063847, 11.730626014177389, 11.79521201755381, 10.721801610413252, 9.760625577683971, 8.82371039770052, 7.749437474554047, 6.910952176575117, 5.856618963763542, 5.069286337492862, 5.881149328145448, 6.8641764516381745, 7.728505881950637, 8.71328168413183, 9.700590024889957, 10.70422941051043, 11.645318416556423, 12.583068040779088, 13.573931158580258, 14.574916235484341, 13.715332141031361, 12.680517477044198, 12.786762122064175, 11.740820601188755, 10.742805881891151, 9.750610310073515, 8.717028947955932, 7.819765633954447, 6.864245551765317, 6.105176410517895, 6.876632421356474, 7.935640515333596, 8.673089030827644, 9.630043290752496, 10.677467870407986, 11.669257997963147, 12.654279672013285, 13.612046833066174, 14.540575893537559, 15.542989501904206, 14.68197417786307, 13.703874224893989], [15.732444543271678, 16.448821442453085, 15.455479106909095, 14.495686953367525, 13.636993036110242, 12.632294721021392, 11.681563683851962, 10.67496020498364, 9.635422401243723, 8.690658945609947, 7.933656904494265, 6.907181314208114, 7.871123986848509, 8.80371380289557, 9.750888254065462, 10.628145696854245, 11.656089404584343, 12.668281363733183, 13.716828604345055, 14.736465074738824, 16.486163966358497, 17.42485732713324, 16.486285417917937, 15.436085032355468, 14.572553481458035, 13.595340268507233, 12.53431437985916, 11.599088648304468, 10.612341641672007, 9.682812648525196, 8.779097219235432, 7.849464209834168, 8.888188227806893, 9.755651083365175, 10.677853646878198, 11.684223528215709, 12.647183899360941, 13.612028154558496, 14.598647471598596, 15.545573860154617, 17.467347049542443, 17.524635099191823, 16.589574174011734, 15.591708817153842, 14.638700753395904, 13.720121544041076, 12.67090783052306, 11.848288219424676, 10.949030241517487, 10.615988223070099, 9.754273071987749, 8.786963655763486, 9.844399633991612, 10.777769330841842, 11.697084604125436, 12.735199152843919, 13.629129316970685, 14.582306425133511, 15.546321299849946, 16.483340410966306, 17.49160450435169, 16.563226024352677, 15.579009357533629, 14.629198193161555, 13.685750857331236, 12.696478551811843, 11.713471253936184, 10.79133755686565, 9.967700518240534, 10.815033528878738, 10.821036801525512, 9.799327360241927, 10.762958408905318, 11.808066977690832, 12.641390765637823, 13.715563971978522, 14.582795533236816, 15.520925155226365, 16.518461484441698, 17.45596932417689, 16.546581204086188, 15.59785029611368, 14.630007722059354, 13.59032502118005, 12.626118154716771, 11.692470226008219, 10.703418580733198, 9.760682667110377, 8.946056067298253, 9.781039190573495, 10.796503763101034, 10.72941911472972, 11.722387169107385, 12.73467531544937, 13.711519640312165, 14.668349996259701, 15.563008954407803, 16.48239037597682, 17.459627280515132, 17.484481808114378, 15.599538663485696, 14.763481774107461, 13.78574616014496, 12.757820958646285, 11.742013741947806, 10.80440668223261, 9.764146855383652, 8.83543402632513, 7.935837398396145, 8.803371866151496, 9.73796185500929, 10.764407932831219, 11.735095253957981, 12.706506454672137, 13.6969341857222, 14.535932023380688, 15.371942680296545, 16.286875425599856, 17.22344063609726, 16.527333195236743, 14.606336575362333, 13.749741235235291, 12.782219616011167, 11.768617529657593, 10.79234527780352, 9.776355445153412, 8.757800051568868, 7.88934007960882, 6.952986366342449, 7.867591839190051, 8.873377029374874, 9.838332792657972, 10.689784608120803, 11.735622274202717, 12.6387979911978, 13.543832213837723, 14.4391086507793, 15.352255561953296, 16.31771619638689, 15.538290907318366, 13.63913026206419, 12.738679314596974, 11.79106861569184, 10.779389098566355, 9.758632058038378, 8.790892769311405, 7.804232710744125, 6.94283129716872, 6.011170476114184, 6.850944193342988, 7.902655430944055, 8.80652984465358, 9.757690272258817, 10.751589742992143, 11.668548148660992, 12.527851743058221, 13.475176332956881, 14.407034013235405, 15.432289533243772, 14.699802803795261, 12.710530205960033, 11.830343610199229, 10.885366631162142, 9.869114061066753, 8.84237287303642, 7.8236692398902195, 6.799598455548617, 5.874151065928136, 4.936197166425891, 5.887882142993634, 6.850714932471305, 7.855362355776678, 8.815025633271423, 9.757491550154855, 10.652946246111405, 11.590685651430189, 12.59533417651771, 13.538764916661755, 14.5538487923086, 13.762302084493612, 11.70403816124992, 10.856153369693217, 9.863955096856737, 8.920547286858206, 7.937156200702173, 6.940969943757153, 5.866384907629861, 4.930978699403015, 3.9823841987255673, 4.917779710969501, 5.871097303237255, 6.853946373020705, 7.866339682853829, 8.79989252762339, 9.664244250949752, 10.617846024597092, 11.66105748101812, 12.651009451800848, 13.60592636894397, 12.773943158013251, 10.737406736053485, 9.78724498667048, 8.806272124607707, 7.9247774167371965, 7.038862493772981, 5.999858751497736, 5.054214125733866, 4.004709418304294, 3.003224449430852, 3.968459505424278, 4.94921674455887, 5.98908360878245, 6.839909395176857, 7.786878780952241, 8.712079224355707, 9.658142433874858, 10.641912530310956, 11.580394998293789, 12.578062111668041, 11.762294942621432, 9.964949614908216, 8.895404043044364, 7.868364792983073, 6.908682019687919, 5.996621123714657, 5.009067219987455, 4.039657094080338, 3.024520436193142, 1.9605133977906803, 2.9775390047087065, 3.973833221032687, 4.963583025577786, 5.885506037150529, 6.9216209973524885, 7.832028245621718, 8.685368594675683, 9.643667055550303, 10.628214467784117, 11.651795239188129, 10.932969498889138, 8.972508534682454, 7.959583100360715, 7.029969277641036, 5.977384705485973, 4.999690652674937, 4.0049546583987174, 3.031300804709703, 1.989852521200652, 0.9526994629477672, 1.9240573573538333, 2.983206246032424, 3.9814978561851806, 4.910577426482285, 5.922494397622612, 6.803123585756962, 7.741870054702293, 8.687983031713788, 9.658229615060543, 10.623215681676768, 9.9466810074766, 8.093322783040866, 7.132093033480253, 6.094926694965854, 5.153187233526217, 4.163855757031317, 3.099446441669892, 2.0633996521392, 1.07041694376998, 0.0, 0.9771287995820602, 1.9605481688421957, 2.9701052776126637, 3.9175067025900248, 4.8803319195376655, 5.8643255893597654, 6.804343265342434, 7.8368342859680435, 8.90208050812752, 9.94307427052631, 9.084705489187318, 8.975711300048818, 8.017677919508891, 7.022129628276959, 6.11588632034293, 5.101295781039256, 4.102007975692321, 3.0491443715226576, 2.004789759574956, 0.9329856043412068, 1.8965150501491175, 2.9323869373908873, 3.919706225148694, 4.875396708381392, 5.894342099243401, 6.816177977196778, 7.783430530591078, 8.796152566008978, 9.73864198203415, 10.724989142905404, 10.027353728847974, 10.001059787306627, 8.955062581556614, 7.973000010925559, 6.981989164533199, 5.931011496378065, 4.956905914847665, 3.9083323445605007, 2.9257109751388084, 1.958288294739884, 2.902745048394345, 3.828095168628061, 4.764303038767845, 5.797062634629819, 6.8076041270825804, 7.831224682217952, 8.721025945480113, 9.793478448918897, 10.810037191314693, 11.677744456918063, 10.96675759235041, 10.897133841059885, 9.867631306617671, 8.82930937104518, 7.84552244151401, 6.845764032052567, 5.8468075525517405, 4.867113275828288, 3.895022363841454, 2.940601162925181, 3.901770781048029, 4.765747407639822, 5.76808995166948, 6.725618779239808, 7.758837002538344, 8.772388874301374, 9.712747822606737, 10.717611427921373, 11.790772229278979, 12.6920539270934, 11.866191709351082, 11.73070199059118, 10.783828705193045, 9.797796931191122, 8.777706539873027, 7.769319603419607, 6.8141955616308625, 5.857894373761316, 4.864977948420282, 3.8844118261359624, 4.87245463591911, 5.775397037156379, 6.796160850337231, 7.724730067799825, 8.665178424457018, 9.671551411623389, 10.666512210146552, 11.651043804963102, 12.615716442719089, 13.576519893662029, 12.684444408094592, 12.74903041147101, 11.675620004330451, 10.71444397160117, 9.777528791617721, 8.703255868471249, 7.864770570492319, 6.810437357680744, 5.886266751240122, 4.900122361264802, 5.883149484757528, 6.7474789150699905, 7.732254717251184, 8.71956305800931, 9.723202443629784, 10.664291449675776, 11.602041073898441, 12.592904191699612, 13.593889268603695, 14.635979022277983, 13.6343358709614, 13.740580515981375, 12.694638995105954, 11.696624275808354, 10.704428703990718, 9.670847341873134, 8.773584027871648, 7.818063945682519, 6.8545170036346965, 5.895605454475827, 6.954613548452949, 7.692062063946998, 8.64901632387185, 9.69644090352734, 10.6882310310825, 11.67325270513264, 12.631019866185527, 13.559548926656912, 14.561962535023559, 15.574453375680488, 14.657692618811192], [16.438329637553775, 15.488685124434225, 14.495342788890236, 13.535550635348665, 12.676856718091381, 11.67215840300253, 10.721427365833101, 9.714823886964778, 8.675286083224861, 7.730522627591085, 7.12031597790868, 7.8359585034981745, 8.799901176138569, 9.732490992185632, 10.679665443355523, 11.556922886144307, 12.584866593874404, 13.597058553023246, 14.645605793635118, 15.665242264028887, 17.40980510346764, 16.46472100911438, 15.526149099899078, 14.475948714336608, 13.612417163439174, 12.635203950488371, 11.574178061840298, 10.638952330285607, 9.652205323653146, 8.722676330506335, 8.158452248873438, 8.778241399124228, 9.816965417096954, 10.684428272655236, 11.606630836168259, 12.61300071750577, 13.575961088651002, 14.54080534384856, 15.52742466088866, 16.474351049444678, 18.396124238832506, 17.465376830903192, 16.502707944347467, 15.504842587489573, 14.621520924727696, 13.623542396987677, 12.596547511960605, 11.578507167247876, 10.608680851609305, 9.655851905051238, 9.133628101625755, 9.715740845053547, 10.773176823281673, 11.706546520131901, 12.625861793415497, 13.66397634213398, 14.557906506260746, 15.511083614423574, 16.47509848914001, 17.41211760025637, 18.46873330393375, 17.540354823934738, 16.55613815711569, 15.606326992743616, 14.662879656913297, 13.673607351393905, 12.690600053518246, 11.768466356447712, 10.944829317822595, 10.035299272573846, 10.200391831163518, 10.728104549531988, 11.691735598195379, 12.736844166980893, 13.570167954927884, 14.644341161268581, 15.511572722526878, 16.449702344516428, 17.44723867373176, 18.384746513466954, 17.523710003668246, 16.574979095695742, 15.607136521641415, 14.567453820762111, 13.603246954298832, 12.66959902559028, 11.680547380315259, 10.737811466692438, 9.923184866880314, 9.001304934268603, 10.016769506796143, 10.993587974857874, 11.82371867705833, 12.835091762986135, 13.749263262928014, 14.517424652635853, 15.350542417190821, 16.357807560449768, 17.18087054903921, 18.121461702319596, 16.576667463067754, 15.740610573689521, 14.762874959727018, 13.734949758228343, 12.719142541529868, 11.781535481814672, 10.741275654965714, 9.812562825907191, 8.912966197978205, 8.023637609846604, 8.958227598704399, 9.976152596176208, 10.822359043017892, 11.793770243732048, 12.719805386140138, 13.558803223798627, 14.394813880714484, 15.309746626017796, 16.2463118365152, 17.297761481789763, 15.58346537494439, 14.72687003481735, 13.759348415593227, 12.745746329239651, 11.76947407738558, 10.753484244735471, 9.73492885115093, 8.866468879190881, 7.9301151659245095, 7.087857582885159, 8.027637762126183, 8.925596581717883, 9.777048397180714, 10.822886063262628, 11.661669191615738, 12.566703414255661, 13.461979851197238, 14.375126762371234, 15.340587396804828, 16.345941333198645, 14.616259061646248, 13.715808114179033, 12.7681974152739, 11.756517898148415, 10.735760857620438, 9.768021568893465, 8.781361510326185, 7.91996009675078, 6.988299275696245, 6.0712099370380965, 6.9899192200039675, 7.893793633713493, 8.844954061318727, 9.77598727143378, 10.69141934907893, 11.55072294347616, 12.49804753337482, 13.429905213653344, 14.45516073366171, 15.446417045405159, 13.687659005542091, 12.807472409781289, 11.862495430744202, 10.846242860648813, 9.819501672618479, 8.80079803947228, 7.776727255130678, 6.851279865510197, 5.913325966007951, 5.1081478866887435, 5.937978721531217, 6.9426261448365905, 7.902289422331336, 8.78188907859649, 9.675817446529344, 10.613556851848127, 11.618205376935649, 12.561636117079694, 13.576719992726538, 14.636050736350647, 12.68116696083198, 11.833282169275277, 10.841083896438796, 9.897676086440267, 8.914285000284234, 7.918098743339214, 6.843513707211922, 5.908107498985076, 4.959512998307628, 4.138045454664611, 4.958361092297167, 5.941210162080617, 6.890737211295464, 7.824290056065026, 8.68711545136769, 9.640717225015031, 10.683928681436058, 11.673880652218786, 12.62879756936191, 13.6130309130887, 11.714535535635545, 10.76437378625254, 9.783400924189767, 8.901906216319256, 8.015991293355041, 6.976987551079797, 6.031342925315927, 4.981838217886355, 3.980353249012912, 3.1152117800057257, 4.009054634332553, 5.048921498556132, 5.862780595594797, 6.809749981370182, 7.734950424773646, 8.681013634292796, 9.664783730728894, 10.603266198711728, 11.60093331208598, 12.60138269769688, 10.942078414490275, 9.872532842626423, 8.845493592565132, 7.885810819269978, 6.973749923296717, 5.9861960195695145, 5.016785893662398, 4.0016492357752025, 2.9376421973727407, 2.124291279290154, 3.0336711108063694, 4.023420915351468, 4.9083772375684696, 5.944492197770429, 6.854899446039658, 7.708239795093623, 8.666538255968241, 9.651085668202056, 10.674666439606067, 11.674763450259071, 9.949637334264512, 8.936711899942773, 8.007098077223095, 6.954513505068032, 5.976819452256997, 4.982083457980777, 4.008429604291763, 2.966981320782712, 1.9298282625298273, 1.070809631935281, 2.025618151805137, 3.023909761957894, 3.933448626900225, 4.945365598040552, 5.825994786174903, 6.764741255120233, 7.7108542321317275, 8.681100815478482, 9.646086882094707, 10.688474958846534, 9.070451582622928, 8.109221833062314, 7.072055494547914, 6.1303160331082776, 5.140984556613377, 4.076575241251953, 3.04052845172126, 2.0475457433520403, 0.9771287995820602, 0.0, 0.9834193692601355, 1.9929764780306036, 2.9403779030079646, 3.903203119955606, 4.887196789777706, 5.827214465760374, 6.859705486385984, 7.924951708545461, 8.96594547094425, 9.908639061874096, 9.952840099630878, 8.99480671909095, 7.9992584278590195, 7.09301511992499, 6.073580408086565, 5.067654336780523, 4.01479073261086, 2.970436120663158, 1.8986319654294088, 0.9351025196214982, 1.955258137808827, 2.942577425566634, 3.898267908799332, 4.917213299661341, 5.839049177614719, 6.806301731009018, 7.819023766426918, 8.76151318245209, 9.747860343323344, 10.797107501585064, 10.951542062535282, 9.883839770846674, 8.90177720021562, 7.91076635382326, 6.859788685668126, 5.885683104137726, 4.837109533850561, 3.854488164428868, 2.887065484029944, 1.942608730375483, 2.8679588506091993, 3.804166720748983, 4.828958514047006, 5.839500006499767, 6.854095882635892, 7.743897145898053, 8.816349649336837, 9.832908391732634, 10.700615657336002, 11.634755721582318, 11.825911030349944, 10.79640849590773, 9.758086560335242, 8.774299630804071, 7.774541221342627, 6.775584741841801, 5.795890465118348, 4.823799553131514, 3.8693783522152407, 2.941634463029167, 3.8056110896209603, 4.807953633650618, 5.765482461220945, 6.798700684519482, 7.812252556282511, 8.735619023024677, 9.740482628339311, 10.813643429696917, 11.71492512751134, 12.566316951349101, 12.659479179881242, 11.712605894483106, 10.726574120481184, 9.706483729163088, 8.698096792709668, 7.742972750920923, 6.786671563051376, 5.793755137710342, 4.813189015426023, 3.9731000237159195, 4.815260719137518, 5.83602453231837, 6.764593749780964, 7.705042106438158, 8.71141509360453, 9.706375892127692, 10.690907486944242, 11.65558012470023, 12.61638357564317, 13.530527342314858, 13.677807600761072, 12.604397193620514, 11.643221160891233, 10.706305980907782, 9.63203305776131, 8.79354775978238, 7.739214546970804, 6.815043940530182, 5.828899550554862, 5.014952638051201, 5.787342597051129, 6.772118399232323, 7.759426739990448, 8.763066125610923, 9.704155131656917, 10.641904755879581, 11.632767873680752, 12.633752950584835, 13.675842704259123, 14.480418805181667, 14.669357705271437, 13.623416184396017, 12.625401465098415, 11.63320589328078, 10.599624531163196, 9.702361217161709, 8.74684113497258, 7.783294192924757, 6.824382643765888, 6.086416701746623, 6.7319257459281365, 7.6888800058529885, 8.736304585508478, 9.728094713063639, 10.713116387113779, 11.670883548166668, 12.599412608638053, 13.6018262170047, 14.614317057661628, 15.503775553031458], [15.48505970784866, 14.53541519472911, 13.54207285918512, 12.58228070564355, 11.73622291800096, 10.73152460291211, 9.780793565742682, 8.774190086874361, 7.7346522831344435, 6.789888827500667, 7.777454664437916, 8.746024943875188, 9.709967616515582, 10.642557432562645, 11.589731883732536, 12.466989326521318, 13.494933034251416, 14.507124993400257, 15.55567223401213, 16.494672641486048, 16.456535173762525, 15.511451079409266, 14.572879170193962, 13.522678784631493, 12.671783363348757, 11.694570150397954, 10.633544261749881, 9.69831853019519, 8.711571523562728, 7.782042530415915, 8.736147788424695, 9.66578079782596, 10.704504815798686, 11.59449471303225, 12.516697276545273, 13.523067157882783, 14.486027529028016, 15.450871784225571, 16.43749110126567, 17.38441748982169, 17.47425643702522, 16.512106901198077, 15.549438014642352, 14.551572657784458, 13.680887124637279, 12.68290859689726, 11.655913711870184, 10.637873367157455, 9.668047051518885, 8.715218104960817, 9.711323641177012, 10.603280243755279, 11.660716221983405, 12.609300218056113, 13.53592823379251, 14.574042782510993, 15.46797294663776, 16.421150054800588, 17.385164929517025, 18.32218404063338, 18.48651926566584, 17.448111112967865, 16.463894446148817, 15.514083281776745, 14.622514499657605, 13.553758016645512, 12.570138513535735, 11.57105371401596, 10.614881522722392, 9.66878445581841, 9.992655136380577, 10.944868557456797, 11.816271927275038, 12.77828073148454, 13.826394852454666, 14.495589518880804, 15.347336469101673, 16.285466091091223, 17.217436138655682, 18.129395874005777, 18.07594293708765, 17.43710843832862, 16.469265864274295, 15.429583163394993, 14.465376296931714, 13.531728368223161, 12.54267672294814, 11.59994080932532, 10.763511858404879, 9.791518794908777, 9.05142765817949, 10.014776802969003, 10.840299307798196, 11.851672393726, 12.76584389366788, 13.534005283375718, 14.367123047930686, 15.374388191189633, 16.197451179779073, 17.13804233305946, 17.244970223240546, 16.665959594166466, 15.688223980203961, 14.660298778705286, 13.644491562006811, 12.706884502291615, 11.666624675442657, 10.674692168540073, 9.75329318950277, 8.813851470486778, 7.992885750087745, 8.992733226916075, 9.838939673757757, 10.810350874471913, 11.736386016880003, 12.575383854538492, 13.411394511454349, 14.326327256757661, 15.262892467255064, 16.314342112529626, 16.29447629589454, 15.652219055294294, 14.68469743607017, 13.671095349716595, 12.694823097862523, 11.678833265212415, 10.660277871627873, 9.728598221823763, 8.770442157449075, 7.878071443525333, 7.044218392866046, 7.942177212457749, 8.793629027920579, 9.839466694002493, 10.678249822355603, 11.583284044995526, 12.478560481937103, 13.3917073931111, 14.357168027544692, 15.362521963938509, 15.523670217876095, 14.641157134655977, 13.693546435750843, 12.681866918625358, 11.661109878097381, 10.693370589370408, 9.706710530803129, 8.845309117227723, 7.828626267220812, 6.86142379767827, 6.006499850743831, 6.910374264453358, 7.861534692058593, 8.792567902173644, 9.707999979818796, 10.567303574216025, 11.514628164114685, 12.446485844393209, 13.471741364401575, 14.462997676145024, 14.614125416797268, 13.766629465317898, 12.787844451221146, 11.771591881125756, 10.744850693095422, 9.726147059949223, 8.70207627560762, 7.776628885987139, 6.817467795249042, 5.898361747328917, 4.954559352271081, 5.9592067755764555, 6.918870053071201, 7.798469709336355, 8.692398077269209, 9.630137482587992, 10.634786007675514, 11.578216747819557, 12.593300623466403, 13.652631367090512, 13.607633372087157, 12.816701538535414, 11.824503265698933, 10.823025106917209, 9.839634020761176, 8.843447763816156, 7.768862727688864, 6.833456519462018, 5.863654827548719, 4.928259315304785, 3.974941723037032, 4.957790792820482, 5.9073178420353285, 6.84087068680489, 7.703696082107554, 8.657297855754896, 9.700509312175924, 10.690461282958651, 11.645378200101774, 12.629611543828565, 12.641001946890722, 11.747793155512676, 10.766820293449904, 9.885325585579393, 8.999410662615178, 7.960406920339932, 7.014762294576062, 5.96525758714649, 4.9637726182730475, 4.0374664585857865, 3.025635265072417, 4.0655021292959965, 4.8793612263346615, 5.826330612110046, 6.75153105551351, 7.697594265032661, 8.68136436146876, 9.619846829451593, 10.617513942825845, 11.617963328436746, 11.686428852539262, 10.85595221188656, 9.828912961825269, 8.869230188530114, 7.957169292556854, 6.969615388829651, 6.000205262922535, 4.985068605035337, 3.9210615666328756, 3.0465459578702148, 2.050251741546234, 3.0400015460913328, 3.9249578683083337, 4.961072828510293, 5.871480076779523, 6.724820425833488, 7.683118886708107, 8.667666298941922, 9.691247070345934, 10.691344080998936, 10.679228062380545, 9.92013126920291, 8.990517446483231, 7.937932874328168, 6.960238821517133, 5.965502827240913, 4.991848973551899, 3.9504006900428474, 2.9132476317899627, 2.0542290011954165, 1.0421987825450016, 2.040490392697759, 2.9500292576400895, 3.961946228780416, 4.842575416914768, 5.781321885860098, 6.7274348628715925, 7.697681446218347, 8.662667512834572, 9.705055589586399, 9.916602398760412, 9.092641202322449, 8.05547486380805, 7.1137354023684125, 6.124403925873512, 5.059994610512088, 4.0239478209813955, 3.0309651126121757, 1.9605481688421957, 0.9834193692601355, 0.0, 1.0095571087704682, 1.9569585337478292, 2.91978375069547, 3.9037774205175704, 4.843795096500239, 5.876286117125849, 6.941532339285326, 7.982526101684115, 8.925219692613961, 10.862451666307685, 9.978226088351088, 8.982677797119155, 8.076434489185125, 7.0569997773467, 6.0510737060406585, 4.9982101018709955, 3.9538554899232934, 2.882051334689544, 1.9185218888816338, 0.9718387685486914, 1.9591580563064985, 2.9148485395391965, 3.9337939304012055, 4.855629808354584, 5.822882361748883, 6.835604397166783, 7.778093813191954, 8.764440974063207, 9.813688132324927, 11.617034157365964, 10.793906211223689, 9.811843640592635, 8.820832794200275, 7.769855126045139, 6.79574954451474, 5.7471759742275745, 4.764554604805882, 3.7971319244069583, 2.852675170752497, 1.927325050518781, 2.8635329206585647, 3.8455391447868705, 4.856080637239632, 5.8706765133757575, 6.760477776637918, 7.832930280076702, 8.849489022472497, 9.717196288075865, 10.651336352322181, 12.547788964884846, 11.706474936284746, 10.668153000712255, 9.684366071181085, 8.68460766171964, 7.685651182218814, 6.705956905495362, 5.733865993508528, 4.779444792592255, 3.851700903406181, 2.864977289530542, 3.8673198335601997, 4.8248486611305275, 5.858066884429064, 6.871618756192093, 7.752199653764543, 8.757063259079178, 9.830224060436784, 10.731505758251203, 11.582897582088965, 13.500850390558133, 12.62267233486012, 11.636640560858197, 10.616550169540101, 9.60816323308668, 8.653039191297935, 7.69673800342839, 6.703821578087355, 5.723255455803036, 4.805785286848985, 3.874626919047099, 4.895390732227951, 5.823959949690545, 6.764408306347739, 7.770781293514109, 8.765742092037272, 9.717255990388397, 10.681928628144384, 11.642732079087324, 12.547107973054722, 14.46118880381025, 13.514463633997526, 12.553287601268245, 11.616372421284794, 10.542099498138322, 9.703614200159395, 8.649280987347819, 7.7251103809071955, 6.7389659909318755, 5.784040375667052, 4.84670879696071, 5.831484599141904, 6.818792939900029, 7.822432325520504, 8.763521331566496, 9.70127095578916, 10.679497943975637, 11.66010145402899, 12.702191207703278, 13.49699943592153, 15.4889417984851, 14.533482624773029, 13.535467905475427, 12.543272333657791, 11.509690971540207, 10.612427657538722, 9.656907575349594, 8.69336063330177, 7.734449084142901, 6.830839449045866, 5.791291945837718, 6.74824620576257, 7.795670785418059, 8.78746091297322, 9.772482587023358, 10.730249748076247, 11.646142678932938, 12.648556287299584, 13.661047127956513, 14.520356183771321], [14.475502599078192, 13.525858085958642, 12.532515750414653, 11.572723596873082, 10.769750303153376, 9.809031215346522, 8.892258035482975, 7.947346066295507, 6.958217722582424, 7.76692640108101, 8.75449223801826, 9.723062517455533, 10.687005190095928, 11.619595006142989, 12.56676945731288, 13.444026900101662, 14.471970607831759, 15.4841625669806, 16.504752003109353, 15.485115532715584, 15.446978064992058, 14.501893970638799, 13.563322061423495, 12.513121675861026, 11.757329039135533, 10.854986521777622, 9.832151239560911, 8.921883969643169, 7.9351369630107085, 8.75908010399626, 9.71318536200504, 10.642818371406305, 11.68154238937903, 12.571532286612593, 13.493734850125616, 14.500104731463127, 15.46306510260836, 16.427909357805916, 17.334494559751956, 16.387568171195937, 16.464699328254753, 15.502549792427612, 14.539880905871884, 13.54201554901399, 12.766432800424054, 11.843324968276928, 10.855752911048661, 9.880387588809185, 8.910561273170615, 9.692255678541162, 10.688361214757357, 11.14495466632324, 11.775403631651306, 12.723987627724014, 13.696987517590781, 14.501035228815795, 15.291445576597336, 16.330778403655785, 17.259826889110638, 17.32533472200763, 17.476962156895375, 16.4385540041974, 15.454337337378352, 14.504526173006278, 13.719382696488722, 12.796808990745314, 11.813189487635537, 10.848063187741136, 9.891890996447568, 10.645822029398754, 10.996380950566637, 10.1325909618448, 10.808498831998401, 11.770507636207903, 12.818621757178029, 13.486032410110335, 14.337779360331204, 15.275908982320754, 16.207879029885213, 17.119838765235308, 17.06638582831718, 17.372222617789326, 16.404380043735, 15.543399344987783, 14.734465245257493, 13.80081731654894, 12.821453991119231, 11.87871807749641, 10.91353544738985, 10.795244609094835, 10.05515347236555, 9.202499207357006, 9.83252621252156, 10.843899298449363, 11.75628678489741, 12.524448174605249, 13.357565939160217, 14.364831082419164, 15.187894071008603, 16.12848522428899, 16.235413114470077, 17.190619115966808, 16.691949794390023, 15.664024592891348, 14.648217376192871, 13.710610316477675, 12.670350489628717, 11.678417982726133, 10.75701900368883, 9.817577284672836, 8.996611564273806, 8.180455631304078, 8.83116657848112, 9.802577779195277, 10.726828908109534, 11.565826745768023, 12.40183740268388, 13.316770147987192, 14.253335358484595, 15.304785003759157, 15.284919187124073, 16.26050468330586, 15.68842325025623, 14.674821163902656, 13.698548912048583, 12.682559079398475, 11.664003685813933, 10.732324036009823, 9.774167971635135, 8.881797257711392, 8.047944207052106, 7.129899616845753, 7.785855932643942, 8.831693598725856, 9.668692713585134, 10.573726936225057, 11.469003373166634, 12.38215028434063, 13.347610918774222, 14.35296485516804, 14.514113109105626, 15.504780692004383, 14.697272249936903, 13.685592732811418, 12.664835692283441, 11.697096403556468, 10.710436344989189, 9.849034931413783, 8.83235208140687, 7.8651496118643305, 7.010225664929891, 6.098096668841362, 6.853761596781957, 7.783010793403176, 8.698442871048327, 9.557746465445556, 10.505071055344215, 11.43692873562274, 12.462184255631106, 13.453440567374555, 13.6045683080268, 14.515240455196587, 13.791570265407204, 12.775317695311815, 11.74857650728148, 10.729872874135282, 9.70580208979368, 8.780354700173199, 7.8211936094351024, 6.9020875615149775, 5.9582851664571415, 5.146929179964459, 5.911096957794564, 6.788912600565887, 7.6828409684987395, 8.620580373817523, 9.625228898905045, 10.568659639049088, 11.583743514695936, 12.643074258320045, 12.598076263316688, 13.541050214690575, 12.834060374469402, 11.826750921103269, 10.843359834947236, 9.847173578002216, 8.772588541874924, 7.837182333648078, 6.867380641734779, 5.931985129490845, 4.9786675372230915, 4.145513197208486, 4.89776073326486, 5.831313578034422, 6.694138973337086, 7.64774074698443, 8.690952203405455, 9.680904174188184, 10.635821091331307, 11.620054435058098, 11.631444838120252, 12.581606587503257, 11.776377402220373, 10.894882694349862, 10.008967771385645, 8.9699640291104, 8.02431940334653, 6.974814695916958, 5.973329727043515, 5.041192272771846, 4.029361079258477, 3.1151515391132136, 3.869804117564193, 4.8167735033395775, 5.741973946743042, 6.688037156262194, 7.671807252698292, 8.610289720681125, 9.607956834055377, 10.608406219666279, 10.676871743768793, 11.618417330615465, 10.838470070595738, 9.878787297300583, 8.966726401327321, 7.979172497600119, 7.009762371693002, 5.994625713805806, 4.930618675403344, 4.050271772056274, 3.0539775557322937, 2.08965095590855, 2.9154007595378655, 3.9515157197398256, 4.861922968009054, 5.71526331706302, 6.673561777937639, 7.658109190171453, 8.681689961575465, 9.681786972228467, 9.669670953610076, 10.682596387931815, 10.000074555253699, 8.947489983098636, 7.969795930287601, 6.975059936011381, 6.001406082322367, 4.959957798813315, 3.922804740560431, 3.0637861099658847, 2.0459245967310613, 1.0476329865783043, 1.9404721488696213, 2.9523891200099484, 3.833018308144299, 4.77176477708963, 5.717877754101124, 6.688124337447879, 7.653110404064104, 8.69549848081593, 8.907045289989943, 9.868275039550557, 9.065031972578518, 8.123292511138882, 7.13396103464398, 6.069551719282556, 5.033504929751864, 4.040522221382644, 2.9701052776126637, 1.9929764780306036, 1.0095571087704682, 0.0, 0.947401424977361, 1.910226641925002, 2.894220311747102, 3.8342379877297708, 4.86672900835538, 5.9319752305148565, 6.972968992913646, 7.915662583843492, 9.852894557537216, 10.810927938077143, 9.992234905889624, 9.085991597955594, 8.066556886117167, 7.060630814811126, 6.007767210641463, 4.963412598693761, 3.8916084434600124, 2.9280789976521016, 1.9488763421290343, 0.9496009475360304, 1.9052914307687285, 2.9242368216307377, 3.8460726995841155, 4.813325252978415, 5.826047288396316, 6.768536704421487, 7.754883865292741, 8.80413102355446, 10.607477048595499, 11.675179340284107, 10.788881214172976, 9.797870367780616, 8.746892699625482, 7.772787118095081, 6.724213547807917, 5.741592178386225, 4.774169497987301, 3.82971274433284, 2.904362624099124, 1.9970219860585599, 2.8359820360164028, 3.846523528469164, 4.861119404605289, 5.750920667867451, 6.823373171306234, 7.8399319137020305, 8.7076391793054, 9.641779243551715, 11.53823185611438, 12.567734390556595, 11.645190574292597, 10.661403644761426, 9.661645235299982, 8.662688755799156, 7.682994479075704, 6.710903567088871, 5.756482366172598, 4.828738476986524, 3.842014863110885, 3.000808898960195, 3.8738956158733813, 4.877716532000257, 5.891268403763285, 6.742642544994076, 7.747506150308711, 8.820666951666317, 9.721948649480737, 10.573340473318499, 12.491293281787668, 13.438166567185803, 12.613678134438539, 11.593587743120443, 10.585200806667023, 9.630076764878279, 8.673775577008733, 7.680859151667699, 6.70029302938338, 5.782822860429328, 4.851664492627442, 4.072262155283786, 4.9224842407263925, 5.825644566051444, 6.832017553217815, 7.791821064713879, 8.70769888161793, 9.672371519373916, 10.633174970316857, 11.537550864284256, 13.451631695039785, 14.432344686139496, 13.530325174848588, 12.593409994865137, 11.519137071718665, 10.680651773739738, 9.626318560928162, 8.70214795448754, 7.716003564512219, 6.761077949247396, 5.823746370541054, 5.008356022197739, 5.917317230935876, 6.88366858522421, 7.8247575912702025, 8.727349928465769, 9.66994083520517, 10.650544345258522, 11.69263409893281, 12.487442327151065, 14.479384689714635, 15.451363676915, 14.51250547905577, 13.520309907238135, 12.48672854512055, 11.589465231119066, 10.633945148929937, 9.670398206882115, 8.711486657723245, 7.80787702262621, 6.768329519418061, 5.9718116452105505, 6.945725570209416, 7.898925382713513, 8.84998919945777, 9.756328720752855, 10.63658557016247, 11.638999178529117, 12.651490019186046, 13.510799075000856], [13.528101174100831, 12.578456660981281, 11.585114325437292, 10.625322171895721, 9.822348878176015, 8.862741459321132, 7.945968279457585, 7.001056310270116, 7.790719269462234, 8.714327826058371, 9.701893662995621, 10.670463942432894, 11.634406615073289, 12.56699643112035, 13.51417088229024, 14.391428325079023, 15.41937203280912, 16.43156399195796, 15.557350578131992, 14.537714107738223, 14.499576640014697, 13.554492545661438, 12.615920636446134, 11.565720250883665, 10.809927614158171, 9.908696765752232, 8.885861483535521, 8.001424577613257, 8.767638509890519, 9.70648152897362, 10.660586786982401, 11.590219796383666, 11.849562122330978, 12.798704450223319, 13.768817049860658, 14.604609428466645, 15.32598956922972, 16.353655249253443, 16.387093134774595, 15.440166746218576, 15.517297903277392, 14.55514836745025, 13.592479480894523, 12.59461412403663, 11.819031375446693, 10.897035212251538, 9.909463155023271, 9.050647055186735, 9.743062820050424, 10.639657103518523, 11.635762639734718, 11.783990095574534, 10.828002206673945, 11.776586202746653, 12.74958609261342, 13.553633803838435, 14.344044151619975, 15.383376978678426, 16.31242546413328, 16.377933297030268, 16.529560731918014, 15.491152579220039, 14.50693591240099, 13.557124748028917, 12.771981271511361, 11.850519234719924, 10.866899731610147, 10.10759771774576, 10.724392543327378, 11.593223454376115, 11.683152793399108, 10.771626391096094, 9.86109740702104, 10.823106211230542, 11.871220332200668, 12.538630985132976, 13.390377935353845, 14.328507557343395, 15.260477604907853, 16.17243734025795, 16.11898440333982, 16.42482119281196, 15.456978618757637, 14.595997920010422, 13.788175489232103, 12.85452756052355, 11.876952404813132, 11.138252607501034, 11.746036994269659, 11.59564072038607, 10.74192531519802, 9.8415346366083, 8.885124787544198, 9.896497873472002, 10.80888535992005, 11.57704674962789, 12.410164514182858, 13.417429657441804, 14.240492646031244, 15.181083799311631, 15.288011689492718, 16.24321769098945, 16.50367694770001, 15.595011290354108, 14.725726931061649, 13.788119871346453, 12.93936888622845, 12.063501248286281, 11.603625249584077, 10.617973395964071, 9.683383407106277, 8.819491060555372, 7.883765153503759, 8.855176354217916, 9.779427483132173, 10.618425320790664, 11.45443597770652, 12.369368723009833, 13.305933933507236, 14.3573835787818, 14.337517762146716, 15.313103258328505, 16.376667598224618, 15.555005009469514, 14.578732757615441, 13.562742924965333, 12.544187531380791, 11.612507881576681, 10.654351817201993, 9.7405012400694, 8.734716049884577, 7.768935046097047, 6.838454507666581, 7.884292173748495, 8.721291288607773, 9.626325511247698, 10.521601948189275, 11.434748859363271, 12.400209493796865, 13.405563430190682, 13.566711684128267, 14.557379267027024, 15.499578431432925, 14.565776578378276, 13.5450195378503, 12.577280249123326, 11.590620190556047, 10.729218776980641, 9.712535926973729, 8.745333457431189, 7.792174289668233, 6.836495820421245, 5.906360171804596, 6.835609368425815, 7.751041446070967, 8.610345040468196, 9.557669630366856, 10.48952731064538, 11.514782830653747, 12.506039142397196, 12.657166883049438, 13.567839030219226, 14.546624044315978, 13.655501540878673, 12.628760352848339, 11.61005671970214, 10.585985935360538, 9.660538545740057, 8.70137745500196, 7.7822714070818355, 6.8384690120239995, 5.8853283315443425, 4.963695532817203, 5.841511175588526, 6.73543954352138, 7.673178948840164, 8.677827473927685, 9.62125821407173, 10.636342089718575, 11.695672833342684, 11.650674838339327, 12.593648789713214, 13.595865899198184, 12.706934766670127, 11.723543680514094, 10.727357423569075, 9.652772387441782, 8.717366179214936, 7.747564487301637, 6.812168975057703, 5.8588513827899495, 4.883912348788369, 3.9503593082874993, 4.883912153057061, 5.746737548359726, 6.700339322007069, 7.743550778428095, 8.733502749210823, 9.688419666353946, 10.672653010080738, 10.684043413142891, 11.634205162525896, 12.538182926949155, 11.842284119327223, 10.956369196363006, 9.917365454087761, 8.97172082832389, 7.922216120894319, 6.913515276821654, 5.936686853375013, 4.909544924825335, 3.8535506906930963, 2.9224026925868323, 3.869372078362217, 4.794572521765682, 5.740635731284833, 6.724405827720931, 7.662888295703765, 8.660555409078018, 9.66100479468892, 9.729470318791432, 10.671015905638104, 11.60027559532452, 10.826188722277944, 9.914127826304682, 8.926573922577479, 7.957163796670363, 6.942027138783167, 5.878020100380705, 4.997673197033635, 4.001378980709655, 3.037052380885911, 1.967999334560505, 3.0041142947624646, 3.914521543031693, 4.767861892085659, 5.726160352960278, 6.710707765194092, 7.734288536598104, 8.734385547251106, 8.722269528632715, 9.735194962954454, 10.664808785674133, 9.894891408075997, 8.917197355264962, 7.922461360988742, 6.948807507299728, 5.907359223790676, 4.870206165537792, 4.011187534943246, 2.9933260217084223, 1.9950344115556653, 0.9930707238922604, 2.0049876950325873, 2.885616883166938, 3.824363352112269, 4.770476329123763, 5.740722912470518, 6.705708979086743, 7.748097055838569, 7.959643865012583, 8.920873614573196, 9.958039953087596, 9.070693936116243, 8.081362459621342, 7.016953144259917, 5.980906354729225, 4.987923646360005, 3.9175067025900248, 2.9403779030079646, 1.9569585337478292, 0.947401424977361, 0.0, 0.962825216947641, 1.9468188867697411, 2.8868365627524097, 3.9193275833780192, 4.984573805537496, 6.025567567936286, 6.968261158866132, 8.905493132559855, 9.863526513099782, 10.859074804331714, 10.033393022932955, 9.01395831109453, 8.008032239788488, 6.955168635618824, 5.910814023671122, 4.8390098684373735, 3.8754804226294626, 2.8962777671063953, 1.8970023725133913, 0.9590016747433384, 1.9779470656053477, 2.8986712746067544, 3.865923828001054, 4.878645863418955, 5.821135279444126, 6.80748244031538, 7.856729598577099, 9.660075623618138, 10.727777915306746, 11.7098404859378, 10.745271792757977, 9.694294124602843, 8.720188543072442, 7.671614972785278, 6.688993603363586, 5.721570922964662, 4.777114169310201, 3.851764049076485, 2.9224518758529863, 1.8896922799910123, 2.9002337724437735, 3.9137179796279282, 4.80351924289009, 5.875971746328873, 6.8925304887246694, 7.760237754328038, 8.694377818574354, 10.59083043113702, 11.620332965579234, 12.592591999269958, 11.608805069738787, 10.609046660277343, 9.610090180776517, 8.630395904053065, 7.658304992066232, 6.703883791149959, 5.776139901963885, 4.789416288088246, 3.8851346874183186, 2.927605859847991, 3.9314267759748667, 4.944978647737895, 5.795241120016715, 6.80010472533135, 7.8732655266889555, 8.774547224503376, 9.625939048341138, 11.543891856810307, 12.490765142208442, 13.476796916210365, 12.540989168097804, 11.532602231644384, 10.57747818985564, 9.621177001986094, 8.62826057664506, 7.647694454360741, 6.730224285406689, 5.799065917604803, 4.904763702163596, 3.9761944847010016, 4.879354810026054, 5.885727797192425, 6.844419639736518, 7.7602974566405685, 8.724970094396555, 9.685773545339496, 10.590149439306895, 12.504230270062424, 13.484943261162135, 14.446119293891416, 13.540811419842498, 12.466538496696026, 11.6280531987171, 10.573719985905523, 9.6495493794649, 8.66340498948958, 7.708479374224757, 6.771147795518415, 5.840857569077548, 4.9710274749104855, 5.93737882919882, 6.8784678352448125, 7.7799485034884075, 8.722539410227808, 9.703142920281161, 10.74523267395545, 11.540040902173704, 13.531983264737274, 14.503962251937638, 15.459906904033131, 14.467711332215496, 13.434129970097912, 12.536866656096427, 11.581346573907298, 10.617799631859477, 9.658888082700607, 8.75527844760357, 7.715730944395422, 6.80431319209036, 5.999435814184025, 6.952635626688123, 7.90369944343238, 8.808927295775494, 9.68918414518511, 10.691597753551756, 11.704088594208685, 12.563397650023495], [12.565275957153187, 11.615631444033637, 10.622289108489648, 9.662496954948077, 8.859523661228373, 7.984802638866861, 7.070780080035771, 7.963881527217758, 8.753544486409874, 9.67715304300601, 10.66471887994326, 11.633289159380535, 12.59723183202093, 13.071809886369746, 13.923109803011602, 14.720449721642714, 15.44836970229931, 15.580312638999347, 14.59452536118435, 13.574888890790582, 13.536751423067052, 12.591667328713793, 11.65309541949849, 10.60289503393602, 9.847102397210529, 9.03075794529796, 8.010673284113707, 8.945899015668399, 9.730463726838158, 10.66930674592126, 11.62341200393004, 12.553045013331305, 12.812387339278619, 12.119872605900142, 12.996144410198866, 13.654875962870268, 14.376256103633342, 15.403921783657063, 15.424267917826953, 14.477341529270932, 14.554472686329747, 13.592323150502606, 12.629654263946879, 11.631788907088985, 10.85620615849905, 10.019096391797266, 9.034274955601457, 9.995121493241877, 10.705888036998063, 11.602482320466162, 12.598587856682357, 12.746815312522175, 11.790827423621586, 11.097754358423476, 11.976913452951628, 12.603900338242058, 13.394310686023598, 14.433643513082048, 15.362691998536901, 15.415108080082621, 15.566735514970372, 14.528327362272394, 13.544110695453346, 12.594299531081273, 11.809156054563719, 10.97533103529811, 9.991711532188333, 10.990796331708108, 11.687217760275017, 12.556048671323754, 12.645978010346749, 11.734451608043734, 10.82392262396868, 10.050894149455832, 11.032607291439241, 11.588897519536598, 12.440644469757467, 13.378774091747017, 14.310744139311476, 15.22270387466157, 15.169250937743442, 15.461995975864319, 14.494153401809992, 13.633172703062778, 12.868788757178184, 11.979339361101736, 11.001764205391318, 11.944500119014139, 12.708862211217298, 12.558465937333711, 11.704750532145662, 10.80435985355594, 9.847950004491839, 9.124285811697293, 9.962478416764899, 10.627313284031512, 11.46043104858648, 12.467696191845427, 13.290759180434867, 14.231350333715254, 14.33827822389634, 15.29348422539307, 15.540851730752369, 14.632186073406464, 13.850538731639835, 12.912931671924639, 12.064180686806637, 12.869748759799386, 12.566450466531718, 11.580798612911712, 10.646208624053918, 9.782316277503012, 8.8465903704514, 8.082964292443206, 8.933020539977022, 9.668691855194286, 10.504702512110143, 11.419635257413455, 12.356200467910858, 13.407650113185422, 13.387784296550338, 14.363369792732128, 15.426934132628242, 15.621389502395154, 14.84248183393517, 13.963730567524639, 13.070527490621421, 12.575333098524323, 11.617177034149636, 10.703326457017042, 9.697541266832218, 8.731760263044688, 7.801279724614222, 7.0892214571284144, 7.874884345452623, 8.67659204565132, 9.571868482592897, 10.485015393766894, 11.450476028200487, 12.455829964594304, 12.616978218531889, 13.607645801430646, 14.536753214485284, 15.528601795325917, 14.50784475479794, 13.540105466070967, 12.553445407503688, 11.692043993928284, 10.675361143921371, 9.708158674378831, 8.754999506615874, 7.799321037368886, 6.8691853887522365, 6.021061227548066, 6.904634502915816, 7.660611574871819, 8.607936164770479, 9.539793845049003, 10.56504936505737, 11.556305676800818, 11.6943416661018, 12.605013813271585, 13.583798827368337, 14.55054692831888, 13.591585569795981, 12.572881936649782, 11.54881115230818, 10.623363762687699, 9.664202671949601, 8.745096624029477, 7.801294228971641, 6.848153548491983, 5.926520749764844, 5.026963034710777, 5.88903260036623, 6.723445483243787, 7.7280940083313086, 8.671524748475353, 9.673516872770934, 10.732847616395043, 10.687849621391686, 11.630823572765573, 12.633040682250545, 13.581346920824153, 12.686368897461735, 11.690182640516715, 10.615597604389423, 9.680191396162577, 8.710389704249279, 7.7749941920053445, 6.821676599737591, 5.84673756573601, 4.91318452523514, 4.069364012179312, 4.9003306052045765, 5.737514105059428, 6.7807255614804545, 7.770677532263182, 8.725594449406305, 9.709827793133098, 9.72121819619525, 10.671379945578256, 11.575357710001516, 12.583144156473558, 11.919194413310649, 10.880190671035402, 9.934546045271532, 8.88504133784196, 7.876340493769296, 6.899512070322655, 5.872370141772977, 4.8163759076407375, 3.8852279095344735, 3.022965135207068, 3.9481655786105323, 4.777810514337192, 5.76158061077329, 6.700063078756124, 7.697730192130377, 8.698179577741278, 8.76664510184379, 9.708190688690465, 10.637450378376881, 11.597133151672036, 10.876953043252325, 9.889399139525121, 8.919989013618004, 7.9048523557308075, 6.840845317328346, 5.960498413981276, 4.9642041976572955, 3.999877597833552, 2.930824551508146, 2.0412890778148234, 2.9516963260840523, 3.805036675138018, 4.763335136012637, 5.7478825482464515, 6.771463319650463, 7.771560330303466, 7.759444311685075, 8.772369746006815, 9.701983568726494, 10.754568140881556, 9.880022572212603, 8.885286577936382, 7.911632724247369, 6.870184440738317, 5.833031382485433, 4.9740127518908865, 3.956151238656063, 2.9578596285033063, 1.9558959408399015, 1.0421624780849463, 1.9227916662192972, 2.8615381351646283, 3.807651112176123, 4.777897695522878, 5.742883762139103, 6.785271838890929, 6.9968186480649415, 7.958048397625555, 8.995214736139955, 9.936954197579592, 9.044187676568981, 7.979778361207558, 6.9437315716768655, 5.950748863307646, 4.8803319195376655, 3.9032031199556054, 2.91978375069547, 1.910226641925002, 0.962825216947641, 0.0, 0.9839936698221002, 1.9240113458047687, 2.956502366430378, 4.021748588589855, 5.0627423509886444, 6.00543594191849, 7.942667915612213, 8.900701296152139, 9.896249587384071, 10.858041230156356, 9.976783528042171, 8.970857456736129, 7.917993852566465, 6.873639240618763, 5.801835085385014, 4.838305639577103, 3.8591029840540365, 2.8598275894610325, 1.9218268916909795, 1.0302702072900165, 1.9358460576591137, 2.903098611053413, 3.9158206464713134, 4.858310062496485, 5.844657223367739, 6.893904381629458, 8.697250406670497, 9.764952698359105, 10.74701526899016, 11.70809700970562, 10.657119341550485, 9.683013760020085, 8.63444018973292, 7.651818820311227, 6.6843961399123035, 5.739939386257842, 4.814589266024126, 3.8852770928006275, 2.8525174969386535, 2.025045573021959, 2.9508927626802874, 3.8406940259424487, 4.913146529381232, 5.929705271777029, 6.7974125373803975, 7.7315526016267135, 9.628005214189379, 10.657507748631593, 11.695829684204082, 12.57163028668643, 11.571871877224986, 10.57291539772416, 9.593221121000708, 8.621130209013874, 7.6667090080976, 6.738965118911526, 5.752241505035887, 4.84795990436596, 3.890431076795632, 3.0562385765530524, 3.9840430824787556, 4.832415903069073, 5.837279508383708, 6.910440309741315, 7.811722007555735, 8.663113831393497, 10.581066639862666, 11.527939925260801, 12.513971699262724, 13.503814385045446, 12.495427448592027, 11.540303406803282, 10.584002218933737, 9.591085793592702, 8.610519671308381, 7.69304950235433, 6.761891134552444, 5.867588919111237, 4.939019701648643, 4.004166610604241, 5.007788976738153, 5.881594422788876, 6.797472239692926, 7.762144877448913, 8.722948328391853, 9.627324222359254, 11.541405053114783, 12.522118044214494, 13.483294076943775, 14.420209256927226, 13.429363713643669, 12.590878415664742, 11.536545202853166, 10.612374596412542, 9.62623020643722, 8.671304591172397, 7.7339730124660555, 6.80368278602519, 5.933852691858127, 5.062190629777006, 6.000529014790541, 6.817123286540765, 7.759714193280165, 8.740317703333519, 9.782407457007807, 10.577215685226063, 12.569158047789633, 13.541137034989998, 14.515185180230974, 15.352900969094424, 14.396955187045554, 13.49969187304407, 12.544171790854941, 11.580624848807116, 10.621713299648247, 9.718103664551212, 8.678556161343062, 7.767138409038001, 6.962261031131667, 6.077447427266309, 7.025760622978108, 7.846102078827851, 8.726358928237465, 9.728772536604112, 10.74126337726104, 11.600572433075854], [11.581282287331087, 10.631637774211537, 9.638295438667548, 8.678503285125977, 7.875529991406272, 7.000808969044761, 8.0150908719666, 8.92683950069718, 9.716502459889297, 10.66114671282811, 11.64871254976536, 12.617282829202635, 13.58122550184303, 13.900909963257728, 12.958730211275725, 13.736456051820614, 14.464376032477212, 14.596318969177247, 13.610531691362251, 12.590895220968482, 12.552757753244952, 11.607673658891693, 10.66910174967639, 9.61890136411392, 8.863108727388429, 8.04676427547586, 8.954984076044536, 9.890209807599227, 10.69342170031758, 11.65330041574336, 12.60740567375214, 13.537038683153405, 13.783115245797646, 12.948972682788124, 12.031764818462989, 12.670882293048168, 13.392262433811243, 14.419928113834963, 14.440274248004853, 13.493347859448832, 13.570479016507647, 12.608329480680506, 11.645660594124779, 10.647795237266886, 9.87221248867695, 9.035102721975166, 9.978585747532286, 10.939432285172705, 11.668846010477486, 12.586475990288262, 13.582581526504457, 13.717543219041202, 12.761555330140613, 11.926854435311457, 11.01253386121575, 11.619906668419958, 12.4103170162015, 13.449649843259948, 14.3786983287148, 14.431114410260522, 14.582741845148272, 13.544333692450294, 12.560117025631246, 11.610305861259173, 10.825162384741619, 10.058874148061108, 10.936022324119161, 11.935107123638936, 12.65017573375444, 13.540042341145854, 13.616705916865776, 12.705179514562762, 11.794650530487708, 10.879994226343813, 10.068227699703364, 10.604903849714498, 11.456650799935368, 12.394780421924917, 13.326750469489374, 14.23871020483947, 14.18525726792134, 14.47800230604222, 13.510159731987892, 12.649179033240678, 11.884795087356082, 11.062882473864732, 11.946074997322146, 12.888810910944967, 13.67182018469672, 13.529193843852738, 12.675478438664689, 11.775087760074967, 10.818677911010866, 9.953385888585274, 8.998098825029022, 9.643319614209412, 10.47643737876438, 11.483702522023325, 12.306765510612765, 13.247356663893152, 13.354284554074239, 14.309490555570969, 14.556858060930267, 13.648192403584364, 12.934081844402831, 11.996474784687635, 13.008491478737465, 13.814059551730214, 13.537178373050745, 12.55152651943074, 11.616936530572945, 10.75304418402204, 9.817318276970427, 8.912064369331187, 7.968640948241144, 8.684698185372186, 9.520708842288043, 10.435641587591354, 11.372206798088756, 12.42365644336332, 12.403790626728236, 13.379376122910026, 14.44294046280614, 14.637395832573056, 13.926024946698165, 13.047273680287635, 14.01483828255225, 13.54606100504335, 12.587904940668663, 11.674054363536069, 10.668269173351245, 9.702488169563715, 8.772007631133249, 7.918321534016394, 6.910504753716744, 7.6925983758292205, 8.587874812770798, 9.501021723944792, 10.466482358378386, 11.471836294772203, 11.632984548709787, 12.623652131608544, 13.552759544663182, 14.564439061788667, 14.98169157568102, 14.032736356129641, 13.524173314022715, 12.66277190044731, 11.646089050440398, 10.678886580897858, 9.725727413134901, 8.770048943887913, 7.839913295271264, 6.8723599244574185, 5.940254911179937, 6.676617905049718, 7.623942494948378, 8.555800175226901, 9.581055695235268, 10.572312006978716, 10.710347996279697, 11.621020143449483, 12.599805157546236, 13.566553258496779, 14.535680241519668, 13.54360984316881, 12.519539058827206, 11.594091669206726, 10.634930578468628, 9.715824530548504, 8.772022135490667, 7.81888145501101, 6.897248656283871, 5.878261731620129, 4.924653008630351, 5.739451813421686, 6.744100338509208, 7.687531078653252, 8.689523202948832, 9.748853946572941, 9.703855951569585, 10.646829902943471, 11.649047012428444, 12.597353251002051, 13.485009961918088, 12.660910547035742, 11.58632551090845, 10.650919302681604, 9.681117610768306, 8.745722098524372, 7.792404506256618, 6.817465472255037, 5.883912431754168, 4.955385307250361, 3.9359510134686966, 4.753520435237327, 5.796731891658355, 6.786683862441082, 7.741600779584204, 8.725834123310998, 8.737224526373149, 9.687386275756154, 10.591364040179414, 11.599150486651457, 12.541048966424691, 11.864184340857504, 10.918539715093633, 9.869035007664062, 8.847068400288324, 7.870239976841682, 6.843098048292004, 5.787103814159765, 4.855955816053501, 3.9089864302781168, 2.9837859868746524, 3.7938168445150917, 4.77758694095119, 5.7160694089340245, 6.713736522308277, 7.714185907919179, 7.78265143202169, 8.724197018868363, 9.65345670855478, 10.613139481849934, 11.546411742798348, 10.873392809347223, 9.903982683440105, 8.888846025552908, 7.8248389871504465, 6.944492083803376, 5.948197867479395, 4.983871267655652, 3.914818221330246, 2.9315494590232287, 1.967702656261952, 2.821043005315918, 3.7793414661905373, 4.763888878424352, 5.787469649828363, 6.787566660481366, 6.7754506418629745, 7.788376076184714, 8.717989898904392, 9.770574471059454, 10.74826852387049, 9.869280247758484, 8.89562639406947, 7.854178110560419, 6.8170250523075335, 5.9580064217129864, 4.940144908478163, 3.941853298325406, 2.9398896106620014, 1.9324228592933514, 0.938797996397197, 1.877544465342528, 2.8236574423540226, 3.7939040257007774, 4.758890092317002, 5.801278169068828, 6.012824978242842, 6.9740547278034555, 8.011221066317855, 8.952960527757492, 9.942292004252392, 8.96377203102966, 7.927725241498966, 6.9347425331297465, 5.864325589359766, 4.887196789777706, 3.9037774205175704, 2.894220311747102, 1.9468188867697411, 0.9839936698221002, 0.0, 0.9400176759826685, 1.972508696608278, 3.0377549187677553, 4.0787486811665445, 5.02144227209639, 6.958674245790113, 7.916707626330039, 8.912255917561971, 9.874047560334256, 10.879732028260332, 9.95485112655823, 8.901987522388566, 7.857632910440865, 6.785828755207115, 5.822299309399204, 4.843096653876136, 3.8438212592831325, 2.9058205615130794, 2.0018347690780898, 0.9518523878370133, 1.9191049412313128, 2.931826976649213, 3.874316392674384, 4.860663553545638, 5.909910711807357, 7.713256736848396, 8.780959028537003, 9.763021599168058, 10.754032445560417, 11.641113011372585, 10.667007429842185, 9.61843385955502, 8.635812490133327, 7.668389809734403, 6.723933056079942, 5.798582935846226, 4.869270762622728, 3.8365111667607534, 2.996610134810032, 1.9668990928581869, 2.8567003561203483, 3.9291528595591316, 4.945711601954928, 5.813418867558297, 6.747558931804613, 8.64401154436728, 9.673514078809493, 10.711836014381984, 11.695622943913154, 12.555865547047086, 11.55690906754626, 10.577214790822808, 9.605123878835974, 8.6507026779197, 7.722958788733626, 6.7362351748579865, 5.83195357418806, 4.874424746617732, 4.013601284419684, 3.0000494126566553, 3.848422233246973, 4.853285838561608, 5.926446639919215, 6.827728337733634, 7.679120161571397, 9.597072970040566, 10.543946255438701, 11.529978029440624, 12.55006842075872, 13.479421118414127, 12.524297076625382, 11.567995888755837, 10.575079463414802, 9.594513341130481, 8.677043172176429, 7.745884804374544, 6.830546892590659, 5.901977675128065, 4.9615293184708715, 4.023795306916053, 4.897600752966776, 5.813478569870826, 6.778151207626813, 7.738954658569752, 8.643330552537154, 10.557411383292683, 11.538124374392394, 12.499300407121675, 13.436215587105124, 14.413357383465769, 13.57487208548684, 12.520538872675264, 11.596368266234641, 10.61022387625932, 9.655298260994497, 8.717966682288155, 7.766640759504612, 6.896810665337549, 6.019553337643637, 5.016535344968441, 5.833129616718665, 6.775720523458065, 7.75632403351142, 8.798413787185709, 9.593222015403963, 11.585164377967534, 12.557143365167898, 13.531191510408874, 14.368907299272323, 14.693754406801725, 13.936034437469539, 13.52816546067704, 12.564618518629217, 11.605706969470347, 10.70209733437331, 9.662549831165162, 8.730096382517424, 7.925219004611089, 7.026788627206147, 6.041766953156008, 6.862108409005751, 7.742365258415366, 8.744778866782013, 9.757269707438942, 10.616578763253754], [10.642758447015456, 9.693113933895907, 8.699771598351917, 7.739979444810347, 6.937006151090641, 7.9164025478773405, 8.930684450799179, 9.866857176679847, 10.656520135871965, 11.601164388810778, 12.588730225748028, 13.557300505185303, 14.521243177825697, 14.57736321127556, 13.620763680420984, 12.796438375837946, 13.524358356494542, 13.657795128861615, 12.672007851046619, 11.65237138065285, 11.614233912929322, 10.669149818576063, 9.73057790936076, 8.68037752379829, 7.924584887072797, 8.9017981000236, 9.870577654877115, 10.805803386431807, 11.633439376300249, 12.593318091726028, 13.547423349734808, 14.477056359136073, 14.587711372056027, 13.669685467704443, 12.693798287608248, 11.7308646170655, 12.452244757828574, 13.479910437852295, 13.501750407689222, 12.554824019133202, 12.631955176192017, 11.669805640364876, 10.707136753809149, 9.709271396951255, 8.933688648361318, 9.890136546522905, 10.894179326364865, 11.855025864005285, 12.608863686460154, 13.52649366627093, 14.522599202487125, 14.558697550613147, 13.566151456398995, 12.647567220227776, 11.67456733036101, 10.67988899243729, 11.47029934021883, 12.50963216727728, 13.438680652732131, 13.492590569944891, 13.644218004832641, 12.605809852134664, 11.621593185315616, 10.671782020943542, 9.886638544425987, 10.913907972608847, 11.851615902951742, 12.850700702471517, 13.590193409737108, 14.480060017128523, 14.467557043232155, 13.546333846134706, 12.59924665674609, 11.618433059527279, 10.730261168848623, 9.66488617373183, 10.5166331239527, 11.454762745942249, 12.386732793506706, 13.298692528856801, 13.245239591938672, 13.539478465726589, 12.571635891672262, 11.710655192925048, 10.94627124704045, 11.879919175749002, 12.861668576154727, 13.804404489777548, 14.611837860679389, 14.380044970219117, 13.526329565031068, 12.616242091646912, 11.623274037269248, 10.69182472176874, 9.66013229417428, 8.703301938226744, 9.536419702781712, 10.543684846040657, 11.366747834630097, 12.307338987910484, 12.414266878091569, 13.369472879588299, 13.618334220614638, 12.709668563268734, 12.017373130827304, 12.813511486571905, 13.853771313420863, 14.729653130562795, 14.388029499417124, 13.402377645797118, 12.467787656939324, 11.603895310388419, 10.621914403228809, 9.650503202514653, 8.707079781424609, 7.744680509389517, 8.580691166305375, 9.495623911608686, 10.432189122106088, 11.48363876738065, 11.463772950745566, 12.439358446927356, 13.50292278682347, 13.698871992257423, 13.009316233122638, 13.864310382171904, 14.860118117235647, 14.396912131409726, 13.438756067035039, 12.524905489902448, 11.519120299717624, 10.553339295930094, 9.622858757499628, 8.65676036719986, 7.648943586900209, 6.752580699846552, 7.6478571367881285, 8.561004047962124, 9.526464682395716, 10.531818618789533, 10.69296687272712, 11.683634455625876, 12.612741868680516, 13.624421385806, 14.064982862105493, 14.849773058013911, 14.37502444038909, 13.513623026813686, 12.496940176806774, 11.529737707264234, 10.576578539501277, 9.620900070254288, 8.690764421637642, 7.662968818755539, 6.678693744363403, 5.73660022906705, 6.68392481896571, 7.615782499244234, 8.6410380192526, 9.632294330996048, 9.770330320297031, 10.681002467466817, 11.65978748156357, 12.626535582514112, 13.595662565537001, 14.394460969535185, 13.370390185193582, 12.444942795573102, 11.485781704835004, 10.56667565691488, 9.622873261857043, 8.669732581377387, 7.7480997826502485, 6.69078226574758, 5.737173542757802, 4.799434137439018, 5.80408266252654, 6.747513402670584, 7.749505526966164, 8.808836270590273, 8.763838275586918, 9.706812226960805, 10.709029336445777, 11.657335575019385, 12.544992285935422, 13.511761673402118, 12.437176637274826, 11.50177042904798, 10.531968737134681, 9.596573224890747, 8.643255632622994, 7.668316598621414, 6.7347635581205445, 5.806236433616737, 4.786802139835073, 3.813502759254659, 4.8567142156756855, 5.846666186458414, 6.801583103601536, 7.78581644732833, 7.797206850390482, 8.747368599773486, 9.651346364196748, 10.65913281066879, 11.601031290442025, 12.665725883613636, 11.784343808918639, 10.734839101489067, 9.6979195266547, 8.721091103208058, 7.69394917465838, 6.637954940526141, 5.7068069424198775, 4.759837556644493, 3.8346371132410284, 2.853799168532423, 3.837569264968521, 4.776051732951355, 5.773718846325608, 6.7741682319365095, 6.842633756039022, 7.784179342885695, 8.713439032572113, 9.673121805867268, 10.606394066815682, 11.593947970542885, 10.844000359422774, 9.828863701535578, 8.764856663133116, 7.884509759786045, 6.888215543462064, 5.923888943638321, 4.854835897312914, 3.8715671350058973, 2.8602529440197078, 1.8810253293332493, 2.8393237902078687, 3.8238712024416834, 4.847451973845695, 5.847548984498697, 5.835432965880306, 6.848358400202046, 7.777972222921725, 8.830556795076788, 9.808250847887823, 10.802986842164044, 9.835644070052139, 8.794195786543087, 7.757042728290203, 6.8980240976956555, 5.880162584460832, 4.881870974308075, 3.87990728664467, 2.87244053527602, 1.8788156723798655, 0.9375267893598594, 1.883639766371354, 2.853886349718109, 3.8188724163343335, 4.86126049308616, 5.072807302260173, 6.034037051820787, 7.071203390335186, 8.012942851774822, 9.002274328269722, 9.903789707012328, 8.867742917481635, 7.874760209112416, 6.804343265342435, 5.827214465760375, 4.843795096500239, 3.8342379877297708, 2.8868365627524097, 1.9240113458047687, 0.9400176759826685, 0.0, 1.0324910206256095, 2.0977372427850867, 3.1387310051838764, 4.081424596113722, 6.018656569807445, 6.976689950347371, 7.972238241579302, 8.934029884351586, 9.939714352277662, 10.894868802540898, 9.842005198371234, 8.797650586423533, 7.725846431189784, 6.762316985381873, 5.783114329858805, 4.783838935265801, 3.845838237495748, 2.941852445060758, 1.891870063819682, 0.9805811009156815, 1.9933031363335818, 2.9357925523587527, 3.9221397132300067, 4.971386871491726, 6.774732896532765, 7.842435188221373, 8.824497758852427, 9.815508605244787, 10.866486273399921, 11.607025105824853, 10.558451535537689, 9.575830166115995, 8.608407485717072, 7.66395073206261, 6.738600611828894, 5.809288438605396, 4.7765288427434225, 3.9366278107927, 2.9069167688408557, 1.918176515804717, 2.9906290192435003, 4.007187761639297, 4.874895027242665, 5.8090350914889815, 7.705487704051648, 8.734990238493861, 9.773312174066351, 10.757099103597522, 11.756857513058966, 12.496926743528928, 11.517232466805476, 10.545141554818642, 9.590720353902368, 8.662976464716294, 7.676252850840655, 6.771971250170728, 5.814442422600401, 4.953618960402352, 3.940067088639324, 2.909898392931342, 3.914761998245977, 4.987922799603583, 5.889204497418003, 6.740596321255766, 8.658549129724934, 9.60542241512307, 10.591454189124992, 11.611544580443088, 12.678279398658127, 13.46431475260805, 12.508013564738505, 11.51509713939747, 10.53453101711315, 9.617060848159097, 8.685902480357212, 7.770564568573327, 6.841995351110733, 5.90154699445354, 4.9540377111743075, 3.959076912651145, 4.874954729555196, 5.8396273673111825, 6.800430818254122, 7.704806712221522, 9.61888754297705, 10.599600534076762, 11.560776566806043, 12.497691746789492, 13.571964669935964, 14.51488976146951, 13.460556548657934, 12.53638594221731, 11.550241552241989, 10.595315936977165, 9.657984358270824, 8.706658435487281, 7.836828341320217, 6.959571013626305, 5.93212892380102, 4.894605776403034, 5.837196683142435, 6.817800193195789, 7.859889946870078, 8.654698175088331, 10.646640537651901, 11.618619524852265, 12.592667670093242, 13.43038345895669, 13.753736730819057, 14.598067906614798, 14.46818313665971, 13.504636194611884, 12.545724645453015, 11.64211501035598, 10.60256750714783, 9.670114058500092, 8.865236680593757, 7.942382206038727, 6.957360531988588, 5.92358456869012, 6.8038414180997355, 7.806255026466383, 8.818745867123312, 9.678054922938122], [9.694063474461881, 8.744418961342332, 7.751076625798343, 6.791284472256772, 7.844751175870746, 8.849449490959596, 9.863731393881434, 10.877435319734012, 11.667098278926128, 12.633655409436388, 13.621221246373638, 14.589791525810911, 15.553734198451306, 15.552088590435028, 14.595489059580451, 13.771163754997414, 12.934502634506988, 12.644178239609683, 11.658390961794687, 10.638754491400919, 10.665538940375747, 9.720454846022488, 8.781882936807184, 7.731682551244715, 8.666835955970015, 9.644049168920818, 10.70507505756889, 11.640300789123582, 12.627047795756043, 13.625809112351638, 14.579914370360418, 15.509547379761683, 15.562436751215497, 14.64441084686391, 13.668523666767715, 12.705589996224967, 11.86238903584102, 12.84656635625145, 12.514375183749822, 11.567448795193801, 11.683260203638442, 10.7211106678113, 9.758441781255573, 8.76057642439768, 9.675939717258537, 10.632387615420123, 11.68160132893814, 12.68952326669706, 13.602472105915949, 14.555301052474016, 15.555090223112735, 15.533422929772616, 14.540876835558464, 13.622292599387244, 12.649292709520477, 11.654614371596757, 10.880443618231276, 11.876288085676435, 12.754949250282426, 12.50521534600549, 12.695523032279066, 11.657114879581089, 10.67289821276204, 9.723087048389967, 10.628889613323205, 11.656159041506065, 12.639037905525015, 13.63812270504479, 14.583801829192902, 15.508867403331609, 15.44228242239162, 14.521059225294175, 13.573972035905559, 12.593158438686748, 11.70498654800809, 10.639611552891298, 9.926777401965143, 10.821418664341405, 11.703001391057, 12.614961126407096, 12.561508189488967, 12.590783493173014, 11.622940919118687, 10.761960220371472, 11.688522315937668, 12.62217024464622, 13.611221889921241, 14.553957803544062, 15.53638928944334, 15.354770349378583, 14.501054944190534, 13.590967470806381, 12.597999416428717, 11.666550100928209, 10.634857673333748, 9.678027317386212, 8.946563980794156, 9.859953443590951, 10.683016432180391, 11.623607585460778, 11.730535475641863, 12.685741477138594, 12.669639248061063, 11.760973590715158, 12.759624199724522, 13.555762555469123, 14.59602238231808, 15.479206444329309, 15.36275487857659, 14.377103024956584, 13.44251303609879, 12.578620689547884, 11.596639782388278, 10.625228581674122, 9.681805160584078, 8.719405888548986, 7.990835444317819, 8.81189250915898, 9.748457719656383, 10.799907364930945, 10.74863611483581, 11.7242216110176, 12.686392294136324, 12.750177019703848, 13.726449271557922, 14.606561451069123, 15.602369186132865, 15.371637510569194, 14.413481446194506, 13.499630869061914, 12.49384567887709, 11.52806467508956, 10.597584136659094, 9.63148574635933, 8.623668966059679, 7.72730607900602, 7.0580014148005725, 7.877272645512418, 8.84273327994601, 9.848087216339827, 9.781429801537668, 10.772097384436425, 11.695241293816997, 12.706920810942481, 13.709549824040378, 14.617517131062819, 15.349749819548558, 14.488348405973152, 13.471665555966242, 12.504463086423701, 11.551303918660746, 10.595625449413758, 9.665489800797108, 8.637694197915007, 7.6534191235228715, 6.7113256082265185, 6.094069096978154, 6.932051096794528, 7.922343307072808, 8.900175213277944, 8.85282974543351, 9.763501892603298, 10.74228690670005, 11.709035007650591, 12.67816199067348, 13.635474068363177, 14.34511556435305, 13.419668174732568, 12.460507083994472, 11.541401036074348, 10.59759864101651, 9.644457960536856, 8.722825161809716, 7.665507644907049, 6.711898921917271, 5.774159516598487, 5.0914530473828465, 5.9298270449991985, 6.880972143843708, 7.939623001197246, 7.8463377007233985, 8.789311652097286, 9.791528761582256, 10.739835000155864, 11.627491711071901, 12.62367796801692, 13.411902016434293, 12.476495808207448, 11.506694116294149, 10.571298604050215, 9.617981011782462, 8.643041977780882, 7.709488937280013, 6.780961812776206, 5.761527518994542, 4.788228138414127, 4.035250342502225, 4.978132803335958, 5.93304972047908, 6.874158836607252, 6.879706275526962, 7.829868024909966, 8.733845789333227, 9.74163223580527, 10.683530715578504, 11.748225308750115, 12.666369770319887, 11.709564480648535, 10.672644905814167, 9.695816482367526, 8.668674553817848, 7.61268031968561, 6.681532321579346, 5.734562935803962, 4.809362492400497, 3.828524547691892, 3.0161053917950604, 3.9075183498289, 4.905185463203153, 5.862510621215433, 5.925133181175502, 6.866678768022175, 7.795938457708592, 8.755621231003747, 9.688893491952161, 10.676447395679364, 11.645857521586482, 10.861354722161186, 9.797347683758725, 8.917000780411655, 7.920706564087674, 6.956379964263931, 5.887326917938524, 4.855706117365595, 3.8349783231791763, 2.8557507084927183, 2.017859917034408, 2.9067101531458457, 3.9302909245498574, 4.9300484096351775, 4.9179323910167865, 5.930857825338526, 6.860471648058205, 7.913056220213268, 8.890750273024304, 9.885486267300525, 10.859140120989538, 9.826686807168697, 8.789533748915812, 7.930515118321265, 6.912653605086442, 5.914361994933685, 4.91239830727028, 3.904931555901629, 2.911306693005475, 1.9122521685193288, 0.9661391915078342, 1.936385774854589, 2.9013718414708136, 3.94375991822264, 4.0403162816345635, 5.001546031195177, 6.038712369709576, 6.980451831149213, 7.969783307644113, 9.034192623005538, 9.900233938107245, 8.907251229738025, 7.836834285968045, 6.859705486385985, 5.876286117125849, 4.866729008355381, 3.9193275833780197, 2.9565023664303784, 1.972508696608278, 1.0324910206256095, 0.0, 1.0652462221594772, 2.106239984558267, 3.0489335754881126, 4.986165549181835, 5.944198929721761, 6.939747220953692, 7.901538863725977, 8.907223331652052, 9.913149402958094, 10.874496218996844, 9.830141607049143, 8.758337451815393, 7.794808006007483, 6.8156053504844145, 5.816329955891411, 4.878329258121358, 3.974343465686368, 2.9243610844452914, 1.9924082824995515, 0.9796862470816512, 1.922175663106822, 2.908522823978076, 3.9577699822397947, 5.761116007280834, 6.828818298969442, 7.810880869600497, 8.801891715992857, 9.852869384147992, 10.826974965678392, 11.590942556163297, 10.608321186741604, 9.64089850634268, 8.69644175268822, 7.771091632454504, 6.841779459231006, 5.809019863369032, 4.96911883141831, 3.9394077894664647, 2.930003697388587, 2.0030431358533907, 2.993570872387366, 3.8612781379907344, 4.795418202237051, 6.691870814799717, 7.72137334924193, 8.75969528481442, 9.74348221434559, 10.743240623807035, 11.742197103307861, 12.549723487431084, 11.57763257544425, 10.623211374527976, 9.695467485341903, 8.708743871466265, 7.804462270796338, 6.8469334432260105, 5.986109981027961, 4.9725581092649325, 3.9217255745152118, 2.966067025692401, 4.012374572243436, 4.875587608166072, 5.726979432003835, 7.644932240473002, 8.591805525871138, 9.57783729987306, 10.597927691191156, 11.664662509406195, 12.61978655119494, 13.540504585364113, 12.547588160023079, 11.567022037738758, 10.649551868784707, 9.718393500982822, 8.78114271162749, 7.852573494164895, 6.912125137507702, 5.905752150341331, 4.910791351818169, 3.926259757001619, 4.890932394757606, 5.841272820902253, 6.691189822969592, 8.60527065372512, 9.58598364482483, 10.547159677554111, 11.48407485753756, 12.558347780684032, 13.631121521717356, 14.49304756928354, 13.568876962842918, 12.582732572867597, 11.627806957602775, 10.690475378896434, 9.717236578541444, 8.84740648437438, 7.94578259957268, 6.883843362968045, 5.846320215570058, 4.888501710588859, 5.869105220642213, 6.908156378350045, 7.6410812858364, 9.63302364839997, 10.605002635600334, 11.57905078084131, 12.416766569704759, 13.450347931822343, 14.476984055749579, 15.432504137938707, 14.537127215237494, 13.578215666078624, 12.67460603098159, 11.63505852777344, 10.680692201554255, 9.87581482364792, 8.894096645205753, 7.909074971155613, 6.8481669610939235, 5.8551464455461595, 6.857560053912806, 7.870050894569735, 8.66443803368619], [8.799664653347497, 7.983986806953176, 7.049876473410656, 7.736737999507932, 8.790204703121907, 9.794903018210757, 10.809184921132594, 11.822888846985173, 12.612551806177288, 13.581696870393216, 14.569262707330466, 15.595738297616618, 16.385031156663146, 15.395038258021042, 14.438438727166465, 13.467402899909803, 12.428901965499204, 11.704652934810504, 10.718865656995508, 9.69922918660174, 9.772064301344935, 8.960022691633332, 8.080682784419498, 8.677136078495876, 9.612289483221176, 10.589502696171978, 11.650528584820051, 12.585754316374743, 13.572501323007204, 14.573850573308466, 15.527955831317247, 16.45758884071851, 16.554994255922292, 15.636968351570705, 14.653623306431944, 13.647253425094434, 12.684293053949201, 11.898630694264734, 11.574849878950642, 10.627923490394622, 10.78978556460763, 9.960678513422145, 9.115514247111427, 9.70602995164884, 10.621393244509697, 11.577841142671284, 12.6270548561893, 13.634976793948221, 14.54792563316711, 15.500754579725177, 16.50313168406956, 16.52598043447941, 15.533434340265257, 14.614850104094037, 13.64185021422727, 12.64717187630355, 11.702347636339457, 10.928352423689718, 11.807013588295709, 11.565690041206311, 11.822779411230048, 10.922087588261292, 10.164639409575747, 10.668540575641128, 11.574343140574365, 12.601612568757226, 13.584491432776176, 14.58357623229595, 15.529255356444063, 16.45432093058277, 16.434839927098416, 15.513616730000969, 14.566529540612352, 13.585715943393541, 12.697544052714884, 11.632169057598091, 10.748681420073325, 9.873483002354687, 10.755065729070283, 11.667025464420378, 11.61357252750225, 11.960262520520379, 11.114682115932393, 11.707413747622633, 12.633975843188828, 13.567623771897381, 14.556675417172402, 15.499411330795223, 16.481842816694503, 16.34732785408538, 15.493612448897329, 14.583524975513175, 13.59055692113551, 12.659107605635002, 11.627415178040541, 10.670584822093005, 9.768467998902338, 8.912017781604234, 9.735080770193674, 10.675671923474061, 10.720361042058121, 11.675567043554851, 12.16138044487477, 12.706427117966319, 13.705077726975682, 14.501216082720283, 15.541475909569241, 16.42465997158047, 16.355312383283383, 15.36966052966338, 14.435070540805585, 13.57117819425468, 12.589197287095072, 11.617786086380915, 10.674362665290872, 9.711963393255779, 8.812739462426, 7.863956847172263, 8.800522057669665, 9.85197170294423, 9.727158953934758, 10.702744450116548, 11.664915133235272, 12.70953674759395, 13.685808999448021, 14.571444866096039, 15.464067177164345, 16.36419501527599, 15.406038950901301, 14.492188373768709, 13.486403183583885, 12.520622179796355, 11.59014164136589, 10.624043251066123, 9.616226470766472, 8.719863583712813, 7.879905432908754, 6.929336983525701, 7.894797617959294, 8.887043357108821, 8.759952640636616, 9.750620223535373, 10.673764132915945, 11.68544365004143, 12.678014883231592, 13.585982190254033, 14.510499836339601, 15.480905910679947, 14.464223060673037, 13.497020591130497, 12.543861423367542, 11.588182954120553, 10.658047305503903, 9.6302517026218, 8.645976628229665, 7.703883112933312, 6.915973115086335, 5.984115434807811, 6.974407645086091, 7.878698052376892, 7.831352584532459, 8.742024731702246, 9.720809745798999, 10.677500066841802, 11.646627049864694, 12.60393912755439, 13.505865581144093, 14.412225679439363, 13.453064588701267, 12.533958540781143, 11.590156145723306, 10.637015465243651, 9.71538266651651, 8.658065149613844, 7.7044564266240645, 6.76671702130528, 5.925322123156525, 4.981891383012481, 5.933036481856991, 6.918145840296194, 6.824860539822347, 7.767834491196234, 8.759993820773467, 9.708300059347076, 10.595956770263115, 11.592143027208134, 12.572652033225337, 13.469053312914243, 12.499251621000944, 11.56385610875701, 10.610538516489257, 9.635599482487677, 8.702046441986806, 7.773519317482999, 6.754085023701335, 5.780785643120921, 4.917210106532181, 4.030197141349241, 4.985114058492363, 5.852681675706201, 5.85822911462591, 6.804639214029881, 7.702310848524438, 8.710097294996482, 9.651995774769716, 10.716690367941325, 11.634834829511098, 12.651924455007128, 11.665202410520962, 10.688373987074321, 9.661232058524643, 8.605237824392404, 7.6740898262861394, 6.727120440510755, 5.801919997107291, 4.821082052398685, 3.898065155825017, 2.9595826878421825, 3.9572498012164354, 4.841033460314382, 4.90365602027445, 5.835143827213387, 6.7644035168998045, 7.7240862901949585, 8.657358551143373, 9.644912454870576, 10.614322580777692, 11.671735472895975, 10.862593905918201, 9.95430651790988, 8.9580123015859, 7.968262497040801, 6.894762328514949, 5.848263622072388, 4.827535827885969, 3.8483082131995108, 2.9433219033929428, 1.9587744911591283, 2.98235526256314, 3.908571248734127, 3.8964552301157354, 4.899322884529738, 5.828936707249417, 6.88152127940448, 7.839732768921692, 8.834468763197913, 9.808122616886926, 10.849570900395978, 9.854779971075288, 8.995761340480742, 7.977899827245919, 6.979608217093162, 5.956113338058964, 4.922352774048294, 3.9287279111521394, 2.904809673226121, 1.9586966962146262, 0.9884501128678713, 1.953436179484096, 2.9222827573215895, 2.9750700594750863, 3.9362998090356998, 4.9734661475500985, 5.915205608989735, 6.904537085484636, 7.96894640084606, 9.004993190376753, 9.972497451897501, 8.902080508127522, 7.9249517085454615, 6.941532339285326, 5.931975230514857, 4.984573805537496, 4.021748588589856, 3.0377549187677553, 2.0977372427850867, 1.0652462221594772, 0.0, 1.0409937623987897, 1.9836873533286354, 3.9209193270223577, 4.878952707562284, 5.874500998794216, 6.836292641566501, 7.841977109492575, 8.847903180798617, 9.900766784968281, 10.89538782920862, 9.82358367397487, 8.860054228166959, 7.880851572643891, 6.881576178050888, 5.943575480280835, 4.95509674438609, 3.9051143631450134, 2.937861809750714, 1.9251397743328136, 0.9826503583076427, 1.9689975191788966, 3.0182446774406153, 4.821590702481655, 5.837119692908354, 6.8191822635394095, 7.762062620531347, 8.813040288686482, 9.787145870216882, 10.835719440504047, 11.67356740890108, 10.706144728502156, 9.761687974847696, 8.83633785461398, 7.907025681390483, 6.874266085528509, 5.949872110118032, 4.918183926733448, 3.8754572246397494, 2.948496663104553, 2.0540455675881866, 2.921752833191555, 3.8558928974378714, 5.752345510000538, 6.781848044442751, 7.82016998001524, 8.719995427930824, 9.719753837392268, 10.718710316893095, 11.698404593616546, 12.642878797603727, 11.688457596687453, 10.76071370750138, 9.773990093625741, 8.869708492955816, 7.912179665385487, 6.937302589804813, 5.923750718041784, 4.867179101766374, 3.9115205529435633, 3.0728492674442567, 3.9360623033668922, 4.787454127204656, 6.705406935673823, 7.652280221071958, 8.638311995073881, 9.65217952628984, 10.71891434450488, 11.674038386293624, 12.63033957416317, 13.612834382182555, 12.632268259898234, 11.678518419861387, 10.747360052059502, 9.72659623887865, 8.798027021416056, 7.857578664758863, 6.8512056775924925, 5.8562448790693304, 4.871713284252781, 4.0528656688684945, 4.9017475161030735, 5.751664518170412, 7.66574534892594, 8.646458340025651, 9.607634372754932, 10.544549552738381, 11.618822475884853, 12.691596216918176, 13.582882558082598, 14.537906289793712, 13.637219009087122, 12.654191885594395, 11.716860306888053, 10.662690105792604, 9.79286001162554, 8.89123612682384, 7.829296890219205, 6.791773742821219, 5.83395523784002, 5.031038494753101, 5.968631073550865, 6.70155598103722, 8.69349834360079, 9.665477330801155, 10.639525476042131, 11.47724126490558, 12.510822627023163, 13.5374587509504, 14.492978833139528, 15.524235259919465, 14.632702102298149, 13.622647491938416, 12.583099988730268, 11.626145728805415, 10.82126835089908, 9.839550172456914, 8.854528498406774, 7.793620488345085, 6.800599972797321, 6.064316349584607, 7.037807888096321, 7.724912728887011], [7.799922747624187, 6.984244901229866, 7.859819865864864, 8.692506414333842, 9.745973117947816, 10.750671433036667, 11.764953335958504, 12.77865726181108, 13.568320221003198, 14.537465285219124, 15.525031122156374, 16.34923192358023, 15.385289250939836, 14.395296352297734, 13.438696821443157, 12.467660994186495, 11.429160059775896, 10.704911029087194, 9.719123751272198, 8.69948728087843, 8.772322395621625, 7.960280785910022, 8.890626176873706, 9.632904493321785, 10.568057898047085, 11.545271110997888, 12.606296999645961, 13.541522731200653, 14.528269737833114, 15.529618988134374, 16.483724246143154, 17.291514819206284, 16.32851010913209, 15.347233632767338, 14.365662214255893, 13.464234029587097, 12.501273658441864, 11.561727290267434, 10.575107973227334, 9.628181584671314, 9.79004365888432, 8.960936607698835, 9.925457639565636, 10.66179836647475, 11.577161659335607, 12.533609557497194, 13.58282327101521, 14.59074520877413, 15.503694047993019, 16.456522994551086, 17.45890009889547, 17.510217168681386, 16.517671074467234, 15.599086838296014, 14.626086948429247, 13.631408610505527, 12.686584370541432, 11.912589157891695, 11.030784633948763, 10.565948135483003, 10.823037505506736, 9.922345682537983, 10.906562349357031, 11.624308990467037, 12.530111555400275, 13.557380983583135, 14.540259847602087, 15.539344647121862, 16.485023771269972, 17.41008934540868, 17.419076661300394, 16.497853464202944, 15.550766274814329, 14.569952677595518, 13.68178078691686, 12.616405791800068, 11.732918154275302, 10.857719736556664, 9.978836774723337, 10.801238823075941, 10.626409820259822, 10.96052061479707, 11.856605055713677, 12.663182162448543, 13.58974425801474, 14.523392186723292, 15.512443831998313, 16.455179745621134, 17.437611231520414, 17.331564588287353, 16.47784918309931, 15.567761709715151, 14.574793655337487, 13.643344339836979, 12.611651912242518, 11.654821556294982, 10.752704733104315, 9.896254515806211, 8.958851815846728, 9.809885282129624, 9.679367279659331, 10.634573281156062, 11.625980294759314, 12.65390549625799, 13.636758339344563, 14.57436539905976, 15.429420218580342, 16.353666249571162, 17.326579110006715, 16.353897263865356, 15.419307275007563, 14.555414928456658, 13.573434021297048, 12.602022820582892, 11.658599399492848, 10.696200127457756, 9.796976196627977, 8.84819358137424, 8.02429310332272, 8.835091882628408, 8.686165191535968, 9.661750687717758, 10.62392137083648, 11.668542985195158, 12.64481523704923, 13.530451103697247, 14.423073414765557, 15.407572302854852, 16.36572836722954, 15.476425107970687, 14.470639917785864, 13.504858913998333, 12.574378375567868, 11.6082799852681, 10.600463204968449, 9.70410031791479, 8.864142167110732, 7.913573717727678, 7.0601747876135565, 7.846049594710032, 7.718958878237826, 8.709626461136583, 9.632770370517154, 10.644449887642638, 11.6370211208328, 12.544988427855241, 13.469506073940813, 14.461063520414752, 15.448459794875014, 14.481257325332473, 13.528098157569518, 12.57241968832253, 11.642284039705881, 10.614488436823777, 9.630213362431641, 8.688119847135289, 7.900209849288312, 6.968352169009788, 6.120455622567782, 6.837704289978103, 6.790358822133669, 7.7010309693034555, 8.679815983400207, 9.636506304443014, 10.605633287465903, 11.5629453651556, 12.464871818745305, 13.410236845578517, 14.390679138667016, 13.51819527498312, 12.574392879925282, 11.621252199445628, 10.699619400718488, 9.64230188381582, 8.688693160826041, 7.750953755507257, 6.909558857358502, 5.966128117214458, 5.079084459338683, 5.877152077897406, 5.783866777423557, 6.726840728797444, 7.719000058374677, 8.667306296948286, 9.554963007864323, 10.551149264809343, 11.531658270826549, 12.467064479053395, 13.436866170966693, 12.548092842958987, 11.594775250691233, 10.619836216689654, 9.686283176188784, 8.757756051684977, 7.738321757903312, 6.7650223773228975, 5.901446840734158, 5.014433875551218, 4.131162035974054, 4.811687913307412, 4.8172353522271205, 5.763645451631091, 6.661317086125648, 7.669103532597692, 8.611002012370927, 9.675696605542537, 10.59384106711231, 11.61093069260834, 12.647850267442708, 11.672610721276298, 10.64546879272662, 9.58947455859438, 8.658326560488117, 7.711357174712732, 6.786156731309267, 5.805318786600662, 4.882301890026993, 3.9438194220441596, 3.1013920986297867, 3.8000396979155924, 3.862662257875661, 4.794150064814597, 5.723409754501015, 6.683092527796169, 7.616364788744583, 8.603918692471787, 9.573328818378904, 10.630741710497187, 11.694748748899649, 10.938543252111856, 9.942249035787876, 8.952499231242777, 7.878999062716925, 6.832500356274364, 5.8117725620879455, 4.832544947401487, 3.92755863759492, 2.943011225361105, 2.076438174810187, 2.867577486335337, 2.8554614677169456, 3.858329122130948, 4.787942944850627, 5.8405275170056905, 6.7987390065229025, 7.7934750007991225, 8.767128854488137, 9.808577137997188, 10.845730196250074, 10.036755102879532, 8.991836180393642, 7.993544570240886, 6.940350072260941, 5.906589508250271, 4.9129646453541165, 3.889046407428098, 2.9429334304166033, 1.9726868470698484, 1.0077007804536235, 1.8812889949227998, 1.9340762970762966, 2.89530604663691, 3.932472385151309, 4.874211846590946, 5.863543323085846, 6.9279526384472705, 7.963999427977963, 8.956982136347182, 9.94307427052631, 8.96594547094425, 7.9825261016841145, 6.972968992913646, 6.025567567936285, 5.0627423509886444, 4.0787486811665445, 3.1387310051838764, 2.106239984558267, 1.0409937623987897, 0.0, 0.9426935909298456, 2.879925564623568, 3.8379589451634946, 4.833507236395426, 5.795298879167711, 6.800983347093785, 7.806909418399828, 8.859773022569492, 9.904127634517193, 10.86457743637366, 9.901047990565749, 8.901960429092998, 7.902685034499994, 6.946994551267296, 5.928049160405287, 4.878066779164211, 3.910814225769912, 2.8980921903520116, 1.9556027743268407, 0.9692556134555868, 1.9833609463227244, 3.821848796758345, 4.7961259305095645, 5.77818850114062, 6.721068858132558, 7.772046526287692, 8.746152107818093, 9.794725678105257, 10.77734704752695, 11.716459496404903, 10.772002742750443, 9.846652622516727, 8.910444752376943, 7.8776851565149695, 6.922824526137229, 5.891136342752646, 4.848409640658947, 3.921449079123751, 2.9833614341350048, 1.922010927468245, 2.8561509917145615, 4.752603604277228, 5.782106138719441, 6.8204280742919305, 7.679001665532034, 8.678760074993479, 9.677716554494305, 10.657410831217756, 11.639424778652673, 12.593845979568947, 11.771028475404126, 10.784304861528488, 9.873127563942276, 8.915598736371948, 7.910255005824011, 6.896703134060982, 5.840131517785572, 4.884472968962761, 3.898425676452945, 2.9363203976435823, 3.787712221481346, 5.705665029950513, 6.652538315348648, 7.638570089350572, 8.61118576389105, 9.67792058210609, 10.633044623894834, 11.58934581176438, 12.605821059169374, 13.537656642779728, 12.634286834687298, 11.703128466885413, 10.68236465370456, 9.753795436241965, 8.813347079584773, 7.806974092418401, 6.812013293895239, 5.82748169907869, 4.862809061322703, 3.9020056103797636, 4.751922612447102, 6.66600344320263, 7.646716434302341, 8.607892467031622, 9.544807647015073, 10.611856847157732, 11.684630588191055, 12.541888795683807, 13.49691252739492, 14.483056917370241, 13.609960300420305, 12.672628721713963, 11.618458520618514, 10.74862842645145, 9.847004541649751, 8.785065305045116, 7.747542157647128, 6.789723652665929, 5.84098188720731, 4.968889167827555, 5.70181407531391, 7.6937564378774805, 8.665735425077845, 9.639783570318821, 10.477499359182271, 11.511080721299855, 12.537716845227092, 13.49323692741622, 14.524493354196157, 15.478540010581268, 14.578415906764324, 13.538868403556176, 12.581914143631325, 11.77703676572499, 10.795318587282821, 9.810296913232683, 8.749388903170994, 7.75636838762323, 6.874259742038816, 6.038065982373011, 6.725170823163701], [7.033704141864239, 7.88323108922969, 8.80251345679471, 9.635200005263687, 10.688666708877662, 11.693365023966512, 12.70764692688835, 13.721350852740926, 14.511013811933044, 15.48015887614897, 16.46772471308622, 15.473453308208004, 14.50951063556761, 13.519517736925508, 12.56291820607093, 11.591882378814269, 10.553381444403668, 9.871045536702745, 8.889842157229888, 7.933268675118481, 8.006103789861676, 8.859266973909845, 9.833319767803552, 10.57559808425163, 11.510751488976931, 12.487964701927734, 13.548990590575807, 14.484216322130498, 15.47096332876296, 16.47231257906422, 17.345369213235323, 16.415736203834058, 15.452731493759863, 14.471455017395112, 13.489883598883667, 12.588455414214868, 11.625495043069636, 10.795508684507485, 9.808889367467385, 8.861962978911365, 9.023825053124371, 9.859922795698658, 10.868151230495481, 11.604491957404596, 12.519855250265453, 13.47630314842704, 14.525516861945055, 15.533438799703976, 16.446387638922864, 17.399216585480932, 18.320545065987638, 17.353235649763377, 16.43069844207038, 15.482114445997672, 14.509114556130905, 13.639431038843078, 12.60744046067938, 11.764947739650571, 10.800932864934136, 9.799729529723054, 10.056818899746787, 10.821331870537804, 11.805548537356852, 12.567002581396883, 13.47280514633012, 14.50007457451298, 15.482953438531933, 16.482038238051707, 17.427717362199818, 18.352782936338524, 18.361770252230233, 17.44054705513279, 16.493459865744175, 15.474615752867495, 14.55472740460801, 13.489352409491218, 12.530314760000726, 11.62330546929496, 10.704588302882804, 9.858545232146096, 9.683716229329978, 10.691389190278391, 11.659231764332718, 12.698914465212022, 13.6631213316753, 14.56526411895282, 15.549143109065813, 16.336221299426562, 17.318652785325842, 18.274258179217195, 17.420542774029148, 16.510455300644995, 15.517487246267331, 14.548007415108955, 13.484598529933669, 12.527768173986132, 11.550101338829739, 10.661840248544507, 9.684603344006195, 8.867191691199778, 8.736673688729487, 9.691879690226218, 10.68328670382947, 11.711211905328145, 12.694064748414721, 13.631671808129918, 14.486726627650494, 15.410972658641315, 16.38388551907687, 17.2965908547952, 16.362000865937404, 15.4981085193865, 14.516127612226892, 13.544716411512736, 12.601292990422692, 11.569146745148906, 10.594372802353401, 9.645590187099666, 8.750044631482186, 7.892398291698561, 7.7434716006061235, 8.719057096787912, 9.681227779906637, 10.725849394265314, 11.702121646119387, 12.587757512767402, 13.48037982383571, 14.464878711925005, 15.423034776299692, 16.37938022050133, 15.413333508715706, 14.447552504928176, 13.51707196649771, 12.550973576197944, 11.543156795898293, 10.620984086202155, 9.661538772836156, 8.710970323453104, 7.785926315773024, 6.903356003780186, 6.776265287307981, 7.7669328702067375, 8.69007677958731, 9.701756296712794, 10.694327529902955, 11.602294836925395, 12.526812483010966, 13.518369929484905, 14.522958857425463, 15.362732574654267, 14.470791748499362, 13.515113279252374, 12.584977630635724, 11.55718202775362, 10.572906953361485, 9.630813438065132, 8.697606455013737, 7.765748774735213, 6.846207150727249, 5.895010699048258, 5.847665231203824, 6.758337378373611, 7.737122392470363, 8.693812713513168, 9.662939696536057, 10.620251774225753, 11.522178227815457, 12.467543254648668, 13.447985547737169, 14.399670524304913, 13.517086470855126, 12.563945790375472, 11.642312991648332, 10.584995474745662, 9.631386751755883, 8.6936473464371, 7.706955463083927, 6.763524722939883, 5.80483598749815, 4.93445848696756, 4.841173186493712, 5.784147137867599, 6.776306467444831, 7.724612706018441, 8.612269416934478, 9.608455673879497, 10.588964679896701, 11.524370888123547, 12.494172580036846, 13.42956809228078, 12.537468841621077, 11.562529807619498, 10.628976767118628, 9.70044964261482, 8.681015348833157, 7.707715968252741, 6.813090024660899, 5.811830481276643, 4.856913564133521, 3.8689943223775662, 3.8745417612972757, 4.820951860701245, 5.718623495195803, 6.726409941667846, 7.668308421441081, 8.73300301461269, 9.651147476182462, 10.668237101678493, 11.70515667651286, 12.615304312206142, 11.588162383656464, 10.532168149524225, 9.601020151417961, 8.654050765642577, 7.728850322239111, 6.748012377530506, 5.793945073953735, 4.8554626059709, 3.857795492596648, 2.8573461069857466, 2.919968666945816, 3.8514564738847517, 4.780716163571169, 5.740398936866323, 6.673671197814738, 7.66122510154194, 8.630635227449057, 9.68804811956734, 10.752055157969801, 11.825345494833396, 10.884942626717722, 9.895192822172623, 8.821692653646771, 7.775193947204209, 6.75446615301779, 5.775238538331332, 4.870252228524765, 3.885704816290951, 2.9748627794138853, 1.9248838954054914, 1.9127678767871001, 2.9156355312011026, 3.8452493539207815, 4.897833926075845, 5.856045415593059, 6.8507814098692785, 7.824435263558293, 8.865883547067344, 9.90303660532023, 10.874394499726296, 9.934529771323486, 8.93623816117073, 7.883043663190785, 6.8492830991801155, 5.855658236283961, 4.831739998357943, 3.8856270213464486, 2.9153804379996937, 1.950394371383469, 0.9385954039929542, 0.991382706146451, 1.9526124557070645, 2.9897787942214635, 3.9315182556611004, 4.920849732156001, 5.985259047517426, 7.021305837048118, 8.014288545417337, 9.084705489187316, 9.908639061874096, 8.925219692613961, 7.915662583843492, 6.968261158866131, 6.00543594191849, 5.02144227209639, 4.081424596113722, 3.0489335754881126, 1.9836873533286354, 0.9426935909298456, 0.0, 1.9372319736937222, 2.895265354233649, 3.89081364546558, 4.852605288237865, 5.85828975616394, 6.864215827469982, 7.917079431639645, 8.961434043587346, 10.017691093528523, 10.843741581495594, 9.844654020022844, 8.84537862542984, 7.889688142197142, 6.870742751335133, 5.820760370094057, 4.853507816699757, 3.8407857812818573, 2.8982963652566864, 1.9119492043854325, 1.0406673553928787, 2.9625804609515307, 3.853432339579719, 4.835494910210774, 5.778375267202712, 6.829352935357846, 7.803458516888246, 8.852032087175411, 9.834653456597104, 10.802076136996028, 11.714696333680289, 10.789346213446573, 9.853138343306789, 8.820378747444815, 7.865518117067075, 6.833829933682491, 5.791103231588792, 4.864142670053597, 3.9260550250648505, 2.864704518398091, 2.089932385954613, 3.8933352684704134, 4.918883211683373, 5.879004896025444, 6.736308074602189, 7.736066484063632, 8.735022963564457, 9.714717240287909, 10.696731187722825, 11.6511523886391, 12.689150039455935, 11.726998452458334, 10.815821154872122, 9.858292327301793, 8.852948596753855, 7.839396724990827, 6.782825108715417, 5.827166559892607, 4.8411192673827905, 3.879013988573428, 3.0214936157213974, 4.871799537566063, 5.818672822964198, 6.804704596966122, 7.668492172961204, 8.735226991176244, 9.690351032964989, 10.646652220834534, 11.663127468239528, 12.59496305184988, 13.576980425617144, 12.64582205781526, 11.625058244634406, 10.696489027171811, 9.756040670514619, 8.749667683348248, 7.754706884825085, 6.7701752900085355, 5.805502652252549, 4.844699201309609, 3.9857040066871536, 5.899784837442682, 6.812850941917891, 7.774026974647173, 8.669029031642845, 9.669163256227886, 10.74193699726121, 11.599195204753961, 12.554218936465075, 13.540363326440396, 14.523390449933123, 13.615322312643809, 12.56115211154836, 11.691322017381296, 10.789698132579597, 9.727758895974961, 8.690235748576974, 7.7324172435957745, 6.783675478137155, 5.911582758757401, 4.935595469553962, 6.927537832117532, 7.831869932693395, 8.805918077934372, 9.601720743810043, 10.635302105927627, 11.661938229854863, 12.606821792755737, 13.590109009490108, 14.535846419651422, 15.52110949769417, 14.481561994486022, 13.52460773456117, 12.719730356654836, 11.738012178212667, 10.752990504162529, 9.69208249410084, 8.699061978553075, 7.816953332968661, 6.9370521703728345, 5.958952217403753], [6.934818048211218, 7.784344995576669, 8.77159276727011, 9.604279315739088, 10.657746019353063, 11.662444334441913, 12.67672623736375, 13.690430163216327, 14.480093122408444, 15.44923818662437, 14.562696924800429, 13.536221334514277, 12.572278661873883, 11.58228576323178, 10.625686232377204, 9.654650405120542, 8.616149470709942, 7.933813563009023, 6.952610183536166, 6.011654610753696, 7.88093902075046, 8.760380880256825, 9.738838087050008, 10.544677394727032, 11.479830799452332, 12.457044012403134, 13.518069901051208, 14.453295632605899, 15.44004263923836, 16.362242497550376, 15.408137239541595, 14.47850423014033, 13.515499520066136, 12.534223043701385, 11.55265162518994, 10.651223440521143, 9.68826306937591, 8.872025632098934, 7.885406315058833, 6.940348914546579, 8.862122103934405, 9.761036702045638, 10.773669549741937, 11.573571267879997, 12.488934560740853, 13.44538245890244, 14.494596172420456, 15.502518110179377, 16.415466949398265, 17.295418072095277, 16.38331309229391, 15.41600367606965, 14.493466468376653, 13.544882472303945, 12.571882582437178, 11.702199065149353, 10.670208486985654, 9.84146468724202, 8.877449812525585, 7.8781154653582695, 9.895115950556821, 10.722445776884786, 11.706662443703834, 12.536081891872284, 13.441884456805521, 14.469153884988382, 15.452032749007333, 16.451117548527108, 17.39679667267522, 18.24898442295287, 17.450076821831672, 16.42400231669295, 15.460371268029558, 14.564302864919691, 13.516188743949565, 12.69336617218158, 11.623874703251786, 10.800013706468633, 9.8024773772533, 8.864969537518109, 9.727618732435412, 10.735291693383825, 11.703134267438152, 12.727744169179228, 13.691951035642507, 14.526615280591125, 15.503609670466632, 16.290687860827383, 17.273119346726663, 18.247294133285592, 18.330912539242473, 17.354094071180743, 16.4363438875064, 15.49091120267823, 14.586317618623907, 13.654950407686666, 12.604088124422773, 11.761478927219086, 10.796914231744813, 9.856323078464426, 8.780576191834921, 9.735782193331652, 10.727189206934904, 11.728730798835542, 12.696403822581965, 13.593022969768223, 14.441193189051313, 15.365439220042134, 16.338352080477687, 17.269626808863595, 18.20421679772139, 17.435340493080226, 16.453359585920616, 15.48194838520646, 14.538524964116416, 13.506378718842628, 12.531604776047123, 11.582822160793388, 10.687276605175908, 9.708370723585965, 7.787374103711557, 8.762959599893346, 9.709997651460268, 10.73952736984685, 11.704460720286631, 12.542224074168223, 13.43484638523653, 14.419345273325824, 15.377501337700512, 16.33384678190215, 17.339631972086973, 16.3847844786219, 15.454303940191433, 14.488205549891667, 13.480388769592016, 12.558216059895877, 11.598770746529878, 10.648202297146826, 9.723158289466745, 8.71932843566759, 6.820167790413415, 7.810835373312171, 8.718846651140941, 9.715434272294331, 10.648794091303776, 11.556761398326216, 12.481279044411785, 13.472836490885724, 14.477425418826282, 15.317199136055086, 16.368910373656153, 15.452345252946097, 14.522209604329447, 13.494414001447344, 12.510138927055209, 11.568045411758856, 10.634838428707459, 9.702980748428935, 8.78343912442097, 7.83224267274198, 5.891567734309258, 6.802239881479045, 7.765892264023996, 8.648279274913987, 9.617406257936878, 10.574718335626574, 11.476644789216277, 12.422009816049489, 13.402452109137988, 14.354137085705732, 15.316969875183402, 14.501177764069196, 13.579544965342055, 12.522227448439386, 11.568618725449607, 10.630879320130823, 9.64418743677765, 8.700756696633606, 7.7420679611918715, 6.8716904606612825, 4.885075689599146, 5.828049640973033, 6.730773028845652, 7.679079267419261, 8.566735978335299, 9.562922235280318, 10.54343124129752, 11.478837449524367, 12.448639141437665, 13.3840346536816, 14.337352245949353, 13.499761781313222, 12.566208740812352, 11.637681616308544, 10.61824732252688, 9.644947941946464, 8.750321998354622, 7.749062454970366, 6.7941455378272435, 5.806226296071289, 3.9184442644027095, 4.7754184221020655, 5.673090056596623, 6.680876503068666, 7.622774982841902, 8.687469576013509, 9.605614037583281, 10.622703663079312, 11.65962323791368, 12.63645166136032, 13.525394357350187, 12.469400123217948, 11.538252125111685, 10.5912827393363, 9.666082295932835, 8.68524435122423, 7.731177047647457, 6.792694579664623, 5.79502746629037, 4.794578080679469, 2.96387117005125, 3.8059230352855717, 4.735182724971989, 5.694865498267143, 6.628137759215558, 7.61569166294276, 8.585101788849876, 9.642514680968159, 10.70652171937062, 11.779812056234215, 12.776106272558195, 11.832424795866345, 10.758924627340493, 9.712425920897932, 8.691698126711513, 7.712470512025055, 6.807484202218488, 5.822936789984674, 4.912094753107608, 3.8621158690992137, 1.9566703798925347, 2.8701020926019227, 3.7997159153216016, 4.795447449741383, 5.747051226454557, 6.741787220730777, 7.715441074419791, 8.756889357928843, 9.794042416181728, 10.765400310587795, 11.824549199266386, 10.873470134864453, 9.820275636884508, 8.786515072873838, 7.792890209977684, 6.7689719720516655, 5.822858995040171, 4.852612411693417, 3.8876263450771917, 2.8758273776866763, 0.9458492675472714, 1.9070790171078849, 2.880784605082963, 3.8225240665226, 4.811855543017501, 5.876264858378925, 6.912311647909617, 7.905294356278837, 8.975711300048816, 9.952840099630876, 10.862451666307681, 9.852894557537214, 8.905493132559853, 7.942667915612212, 6.958674245790112, 6.018656569807444, 4.986165549181835, 3.9209193270223577, 2.879925564623568, 1.9372319736937222, 0.0, 0.9580333805399264, 1.953581671771858, 2.9153733145441425, 3.975165716701552, 4.9810917880075944, 6.0339553921772575, 7.078310004124959, 8.150114159358708, 9.113643605166619, 10.033594402698288, 9.034319008105284, 8.078628524872585, 7.059683134010575, 6.009700752769499, 5.042448199375199, 4.0297261639572985, 3.087236747932127, 2.1008895870608733, 1.0516424287991546, 1.0253484872578085, 1.9162003658859965, 2.898262936517052, 3.8411432935089893, 4.892120961664124, 5.866226543194523, 6.914800113481688, 7.89742148290338, 8.864844163302305, 9.809300916956765, 10.734651037190481, 10.042078725982233, 9.009319130120259, 8.054458499742518, 7.022770316357933, 5.980043614264234, 5.031862274335841, 3.986536863214668, 2.9251863565479086, 1.9910462923015921, 1.9561032947766912, 2.9816512379896505, 3.9417729223317224, 4.799076100908466, 5.798834510369909, 6.797790989870736, 7.777485266594188, 8.759499214029105, 9.71392041494538, 10.751918065762215, 11.672303276202243, 10.949093523437739, 9.99156469586741, 8.958346472568874, 7.944794600805844, 6.888222984530434, 5.883359379215799, 4.810198577858192, 3.8480932990488297, 2.9226075220683767, 2.934567563872341, 3.8814408492704766, 4.8674726232724, 5.731260199267481, 6.7979950174825206, 7.753119059271265, 8.70942024714081, 9.725895494545805, 10.65773107815616, 11.645773887939308, 12.576932255741193, 11.594137555109807, 10.665568337647212, 9.72511998099002, 8.718746993823649, 7.7237861953004865, 6.739254600483937, 5.77458196272795, 4.813778511785011, 3.886817913034133, 3.9781707730778963, 4.8756189682241695, 5.836795000953451, 6.731797057949121, 7.731931282534163, 8.804705023567486, 9.661963231060238, 10.616986962771351, 11.603131352746672, 12.5861584762394, 13.523490054945741, 12.53023142202376, 11.660401327856697, 10.758777443054997, 9.696838206450362, 8.659315059052375, 7.701496554071176, 6.752754788612557, 5.871524039888104, 4.836709375900941, 5.005923767752747, 5.894637958999673, 6.86868610424065, 7.664488770116319, 8.698070132233902, 9.724706256161138, 10.669589819062013, 11.652877035796385, 12.598614445957699, 13.65762253993482, 14.450641304961422, 13.493687045036571, 12.688809667130236, 11.707091488688068, 10.72206981463793, 9.66116180457624, 8.668141289028476, 7.786032643444063, 6.838166076719814, 5.860066123750732], [7.892851428751145, 8.742378376116596, 9.729626147810038, 10.562312696279015, 11.61577939989299, 12.62047771498184, 13.634759617903677, 14.648463543756254, 15.438126502948371, 14.508636704945772, 13.604663544260506, 12.578187953974354, 11.61424528133396, 10.624252382691857, 9.66765285183728, 8.696617024580618, 7.658116090170017, 7.122653419075501, 6.141450039602645, 6.969687991293622, 8.838972401290386, 9.718414260796752, 10.696871467589935, 11.502710775266959, 12.437864179992259, 13.415077392943061, 14.476103281591135, 15.411329013145826, 16.398076019778287, 15.404209117010453, 14.450103859001672, 13.520470849600407, 12.557466139526213, 11.576189663161461, 10.594618244650016, 9.693190059981218, 8.730229688835985, 8.060865488165412, 7.074246171125312, 7.898382295086505, 9.820155484474332, 10.719070082585565, 11.731702930281864, 12.531604648419924, 13.44696794128078, 14.403415839442367, 15.452629552960383, 16.460551490719304, 17.29021363811342, 16.337384691555354, 15.425279711753989, 14.457970295529726, 13.53543308783673, 12.586849091764021, 11.613849201897255, 10.744165684609428, 9.712175106445729, 9.030304543308498, 8.066289668592063, 8.836148845898196, 10.853149331096748, 11.083535105235491, 11.801493534104436, 12.75130469847651, 13.759801985303735, 14.593115858887806, 15.576154596162674, 16.383835003075713, 17.34000719436928, 17.290951042412946, 16.492043441291752, 15.465968936153025, 14.502337887489634, 13.606269484379768, 12.558155363409641, 11.735332791641653, 10.66584132271186, 10.085173964643529, 9.118237527817488, 9.823002918058036, 10.664351838379112, 10.045360172976403, 10.85145082774779, 11.790236421672283, 12.754443288135562, 13.589107533084182, 14.566101922959689, 15.353180113320438, 16.335611599219718, 17.309786385778647, 17.37287915870255, 16.39606069064082, 15.478310506966476, 14.532877822138307, 13.628284238083983, 12.696917027146739, 11.646054743882846, 11.046639185393982, 10.138222486694097, 10.814356459004353, 9.717309297778622, 9.04585067292423, 9.804752498805414, 10.791223051328597, 11.758896075075022, 12.655515222261279, 13.50368544154437, 14.42793147253519, 15.400844332970745, 16.33211906135665, 17.266709050214445, 17.41810426669375, 16.479670141006917, 15.574199341392394, 14.62374441710183, 13.576557223154689, 12.601783280359184, 12.009346409715508, 11.072781199218106, 10.645103829529667, 8.724107209655259, 8.03211013405206, 8.772489903953325, 9.802019622339905, 10.766952972779688, 11.60471632666128, 12.497338637729586, 13.48183752581888, 14.439993590193568, 15.396339034395204, 16.402124224580028, 17.342817859161826, 16.41233732073136, 15.446238930431594, 14.438422150131943, 13.516249440435804, 12.556804127069805, 11.606235677686753, 10.66141547800511, 9.656061541611292, 7.756900896357117, 7.021048213413742, 7.781338903633997, 8.777926524787386, 9.711286343796832, 10.619253650819273, 11.543771296904842, 12.53532874337878, 13.539917671319339, 14.379691388548142, 15.431402626149207, 16.335277039858735, 15.480242984869374, 14.452447381987271, 13.468172307595136, 12.526078792298783, 11.592871809247386, 10.661014128968862, 9.741472504960896, 8.790276053281906, 6.82830084025296, 5.948114244492157, 6.82838451651705, 7.710771527407042, 8.679898510429934, 9.63721058811963, 10.539137041709333, 11.484502068542543, 12.464944361631044, 13.416629338198788, 14.379462127676458, 15.384109550981833, 14.537578345881983, 13.480260828979313, 12.526652105989534, 11.58891270067075, 10.602220817317576, 9.658790077173531, 8.700101341731797, 7.829723841201208, 5.821808795542848, 4.973924003986145, 5.793265281338707, 6.741571519912315, 7.629228230828354, 8.625414487773375, 9.605923493790577, 10.541329702017423, 11.511131393930722, 12.446526906174656, 13.399844498442409, 14.382693568225859, 13.524242121352279, 12.595714996848471, 11.576280703066807, 10.602981322486391, 9.708355378894549, 8.707095835510291, 7.752178918367169, 6.764259676611214, 4.855177370346412, 3.9050156209634075, 4.735582309089677, 5.743368755561721, 6.6852672353349565, 7.749961828506565, 8.668106290076338, 9.685195915572368, 10.722115490406736, 11.698943913853377, 12.726085842403055, 13.427433503757875, 12.496285505651612, 11.549316119876227, 10.624115676472762, 9.643277731764156, 8.689210428187383, 7.750727960204549, 6.753060846830296, 5.752611461219395, 3.9219045505911767, 2.9355202341469138, 3.797674977465044, 4.757357750760198, 5.690630011708612, 6.678183915435815, 7.6475940413429315, 8.705006933461215, 9.769013971863677, 10.842304308727272, 11.838598525051252, 12.790458176406272, 11.71695800788042, 10.670459301437859, 9.64973150725144, 8.670503892564982, 7.765517582758414, 6.7809701705246, 5.870128133647534, 4.82014924963914, 2.9147037604324613, 1.9996992914632647, 2.8622081678146563, 3.837414069201457, 4.789017845914632, 5.783753840190852, 6.757407693879866, 7.798855977388918, 8.836009035641803, 9.80736693004787, 10.86651581872646, 11.83150351540438, 10.778309017424435, 9.744548453413765, 8.75092359051761, 7.727005352591592, 6.780892375580097, 5.810645792233343, 4.845659725617118, 3.833860758226603, 1.9038826480871978, 1.0366762159692269, 1.922751224543037, 2.8644906859826738, 3.8538221624775746, 4.918231477838999, 5.954278267369691, 6.947260975738911, 8.017677919508891, 8.99480671909095, 9.978226088351086, 10.81092793807714, 9.86352651309978, 8.900701296152139, 7.916707626330039, 6.976689950347371, 5.944198929721761, 4.878952707562284, 3.8379589451634946, 2.895265354233649, 0.9580333805399264, 0.0, 0.9955482912319316, 1.9573399340042164, 3.017132336161626, 4.023058407467667, 5.0759220116373305, 6.120276623585032, 7.192080778818781, 8.155610224626692, 9.212473158460453, 9.992352388645209, 9.03666190541251, 8.0177165145505, 6.967734133309424, 6.0004815799151245, 4.987759544497225, 4.045270128472054, 3.0589229676007994, 2.0096758093390807, 1.9833818677977348, 0.9581669853460703, 1.9402295559771254, 2.883109912969063, 3.9340875811241975, 4.908193162654597, 5.956766732941762, 6.939388102363455, 7.906810782762379, 8.85126753641684, 9.776617656650556, 10.71282552679034, 9.967352510660184, 9.012491880282443, 7.980803696897858, 6.93807699480416, 5.989895654875767, 4.944570243754594, 3.8832197370878347, 2.9490796728415183, 2.914136675316618, 2.0236178574497243, 2.983739541791796, 3.8410427203685398, 4.840801129829983, 5.8397576093308095, 6.819451886054262, 7.801465833489178, 8.755887034405452, 9.793884685222288, 10.714269895662317, 11.716612439691975, 10.949598076407334, 9.916379853108797, 8.90282798134577, 7.846256365070359, 6.841392759755724, 5.768231958398118, 4.806126679588756, 3.880640902608303, 3.8926009444122673, 3.0702807053369554, 4.051053286428807, 4.773226818727555, 5.839961636942594, 6.795085678731339, 7.751386866600885, 8.76786211400588, 9.699697697616234, 10.687740507399381, 11.618898875201266, 12.552170935649734, 11.623601718187139, 10.683153361529946, 9.676780374363576, 8.681819575840413, 7.697287981023863, 6.732615343267876, 5.771811892324937, 4.8448512935740595, 4.9362041536178225, 4.064458824290648, 5.02563485701993, 5.773763677409196, 6.7738979019942365, 7.846671643027561, 8.703929850520314, 9.658953582231428, 10.645097972206749, 11.628125095699476, 12.565456674405818, 13.488264802563688, 12.618434708396624, 11.716810823594924, 10.65487158699029, 9.617348439592302, 8.659529934611102, 7.710788169152483, 6.829557420428031, 5.7947427564408684, 5.963957148292673, 5.083477815066152, 6.057525960307129, 6.706455389576393, 7.740036751693976, 8.766672875621213, 9.71155643852209, 10.694843655256461, 11.640581065417775, 12.699589159394897, 13.510039823282824, 14.451720425576498, 13.646843047670163, 12.665124869227995, 11.680103195177857, 10.619195185116167, 9.626174669568403, 8.74406602398399, 7.796199457259741, 6.818099504290659], [8.888399719983076, 9.737926667348527, 10.725174439041968, 11.557860987510947, 12.611327691124922, 13.616026006213772, 14.63030790913561, 15.497389673087532, 14.457851869347616, 13.51308841371384, 12.609115253028573, 11.582639662742421, 10.618696990102027, 9.628704091459925, 8.672104560605348, 7.701068733348686, 6.662567798938086, 6.251638178761269, 7.136998330834576, 7.965236282525553, 9.834520692522316, 10.713962552028683, 11.692419758821865, 12.49825906649889, 13.433412471224191, 14.410625684174994, 15.471651572823067, 16.40687730437776, 15.42977685497407, 14.40866082577852, 13.45455556776974, 12.524922558368475, 11.56191784829428, 10.580641371929529, 9.599069953418084, 8.697641768749287, 7.734681397604054, 7.195384969586582, 8.069794462357242, 8.893930586318437, 10.815703775706263, 11.714618373817496, 11.855070405336821, 12.718267031236863, 13.717203590136469, 14.621338993741817, 15.538042881517619, 16.445237374402804, 16.29466534688149, 15.341836400323423, 14.429731420522057, 13.462422004297794, 12.539884796604797, 11.591300800532089, 10.618300910665322, 9.748617393377497, 8.716626815213798, 8.165663240161598, 9.061837959823993, 9.831697137130126, 11.848697622328679, 11.79016190969155, 10.805945242872502, 11.755756407244576, 12.764253694071801, 13.597567567655876, 14.580606304930743, 15.38828671184378, 16.344458903137348, 16.295402751181015, 15.49649515005982, 14.470420644921093, 13.506789596257702, 12.610721193147835, 11.562607072177709, 10.739784500409723, 9.670293031479929, 9.220532661496629, 10.113785819049419, 10.818551209289966, 11.460926246218252, 10.757713270869859, 9.855902536515856, 10.794688130440349, 11.758894996903628, 12.59355924185225, 13.570553631727757, 14.357631822088505, 15.340063307987784, 16.314238094546713, 16.37733086747062, 15.400512399408887, 14.482762215734544, 13.537329530906375, 12.632735946852051, 11.701368735914809, 10.650506452650916, 10.181997882247082, 11.133770777926028, 11.809904750236283, 10.513883705617761, 9.758203770817685, 8.80920420757348, 9.795674760096663, 10.76334778384309, 11.659966931029347, 12.508137150312438, 13.432383181303258, 14.405296041738813, 15.336570770124716, 16.27116075898251, 16.422555975461815, 15.484121849774983, 14.578651050160461, 13.6281961258699, 12.581008931922758, 11.606234989127254, 11.230058816679053, 12.068329490450036, 11.441678237368807, 9.520681617494398, 8.744463231945515, 7.776941612721392, 8.806471331107973, 9.771404681547756, 10.609168035429347, 11.501790346497653, 12.486289234586948, 13.444445298961636, 14.400790743163272, 15.406575933348096, 16.371531696631195, 16.529432495612163, 15.485040770814207, 14.477223990514556, 13.498514332010497, 12.539069018644499, 12.164678680325615, 11.457989885844249, 10.452635949450432, 8.553475304196256, 7.7334013113071975, 6.785790612402065, 7.7823782335554545, 8.7157380525649, 9.62370535958734, 10.54822300567291, 11.539780452146848, 12.544369380087407, 13.38414309731621, 14.435854334917275, 15.339728748626802, 16.29088917623204, 15.390593512368639, 14.406318437976504, 13.46422492268015, 12.516900332781491, 11.585042652502967, 10.605404157670776, 9.614147845927327, 7.624875248092099, 6.7446886523312966, 5.832836225285118, 6.7152232361751105, 7.684350219198002, 8.641662296887699, 9.5435887504774, 10.488953777310613, 11.469396070399112, 12.421081046966856, 13.383913836444526, 14.3885612597499, 15.348224537244645, 14.422245994247765, 13.468637271257986, 12.530897865939203, 11.526249340851681, 10.582818600707636, 9.624129865265902, 8.676647126625678, 6.618383203381987, 5.770498411825285, 4.797716990106775, 5.746023228680384, 6.633679939596422, 7.6298661965414425, 8.610375202558645, 9.54578141078549, 10.51558310269879, 11.450978614942724, 12.404296207210477, 13.387145276993927, 14.39953858682705, 13.57581495440147, 12.556380660619805, 11.583081280039389, 10.63238390242865, 9.631124359044396, 8.676207441901273, 7.688288200145317, 5.651751778185551, 4.7015900288025465, 3.740034017857746, 4.74782046432979, 5.689718944103024, 6.754413537274633, 7.672557998844406, 8.689647624340436, 9.726567199174804, 10.703395622621445, 11.730537551171123, 12.786531785303362, 13.47638546320461, 12.529416077429225, 11.60421563402576, 10.623377689317154, 9.613238951721485, 8.674756483738651, 7.677089370364399, 6.676639984753498, 4.801640213849904, 3.732094641986053, 2.802126686233112, 3.7618094595282665, 4.695081720476681, 5.682635624203884, 6.652045750111, 7.709458642229284, 8.773465680631745, 9.84675601749534, 10.84305023381932, 11.832800038364418, 12.697057965433418, 11.650559258990857, 10.629831464804438, 9.65060385011798, 8.745617540311411, 7.761070128077597, 6.81963898183922, 5.769660097830826, 3.8091991336241424, 2.7962736993024033, 1.8666598765827245, 2.841865777969525, 3.7934695546826998, 4.78820554895892, 5.761859402647934, 6.803307686156986, 7.840460744409871, 8.811818638815938, 9.870967527494528, 10.869259137647285, 11.758408974977433, 10.724648410966763, 9.731023548070608, 8.70710531014459, 7.760992333133094, 6.79074574978634, 5.825759683170115, 4.783371606418289, 2.8994309393191293, 1.9643692718255044, 0.9272029333111053, 1.868942394750742, 2.858273871245643, 3.9226831866070673, 4.95872997613776, 5.95171268450698, 7.02212962827696, 7.99925842785902, 8.982677797119155, 9.992234905889624, 10.859074804331712, 9.896249587384071, 8.912255917561971, 7.972238241579303, 6.939747220953693, 5.874500998794216, 4.833507236395426, 3.89081364546558, 1.953581671771858, 0.9955482912319316, 0.0, 0.9617916427722848, 2.021584044929694, 3.027510116235736, 4.080373720405399, 5.124728332353101, 6.19653248758685, 7.160061933394761, 8.216924867228522, 9.216200261821527, 10.032210196644442, 9.013264805782432, 7.963282424541356, 6.996029871147057, 5.983307835729156, 5.040818419703985, 4.054471258832731, 3.0052241005710125, 2.9789301590296664, 1.9537152765780017, 1.06448274139633, 1.8875616217371318, 2.938539289892266, 3.9126448714226663, 4.961218441709831, 5.943839811131523, 6.911262491530447, 7.8557192451849085, 8.781069365418624, 9.717277235558408, 10.750036831420381, 10.008040171514375, 8.97635198812979, 7.933625286036092, 6.985443946107699, 5.940118534986525, 4.878768028319766, 3.94462796407345, 3.909684966548549, 3.0191661486816557, 2.107992727211, 2.8454944291366084, 3.8452528385980522, 4.844209318098878, 5.8239035948223306, 6.805917542257247, 7.76033874317352, 8.798336393990354, 9.718721604430385, 10.721064148460043, 11.678592976030371, 10.911928144340731, 9.898376272577702, 8.84180465630229, 7.836941050987656, 6.76378024963005, 5.801674970820687, 4.876189193840235, 4.888149235644199, 4.065828996568887, 3.175306471848012, 3.7776785274956244, 4.844413345710663, 5.799537387499408, 6.755838575368954, 7.772313822773948, 8.704149406384301, 9.692192216167449, 10.623350583969334, 11.644114397150187, 12.572683614612782, 11.678701652761879, 10.672328665595508, 9.677367867072345, 8.692836272255795, 7.728163634499808, 6.767360183556868, 5.840399584805991, 5.931752444849754, 5.06000711552258, 4.1546196167056975, 4.778215386177265, 5.778349610762305, 6.8511233517956285, 7.708381559288382, 8.663405290999496, 9.649549680974816, 10.632576804467543, 11.569908383173885, 12.58020826406414, 13.567516604822266, 12.712359114826857, 11.650419878222221, 10.612896730824234, 9.655078225843035, 8.706336460384414, 7.825105711659962, 6.790291047672799, 6.959505439524604, 6.079026106298083, 5.186510719992897, 5.710907098344462, 6.744488460462046, 7.771124584389282, 8.716008147290157, 9.699295364024529, 10.645032774185843, 11.704040868162965, 12.514491532050892, 13.471445791975743, 14.518870371631232, 13.660673160459929, 12.67565148640979, 11.6147434763481, 10.621722960800335, 9.73961431521592, 8.791747748491671, 7.81364779552259], [9.77062488812199, 10.620151835487441, 11.61349417103143, 12.512965924230482, 13.566432627844456, 14.571130942933307, 15.542201509183572, 14.53559803031525, 13.496060226575333, 12.551296770941557, 11.647323610256288, 10.620848019970136, 9.656905347329742, 8.66691244868764, 7.710312917833063, 6.739277090576401, 5.700776156165801, 6.712968115314641, 7.761515355926514, 8.781151826320283, 10.530850717939956, 11.475934812293215, 12.454392019086397, 12.96016051652404, 13.89531392124934, 14.744872157198055, 15.666754877714542, 15.454732218834247, 14.467985212201786, 13.446869183006235, 12.492763924997455, 11.56313091559619, 10.600126205521995, 9.618849729157244, 8.637278310645799, 7.735850125977001, 6.772889754831769, 7.656714906139955, 8.643334223180055, 9.590260611736076, 11.512033801123902, 12.476590634082028, 12.816862048109108, 11.931266643371075, 12.906672312539692, 13.756533710698749, 14.643153206226792, 15.55034769911198, 15.332873704109206, 14.380044757551138, 13.467939777749772, 12.50063036152551, 11.578093153832512, 10.629509157759804, 9.656509267893037, 8.786825750605212, 7.754835172441513, 8.62699317671497, 9.591008051431405, 10.528027162547765, 12.54502764774632, 12.751953552463837, 11.767736885644789, 10.968756019378787, 11.953722416475024, 12.732762284612807, 13.685716629639916, 14.493397036552954, 15.449569227846522, 15.33361110840873, 14.534703507287535, 13.508629002148808, 12.544997953485417, 11.64892955037555, 10.600815429405424, 9.77799285763744, 8.708501388707646, 9.646631010697195, 10.64295591065683, 11.514881234707605, 12.422717888990535, 11.719504913642144, 10.817694179288143, 9.929882847397282, 10.894089713860561, 11.72875395880918, 12.675663956436932, 13.46274214679768, 14.445173632696958, 15.41934841925589, 15.415539224698332, 14.438720756636602, 13.52097057296226, 12.57553788813409, 11.670944304079766, 10.739577093142525, 9.688714809878633, 10.608096231447648, 11.58533313598596, 12.506234775653922, 11.475675348390045, 10.71999541358997, 9.770995850345766, 8.930869477053596, 9.898542500800021, 10.795161647986278, 11.613247475021613, 12.537493506012433, 13.510406366447988, 14.441681094833891, 15.376271083691686, 15.46076433268953, 14.522330207002698, 13.616859407388176, 12.666404483097617, 11.619217289150475, 10.64444334635497, 11.65615716587962, 12.51989184850997, 12.40346988014109, 10.482473260266682, 9.7062548747178, 8.738733255493678, 7.9416660480649055, 8.906599398504687, 9.744362752386278, 10.606900671206828, 11.591399559296123, 12.54955562367081, 13.505901067872447, 14.51168625805727, 15.476642021340368, 15.567640852839876, 14.523249128041924, 13.515432347742273, 12.536722689238214, 11.577277375872216, 12.590777029526182, 12.419781528616532, 11.414427592222715, 9.51526694696854, 8.695192954079483, 7.74758225517435, 6.917572950512386, 7.850932769521831, 8.758900076544272, 9.653333330382084, 10.644890776856023, 11.649479704796581, 12.489253422025385, 13.54096465962645, 14.444839073335977, 15.395999500941212, 15.414902873281783, 14.430627798889647, 13.488534283593294, 12.541209693694634, 12.54683429527525, 11.56719580044306, 10.57593948869961, 8.586666890864382, 7.70648029510358, 6.794627868057403, 5.850417953132042, 6.819544936154934, 7.776857013844629, 8.648699075186576, 9.594064102019786, 10.574506395108287, 11.526191371676031, 12.4890241611537, 13.493671584459076, 14.45333486195382, 15.384037637020048, 14.43042891403027, 13.492689508711486, 12.488040983623964, 11.54461024347992, 10.585921508038185, 9.638438769397961, 7.5801748461542715, 6.732290054597568, 5.75950863287906, 4.8812179456373155, 5.768874656553353, 6.765060913498374, 7.71548552726782, 8.650891735494666, 9.620693427407964, 10.556088939651898, 11.509406531919652, 12.492255601703102, 13.504648911536226, 14.438201756305787, 13.51817230339209, 12.544872922811674, 11.594175545200933, 10.592916001816679, 9.637999084673556, 8.6500798429176, 6.613543420957835, 5.663381671574831, 4.70182566063003, 3.8830151812867206, 4.824913661059956, 5.859523861983809, 6.7776683235535815, 7.794757949049612, 8.831677523883979, 9.80850594733062, 10.835647875880298, 11.891642110012537, 12.8227901081188, 13.49120772020151, 12.566007276798045, 11.585169332089439, 10.575030594493768, 9.636548126510935, 8.638881013136682, 7.638431627525781, 5.763431856622188, 4.693886284758337, 3.7639183290053966, 2.8669197842374423, 3.800192045185857, 4.787745948913059, 5.757156074820176, 6.8145689669384595, 7.878576005340921, 8.951866342204516, 9.948160558528496, 10.937910363073595, 11.991138938361445, 12.612350901763142, 11.591623107576723, 10.612395492890265, 9.707409183083696, 8.722861770849882, 7.781430624611505, 6.731451740603111, 4.770990776396427, 3.758065342074688, 2.828451519355009, 1.9356224700354963, 2.8872262467486705, 3.881962241024891, 4.855616094713905, 5.8970643782229555, 6.934217436475841, 7.905575330881907, 8.964724219560498, 9.963015829713255, 11.0162103276932, 11.686440053739048, 10.692815190842893, 9.668896952916874, 8.72278397590538, 7.752537392558625, 6.7875513259424, 5.745163249190574, 3.861222582091414, 2.926160914597789, 1.8889945760833902, 0.962699086816713, 1.9520305633116137, 3.0164398786730384, 4.052486668203731, 5.04546937657295, 6.115886320342931, 7.093015119924991, 8.076434489185127, 9.085991597955594, 10.033393022932955, 10.858041230156356, 9.874047560334256, 8.934029884351588, 7.901538863725978, 6.836292641566501, 5.795298879167711, 4.852605288237865, 2.9153733145441425, 1.9573399340042164, 0.9617916427722848, 0.0, 1.0597924021574092, 2.065718473463451, 3.118582077633114, 4.162936689580816, 5.234740844814565, 6.198270290622476, 7.255133224456237, 8.254408619049242, 9.21009910228194, 9.975056448554717, 8.925074067313641, 7.957821513919342, 6.945099478501441, 6.00261006247627, 5.016262901605016, 3.967015743343297, 3.940721801801951, 2.898843395988262, 1.9167808253572067, 0.9257699789648469, 1.9767476471199816, 2.9508532286503817, 3.9994267989375465, 4.982048168359239, 5.949470848758163, 6.893927602412624, 7.819277722646341, 8.755485592786124, 9.788245188648098, 10.798786681100859, 9.938143630902076, 8.895416928808377, 7.947235588879982, 6.901910177758809, 5.84055967109205, 4.906419606845734, 4.871476609320834, 3.9058116514679835, 2.867489715895494, 1.8837027863643236, 2.883461195825767, 3.882417675326593, 4.8621119520500455, 5.844125899484962, 6.798547100401235, 7.83654475121807, 8.756929961658102, 9.75927250568776, 10.716801333258088, 11.750019556556625, 10.860167915349985, 9.803596299074574, 8.79873269375994, 7.725571892402334, 6.763466613592971, 5.837980836612519, 5.768882335441494, 4.822009050043358, 3.835977276041435, 2.8158868847233394, 3.8826217029383785, 4.8377457447271235, 5.79404693259667, 6.810522180001664, 7.742357763612016, 8.730400573395164, 9.661558941197049, 10.6823227543779, 11.610891971840495, 12.551340328497687, 11.627433602315042, 10.63247280379188, 9.647941208975329, 8.683268571219342, 7.722465120276402, 6.722624752944904, 6.787925363258271, 5.7145149561177115, 4.75333892338843, 3.8164237434049797, 4.816557967990021, 5.889331709023345, 6.746589916516098, 7.701613648227212, 8.687758038202533, 9.67078516169526, 10.608116740401602, 11.618416621291853, 12.60572496204998, 13.609364347670454, 12.605524814941756, 11.568001667543768, 10.610183162562569, 9.661441397103948, 8.707330879798876, 7.672516215811713, 7.779475467768635, 6.733533946893215, 5.741311027389813, 4.749115455572177, 5.782696817689761, 6.809332941616997, 7.754216504517873, 8.737503721252246, 9.68324113141356, 10.742249225390681, 11.552699889278609, 12.50965414920346, 13.557078728858949, 14.54886885641411, 13.630756423129323, 12.569848413067634, 11.57682789751987, 10.686463757287514, 9.673972916630586, 8.695872963661504], [10.8304172902794, 11.67994423764485, 12.67328657318884, 13.572758326387891, 14.096216908849481, 14.908134891941947, 14.649401074784729, 13.642797595916406, 12.60325979217649, 11.658496336542711, 10.860799127578074, 9.834323537291922, 8.870380864651528, 7.880387966009425, 6.953964863832795, 5.982929036576132, 6.76056855832321, 7.772760517472051, 8.821307758083924, 9.840944228477692, 11.590643120097365, 12.535727214450624, 13.514184421243806, 13.874867806744575, 13.108638172867325, 13.862179585510846, 14.758980647675234, 14.566926039237234, 13.580179032604773, 12.650650039457961, 11.70623944231924, 10.776606432917976, 9.813601722843782, 8.83232524647903, 7.880930256645531, 7.048502795348578, 7.832682156989178, 8.716507308297365, 9.703126625337465, 10.650053013893485, 12.571826203281312, 13.536383036239437, 13.794253566856842, 12.84597393359161, 12.099534411578803, 12.87384113901154, 13.735378976187484, 14.64257346907267, 14.536654560560931, 13.583825614002864, 12.681415295071558, 11.714105878847295, 10.803027490028404, 9.854443493955696, 8.900161213892769, 8.099478419976789, 8.814627574598923, 9.68678557887238, 10.650800453588815, 11.587819564705175, 13.60482004990373, 13.72934507121157, 12.745128404392522, 11.883463309599323, 11.146584515514135, 11.850069712925599, 12.777942399600608, 13.585622806513644, 14.541794997807212, 14.537391964860456, 13.748179024609321, 12.726469583325736, 11.769932289681309, 10.892581496375282, 9.844467375405156, 9.114481238682249, 9.768293790865055, 10.706423412854605, 11.70274831281424, 12.574673636865015, 13.40223427484962, 12.69689643238988, 11.795085698035876, 10.844590137617818, 10.08695181289967, 10.846061387121974, 11.767889726397621, 12.55496791675837, 13.537399402657648, 14.51157418921658, 14.633379805875261, 13.65656133781353, 12.74590490915815, 11.819189834133821, 10.914596250079498, 10.076065474187335, 10.748507212036042, 11.667888633605058, 12.64512553814337, 13.566027177811332, 12.45519173424913, 11.697386932337706, 10.7483873690935, 9.845576767274132, 9.015849929112816, 9.912469076299072, 10.705473244982302, 11.629719275973123, 12.602632136408678, 13.53390686479458, 14.468496853652375, 14.678604913866458, 13.74726454319859, 12.860511353387908, 11.944054126867375, 11.03468690302456, 11.70423574851238, 12.71594956803703, 13.579684250667379, 13.382986266000175, 11.461989646125767, 10.683646393465535, 9.716124774241411, 8.85637333828544, 8.023906826817482, 8.861670180699072, 9.699126441167518, 10.683625329256813, 11.6417813936315, 12.598126837833137, 13.60391202801796, 14.56886779130106, 14.792575189035768, 13.8542541887027, 13.002190321391774, 12.026786712567526, 12.637069778029625, 13.650569431683591, 13.399297914475618, 12.3939439780818, 10.494783332827625, 9.672584472827218, 8.724973773922084, 7.832280240732921, 6.968240197834627, 7.876207504857066, 8.745559100342774, 9.737116546816713, 10.741705474757271, 11.581479191986075, 12.63319042958714, 13.537064843296667, 14.488225270901903, 14.922414418283049, 13.972440163928582, 13.042767183347028, 13.601002095852044, 13.526350681134335, 12.546712186302145, 11.555455874558696, 9.566183276723468, 8.685996680962667, 7.772019386805138, 6.765125243352577, 5.936852364467729, 6.894164442157424, 7.740924845147266, 8.686289871980478, 9.666732165068977, 10.618417141636721, 11.58124993111439, 12.585897354419766, 13.54556063191451, 14.488026548797942, 14.917672680293844, 13.97993327497506, 13.46755736948305, 12.524126629339005, 11.56543789389727, 10.617955155257047, 8.559691232013357, 7.711806440456655, 6.736900151626795, 5.79592523585785, 4.886182084866149, 5.882368341811169, 6.80771129722851, 7.743117505455356, 8.712919197368654, 9.648314709612588, 10.601632301880342, 11.584481371663792, 12.596874681496915, 13.530427526266477, 14.497688689251177, 13.524389308670761, 12.573691931060019, 11.572432387675764, 10.617515470532641, 9.629596228776688, 7.593059806816921, 6.642898057433917, 5.6792171793777655, 4.797722471507256, 3.942221089372751, 4.95931153611238, 5.8698940935142705, 6.886983719010301, 7.923903293844668, 8.90073171729131, 9.916144178783268, 10.956011043006848, 11.887159041113112, 12.834128426888496, 13.545523662657132, 12.564685717948526, 11.554546980352855, 10.616064512370022, 9.61839739899577, 8.617948013384868, 6.742948242481274, 5.673402670617423, 4.741309847753132, 3.7816270744579774, 2.8999797193144277, 3.88753362304163, 4.849381844780865, 5.9067947368991485, 6.92744083201508, 7.944466438933105, 8.940760655257085, 9.930510459802184, 10.976548399057771, 12.018072605856995, 12.57113949343581, 11.591911878749352, 10.686925568942783, 9.702378156708969, 8.760947010470591, 7.710968126462197, 5.750507162255514, 4.737581727933774, 3.8079679052140953, 2.8503297602560314, 1.872635707444996, 2.867371701721216, 3.84102555541023, 4.882473838919282, 5.919626897172167, 6.890984791578233, 7.950133680256823, 8.948425290409581, 10.001619788389526, 11.018946006127118, 11.67233157670198, 10.648413338775962, 9.702300361764467, 8.732053778417711, 7.767067711801486, 6.72467963504966, 4.866907050017489, 3.9056773004568752, 2.8685109619424765, 1.9267715005028396, 0.937440024007939, 2.0018493393693637, 3.037896128900056, 4.030878837269276, 5.101295781039256, 6.073580408086565, 7.056999777346701, 8.06655688611717, 9.01395831109453, 9.976783528042171, 10.879732028260332, 9.939714352277663, 8.907223331652053, 7.841977109492576, 6.800983347093786, 5.85828975616394, 3.975165716701552, 3.017132336161626, 2.021584044929694, 1.0597924021574092, 0.0, 1.005926071306042, 2.0587896754757056, 3.103144287423407, 4.174948442657156, 5.138477888465067, 6.195340822298828, 7.1946162168918315, 8.15030670012453, 9.16925209098654, 9.98486646947105, 9.017613916076751, 8.004891880658851, 7.06240246463368, 6.076055303762425, 5.0268081455007065, 5.00051420395936, 3.9586357981456715, 2.976573227514616, 1.9855623811222562, 1.0404460460996432, 2.014551627630043, 3.063125197917208, 4.045746567338901, 5.0131692477378245, 5.957626001392286, 6.882976121626002, 7.819183991765786, 8.85194358762776, 9.862485080080521, 10.925332799593127, 9.955209330965786, 9.007027991037392, 7.961702579916219, 6.90035207324946, 5.966212009003144, 5.931269011478244, 4.965604053625393, 3.9272821180529034, 2.943495188521733, 2.1003259054958816, 2.9640931622186906, 3.9437874389421426, 4.925801386377059, 5.880222587293332, 6.918220238110167, 7.8206283606377625, 8.822970904667422, 9.78049973223775, 10.813717955536287, 11.827269827299315, 10.863388701231983, 9.858525095917349, 8.785364294559743, 7.823259015750381, 6.897773238769928, 6.828674737598903, 5.881801452200768, 4.895769678198844, 3.875679286880749, 3.124102943141493, 4.015782020403902, 4.934568536875171, 5.895756970955887, 6.8240332505041135, 7.812076060287261, 8.743234428089146, 9.763998241269999, 10.692567458732594, 11.633015815389786, 12.639388802556157, 11.692265205949289, 10.707733611132738, 9.743060973376751, 8.782257522433811, 7.782417155102314, 7.8477177654156804, 6.774307358275121, 5.8131313255458394, 4.876216145562389, 4.058039208193136, 5.073049665779059, 5.8871115207945985, 6.842135252505713, 7.828279642481033, 8.81130676597376, 9.715316306002757, 10.700092108183952, 11.687400448942078, 12.691039834562552, 13.632128840608544, 12.627794069701178, 11.669975564719978, 10.721233799261357, 9.767123281956286, 8.732308617969123, 8.839267869926045, 7.793326349050624, 6.801103429547222, 5.8089078577295865, 5.025630681595021, 6.052266805522257, 6.894738108796374, 7.878025325530746, 8.823762735692059, 9.88277082966918, 10.659899454879763, 11.616853714804616, 12.664278294460106, 13.656068422015267, 14.641090096065405, 13.629640815225043, 12.63662029967728, 11.746256159444924, 10.733765318787995, 9.755665365818913], [11.836343361585442, 12.685870308950893, 13.679212644494882, 14.578684397693934, 14.991728624256933, 14.110889104418542, 13.665156877012654, 12.658553398144331, 11.619015594404415, 10.674252138770639, 9.876554929806, 8.850079339519848, 7.886136666879454, 6.896143768237351, 6.135599865459908, 6.8454879578552115, 7.766494629629252, 8.778686588778093, 9.827233829389966, 10.846870299783735, 12.596569191403407, 13.541653285756666, 14.520110492549849, 14.880793878050614, 14.004149888274776, 13.064933797987441, 13.888222567305842, 13.58268184146516, 12.595934834832699, 11.666405841685888, 10.721995244547166, 9.792362235145902, 8.829357525071707, 7.848081048706955, 7.062565258272644, 7.911061716627658, 8.83860822829522, 9.722433379603407, 10.709052696643507, 11.655979085199528, 13.577752274587354, 14.54230910754548, 14.80017963816288, 13.851900004897649, 12.995046126986255, 12.076595351488136, 12.864620895818092, 13.77181538870328, 13.552410362788859, 12.59958141623079, 11.697171097299483, 10.72986168107522, 9.81878329225633, 8.870199296183621, 8.081796215519882, 8.962037341255868, 9.820553645904964, 10.692711650178422, 11.656726524894857, 12.593745636011217, 14.610746121209772, 14.73527114251761, 13.751054475698561, 12.889389380905362, 12.042096230921587, 11.052823925402194, 11.907184319231217, 12.714864726144254, 13.671036917437823, 13.553147767088383, 12.763934826837247, 11.742225385553661, 10.785688091909234, 9.917059505151265, 9.026102377032268, 9.977040159961328, 10.774219862171094, 11.712349484160644, 12.708674384120282, 13.580599708171057, 14.408160346155663, 13.70282250369592, 12.801011769341915, 11.850516208923857, 10.982463528307122, 10.04881559959857, 10.897131646028232, 11.68420983638898, 12.666641322288259, 13.640816108847194, 13.649135608103187, 12.672317140041455, 11.761660711386076, 10.843667842909804, 10.09623125170661, 10.938624395466414, 11.754433283342081, 12.673814704911097, 13.651051609449409, 14.571953249117374, 13.461117805555173, 12.703313003643746, 11.75431344039954, 10.85150283858017, 10.021776000418859, 9.115223288775667, 9.834715164612913, 10.758961195603733, 11.731874056039288, 12.663148784425195, 13.59773877328299, 13.694360716094383, 12.763020345426515, 11.884989362163891, 11.125689128494487, 11.89724582430364, 12.710161819818419, 13.721875639343068, 14.585610321973418, 14.388912337306218, 12.46791571743181, 11.689572464771576, 10.722050845547452, 9.86229940959148, 9.029832898123525, 8.064424393175667, 8.828368360798128, 9.812867248887423, 10.771023313262111, 11.72736875746375, 12.733153947648574, 13.698109710931671, 13.808330991263693, 12.878732197478683, 12.183825323018887, 12.889345633846606, 13.642995849335664, 14.65649550298963, 14.40522398578166, 13.399870049387843, 11.500709404133667, 10.678510544133259, 9.730899845228125, 8.838206312038961, 7.974166269140669, 7.078961717333661, 7.874801019973385, 8.866358466447323, 9.870947394387885, 10.710721111616689, 11.762432349217754, 12.666306762927281, 13.617467190532516, 13.946892427059032, 13.154075165555694, 13.905326104626107, 14.606928167158083, 14.532276752440378, 13.552638257608187, 12.561381945864738, 10.57210934802951, 9.69192275226871, 8.777945458111178, 7.771051314658618, 6.942778435773771, 6.0969186546340195, 6.870166764777878, 7.815531791611089, 8.79597408469959, 9.747659061267335, 10.710491850745004, 11.71513927405038, 12.674802551545124, 13.617268468428556, 14.169677068105281, 14.84249219625414, 14.473483440789092, 13.530052700645047, 12.571363965203313, 11.623881226563089, 9.5656173033194, 8.717732511762698, 7.742826222932836, 6.801851307163892, 5.892108156172191, 5.085122554287764, 5.936953216859122, 6.872359425085968, 7.842161116999267, 8.777556629243202, 9.730874221510955, 10.713723291294405, 11.72611660112753, 12.65966944589709, 13.73441423628033, 14.530315379976804, 13.579618002366061, 12.578358458981807, 11.623441541838684, 10.63552230008273, 8.598985878122964, 7.648824128739959, 6.685143250683807, 5.803648542813297, 4.9481471606787935, 4.129183925943017, 4.999136013144883, 6.016225638640914, 7.053145213475281, 8.029973636921921, 9.04538609841388, 10.08525296263746, 10.930434932375322, 11.877404318150706, 12.802604761554171, 13.570611789254569, 12.560473051658898, 11.621990583676064, 10.624323470301812, 9.623874084690911, 7.748874313787317, 6.679328741923466, 5.7472359190591735, 4.7875531457640195, 3.9059057906204697, 3.057406012872267, 3.978623764411478, 5.036036656529761, 6.056682751645692, 7.073708358563717, 8.070002574887697, 9.059752379432796, 9.976031574348994, 11.012146534550952, 11.92255378282018, 12.597837950055395, 11.692851640248826, 10.708304228015011, 9.766873081776634, 8.716894197768239, 6.756433233561556, 5.743507799239817, 4.813893976520138, 3.8562558315620734, 2.8785617787510382, 1.9966136213518284, 2.9702674750408424, 4.011715758549894, 5.048868816802779, 6.020226711208845, 7.0793755998874355, 8.077667210040193, 9.001102963680749, 10.013019934821076, 10.893649122955425, 11.654339410082004, 10.708226433070509, 9.737979849723754, 8.772993783107529, 7.7306057063557025, 5.872833121323532, 4.911603371762918, 3.8744370332485185, 2.9326975718088817, 1.943366095313981, 1.0354509798126186, 2.0714977693433108, 3.0644804777125305, 4.10200797569232, 5.067654336780523, 6.0510737060406585, 7.060630814811127, 8.008032239788488, 8.970857456736129, 9.954851126558228, 10.894868802540897, 9.913149402958094, 8.847903180798617, 7.806909418399829, 6.864215827469983, 4.981091788007594, 4.023058407467667, 3.027510116235736, 2.065718473463451, 1.005926071306042, 0.0, 1.0528636041696633, 2.0972182161173647, 3.169022371351114, 4.132551817159024, 5.1894147509927855, 6.188690145585789, 7.144380628818487, 8.163326019680497, 9.213308400921573, 10.023539987382792, 9.010817951964892, 8.06832853593972, 7.081981375068467, 6.032734216806748, 6.006440275265402, 4.964561869451713, 3.982499298820658, 2.991488452428298, 2.0044130113883685, 1.0303074298579686, 2.0788810001451337, 3.0595473745978934, 4.026970054996817, 4.9714268086512785, 5.896776928884995, 6.8329847990247785, 7.865744394886752, 8.876285887339513, 9.939133606852119, 10.961135402271827, 10.012954062343434, 8.967628651222261, 7.906278144555501, 6.972138080309185, 6.937195082784285, 5.9715301249314345, 4.933208189358945, 3.9494212598277745, 2.9788054439474427, 1.9798489644466164, 2.9595432411700684, 3.941557188604985, 4.895978389521258, 5.933976040338093, 6.834429167896756, 7.8367717119264135, 8.794300539496742, 9.827518762795279, 10.841070634558307, 11.869314772538026, 10.864451167223391, 9.791290365865786, 8.829185087056423, 7.90369931007597, 7.834600808904945, 6.887727523506809, 5.901695749504886, 4.88160535818679, 3.986661864420573, 3.0315378226318286, 3.9503243391030964, 4.911512773183813, 5.83978905273204, 6.827831862515187, 7.758990230317073, 8.779754043497924, 9.708323260960519, 10.648771617617712, 11.655144604784082, 12.650105403307245, 11.71365968243878, 10.748987044682794, 9.788183593739854, 8.788343226408356, 8.853643836721721, 7.780233429581163, 6.819057396851881, 5.882142216868431, 4.920598129472215, 4.088805468006985, 4.902867323022525, 5.857891054733639, 6.844035444708959, 7.827062568201686, 8.731072108230684, 9.715847910411878, 10.703156251170004, 11.706795636790478, 12.64788464283647, 13.585634267059135, 12.67590163602602, 11.7271598705674, 10.773049353262328, 9.738234689275165, 9.845193941232086, 8.799252420356666, 7.807029500853264, 6.814833929035628, 5.8881896028741005, 5.158295639266095, 5.9104939110243, 6.893781127758673, 7.839518537919985, 8.898526631897107, 9.67565525710769, 10.632609517032542, 11.680034096688031, 12.671824224243192, 13.65684589829333, 14.61461305934622, 13.642546370983322, 12.752182230750966, 11.739691390094038, 10.761591437124956], [12.873365947552347, 13.722892894917798, 14.716235230461788, 15.511505109454795, 14.65281119219751, 13.648112877108659, 12.697381839939231, 11.690778361070908, 10.651240557330992, 9.706477101697216, 8.92504636874489, 7.89857077845874, 6.934628105818345, 5.944635207176242, 6.8918096583461335, 7.769067101134917, 8.797010808865014, 9.809202768013854, 10.857750008625727, 11.877386479019496, 13.627085370639168, 14.572169464992427, 15.55062667178561, 15.851737636215166, 14.916584231489866, 13.97736814120253, 13.04090520783473, 12.614906804391737, 11.628159797759276, 10.698630804612465, 9.770486683486057, 8.840853674084793, 7.877848964010599, 6.896572487645846, 7.81877505115887, 8.82514493249638, 9.788105303641613, 10.752949558839168, 11.739568875879268, 12.686495264435289, 14.608268453823115, 15.57282528678124, 15.853043242332546, 14.860488533959282, 13.907480470201344, 12.989029694703225, 12.01730353634698, 12.924498029232165, 12.584635325715436, 11.631806379157368, 10.745662536238374, 9.778353120014112, 8.86727473119522, 7.918690735122513, 8.838006008406108, 9.87612055712459, 10.770050721251357, 11.723227829414183, 12.687242704130618, 13.624261815246978, 15.641262300445533, 15.788134746687275, 14.803918079868227, 13.897977909966995, 12.954530574136676, 11.965258268617283, 11.059866959760104, 11.86754736667314, 12.823719557966708, 12.58537273001496, 11.812426265776137, 10.790716824492552, 9.834179530848125, 8.965550944090158, 9.782312169918495, 10.856485376259194, 11.723716937517487, 12.661846559507037, 13.65938288872237, 14.596890728457561, 15.461023950325329, 14.755686107865584, 13.853875373511581, 12.85910473798549, 11.894897871522211, 10.961249942813659, 10.049814286557117, 10.836892476917866, 11.819323962817144, 12.793498749376077, 12.697627047042076, 11.720808578980346, 10.810152150324967, 9.892159281848697, 10.852441044592837, 11.809271400540373, 12.703930358688474, 13.62331178025749, 14.600548684795802, 15.54113983807619, 14.513981409724838, 13.75617660781341, 12.807177044569205, 11.904366442749836, 10.965264691705952, 10.027657631990756, 8.987397805141798, 9.911643836132619, 10.884556696568174, 11.815831424954078, 12.750421413811873, 12.742852155033274, 11.811511784365406, 10.933480801102784, 11.881898921380714, 12.7678928293776, 13.659658895164812, 14.671372714689461, 15.53510739731981, 15.441775941475884, 13.520779321601475, 12.74243606894124, 11.774914449717116, 10.915163013761147, 10.015596227561666, 8.999606394911558, 7.981051001327014, 8.965549889416309, 9.923705953790996, 10.880051397992634, 11.885836588177458, 12.850792351460555, 12.856822430202584, 11.927223636417576, 12.935040416717227, 13.759992638920565, 14.592492924682057, 15.605992578336023, 15.458087589951326, 14.452733653557509, 12.553573008303333, 11.731374148302923, 10.783763449397789, 9.891069916208627, 8.981883007796524, 8.014143719069551, 7.027483660502271, 8.019041106976209, 9.02363003491677, 9.863403752145572, 10.915114989746638, 11.818989403456165, 12.7701498310614, 12.995383865997924, 13.905290259254034, 14.775973109700066, 15.556425242504476, 15.585140356610044, 14.605501861777853, 13.614245550034404, 11.624972952199176, 10.744786356438372, 9.830809062280842, 8.823914918828283, 7.9956420399434345, 7.0469201896483655, 6.022849405306763, 6.968214432139974, 7.948656725228476, 8.900341701796219, 9.863174491273888, 10.867821914579263, 11.827485192074008, 12.76995110895744, 13.690608179140206, 14.62834758445899, 15.526347044958758, 14.582916304814713, 13.624227569372978, 12.676744830732755, 10.618480907489063, 9.77059611593236, 8.7956898271025, 7.854714911333556, 6.944971760341854, 6.053401907782386, 5.089635857388007, 6.025042065614853, 6.994843757528153, 7.930239269772087, 8.883556862039839, 9.866405931823289, 10.878799241656413, 11.812352086425975, 12.701906183978553, 13.655507957625893, 14.632481606535727, 13.631222063151473, 12.67630514600835, 11.688385904252394, 9.651849482292628, 8.701687732909622, 7.738006854853471, 6.856512146982961, 6.0010107648484565, 5.097463279437639, 4.151818653673769, 5.115785458104493, 6.052368820953509, 7.017603876946934, 7.998361116081527, 9.038227980305106, 9.877571328205658, 10.824540713981042, 11.749741157384507, 12.695804366903658, 13.613336655828562, 12.674854187845728, 11.677187074471476, 10.676737688860575, 8.80173791795698, 7.732192346093129, 6.8000995232288375, 5.840416749933683, 4.958769394790133, 4.10071653084748, 3.131306404940363, 4.13559647599334, 5.009657769313337, 6.026683376231363, 7.0229775925553435, 8.012727397100441, 8.92316797017933, 9.959282930381288, 10.869690178650519, 11.723030527704484, 12.681328988579104, 11.761167832184675, 10.819736685946298, 9.769757801937903, 7.809296837731219, 6.79637140340948, 5.866757580689801, 4.909119435731737, 3.9314253829207018, 3.0494772255214917, 2.1229501155697275, 3.0658920348680496, 4.001843834470424, 4.97320172887649, 6.032350617555081, 7.030642227707838, 7.948239359511085, 8.960156330651412, 9.840785518785763, 10.779531987731094, 11.725644964742589, 10.790843453893418, 9.825857387277193, 8.783469310525366, 6.925696725493195, 5.964466975932581, 4.927300637418182, 3.9855611759785456, 2.996229699483645, 2.0883145839822816, 1.0733764787943467, 2.0539180346887793, 3.0491443715226576, 4.01479073261086, 4.9982101018709955, 6.007767210641464, 6.955168635618825, 7.9179938525664655, 8.901987522388566, 9.842005198371234, 10.874496218996844, 9.900766784968281, 8.859773022569492, 7.917079431639646, 6.0339553921772575, 5.075922011637331, 4.0803737204054, 3.118582077633115, 2.0587896754757056, 1.0528636041696633, 0.0, 1.0443546119477016, 2.116158767181451, 3.0796882129893612, 4.1365511468231215, 5.135826541416125, 6.091517024648823, 7.110462415510832, 8.160444796751909, 9.127697350146208, 10.063681556134558, 9.121192140109386, 8.134844979238132, 7.085597820976412, 7.059303879435066, 6.017425473621377, 5.035362902990322, 4.044352056597962, 3.057276615558032, 2.083171034027632, 1.0492537488411717, 2.0066837704282303, 2.9741064508271546, 3.9185632044816154, 4.843913324715332, 5.780121194855115, 6.81288079071709, 7.823422283169851, 8.886270002682457, 9.928996704776155, 11.00144920821494, 10.020492255391925, 8.959141748725166, 8.02500168447885, 7.990058686953949, 7.008552710898341, 5.9702307753258514, 4.986443845794681, 3.9866854363332376, 2.9877289568324112, 2.0080346801089592, 2.990048627543876, 3.944469828460149, 4.917588937135299, 5.781565563727092, 6.7839081077567505, 7.741436935327078, 8.774655158625615, 9.788207030388644, 10.844778646664055, 11.84964225197869, 10.84415397003545, 9.882048691226087, 8.956562914245634, 8.87162339487185, 7.924750109473716, 6.938718335471792, 5.918627944153696, 4.910241007700279, 3.9551169659115337, 2.9988157780419873, 3.960004212122704, 4.888280491670931, 5.876323301454078, 6.79121519324365, 7.811979006424502, 8.740548223887096, 9.680996580544289, 10.68736956771066, 11.682330366233822, 12.666861961050373, 11.7860096306497, 10.82520617970676, 9.825365812375262, 9.889951815751683, 8.816541408611124, 7.855365375881844, 6.9184501958983935, 5.844177272751921, 5.005691974772991, 3.9513587619614152, 4.906382493672529, 5.892526883647849, 6.875554007140575, 7.763297071157261, 8.748072873338455, 9.73538121409658, 10.739020599717055, 11.680109605763047, 12.617859229985712, 13.608722347786882, 12.764182456534305, 11.810071939229234, 10.77525727524207, 10.881501920262048, 9.835560399386628, 8.837545680089026, 7.84535010827139, 6.811768746153806, 5.91450543215232, 4.958985349963191, 5.942272566697563, 6.888009976858875, 7.9470180708359965, 8.707880220034268, 9.664834479959119, 10.712259059614608, 11.704049187169769, 12.689070861219907, 13.646838022272798, 14.575367082744183, 13.789204816717872, 12.776713976060943, 11.798614023091861], [13.769062726613397, 14.618589673978848, 15.426942651048664, 14.467150497507093, 13.60845658024981, 12.603758265160959, 11.653027227991531, 10.646423749123208, 9.606885945383292, 8.662122489749516, 7.905120448633834, 6.878644858347683, 6.1402274325725665, 6.840331986237292, 7.787506437407183, 8.664763880195967, 9.692707587926064, 10.704899547074906, 11.753446787686778, 12.773083258080547, 14.52278214970022, 15.467866244053479, 16.44632345084666, 15.407548576495037, 14.544017025597604, 13.566803812646802, 12.505777923998728, 11.570552192444037, 10.583805185811576, 9.654276192664765, 8.750560763375, 7.820927753973737, 7.205794632952551, 7.792269266706896, 8.71447183021992, 9.72084171155743, 10.683802082702663, 11.64864633790022, 12.63526565494032, 13.58219204349634, 15.503965232884166, 16.46852206584229, 16.656295601864233, 15.65843024500634, 14.7054221812484, 13.786842971893572, 12.737629258375556, 11.915009647277174, 11.540280713767736, 10.587451767209668, 9.725736616127318, 8.758427199903057, 8.227354548609584, 8.814387514183561, 9.733702787467157, 10.77181733618564, 11.665747500312406, 12.618924608475234, 13.58293948319167, 14.51995859430803, 16.536959079506584, 16.629947452205176, 15.645730785386126, 14.695919621014053, 13.752472285183732, 12.763199979664343, 11.78019268178868, 10.858058984718149, 11.814231176011717, 11.54101811806726, 10.792500345665081, 9.770790904381498, 9.19425934826249, 9.861247723151205, 10.678008948979544, 11.752182155320241, 12.619413716578538, 13.557543338568088, 14.55507966778342, 15.492587507518612, 16.50537856227303, 15.664571723966178, 14.696729149911851, 13.657046449032547, 12.692839582569269, 11.759191653860716, 10.770140008585695, 9.827404094962874, 10.809835580862153, 11.766156811016737, 11.677701126931023, 10.700882658869292, 10.170231967739332, 10.787856060909744, 11.748137823653886, 12.704968179601423, 13.599627137749525, 14.519008559318541, 15.496245463856853, 16.43683661713724, 15.558336021672538, 14.800531219761112, 13.851531656516906, 12.82454238649878, 11.808735169800304, 10.871128110085108, 9.83086828323615, 8.902155454177628, 9.875068314613182, 10.788489486594738, 11.723079475452533, 11.72292623492222, 11.17159160177977, 11.829177580163831, 12.777595700441763, 13.663589608438649, 14.555355674225863, 15.567069493750513, 16.430804176380864, 16.486130553423585, 14.565133933549175, 13.786790680888942, 12.819269061664817, 11.83533895751009, 10.859066705656016, 9.843076873005908, 8.824521479421366, 7.9560615074613175, 8.914217571836005, 9.852709459633294, 10.858494649818118, 11.823450413101217, 12.216902247616948, 12.822920415478624, 13.830737195778275, 14.655689417981614, 15.488189703743108, 16.501689357397073, 16.502442201899026, 15.497088265505209, 13.597927620251033, 12.775728760250624, 11.82811806134549, 10.846110526418851, 9.825353485890874, 8.857614197163901, 7.8709541385966215, 7.009552725021217, 7.996288096557429, 8.836061813786232, 9.887773051387297, 10.791647465096824, 11.74280789270206, 12.736707363435388, 13.66185546974209, 14.521159064139319, 15.468483654037978, 16.4003413343165, 15.649856473725553, 14.658600161982104, 12.669327564146876, 11.789140968386073, 10.875163674228544, 9.868269530775983, 8.909094300888915, 7.890390667742716, 6.866319883401114, 5.940872493780633, 6.921314786869135, 7.872999763436878, 8.835832552914548, 9.840479976219923, 10.800143253714667, 11.742609170598099, 12.646253567192502, 13.583992972511286, 14.588641497598807, 15.532072237742852, 14.668582181320678, 13.721099442680455, 11.662835519436765, 10.814950727880062, 9.840044439050201, 8.899069523281256, 7.9787578170433555, 6.982571560098336, 5.933106335482358, 4.997700127255512, 5.967501819168811, 6.9028973314127455, 7.856214923680499, 8.839063993463949, 9.851457303297073, 10.785010148066634, 11.65755157203085, 12.61115334567819, 13.654364802099217, 14.644316772881945, 13.72065975795605, 12.732740516200096, 10.69620409424033, 9.746042344857324, 8.782361466801172, 7.900866758930661, 7.045365376796156, 6.026632931753588, 5.0809883059897185, 4.071430846156791, 5.0080142090058075, 5.973249264999234, 6.954006504133827, 7.993873368357407, 8.833216716257954, 9.780186102033339, 10.705386545436804, 11.651449754955955, 12.635219851392053, 13.573702319374886, 12.721541686419178, 11.721092300808277, 9.846092529904682, 8.77654695804083, 7.844454135176537, 6.884771361881383, 6.003124006737833, 5.02988618316343, 4.060476057256313, 3.0912418640456387, 3.9653031573656365, 4.982328764283663, 5.978622980607644, 6.968372785152742, 7.878813358231627, 8.914928318433587, 9.825335566702815, 10.67867591575678, 11.6369743766314, 12.621521788865214, 11.864091297893998, 10.814112413885603, 8.85365144967892, 7.8407260153571805, 6.911112192637502, 5.953474047679437, 4.975779994868402, 3.9997555621801997, 3.052119767885678, 2.021537422920348, 2.957489222522723, 3.9288471169287895, 4.98799600560738, 5.986287615760137, 6.903884747563382, 7.915801718703709, 8.79643090683806, 9.73517737578339, 10.681290352794885, 11.65153693614164, 10.870211999224892, 9.827823922473065, 7.9700513374408954, 7.0088215878802815, 5.971655249365883, 5.029915787926246, 4.0405843114313456, 3.0385929206409896, 2.0025461311102974, 1.0095634227410775, 2.004789759574956, 2.970436120663158, 3.9538554899232934, 4.963412598693761, 5.910814023671122, 6.873639240618763, 7.857632910440863, 8.797650586423531, 9.830141607049141, 10.895387829208618, 9.904127634517192, 8.961434043587346, 7.078310004124958, 6.120276623585032, 5.124728332353101, 4.162936689580816, 3.1031442874234068, 2.0972182161173647, 1.0443546119477016, 0.0, 1.0718041552337492, 2.0353336010416596, 3.0921965348754203, 4.091471929468424, 5.047162412701122, 6.066107803563131, 7.116090184804207, 8.083342738198507, 9.096064773616407, 10.038554189641578, 9.179199591185832, 8.129952432924114, 8.059383056586944, 6.991680764898336, 6.009618194267281, 5.018607347874921, 3.9676296797197863, 2.9935240981893863, 1.9449505279022214, 0.9623291584805288, 1.929751838879453, 2.874208592533914, 3.79955871276763, 4.735766582907414, 5.768526178769388, 6.779067671222149, 7.841915390734754, 8.884642092828454, 9.957094596267238, 11.00242000738841, 9.959220925877043, 9.025080861630727, 8.933752024401604, 7.9042494899593905, 6.865927554386901, 5.88214062485573, 4.882382215394287, 3.883425735893461, 2.903731459170009, 2.02474509731497, 2.91206470706475, 3.873234325187598, 4.7372109517793906, 5.739553495809049, 6.697082323379377, 7.730300546677913, 8.743852418440941, 9.800424034716352, 10.805287640030986, 11.790400948482617, 10.828295669673254, 9.902809892692801, 9.7673201739329, 8.820446888534764, 7.834415114532842, 6.814324723214746, 5.805937786761328, 4.850813744972584, 3.8945125571030372, 2.9947006818937982, 3.8558753702755313, 4.843918180058679, 5.746860581295948, 6.7676243944768, 7.696193611939394, 8.636641968596587, 9.643014955762958, 10.63797575428612, 11.622507349102671, 12.587179986858658, 11.720902958767809, 10.721062591436311, 10.785648594812733, 9.712238187672174, 8.751062154942893, 7.814146974959443, 6.73987405181297, 5.90138875383404, 4.847055541022465, 4.059722914751784, 4.871585905404371, 5.854613028897097, 6.7189424592095595, 7.703718261390753, 8.69102660214888, 9.694665987769353, 10.635754993815345, 11.57350461803801, 12.56436773583918, 13.565352812743264, 12.705768718290283, 11.67095405430312, 11.777198699323097, 10.731257178447677, 9.733242459150075, 8.74104688733244, 7.707465525214856, 6.81020221121337, 5.854682129024241, 5.095612987776818, 5.867068998615396, 6.926077092592518, 7.663525608086567, 8.620479868011419, 9.667904447666908, 10.659694575222069, 11.644716249272207, 12.602483410325096, 13.531012470796481, 14.533426079163128, 13.672410755121993, 12.694310802152911], [14.799458938930469, 15.51583583811188, 14.52249350256789, 13.56270134902632, 12.704007431769034, 11.699309116680183, 10.748578079510756, 9.741974600642433, 8.702436796902516, 7.75767334126874, 7.0006713001530585, 5.974195709866907, 6.938138382507302, 7.870728198554364, 8.817902649724255, 9.695160092513039, 10.723103800243136, 11.735295759391978, 12.78384300000385, 13.803479470397619, 15.553178362017292, 16.491871722792034, 15.553299813576732, 14.503099428014263, 13.639567877116828, 12.662354664166026, 11.601328775517953, 10.666103043963261, 9.6793560373308, 8.74982704418399, 7.846111614894225, 6.916478605492961, 7.955202623465687, 8.822665479023968, 9.744868042536991, 10.751237923874502, 11.714198295019735, 12.679042550217291, 13.665661867257391, 14.612588255813412, 16.534361445201238, 17.492527544580845, 16.52985865802512, 15.531993301167228, 14.64867163840535, 13.650693110665332, 12.62369822563826, 11.60565788092553, 10.63583156528696, 9.683002618728892, 8.821287467646542, 7.85397805142228, 8.911414029650405, 9.844783726500633, 10.76409899978423, 11.802213548502712, 12.696143712629478, 13.649320820792306, 14.613335695508741, 15.550354806625101, 17.567355291823656, 17.49621162869388, 16.511994961874834, 15.562183797502762, 14.618736461672441, 13.629464156153052, 12.64645685827739, 11.724323161206858, 10.90068612258174, 10.636568969586484, 9.888051197184305, 8.866341755900722, 9.829972804564113, 10.875081373349627, 11.708405161296616, 12.782578367637313, 13.64980992889561, 14.58793955088516, 15.585475880100493, 16.522983719835686, 17.479566808427393, 16.530835900454885, 15.56299332640056, 14.523310625521257, 13.559103759057978, 12.625455830349425, 11.636404185074404, 10.693668271451584, 9.87904167163946, 10.7140247949147, 10.773251978450247, 9.796433510388516, 10.78940156476618, 11.801689711108166, 12.778534035970958, 13.735364391918495, 14.630023350066597, 15.549404771635613, 16.526641676173927, 17.467232829454314, 16.5325242678269, 15.696467378448668, 14.718731764486165, 13.69080656298749, 12.674999346289015, 11.737392286573819, 10.69713245972486, 9.768419630666337, 8.86882300273735, 9.7363574704927, 10.670947459350495, 10.818477086441444, 11.790761198806619, 12.762172399520775, 13.807991912758835, 14.69398582075572, 15.585751886542935, 16.597465706067585, 17.461200388697936, 17.460318799577948, 15.539322179703538, 14.682726839576498, 13.715205220352374, 12.701603133998798, 11.725330882144727, 10.709341049494618, 9.690785655910076, 8.822325683950027, 7.885971970683656, 8.800577443531257, 9.80636263371608, 10.771318396999177, 11.622770212462008, 12.668607878543922, 13.56030115704515, 14.465335379685072, 15.36061181662665, 16.273758727800644, 17.239219362234238, 16.47127651165957, 14.572115866405396, 13.67166491893818, 12.724054220033047, 11.712374702907562, 10.691617662379585, 9.723878373652612, 8.737218315085332, 7.875816901509927, 6.944156080455391, 7.783929797684195, 8.835641035285262, 9.739515448994787, 10.690675876600022, 11.674619236863187, 12.590051314508342, 13.44935490890557, 14.39667949880423, 15.328537179082755, 16.35379269909112, 15.632788408136467, 13.643515810301238, 12.763329214540436, 11.81835223550335, 10.80209966540796, 9.775358477377626, 8.756654844231427, 7.732584059889824, 6.807136670269343, 5.869182770767098, 6.820867747334841, 7.783700536812511, 8.788347960117886, 9.74801123761263, 10.680521044025898, 11.574449411958755, 12.512188817277538, 13.51683734236506, 14.460268082509103, 15.475351958155949, 14.695287688834817, 12.637023765591127, 11.789138974034424, 10.796940701197943, 9.853532891199412, 8.87014180504338, 7.87395554809836, 6.799370511971068, 5.863964303744222, 4.915369803066774, 5.850765315310708, 6.8040829075784615, 7.7869319773619114, 8.789369176724872, 9.722922021494433, 10.585747416797101, 11.539349190444442, 12.58256064686547, 13.572512617648197, 14.52742953479132, 13.706928762354458, 11.670392340394692, 10.720230591011687, 9.739257728948914, 8.857763021078403, 7.9718480981141875, 6.9328443558389425, 5.987199730075073, 4.937695022645501, 3.9362100537720583, 4.9014451097654845, 5.882202348900076, 6.922069213123656, 7.761412561024206, 8.70838194679959, 9.633582390203056, 10.579645599722207, 11.563415696158305, 12.501898164141139, 13.49956527751539, 12.695280546962639, 10.897935219249424, 9.828389647385572, 8.80135039732428, 7.841667624029125, 6.929606728055864, 5.942052824328662, 4.972642698421545, 3.9575060405343487, 2.893499002131887, 3.910524609049913, 4.906818825373893, 5.896568629918992, 6.807009202997878, 7.843124163199837, 8.753531411469066, 9.606871760523033, 10.565170221397652, 11.549717633631467, 12.573298405035478, 11.865955103230345, 9.905494139023661, 8.892568704701922, 7.962954881982243, 6.910370309827179, 5.932676257016144, 4.937940262739924, 3.96428640905091, 2.9228381255418587, 1.885685067288974, 2.85704296169504, 3.9161918503736306, 4.914483460526387, 5.832080592329634, 6.84399756346996, 7.724626751604311, 8.663373220549643, 9.609486197561138, 10.579732780907893, 11.544718847524118, 10.879666611817807, 9.026308387382073, 8.06507863782146, 7.027912299307061, 6.086172837867424, 5.096841361372523, 4.032432046011099, 2.9963852564804068, 2.003402548111187, 0.9329856043412068, 1.8986319654294088, 2.882051334689544, 3.8916084434600124, 4.8390098684373735, 5.801835085385014, 6.785828755207114, 7.725846431189782, 8.758337451815391, 9.823583673974868, 10.864577436373658, 10.017691093528525, 8.150114159358708, 7.192080778818782, 6.19653248758685, 5.234740844814565, 4.174948442657156, 3.1690223713511143, 2.116158767181451, 1.0718041552337492, 0.0, 0.9635294458079107, 2.020392379641671, 3.019667774234675, 3.975358257467373, 4.994303648329383, 6.044286029570459, 7.011538582964758, 8.024260618382659, 8.96675003440783, 9.953097195279085, 9.201756588157863, 9.089779268904016, 8.022076977215407, 7.040014406584352, 6.049003560191992, 4.998025892036858, 4.023920310506458, 2.975346740219294, 1.9927253707976016, 1.0253026903986773, 1.9697594440531383, 2.8951095642868543, 3.831317434426638, 4.8640770302886125, 5.874618522741374, 6.937466242253978, 7.949133997853794, 9.021586501292578, 10.038145243688374, 10.905852509291744, 10.055477073947799, 9.964148236718676, 8.934645702276462, 7.896323766703974, 6.912536837172803, 5.91277842771136, 4.913821948210534, 3.934127671487081, 2.962036759500247, 2.007615558583974, 2.968785176706822, 3.8327618032986153, 4.835104347328273, 5.792633174898601, 6.825851398197138, 7.839403269960166, 8.895974886235576, 9.90083849155021, 10.973999292907816, 11.858691881990326, 10.933206105009873, 10.797716386249972, 9.850843100851836, 8.864811326849914, 7.844720935531819, 6.8363339990784, 5.881209957289656, 4.924908769420109, 3.931992344079075, 2.9514262217947556, 3.9394690315779033, 4.842411432815172, 5.8631752459960245, 6.791744463458619, 7.732192820115812, 8.738565807282184, 9.733526605805347, 10.718058200621897, 11.682730838377884, 12.643534289320824, 11.751458803753383, 11.816044807129805, 10.742634399989246, 9.781458367259965, 8.844543187276514, 7.770270264130042, 6.931784966151112, 5.877451753339537, 4.953281146898915, 3.967136756923595, 4.950163880416321, 5.814493310728784, 6.799269112909977, 7.7865774536681025, 8.790216839288577, 9.731305845334571, 10.669055469557236, 11.659918587358407, 12.66090366426249, 13.702993417936778, 12.701350266620192, 12.80759491164017, 11.76165339076475, 10.763638671467147, 9.771443099649511, 8.737861737531928, 7.840598423530442, 6.885078341341313, 5.92153139929349, 4.962619850134621, 6.021627944111742, 6.759076459605791, 7.716030719530643, 8.763455299186132, 9.755245426741293, 10.740267100791431, 11.698034261844322, 12.626563322315707, 13.628976930682354, 14.641467771339283, 13.724707014469983], [15.503227117932274, 14.553582604812725, 13.560240269268736, 12.600448115727165, 11.741754198469883, 10.737055883381032, 9.786324846211603, 8.779721367343281, 7.740183563603364, 6.795420107969587, 6.185213458287182, 6.900855983876676, 7.86479865651707, 8.797388472564133, 9.744562923734025, 10.621820366522808, 11.649764074252905, 12.661956033401747, 13.71050327401362, 14.730139744407388, 16.474702583846142, 15.529618489492881, 14.591046580277578, 13.540846194715108, 12.677314643817677, 11.700101430866875, 10.639075542218801, 9.70384981066411, 8.717102804031649, 7.787573810884836, 7.2233497292519395, 7.84313887950273, 8.881862897475456, 9.749325753033737, 10.67152831654676, 11.677898197884272, 12.640858569029504, 13.60570282422706, 14.59232214126716, 15.539248529823181, 17.461021719211008, 16.530274311281694, 15.567605424725967, 14.569740067868073, 13.686418405106199, 12.68843987736618, 11.661444992339105, 10.643404647626376, 9.673578331987805, 8.720749385429738, 8.198525582004256, 8.780638325432049, 9.838074303660175, 10.771444000510403, 11.690759273793999, 12.728873822512481, 13.622803986639248, 14.575981094802076, 15.539995969518511, 16.47701508063487, 18.494015565833426, 17.466278523051482, 16.482061856232434, 15.53225069186036, 14.628045780126525, 13.559289297114432, 12.575669794004655, 11.57658499448488, 10.620412803191313, 9.67431573628733, 9.26528931154202, 9.79300202991049, 10.75663307857388, 11.801741647359394, 12.635065435306386, 13.709238641647083, 14.57647020290538, 15.51459982489493, 16.512136154110262, 17.449643993845456, 18.443096254235304, 17.494365346262796, 16.52652277220847, 15.486840071329167, 14.522633204865889, 13.588985276157336, 12.599933630882315, 11.657197717259494, 10.842571117447369, 9.9364074538901, 10.206516789743107, 10.723093784398284, 11.716061838775948, 12.728349985117934, 13.705194309980728, 14.662024665928264, 15.556683624076367, 16.476065045645385, 17.453301950183697, 18.393893103464084, 17.49605371363481, 16.65999682425658, 15.682261210294076, 14.6543360087954, 13.638528792096926, 12.70092173238173, 11.660661905532772, 10.731949076474248, 9.83235244854526, 8.9587401294681, 9.893330118325895, 10.911255115797706, 11.75746156263939, 12.728872763353547, 13.654907905761638, 14.493905743420127, 15.329916400335984, 16.244849145639296, 17.1814143561367, 18.23286400141126, 16.502851625511447, 15.646256285384409, 14.678734666160285, 13.66513257980671, 12.688860327952638, 11.67287049530253, 10.654315101717987, 9.785855129757937, 8.849501416491565, 8.022960102506657, 8.962740281747681, 9.860699101339382, 10.712150916802212, 11.757988582884126, 12.596771711237238, 13.501805933877161, 14.397082370818739, 15.310229281992735, 16.275689916426327, 17.281043852820144, 15.535645312213306, 14.635194364746091, 13.687583665840958, 12.675904148715473, 11.655147108187496, 10.687407819460523, 9.700747760893243, 8.839346347317838, 7.907685526263301, 7.006312456659595, 7.925021739625466, 8.828896153334991, 9.780056580940226, 10.711089791055278, 11.626521868700431, 12.48582546309766, 13.43315005299632, 14.365007733274844, 15.39026325328321, 16.381519565026657, 14.60704525610915, 13.726858660348347, 12.78188168131126, 11.76562911121587, 10.738887923185537, 9.720184290039338, 8.696113505697735, 7.770666116077254, 6.832712216575008, 6.043250406310242, 6.873081241152716, 7.877728664458089, 8.837391941952834, 9.716991598217989, 10.610919966150844, 11.548659371469627, 12.553307896557149, 13.496738636701192, 14.511822512348038, 15.571153255972147, 13.600553211399038, 12.752668419842335, 11.760470147005854, 10.817062337007323, 9.83367125085129, 8.837484993906271, 7.762899957778979, 6.827493749552133, 5.878899248874684, 5.073147974286109, 5.893463611918666, 6.876312681702116, 7.825839730916963, 8.759392575686524, 9.62221797098919, 10.575819744636531, 11.61903120105756, 12.608983171840286, 13.56390008898341, 14.5481334327102, 12.633921786202603, 11.683760036819598, 10.702787174756825, 9.821292466886314, 8.9353775439221, 7.896373801646853, 6.950729175882984, 5.901224468453412, 4.899739499579969, 4.050314299627224, 4.944157153954051, 5.984024018177631, 6.797883115216296, 7.74485250099168, 8.670052944395145, 9.616116153914296, 10.599886250350394, 11.538368718333228, 12.53603583170748, 13.536485217318381, 11.861464665057333, 10.791919093193481, 9.76487984313219, 8.805197069837035, 7.893136173863775, 6.9055822701365726, 5.936172144229456, 4.92103548634226, 3.857028447939798, 3.059393798911652, 3.968773630427868, 4.9585234349729665, 5.843479757189968, 6.879594717391927, 7.7900019656611565, 8.643342314715122, 9.601640775589741, 10.586188187823556, 11.609768959227567, 12.609865969880572, 10.86902358483157, 9.856098150509832, 8.926484327790153, 7.87389975563509, 6.896205702824055, 5.901469708547835, 4.927815854858821, 3.8863675713497696, 2.849214513096885, 2.005912151556779, 2.9607206714266354, 3.9590122815793922, 4.868551146521724, 5.88046811766205, 6.761097305796401, 7.699843774741732, 8.645956751753227, 9.616203335099982, 10.581189401716207, 11.623577478468034, 9.989837833189984, 9.02860808362937, 7.9914417451149715, 7.049702283675335, 6.060370807180434, 4.99596149181901, 3.959914702288317, 2.9669319939190975, 1.8965150501491175, 0.9351025196214982, 1.9185218888816338, 2.928078997652102, 3.875480422629463, 4.838305639577104, 5.822299309399204, 6.762316985381872, 7.794808006007482, 8.860054228166959, 9.901047990565749, 10.843741581495594, 9.11364360516662, 8.155610224626693, 7.160061933394761, 6.198270290622476, 5.138477888465067, 4.132551817159024, 3.0796882129893612, 2.0353336010416596, 0.9635294458079107, 0.0, 1.0568629338337607, 2.0561383284267647, 3.0118288116594627, 4.030774202521472, 5.080756583762548, 6.048009137156847, 7.060731172574748, 8.00322058859992, 8.989567749471174, 10.038814907732892, 10.016439542913785, 8.948737251225177, 7.966674680594122, 6.975663834201762, 5.9246861660466275, 4.950580584516228, 3.9020070142290626, 2.9193856448073703, 1.951962964408446, 1.007506210753985, 1.9328563309877012, 2.869064201127485, 3.901823796989459, 4.912365289442221, 5.975213008954825, 6.985604552045883, 8.058057055484667, 9.074615797880464, 9.942323063483833, 10.87646312773015, 10.890808510728446, 9.861305976286232, 8.822984040713742, 7.839197111182572, 6.839438701721129, 5.840482222220302, 4.86078794549685, 3.8886970335100157, 2.934275832593743, 2.0065319434076687, 2.870508569999462, 3.87285111402912, 4.830379941599448, 5.863598164897985, 6.877150036661013, 7.933721652936423, 8.93858525825106, 10.011746059608665, 10.956632533659171, 11.808024357496933, 11.724376660259741, 10.777503374861606, 9.791471600859683, 8.771381209541588, 7.762994273088169, 6.807870231299424, 5.851569043429878, 4.858652618088843, 3.8780864958045242, 3.037997504094421, 3.880158199516019, 4.900922012696871, 5.829491230159465, 6.769939586816658, 7.776312573983029, 8.771273372506192, 9.755804967322742, 10.72047760507873, 11.68128105602167, 12.678119077763153, 12.742705081139574, 11.669294673999016, 10.708118641269735, 9.771203461286284, 8.696930538139812, 7.858445240160881, 6.804112027349306, 5.8799414209086835, 4.893797030933364, 4.079850118429703, 4.852240077429631, 5.837015879610823, 6.824324220368949, 7.8279636059894235, 8.769052612035416, 9.706802236258081, 10.697665354059252, 11.698650430963335, 12.740740184637623, 13.628010540629962, 13.734255185649939, 12.688313664774519, 11.690298945476917, 10.698103373659281, 9.664522011541697, 8.76725869754021, 7.811738615351081, 6.848191673303258, 5.889280124144389, 5.151314182125125, 5.796823226306638, 6.75377748623149, 7.801202065886979, 8.79299219344214, 9.77801386749228, 10.735781028545167, 11.664310089016553, 12.6667236973832, 13.679214538040128, 14.651367288479753], [14.525857068914663, 13.576212555795113, 12.582870220251124, 11.623078066709553, 10.764384149452269, 9.759685834363419, 8.808954797193989, 7.80235131832567, 6.762813514585752, 5.818050058951975, 6.8056158958892246, 7.774186175326498, 8.738128847966891, 9.670718664013954, 10.617893115183845, 11.495150557972629, 12.523094265702726, 13.535286224851568, 14.58383346546344, 15.565668815204917, 15.497332534828528, 14.55224844047527, 13.613676531259966, 12.563476145697496, 11.699944594800064, 10.722731381849261, 9.661705493201188, 8.726479761646496, 7.739732755014036, 6.810203761867224, 7.764309019876004, 8.693942029277268, 9.732666047249994, 10.622655944483558, 11.544858507996581, 12.551228389334092, 13.514188760479325, 14.479033015676881, 15.465652332716981, 16.412578721273, 16.515053798091223, 15.552904262264082, 14.590235375708355, 13.592370018850461, 12.709048356088585, 11.711069828348567, 10.684074943321495, 9.666034598608766, 8.696208282970195, 7.743379336412127, 8.73948487262832, 9.631441475206588, 10.688877453434714, 11.637461449507422, 12.56408946524382, 13.602204013962302, 14.496134178089068, 15.449311286251897, 16.41332616096833, 17.35034527208469, 17.527316626731846, 16.48890847403387, 15.504691807214822, 14.554880642842749, 13.650675731108915, 12.581919248096822, 11.598299744987045, 10.59921494546727, 9.643042754173702, 8.69694568726972, 9.742819698151616, 10.643805179685028, 11.60743622834842, 12.652544797133933, 13.508395626756206, 14.582568833096904, 15.4498003943552, 16.38793001634475, 17.385466345560083, 18.322974185295276, 18.45426128691979, 17.422577087625797, 16.45473451357147, 15.459512189292218, 14.495305322828939, 13.561657394120386, 12.572605748845366, 11.629869835222545, 10.664687205115984, 9.730940025574963, 10.023266426728181, 10.986615571517692, 11.781402554650594, 12.792775640578398, 13.705163127026445, 14.473324516734284, 15.306442281289252, 16.3137074245482, 17.13677041313764, 18.077361566418027, 18.184289456599114, 17.637798362715156, 16.660062748752654, 15.63213754725398, 14.616330330555503, 13.678723270840306, 12.638463443991348, 11.646530937088764, 10.725131958051461, 9.785690239035468, 8.964724518636437, 9.964571995464764, 10.780042920610155, 11.751454121324311, 12.675705250238568, 13.514703087897058, 14.350713744812914, 15.265646490116227, 16.20221170061363, 17.253661345888194, 17.233795529253108, 16.624057823842985, 15.656536204618861, 14.642934118265288, 13.666661866411214, 12.650672033761106, 11.632116640176564, 10.700436990372454, 9.742280925997767, 8.849910212074024, 8.016057161414738, 8.91401598100644, 9.734732274772977, 10.78056994085489, 11.617569055714169, 12.522603278354092, 13.417879715295669, 14.331026626469665, 15.296487260903259, 16.301841197297076, 16.46298945123466, 15.612995903204668, 14.665385204299534, 13.65370568717405, 12.632948646646073, 11.6652093579191, 10.67854929935182, 9.817147885776414, 8.800465035769502, 7.833262566226962, 6.978338619292522, 7.882213033002049, 8.80263793891099, 9.73188713553221, 10.647319213177362, 11.50662280757459, 12.45394739747325, 13.385805077751774, 14.411060597760141, 15.40231690950359, 15.553444650155832, 14.738468233866588, 13.759683219769835, 12.743430649674446, 11.716689461644112, 10.697985828497913, 9.673915044156312, 8.74846765453583, 7.789306563797734, 6.870200515877609, 5.926398120819773, 6.931045544125147, 7.859973299923599, 8.737788942694921, 9.631717310627774, 10.569456715946558, 11.57410524103408, 12.517535981178124, 13.532619856824969, 14.591950600449078, 14.546952605445721, 13.788540307084107, 12.796342034247626, 11.7948638754659, 10.811472789309867, 9.815286532364848, 8.740701496237556, 7.80529528801071, 6.83549359609741, 5.900098083853476, 4.946780491585723, 5.929629561369174, 6.846637075393895, 7.780189920163457, 8.643015315466121, 9.596617089113462, 10.639828545534488, 11.629780516317217, 12.58469743346034, 13.56893077718713, 13.580321180249285, 12.71963192406137, 11.738659061998597, 10.857164354128086, 9.97124943116387, 8.932245688888624, 7.986601063124754, 6.937096355695182, 5.935611386821739, 5.009305227134477, 3.9974740336211085, 5.037340897844688, 5.818680459693228, 6.765649845468612, 7.690850288872077, 8.636913498391227, 9.620683594827325, 10.559166062810158, 11.55683317618441, 12.557282561795311, 12.625748085897825, 11.827790980435251, 10.800751730373962, 9.841068957078807, 8.929008061105545, 7.941454157378343, 6.972044031471226, 5.95690737358403, 4.892900335181568, 4.018384726418906, 3.0220905100949254, 4.011840314640024, 4.8642771016669, 5.9003920618688595, 6.810799310138089, 7.664139659192053, 8.622438120066672, 9.606985532300486, 10.630566303704498, 11.630663314357502, 11.618547295739111, 10.891970037751602, 9.962356215031923, 8.90977164287686, 7.932077590065825, 6.937341595789605, 5.963687742100591, 4.922239458591539, 3.8850864003386545, 3.026067769744108, 2.014037551093693, 2.9965093287073383, 3.8893484909986555, 4.901265462138983, 5.781894650273333, 6.720641119218664, 7.666754096230158, 8.637000679576913, 9.601986746193138, 10.644374822944965, 10.836036726169295, 10.06447997087114, 9.02731363235674, 8.085574170917104, 7.0962426944222035, 6.031833379060779, 4.995786589530087, 4.002803881160867, 2.9323869373908873, 1.955258137808827, 0.9718387685486914, 1.9488763421290343, 2.8962777671063953, 3.8591029840540365, 4.843096653876136, 5.783114329858805, 6.8156053504844145, 7.880851572643891, 8.901960429092998, 9.844654020022844, 10.033594402698284, 9.212473158460453, 8.21692486722852, 7.255133224456236, 6.195340822298826, 5.189414750992785, 4.1365511468231215, 3.0921965348754203, 2.020392379641671, 1.0568629338337607, 0.0, 0.9992753945930039, 1.954965877825702, 2.9739112686877114, 4.023893649928787, 4.991146203323087, 6.003868238740987, 6.946357654766158, 7.932704815637412, 8.98195197389913, 10.78529799894017, 9.822067442674996, 8.840004872043941, 7.848994025651582, 6.798016357496448, 5.8239107759660484, 4.775337205678884, 3.7927158362571913, 2.825293155858267, 1.8808364022038058, 0.9554862819700894, 1.8916941521098734, 2.885656483073376, 3.896197975526137, 4.959045695038742, 5.928741618212122, 7.001194121650905, 8.017752864046702, 8.88546012965007, 9.819600193896386, 11.716052806459052, 10.734636167736053, 9.696314232163564, 8.712527302632393, 7.71276889317095, 6.713812413670124, 5.734118136946671, 4.762027224959837, 3.807606024043564, 2.8798621348574898, 1.8931385209818505, 2.8954810650115084, 3.853009892581836, 4.886228115880373, 5.899779987643401, 6.920463495338747, 7.925327100653382, 8.998487902010988, 9.899769599825408, 10.75116142366317, 12.597706851709564, 11.650833566311428, 10.664801792309506, 9.64471140099141, 8.63632446453799, 7.681200422749246, 6.724899234879699, 5.731982809538666, 4.751416687254346, 3.8339465183002934, 2.9027881504984077, 3.9235519636792597, 4.852121181141854, 5.792569537799047, 6.798942524965418, 7.79390332348858, 8.77843491830513, 9.743107556061117, 10.703911007004058, 11.703751374335555, 13.616035272589395, 12.542624865448836, 11.581448832719555, 10.644533652736104, 9.570260729589632, 8.731775431610703, 7.677442218799127, 6.753271612358505, 5.767127222383185, 4.812201607118361, 3.874870028412019, 4.859645830593212, 5.846954171351338, 6.850593556971813, 7.791682563017805, 8.72943218724047, 9.72029530504164, 10.721280381945723, 11.763370135620011, 12.653642837202364, 14.60758537709976, 13.56164385622434, 12.563629136926737, 11.571433565109102, 10.537852202991518, 9.640588888990031, 8.685068806800903, 7.72152186475308, 6.762610315594211, 5.859000680497175, 4.819453177289026, 5.776407437213878, 6.823832016869368, 7.815622144424528, 8.800643818474667, 9.758410979527556, 10.686940039998941, 11.689353648365588, 12.701844489022516, 13.676999585052155], [13.609331149631029, 12.659686636511479, 11.66634430096749, 10.706552147425919, 9.855306642644443, 8.859430267810492, 7.9426570879469445, 6.997745118759476, 6.008616775046394, 6.81732545354498, 7.804891290482229, 8.773461569919501, 9.737404242559895, 10.669994058606957, 11.617168509776848, 12.494425952565631, 13.522369660295729, 14.53456161944457, 15.583108860056443, 14.649142895921283, 14.580806615544894, 13.635722521191635, 12.697150611976332, 11.646950226413862, 10.8428853786266, 9.905385574241592, 8.882550292024881, 7.972283022107138, 6.985536015474678, 7.809479156460228, 8.763584414469008, 9.693217423870273, 10.731941441842999, 11.62193133907656, 12.544133902589584, 13.550503783927095, 14.513464155072327, 15.478308410269884, 16.464927727309984, 15.521396721748774, 15.59852787880759, 14.636378342980448, 13.67370945642472, 12.675844099566827, 11.851989139915121, 10.893724020740898, 9.906151963512631, 8.930786641273155, 7.960960325634583, 8.74265473100513, 9.738760267221325, 10.630716869799592, 11.688152848027718, 12.636736844100426, 13.563364859836822, 14.601479408555305, 15.495409572682071, 16.4485866808449, 17.412601555561338, 16.459163272560463, 16.610790707448214, 15.572382554750236, 14.588165887931188, 13.638354723559114, 12.804939035979789, 11.847208043209283, 10.863588540099506, 9.898462240205106, 8.942290048911538, 9.696221081862722, 10.742095092744618, 11.082191909380832, 11.758099779534431, 12.720108583743933, 13.76822270471406, 14.435633357646365, 15.287380307867235, 16.225509929856784, 17.157479977421243, 17.446017344720303, 17.537735367636156, 16.50605116834216, 15.538208594287834, 14.67722789554062, 13.784864297721462, 12.85121636901291, 11.8718530435832, 10.92911712996038, 9.963934499853819, 10.730215420167966, 11.00475441990158, 10.152100154893038, 10.78212716005759, 11.793500245985394, 12.70588773243344, 13.47404912214128, 14.307166886696248, 15.314432029955194, 16.137495018544634, 17.07808617182502, 17.185014062006108, 17.505560668394335, 16.58490692323021, 15.676241265884306, 14.722415739551009, 13.784808679835812, 12.887680917679257, 11.854365770745627, 10.974153168755928, 10.767178232208867, 9.946212511809836, 9.13005657884011, 9.78076752601715, 10.752178726731307, 11.676429855645564, 12.515427693304053, 13.35143835021991, 14.266371095523223, 15.202936306020625, 16.254385951295188, 16.2345201346601, 17.21010563084189, 16.638024197792262, 15.624422111438687, 14.648149859584613, 13.632160026934505, 12.613604633349963, 11.681924983545853, 10.723768919171166, 9.831398205247423, 8.997545154588137, 8.079500564381785, 8.735456880179973, 9.781294546261886, 10.618293661121164, 11.523327883761088, 12.418604320702665, 13.33175123187666, 14.297211866310253, 15.30256580270407, 15.463714056641656, 16.45438163954041, 15.646873197472933, 14.635193680347449, 13.614436639819472, 12.646697351092499, 11.66003729252522, 10.798635878949813, 9.781953028942901, 8.81475055940036, 7.959826612465921, 7.047697616377393, 7.803362544317987, 8.732611740939205, 9.648043818584357, 10.507347412981586, 11.454672002880246, 12.38652968315877, 13.411785203167137, 14.403041514910585, 14.55416925556283, 15.464841402732617, 14.741171212943234, 13.724918642847845, 12.698177454817511, 11.679473821671312, 10.65540303732971, 9.729955647709229, 8.770794556971133, 7.851688509051008, 6.907886113993172, 6.096530127500491, 6.8606979053305945, 7.738513548101917, 8.63244191603477, 9.570181321353553, 10.574829846441075, 11.518260586585118, 12.533344462231966, 13.592675205856075, 13.547677210852719, 14.490651162226605, 13.783661322005432, 12.7763518686393, 11.792960782483267, 10.796774525538247, 9.722189489410955, 8.786783281184109, 7.816981589270809, 6.881586077026875, 5.928268484759122, 5.095114144744517, 5.847361680800891, 6.780914525570452, 7.6437399208731165, 8.597341694520459, 9.640553150941486, 10.630505121724214, 11.585422038867337, 12.569655382594128, 12.581045785656283, 13.531207535039288, 12.725978349756403, 11.844483641885892, 10.958568718921676, 9.91956497664643, 8.97392035088256, 7.924415643452988, 6.922930674579545, 5.990793220307876, 4.978962026794507, 4.064752486649245, 4.819405065100224, 5.766374450875608, 6.691574894279072, 7.637638103798224, 8.621408200234322, 9.559890668217156, 10.557557781591408, 11.558007167202309, 11.626472691304823, 12.568018278151495, 11.788071018131768, 10.828388244836614, 9.916327348863351, 8.928773445136148, 7.959363319229032, 6.944226661341836, 5.880219622939374, 4.999872719592305, 4.003578503268324, 3.0392519034445806, 3.865001707073896, 4.901116667275855, 5.811523915545084, 6.66486426459905, 7.623162725473669, 8.607710137707484, 9.631290909111495, 10.631387919764498, 10.619271901146107, 11.632197335467845, 10.949675502789729, 9.897090930634667, 8.919396877823631, 7.9246608835474115, 6.951007029858397, 5.9095587463493455, 4.872405688096461, 4.013387057501915, 2.9955255442670916, 1.9972339341143348, 2.8900730964056516, 3.901990067545978, 4.78261925568033, 5.72136572462566, 6.667478701637155, 7.637725284983909, 8.602711351600133, 9.64509942835196, 9.836761331576293, 10.797991081136907, 10.014632920114549, 9.072893458674912, 8.083561982180012, 7.019152666818586, 5.983105877287894, 4.990123168918674, 3.919706225148694, 2.942577425566634, 1.9591580563064985, 0.9496009475360304, 1.8970023725133913, 2.859827589461032, 3.8438212592831325, 4.783838935265801, 5.81632995589141, 6.881576178050887, 7.902685034499996, 8.845378625429841, 9.034319008105282, 9.992352388645209, 9.216200261821525, 8.25440861904924, 7.194616216891831, 6.188690145585789, 5.135826541416126, 4.091471929468424, 3.0196677742346756, 2.0561383284267647, 0.9992753945930039, 0.0, 0.9556904832326981, 1.9746358740947074, 3.024618255335784, 3.9918708087300834, 5.004592844147984, 5.947082260173155, 6.933429421044409, 7.982676579306128, 9.786022604347167, 10.821342837268, 9.839280266636946, 8.848269420244586, 7.797291752089451, 6.823186170559051, 5.774612600271887, 4.791991230850194, 3.8245685504512705, 2.8801117967968093, 1.9547616765630933, 1.0474210385225295, 1.886381088480372, 2.896922580933133, 3.9597703004457383, 4.929466223619119, 6.001918727057903, 7.018477469453699, 7.886184735057068, 8.820324799303384, 10.71677741186605, 11.733911562329055, 10.695589626756567, 9.711802697225396, 8.712044287763952, 7.7130878082631265, 6.733393531539674, 5.761302619552841, 4.806881418636568, 3.8791375294504933, 2.8924139155748545, 2.0512079514241646, 2.9242946683373505, 3.9281155844642264, 4.941667456227255, 5.921188100745744, 6.926051706060379, 7.999212507417985, 8.900494205232405, 9.751886029070167, 11.669838837539336, 12.616712122937471, 11.664077186902508, 10.643986795584413, 9.635599859130993, 8.680475817342248, 7.724174629472702, 6.731258204131668, 5.750692081847349, 4.833221912893297, 3.9020635450914116, 3.122661207747756, 3.9728832931903613, 4.876043618515414, 5.882416605681785, 6.877377404204947, 7.861908999021496, 8.826581636777483, 9.787385087720423, 10.716096420035925, 12.630177250791453, 13.541900260041839, 12.580724227312558, 11.643809047329107, 10.569536124182635, 9.731050826203706, 8.67671761339213, 7.752547006951509, 6.766402616976189, 5.811477001711365, 4.874145423005023, 4.0587550746617085, 4.967716283399845, 5.934067637688179, 6.875156643734172, 7.812906267956835, 8.803769385758006, 9.804754462662089, 10.846844216336377, 11.665987882902733, 13.657930245466304, 14.560919250817342, 13.56290453151974, 12.570708959702104, 11.53712759758452, 10.639864283583034, 9.684344201393905, 8.720797259346083, 7.761885710187214, 6.8582760750901794, 5.818728571882031, 5.02221069767452, 5.996124622673385, 6.949324435177482, 7.90038825192174, 8.841885060243921, 9.770414120715307, 10.772827729081953, 11.785318569738882, 12.689344630752524], [12.653640666398331, 11.703996153278782, 10.710653817734793, 9.750861664193222, 8.899616159411746, 7.9037397845777955, 6.986966604714247, 6.042054635526778, 6.831717594718897, 7.7622218482313174, 8.749787685168567, 9.718357964605842, 10.682300637246236, 11.614890453293297, 12.562064904463188, 13.43932234725197, 14.467266054982067, 15.479458014130909, 14.713088883082355, 13.693452412688586, 13.625116132312197, 12.680032037958938, 11.741460128743634, 10.691259743181165, 9.887194895393902, 8.949695091008895, 7.926859808792185, 7.042422902869918, 7.808636835147181, 8.754375551146566, 9.708480809155347, 10.638113818556612, 11.676837836529337, 12.566827733762901, 13.489030297275924, 14.495400178613435, 15.458360549758668, 16.423204804956224, 15.512632627072097, 14.565706238516077, 14.642837395574892, 13.680687859747751, 12.718018973192024, 11.72015361633413, 10.896298656682424, 9.9380335375082, 8.950461480279934, 8.091645380443396, 8.784061145307085, 9.687551125691469, 10.683656661907664, 11.57561326448593, 11.787003881417283, 12.73558787748999, 13.708587767356757, 14.512635478581773, 15.303045826363313, 16.34237865342176, 16.50467612453885, 15.503472789327766, 15.655100224215516, 14.616692071517539, 13.632475404698491, 12.682664240326417, 11.849248552747092, 10.891517559976586, 9.90789805686681, 9.14859604300242, 9.765390868584038, 10.641117476549061, 11.686991487430957, 11.730628065839431, 10.820099081764377, 11.782107885973879, 12.830222006944005, 13.497632659876313, 14.349379610097182, 15.287509232086732, 16.219479279651193, 16.490326861487606, 16.58204488440346, 15.550360685109464, 14.582518111055137, 13.721537412307923, 12.829173814488765, 11.895525885780213, 10.917950730069794, 10.179250932757695, 10.78703531952632, 11.675111814854304, 11.700926989941358, 10.800536311351637, 9.844126462287536, 10.85549954821534, 11.767887034663389, 12.536048424371227, 13.369166188926195, 14.376431332185142, 15.199494320774582, 16.140085474054967, 16.247013364236057, 16.549870185161637, 15.629216439997514, 14.720550782651609, 13.766725256318312, 12.829118196603115, 11.980367211485113, 11.104499573542942, 11.797253988428428, 11.576975070707409, 10.642385081849614, 9.778492735298709, 8.842766828247097, 9.814178028961253, 10.738429157875512, 11.577426995534001, 12.413437652449858, 13.32837039775317, 14.264935608250573, 15.316385253525137, 15.296519436890053, 16.27210493307184, 16.661479034849602, 15.709754211640298, 14.758668358613646, 13.879917092203115, 12.986714015299897, 12.050593520259252, 11.613353491945333, 10.699502914812738, 9.693717724627914, 8.727936720840384, 7.797456182409919, 8.843293848491832, 9.680292963351112, 10.585327185991035, 11.480603622932612, 12.393750534106609, 13.359211168540202, 14.36456510493402, 14.525713358871604, 15.516380941770361, 16.45858010617626, 15.524778253121614, 14.504021212593637, 13.536281923866664, 12.549621865299384, 11.688220451723978, 10.671537601717068, 9.704335132174528, 8.751175964411571, 7.795497495164582, 6.865361846547933, 7.794611043169153, 8.710043120814305, 9.569346715211534, 10.516671305110194, 11.448528985388718, 12.473784505397084, 13.465040817140533, 13.616168557792776, 14.526840704962563, 15.505625719059315, 14.61450321562201, 13.587762027591676, 12.569058394445477, 11.544987610103876, 10.619540220483394, 9.660379129745298, 8.741273081825174, 7.797470686767338, 6.84433000628768, 5.922697207560541, 6.800512850331864, 7.694441218264718, 8.632180623583501, 9.636829148671023, 10.580259888815068, 11.595343764461914, 12.654674508086023, 12.609676513082665, 13.552650464456551, 14.554867573941523, 13.665936441413464, 12.682545355257432, 11.686359098312412, 10.61177406218512, 9.676367853958274, 8.706566162044975, 7.771170649801041, 6.817853057533288, 5.842914023531707, 4.909360983030838, 5.842913827800399, 6.7057392231030635, 7.659340996750408, 8.702552453171435, 9.692504423954162, 10.647421341097285, 11.631654684824076, 11.643045087886229, 12.593206837269234, 13.497184601692494, 12.80017412511859, 11.914259202154376, 10.87525545987913, 9.929610834115259, 8.880106126685687, 7.872516951564992, 6.8956885281183515, 5.868546599568673, 4.812552365436434, 3.8814043673301706, 4.828373753105555, 5.753574196509019, 6.699637406028172, 7.68340750246427, 8.621889970447103, 9.619557083821356, 10.620006469432257, 10.688471993534769, 11.630017580381443, 12.55927727006786, 11.78407872806931, 10.872017832096052, 9.884463928368849, 8.915053802461731, 7.899917144574534, 6.835910106172072, 5.955563202825003, 4.959268986501022, 3.9949423866772786, 2.927001009303843, 3.9631159695058034, 4.873523217775032, 5.726863566828998, 6.685162027703617, 7.6697094399374315, 8.693290211341443, 9.693387221994445, 9.681271203376054, 10.694196637697793, 11.623810460417472, 10.852781413867366, 9.87508736105633, 8.88035136678011, 7.906697513091096, 6.865249229582044, 5.828096171329159, 4.969077540734613, 3.9512160274997896, 2.952924417347033, 1.9520723986355988, 2.963989369775926, 3.8446185579102767, 4.783365026855608, 5.7294780038671025, 6.699724587213857, 7.664710653830082, 8.707098730581908, 8.881070848343594, 9.842300597904208, 10.879466936418607, 10.028583941907609, 9.039252465412709, 7.974843150051284, 6.938796360520592, 5.945813652151372, 4.875396708381392, 3.898267908799332, 2.9148485395391965, 1.9052914307687285, 0.9590016747433384, 1.9218268916909795, 2.90582056151308, 3.8458382374957485, 4.878329258121358, 5.943575480280835, 6.946994551267297, 7.8896881421971425, 8.078628524872585, 9.036661905412512, 10.032210196644444, 9.210099102281939, 8.15030670012453, 7.144380628818488, 6.091517024648825, 5.047162412701123, 3.9753582574673736, 3.0118288116594627, 1.954965877825702, 0.9556904832326981, 0.0, 1.0189453908620092, 2.0689277721030854, 3.036180325497385, 4.048902360915285, 4.991391776940456, 5.9777389378117105, 7.026986096073429, 8.830332121114468, 9.898034412803076, 10.784176661323285, 9.793165814930925, 8.74218814677579, 7.76808256524539, 6.719508994958225, 5.736887625536533, 4.769464945137609, 3.825008191483148, 2.8996580712494318, 1.963450201109648, 0.930690605247674, 1.9412320977004351, 3.0040798172130403, 3.9737757403864205, 5.046228243825204, 6.062786986221, 6.930494251824369, 7.864634316070685, 9.76108692863335, 10.790589463075564, 11.640486021442905, 10.656699091911735, 9.65694068245029, 8.657984202949464, 7.678289926226013, 6.706199014239179, 5.7517778133229065, 4.824033924136832, 3.8373103102611927, 2.9261330126749803, 1.9686041851046525, 2.9724251012315284, 3.985976972994557, 4.965497617513045, 5.97036122282768, 7.043522024185286, 7.9448037219997065, 8.796195545837469, 10.714148354306637, 11.661021639704773, 12.608973581588847, 11.588883190270751, 10.580496253817332, 9.625372212028587, 8.669071024159042, 7.676154598818007, 6.695588476533688, 5.778118307579636, 4.84695993977775, 3.945762027420258, 3.0171928099576633, 3.9203531352827166, 4.926726122449088, 5.92168692097225, 6.906218515788799, 7.870891153544786, 8.831694604487726, 9.760405936803226, 11.674486767558754, 12.655199758658465, 13.525620621998897, 12.588705442015446, 11.514432518868974, 10.675947220890047, 9.62161400807847, 8.697443401637848, 7.711299011662527, 6.756373396397703, 5.819041817691361, 4.881855894334211, 4.012025800167147, 4.978377154455482, 5.919466160501475, 6.857215784724138, 7.848078902525309, 8.849063979429392, 9.89115373310368, 10.710297399670035, 12.702239762233605, 13.674218749433969, 14.507800926206079, 13.515605354388443, 12.48202399227086, 11.584760678269374, 10.629240596080246, 9.665693654032424, 8.706782104873554, 7.803172469776517, 6.7636249665683685, 5.845311517347023, 5.040434139440687, 5.993633951944785, 6.944697768689043, 7.886194577011224, 8.81472363748261, 9.817137245849256, 10.829628086506185, 11.733654147519825], [11.67941228073515, 10.7297677676156, 9.736425432071611, 8.77663327853004, 7.953159427443253, 6.957283052609303, 6.040509872745755, 6.939206585540532, 7.728869544732649, 8.698014608948576, 9.685580445885826, 10.712056036171978, 11.675998708812372, 12.633835844155305, 13.581010295325196, 14.45826773811398, 15.418697993270008, 14.694448962581308, 13.708661684766312, 12.689025214372544, 12.650887746649015, 11.705803652295756, 10.767231743080453, 9.717031357517984, 8.940738163425408, 8.003238359040402, 6.980403076823692, 7.915628808378384, 8.705788785160934, 9.690168311863825, 10.644273569872606, 11.57390657927387, 12.612630597246596, 13.150142813190161, 14.026414617488884, 14.672717062126257, 15.39409720288933, 15.525023558449018, 14.538404241408916, 13.591477852852895, 13.66860900991171, 12.70645947408457, 11.743790587528842, 10.745925230670949, 9.94984192471393, 8.991576805539708, 8.004004748311441, 8.964851285951863, 9.681213095320839, 10.623343886408728, 11.619449422624923, 12.51140602520319, 12.805949272279292, 12.128024565713494, 13.007183660241646, 13.621741437498047, 14.412151785279587, 15.451484612338037, 15.530447738875667, 14.529244403664585, 14.680871838552335, 13.642463685854358, 12.65824701903531, 11.708435854663236, 10.902791820778598, 9.945060828008094, 8.961441324898317, 9.960526124418092, 10.662542818597792, 11.57691023726632, 12.622784248148216, 12.749573456701441, 11.839044472626387, 11.08116435674585, 12.062877498729259, 12.606738618792587, 13.458485569013456, 14.396615191003006, 15.328585238567465, 15.516098475824425, 15.607816498740277, 14.576132299446282, 13.608289725391955, 12.747309026644741, 11.882717082520273, 10.94906915381172, 9.971493998101302, 10.914229911724123, 11.684187269540073, 12.610904575571563, 12.719872380803368, 11.819481702213647, 10.863071853149545, 10.15455601898731, 10.992748624054917, 11.645154383287501, 12.47827214784247, 13.485537291101416, 14.308600279690856, 15.249191432971243, 15.35611932315233, 15.575641799498456, 14.654988054334332, 13.746322396988427, 12.82026852434982, 11.882661464634623, 11.03391047951662, 11.83947855250937, 12.694405938442182, 12.595920461569419, 11.661330472711624, 10.797438126160719, 9.861712219109107, 9.113234499733224, 9.96329074726704, 10.686532954450275, 11.522543611366132, 12.437476356669444, 13.374041567166847, 14.425491212441411, 14.405625395806327, 15.381210891988117, 15.68725064918642, 14.735525825977117, 13.812211626645153, 12.933460360234623, 12.040257283331405, 12.78557249922568, 12.632298882807342, 11.718448305674748, 10.712663115489924, 9.746882111702394, 8.816401573271929, 8.119491664418431, 8.90515455274264, 9.69443314490731, 10.589709581848886, 11.502856493022882, 12.468317127456476, 13.473671063850293, 13.634819317787878, 14.625486900686635, 15.554594313741271, 15.759618923529636, 14.867878255628009, 13.91892303607663, 12.993824624156149, 12.70716584258599, 11.690482992579078, 10.723280523036538, 9.77012135527358, 8.814442886026592, 7.884307237409943, 7.051331434838083, 7.934904710205834, 8.678452674127808, 9.625777264026468, 10.557634944304992, 11.582890464313358, 12.574146776056807, 12.712182765357785, 13.622854912527572, 14.601639926624324, 15.5645554648483, 14.606707418453688, 13.588003785307489, 12.563933000965886, 11.638485611345406, 10.679324520607308, 9.760218472687184, 8.816416077629347, 7.86327539714969, 6.9416425984225505, 6.057233242000794, 6.919302807656248, 7.741286582499776, 8.745935107587297, 9.689365847731342, 10.691357972026923, 11.750688715651032, 11.705690720647674, 12.64866467202156, 13.647049218779966, 14.595355457353573, 13.701490746119442, 12.705304489174422, 11.63071945304713, 10.695313244820284, 9.725511552906985, 8.790116040663051, 7.836798448395298, 6.861859414393717, 5.928306373892847, 5.099634219469329, 5.9306008124945935, 6.755355204315417, 7.7985666607364434, 8.788518631519171, 9.743435548662294, 10.727668892389087, 10.739059295451238, 11.689221044834243, 12.589366246530936, 13.597152693002979, 12.933204593016384, 11.89420085074114, 10.948556224977269, 9.899051517547697, 8.891462342427003, 7.914633918980361, 6.887491990430683, 5.831497756298444, 4.90034975819218, 4.053235342497085, 4.978435785900549, 5.795651613593181, 6.779421710029279, 7.717904178012113, 8.715571291386366, 9.716020676997267, 9.784486201099778, 10.722199225219885, 11.651458914906302, 12.611141688201457, 11.89096322295806, 10.903409319230857, 9.933999193323741, 8.918862535436544, 7.854855497034082, 6.974508593687012, 5.978214377363031, 5.013887777539288, 3.9459464001658526, 3.0715592851048403, 3.9695374253400417, 4.822877774394008, 5.781176235268627, 6.765723647502441, 7.789304418906453, 8.789401429559454, 8.777285410941063, 9.786378282536235, 10.715992105255914, 11.768576677410977, 10.89403275191834, 9.89929675764212, 8.925642903953106, 7.884194620444054, 6.847041562191169, 5.988022931596622, 4.970161418361799, 3.971869808209042, 2.971017789497608, 2.072432685374963, 2.9406327654752866, 3.8793792344206177, 4.825492211432112, 5.795738794778867, 6.760724861395092, 7.803112938146918, 7.862125457481584, 8.823355207042198, 9.860521545556598, 10.802261006996234, 10.05819785627472, 8.993788540913295, 7.957741751382602, 6.964759043013382, 5.894342099243402, 4.917213299661341, 3.933793930401206, 2.9242368216307377, 1.9779470656053477, 1.0302702072900165, 2.0018347690780898, 2.9418524450607584, 3.974343465686368, 4.95509674438609, 5.928049160405287, 6.870742751335133, 7.059683134010574, 8.0177165145505, 9.013264805782432, 9.975056448554717, 9.169252090986541, 8.163326019680499, 7.110462415510835, 6.066107803563133, 4.9943036483293834, 4.030774202521473, 2.9739112686877114, 1.9746358740947074, 1.0189453908620092, 0.0, 1.0499823812410762, 2.0172349346353755, 3.029956970053276, 3.9724463860784467, 4.958793546949701, 6.008040705211419, 7.811386730252458, 8.879089021941066, 9.86115159257212, 10.812111205792934, 9.7611335376378, 8.7870279561074, 7.738454385820234, 6.755833016398542, 5.788410335999618, 4.843953582345157, 3.9186034621114407, 2.982395591971657, 1.9496359961096832, 0.9947753657319425, 2.0576230852445474, 2.954830349524411, 4.027282852963195, 5.043841595358991, 5.911548860962359, 6.845688925208675, 8.74214153777134, 9.771644072213554, 10.809966007786045, 11.675644482773745, 10.6758860733123, 9.676929593811474, 8.697235317088023, 7.7251444051011875, 6.770723204184915, 5.842979314998841, 4.856255701123201, 3.9450784035369892, 2.9875495759666615, 2.025968369263036, 3.0395202410260644, 3.9465522266510353, 4.9514158319656705, 6.024576633323276, 6.925858331137697, 7.77725015497546, 9.695202963444627, 10.642076248842763, 11.628108022844685, 12.607828581132761, 11.599441644679342, 10.644317602890597, 9.688016415021051, 8.695099989680015, 7.714533867395696, 6.794836158416749, 5.863677790614863, 4.842913977434011, 3.914344759971417, 2.973896403314224, 3.9802693904805952, 4.975230189003757, 5.911608563274889, 6.876281201030876, 7.837084651973815, 8.741460545941216, 10.655541376696744, 11.636254367796456, 12.597430400525736, 13.534345580509186, 12.533377909730984, 11.694892611752055, 10.640559398940479, 9.716388792499856, 8.730244402524535, 7.770509624149755, 6.833178045443413, 5.779007844347964, 4.909177750180901, 4.03192042248699, 4.973009428532983, 5.910759052755646, 6.873850516862128, 7.854454026915483, 8.896543780589772, 9.691352008808025, 11.683294371371595, 12.655273358571959, 13.629321503812935, 14.467037292676384, 13.500969383132869, 12.603706069131382, 11.648185986942254, 10.684639044894432, 9.725727495735562, 8.738965230493775, 7.699417727285627, 6.742463467360775, 5.937586089454441, 5.047177219976293, 5.99824103672055, 6.939737845042732, 7.840495251819429, 8.842908860186077, 9.855399700843005, 10.714708756657815], [10.629429899494074, 9.679785386374524, 8.686443050830535, 7.726650897288964, 6.923677603569258, 6.048956581207746, 7.0632384841295845, 7.974987112860167, 8.764650072052284, 9.73379513626821, 10.72136097320546, 11.747836563491612, 12.711779236132006, 13.683818225396381, 13.910582599112736, 14.688308439657627, 14.368715612028932, 13.644466581340232, 12.658679303525236, 11.639042833131468, 11.60090536540794, 10.65582127105468, 9.717249361839377, 8.667048976276908, 7.911256339551414, 7.094911887638847, 8.003131688207521, 8.938357419762212, 9.741569312480568, 10.72594883918346, 11.68005409719224, 12.609687106593505, 13.64841112456623, 13.900825070625135, 12.9836172063, 13.62273468088518, 14.344114821648255, 14.475041177207942, 13.48842186016784, 12.54149547161182, 12.618626628670635, 11.656477092843494, 10.693808206287766, 9.695942849429873, 8.920360100839936, 8.083250334138151, 9.026733359695271, 9.98757989733569, 10.716993622640473, 11.659124413728362, 12.655229949944557, 13.547186552522824, 13.713407717977628, 12.87870682314847, 11.964386249052762, 12.57175905625697, 13.36216940403851, 14.401502231096961, 14.480465357634591, 13.479262022423509, 13.630889457311259, 12.592481304613282, 11.608264637794234, 10.65845347342216, 9.873309996904604, 9.107021760224093, 9.984169936282147, 10.983254735801921, 11.698323345917427, 12.612690764585954, 13.65856477546785, 13.657031902399776, 12.746502918324722, 11.831846614180826, 11.020080087540375, 11.556756237551511, 12.40850318777238, 13.34663280976193, 14.278602857326389, 14.466116094583349, 14.557834117499201, 13.526149918205206, 12.55830734415088, 11.697326645403665, 10.932942699519067, 10.111030086027718, 10.994222609485131, 11.936958523107952, 12.719967796859708, 13.646685102891198, 13.627330826501703, 12.726940147911982, 11.77053029884788, 10.905238276422287, 9.949951212866033, 10.595172002046425, 11.428289766601393, 12.43555490986034, 13.25861789844978, 14.199209051730167, 14.306136941911253, 14.52565941825738, 13.605005673093256, 12.696340015747351, 11.982229456565817, 11.04462239685062, 12.05663909090045, 12.8622071638932, 13.730186465761816, 13.503378907267754, 12.56878891840996, 11.704896571859054, 10.769170664807442, 9.8639167571682, 8.920493336078156, 9.636550573209199, 10.472561230125056, 11.387493975428368, 12.32405918592577, 13.375508831200335, 13.355643014565251, 14.33122851074704, 14.637268267945345, 13.685543444736041, 12.97417255886115, 12.09542129245062, 13.062985894715235, 13.80830111060951, 13.539757328505676, 12.625906751373083, 11.62012156118826, 10.65434055740073, 9.723860018970264, 8.870173921853407, 7.8623571415537565, 8.644450763666233, 9.53972720060781, 10.452874111781806, 11.4183347462154, 12.423688682609217, 12.584836936546802, 13.575504519445559, 14.504611932500197, 14.70963654228856, 14.029839187844006, 13.080883968292627, 14.016553235539979, 13.614624288284322, 12.597941438277411, 11.630738968734871, 10.677579800971914, 9.721901331724926, 8.791765683108277, 7.824212312294431, 6.89210729901695, 7.628470292886732, 8.575794882785392, 9.507652563063916, 10.532908083072282, 11.524164394815731, 11.662200384116712, 12.572872531286498, 13.55165754538325, 14.514573083607225, 15.061227021210904, 14.062927030992268, 13.471391446664219, 12.545944057043737, 11.586782966305641, 10.667676918385517, 9.72387452332768, 8.770733842848024, 7.849101044120886, 6.830114119457142, 5.876505396467364, 6.6913042012587, 7.6959527263462215, 8.639383466490266, 9.641375590785847, 10.700706334409956, 10.6557083394066, 11.598682290780486, 12.59706683753889, 13.545373076112497, 14.433029787028534, 13.612762934872755, 12.538177898745463, 11.602771690518617, 10.632969998605319, 9.697574486361384, 8.744256894093631, 7.769317860092051, 6.835764819591182, 5.907237695087375, 4.88780340130571, 5.705372823074341, 6.748584279495367, 7.738536250278095, 8.693453167421218, 9.67768651114801, 9.689076914210164, 10.639238663593169, 11.53938386528986, 12.547170311761903, 13.489068791535137, 12.816036728694518, 11.870392102930648, 10.820887395501076, 9.798920788125336, 8.822092364678696, 7.794950436129017, 6.738956201996778, 5.807808203890515, 4.8608388181151305, 3.935638374711666, 4.745669232352105, 5.729439328788203, 6.667921796771037, 7.66558891014529, 8.666038295756191, 8.734503819858704, 9.67221684397881, 10.601476533665226, 11.56115930696038, 12.494431567908794, 11.825245197184234, 10.855835071277118, 9.840698413389923, 8.776691374987461, 7.89634447164039, 6.900050255316409, 5.935723655492666, 4.866670609167259, 3.883401846860242, 2.9195550440989653, 3.7728953931529308, 4.73119385402755, 5.7157412662613645, 6.739322037665376, 7.739419048318379, 7.727303029699988, 8.73639590129516, 9.666009724014838, 10.7185942961699, 11.676805785687115, 10.821132635595497, 9.847478781906483, 8.806030498397432, 7.768877440144547, 6.90985880955, 5.891997296315177, 4.89370568616242, 3.8917419984990147, 2.8842752471303648, 1.8906503842342102, 2.8293968531795413, 3.775509830191036, 4.745756413537791, 5.710742480154016, 6.753130556905842, 6.812143076240508, 7.773372825801122, 8.810539164315522, 9.752278625755158, 10.741610102250059, 9.915624418866672, 8.87957762933598, 7.88659492096676, 6.81617797719678, 5.8390491776147195, 4.855629808354584, 3.8460726995841155, 2.8986712746067544, 1.9358460576591137, 0.9518523878370133, 1.891870063819682, 2.9243610844452914, 3.9051143631450134, 4.878066779164211, 5.820760370094057, 6.009700752769498, 6.967734133309424, 7.963282424541355, 8.92507406731364, 9.984866469471049, 9.213308400921575, 8.16044479675191, 7.116090184804209, 6.0442860295704595, 5.080756583762549, 4.023893649928787, 3.0246182553357834, 2.0689277721030854, 1.0499823812410762, 0.0, 0.9672525533942995, 1.9799745888121998, 2.9224640048373707, 3.9088111657086246, 4.958058323970343, 6.761404349011382, 7.82910664069999, 8.811169211331045, 9.802180057723405, 10.811115918878876, 9.837010337348476, 8.788436767061311, 7.805815397639619, 6.838392717240695, 5.893935963586234, 4.968585843352518, 4.032377973212734, 2.9996183773507594, 2.0447577469730187, 1.0150467050211736, 1.904847968283335, 2.9773004717221188, 3.9938592141179146, 4.861566479721283, 5.795706543967599, 7.692159156530265, 8.721661690972478, 9.759983626544969, 10.74377055607614, 11.725868454553376, 10.72691197505255, 9.747217698329099, 8.775126786342266, 7.820705585425992, 6.892961696239918, 5.906238082364279, 4.995060784778066, 4.037531957207738, 3.06174889658267, 2.0481970248196415, 2.8965698454099593, 3.9014334507245945, 4.9745942520822, 5.875875949896621, 6.727267773734384, 8.645220582203551, 9.592093867601687, 10.57812564160361, 11.598216032921705, 12.649424025920418, 11.694299984131673, 10.737998796262127, 9.745082370921095, 8.764516248636774, 7.830616685736384, 6.899458317934498, 5.878694504753646, 4.950125287291052, 4.009676930633859, 3.0719429190790395, 3.9457483651297625, 4.861626182033813, 5.8262988197898, 6.787102270732739, 7.69147816470014, 9.605558995455668, 10.58627198655538, 11.54744801928466, 12.48436319926811, 13.558636122414581, 12.74487499299313, 11.690541780181555, 10.766371173740934, 9.780226783765613, 8.806290151469389, 7.868958572763048, 6.814788371667599, 5.944958277500536, 5.067700949806624, 4.064682957131426, 4.881277228881651, 5.823868135621052, 6.804471645674407, 7.846561399348696, 8.641369627566949, 10.633311990130519, 11.605290977330883, 12.57933912257186, 13.417054911435308, 14.450636273552892, 13.653688450372458, 12.69816836818333, 11.734621426135508, 10.77570987697664, 9.77474575781341, 8.735198254605262, 7.778243994680411, 6.973366616774076, 6.074936239369133, 5.089914565318994, 5.910256021168737, 6.790512870578353, 7.792926478945001, 8.80541731960193, 9.66472637541674], [9.662177346099774, 8.712532832980225, 7.719190497436236, 6.759398343894665, 5.956425050174959, 6.93582144696166, 7.9501033498834985, 8.912678996331596, 9.702341955523712, 10.67148701973964, 11.65905285667689, 12.685528446963042, 13.649471119603437, 14.639464018245539, 14.601344781336664, 13.777019476753626, 13.401463058634633, 12.677214027945931, 11.691426750130937, 10.671790279737168, 10.63365281201364, 9.688568717660381, 8.749996808445077, 7.699796422882608, 6.944003786157115, 7.921216999107917, 8.889996553961435, 9.825222285516126, 10.679261195951996, 11.66364072265489, 12.61774598066367, 13.547378990064935, 14.58610300803766, 14.650266568620122, 13.674379388523928, 12.71144571798118, 13.432825858744255, 13.507788623813642, 12.52116930677354, 11.57424291821752, 11.651374075276335, 10.689224539449194, 9.726555652893467, 8.728690296035573, 7.953107547445636, 8.909555445607221, 9.913598225449185, 10.874444763089604, 11.654685506111901, 12.596816297199792, 13.592921833415987, 14.484878435994254, 14.546732557314677, 13.628148321143456, 12.65514843127669, 11.66047009335297, 12.450880441134512, 13.49021326819296, 13.513212804240291, 12.51200946902921, 12.66363690391696, 11.625228751218982, 10.641012084399934, 9.69120092002786, 8.906057443510305, 9.933326871693163, 10.87103480203606, 11.870119601555835, 12.636015229388855, 13.550382648057385, 14.59625665893928, 14.526914947050388, 13.579827757661771, 12.59901416044296, 11.710842269764303, 10.64546727464751, 11.49721422486838, 12.43534384685793, 13.367313894422388, 13.49886354118905, 13.590581564104902, 12.558897364810907, 11.59105479075658, 10.730074092009366, 9.965690146124768, 10.89933807483332, 11.881087475239045, 12.823823388861866, 13.657659680331136, 14.584376986362628, 14.506910665946746, 13.596823192562594, 12.60385513818493, 11.672405822684421, 10.64071339508996, 9.683883039142424, 10.517000803697393, 11.524265946956339, 12.347328935545779, 13.287920088826166, 13.39484797900725, 13.55840686486308, 12.637753119698957, 11.729087462353052, 11.036792029911622, 11.832930385656223, 12.87319021250518, 13.749072029647113, 14.667878349233245, 14.382958746712797, 13.448368757855002, 12.584476411304097, 11.60249550414449, 10.631084303430335, 9.68766088234029, 8.725261610305198, 9.561272267221055, 10.476205012524368, 11.41277022302177, 12.464219868296333, 12.444354051661248, 13.419939547843038, 13.670015714551045, 12.718290891341741, 12.028735132206956, 12.883729281256223, 13.879537016319965, 14.695165976363423, 14.419337167950719, 13.505486590818126, 12.499701400633302, 11.533920396845772, 10.603439858415307, 9.637341468115542, 8.629524687815891, 7.7331618007622325, 8.62843823770381, 9.541585148877806, 10.507045783311398, 11.512399719705215, 11.629773104007738, 12.620440686906495, 13.543584596287065, 13.742383988894261, 13.084401761189811, 13.869191957098229, 14.833104357144709, 14.494204127729365, 13.477521277722454, 12.510318808179914, 11.557159640416959, 10.60148117116997, 9.67134552255332, 8.64354991967122, 7.659274845279084, 6.717181329982731, 7.664505919881391, 8.596363600159915, 9.621619120168281, 10.61287543191173, 10.70117304790358, 11.611845195073366, 12.590630209170119, 13.547320530212925, 14.11578959455671, 14.85123501979787, 14.350971286109262, 13.42552389648878, 12.466362805750684, 11.54725675783056, 10.603454362772723, 9.650313682293069, 8.728680883565929, 7.671363366663262, 6.717754643673484, 5.780015238354699, 6.784663763442221, 7.728094503586265, 8.730086627881844, 9.787966303667316, 9.694681003193468, 10.637654954567354, 11.62981428414459, 12.578120522718198, 13.465777233634235, 14.461963490579254, 13.417757738190506, 12.48235152996366, 11.512549838050361, 10.577154325806427, 9.623836733538674, 8.648897699537095, 7.715344659036226, 6.786817534532418, 5.767383240750754, 4.79408386017034, 5.837295316591367, 6.827247287374094, 7.782164204517216, 8.722502139077323, 8.728049577997032, 9.674459677401003, 10.57213131189556, 11.579917758367603, 12.521816238140838, 13.586510831312449, 12.764924909834319, 11.715420202404747, 10.67850062757038, 9.701672204123739, 8.67453027557406, 7.618536041441822, 6.687388043335559, 5.740418657560174, 4.81521821415671, 3.8343802694481046, 4.818150365884202, 5.7566328338670365, 6.7542999472412895, 7.710853923685503, 7.773476483645573, 8.70496429058451, 9.634223980270926, 10.593906753566081, 11.527179014514495, 12.514732918241698, 11.823087624671418, 10.80795096678422, 9.743943928381759, 8.86359702503469, 7.867302808710709, 6.902976208886965, 5.833923162561558, 4.850654400254541, 3.840834044935389, 2.861606430248931, 3.8199048911235503, 4.8044523033573645, 5.828033074761376, 6.778391712105249, 6.7662756934868575, 7.76914334790086, 8.698757170620539, 9.751341742775601, 10.709553232292814, 11.704289226569035, 10.814731335300783, 9.773283051791731, 8.736129993538846, 7.8771113629443, 6.859249849709476, 5.8609582395567195, 4.858994551893314, 3.8515278005246643, 2.8579029376285097, 1.9181078902755408, 2.8642208672870355, 3.8344674506337904, 4.799453517250015, 5.792103220692711, 5.8448905228462085, 6.806120272406822, 7.843286610921221, 8.785026072360857, 9.774357548855757, 10.838766864217181, 9.84683018273028, 8.853847474361059, 7.78343053059108, 6.806301731009019, 5.822882361748883, 4.813325252978415, 3.865923828001054, 2.903098611053413, 1.9191049412313128, 0.9805811009156815, 1.9924082824995515, 2.937861809750714, 3.910814225769912, 4.853507816699757, 5.042448199375198, 6.0004815799151245, 6.996029871147056, 7.957821513919341, 9.01761391607675, 10.023539987382792, 9.127697350146208, 8.083342738198507, 7.011538582964757, 6.048009137156846, 4.991146203323086, 3.9918708087300825, 3.0361803254973845, 2.0172349346353755, 0.9672525533942995, 0.0, 1.0127220354179003, 1.9552114514430712, 2.941558612314325, 3.990805770576044, 5.794151795617083, 6.861854087305691, 7.843916657936746, 8.834927504329105, 9.88590517248424, 10.804262890742775, 9.75568932045561, 8.773067951033918, 7.805645270634994, 6.8611885169805324, 5.935838396746816, 4.999630526607032, 3.9668709307450585, 3.0120103003673178, 1.9803221169827345, 0.9375954148890355, 2.0100479183278193, 3.026606660723615, 3.8943139263269835, 4.8284539905732995, 6.724906603135966, 7.754409137578179, 8.79273107315067, 9.77651800268184, 10.776276412143284, 11.69416452844685, 10.714470251723398, 9.742379339736564, 8.78795813882029, 7.860214249634216, 6.873490635758577, 5.962313338172365, 5.004784510602037, 3.999440780054099, 2.9858889082910705, 1.92931729201566, 2.934180897330295, 4.007341698687901, 4.908623396502321, 5.760015220340084, 7.677968028809251, 8.624841314207385, 9.610873088209308, 10.630963479527404, 11.697698297742443, 12.652822339531188, 11.705251349656427, 10.712334924315392, 9.731768802031072, 8.768308569207813, 7.837150201405927, 6.816386388225075, 5.887817170762481, 4.947368814105287, 3.9734566102586255, 2.9784958117354634, 3.894373628639513, 4.8590462663955005, 5.81984971733844, 6.72422561130584, 8.638306442061369, 9.619019433161078, 10.580195465890359, 11.51711064587381, 12.591383569020282, 13.664157310053605, 12.657794333575854, 11.713153548408865, 10.727009158433544, 9.743982034940817, 8.806650456234475, 7.7524802551390275, 6.882650160971965, 6.005392833278052, 4.951547822885339, 3.9140246754873522, 4.856615582226753, 5.837219092280107, 6.879308845954396, 7.674117074172649, 9.66605943673622, 10.638038423936582, 11.612086569177558, 12.449802358041008, 13.483383720158592, 14.510019844085829, 13.66542092157763, 12.68140380080344, 11.72249225164457, 10.71243764128484, 9.672890138076692, 8.71593587815184, 7.911058500245504, 6.961801105123047, 5.976779431072908, 4.943003467774438, 5.823260317184054, 6.825673925550701, 7.83816476620763, 8.69747382202244], [8.714377227380231, 7.76473271426068, 6.771390378716691, 5.8115982251751195, 6.865064928789094, 7.869763243877944, 8.884045146799782, 9.897749072652356, 10.687412031844474, 11.6565570960604, 12.64412293299765, 13.670598523283802, 14.634541195924196, 15.354877315738573, 14.398277784883996, 13.427241957627334, 12.388741023216735, 11.664491992528033, 10.678704714713037, 9.659068244319268, 9.685852693294095, 8.740768598940836, 7.802196689725533, 6.751996304163063, 7.687149708888363, 8.664362921839166, 9.725388810487239, 10.66061454204193, 11.647361548674391, 12.64871079897565, 13.60281605698443, 14.532449066385695, 15.57117308435842, 15.624097093945561, 14.648209913849367, 13.68527624330662, 12.842075282922668, 12.521308253708273, 11.534688936668173, 10.587762548112153, 10.70357395655679, 9.741424420729649, 8.778755534173921, 7.780890177316028, 8.696253470176885, 9.652701368338471, 10.701915081856487, 11.709837019615408, 12.622785858834296, 13.575614805392364, 14.577991909736747, 15.469948512315014, 15.520563082640116, 14.601978846468896, 13.628978956602129, 12.63430061867841, 11.860129865312924, 12.853492198022533, 12.526732434134924, 11.525529098923842, 11.715836785197414, 10.677428632499437, 9.693211965680389, 8.743400801308315, 9.649203366241553, 10.676472794424413, 11.659351658443363, 12.658436457963138, 13.60411558211125, 14.529181156249956, 15.575055167131852, 15.500745472375828, 14.553658282987211, 13.5728446857684, 12.684672795089742, 11.61929779997295, 10.906463649046794, 11.798622776687502, 12.680205503403098, 12.512383171083682, 12.642781445385356, 11.611097246091362, 10.643254672037035, 9.78227397328982, 10.708836068856016, 11.642483997564568, 12.631535642839589, 13.57427155646241, 14.556703042361688, 15.5631754945552, 15.48074119127219, 14.570653717888034, 13.577685663510369, 12.646236348009861, 11.6145439204154, 10.657713564467864, 9.926250227875807, 10.837157555937049, 11.660220544526489, 12.600811697806876, 12.577459470011345, 12.610606746143535, 11.689953000979411, 10.781287343633506, 11.77993795264287, 12.57607630838747, 13.616336135236429, 14.499520197247657, 15.472433057683212, 15.35678927203824, 14.422199283180445, 13.55830693662954, 12.57632602946993, 11.604914828755774, 10.66149140766573, 9.699092135630638, 8.970521691399469, 9.789096621505077, 10.72566183200248, 11.733184072980418, 11.584257381887982, 12.559842878069771, 12.7222155958315, 11.770490772622196, 12.74676302447627, 13.62687520398747, 14.622682939051213, 15.445614143963967, 15.39316769327616, 14.47931711614357, 13.473531925958746, 12.507750922171216, 11.57727038374075, 10.611171993440982, 9.603355213141331, 8.706992326087672, 8.037687661882224, 8.854476757858516, 9.819937392292108, 10.744141785062043, 10.61705106858984, 11.607718651488597, 12.530862560869167, 12.794583870174716, 13.802429653459125, 14.612337879829477, 15.576250279875957, 15.468034653054808, 14.451351803047896, 13.484149333505355, 12.5309901657424, 11.575311696495412, 10.645176047878763, 9.617380444996659, 8.633105370604524, 7.6910118553081706, 7.073755344059804, 7.909255209140626, 8.899547419418905, 9.735796480330114, 9.688451012485682, 10.599123159655468, 11.57790817375222, 12.534598494795024, 13.503725477817916, 14.461037555507612, 15.324801811434703, 14.399354421814223, 13.440193331076125, 12.521087283156001, 11.577284888098164, 10.62414420761851, 9.70251140889137, 8.645193891988702, 7.691585168998923, 6.753845763680139, 6.071139294464497, 6.907031157345296, 7.858176256189806, 8.775244268249416, 8.68195896777557, 9.624932919149456, 10.61709224872669, 11.565398487300298, 12.453055198216337, 13.449241455161356, 14.391588263515947, 13.456182055289101, 12.486380363375803, 11.550984851131869, 10.597667258864115, 9.622728224862536, 8.689175184361666, 7.760648059857858, 6.741213766076194, 5.7679143854957795, 5.014936589583876, 5.9553369156820555, 6.910253832825178, 7.709780103659423, 7.715327542579133, 8.661737641983102, 9.55940927647766, 10.567195722949704, 11.509094202722938, 12.57378879589455, 13.491933257464323, 12.689250727730188, 11.65233115289582, 10.67550272944918, 9.648360800899502, 8.592366566767263, 7.661218568660998, 6.714249182885614, 5.7890487394821495, 4.808210794773544, 3.9957916388767116, 4.884722462174997, 5.88238957554925, 6.6981318882676035, 6.760754448227673, 7.692242255166609, 8.621501944853026, 9.581184718148181, 10.514456979096597, 11.5020108828238, 12.471421008730918, 11.820673002202122, 10.75666596379966, 9.87631906045259, 8.88002484412861, 7.915698244304866, 6.846645197979459, 5.835392364447246, 4.8146645702608275, 3.8354369555743695, 2.9975461641160592, 3.883914265491942, 4.907495036895954, 5.765669676687349, 5.753553658068958, 6.75642131248296, 7.686035135202639, 8.738619707357701, 9.696831196874916, 10.691567191151137, 11.66522104484015, 10.786005087209633, 9.748852028956748, 8.889833398362201, 7.871971885127377, 6.87368027497462, 5.871716587311215, 4.864249835942564, 3.87062497304641, 2.89193841560098, 1.9458254385894853, 2.913589887200685, 3.8785759538169096, 4.779381185274811, 4.832168487428309, 5.7933982369889225, 6.830564575503321, 7.772304036942958, 8.76163551343786, 9.826044828799283, 10.859552218148178, 9.866569509778959, 8.79615256600898, 7.81902376642692, 6.835604397166784, 5.826047288396316, 4.878645863418955, 3.9158206464713134, 2.931826976649213, 1.9933031363335818, 0.9796862470816512, 1.9251397743328136, 2.8980921903520116, 3.8407857812818573, 4.0297261639572985, 4.987759544497225, 5.983307835729156, 6.945099478501441, 8.00489188065885, 9.010817951964892, 10.063681556134556, 9.096064773616408, 8.024260618382659, 7.060731172574748, 6.003868238740987, 5.004592844147983, 4.048902360915285, 3.0299569700532762, 1.9799745888121998, 1.0127220354179003, 0.0, 0.942489416025171, 1.928836576896425, 2.978083735158144, 4.781429760199183, 5.849132051887791, 6.831194622518846, 7.822205468911206, 8.873183137066341, 9.847288718596742, 10.76841135587351, 9.785789986451817, 8.818367306052894, 7.873910552398433, 6.948560432164717, 6.012352562024933, 4.97959296616296, 4.0247323357852185, 2.9930441524006346, 1.9503174503069358, 1.0233568887717392, 2.0138846253057148, 2.8815918909090836, 3.8157319551553996, 5.712184567718066, 6.741687102160279, 7.780009037732769, 8.763795967263938, 9.763554376725383, 10.762510856226209, 11.727192287141298, 10.755101375154464, 9.80068017423819, 8.872936285052116, 7.886212671176478, 6.9750353735902655, 6.017506546019938, 5.012162815471999, 3.9986109437089707, 2.9420393274335606, 1.9863807786107492, 3.032688325161785, 3.8959013610844213, 4.747293184922184, 6.665245993391351, 7.6121192787894865, 8.59815105279141, 9.618241444109506, 10.684976262324545, 11.64010030411329, 12.596401491982835, 11.725056959733292, 10.741421455311722, 9.753378645528574, 8.82222027772669, 7.801456464545837, 6.872887247083243, 5.93243889042605, 4.926065903259679, 3.931105104736517, 2.9465735099199675, 3.9112461476759544, 4.8615865738206026, 5.71150357588794, 7.625584406643469, 8.60629739774318, 9.567473430472461, 10.504388610455912, 11.578661533602384, 12.651435274635707, 13.548944475902264, 12.698223624729629, 11.712079234754308, 10.72905211126158, 9.791720532555239, 8.73755033145979, 7.867720237292727, 6.966096352491028, 5.904157115886393, 4.866633968488406, 3.908815463507207, 4.889418973560561, 5.928470131268394, 6.661395038754749, 8.65333740131832, 9.625316388518684, 10.59936453375966, 11.43708032262311, 12.470661684740694, 13.49729780866793, 14.452817890857059, 13.666473877124204, 12.707562327965334, 11.6975077176056, 10.657960214397452, 9.7010059544726, 8.896128576566266, 7.9144103981241, 6.929388724073961, 5.8684807140122714, 4.875460198464507, 5.877873806831154, 6.890364647488083, 7.68475178660454], [7.817014295039854, 7.001336448645533, 6.067226115103013, 6.754087641200291, 7.807554344814266, 8.812252659903116, 9.826534562824953, 10.840238488677532, 11.629901447869647, 12.599046512085575, 13.586612349022825, 14.613087939308977, 15.402380798355503, 14.412387899713401, 13.455788368858824, 12.484752541602163, 11.446251607191563, 10.722002576502861, 9.736215298687865, 8.716578828294097, 8.789413943037292, 7.97737233332569, 7.098032426111855, 7.694485720188235, 8.629639124913535, 9.606852337864337, 10.66787822651241, 11.603103958067102, 12.589850964699563, 13.591200215000825, 14.545305473009606, 15.47493848241087, 16.345601656547757, 15.364325180183005, 14.38275376167156, 13.481325577002764, 12.518365205857531, 11.578818837683102, 10.592199520643002, 9.645273132086981, 9.807135206299987, 8.978028155114503, 8.132863888803785, 8.7233795933412, 9.638742886202056, 10.595190784363643, 11.64440449788166, 12.65232643564058, 13.565275274859468, 14.518104221417536, 15.520481325761923, 16.41243792834019, 16.463052498665288, 15.544468262494066, 14.571468372627299, 13.57679003470358, 12.684997994647098, 11.911002781997361, 11.584243018109753, 10.58303968289867, 10.840129052922403, 9.93943722995365, 9.181989051268104, 9.685890217333487, 10.591692782266724, 11.618962210449585, 12.601841074468535, 13.60092587398831, 14.546604998136422, 15.471670572275128, 16.517544583157026, 16.443234888400998, 15.496147699012381, 14.51533410179357, 13.627162211114912, 12.56178721599812, 11.731331778380968, 10.85613336066233, 11.737716087377926, 11.56989375505851, 11.785152353187907, 10.977612162212738, 10.13203175762475, 10.724763389314992, 11.651325484881188, 12.58497341358974, 13.57402505886476, 14.516760972487582, 15.49919245838686, 16.50566491058037, 16.42323060729736, 15.513143133913204, 14.520175079535539, 13.588725764035031, 12.55703333644057, 11.600202980493034, 10.75111835720998, 9.894668139911877, 10.717731128501317, 11.658322281781704, 11.634970053986173, 11.977121662264912, 11.178730086567125, 11.723776759658678, 12.722427368668042, 13.518565724412642, 14.5588255512616, 15.442009613272829, 16.414922473708383, 16.299278688063406, 15.364688699205614, 14.500796352654708, 13.5188154454951, 12.547404244780944, 11.6039808236909, 10.641581551655808, 9.795389820733643, 8.846607205479906, 9.783172415977308, 10.790694656955248, 10.64176796586281, 11.6173534620446, 12.210992681419214, 12.712980188647368, 13.689252440501441, 14.569364620012642, 15.565172355076385, 16.38810355998914, 16.33565710930133, 15.421806532168738, 14.416021341983914, 13.450240338196384, 12.519759799765918, 11.553661409466152, 10.545844629166501, 9.649481742112842, 8.862555791216398, 7.911987341833344, 8.877447976266936, 9.801652369036873, 9.674561652564668, 10.665229235463425, 11.588373144843997, 12.600052661969482, 13.592623895159642, 14.500591202182083, 15.425108848267655, 16.410524069079976, 15.393841219073066, 14.426638749530525, 13.47347958176757, 12.517801112520582, 11.587665463903932, 10.559869861021829, 9.575594786629694, 8.63350127133334, 7.898623473393978, 6.966765793115454, 7.957058003393733, 8.793307064304944, 8.74596159646051, 9.656633743630298, 10.63541875772705, 11.592109078769852, 12.561236061792744, 13.51854813948244, 14.420474593072147, 15.341843837839392, 14.382682747101295, 13.463576699181171, 12.519774304123334, 11.56663362364368, 10.64500082491654, 9.587683308013872, 8.634074585024093, 7.696335179705309, 6.907972481464168, 5.964541741320124, 6.915686840164634, 7.832754852224246, 7.739469551750399, 8.682443503124286, 9.674602832701519, 10.622909071275126, 11.510565782191165, 12.506752039136185, 13.48726104515339, 14.398671471314271, 13.428869779400973, 12.493474267157039, 11.540156674889285, 10.565217640887706, 9.631664600386836, 8.703137475883029, 7.683703182101364, 6.7104038015209495, 5.899860464839824, 5.012847499656884, 5.967764416800006, 6.767290687634253, 6.772838126553962, 7.719248225957931, 8.616919860452489, 9.624706306924532, 10.566604786697766, 11.631299379869379, 12.549443841439151, 13.566533466935182, 12.59482056892099, 11.61799214547435, 10.590850216924672, 9.534855982792433, 8.603707984686169, 7.656738598910784, 6.7315381555073195, 5.750700210798714, 4.8807155141326595, 3.9422330461498256, 4.939900159524078, 5.7556424722424335, 5.818265032202502, 6.749752839141437, 7.679012528827855, 8.63869530212301, 9.571967563071425, 10.559521466798628, 11.528931592705746, 12.586344484824028, 11.699155379824829, 10.818808476477761, 9.822514260153781, 8.858187660330035, 7.789134614004629, 6.777881780472417, 5.757153986285998, 4.77792637159954, 3.925972261700586, 2.941424849466771, 3.965005620870783, 4.823180260662178, 4.811064242043787, 5.813931896457788, 6.743545719177467, 7.79613029133253, 8.754341780849744, 9.749077775125965, 10.722731628814978, 11.728494503234801, 10.691341444981916, 9.832322814387371, 8.814461301152548, 7.81616969099979, 6.814206003336385, 5.806739251967735, 4.813114389071581, 3.834427831626151, 2.888314854614656, 1.971100471175514, 2.9360865377917387, 3.8368917692496405, 3.8896790714031373, 4.850908820963751, 5.8880751594781495, 6.829814620917786, 7.819146097412687, 8.883555412774111, 9.919602202304803, 10.809058925804129, 9.73864198203415, 8.76151318245209, 7.778093813191954, 6.768536704421486, 5.821135279444125, 4.858310062496484, 3.874316392674384, 2.9357925523587527, 1.922175663106822, 0.9826503583076427, 1.9556027743268407, 2.8982963652566864, 3.087236747932127, 4.045270128472054, 5.040818419703985, 6.00261006247627, 7.06240246463368, 8.068328535939722, 9.121192140109386, 10.038554189641578, 8.966750034407829, 8.003220588599918, 6.946357654766158, 5.947082260173154, 4.991391776940456, 3.972446386078447, 2.9224640048373707, 1.9552114514430712, 0.942489416025171, 0.0, 0.9863471608712541, 2.0355943191329726, 3.8389403441740124, 4.90664263586262, 5.888705206493675, 6.879716052886035, 7.93069372104117, 8.90479930257157, 9.953372872858735, 10.728279402476987, 9.760856722078064, 8.816399968423603, 7.891049848189887, 6.954841978050103, 5.92208238218813, 4.967221751810389, 3.9355335684258055, 2.8928068663321067, 1.9658463047969104, 1.0713952092805439, 1.9391024748839123, 2.8732425391302288, 4.769695151692895, 5.799197686135108, 6.837519621707598, 7.821306551238768, 8.821064960700213, 9.820021440201039, 10.79971571692449, 11.697590791179634, 10.74316959026336, 9.815425701077286, 8.828702087201648, 7.9175247896154355, 6.959995962045108, 5.95465223149717, 4.941100359734142, 3.8845287434587314, 2.9288701946359206, 2.090198909136614, 2.9534119450592495, 3.8048037688970133, 5.72275657736618, 6.669629862764316, 7.655661636766239, 8.675752028084334, 9.742486846299373, 10.697610888088118, 11.653912075957663, 12.667546375758462, 11.683910871336893, 10.695868061553746, 9.764709693751861, 8.74394588057101, 7.815376663108415, 6.874928306451221, 5.868555319284851, 4.873594520761689, 3.889062925945139, 3.070215310560852, 3.9190971577954308, 4.7690141598627696, 6.683094990618297, 7.6638079817180085, 8.62498401444729, 9.56189919443074, 10.636172117577212, 11.708945858610535, 12.606455059877092, 13.561478791588206, 12.654568650779481, 11.671541527286754, 10.734209948580412, 9.680039747484964, 8.8102096533179, 7.9085857685161995, 6.846646531911564, 5.809123384513578, 4.851304879532378, 4.048388136445459, 4.9859807152432225, 5.718905622729578, 7.710847985293148, 8.682826972493512, 9.656875117734488, 10.494590906597939, 11.528172268715522, 12.554808392642759, 13.510328474831887, 14.541584901611824, 13.650051743990508, 12.639997133630775, 11.600449630422627, 10.643495370497774, 9.83861799259144, 8.856899814149273, 7.871878140099133, 6.810970130037443, 5.817949614489679, 5.081665991276965, 6.055157529788678, 6.742262370579368], [6.8306671341686, 6.01498928777428, 6.890564252409277, 7.7232508008782546, 8.776717504492229, 9.78141581958108, 10.795697722502917, 11.809401648355493, 12.59906460754761, 13.568209671763537, 14.555775508700787, 15.379976310124643, 14.416033637484249, 13.426040738842147, 12.46944120798757, 11.498405380730908, 10.459904446320309, 9.735655415631609, 8.74986813781661, 7.730231667422842, 7.803066782166038, 6.991025172454436, 7.921370563418119, 8.663648879866198, 9.598802284591498, 10.5760154975423, 11.637041386190374, 12.572267117745065, 13.559014124377526, 14.560363374678786, 15.514468632687567, 16.322259205750697, 15.359254495676502, 14.377978019311751, 13.396406600800306, 12.49497841613151, 11.532018044986277, 10.592471676811847, 9.605852359771747, 8.658925971215726, 8.820788045428733, 7.991680994243249, 8.956202026110049, 9.692542753019163, 10.60790604588002, 11.564353944041606, 12.613567657559623, 13.621489595318543, 14.534438434537432, 15.4872673810955, 16.489644485439882, 17.259758651680016, 16.33722144398702, 15.388637447914311, 14.415637558047544, 13.54595404075972, 12.51396346259602, 11.561910731954933, 10.597895857238498, 9.596692522027416, 9.853781892051149, 8.953090069082396, 9.937306735901444, 10.65505337701145, 11.560855941944688, 12.588125370127548, 13.5710042341465, 14.570089033666275, 15.515768157814385, 16.44083373195309, 17.486707742834987, 17.429582049272252, 16.482494859883637, 15.501681262664825, 14.613509371986167, 13.548134376869374, 12.702173767730887, 11.826975350012251, 10.948092388178923, 10.583546594187256, 10.798805192316653, 9.991265001341484, 10.88734944225809, 11.693926548992955, 12.620488644559153, 13.554136573267705, 14.543188218542726, 15.485924132165547, 16.468355618064827, 17.474828070258337, 17.40957776816861, 16.499490294784458, 15.506522240406794, 14.575072924906285, 13.543380497311825, 12.586550141364288, 11.7219603465599, 10.865510129261798, 9.928107429302313, 10.77914089558521, 10.648622893114918, 10.990774501393657, 11.934047771200465, 12.692939919336641, 13.691590528346007, 14.487728884090608, 15.527988710939566, 16.411172772950795, 17.38408563338635, 17.28562584893466, 16.351035860076866, 15.487143513525963, 14.505162606366355, 13.533751405652199, 12.590327984562155, 11.627928712527062, 10.766231810083562, 9.817449194829827, 8.993548716778305, 9.804347496083993, 9.655420804991556, 10.631006301173345, 11.59317698429207, 12.637798598650747, 13.61407085050482, 14.499706717152835, 15.392329028221145, 16.37682791631044, 17.322004270172584, 16.408153693039992, 15.402368502855168, 14.436587499067638, 13.506106960637172, 12.540008570337406, 11.532191790037755, 10.635828902984096, 9.833397780566317, 8.882829331183265, 8.029430401069142, 8.815305208165618, 8.688214491693413, 9.67888207459217, 10.602025983972743, 11.613705501098227, 12.606276734288388, 13.514244041310828, 14.4387616873964, 15.43031913387034, 16.38018837994432, 15.41298591040178, 14.459826742638825, 13.504148273391836, 12.574012624775186, 11.546217021893083, 10.561941947500948, 9.619848432204595, 8.869465462743898, 7.937607782465375, 7.089711236023367, 7.80695990343369, 7.759614435589256, 8.670286582759044, 9.649071596855796, 10.605761917898597, 11.57488890092149, 12.532200978611186, 13.434127432200892, 14.379492459034104, 15.359934752122603, 14.449923860052426, 13.506121464994589, 12.552980784514935, 11.631347985787794, 10.574030468885125, 9.620421745895346, 8.682682340576562, 7.878814470814089, 6.935383730670045, 6.048340072794268, 6.846407691352992, 6.7531223908791445, 7.696096342253031, 8.688255671830264, 9.636561910403872, 10.52421862131991, 11.52040487826493, 12.500913884282136, 13.436320092508982, 14.40612178442228, 13.479821428028293, 12.52650383576054, 11.55156480175896, 10.61801176125809, 9.689484636754283, 8.670050342972619, 7.696750962392204, 6.870702454189745, 5.983689489006805, 5.10041764942964, 5.780943526762998, 5.786490965682708, 6.732901065086677, 7.630572699581235, 8.638359146053277, 9.580257625826512, 10.644952218998124, 11.563096680567897, 12.580186306063927, 13.581167729792245, 12.604339306345604, 11.577197377795926, 10.521203143663687, 9.590055145557423, 8.64308575978204, 7.717885316378574, 6.737047371669968, 5.851557503482581, 4.913075035499746, 4.070647712085373, 4.769295311371179, 4.831917871331248, 5.763405678270184, 6.692665367956601, 7.652348141251755, 8.58562040220017, 9.573174305927374, 10.542584431834491, 11.599997323952774, 12.664004362355236, 11.805155637349012, 10.808861421025032, 9.84453482120129, 8.775481774875884, 7.764228941343672, 6.743501147157253, 5.764273532470795, 4.896814251050507, 3.9122668388166923, 3.045693788265774, 3.836833099790924, 3.8247170811725324, 4.827584735586535, 5.7571985583062135, 6.809783130461277, 7.76799461997849, 8.76273061425471, 9.736384467943724, 10.777832751452776, 11.67768860585317, 10.818669975258626, 9.8008084620238, 8.802516851871044, 7.800553164207639, 6.793086412838989, 5.799461549942835, 4.820774992497405, 3.8746620154859106, 2.941942460525435, 1.9769563939092103, 2.8505446083783865, 2.9033319105318833, 3.864561660092497, 4.901727998606896, 5.843467460046533, 6.832798936541433, 7.897208251902858, 8.93325504143355, 9.92623774980277, 10.724989142905404, 9.747860343323344, 8.76444097406321, 7.75488386529274, 6.807482440315379, 5.844657223367738, 4.860663553545638, 3.9221397132300067, 2.9085228239780765, 1.9689975191788966, 0.9692556134555868, 1.9119492043854325, 2.1008895870608733, 3.0589229676007994, 4.054471258832731, 5.016262901605016, 6.076055303762425, 7.081981375068468, 8.134844979238132, 9.179199591185833, 9.953097195279083, 8.989567749471172, 7.932704815637411, 6.933429421044408, 5.97773893781171, 4.958793546949701, 3.9088111657086246, 2.941558612314325, 1.928836576896425, 0.9863471608712541, 0.0, 1.0492471582617187, 2.852593183302758, 3.9202954749913657, 4.902358045622421, 5.893368892014781, 6.944346560169915, 7.918452141700315, 8.96702571198748, 9.949647081409173, 10.747203882949318, 9.802747129294858, 8.877397009061141, 7.941189138921358, 6.908429543059384, 5.953568912681643, 4.92188072929706, 3.8791540272033607, 2.9521934656681643, 2.0141058206794176, 0.9527553140126583, 1.8868953782589746, 3.7833479908216407, 4.812850525263854, 5.851172460836343, 6.834959390367514, 7.834717799828957, 8.833674279329783, 9.813368556053234, 10.79538250348815, 11.729516751134614, 10.80177286194854, 9.815049248072903, 8.90387195048669, 7.946343122916362, 6.940999392368424, 5.927447520605395, 4.870875904329985, 3.9152173555071745, 2.929170062997358, 1.9670647841879958, 2.818456608025759, 4.736409416494926, 5.683282701893061, 6.669314475894985, 7.689404867213081, 8.75613968542812, 9.711263727216865, 10.66756491508641, 11.684040162491405, 12.653074031014858, 11.665031221231711, 10.733872853429826, 9.713109040248973, 8.784539822786378, 7.844091466129186, 6.837718478962815, 5.842757680439653, 4.858226085623103, 3.8935534478671165, 2.9327499969241773, 3.782666998991515, 5.696747829747043, 6.677460820846754, 7.638636853576036, 8.575552033559486, 9.649824956705958, 10.722598697739281, 11.620107899005838, 12.575131630716951, 13.561276020692272, 12.640704686964717, 11.703373108258376, 10.649202907162927, 9.779372812995863, 8.877748928194162, 7.815809691589528, 6.778286544191541, 5.8204680392103425, 4.871726273751723, 3.999633554371969, 4.732558461858323, 6.724500824421893, 7.6964798116222575, 8.670527956863236, 9.508243745726684, 10.541825107844268, 11.568461231771504, 12.523981313960633, 13.55523774074057, 14.51414928989944, 13.609160293308737, 12.569612790100589, 11.612658530175738, 10.807781152269403, 9.826062973827234, 8.841041299777096, 7.780133289715407, 6.787112774167643, 5.905004128583229, 5.068810368917425, 5.755915209708114], [5.99303678647136, 6.842563733836811, 7.8298115055302535, 8.662498053999231, 9.715964757613206, 10.720663072702056, 11.734944975623893, 12.748648901476471, 13.538311860668587, 14.507456924884515, 15.495022761821765, 14.542345962427405, 13.57840328978701, 12.588410391144908, 11.631810860290331, 10.66077503303367, 9.622274098623068, 8.898025067934366, 7.912237790119371, 6.892601319725602, 6.965436434468798, 7.818599618516967, 8.797056825310149, 9.602896132987174, 10.538049537712475, 11.515262750663277, 12.57628863931135, 13.511514370866042, 14.498261377498503, 15.499610627799765, 16.414261867454723, 15.484628858053458, 14.521624147979264, 13.540347671614512, 12.558776253103067, 11.657348068434269, 10.694387697289036, 9.754841329114608, 8.768222012074506, 7.821295623518486, 7.983157697731492, 8.81925544030578, 9.831888288002078, 10.63179000614014, 11.547153299000996, 12.503601197162583, 13.552814910680599, 14.56073684843952, 15.473685687658408, 16.426514634216478, 17.389437720207038, 16.422128303982777, 15.49959109628978, 14.551007100217072, 13.578007210350306, 12.708323693062479, 11.67633311489878, 10.724280384257693, 9.760265509541258, 8.759062174330175, 9.01615154435391, 9.780664515144927, 10.764881181963975, 11.594300630132427, 12.500103195065664, 13.527372623248525, 14.510251487267475, 15.50933628678725, 16.455015410935363, 17.38008098507407, 18.425954995955966, 17.430126944606076, 16.466495895942685, 15.570427492832819, 14.522313371862692, 13.688581506359883, 12.61909003743009, 11.68096041544054, 10.683424086225207, 9.745916246490015, 9.961174844619414, 10.818839447404015, 11.714923888320621, 12.633173802113932, 13.559735897680127, 14.49338382638868, 15.4824354716637, 16.42517138528652, 17.4076028711858, 18.414075323379315, 18.458824926430328, 17.54873745304618, 16.555769398668513, 15.588674770501832, 14.525265885326547, 13.56843552937901, 12.590768694222618, 11.702507603937386, 10.725270699399074, 9.907859046592655, 9.777341044122364, 10.732547045619095, 11.723954059222347, 12.751879260721022, 13.734732103807598, 14.644665398567378, 15.492835617850469, 16.41708164884129, 17.389994509276843, 18.321269237662747, 17.400283018338584, 16.536390671787682, 15.554409764628073, 14.582998563913916, 13.639575142823873, 12.609814100541785, 11.63504015774628, 10.686257542492545, 9.790711986875065, 8.93306564709144, 8.784138955999001, 9.75972445218079, 10.721895135299516, 11.766516749658193, 12.742789001512264, 13.593866502967378, 14.486488814035685, 15.47098770212498, 16.429143766499667, 17.3854892107013, 16.451615661116886, 15.485834657329356, 14.55535411889889, 13.589255728599124, 12.581438948299473, 11.661651441595033, 10.702206128229035, 9.751637678845983, 8.826593671165902, 7.944023359173065, 7.816932642700859, 8.807600225599616, 9.730744134980188, 10.742423652105673, 11.700436520102931, 12.608403827125372, 13.53292147321094, 14.52447891968488, 15.529067847625438, 16.36884156485424, 15.509073900900542, 14.553395431653554, 13.623259783036904, 12.595464180154801, 11.611189105762666, 10.669095590466313, 9.738273810406616, 8.806416130128092, 7.886874506120128, 6.935678054441136, 6.888332586596702, 7.7990047337664885, 8.777789747863242, 9.69992170371314, 10.669048686736033, 11.62636076442573, 12.528287218015432, 13.473652244848644, 14.454094537937143, 15.405779514504887, 14.555368623256307, 13.602227942776652, 12.680595144049512, 11.623277627146843, 10.669668904157064, 9.73192949883828, 8.747622818476806, 7.804192078332762, 6.845503342891028, 5.9751258423604385, 5.88184054188659, 6.824814493260477, 7.782415457644806, 8.730721696218415, 9.618378407134454, 10.614564664079474, 11.595073670096676, 12.530479878323522, 13.50028157023682, 14.435677082480755, 13.575750994022258, 12.600811960020678, 11.667258919519808, 10.738731795016001, 9.719297501234337, 8.74599812065392, 7.853757380053778, 6.852497836669522, 5.8975809195263995, 4.909661677770445, 4.9152091166901535, 5.82706085090122, 6.724732485395777, 7.732518931867821, 8.674417411641056, 9.739112004812664, 10.657256466382437, 11.674346091878467, 12.711265666712835, 13.653586464607322, 12.626444536057644, 11.570450301925405, 10.639302303819141, 9.692332918043757, 8.767132474640292, 7.786294529931686, 6.834612429346613, 5.896129961363779, 4.898462847989526, 3.8980134623786253, 3.960636022338694, 4.857565464084726, 5.786825153771144, 6.746507927066298, 7.679780188014712, 8.667334091741916, 9.636744217649031, 10.694157109767314, 11.758164148169776, 12.83145448503337, 11.85810857928675, 10.893781979463007, 9.824728933137603, 8.81347609960539, 7.792748305418971, 6.8135206907325125, 5.910919583917644, 4.92637217168383, 4.015530134806764, 2.96555125079837, 2.9534352321799786, 3.9217445214010773, 4.851358344120756, 5.847089878540538, 6.798693655253711, 7.793429649529931, 8.767083503218945, 9.808531786727997, 10.845684844980882, 11.817042739386949, 10.850055620285518, 9.851764010132761, 8.849800322469358, 7.842333571100707, 6.848708708204553, 5.870022150759123, 4.923909173747629, 3.9560477933925724, 2.9910617267763477, 1.9792627593858327, 1.997491696346426, 2.9587214459070394, 3.9324270338821172, 4.874166495321754, 5.863497971816654, 6.927907287178079, 7.963954076708771, 8.95693678507799, 10.02735372884797, 10.797107501585062, 9.813688132324927, 8.804131023554458, 7.856729598577097, 6.893904381629456, 5.909910711807356, 4.971386871491726, 3.9577699822397947, 3.0182446774406153, 1.9833609463227244, 1.0406673553928787, 1.0516424287991546, 2.0096758093390807, 3.005224100571012, 3.967015743343297, 5.0268081455007065, 6.032734216806748, 7.085597820976411, 8.129952432924114, 9.201756588157863, 10.038814907732892, 8.98195197389913, 7.982676579306126, 7.026986096073428, 6.008040705211419, 4.958058323970343, 3.990805770576044, 2.9780837351581435, 2.0355943191329726, 1.0492471582617187, 0.0, 2.014962835605518, 2.967842794685151, 3.9499053653162064, 4.892785722308144, 5.943763390463278, 6.917868971993678, 7.966442542280843, 8.949063911702536, 9.91648659210146, 10.851994287556575, 9.92664416732286, 8.990436297183075, 7.957676701321102, 7.002816070943362, 5.971127887558778, 4.928401185465079, 4.0014406239298825, 3.04475560147481, 1.9834050948080504, 1.0492650305617341, 2.9457176431244005, 3.975220177566614, 4.993415351130877, 5.8507185297076205, 6.850476939169064, 7.84943341866989, 8.829127695393343, 9.81114164282826, 10.765562843744533, 11.803560494561367, 10.86429640633462, 9.953119108748409, 8.99559028117808, 7.990246550630142, 6.976694678867114, 5.920123062591704, 4.94157811747594, 3.868417316118334, 2.9063120373089717, 1.9808262603285187, 3.8987790687976855, 4.8456523541958205, 5.831684128197744, 6.782902628066636, 7.849637446281675, 8.80476148807042, 9.761062675939966, 10.77753792334496, 11.709373506955314, 12.604278474352686, 11.673120106550801, 10.65235629336995, 9.723787075907355, 8.783338719250162, 7.776965732083791, 6.7820049335606285, 5.797473338744079, 4.832800700988092, 3.871997250045153, 2.945036651294275, 4.859117482049803, 5.839830473149513, 6.801006505878795, 7.737921685862245, 8.783573711333318, 9.856347452366641, 10.713605659859393, 11.668629391570507, 12.654773781545828, 13.579951940085694, 12.642620361379352, 11.588450160283903, 10.71862006611684, 9.81699618131514, 8.755056944710505, 7.717533797312518, 6.759715292331318, 5.810973526872699, 4.929742778148246, 3.8949281141610834, 5.886870476724654, 6.858849463925017, 7.832897609165994, 8.670613398029444, 9.704194760147027, 10.730830884074264, 11.686350966263392, 12.70451946459554, 13.650256874756854, 14.548407546429715, 13.508860043221567, 12.551905783296714, 11.74702840539038, 10.765310226948213, 9.780288552898073, 8.719380542836383, 7.726360027288619, 6.844251381704205, 5.896384814979956, 4.918284862010874], [5.90946956095341, 6.758996508318861, 7.746244280012302, 8.57893082848128, 9.632397532095254, 10.637095847184105, 11.651377750105942, 12.665081675958518, 13.454744635150636, 14.423889699366562, 13.579261560530401, 12.55278597024425, 11.588843297603855, 10.598850398961753, 9.642250868107176, 8.671215040850514, 7.632714106439914, 6.908465075751215, 5.927261696278357, 4.986306123495887, 6.855590533492651, 7.735032392999017, 8.713489599792199, 9.519328907469223, 10.454482312194523, 11.431695525145326, 12.492721413793399, 13.42794714534809, 14.414694151980552, 15.378807133280349, 14.424701875271568, 13.495068865870303, 12.532064155796109, 11.550787679431357, 10.569216260919912, 9.667788076251115, 8.704827705105883, 7.846677144841125, 6.8600578278010245, 5.915000427288771, 7.836773616676598, 8.73568821478783, 9.748321062484129, 10.548222780622188, 11.463586073483045, 12.420033971644632, 13.469247685162648, 14.477169622921569, 15.390118462140457, 16.31198270782525, 15.399877728023885, 14.432568311799622, 13.510031104106625, 12.561447108033917, 11.58844721816715, 10.718763700879325, 9.686773122715627, 8.816116199984211, 7.8521013252677765, 6.852766978100461, 8.869767463299015, 9.697097289626978, 10.681313956446026, 11.510733404614475, 12.416535969547713, 13.443805397730573, 14.426684261749525, 15.4257690612693, 16.37144818541741, 17.265549058682844, 16.466641457561646, 15.440566952422921, 14.47693590375953, 13.580867500649664, 12.532753379679537, 11.709930807911551, 10.640439338981757, 9.774665219210824, 8.777128889995492, 7.8396210502603, 9.768875195234806, 10.735272221886065, 11.631356662802672, 12.54960657659598, 13.476168672162178, 14.40981660087073, 15.398868246145751, 16.341604159768572, 17.324035645667852, 18.29954339698809, 17.347477174972443, 16.370658706910714, 15.452908523236372, 14.507475838408203, 13.60288225435388, 12.671515043416637, 11.620652760152744, 10.736130439961277, 9.771565744487004, 8.830974591206617, 9.805924679092728, 10.761130680589458, 11.75253769419271, 12.75407928609335, 13.721752309839774, 14.618371457026031, 15.466541676309122, 16.390787707299943, 17.363700567735496, 18.2949752961214, 18.406019083064187, 17.392702282963644, 16.45426815727681, 15.54879735766229, 14.598342433371728, 13.551155239424586, 12.576381296629082, 11.642689667508415, 10.706124457011013, 9.805767990707833, 8.812722590969365, 9.788308087151155, 10.735346138718077, 11.764875857104661, 12.72980920754444, 13.567572561426031, 14.460194872494338, 15.444693760583633, 16.40284982495832, 17.359195269159954, 18.254961686157927, 17.289180682370397, 16.35870014393993, 15.392601753640164, 14.384784973340514, 13.488422086286855, 12.624119233787686, 11.673550784404634, 10.748506776724552, 9.744676922925398, 7.845516277671224, 8.83618386056998, 9.74419513839875, 10.740782759552141, 11.674142578561584, 12.582109885584025, 13.506627531669594, 14.498184978143533, 15.50277390608409, 16.342547623312893, 17.312419925941583, 16.356741456694596, 15.426605808077944, 14.398810205195842, 13.414535130803706, 12.472441615507353, 11.660186915965268, 10.728329235686743, 9.808787611678778, 8.857591159999787, 6.9169162215670665, 7.827588368736853, 8.791240751281803, 9.673627762171797, 10.642754745194686, 11.600066822884383, 12.501993276474085, 13.447358303307297, 14.427800596395796, 15.37948557296354, 16.342318362441212, 15.405573967817693, 14.483941169090553, 13.426623652187883, 12.473014929198104, 11.53527552387932, 10.669535924035458, 9.726105183891413, 8.767416448449678, 7.897038947919089, 5.910424176856955, 6.853398128230841, 7.756121516103461, 8.70442775467707, 9.592084465593107, 10.588270722538127, 11.568779728555329, 12.504185936782175, 13.473987628695474, 14.409383140939408, 15.362700733207161, 14.404157985061719, 13.470604944560849, 12.542077820057042, 11.522643526275377, 10.549344145694961, 9.723295637492502, 8.774410942228172, 7.81949402508505, 6.831574783329096, 4.943792751660518, 5.800766909359874, 6.698438543854431, 7.706224990326475, 8.64812347009971, 9.712818063271317, 10.63096252484109, 11.64805215033712, 12.684971725171488, 13.661800148618129, 14.429790561098685, 13.373796326966445, 12.442648328860182, 11.495678943084798, 10.570478499681332, 9.589640554972727, 8.704150686785338, 7.765668218802505, 6.820375953548178, 5.8199265679372765, 3.9892196573090586, 4.83127152254338, 5.760531212229798, 6.720213985524952, 7.653486246473366, 8.641040150200569, 9.610450276107684, 10.667863168225967, 11.731870206628429, 12.805160543492024, 13.66145460432779, 12.697128004504046, 11.628074958178642, 10.61682212464643, 9.59609433046001, 8.616866715773552, 7.749407434353264, 6.76486002211945, 5.898286971568532, 4.887464356357022, 2.982018867150343, 3.895450579859731, 4.82506440257941, 5.8207959369991915, 6.772399713712366, 7.767135707988586, 8.7407895616776, 9.782237845186652, 10.819390903439537, 11.790748797845604, 12.653401645326557, 11.6551100351738, 10.653146347510397, 9.645679596141747, 8.652054733245592, 7.673368175800163, 6.727255198788669, 5.794535643828193, 4.829549577211968, 3.9011758649444848, 1.9711977548050799, 2.9324275043656933, 3.9061330923407716, 4.847872553780408, 5.837204030275308, 6.901613345636733, 7.937660135167425, 8.930642843536646, 10.001059787306625, 10.951542062535282, 11.617034157365964, 10.607477048595497, 9.660075623618136, 8.697250406670495, 7.713256736848395, 6.774732896532765, 5.761116007280834, 4.821590702481655, 3.8218487967583448, 2.9625804609515307, 1.0253484872578085, 1.9833818677977348, 2.9789301590296664, 3.940721801801951, 5.00051420395936, 6.006440275265403, 7.059303879435066, 8.059383056586944, 9.089779268904016, 10.016439542913783, 10.785297998940171, 9.786022604347167, 8.830332121114468, 7.811386730252458, 6.761404349011382, 5.794151795617083, 4.781429760199183, 3.838940344174012, 2.852593183302758, 2.014962835605518, 0.0, 1.0677022916886079, 2.049764862319663, 3.040775708712023, 4.091753376867158, 5.065858958397557, 6.114432528684722, 7.097053898106414, 8.064476578505339, 9.008933332159799, 9.934283452393515, 9.227841800437854, 8.19508220457588, 7.18454071212312, 6.121692992610515, 5.078966290516816, 4.006513787078033, 2.9611883759568594, 1.8998378692900997, 0.9656978050437836, 0.9307548075188828, 1.9602573419610962, 2.9985792775335858, 3.9823662070647563, 4.9821246165262, 5.981081096027026, 6.960775372750478, 7.942789320185395, 8.897210521101668, 9.935208171918504, 10.871935691405277, 9.923745036179927, 8.966216208609598, 7.932997985311062, 6.919446113548034, 5.862874497272624, 4.8580108919579885, 3.784850090600383, 2.8227448117910208, 1.897259034810568, 1.9092190766145327, 2.856092362012668, 3.8421241360145917, 4.8622145273326876, 5.928949345547727, 6.884073387336471, 7.840374575206018, 8.85684982261101, 9.84102118431245, 10.829063994095597, 11.589552881032851, 10.568789067851998, 9.640219850389403, 8.69977149373221, 7.69339850656584, 6.698437708042678, 5.713906113226129, 4.749233475470142, 3.788430024527202, 2.8614694257763245, 2.952822285820088, 3.850270480966361, 4.811446513695643, 5.748361693679093, 6.822634616825566, 7.895408357858889, 8.792917559125446, 9.74794129083656, 10.73408568081188, 11.717112804304607, 12.5590531358614, 11.504882934765952, 10.635052840598888, 9.733428955797189, 8.671489719192554, 7.633966571794566, 6.676148066813368, 5.7274063013547485, 4.846175552630296, 3.811360888643133, 3.9805752804949384, 4.869289471741864, 5.843337616982842, 6.68105340584629, 7.714634767963874, 8.74127089189111, 9.696790974080239, 10.728047400860177, 11.686958950019047, 12.759365871700771, 13.425292817703614, 12.468338557778763, 11.663461179872428, 10.68174300143026, 9.696721327380121, 8.635813317318433, 7.6427928017706686, 6.7606841561862545, 5.812817589462005, 4.834717636492924], [6.977171852642018, 7.826698800007469, 8.81394657170091, 9.646633120169888, 10.700099823783862, 11.704798138872713, 12.71908004179455, 13.732783967647126, 14.522446926839244, 13.598600209000123, 12.694627048314857, 11.668151458028705, 10.70420878538831, 9.714215886746208, 8.757616355891631, 7.786580528634969, 6.748079594224369, 6.164486433729431, 5.183283054256575, 6.054008415184495, 7.923292825181259, 8.802734684687625, 9.781191891480807, 10.587031199157831, 11.522184603883131, 12.499397816833934, 13.560423705482007, 14.495649437036699, 15.48239644366916, 14.494172621064804, 13.540067363056023, 12.610434353654759, 11.647429643580564, 10.666153167215812, 9.684581748704367, 8.78315356403557, 7.820193192890337, 7.102698502819343, 6.116079185779242, 6.982702718977379, 8.904475908365205, 9.803390506476438, 10.816023354172737, 11.615925072310796, 12.531288365171653, 13.48773626333324, 14.536949976851256, 15.544871914610177, 16.380177142167774, 15.427348195609706, 14.51524321580834, 13.547933799584078, 12.62539659189108, 11.676812595818372, 10.703812705951606, 9.83412918866378, 8.802138610500082, 8.072137557962428, 7.108122683245993, 7.920469269789069, 9.937469754987621, 10.764799581315586, 11.749016248134634, 12.578435696303083, 13.484238261236321, 14.511507689419181, 15.494386553438133, 16.493471352957908, 17.32701161337128, 16.3809145464673, 15.582006945346103, 14.555932440207377, 13.592301391543986, 12.696232988434119, 11.648118867463992, 10.825296295696006, 9.755804826766212, 9.127006979297459, 8.160070542471418, 8.907323341948908, 10.836577486923414, 11.003527158322475, 11.809617813093858, 12.748403407018351, 13.71261027348163, 14.547274518430251, 15.524268908305759, 16.31134709866651, 17.29377858456579, 17.414908884772544, 16.462842662756902, 15.48602419469517, 14.568274011020828, 13.622841326192658, 12.718247742138335, 11.786880531201092, 10.7360182479372, 10.088472200047912, 9.180055501348027, 9.898676882895225, 10.675476283124693, 10.004017658270302, 10.762919484151482, 11.749390036674665, 12.717063060421092, 13.613682207607349, 14.46185242689044, 15.38609845788126, 16.359011318316814, 17.29028604670272, 17.521384570848646, 16.5080677707481, 15.569633645061266, 14.664162845446745, 13.713707921156184, 12.666520727209042, 11.691746784413537, 11.051179424369439, 10.114614213872036, 10.873470282396442, 9.68227419500133, 8.990277119398131, 9.730656889299393, 10.760186607685975, 11.725119958125758, 12.562883312007349, 13.455505623075656, 14.44000451116495, 15.398160575539638, 16.354506019741276, 17.3602912099261, 17.54542482932891, 16.614944290898443, 15.57055256610049, 14.56273578580084, 13.58402612729678, 12.624580813930782, 11.985799288016, 11.078732529581199, 10.614228526957364, 8.715067881703188, 7.979215198759814, 8.739505888980066, 9.736093510133456, 10.669453329142902, 11.577420636165343, 12.501938282250912, 13.49349572872485, 14.498084656665409, 15.337858373894212, 16.38956961149528, 17.293444025204803, 16.438409970215446, 15.410614367333341, 14.426339292941206, 13.484245777644853, 12.551038794593458, 11.619181114314934, 10.699639490306968, 9.748443038627975, 7.786467825599031, 6.906281229838228, 7.78655150186312, 8.668938512753112, 9.638065495776004, 10.5953775734657, 11.497304027055403, 12.442669053888615, 13.423111346977114, 14.374796323544858, 15.337629113022528, 16.3422765363279, 15.495745331228052, 14.438427814325383, 13.484819091335604, 12.54707968601682, 11.560387802663648, 10.616957062519603, 9.658268327077868, 8.787890826547278, 6.779975780888919, 5.932090989332217, 6.751432266684777, 7.699738505258385, 8.587395216174425, 9.583581473119445, 10.564090479136647, 11.499496687363493, 12.469298379276792, 13.404693891520726, 14.358011483788479, 15.340860553571929, 14.482409106698348, 13.553881982194541, 12.534447688412877, 11.561148307832461, 10.666522364240617, 9.665262820856363, 8.71034590371324, 7.722426661957284, 5.813344355692482, 4.863182606309478, 5.693749294435747, 6.701535740907791, 7.643434220681026, 8.708128813852635, 9.626273275422408, 10.643362900918438, 11.680282475752806, 12.657110899199447, 13.684252827749125, 14.385600489103945, 13.454452490997681, 12.507483105222297, 11.582282661818832, 10.601444717110226, 9.647377413533452, 8.708894945550618, 7.711227832176366, 6.710778446565465, 4.880071535937247, 3.8936872194929846, 4.755841962811114, 5.715524736106268, 6.648796997054682, 7.636350900781885, 8.605761026689002, 9.663173918807285, 10.727180957209747, 11.800471294073342, 12.796765510397321, 13.748625161752342, 12.67512499322649, 11.628626286783929, 10.60789849259751, 9.628670877911052, 8.723684568104485, 7.73913715587067, 6.828295118993604, 5.77831623498521, 3.872870745778531, 2.957866276809335, 3.820375153160726, 4.795581054547527, 5.747184831260702, 6.741920825536922, 7.715574679225936, 8.757022962734988, 9.794176020987873, 10.76553391539394, 11.82468280407253, 12.722812326862408, 11.720848639199005, 10.702715438759835, 9.70909057586368, 8.685172337937662, 7.739059360926167, 6.768812777579413, 5.803826710963188, 4.792027743572673, 2.862049633433268, 1.9948432013152972, 2.880918209889107, 3.8226576713287437, 4.8119891478236445, 5.876398463185069, 6.912445252715761, 7.905427961084981, 8.955062581556614, 9.883839770846675, 10.793906211223687, 11.675179340284105, 10.727777915306744, 9.764952698359103, 8.780959028537003, 7.842435188221373, 6.828818298969442, 5.837119692908354, 4.7961259305095645, 3.8534323395797188, 1.9162003658859965, 0.9581669853460703, 1.9537152765780017, 2.898843395988262, 3.9586357981456715, 4.964561869451714, 6.017425473621377, 6.9916807648983355, 8.022076977215407, 8.948737251225177, 9.822067442674996, 10.821342837268, 9.898034412803076, 8.879089021941066, 7.82910664069999, 6.861854087305691, 5.849132051887791, 4.90664263586262, 3.9202954749913657, 2.967842794685151, 1.0677022916886079, 0.0, 0.9820625706310552, 1.9730734170234152, 3.0240510851785496, 3.9981566667089496, 5.0467302369961144, 6.029351606417807, 6.996774286816731, 7.941231040471192, 8.866581160704907, 9.802789030844691, 9.262784496264487, 8.252243003811726, 7.189395284299121, 6.146668582205423, 5.074216078766639, 4.0288906676454666, 2.9675401609787073, 2.0334000967323913, 1.9984570992074908, 1.0654508721036542, 2.0255725564457254, 2.931006224422892, 3.9307646338843356, 4.9297211133851615, 5.909415390108614, 6.8914293375435305, 7.845850538459803, 8.883848189276637, 9.804233399716669, 10.806575943746326, 10.033918500298206, 9.00070027699967, 7.987148405236642, 6.930576788961232, 5.925713183646597, 4.852552382288991, 3.890447103479629, 2.964961326499176, 2.976921368303141, 2.1121137199908855, 3.0928863010827374, 3.8631903227819078, 4.9299251409969465, 5.885049182785691, 6.841350370655237, 7.8578256180602315, 8.789661201670585, 9.777704011453732, 10.708862379255617, 11.636491359540607, 10.707922142078012, 9.767473785420819, 8.761100798254448, 7.766139999731286, 6.781608404914737, 5.81693576715875, 4.8561323162158105, 3.929171717464932, 4.020524577508696, 3.1062918389445784, 4.06746787167386, 4.863727181463548, 5.8638614060485885, 6.936635147081912, 7.793893354574665, 8.748917086285779, 9.7350614762611, 10.718088599753827, 11.655420178460169, 12.57258522645456, 11.702755132287496, 10.801131247485797, 9.739192010881162, 8.701668863483174, 7.743850358501976, 6.795108593043357, 5.913877844318904, 4.879063180331741, 5.0482775721835464, 4.125310829720082, 5.099358974961059, 5.7964188936307455, 6.830000255748329, 7.856636379675566, 8.80151994257644, 9.784807159310812, 10.730544569472126, 11.789552663449248, 12.600003327337175, 13.536040849467371, 12.731163471561036, 11.749445293118868, 10.76442361906873, 9.70351560900704, 8.710495093459276, 7.828386447874863, 6.880519881150613, 5.902419928181532], [7.959234423273072, 8.808761370638523, 9.796009142331965, 10.628695690800944, 11.682162394414918, 12.686860709503769, 13.701142612425606, 14.600838897742761, 13.561301094002845, 12.616537638369069, 11.712564477683802, 10.68608888739765, 9.722146214757256, 8.732153316115154, 7.775553785260577, 6.804517958003914, 5.766017023593314, 5.18715543736494, 6.128304123350645, 7.03607098581555, 8.905355395812313, 9.78479725531868, 10.763254462111862, 11.569093769788887, 12.504247174514187, 13.48146038746499, 14.542486276113063, 15.477712007667755, 14.5332260796293, 13.51211005043375, 12.558004792424969, 11.628371783023704, 10.66536707294951, 9.684090596584758, 8.702519178073313, 7.8010909934045145, 6.838130622259282, 6.130902228190253, 7.061100254873312, 7.964765289608433, 9.88653847899626, 10.785453077107492, 11.798085924803791, 12.597987642941852, 13.513350935802709, 14.469798833964296, 15.519012547482312, 16.36794088717529, 15.39811457153672, 14.445285624978652, 13.533180645177286, 12.565871228953023, 11.643334021260026, 10.694750025187318, 9.721750135320551, 8.852066618032724, 7.8200760398690266, 7.1011804987652685, 8.053143752340064, 8.902531840420123, 10.919532325618675, 11.74686215194664, 11.870427984268831, 12.820239148640905, 13.82873643546813, 14.649543109970011, 15.602497454997124, 16.410177861910164, 16.344949042740225, 15.398851975836244, 14.599944374715049, 13.573869869576322, 12.610238820912931, 11.714170417803064, 10.666056296832938, 9.843233725064952, 8.773742256135158, 8.1560499201003, 9.10509161156549, 9.889385912579963, 11.818640057554468, 11.822196012266188, 10.920385277912185, 11.846663672754488, 12.810870539217767, 13.645534784166387, 14.59244478179414, 15.379522972154888, 16.361954458054168, 16.43284631414149, 15.480780092125848, 14.503961624064116, 13.586211440389773, 12.640778755561604, 11.73618517150728, 10.804817960570038, 9.753955677306145, 9.117515140850752, 10.094752045389065, 10.88073945352628, 11.57836644701409, 10.822686512214014, 9.87368694896981, 10.847650302410802, 11.815323326157227, 12.711942473343484, 13.53002830037882, 14.454274331369641, 15.427187191805196, 16.3584619201911, 16.53932200021759, 15.526005200117044, 14.587571074430212, 13.68210027481569, 12.73164535052513, 11.684458156577987, 10.709684213782483, 10.165576075282724, 11.029310757913073, 11.855532853027496, 10.585164358890728, 9.808945973341844, 8.841424354117722, 9.85844687342211, 10.823380223861893, 11.661143577743484, 12.523681496564036, 13.50818038465333, 14.466336449028018, 15.422681893229655, 16.42846708341448, 16.563362258697857, 15.63288172026739, 14.588489995469436, 13.580673215169785, 12.601963556665726, 11.642518243299728, 11.100195938929286, 11.993429073622236, 11.517118690846761, 9.617958045592585, 8.797884052703527, 7.850273353798394, 8.834353775869591, 9.767713594879037, 10.675680901901478, 11.570114155739292, 12.56167160221323, 13.566260530153789, 14.406034247382593, 15.457745484983658, 16.361619898693185, 16.546225549367207, 15.480143740709295, 14.49586866631716, 13.553775151020806, 12.606450561122147, 12.045417487647176, 11.669886899067105, 10.678630587323656, 8.689357989488428, 7.809171393727626, 6.897318966681447, 7.767198778489248, 8.73632576151214, 9.693637839201836, 10.565479900543783, 11.510844927376993, 12.491287220465495, 13.442972197033239, 14.405804986510908, 15.410452409816283, 16.370115687311028, 15.42049038495644, 14.46688166196666, 13.529142256647877, 12.542450373294702, 11.599019633150657, 10.640330897708923, 9.741129868022007, 7.6828659447783165, 6.834981153221614, 5.862199731503104, 6.797998770994521, 7.685655481910559, 8.68184173885558, 9.632266352625027, 10.567672560851873, 11.537474252765172, 12.472869765009106, 13.42618735727686, 14.40903642706031, 15.421429736893433, 14.535944552825597, 13.516510259043933, 12.543210878463517, 11.648584934871671, 10.647325391487417, 9.692408474344294, 8.70448923258834, 6.71623451958188, 5.766072770198876, 4.804516759254075, 5.799796006643927, 6.7416944864171615, 7.776304687341016, 8.694449148910788, 9.711538774406819, 10.748458349241186, 11.725286772687827, 12.752428701237505, 13.808422935369745, 14.436515061628738, 13.489545675853353, 12.564345232449888, 11.583507287741282, 10.629439984164508, 9.690957516181674, 8.693290402807422, 7.692841017196521, 5.862134106568302, 4.796577383382382, 3.8666094276294416, 4.783700609594649, 5.716972870543064, 6.704526774270266, 7.673936900177383, 8.731349792295665, 9.795356830698127, 10.868647167561722, 11.862095382138868, 12.851845186683967, 13.657187563857546, 12.610688857414985, 11.589961063228566, 10.610733448542108, 9.70574713873554, 8.721199726501725, 7.810357689624659, 6.7603788056162655, 4.8549333164095865, 3.860756440698733, 2.931142617979054, 3.852403295392703, 4.804007072105877, 5.798743066382097, 6.772396920071111, 7.813845203580163, 8.850998261833048, 9.822356156239115, 10.854042423137635, 11.83651420075128, 12.702911209830061, 11.684778009390891, 10.691153146494736, 9.667234908568718, 8.721121931557223, 7.750875348210468, 6.785889281594243, 5.774090314203728, 3.844112204064323, 2.9769057719463525, 1.9916856747074352, 2.87947991217392, 3.8688113886688207, 4.933220704030245, 5.969267493560937, 6.962250201930157, 7.97300001092556, 8.90177720021562, 9.811843640592633, 10.788881214172976, 11.7098404859378, 10.74701526899016, 9.76302159916806, 8.824497758852429, 7.810880869600497, 6.8191822635394095, 5.77818850114062, 4.835494910210774, 2.898262936517052, 1.9402295559771254, 1.06448274139633, 1.9167808253572067, 2.976573227514616, 3.9824992988206582, 5.035362902990322, 6.00961819426728, 7.040014406584353, 7.966674680594122, 8.840004872043941, 9.839280266636946, 10.784176661323285, 9.861151592572122, 8.811169211331046, 7.843916657936747, 6.831194622518846, 5.888705206493675, 4.902358045622421, 3.9499053653162064, 2.049764862319663, 0.9820625706310552, 0.0, 0.9910108463923599, 2.0419885145474943, 3.0160940960778944, 4.064667666365059, 5.0472890357867515, 6.014711716185675, 6.959168469840137, 7.884518590073853, 8.820726460213637, 9.85348605607561, 9.234305574442784, 8.171457854930178, 7.128731152836479, 6.0562786493976954, 5.010953238276522, 3.9496027316097626, 3.0154626673634466, 2.9805196698385457, 2.0475134427347093, 1.0435099858146704, 1.9489436537918365, 2.9487020632532803, 3.947658542754106, 4.927352819477559, 5.909366766912475, 6.863787967828748, 7.901785618645583, 8.822170829085614, 9.824513373115272, 10.7820422006856, 9.982762847630728, 8.969210975867698, 7.912639359592288, 6.907775754277653, 5.834614952920046, 4.872509674110684, 3.947023897130231, 3.958983938934195, 3.0941762906219403, 2.110823730451682, 2.8811277521508525, 3.9478625703658916, 4.902986612154637, 5.859287800024183, 6.875763047429177, 7.80759863103953, 8.795641440822678, 9.726799808624563, 10.747563621805416, 11.67613283926801, 10.749536356051875, 9.743163368885504, 8.748202570362341, 7.763670975545791, 6.798998337789804, 5.838194886846865, 4.911234288095987, 5.00258714813975, 4.051312908038649, 3.0901368753093674, 3.881664610832493, 4.881798835417534, 5.9545725764508575, 6.811830783943611, 7.7668545156547255, 8.752998905630045, 9.736026029122772, 10.673357607829114, 11.68365748871937, 12.670965829477495, 11.783193818116853, 10.721254581512218, 9.68373143411423, 8.725912929133031, 7.777171163674411, 6.895940414949958, 5.861125750962795, 6.030340142814601, 5.070331898814152, 4.1220279785965666, 4.81435632299969, 5.847937685117273, 6.874573809044509, 7.819457371945386, 8.802744588679758, 9.748481998841072, 10.807490092818194, 11.61794075670612, 12.574895016630972, 13.622319596286461, 12.731507863749925, 11.746486189699786, 10.685578179638096, 9.692557664090332, 8.810449018505917, 7.862582451781668, 6.884482498812586], [8.844854909157142, 9.694381856522593, 10.687724192066582, 11.587195945265634, 12.640662648879609, 13.645360963968459, 14.616431530218724, 13.609828051350402, 12.570290247610485, 11.625526791976707, 10.721553631291444, 9.695078041005292, 8.731135368364898, 7.741142469722795, 6.784542938868217, 5.813507111611554, 4.775006177200954, 5.787198136349795, 6.835745376961668, 7.855381847355437, 9.60508073897511, 10.550164833328369, 11.528622040121551, 12.527594024253577, 13.462747428978878, 14.43996064192968, 15.464187971424094, 14.528962239869402, 13.542215233236941, 12.521099204041391, 11.56699394603261, 10.637360936631346, 9.674356226557151, 8.6930797501924, 7.711508331680953, 6.810080147012155, 5.847119775866922, 6.730944927175108, 7.717564244215209, 8.66449063277123, 10.586263822159056, 11.550820655117182, 12.56345350281348, 12.85703662233592, 13.83244229150454, 14.682303689663593, 15.56892318519164, 15.376930040782932, 14.407103725144362, 13.454274778586294, 12.542169798784927, 11.574860382560665, 10.652323174867666, 9.703739178794958, 8.730739288928191, 7.861055771640364, 6.829065193476667, 7.701223197750124, 8.66523807246656, 9.60225718358292, 11.619257668781472, 12.512229729956328, 12.693506864609633, 11.894525998343633, 12.879492395439872, 13.658532263577651, 14.611486608604764, 15.419167015517802, 15.353938196347869, 14.407841129443886, 13.60893352832269, 12.582859023183962, 11.619227974520571, 10.723159571410704, 9.675045450440578, 8.852222878672592, 7.782731409742798, 8.720861031732348, 9.717185931691985, 10.58911125574276, 12.518365400717265, 12.64527489260699, 11.743464158252987, 10.855652826362128, 11.819859692825407, 12.654523937774027, 13.60143393540178, 14.388512125762528, 15.370943611661806, 15.44183546774913, 14.489769245733488, 13.512950777671756, 12.595200593997413, 11.649767909169244, 10.74517432511492, 9.813807114177678, 8.762944830913785, 9.6823262524828, 10.659563157021113, 11.580464796689077, 12.401445327354892, 11.645765392554816, 10.69676582931061, 9.856639456018442, 10.824312479764867, 11.720931626951124, 12.53901745398646, 13.463263484977281, 14.436176345412836, 15.367451073798739, 15.548311153825232, 14.534994353724684, 13.596560228037852, 12.69108942842333, 11.74063450413277, 10.693447310185627, 9.718673367390123, 10.730387186914772, 11.594121869545122, 12.555258196190293, 11.40824323923153, 10.632024853682646, 9.664503234458522, 8.86743602702975, 9.832369377469533, 10.670132731351124, 11.532670650171676, 12.517169538260971, 13.475325602635658, 14.431671046837295, 15.437456237022118, 15.572351412305496, 14.64187087387503, 13.597479149077076, 12.589662368777425, 11.610952710273367, 10.651507396907368, 11.665007050561334, 12.558240185254284, 12.340197571187563, 10.441036925933387, 9.620962933044328, 8.673352234139195, 7.843342929477232, 8.776702748486677, 9.684670055509118, 10.579103309346932, 11.570660755820871, 12.57524968376143, 13.415023400990233, 14.466734638591298, 15.370609052300825, 15.55521470297485, 14.489132894316935, 13.5048578199248, 12.562764304628447, 11.615439714729787, 12.54729739500831, 12.492965779407907, 11.501709467664458, 9.51243686982923, 8.632250274068427, 7.720397847022249, 6.776187932096888, 7.7453149151197795, 8.702626992809476, 9.574469054151423, 10.519834080984634, 11.500276374073135, 12.451961350640879, 13.414794140118548, 14.419441563423923, 15.379104840918668, 15.391278524565042, 14.437669801575263, 13.49993039625648, 12.618055764325094, 12.470380222444767, 11.511691487003032, 10.564208748362809, 8.505944825119117, 7.658060033562416, 6.685278611843906, 5.806987924602161, 6.694644635518199, 7.69083089246322, 8.641255506232667, 9.576661714459513, 10.546463406372812, 11.481858918616746, 12.4351765108845, 13.41802558066795, 14.430418890501073, 15.363971735270635, 14.443942282356938, 13.470642901776522, 12.51994552416578, 11.518685980781527, 10.563769063638404, 9.575849821882448, 7.539313399922682, 6.589151650539677, 5.627595639594877, 4.808785160251567, 5.750683640024802, 6.785293840948656, 7.703438302518428, 8.720527928014459, 9.757447502848827, 10.734275926295467, 11.761417854845146, 12.817412088977385, 13.667674485344811, 14.416977699166358, 13.491777255762893, 12.510939311054287, 11.500800573458616, 10.562318105475782, 9.56465099210153, 8.564201606490629, 6.689201835587035, 5.619656263723184, 4.689688307970243, 3.792689763202289, 4.725962024150704, 5.713515927877906, 6.682926053785023, 7.740338945903306, 8.804345984305767, 9.877636321169362, 10.871084535746508, 11.860834340291607, 12.713271127318484, 13.53812088072799, 12.51739308654157, 11.538165471855113, 10.633179162048544, 9.64863174981473, 8.707200603576352, 7.657221719567958, 5.696760755361274, 4.683835321039535, 3.754221498319856, 2.861392449000343, 3.8129962257135177, 4.807732219989738, 5.781386073678752, 6.822834357187803, 7.859987415440688, 8.831345309846755, 9.863031576745277, 10.84550335435892, 11.738342516650238, 12.612210032703896, 11.61858516980774, 10.594666931881722, 9.648553954870227, 8.678307371523472, 7.713321304907247, 6.670933228155421, 4.786992561056261, 3.8519308935626357, 2.814764555048237, 1.88846906578156, 2.8778005422764608, 3.9422098576378852, 4.978256647168577, 5.971239355537797, 6.9819891645332, 7.91076635382326, 8.820832794200275, 9.797870367780616, 10.745271792757977, 11.708097009705618, 10.75403244556042, 9.815508605244789, 8.801891715992857, 7.762062620531347, 6.721068858132558, 5.778375267202712, 3.8411432935089893, 2.883109912969063, 1.8875616217371318, 0.9257699789648469, 1.9855623811222562, 2.9914884524282983, 4.044352056597962, 5.01860734787492, 6.049003560191993, 6.975663834201762, 7.848994025651582, 8.848269420244586, 9.793165814930925, 10.812111205792934, 9.802180057723406, 8.834927504329107, 7.822205468911206, 6.879716052886035, 5.893368892014781, 4.892785722308144, 3.0407757087120233, 1.9730734170234152, 0.9910108463923599, 0.0, 1.0509776681551346, 2.0250832496855344, 3.0736568199726992, 4.0562781893943916, 5.023700869793315, 5.968157623447777, 6.893507743681493, 7.829715613821277, 8.86247520968325, 9.873016702136011, 9.162468701322538, 8.11974199922884, 7.047289495790055, 6.001964084668882, 4.9406135780021225, 4.0064735137558065, 3.971530516230906, 2.9800416725031367, 1.9417197369306471, 0.9579328073994767, 1.9576912168609204, 2.9566476963617463, 3.9363419730851983, 4.918355920520115, 5.872777121436388, 6.910774772253223, 7.831159982693254, 8.833502526722912, 9.79103135429324, 10.824249577591777, 9.960221822260058, 8.903650205984647, 7.898786600670013, 6.825625799312406, 5.863520520503044, 4.938034743522591, 4.843112356476647, 3.8962390710785115, 2.910207297076588, 1.8901169057584926, 2.9568517239735317, 3.9119757657622762, 4.868276953631822, 5.884752201036816, 6.81658778464717, 7.804630594430317, 8.735788962232203, 9.756552775413056, 10.68512199287565, 11.625570349532843, 10.701663623350194, 9.706702824827032, 8.722171230010481, 7.7574985922544935, 6.796695141311554, 5.7968547739800576, 5.862155384293423, 4.788744977152865, 3.827568944423583, 2.890653764440133, 3.8907879890251738, 4.9635617300584975, 5.82081993755125, 6.775843669262365, 7.761988059237685, 8.74501518273041, 9.682346761436753, 10.69264664232701, 11.679954983085135, 12.68359436870561, 11.679754835976908, 10.64223168857892, 9.684413183597721, 8.7356714181391, 7.7815609008340285, 6.746746236846866, 6.853705488803788, 5.807763967928368, 4.815541048424966, 3.8233454766073303, 4.856926838724913, 5.8835629626521495, 6.828446525553026, 7.811733742287398, 8.75747115244871, 9.816479246425832, 10.626929910313759, 11.583884170238612, 12.631308749894101, 13.623098877449262, 12.704986444164476, 11.644078434102786, 10.651057918555022, 9.760693778322667, 8.748202937665738, 7.770102984696656], [9.895832577312278, 10.74535952467773, 11.738701860221719, 12.63817361342077, 13.691640317034745, 14.559686065854514, 13.608955028685086, 12.602351549816763, 11.562813746076847, 10.61805029044307, 9.82035308147843, 8.793877491192278, 7.829934818551885, 6.839941919909782, 5.91351881773315, 4.9424829904764875, 5.825983845356089, 6.83817580450493, 7.886723045116803, 8.906359515510571, 10.656058407130246, 11.601142501483505, 12.579599708276687, 13.578571692408714, 14.149084218966967, 14.902625631610492, 14.461705724692283, 13.526479993137592, 12.53973298650513, 11.61020399335832, 10.665793396219597, 9.736160386818332, 8.773155676744137, 7.791879200379386, 6.8404842105458865, 6.008056749248934, 6.898097444022057, 7.7819225953302436, 8.768541912370345, 9.715468300926366, 11.637241490314192, 12.601798323272318, 13.614431170968617, 13.886419979691253, 13.139980457678446, 13.914287185111187, 14.775825022287126, 14.466034830099861, 13.49620851446129, 12.543379567903223, 11.640969248971913, 10.673659832747651, 9.762581443928761, 8.813997447856053, 7.859715167793124, 7.0590323738771446, 7.880042861631802, 8.752200865905259, 9.716215740621694, 10.653234851738056, 12.67023533693661, 13.563207398111466, 13.744484532764767, 12.923909355698965, 12.187030561613778, 12.890515759025245, 13.81838844570025, 14.626068852613288, 14.443042985664798, 13.496945918760815, 12.707732978509677, 11.686023537226092, 10.729486243581666, 9.852135450275636, 8.80402132930551, 8.074035192582604, 8.833709077897932, 9.771838699887482, 10.768163599847119, 11.640088923897896, 13.569343068872401, 13.696252560762124, 12.794441826408121, 11.88503618371746, 11.127397858999315, 11.886507433221619, 12.808335772497266, 13.595413962858014, 14.577845448757293, 14.530940257066058, 13.592933759775615, 12.616115291713886, 11.705458863058508, 10.778743788034175, 9.874150203979852, 9.03561942808769, 9.81392249906892, 10.733303920637935, 11.710540825176247, 12.631442464844213, 13.452422995510027, 12.69674306070995, 11.747743497465745, 10.886022813373774, 10.05629597521246, 10.952915122398716, 11.745919291081947, 12.670165322072767, 13.643078182508322, 14.574352910894225, 14.65147566786736, 13.638158867766814, 12.706818497098947, 11.820065307288262, 10.903608080767729, 9.994240856924916, 10.769651035545257, 11.781364855069906, 12.645099537700256, 13.606235864345429, 12.459220907386664, 11.68300252183778, 10.715480902613656, 9.896819384385083, 9.064352872917127, 9.902116226798716, 10.739572487267163, 11.724071375356457, 12.682227439731145, 13.638572883932781, 14.644358074117605, 14.682609681366591, 13.752129142936125, 12.813808142603055, 11.961744275292128, 10.986340666467882, 11.702485065062502, 12.715984718716468, 13.609217853409419, 13.391175239342697, 11.492014594088522, 10.671940601199463, 9.724329902294329, 8.872726286832563, 8.008686243934271, 8.91665355095671, 9.786005146442418, 10.777562592916357, 11.782151520856916, 12.62192523808572, 13.673636475686784, 14.577510889396311, 14.684223478798112, 13.881968372183403, 12.931994117828935, 12.002321137247383, 12.666417382884921, 13.598275063163445, 13.543943447563041, 12.552687135819593, 10.563414537984364, 9.683227942223562, 8.771375515177382, 7.80557128945222, 6.977298410567372, 7.934610488257067, 8.78137089124691, 9.72673591808012, 10.707178211168621, 11.658863187736365, 12.621695977214035, 13.62634340051941, 14.586006678014154, 14.830835357183979, 13.8772266341942, 12.939487228875416, 13.669033432480228, 13.521357890599901, 12.562669155158167, 11.615186416517943, 9.556922493274252, 8.70903770171755, 7.73625627999904, 6.8363712819574936, 5.926628130965792, 6.922814387910812, 7.848157343328154, 8.783563551555, 9.753365243468298, 10.688760755712233, 11.642078347979986, 12.624927417763436, 13.63732072759656, 14.570873572366121, 14.865928629355853, 13.925418607059775, 13.570923192320915, 12.569663648936661, 11.614746731793538, 10.626827490037583, 8.590291068077816, 7.640129318694812, 6.678573307750011, 5.838168517606899, 4.982667135472394, 5.999757582212023, 6.910340139613915, 7.927429765109945, 8.934235945808917, 9.899471001802343, 10.795490391117557, 11.835357255341137, 12.616696817189677, 13.563666202965061, 14.488866646368527, 13.561916979209421, 12.55177824161375, 11.613295773630917, 10.615628660256665, 9.615179274645763, 7.740179503742169, 6.670633931878318, 5.740665976125378, 4.82207312055762, 3.9404257654140706, 4.927979669141274, 5.889827890880509, 6.947240782998793, 7.891524894168746, 8.908550501086772, 9.820106867591374, 10.809856672136473, 11.66229345916335, 12.698408419365308, 13.568370754696705, 12.589143140010247, 11.684156830203678, 10.699609417969864, 9.758178271731486, 8.708199387723091, 6.747738423516409, 5.734812989194669, 4.80519916647499, 3.8907758063556743, 2.913081753544639, 3.9078177478208596, 4.881471601509873, 5.922919885018924, 6.883710959325833, 7.855068853731899, 8.81205390859014, 9.794525686203785, 10.687364848495104, 11.69928181963543, 12.57991100776978, 11.645644600036857, 10.699531623025361, 9.729285039678606, 8.764298973062381, 7.721910896310555, 5.837970229211395, 4.90290856171777, 3.8657422232033714, 2.9394467339366948, 1.9778860701075822, 3.039863991200987, 4.07591078073168, 4.9771931024608635, 5.931011496378066, 6.859788685668126, 7.769855126045139, 8.746892699625482, 9.694294124602843, 10.657119341550484, 11.641113011372584, 10.866486273399923, 9.852869384147994, 8.813040288686482, 7.772046526287692, 6.829352935357846, 4.892120961664124, 3.9340875811241975, 2.938539289892266, 1.9767476471199816, 1.0404460460996432, 2.0044130113883685, 3.057276615558032, 3.967629679719786, 4.998025892036859, 5.9246861660466275, 6.798016357496448, 7.797291752089452, 8.74218814677579, 9.7611335376378, 10.811115918878876, 9.885905172484241, 8.873183137066341, 7.93069372104117, 6.944346560169915, 5.943763390463278, 4.091753376867158, 3.0240510851785496, 2.0419885145474943, 1.0509776681551346, 0.0, 0.9741055815303999, 2.022679151817565, 3.005300521239257, 3.9727232016381815, 4.917179955292642, 5.8425300755263585, 6.778737945666142, 7.811497541528116, 8.822039033980877, 9.884886753493483, 9.170719667383974, 8.09826716394519, 7.052941752824016, 5.991591246157257, 5.057451181910941, 5.022508184386041, 4.031019340658271, 2.9926974050857815, 2.0089104755546114, 1.0598798593962382, 1.9236471161190476, 2.9033413928424996, 3.885355340277416, 4.8397765411936895, 5.877774192010524, 6.78018231453812, 7.782524858567777, 8.740053686138106, 9.773271909436643, 10.786823781199672, 9.954627874139781, 8.949764268825147, 7.8766034674675405, 6.914498188658178, 5.9890124116777255, 5.894090024631782, 4.947216739233647, 3.9611849652317233, 2.9410945739136274, 2.0836568970418496, 2.97533597430426, 3.8941224907755276, 4.855310924856244, 5.783587204404471, 6.771630014187618, 7.702788381989504, 8.723552195170356, 9.652121412632951, 10.592569769290144, 11.598942756456514, 10.757680492982168, 9.773148898165617, 8.80847626040963, 7.84767280946669, 6.847832442135193, 6.9131330524485595, 5.839722645308, 4.8785466125787185, 3.9416314325952677, 3.0175931620934917, 4.032603619679416, 4.846665474694955, 5.80168920640607, 6.78783359638139, 7.770860719874117, 8.674870259903116, 9.65964606208431, 10.646954402842436, 11.65059378846291, 12.591682794508902, 11.693209356734057, 10.735390851752857, 9.786649086294236, 8.832538568989165, 7.797723905002002, 7.9046831569589235, 6.858741636083503, 5.866518716580101, 4.8743231447624655, 3.9851846354953766, 5.011820759422613, 5.8542920626967305, 6.837579279431103, 7.783316689592415, 8.842324783569538, 9.619453408780123, 10.576407668704974, 11.623832248360463, 12.615622375915624, 13.600644049965762, 12.695056102257922, 11.702035586710158, 10.811671446477803, 9.799180605820874, 8.821080652851792], [10.835178525308583, 11.684705472674034, 12.678047808218023, 13.577519561417075, 14.590278799412966, 13.585580484324115, 12.634849447154687, 11.628245968286365, 10.588708164546448, 9.64394470891267, 8.846247499948031, 7.81977190966188, 6.855829237021486, 5.865836338379383, 5.105292435601939, 5.815180527997242, 6.765329793352395, 7.777521752501236, 8.82606899311311, 9.845705463506878, 11.59540435512655, 12.54048844947981, 13.518945656272992, 14.517917640405019, 15.034457318132747, 14.095241227845412, 13.487600143161885, 12.552374411607193, 11.565627404974732, 10.63609841182792, 9.691687814689198, 8.762054805287933, 7.799050095213739, 6.817773618848987, 6.032257828414675, 6.8807542867696885, 7.837443392018363, 8.72126854332655, 9.70788786036665, 10.654814248922671, 12.576587438310497, 13.541144271268623, 14.553777118964922, 14.860525561221651, 14.025353556844225, 13.106902781346106, 13.894928325676066, 13.49192924856946, 12.52210293293089, 11.569273986372822, 10.666863667441515, 9.699554251217252, 8.78847586239836, 7.839891866325654, 7.051488785661912, 7.931729911397898, 8.819388809628107, 9.691546813901565, 10.655561688618, 11.59258079973436, 13.609581284932915, 14.50255334610777, 14.718590114295166, 13.898014937229364, 13.072403660779557, 12.083131355260164, 12.93749174908919, 13.745172156002226, 13.468937404134397, 12.522840337230415, 11.733627396979278, 10.711917955695693, 9.755380662051266, 8.886752075293298, 7.995794947174298, 8.946732730103358, 9.773055025894237, 10.711184647883787, 11.707509547843426, 12.5794348718942, 14.508689016868706, 14.670358142292525, 13.76854740793852, 12.859141765247859, 12.012770958165092, 11.07912302945654, 11.927439075886204, 12.714517266246952, 13.69694875214623, 13.556834675535658, 12.618828178245217, 11.642009710183487, 10.731353281528108, 9.813360413051837, 9.06592382184864, 9.908316965608444, 10.753268447065224, 11.67264986863424, 12.649886773172552, 13.570788412840518, 14.426528577040425, 13.670848642240351, 12.721849078996145, 11.860128394904173, 11.03040155674286, 10.145530718633637, 10.865022594470885, 11.789268625461705, 12.76218148589726, 13.693456214283163, 13.67737008633696, 12.664053286236415, 11.732712915568547, 10.854681932305924, 10.095381698636517, 10.86693839444567, 11.708996983541562, 12.720710803066211, 13.58444548569656, 14.545581812341734, 13.433326488917062, 12.65710810336818, 11.689586484144057, 10.870924965915483, 10.038458454447525, 9.094731823033637, 9.8586757906561, 10.843174678745395, 11.801330743120083, 12.757676187321719, 13.763461377506543, 13.70850409983619, 12.778023561405725, 11.848424767620717, 11.153517893160917, 11.859038203988636, 12.641831013058807, 13.655330666712773, 14.548563801405724, 14.365280820873096, 12.46612017561892, 11.646046182729863, 10.69843548382473, 9.846831868362964, 8.98279182546467, 8.10926914719163, 8.905108449831356, 9.896665896305295, 10.901254824245854, 11.741028541474657, 12.792739779075722, 13.69661419278525, 13.710117897267711, 12.916584997201065, 12.123767735697724, 12.875018674768137, 13.605763330881226, 14.53762101115975, 14.51804902909344, 13.526792717349991, 11.537520119514763, 10.65733352375396, 9.745481096707783, 8.77967687098262, 7.951403992097772, 7.127226084491988, 7.900474194635848, 8.84583922146906, 9.826281514557559, 10.777966491125303, 11.740799280602973, 12.745446703908348, 13.683884075889647, 13.910683190038354, 13.139369638247311, 13.81218476639617, 14.608379380476533, 14.4954634721303, 13.536774736688566, 12.589291998048342, 10.531028074804652, 9.683143283247949, 8.71036186152944, 7.810476863487894, 6.900733712496192, 6.115429984145733, 6.967260646717092, 7.902666854943938, 8.872468546857236, 9.80786405910117, 10.761181651368924, 11.744030721152374, 12.670547851359943, 13.604100696129505, 14.128071633408965, 14.79811614458053, 14.545028773851314, 13.54376923046706, 12.588852313323937, 11.600933071567983, 9.564396649608216, 8.614234900225211, 7.652678889280411, 6.8122740991373, 5.956772717002794, 5.159491355800985, 6.029443443002853, 7.046533068498883, 7.960130364278518, 8.925365420271943, 9.821384809587158, 10.861251673810738, 11.642591235659276, 12.58956062143466, 13.514761064838126, 14.460824274357275, 13.52588382314415, 12.587401355161317, 11.589734241787065, 10.589284856176164, 8.71428508527257, 7.644739513408718, 6.714771557655777, 5.796178702088021, 4.914531346944471, 4.0877134427302355, 5.008931194269447, 6.066344086387731, 6.917419312638346, 7.9344449195563715, 8.846001286060975, 9.835751090606074, 10.688187877632949, 11.724302837834907, 12.634710086104135, 13.488050435158101, 12.658262411734079, 11.673714999500264, 10.732283853261887, 9.682304969253492, 7.721844005046808, 6.708918570725069, 5.77930474800539, 4.864881387886075, 3.887187335075039, 3.026921051209797, 4.000574904898811, 5.015061521109734, 5.909605377795433, 6.880963272201499, 7.837948327059742, 8.820420104673387, 9.713259266964704, 10.72517623810503, 11.60580542623938, 12.54455189518471, 11.673637204555762, 10.703390621209007, 9.738404554592782, 8.696016477840955, 6.812075810741795, 5.87701414324817, 4.839847804733771, 3.9135523154670944, 2.9519916516379823, 2.065758409670587, 3.101805199201279, 4.003087520930464, 4.956905914847666, 5.885683104137726, 6.79574954451474, 7.772787118095082, 8.720188543072442, 9.683013760020083, 10.667007429842183, 11.607025105824851, 10.826974965678392, 9.78714587021688, 8.74615210781809, 7.803458516888246, 5.866226543194523, 4.908193162654597, 3.912644871422666, 2.9508532286503812, 2.014551627630043, 1.0303074298579686, 2.083171034027632, 2.9935240981893863, 4.023920310506459, 4.950580584516228, 5.8239107759660484, 6.823186170559052, 7.7680825652453915, 8.787027956107401, 9.837010337348477, 10.804262890742777, 9.84728871859674, 8.904799302571568, 7.918452141700315, 6.917868971993678, 5.065858958397557, 3.9981566667089496, 3.0160940960778944, 2.0250832496855344, 0.9741055815303999, 0.0, 1.0485735702871648, 2.0311949397088576, 2.998617620107782, 3.9430743737622427, 4.868424493995959, 5.804632364135743, 6.837391959997717, 7.847933452450478, 8.910781171963084, 9.953507874056783, 9.072372745475588, 8.027047334354416, 6.9656968276876565, 6.0315567634413405, 5.9966137659164405, 4.970365288654578, 3.932043353082088, 2.9482564235509177, 1.9484980140894739, 0.9495415345886477, 1.9292358113120998, 2.9112497587470165, 3.86567095966329, 4.903668610480125, 5.806076733007719, 6.808419277037378, 7.7659481046077055, 8.799166327906242, 9.81271819966927, 10.869289815944681, 9.923869850355546, 8.85070904899794, 7.888603770188578, 6.963117993208125, 6.833435972628088, 5.886562687229953, 4.900530913228029, 3.8804405219099336, 2.9563544345626043, 2.0012303927738597, 2.920016909245128, 3.8812053433258447, 4.809481622874071, 5.797524432657219, 6.728682800459104, 7.7494466136399565, 8.67801583110255, 9.618464187759743, 10.624837174926114, 11.619797973449277, 10.712494846161922, 9.747822208405935, 8.787018757462995, 7.787178390131499, 7.852479000444864, 6.779068593304306, 5.817892560575024, 4.880977380591574, 3.8902906996142463, 3.0584980381490157, 3.872559893164556, 4.82758362487567, 5.81372801485099, 6.796755138343716, 7.700764678372716, 8.68554048055391, 9.672848821312035, 10.67648820693251, 11.617577212978501, 12.555326837201166, 11.674736799749162, 10.725995034290541, 9.77188451698547, 8.737069852998307, 8.84402910495523, 7.798087584079809, 6.805864664576407, 5.813669092758771, 4.857882173016131, 4.127988209408126, 4.880186481166332, 5.863473697900703, 6.809211108062016, 7.868219202039137, 8.645347827249722, 9.602302087174575, 10.649726666830064, 11.641516794385225, 12.626538468435363, 13.584305629488252, 12.641381534706463, 11.751017394474108, 10.738526553817179, 9.760426600848097], [11.824112198711177, 12.673639146076628, 13.666981481620617, 14.478517836625938, 13.619823919368654, 12.615125604279804, 11.664394567110376, 10.657791088242053, 9.618253284502137, 8.673489828868359, 7.875792619903718, 6.849317029617567, 5.885374356977173, 4.89538145833507, 5.842555909504961, 6.7198133522937455, 7.747757060023841, 8.759949019172682, 9.808496259784555, 10.828132730178323, 12.577831621797998, 13.522915716151257, 14.501372922944439, 15.418915915613882, 14.55538436471645, 13.578171151765646, 12.517145263117573, 11.581919531562882, 10.59517252493042, 9.665643531783608, 8.721232934644885, 7.791599925243621, 6.828595215169426, 5.847318738804674, 6.769521302317697, 7.775891183655209, 8.738851554800442, 9.703695809997996, 10.690315127038097, 11.637241515594118, 13.559014704981944, 14.52357153794007, 15.536204385636369, 15.909099131508816, 14.956734219042518, 14.0382834435444, 13.066557285188154, 12.52147436852515, 11.551648052886579, 10.598819106328511, 9.696408787397202, 8.72909937117294, 7.818020982354048, 6.8694369862813405, 7.7887522595649346, 8.82686680828342, 9.720796972410186, 10.67397408057301, 11.637988955289446, 12.575008066405807, 14.592008551604362, 15.484980612779218, 15.767163684582334, 14.946588507516529, 14.00378432297785, 13.014512017458458, 12.109120708601278, 12.803009512620369, 12.498482524090086, 11.552385457186103, 10.763172516934965, 9.74146307565138, 8.784925782006953, 7.916297195248985, 8.73305842107732, 9.80723162741802, 10.674463188676317, 11.612592810665866, 12.610129139881199, 13.54763697961639, 15.429786693263207, 15.71893171257969, 14.817120978225688, 13.907715335535023, 12.944151620363385, 12.010503691654833, 11.099068035398291, 11.772354622865095, 12.754786108764373, 12.586379795491347, 11.648373298200905, 10.671554830139174, 9.760898401483795, 8.842905533007524, 9.803187295751663, 10.760017651699199, 11.654676609847304, 12.57405803141632, 13.551294935954632, 14.491886089235019, 15.475102147327593, 14.719422212527517, 13.770422649283312, 12.908701965191337, 12.014518440547127, 11.07691138083193, 10.036651553982972, 10.847105982079848, 11.820018842515402, 12.711704210711995, 12.70691520629265, 11.693598406192102, 10.762258035524233, 9.884227052261611, 10.83264517253954, 11.718639080536425, 12.610405146323641, 13.62211896584829, 14.48585364847864, 15.466679488736235, 14.48190005920423, 13.705681673655347, 12.738160054431223, 11.919498536202648, 11.064849976402838, 10.04886014375273, 9.030304750168188, 9.901012035363538, 10.859168099738225, 11.77592418375055, 12.781709373935374, 12.738049219791877, 11.807568681361412, 10.877969887576404, 11.885786667876054, 12.71073889007939, 13.543239175840887, 14.556738829494853, 15.449971964187803, 15.413854391160264, 13.514693745906088, 12.69461975301703, 11.747009054111896, 10.895405438650128, 10.031136756637697, 9.063397467910724, 8.076737409343444, 8.954503252923438, 9.919502820674685, 10.759276537903489, 11.753675824971403, 12.65755023868093, 12.739663017223398, 11.946130117156752, 12.856036510412862, 13.726719360858892, 14.507171493663305, 15.43902917394183, 15.566622599380608, 14.57536628763716, 12.586093689801931, 11.705907094041127, 10.794054666994949, 9.828250441269784, 8.999977562384938, 8.096173938489539, 7.0721031541479356, 7.885823021682854, 8.84452951098639, 9.796214487554135, 10.701735326498653, 11.706382749804028, 12.635310505602483, 12.94022830999404, 13.871638412962449, 14.663885452486925, 15.509787543258613, 15.544037042417468, 14.585348306975733, 13.63786556833551, 11.579601645091818, 10.731716853535115, 9.758935431816607, 8.859050433775058, 7.949307282783357, 7.102655656623558, 6.13888960622918, 6.942650655157733, 7.890716543286067, 8.826112055530002, 9.722117697264604, 10.704966767048054, 11.621974281072779, 12.55552712584234, 13.418352521145007, 14.371954294792346, 15.415165751213372, 14.592342800754228, 13.637425883611105, 12.64950664185515, 10.612970219895383, 9.662808470512378, 8.701252459567577, 7.860847669424464, 7.005346287289959, 6.14671702827881, 5.20107240251494, 6.016381374059012, 6.911556793991352, 7.876791849984778, 8.77281123929999, 9.81267810352357, 10.594017665372112, 11.540987051147496, 12.466187494550962, 13.41225070407011, 14.396020800506209, 13.635974925448483, 12.638307812074231, 11.63785842646333, 9.762858655559736, 8.693313083695884, 7.763345127942943, 6.844752272375186, 5.963104917231636, 5.136287013017402, 4.180560153781535, 5.03619239194786, 5.868845742351181, 6.885871349269207, 7.797427715773808, 8.787177520318906, 9.639614307345784, 10.675729267547743, 11.586136515816971, 12.439476864870937, 13.397775325745556, 12.722288569787429, 11.780857423549051, 10.730878539540656, 8.770417575333973, 7.757492141012234, 6.827878318292555, 5.91345495817324, 4.935760905362205, 4.075494621496962, 3.172203864410899, 3.966487950822569, 4.861031807508268, 5.832389701914334, 6.789374756772576, 7.7718465343862215, 8.66468569667754, 9.676602667817866, 10.557231855952216, 11.495978324897546, 12.442091301909041, 11.751964191496171, 10.786978124879946, 9.744590048128119, 7.86064938102896, 6.925587713535335, 5.888421375020936, 4.962125885754259, 4.0005652219251475, 3.1143319799577522, 2.1226302276355185, 2.9545139506432987, 3.9083323445605007, 4.837109533850561, 5.7471759742275745, 6.724213547807917, 7.671614972785278, 8.634440189732919, 9.618433859555019, 10.558451535537687, 11.590942556163297, 10.835719440504047, 9.794725678105257, 8.852032087175411, 6.9148001134816885, 5.956766732941762, 4.961218441709831, 3.999426798937546, 3.0631251979172083, 2.0788810001451337, 1.0492537488411717, 1.9449505279022214, 2.975346740219294, 3.9020070142290626, 4.775337205678883, 5.774612600271887, 6.719508994958225, 7.738454385820234, 8.788436767061311, 9.75568932045561, 10.76841135587351, 9.953372872858736, 8.967025711987482, 7.966442542280843, 6.1144325286847225, 5.0467302369961144, 4.064667666365059, 3.0736568199726992, 2.022679151817565, 1.0485735702871648, 0.0, 0.9826213694216925, 1.9500440498206166, 2.8945008034750774, 3.8198509237087936, 4.756058793848577, 5.788818389710551, 6.799359882163312, 7.862207601675917, 8.904934303769616, 9.9773868072084, 9.075620904641582, 8.014270397974823, 7.080130333728506, 6.9888014964993825, 5.9592989620571695, 4.92097702648468, 3.93719009695351, 2.937431687492066, 1.9384752079912397, 0.9587809312677875, 1.9407948787027043, 2.8952160796189776, 3.8935265361287614, 4.757503162720555, 5.7598457067502125, 6.71737453432054, 7.750592757619077, 8.764144629382105, 9.820716245657517, 10.82557985097215, 9.845450420580395, 8.883345141771033, 7.957859364790579, 7.822369646030681, 6.875496360632545, 5.889464586630622, 4.869374195312526, 3.8609872588591068, 2.905863217070362, 1.9495620292008158, 2.9107504632815324, 3.839026742829759, 4.827069552612906, 5.758227920414792, 6.778991733595644, 7.707560951058238, 8.648009307715432, 9.654382294881803, 10.649343093404966, 11.633874688221516, 10.736755881808529, 9.775952430865589, 8.776112063534091, 8.840698066910512, 7.767287659769954, 6.806111627040672, 5.869196447057222, 4.794923523910749, 3.9564382259318194, 2.9021050131202437, 3.857128744831358, 4.843273134806678, 5.826300258299405, 6.7303097983284035, 7.715085600509597, 8.702393941267722, 9.706033326888198, 10.64712233293419, 11.584871957156855, 12.575735074958025, 11.714928707693135, 10.760818190388063, 9.7260035264009, 9.832248171420877, 8.786306650545457, 7.788291931247853, 6.7960963594302175, 5.762514997312635, 4.865251683311148, 3.909731601122019, 4.893018817856391, 5.838756228017703, 6.897764321994826, 7.674892947205411, 8.631847207130264, 9.679271786785753, 10.671061914340914, 11.656083588391052, 12.613850749443941, 13.542379809915326, 12.739951067876701, 11.727460227219773, 10.74936027425069], [12.806733568132868, 13.65626051549832, 14.464613492568137, 13.504821339026567, 12.64612742176928, 11.64142910668043, 10.690698069511003, 9.68409459064268, 8.644556786902763, 7.699793331268987, 6.9427912901533055, 5.916315699867154, 5.177898274092037, 5.878002827756763, 6.825177278926654, 7.702434721715438, 8.730378429445535, 9.742570388594377, 10.79111762920625, 11.810754099600018, 13.560452991219691, 14.50553708557295, 15.483994292366132, 14.44521941801451, 13.581687867117076, 12.604474654166273, 11.5434487655182, 10.608223033963508, 9.621476027331047, 8.691947034184237, 7.788231604894472, 6.858598595493208, 6.243465474472021, 6.829940108226367, 7.75214267173939, 8.758512553076901, 9.721472924222134, 10.68631717941969, 11.67293649645979, 12.619862885015811, 14.541636074403637, 15.506192907361763, 16.471978648025367, 15.474113291167475, 14.590791628405597, 13.592813100665579, 12.565818215638506, 11.547777870925778, 10.577951555287207, 9.62512260872914, 8.763407457646789, 7.796098041422527, 7.265025390129055, 7.852058355703034, 8.771373628986629, 9.809488177705111, 10.703418341831878, 11.656595449994706, 12.62061032471114, 13.5576294358275, 15.574629921026055, 16.46760198220091, 16.608059943866653, 15.658248779494581, 14.71480144366426, 13.725529138144871, 12.742521840269209, 11.820388143198677, 11.524786026490714, 10.578688959586731, 9.830171187184552, 8.808461745900969, 8.231930189781961, 8.898918564670678, 9.715679790499015, 10.789852996839713, 11.65708455809801, 12.59521418008756, 13.592750509302892, 14.530258349038084, 16.4124080626849, 16.626900882446705, 15.65905830839238, 14.619375607513076, 13.655168741049797, 12.721520812341245, 11.732469167066224, 10.789733253443403, 11.772164739342681, 11.612683297891975, 10.715371968450494, 9.738553500388763, 9.207902809258803, 9.825526902429218, 10.785808665173358, 11.742639021120894, 12.637297979268997, 13.556679400838012, 14.533916305376325, 15.474507458656712, 16.457723516749287, 15.70204358194921, 14.753044018705005, 13.78687154497931, 12.771064328280833, 11.833457268565637, 10.793197441716678, 9.864484612658156, 10.837397473093711, 11.729082841290301, 11.773913876542238, 10.760597076441691, 10.209262443299242, 10.866848421683304, 11.815266541961234, 12.70126044995812, 13.593026515745334, 14.604740335269984, 15.468475017900333, 16.44930085815793, 15.464521428625924, 14.68830304307704, 13.720781423852916, 12.797668115990618, 11.821395864136544, 10.805406031486436, 9.786850637901894, 8.918390665941846, 9.876546730316534, 10.793302814328857, 11.799088004513681, 11.811153090900016, 11.25457308913642, 11.860591256998097, 12.868408037297748, 13.693360259501086, 14.52586054526258, 15.539360198916546, 16.432593333609496, 16.396475760581957, 14.497315115327781, 13.677241122438723, 12.729630423533589, 11.80843968489938, 10.787682644371403, 9.81994335564443, 8.83328329707715, 7.971881883501745, 8.936881451252994, 9.776655168481795, 10.771054455549713, 11.67492886925924, 12.186667424998406, 12.928751486578445, 13.838657879834555, 14.709340730280587, 15.489792863084999, 16.421650543363523, 16.5492439688023, 15.557987657058852, 13.568715059223624, 12.68852846346282, 11.776676036416642, 10.810871810691477, 9.871423459369444, 8.852719826223245, 7.828649041881643, 6.903201652261162, 7.861908141564699, 8.813593118132442, 9.719113957076964, 10.723761380382339, 11.65268913618079, 12.530504778952112, 13.424433146884967, 14.36217255220375, 15.366821077291272, 16.310251817435315, 15.567969676397427, 14.620486937757203, 12.562223014513512, 11.714338222956808, 10.7415568012383, 9.84167180319675, 8.931928652205048, 7.9449007185788645, 6.895435493962887, 5.960029285736041, 6.908095173864376, 7.84349068610831, 8.739496327842915, 9.722345397626365, 10.639352911651086, 11.572905756420647, 12.435731151723314, 13.389332925370654, 14.432544381791683, 15.42249635257441, 14.620047253032798, 13.632128011276842, 11.595591589317076, 10.64542983993407, 9.68387382898927, 8.843469038846155, 7.987967656711651, 6.988962090234117, 6.043317464470247, 5.03376000463732, 5.92893542456966, 6.894170480563085, 7.7901898698783, 8.830056734101879, 9.611396295950419, 10.558365681725803, 11.483566125129268, 12.42962933464842, 13.413399431084517, 14.351881899067351, 13.620929181495924, 12.620479795885023, 10.745480024981429, 9.675934453117577, 8.745966497364636, 7.827373641796878, 6.945726286653327, 5.992215341643958, 5.022805215736842, 4.053571022526167, 4.8862243729294885, 5.903249979847514, 6.814806346352117, 7.804556150897215, 8.656992937924091, 9.69310789812605, 10.60351514639528, 11.456855495449245, 12.415153956323865, 13.399701368557679, 12.763478792970744, 11.71349990896235, 9.753038944755666, 8.740113510433927, 7.810499687714248, 6.8960763275949315, 5.918382274783896, 4.962084720660728, 4.014448926366207, 2.9838665814008767, 3.8784104380865756, 4.8497683324926415, 5.806753387350884, 6.789225164964529, 7.682064327255846, 8.693981298396173, 9.574610486530524, 10.513356955475855, 11.45946993248735, 12.429716515834105, 11.769599494301639, 10.727211417549812, 8.843270750450653, 7.908209082957028, 6.871042744442629, 5.944747255175952, 4.98318659134684, 4.000922079121518, 2.964875289590826, 1.9718925812216064, 2.9257109751388084, 3.8544881644288687, 4.764554604805882, 5.741592178386225, 6.688993603363586, 7.6518188203112265, 8.635812490133327, 9.575830166115995, 10.608321186741605, 11.673567408901082, 10.77734704752695, 9.834653456597104, 7.897421482903382, 6.939388102363456, 5.943839811131524, 4.982048168359239, 4.045746567338901, 3.0595473745978934, 2.0066837704282303, 0.9623291584805288, 1.9927253707976016, 2.9193856448073703, 3.792715836257191, 4.791991230850194, 5.736887625536534, 6.755833016398543, 7.805815397639619, 8.77306795103392, 9.78578998645182, 10.728279402476991, 9.949647081409175, 8.949063911702536, 7.097053898106416, 6.029351606417808, 5.047289035786752, 4.056278189394392, 3.0053005212392576, 2.0311949397088576, 0.9826213694216925, 0.0, 0.9674226803989242, 1.9118794340533851, 2.8372295542871013, 3.773437424426885, 4.8061970202888595, 5.816738512741621, 6.879586232254225, 7.922312934347924, 8.994765437786707, 10.04009084890788, 8.996891767396516, 8.0627517031502, 7.971422865921075, 6.941920331478862, 5.903598395906372, 4.919811466375202, 3.9200530569137584, 2.921096577412932, 1.94140230068948, 1.0624159388344414, 1.9497355485842212, 2.910905166707069, 3.7748817932988623, 4.77722433732852, 5.734753164898848, 6.767971388197385, 7.781523259960413, 8.838094876235823, 9.842958481550458, 10.828071790002086, 9.865966511192724, 8.94048073421227, 8.804991015452371, 7.858117730054237, 6.872085956052313, 5.851995564734217, 4.8436086282807995, 3.8884845864920545, 2.932183398622508, 2.0323715234132695, 2.8935462117950026, 3.8815890215781503, 4.784531422815419, 5.8052952359962715, 6.733864453458866, 7.674312810116059, 8.68068579728243, 9.675646595805594, 10.660178190622144, 11.62485082837813, 10.75857380028728, 9.758733432955783, 9.823319436332204, 8.749909029191645, 7.788732996462365, 6.851817816478914, 5.777544893332442, 4.939059595353512, 3.884726382541936, 3.0973937562712552, 3.909256746923842, 4.892283870416568, 5.756613300729031, 6.741389102910224, 7.7286974436683495, 8.732336829288824, 9.673425835334818, 10.611175459557483, 11.602038577358654, 12.603023654262737, 11.743439559809755, 10.708624895822592, 10.814869540842569, 9.768928019967149, 8.770913300669546, 7.778717728851911, 6.745136366734327, 5.847873052732841, 4.892352970543712, 4.133283829296288, 4.904739840134868, 5.963747934111989, 6.701196449606038, 7.65815070953089, 8.70557528918638, 9.69736541674154, 10.682387090791678, 11.640154251844569, 12.568683312315954, 13.571096920682601, 12.710081596641464, 11.731981643672382], [13.774156248531792, 14.490533147713201, 13.497190812169212, 12.537398658627641, 11.678704741370359, 10.674006426281508, 9.723275389112079, 8.716671910243758, 7.67713410650384, 6.732370650870063, 5.975368609754383, 4.9488930194682315, 5.912835692108626, 6.845425508155687, 7.792599959325578, 8.669857402114362, 9.697801109844459, 10.709993068993299, 11.758540309605172, 12.77817677999894, 14.527875671618613, 15.466569032393357, 14.527997123178054, 13.477796737615584, 12.614265186718153, 11.63705197376735, 10.576026085119278, 9.640800353564586, 8.654053346932125, 7.724524353785312, 6.820808924495549, 5.891175915094285, 6.929899933067011, 7.797362788625291, 8.719565352138314, 9.725935233475825, 10.688895604621058, 11.653739859818613, 12.640359176858713, 13.587285565414733, 15.50905875480256, 16.46722485418217, 15.504555967626443, 14.50669061076855, 13.623368948006675, 12.625390420266656, 11.59839553523958, 10.580355190526852, 9.610528874888281, 8.657699928330214, 7.795984777247865, 6.828675361023604, 7.88611133925173, 8.819481036101958, 9.738796309385553, 10.776910858104035, 11.670841022230801, 12.624018130393628, 13.588033005110063, 14.525052116226423, 16.542052601424977, 17.403229065951958, 16.41901239913291, 15.469201234760837, 14.564996323027001, 13.496239840014908, 12.512620336905131, 11.513535537385357, 10.557363346091789, 9.611266279187806, 8.862748506785628, 7.841039065502046, 8.804670114165438, 9.849778682950951, 10.68310247089794, 11.757275677238638, 12.624507238496932, 13.562636860486482, 14.560173189701814, 15.497681029437006, 17.379830743083822, 17.556138590853564, 16.588296016799237, 15.548613315919935, 14.584406449456656, 13.650758520748104, 12.661706875473083, 11.718970961850262, 10.904344362038136, 10.645260617493049, 9.747949288051569, 8.771130819989839, 9.764098874367503, 10.77638702070949, 11.753231345572281, 12.710061701519818, 13.604720659667919, 14.524102081236935, 15.501338985775247, 16.441930139055632, 17.42514619714821, 16.669466262348134, 15.720466699103929, 14.716109253386168, 13.700302036687692, 12.762694976972496, 11.722435150123538, 10.793722321065015, 9.894125693136028, 10.761660160891378, 10.806491196143313, 9.793174396042767, 10.765458508407942, 11.736869709122098, 12.782689222360158, 13.668683130357044, 14.560449196144257, 15.572163015668906, 16.435897698299257, 17.416723538556848, 16.431944109024844, 15.655725723475964, 14.68820410425184, 13.726905824397477, 12.750633572543403, 11.734643739893295, 10.716088346308753, 9.847628374348705, 8.911274661082333, 9.825880133929934, 10.831665324114757, 10.843730410501092, 11.774210948931557, 12.730612544436891, 13.738429324736542, 14.66078293990001, 15.493283225661502, 16.506782879315466, 17.400016014008422, 17.363898440980876, 15.464737795726704, 14.644663802837647, 13.697053103932513, 12.737677393306239, 11.716920352778262, 10.749181064051289, 9.76252100548401, 8.901119591908605, 7.969458770854069, 8.809232488082872, 9.803631775150789, 10.707506188860316, 11.627931094769256, 12.557180291390475, 13.472612369035629, 14.331915963432857, 15.279240553331517, 16.21109823361004, 17.236353753618406, 16.525410337457775, 14.536137739622546, 13.655951143861744, 12.744098716815566, 11.7782944910904, 10.800661167776301, 9.781957534630102, 8.7578867502885, 7.832439360668021, 6.894485461165775, 7.846170437733519, 8.75169127667804, 9.756338699983415, 10.685266455781864, 11.563082098553187, 12.457010466486041, 13.394749871804825, 14.399398396892346, 15.34282913703639, 16.357913012683237, 15.587909618156125, 13.529645694912436, 12.681760903355732, 11.708979481637224, 10.809094483595674, 9.895444495442057, 8.899258238497037, 7.824673202369746, 6.8892669941429, 5.940672493465452, 6.876068005709386, 7.77207364744399, 8.75492271722744, 9.67193023125216, 10.605483076021722, 11.468308471324388, 12.42191024497173, 13.465121701392757, 14.455073672175486, 15.409990589318609, 14.599550691675766, 12.563014269716, 11.612852520332995, 10.651296509388194, 9.81089171924508, 8.955390337110575, 7.956384770633041, 7.010740144869171, 5.962997713044179, 4.9615127441707365, 5.926747800164161, 6.822767189479375, 7.862634053702955, 8.643973615551493, 9.590943001326877, 10.516143444730343, 11.462206654249496, 12.445976750685594, 13.384459218668427, 14.382126332042679, 13.587902476283947, 11.712902705380353, 10.643357133516501, 9.71338917776356, 8.7947963221958, 7.913148967052251, 6.959638022042882, 5.990227896135766, 4.9828087309330265, 3.9188016925305647, 4.93582729944859, 5.847383665953192, 6.837133470498291, 7.689570257525166, 8.725685217727126, 9.636092465996356, 10.489432815050321, 11.44773127592494, 12.432278688158755, 13.455859459562767, 12.680922589361273, 10.72046162515459, 9.707536190832851, 8.777922368113172, 7.863499007993855, 6.88580495518282, 5.929507401059652, 4.9818716067651305, 3.948140815940536, 2.9109877576876513, 3.8823456520937176, 4.8393307069519595, 5.821802484565605, 6.714641646856922, 7.726558617997249, 8.6071878061316, 9.545934275076931, 10.492047252088426, 11.462293835435181, 12.427279902051406, 11.694634097948736, 9.810693430849579, 8.875631763355953, 7.838465424841553, 6.912169935574876, 5.950609271745764, 4.968344759520442, 3.93229796998975, 2.9393152616205303, 1.958288294739884, 2.887065484029944, 3.797131924406958, 4.774169497987301, 5.721570922964662, 6.684396139912303, 7.6683898097344025, 8.608407485717072, 9.640898506342682, 10.706144728502158, 11.716459496404907, 10.80207613699603, 8.864844163302307, 7.9068107827623795, 6.911262491530448, 5.949470848758163, 5.0131692477378245, 4.026970054996818, 2.9741064508271546, 1.929751838879453, 1.0253026903986773, 1.951962964408446, 2.8252931558582666, 3.8245685504512705, 4.769464945137609, 5.788410335999618, 6.838392717240694, 7.805645270634994, 8.818367306052894, 9.760856722078065, 10.74720388294932, 9.91648659210146, 8.064476578505339, 6.9967742868167315, 6.014711716185676, 5.023700869793316, 3.9727232016381815, 2.9986176201077814, 1.9500440498206166, 0.9674226803989242, 0.0, 0.944456753654461, 1.8698068738881772, 2.8060147440279612, 3.838774339889935, 4.849315832342697, 5.9121635518553015, 6.954890253949, 8.027342757387784, 9.072668168508956, 9.964314447795438, 9.030174383549122, 8.93884554632, 7.909343011877786, 6.871021076305296, 5.887234146774126, 4.887475737312682, 3.8885192578118564, 2.9088249810884044, 1.93673406910157, 0.9823128681852968, 1.9434824863081448, 2.807459112899938, 3.8098016569295963, 4.767330484499924, 5.800548707798461, 6.814100579561489, 7.8706721958368995, 8.875535801151536, 9.948696602509141, 10.83338919159165, 9.907903414611196, 9.772413695851295, 8.82554041045316, 7.839508636451237, 6.819418245133141, 5.811031308679723, 4.855907266890979, 3.8996060790214324, 2.906689653680398, 1.9261235313960785, 2.914166341179226, 3.817108742416495, 4.837872555597347, 5.766441773059941, 6.706890129717134, 7.713263116883505, 8.708223915406668, 9.692755510223218, 10.657428147979205, 11.618231598922145, 10.726156113354707, 10.790742116731128, 9.71733170959057, 8.756155676861288, 7.819240496877838, 6.7449675737313655, 5.906482275752436, 4.85214906294086, 3.927978456500238, 2.941834066524918, 3.9248611900176447, 4.789190620330107, 5.773966422511299, 6.761274763269425, 7.7649141488899, 8.706003154935892, 9.643752779158557, 10.634615896959728, 11.635600973863811, 12.6776907275381, 11.676047576221515, 11.782292221241493, 10.736350700366073, 9.73833598106847, 8.746140409250835, 7.712559047133251, 6.815295733131765, 5.859775650942636, 4.896228708894814, 3.937317159735944, 4.996325253713066, 5.733773769207114, 6.690728029131966, 7.7381526087874555, 8.729942736342617, 9.714964410392756, 10.672731571445643, 11.601260631917029, 12.603674240283675, 13.616165080940604, 12.699404324071306], [14.495720907178288, 13.546076394058739, 12.55273405851475, 11.592941904973179, 10.734247987715895, 9.729549672627044, 8.778818635457617, 7.772215156589296, 6.732677352849379, 5.787913897215602, 5.1777072475331956, 5.893349773122692, 6.857292445763086, 7.789882261810147, 8.737056712980038, 9.614314155768822, 10.64225786349892, 11.65444982264776, 12.702997063259632, 13.7226335336534, 15.467196373092154, 14.522112278738895, 13.583540369523591, 12.533339983961122, 11.669808433063691, 10.692595220112889, 9.631569331464815, 8.696343599910124, 7.709596593277663, 6.780067600130851, 6.2158435184979535, 6.835632668748746, 7.874356686721471, 8.741819542279751, 9.664022105792775, 10.670391987130285, 11.633352358275518, 12.598196613473073, 13.584815930513173, 14.531742319069194, 16.45351550845702, 15.522768100527708, 14.56009921397198, 13.562233857114087, 12.678912194352213, 11.680933666612194, 10.65393878158512, 9.635898436872392, 8.666072121233821, 7.713243174675753, 7.1910193712502695, 7.773132114678065, 8.83056809290619, 9.763937789756419, 10.683253063040013, 11.721367611758495, 12.615297775885262, 13.568474884048088, 14.532489758764523, 15.469508869880883, 17.486509355079438, 16.458772312297498, 15.474555645478448, 14.524744481106374, 13.620539569372541, 12.551783086360448, 11.568163583250671, 10.569078783730896, 9.612906592437328, 8.666809525533345, 8.257783100788032, 8.785495819156505, 9.749126867819896, 10.79423543660541, 11.6275592245524, 12.701732430893099, 13.568963992151392, 14.507093614140942, 15.504629943356274, 16.442137783091468, 18.324287496738286, 17.39244092588942, 16.424598351835094, 15.429376027555843, 14.465169161092565, 13.531521232384012, 12.542469587108991, 11.59973367348617, 10.63455104337961, 9.700803863838589, 9.19901057898912, 9.7155875736443, 10.708555628021964, 11.72084377436395, 12.697688099226742, 13.654518455174278, 14.54917741332238, 15.468558834891395, 16.44579573942971, 17.386386892710096, 18.36960295080267, 17.613923016002595, 16.664923452758387, 15.660566007040629, 14.644758790342154, 13.707151730626958, 12.666891903778, 11.738179074719476, 10.83858244679049, 9.966246340222087, 10.257552487080863, 10.737631149697227, 11.709915262062403, 12.681326462776559, 13.727145976014619, 14.613139884011504, 15.504905949798717, 16.516619769323366, 17.380354451953718, 18.361180292211312, 17.376400862679304, 16.600182477130424, 15.6326608579063, 14.671362578051937, 13.695090326197866, 12.679100493547757, 11.660545099963215, 10.792085128003166, 9.855731414736795, 9.030466313260643, 9.896893563618544, 10.794852383210248, 11.615568676976782, 12.661406343058696, 13.498405457917976, 14.403439680557899, 15.298716117499476, 16.21186302867347, 17.177323663107064, 18.18267759950088, 16.409194549381162, 15.589120556492107, 14.641509857586973, 13.682134146960701, 12.661377106432724, 11.693637817705751, 10.706977759138471, 9.845576345563066, 8.91391552450853, 8.013818667413581, 8.859175021496329, 9.763049435205856, 10.683474341114795, 11.612723537736015, 12.528155615381168, 13.387459209778397, 14.334783799677057, 15.266641479955581, 16.291896999963946, 17.283153311707395, 15.480594493277007, 14.600407897516204, 13.688555470470027, 12.722751244744863, 11.745117921430765, 10.726414288284566, 9.702343503942963, 8.776896114322481, 7.838942214820236, 7.050756617064227, 7.807234523023579, 8.811881946328954, 9.740809702127404, 10.618625344898726, 11.512553712831581, 12.450293118150364, 13.454941643237886, 14.398372383381929, 15.413456259028775, 16.472787002652886, 14.474102448566896, 13.626217657010192, 12.653436235291684, 11.753551237250138, 10.839901249096519, 9.843714992151499, 8.769129956024207, 7.83372374779736, 6.885129247119912, 6.080654185040094, 6.827616893789529, 7.81046596357298, 8.7274734775977, 9.661026322367261, 10.523851717669928, 11.477453491317268, 12.520664947738297, 13.510616918521023, 14.465533835664147, 15.449767179390937, 13.50747102337046, 12.557309273987455, 11.595753263042655, 10.755348472899543, 9.899847090765038, 8.900841524287504, 7.955196898523633, 6.907454466698639, 5.905969497825197, 5.057820510381209, 5.878310435824915, 6.9181773000484945, 7.699516861897033, 8.646486247672417, 9.571686691075882, 10.517749900595033, 11.501519997031131, 12.440002465013965, 13.437669578388217, 14.438118963999118, 12.657359459034813, 11.587813887170961, 10.65784593141802, 9.739253075850264, 8.857605720706713, 7.904094775697344, 6.934684649790228, 5.927265484587487, 4.863258446185025, 4.066900009665638, 4.902926912298732, 5.89267671684383, 6.745113503870705, 7.781228464072664, 8.691635712341894, 9.54497606139586, 10.503274522270479, 11.487821934504293, 12.511402705908305, 13.511499716561309, 11.66491837880905, 10.651992944487311, 9.722379121767633, 8.807955761648318, 7.830261708837282, 6.8739641547141135, 5.926328360419592, 4.892597569594997, 3.855444511342112, 3.013418362310764, 3.8948739532974987, 4.877345730911144, 5.770184893202461, 6.7821018643427875, 7.662731052477138, 8.601477521422469, 9.547590498433964, 10.51783708178072, 11.482823148396944, 12.525211225148771, 10.75515018450404, 9.820088517010413, 8.782922178496014, 7.856626689229336, 6.895066025400225, 5.912801513174903, 4.876754723644211, 3.8837720152749915, 2.902745048394345, 1.942608730375483, 2.852675170752497, 3.82971274433284, 4.777114169310201, 5.739939386257841, 6.723933056079941, 7.6639507320626095, 8.69644175268822, 9.761687974847696, 10.772002742750447, 11.714696333680292, 9.809300916956767, 8.85126753641684, 7.8557192451849085, 6.8939276024126235, 5.957626001392286, 4.9714268086512785, 3.9185632044816154, 2.874208592533914, 1.9697594440531383, 1.007506210753985, 1.8808364022038058, 2.8801117967968097, 3.825008191483148, 4.843953582345157, 5.893935963586233, 6.8611885169805324, 7.873910552398433, 8.816399968423605, 9.80274712929486, 10.851994287556579, 9.008933332159799, 7.941231040471192, 6.959168469840137, 5.968157623447777, 4.917179955292642, 3.9430743737622422, 2.8945008034750774, 1.9118794340533851, 0.944456753654461, 0.0, 0.9253501202337162, 1.8615579903735, 2.894317586235474, 3.904859078688235, 4.96770679820084, 6.010433500294539, 7.082886003733322, 8.128211414854496, 9.189561921521255, 9.974631137203582, 9.883302299974462, 8.853799765532248, 7.815477829959757, 6.831690900428587, 5.8319324909671435, 4.832976011466317, 3.8532817347428647, 2.881190822756031, 1.9267696218397579, 0.9990257326536839, 1.8630023592454772, 2.865344903275135, 3.822873730845463, 4.8560919541439995, 5.869643825907028, 6.926215442182438, 7.931079047497073, 9.004239848854679, 9.966345127664042, 10.852360168265658, 10.716870449505755, 9.76999716410762, 8.783965390105697, 7.763874998787602, 6.755488062334184, 5.800364020545439, 4.844062832675893, 3.851146407334859, 2.8705802850505395, 2.030491293340436, 2.8726519887620343, 3.8934158019428864, 4.8219850194054805, 5.762433376062674, 6.768806363229045, 7.763767161752207, 8.748298756568756, 9.712971394324743, 10.673774845267683, 11.670612867009167, 11.735198870385586, 10.661788463245028, 9.700612430515747, 8.763697250532298, 7.689424327385826, 6.850939029406896, 5.796605816595321, 4.872435210154699, 3.886290820179379, 3.0723439076757177, 3.8447338666756457, 4.829509668856839, 5.816818009614964, 6.820457395235439, 7.761546401281432, 8.699296025504095, 9.690159143305266, 10.691144220209349, 11.733233973883637, 12.620504329875976, 12.726748974895951, 11.680807454020531, 10.68279273472293, 9.690597162905295, 8.657015800787711, 7.759752486786225, 6.804232404597096, 5.840685462549274, 4.881773913390405, 4.143807971371139, 4.789317015552653, 5.746271275477505, 6.793695855132994, 7.785485982688154, 8.770507656738292, 9.728274817791181, 10.656803878262567, 11.659217486629213, 12.671708327286142, 13.643861077725767], [13.570370786944572, 12.620726273825023, 11.627383938281033, 10.667591784739463, 9.80889786748218, 8.80419955239333, 7.8534685152239, 6.84686503635558, 5.807327232615663, 4.862563776981886, 5.850129613919135, 6.818699893356407, 7.7826425659968015, 8.715232382043864, 9.662406833213755, 10.539664276002538, 11.567607983732636, 12.579799942881476, 13.628347183493348, 14.610182533234827, 14.541846252858438, 13.596762158505179, 12.658190249289875, 11.607989863727406, 10.744458312829975, 9.767245099879172, 8.7062192112311, 7.770993479676408, 6.784246473043947, 5.854717479897134, 6.808822737905914, 7.738455747307178, 8.777179765279904, 9.667169662513468, 10.58937222602649, 11.595742107364002, 12.558702478509234, 13.52354673370679, 14.51016605074689, 15.45709243930291, 15.559567516121133, 14.597417980293992, 13.634749093738264, 12.636883736880371, 11.753562074118497, 10.755583546378478, 9.728588661351404, 8.710548316638675, 7.740722001000105, 6.787893054442037, 7.78399859065823, 8.675955193236497, 9.733391171464623, 10.681975167537331, 11.608603183273729, 12.646717731992211, 13.540647896118978, 14.493825004281804, 15.45783987899824, 16.3948589901146, 16.571830344761757, 15.53342219206378, 14.549205525244732, 13.599394360872658, 12.695189449138825, 11.626432966126732, 10.642813463016955, 9.64372866349718, 8.687556472203612, 7.741459405299629, 8.787333416181525, 9.688318897714938, 10.651949946378329, 11.697058515163842, 12.552909344786116, 13.627082551126815, 14.494314112385108, 15.432443734374658, 16.42998006358999, 17.367487903325184, 17.4987750049497, 16.467090805655705, 15.499248231601378, 14.504025907322127, 13.539819040858848, 12.606171112150296, 11.617119466875275, 10.674383553252454, 9.709200923145893, 8.775453743604873, 9.728560894382612, 10.618410652202732, 11.611378706580396, 12.623666852922382, 13.623038219460458, 14.579868575407994, 15.474527533556095, 16.393908955125113, 17.371145859663425, 18.311737012943812, 18.42180630720461, 17.46660030570788, 16.53096447916449, 15.503039277665813, 14.477370482688395, 13.539763422973198, 12.63294734097133, 11.599632194037701, 10.719419592048002, 9.753121068026871, 9.920210800606528, 10.920058277434856, 11.735529202580244, 12.7069404032944, 13.631191532208659, 14.470189369867148, 15.306200026783005, 16.221132772086317, 17.15769798258372, 18.209147627858282, 18.189281811223196, 17.525532597364137, 16.558010978140018, 15.596712698285653, 14.62044044643158, 13.604450613781472, 12.58589522019693, 11.655923272342545, 10.697767207967857, 9.805396494044114, 8.971543443384828, 9.869502262976532, 10.690218556743066, 11.73605622282498, 12.57305533768426, 13.478089560324182, 14.37336599726576, 15.286512908439756, 16.251973542873348, 17.257327479267165, 17.33454466961488, 16.51447067672582, 15.56685997782069, 14.607484267194415, 13.586727226666438, 12.618987937939465, 11.632327879372186, 10.77092646579678, 9.755951317739592, 8.788748848197052, 7.9338249012626125, 8.83769931497214, 9.75812422088108, 10.6873734175023, 11.602805495147452, 12.46210908954468, 13.40943367944334, 14.341291359721865, 15.366546879730231, 16.35780319147368, 16.405944613510723, 15.52575801774992, 14.613905590703743, 13.648101364978576, 12.670468041664478, 11.651764408518279, 10.627693624176677, 9.702246234556196, 8.744792845767824, 7.825686797847699, 6.881884402789863, 7.886531826095237, 8.815459581893688, 9.693275224665012, 10.587203592597865, 11.524942997916648, 12.52959152300417, 13.473022263148213, 14.48810613879506, 15.547436882419168, 15.399452568800612, 14.551567777243909, 13.5787863555254, 12.67890135748385, 11.765251369330233, 10.769065112385213, 9.694480076257921, 8.759073868031075, 7.790979878067501, 6.8555843658235665, 5.902266773555813, 6.885115843339264, 7.8021233573639845, 8.735676202133547, 9.598501597436211, 10.552103371083552, 11.59531482750458, 12.585266798287307, 13.54018371543043, 14.524417059157221, 14.432821143604176, 13.482659394221171, 12.52110338327637, 11.680698593133256, 10.825197210998752, 9.82619164452122, 8.88054701875735, 7.8328045869323555, 6.831319618058913, 5.9647915091045665, 4.9529603155911985, 5.992827179814777, 6.774166741663318, 7.721136127438702, 8.646336570842166, 9.592399780361317, 10.576169876797415, 11.514652344780249, 12.5123194581545, 13.512768843765402, 13.581234367867918, 12.513164007404677, 11.583196051651736, 10.664603196083977, 9.782955840940428, 8.829444895931061, 7.860034770023944, 6.852615604821203, 5.788608566418741, 4.973871008388995, 3.977576792065015, 4.967326596610113, 5.81976338363699, 6.855878343838949, 7.7662855921081775, 8.619625941162143, 9.577924402036762, 10.562471814270577, 11.586052585674588, 12.586149596327592, 12.574033577709201, 11.577343064721028, 10.647729242001349, 9.733305881882032, 8.755611829070997, 7.79931427494783, 6.851678480653308, 5.8179476898287135, 4.780794631575828, 3.9387684825444804, 2.9695238330637825, 3.951995610677428, 4.8448347729687455, 5.856751744109072, 6.737380932243423, 7.6761274011887535, 8.622240378200248, 9.592486961547003, 10.557473028163228, 11.599861104915055, 11.680500304737755, 10.74543863724413, 9.70827229872973, 8.781976809463051, 7.82041614563394, 6.83815163340862, 5.8021048438779275, 4.809122135508708, 3.828095168628061, 2.8679588506091993, 1.927325050518781, 2.904362624099124, 3.851764049076485, 4.814589266024126, 5.798582935846226, 6.738600611828894, 7.771091632454503, 8.83633785461398, 9.846652622516729, 10.789346213446574, 10.734651037190483, 9.776617656650556, 8.781069365418624, 7.819277722646339, 6.882976121626001, 5.896776928884995, 4.843913324715332, 3.79955871276763, 2.8951095642868543, 1.9328563309877012, 0.9554862819700894, 1.9547616765630933, 2.8996580712494318, 3.9186034621114407, 4.968585843352517, 5.935838396746816, 6.948560432164717, 7.891049848189888, 8.877397009061141, 9.92664416732286, 9.934283452393515, 8.866581160704907, 7.884518590073852, 6.893507743681492, 5.842530075526358, 4.868424493995958, 3.8198509237087936, 2.8372295542871013, 1.8698068738881772, 0.9253501202337162, 0.0, 0.9362078701397838, 1.9689674660017578, 2.979508958454519, 4.042356677967124, 5.085083380060823, 6.157535883499606, 7.20286129462078, 8.264211801287539, 9.198351865533855, 10.808652420208178, 9.779149885765964, 8.740827950193474, 7.757041020662303, 6.75728261120086, 5.758326131700033, 4.778631854976581, 3.8065409429897468, 2.852119742073474, 1.9243758528874002, 0.937652239011761, 1.9399947830414188, 2.8975236106117466, 3.9307418339102833, 4.944293705673312, 6.000865321948722, 7.005728927263357, 8.078889728620963, 9.040995007430325, 9.966480784410779, 11.642220569739473, 10.695347284341338, 9.709315510339415, 8.68922511902132, 7.6808381825679, 6.725714140779155, 5.769412952909609, 4.776496527568575, 3.7959304052842553, 2.878460236330204, 1.947301868528318, 2.96806568170917, 3.8966348991717648, 4.837083255828958, 5.8434562429953285, 6.838417041518491, 7.82294863633504, 8.787621274091027, 9.748424725033967, 10.748265092365465, 12.660548990619303, 11.587138583478744, 10.625962550749463, 9.689047370766014, 8.614774447619542, 7.776289149640612, 6.721955936829037, 5.797785330388415, 4.811640940413095, 3.8567153251482713, 2.9193837464419294, 3.9041595486231233, 4.891467889381249, 5.895107275001723, 6.836196281047716, 7.773945905270379, 8.76480902307155, 9.765794099975633, 10.80788385364992, 11.698156555232273, 13.652099095129667, 12.606157574254247, 11.608142854956647, 10.615947283139011, 9.582365921021427, 8.68510260701994, 7.729582524830812, 6.766035582782989, 5.80712403362412, 4.9035143985270855, 3.863966895318937, 4.820921155243789, 5.868345734899278, 6.860135862454438, 7.845157536504577, 8.802924697557465, 9.73145375802885, 10.733867366395497, 11.746358207052426, 12.721513303082064], [12.675749528937303, 11.726105015817753, 10.732762680273764, 9.772970526732193, 8.921725021950717, 7.925848647116767, 7.007337019132102, 6.000733540263782, 4.961195736523864, 5.7987716471216695, 6.786337484058919, 7.754907763496192, 8.718850436136586, 9.651440252183647, 10.598614703353539, 11.475872146142324, 12.503815853872421, 13.516007813021261, 14.564555053633134, 13.715561275227557, 13.647224994851168, 12.70214090049791, 11.763568991282606, 10.713368605720136, 9.898326816738177, 8.921113603787374, 7.860087715139301, 6.924861983584609, 5.938114976952148, 6.790925350036918, 7.745030608045698, 8.674663617446962, 9.713387635419688, 10.603377532653251, 11.525580096166275, 12.531949977503785, 13.494910348649018, 14.459754603846575, 15.446373920886675, 14.587815101055048, 14.664946258113863, 13.702796722286722, 12.740127835730995, 11.742262478873101, 10.907430578026698, 9.90945205028668, 8.88368938662705, 7.883365602750625, 6.913539287112053, 7.724100924581821, 8.720206460798014, 9.612163063376281, 10.669599041604407, 11.618183037677115, 12.544811053413513, 13.582925602131995, 14.476855766258762, 15.43003287442159, 16.394047749138025, 15.525581651866737, 15.677209086754488, 14.63880093405651, 13.654584267237462, 12.704773102865389, 11.860380474091366, 10.824745466323703, 9.841125963213926, 8.851041201682575, 7.894869010389007, 8.677667275439413, 9.723541286321309, 10.624526767854721, 11.588157816518112, 12.633266385303626, 13.4891172149259, 14.563290421266597, 15.430521982524894, 16.368651604514444, 17.366187933729776, 16.512435724026577, 16.60415374694243, 15.572469547648435, 14.604626973594108, 13.711338445507522, 12.747131579044243, 11.81348365033569, 10.82443200506067, 9.881696091437849, 8.916513461331288, 9.711661613744656, 10.664768764522396, 11.199521193415567, 11.807576663397185, 12.81894974932499, 13.731337235773037, 14.499498625480875, 15.332616390035843, 16.33988153329479, 17.16294452188423, 17.503789264972895, 17.52718504919734, 16.57197904770061, 15.651325302536485, 14.710351815851208, 13.68468302087379, 12.747075961158593, 11.840259879156726, 10.806944732223096, 9.926732130233397, 10.689328938166655, 10.856418670746312, 10.177477617362639, 10.806217029356747, 11.777628230070903, 12.70187935898516, 13.540877196643649, 14.376887853559506, 15.291820598862818, 16.228385809360223, 17.279835454634785, 17.2599696379997, 17.58571958657278, 16.683587897388573, 15.652898375023195, 14.676626123169124, 13.797874856758593, 12.768339999571364, 11.753038678939406, 10.909583162287092, 10.741604364183898, 9.907751313524612, 9.126921602904314, 9.760906383519568, 10.806744049601482, 11.64374316446076, 12.548777387100683, 13.44405382404226, 14.357200735216257, 15.32266136964985, 16.328015306043667, 16.48916355998125, 17.450678546865607, 16.503067847960473, 15.543692137334201, 14.522935096806224, 13.555195808079251, 12.568535749511971, 11.707134335936566, 10.692159187879376, 9.724956718336836, 8.870032771402396, 8.095118654899922, 8.828812047657582, 9.7580612442788, 10.673493321923953, 11.532796916321182, 12.480121506219842, 13.411979186498366, 14.437234706506732, 15.428491018250181, 15.579618758902424, 16.461965887889708, 15.550113460843528, 14.584309235118361, 13.606675911804263, 12.587972278658064, 11.563901494316463, 10.638454104695981, 9.681000715907608, 8.761894667987482, 7.818092272929647, 7.14395116602302, 7.886147408670189, 8.763963051441511, 9.657891419374366, 10.59563082469315, 11.60027934978067, 12.543710089924716, 13.55879396557156, 14.61812470919567, 14.573126714192313, 15.487775647383694, 14.514994225665186, 13.615109227623636, 12.701459239470019, 11.705272982524999, 10.630687946397707, 9.695281738170861, 8.727187748207285, 7.79179223596335, 6.838474643695597, 6.1425351832670465, 6.8728111841404855, 7.806364028910047, 8.669189424212712, 9.622791197860053, 10.66600265428108, 11.655954625063808, 12.610871542206931, 13.595104885933722, 13.606495288995877, 14.418867264360957, 13.457311253416156, 12.616906463273041, 11.761405081138538, 10.762399514661004, 9.816754888897133, 8.76901245707214, 7.767527488198697, 6.900999379244351, 5.889168185730982, 5.112173525171774, 5.8448545684398185, 6.791823954215203, 7.717024397618667, 8.663087607137818, 9.646857703573916, 10.58534017155675, 11.583007284931002, 12.583456670541903, 12.651922194644417, 13.449371877544463, 12.519403921791522, 11.600811066223763, 10.719163711080213, 9.765652766070843, 8.796242640163728, 7.788823474960988, 6.724816436558526, 5.91007887852878, 4.913784662204799, 4.08667294196711, 4.890451210413491, 5.92656617061545, 6.8369734188846785, 7.690313767938644, 8.648612228813263, 9.633159641047078, 10.65674041245109, 11.656837423104093, 11.644721404485702, 12.513550934860813, 11.583937112141134, 10.669513752021818, 9.691819699210782, 8.735522145087614, 7.787886350793093, 6.754155559968497, 5.717002501715613, 4.874976352684264, 3.9057317032035663, 3.044654972636864, 3.9155225997452465, 4.927439570885573, 5.808068759019924, 6.7468152279652545, 7.692928204976749, 8.663174788323504, 9.628160854939729, 10.670548931691556, 10.844521049453242, 11.681646507383915, 10.644480168869515, 9.718184679602837, 8.756624015773726, 7.774359503548404, 6.738312714017712, 5.745330005648492, 4.764303038767846, 3.8041667207489835, 2.8635329206585647, 1.9970219860585599, 2.9224518758529863, 3.885277092800627, 4.869270762622727, 5.809288438605395, 6.841779459231004, 7.907025681390481, 8.910444752376945, 9.85313834330679, 10.042078725982233, 10.712825526790342, 9.71727723555841, 8.755485592786124, 7.819183991765787, 6.832984799024779, 5.780121194855116, 4.735766582907415, 3.8313174344266385, 2.869064201127485, 1.8916941521098734, 1.0474210385225295, 1.963450201109648, 2.982395591971657, 4.032377973212733, 4.999630526607032, 6.012352562024933, 6.954841978050104, 7.9411891389213585, 8.990436297183077, 9.227841800437854, 9.802789030844693, 8.820726460213638, 7.829715613821278, 6.778737945666143, 5.804632364135744, 4.756058793848578, 3.7734374244268856, 2.8060147440279612, 1.8615579903735, 0.9362078701397838, 0.0, 1.032759595861974, 2.043301088314735, 3.1061488078273403, 4.148875509921039, 5.221328013359822, 6.266653424480996, 7.328003931147755, 8.262143995394071, 9.999330782562192, 10.71535775590575, 9.67703582033326, 8.693248890802089, 7.693490481340644, 6.694534001839818, 5.714839725116366, 4.7427488131295314, 3.788327612213258, 2.860583723027184, 1.8738601091515448, 1.003786912901635, 1.961315740471963, 2.9945339637704995, 4.008085835533528, 5.064657451808938, 6.069521057123573, 7.142681858481179, 8.104787137290542, 9.030272914270995, 10.807386251861606, 11.631555154481124, 10.6455233804792, 9.625432989161105, 8.617046052707686, 7.66192201091894, 6.705620823049394, 5.712704397708359, 4.73213827542404, 3.8146681064699877, 2.883509738668102, 2.075240169225226, 3.0038093866878204, 3.9424619978216877, 4.948834984988059, 5.943795783511221, 6.92832737832777, 7.893000016083757, 8.853803467026697, 9.853643834358195, 11.767724665113724, 12.52334645361853, 11.562170420889249, 10.6252552409058, 9.550982317759328, 8.712497019780397, 7.658163806968822, 6.733993200528199, 5.747848810552879, 4.792923195288055, 3.8555916165817132, 3.011334036139179, 3.9986423768973043, 5.000486016994453, 5.941575023040446, 6.879324647263109, 7.87018776506428, 8.871172841968363, 9.913262595642651, 10.803535297225004, 12.795477659788574, 13.542365444394033, 12.544350725096432, 11.552155153278797, 10.518573791161213, 9.621310477159724, 8.665790394970596, 7.702243452922774, 6.743331903763905, 5.839722268666869, 4.800174765458721, 3.9747896591519902, 5.0222142388074795, 6.01400436636264, 6.966806631228014, 7.908303439550195, 8.83683250002158, 9.839246108388227, 10.851736949045156, 11.826892045074795], [11.722950061150657, 10.773305548031107, 9.779963212487118, 8.820171058945547, 7.968925554164071, 6.973049179330121, 6.056275999466573, 5.111364030279105, 5.901026989471222, 6.831531242983644, 7.819097079920893, 8.787667359358165, 9.75161003199856, 10.68419984804562, 11.631374299215512, 12.508631742004296, 13.536575449734393, 14.548767408883233, 13.78239827783468, 12.762761807440912, 12.694425527064523, 11.749341432711264, 10.81076952349596, 9.76056913793349, 8.956504290146228, 8.01900448576122, 6.99616920354451, 6.111732297622245, 6.877946229899506, 7.823684945898893, 8.777790203907673, 9.707423213308937, 10.746147231281663, 11.636137128515225, 12.558339692028248, 13.564709573365759, 14.527669944510992, 15.492514199708546, 14.581942021824423, 13.635015633268402, 13.712146790327218, 12.749997254500077, 11.78732836794435, 10.789463011086456, 9.96560805143475, 9.007342932260526, 8.01977087503226, 7.160954775195724, 7.853370540059411, 8.756860520443794, 9.75296605665999, 10.644922659238256, 11.702358637466382, 12.65094263353909, 13.577570649275486, 14.615685197993969, 15.509615362120735, 16.462792470283564, 15.573985519291174, 14.572782184080092, 14.724409618967842, 13.686001466269865, 12.701784799450817, 11.751973635078743, 10.918557947499417, 9.960826954728914, 8.977207451619137, 8.217905437754748, 8.834700263336366, 9.710426871301387, 10.756300882183282, 11.657286363716697, 11.750789687012052, 12.712798491221553, 13.76091261219168, 14.428323265123987, 15.280070215344857, 16.218199837334407, 16.497144095975123, 15.559636256239932, 15.651354279155786, 14.61967007986179, 13.651827505807463, 12.790846807060248, 11.898483209241093, 10.96483528053254, 9.987260124822122, 9.248560327510022, 9.856344714278647, 10.74442120960663, 11.69752836038437, 11.731226916599311, 10.77481706753521, 11.786190153463014, 12.698577639911063, 13.466739029618902, 14.29985679417387, 15.307121937432816, 16.130184926022256, 16.55098979718625, 16.574385581410695, 15.619179579913963, 14.698525834749837, 13.789860177403934, 12.836034651070639, 11.898427591355443, 11.04967660623744, 10.173808968295269, 10.866563383180756, 11.722088534028629, 11.573075687097289, 10.709183340546383, 9.773457433494771, 10.744868634208927, 11.669119763123186, 12.508117600781675, 13.344128257697532, 14.259061003000845, 15.195626213498247, 16.24707585877281, 16.227210042137724, 16.632920118786135, 15.730788429601926, 14.779063606392626, 13.827977753365973, 12.949226486955443, 12.056023410052225, 11.11990291501158, 11.84941441523445, 11.630193520060413, 10.624408329875589, 9.658627326088059, 8.728146787657593, 9.773984453739507, 10.610983568598787, 11.51601779123871, 12.411294228180287, 13.324441139354283, 14.289901773787875, 15.295255710181692, 15.456403964119279, 16.447071547018034, 16.721939429921253, 15.803156703945145, 14.883644382348828, 13.934689162797449, 13.009590750876969, 12.066411697451679, 11.602228206964742, 10.635025737422202, 9.681866569659245, 8.726188100412257, 7.796052451795608, 8.725301648416828, 9.64073372606198, 10.500037320459208, 11.447361910357868, 12.379219590636392, 13.404475110644759, 14.395731422388208, 14.546859163040452, 15.45753131021024, 16.436316324306993, 15.545193820869686, 14.518452632839352, 13.499748999693153, 12.47567821535155, 11.55023082573107, 10.591069734992972, 9.671963687072848, 8.728161292015011, 7.775020611535354, 6.853387812808215, 7.731203455579538, 8.625131823512392, 9.562871228831176, 10.567519753918697, 11.51095049406274, 12.526034369709587, 13.585365113333696, 13.540367118330341, 14.483341069704228, 15.485558179189198, 14.596627046661139, 13.613235960505106, 12.617049703560086, 11.542464667432794, 10.607058459205948, 9.63725676729265, 8.701861255048716, 7.748543662780962, 6.773604628779381, 5.840051588278512, 6.773604433048074, 7.636429828350738, 8.59003160199808, 9.633243058419108, 10.623195029201835, 11.578111946344958, 12.562345290071748, 12.573735693133905, 13.52389744251691, 14.427875206940168, 13.649666059135013, 12.79416467700051, 11.795159110522977, 10.849514484759107, 9.801772052934114, 8.80028708406067, 7.826379133366026, 6.799237204816348, 5.743242970684109, 4.812094972577845, 5.759064358353229, 6.684264801756694, 7.630328011275845, 8.614098107711943, 9.552580575694776, 10.550247689069028, 11.55069707467993, 11.619162598782445, 12.560708185629117, 13.489967875315534, 12.633570662085734, 11.751923306942185, 10.798412361932819, 9.829002236025701, 8.82158307082296, 7.757576032420499, 6.886253808072676, 5.8899595917486955, 4.925632991924952, 3.857691614551517, 4.8938065747534765, 5.804213823022707, 6.657554172076671, 7.615852632951291, 8.600400045185106, 9.623980816589118, 10.62407782724212, 10.611961808623729, 11.624887242945467, 12.554501065665146, 11.70227334788379, 10.724579295072754, 9.768281740949586, 8.820645946655066, 7.786915155830471, 6.7497620975775865, 5.899768145982287, 4.881906632747463, 3.8836150225947064, 2.8827630038832726, 3.8946799750235996, 4.775309163157951, 5.714055632103282, 6.660168609114776, 7.63041519246153, 8.595401259077756, 9.637789335829583, 9.811761453591268, 10.772991203151882, 11.677239764731489, 10.75094427546481, 9.789383611635698, 8.807119099410377, 7.771072309879685, 6.778089601510465, 5.797062634629819, 4.828958514047006, 3.8455391447868705, 2.8359820360164023, 1.8896922799910123, 2.8525174969386535, 3.836511166760754, 4.7765288427434225, 5.809019863369032, 6.874266085528509, 7.877685156514971, 8.820378747444817, 9.009319130120257, 9.967352510660184, 10.750036831420383, 9.788245188648098, 8.851943587627758, 7.865744394886752, 6.812880790717089, 5.768526178769387, 4.8640770302886125, 3.9018237969894587, 2.885656483073376, 1.886381088480372, 0.930690605247674, 1.9496359961096832, 2.9996183773507594, 3.966870930745059, 4.97959296616296, 5.9220823821881305, 6.908429543059385, 7.957676701321104, 8.195082204575879, 9.262784496264487, 9.85348605607561, 8.86247520968325, 7.811497541528115, 6.837391959997715, 5.788818389710551, 4.806197020288859, 3.8387743398899348, 2.894317586235474, 1.9689674660017578, 1.032759595861974, 0.0, 1.0105414924527611, 2.073389211965366, 3.1161159140590646, 4.188568417497848, 5.233893828619021, 6.29524433528578, 7.229384399532096, 9.042511121938944, 10.072013656381158, 10.709795416195231, 9.72600848666406, 8.726250077202616, 7.727293597701791, 6.747599320978338, 5.775508408991505, 4.821087208075232, 3.893343318889158, 2.9066197050135187, 1.9954424074273065, 1.0379135798569785, 2.0417344959838544, 3.055286367746883, 4.107837791185689, 5.1127013965003245, 6.185862197857931, 7.147967476667294, 8.073453253647747, 9.854586784074959, 10.801460069473094, 11.678282976341173, 10.658192585023077, 9.649805648569657, 8.694681606780913, 7.738380418911366, 6.745463993570333, 5.7648978712860135, 4.847427702331961, 3.916269334530076, 3.0150714221725843, 2.0865022047099897, 2.9896625300350426, 3.9960355172014133, 4.990996315724575, 5.975527910541125, 6.940200548297112, 7.901003999240051, 8.900844366571548, 10.814925197327076, 11.795638188426787, 12.59493001675122, 11.658014836767771, 10.5837419136213, 9.74525661564237, 8.690923402830794, 7.766752796390173, 6.780608406414853, 5.8256827911500295, 4.888351212443688, 3.9511652890865374, 3.0813351949194736, 4.047686549207808, 4.988775555253801, 5.926525179476464, 6.917388297277634, 7.918373374181718, 8.960463127856007, 9.850735829438356, 11.842678192001927, 12.81465717920229, 13.577110320958404, 12.584914749140768, 11.551333387023185, 10.654070073021698, 9.69854999083257, 8.735003048784748, 7.7760914996258785, 6.872481864528844, 5.832934361320695, 4.914620912099348, 4.109743534193013, 5.062943346697111, 6.014007163441368, 6.95550397176355, 7.884033032234935, 8.886446640601582, 9.89893748125851, 10.874092577288147], [10.712408568697896, 9.762764055578346, 8.769421720034357, 7.809629566492786, 6.9583840617113095, 5.96250768687736, 5.045734507013812, 5.94443121980859, 6.734094179000707, 7.703239243216634, 8.690805080153885, 9.717280670440037, 10.68122334308043, 11.671216241722533, 12.62781577257711, 13.519173234457057, 14.547116942187154, 13.820404025993792, 12.77185678538192, 11.75222031498815, 11.683884034611761, 10.738799940258502, 9.800228031043199, 8.75002764548073, 7.945962797693466, 7.00846299330846, 5.985627711091749, 6.9208534426464405, 7.711013419428991, 8.695392946131884, 9.649498204140665, 10.57913121354193, 11.617855231514655, 12.599131707879407, 13.554781165389846, 14.561151046727357, 15.52411141787259, 14.558019846411764, 13.571400529371662, 12.624474140815641, 12.701605297874456, 11.739455762047315, 10.776786875491588, 9.778921518633695, 8.955066558981986, 7.996801439807765, 7.009229382579499, 7.970075920219919, 8.686437729588896, 9.628568520676787, 10.624674056892982, 11.516630659471248, 12.574066637699374, 13.122799931445435, 14.001959025973589, 14.61651680322999, 15.40692715101153, 15.527458901554848, 14.563444026838413, 13.56224069162733, 13.71386812651508, 12.675459973817103, 11.691243306998055, 10.741432142625982, 9.908016455046655, 8.950285462276153, 7.9666659591663755, 8.96575075868615, 9.66776745286585, 10.582134871534379, 11.628008882416275, 12.528994363949689, 12.761331179464815, 12.075939722477791, 13.057652864461202, 13.60151398452453, 14.4532609347454, 15.39139055673495, 15.486602603522362, 14.54909476378717, 14.640812786703023, 13.609128587409028, 12.641286013354701, 11.780305314607487, 10.88794171678833, 9.954293788079777, 8.976718632369362, 9.919454545992183, 10.68941190380813, 11.616129209839622, 12.569236360617362, 12.741768409052074, 11.785358559987973, 11.149331384719252, 11.98752398978686, 12.639929749019444, 13.473047513574413, 14.480312656833359, 15.303375645422799, 15.540448304733488, 15.563844088957932, 14.608638087461202, 13.687984342297078, 12.779318684951173, 11.825493158617876, 10.88788609890268, 10.039135113784681, 10.84470318677743, 11.69963057271024, 12.593796534261621, 12.583617179550052, 11.719724832999146, 10.783998925947534, 10.108009865465165, 10.958066112998983, 11.681308320182218, 12.517318977098075, 13.432251722401388, 14.36881693289879, 15.420266578173354, 15.40040076153827, 15.622378626333372, 14.720246937149167, 13.768522113939863, 12.81743626091321, 11.93868499450268, 11.045481917599465, 11.79079713349374, 12.682481604763934, 12.640735012513176, 11.634949822328352, 10.669168818540822, 9.738688280110356, 9.114267030150373, 9.899929918474584, 10.689208510639252, 11.58448494758083, 12.497631858754826, 13.46309249318842, 14.468446429582237, 14.629594683519821, 15.620262266418578, 15.711397937468494, 14.792615211492382, 13.873102889896066, 12.924147670344686, 11.99904925842421, 12.73730591593384, 12.612769699417504, 11.645567229874963, 10.692408062112007, 9.736729592865018, 8.80659394424837, 8.046106800570024, 8.929680075937776, 9.673228039859751, 10.62055262975841, 11.552410310036935, 12.577665830045301, 13.56892214178875, 13.706958131089728, 14.617630278259515, 15.596415292356268, 15.859770208872726, 14.904490723262963, 13.906190733044328, 13.003683513619718, 12.56077231818383, 11.601611227445733, 10.68250517952561, 9.738702784467772, 8.785562103988116, 7.863929305260976, 7.052008607732736, 7.914078173388189, 8.736061948231718, 9.74071047331924, 10.684141213463285, 11.686133337758866, 12.745464081382975, 12.700466086379617, 13.643440037753503, 14.641824584511909, 15.590130823085516, 14.623777452957867, 13.627591196012848, 12.553006159885555, 11.61759995165871, 10.64779825974541, 9.712402747501477, 8.759085155233723, 7.784146121232142, 6.850593080731273, 6.094409585201271, 6.925376178226536, 7.75013057004736, 8.793342026468387, 9.783293997251114, 10.738210914394237, 11.722444258121028, 11.733834661183181, 12.683996410566186, 13.58414161226288, 14.591928058734922, 13.80470616945327, 12.805700602975737, 11.860055977211866, 10.812313545386877, 9.810828576513433, 8.836920625818786, 7.809778697269109, 6.75378446313687, 5.822636465030606, 5.048010708229027, 5.9732111516324915, 6.790426979325124, 7.774197075761222, 8.712679543744056, 9.710346657118308, 10.710796042729209, 10.779261566831721, 11.716974590951828, 12.646234280638245, 13.6059170539334, 12.762464799394946, 11.808953854385578, 10.83954372847846, 9.832124563275723, 8.768117524873261, 7.896795300525437, 6.900501084201457, 5.936174484377713, 4.868233107004278, 4.066334650836782, 4.964312791071984, 5.81765314012595, 6.775951601000569, 7.760499013234384, 8.784079784638395, 9.784176795291398, 9.772060776673007, 10.781153648268178, 11.710767470987857, 12.71281484033655, 11.735120787525515, 10.778823233402347, 9.831187439107826, 8.797456648283232, 7.760303590030348, 6.910309638435049, 5.892448125200224, 4.8941565150474675, 3.8933044963360337, 3.0672080511069053, 3.935408131207229, 4.87415460015256, 5.820267577164055, 6.790514160510809, 7.755500227127034, 8.79788830387886, 8.856900823213527, 9.818130572774141, 10.85529691128854, 11.761485767917572, 10.799925104088459, 9.817660591863138, 8.781613802332446, 7.788631093963226, 6.8076041270825804, 5.839500006499768, 4.856080637239632, 3.8465235284691635, 2.9002337724437735, 2.025045573021959, 2.996610134810032, 3.9366278107927006, 4.96911883141831, 5.949872110118032, 6.92282452613723, 7.865518117067076, 8.054458499742516, 9.012491880282443, 10.008040171514375, 10.798786681100859, 9.86248508008052, 8.876285887339513, 7.82342228316985, 6.7790676712221485, 5.874618522741374, 4.91236528944222, 3.896197975526137, 2.896922580933133, 1.9412320977004351, 0.9947753657319425, 2.0447577469730187, 3.012010300367318, 4.0247323357852185, 4.967221751810389, 5.953568912681644, 7.0028160709433624, 7.18454071212312, 8.252243003811728, 9.234305574442782, 9.873016702136011, 8.822039033980877, 7.8479334524504765, 6.799359882163312, 5.81673851274162, 4.849315832342696, 3.904859078688235, 2.979508958454519, 2.043301088314735, 1.0105414924527611, 0.0, 1.062847719512605, 2.105574421606304, 3.1780269250450877, 4.223352336166261, 5.2847028428330205, 6.2188429070793365, 8.03196962948618, 9.061472163928395, 10.099794099500883, 10.736549979116822, 9.736791569655377, 8.737835090154551, 7.758140813431099, 6.786049901444266, 5.831628700527993, 4.903884811341919, 3.91716119746628, 3.005983899880068, 2.0484550723097397, 1.0311930035310932, 2.0447448752941217, 3.097296298732928, 4.102159904047563, 5.17532070540517, 6.1374259842145324, 7.062911761194985, 8.844045291622198, 9.790918577020333, 10.776950351022256, 11.668734077475838, 10.660347141022418, 9.705223099233674, 8.748921911364128, 7.756005486023094, 6.775439363738775, 5.800060792684807, 4.868902424882921, 3.848138611702069, 2.9195693942394745, 1.9791210375822814, 2.985494024748652, 3.980454823271814, 4.964986418088364, 5.9296590558443505, 6.89046250678729, 7.890302874118786, 9.804383704874315, 10.785096695974026, 11.746272728703307, 12.668556329220532, 11.59428340607406, 10.75426271640855, 9.699929503596973, 8.74490577188586, 7.7587613819105385, 6.775734258417812, 5.8384026797114705, 4.784232478616022, 3.9144023844489584, 3.0371450567550466, 3.978234062801039, 4.915983687023703, 5.906846804824873, 6.907831881728957, 7.949921635403246, 8.840194336985595, 10.832136699549165, 11.80411568674953, 12.778163831990506, 13.59545624159353, 12.561874879475946, 11.663076173787877, 10.707556091598748, 9.713156024280433, 8.754244475121565, 7.744189864761834, 6.704642361553685, 5.7476881016288335, 4.9428107237224985, 4.05240185424435, 5.003465670988607, 5.944962479310789, 6.873491539782174, 7.875905148148821, 8.88839598880575, 9.863551084835386], [9.767308633304438, 8.817664120184888, 7.8243217846409, 6.8645296310993285, 6.029786251020524, 5.033909876186574, 6.0481917791084125, 6.959940407838993, 7.749603367031111, 8.718748431247038, 9.706314268184288, 10.73278985847044, 11.696732531110834, 12.686725429752936, 13.643324960607513, 14.582020953969662, 13.602058819203393, 12.875304090600334, 11.826756849988461, 10.807120379594693, 10.738784099218304, 9.793700004865045, 8.855128095649741, 7.804927710087272, 7.01736498700268, 6.079865182617675, 6.98808498318635, 7.923310714741041, 8.726522607459396, 9.710902134162287, 10.665007392171068, 11.594640401572333, 12.633364419545059, 13.61464089590981, 13.998663911321174, 14.637781385906354, 14.657901404075812, 13.612919911018306, 12.626300593978204, 11.679374205422183, 11.756505362480999, 10.794355826653858, 9.83168694009813, 8.833821583240237, 8.026468748291201, 7.068203629116979, 8.011686654674099, 8.97253319231452, 9.701946917619301, 10.64407770870719, 11.640183244923385, 12.532139847501652, 13.589575825729778, 13.893753528169643, 12.979432954073935, 13.586805761278145, 14.377216109059685, 14.58235896616139, 13.618344091444955, 12.617140756233873, 12.768768191121623, 11.730360038423646, 10.746143371604598, 9.796332207232524, 8.979418644355869, 8.091975055202921, 8.969123231260976, 9.968208030780751, 10.683276640896255, 11.597644059564782, 12.643518070446678, 13.544503551980092, 13.761549623345896, 12.846893319202, 12.035126792561549, 12.571802942572685, 13.423549892793554, 14.361679514783104, 14.541502668128905, 13.603994828393713, 13.695712851309565, 12.66402865201557, 11.696186077961244, 10.83520537921403, 10.0296313097151, 9.095983381006548, 9.979175904463961, 10.921911818086782, 11.704921091838536, 12.631638397870026, 13.584745548647765, 13.741986852933156, 12.785577003869054, 11.92028498144346, 10.964997917887207, 11.610218707067599, 12.443336471622567, 13.450601614881514, 14.273664603470953, 14.59534836934003, 14.618744153564474, 13.663538152067744, 12.74288440690362, 11.834218749557715, 10.967182751544646, 10.02957569182945, 11.04159238587928, 11.847160458872029, 12.715139760740644, 13.609305722292024, 13.583835623431133, 12.719943276880228, 11.784217369828616, 10.878963462189374, 9.93554004109933, 10.651597278230373, 11.48760793514623, 12.402540680449542, 13.339105890946945, 14.390555536221509, 14.370689719586425, 14.677278690939914, 13.775147001755709, 12.823422178546405, 11.95912585383998, 11.08037458742945, 12.047939189694064, 12.793254405588339, 13.69799079279434, 13.640953456394257, 12.635168266209433, 11.669387262421903, 10.738906723991438, 9.885220626874581, 8.87740384657493, 9.659497468687407, 10.554773905628984, 11.46792081680298, 12.433381451236574, 13.438735387630391, 13.599883641567976, 14.590551224466733, 14.766298002075036, 13.847515276098925, 13.014792482822836, 12.065837263271456, 13.001506530518808, 13.739763188028439, 13.612988143298585, 12.645785673756045, 11.69262650599309, 10.736948036746101, 9.806812388129451, 8.839259017315605, 7.907154004038124, 8.643516997907906, 9.590841587806565, 10.52269926808509, 11.547954788093456, 12.539211099836905, 12.677247089137882, 13.58791923630767, 14.566704250404422, 14.914670273479269, 14.046180316189734, 13.047880325971098, 14.006140785714317, 13.560990762064911, 12.601829671326815, 11.682723623406691, 10.738921228348854, 9.7857805478692, 8.86414774914206, 7.845160824478316, 6.8915521014885375, 7.706350906279874, 8.710999431367394, 9.65443017151144, 10.65642229580702, 11.71575303943113, 11.670755044427771, 12.613728995801658, 13.610136401127326, 14.558442639700933, 15.055862683262374, 14.059676426317354, 13.553224603766637, 12.617818395539791, 11.648016703626492, 10.712621191382558, 9.759303599114805, 8.784364565113226, 7.8508115246123555, 6.922284400108548, 5.902850106326884, 6.720419528095515, 7.763630984516541, 8.753582955299269, 9.708499872442392, 10.692733216169184, 10.704123619231336, 11.65428536861434, 12.552453428878296, 13.560239875350339, 14.502138355123574, 13.83108343371569, 12.88543880795182, 11.835934100522248, 10.81396749314651, 9.83713906969987, 8.809997141150191, 7.754002907017952, 6.8228549089116886, 5.875885523136304, 4.95068507973284, 5.760715937373279, 6.744486033809377, 7.682968501792211, 8.680635615166464, 9.681085000777365, 9.749550524879876, 10.685286407567245, 11.614546097253662, 12.574228870548817, 13.507501131497232, 12.840291902205408, 11.870881776298292, 10.855745118411095, 9.791738080008633, 8.911391176661564, 7.915096960337583, 6.95077036051384, 5.881717314188433, 4.898448551881415, 3.934601749120139, 4.7879420981741045, 5.746240559048724, 6.730787971282538, 7.75436874268655, 8.754465753339552, 8.742349734721161, 9.749465464883595, 10.679079287603274, 11.731663859758337, 12.689875349275551, 11.83617934061667, 10.862525486927657, 9.821077203418605, 8.78392414516572, 7.924905514571174, 6.9070440013363505, 5.908752391183594, 4.9067887035201885, 3.8993219521515385, 2.905697089255384, 3.8444435582007146, 4.790556535212209, 5.760803118558964, 6.725789185175189, 7.768177261927015, 7.825212639828944, 8.786442389389558, 9.823608727903958, 10.765348189343594, 11.754679665838495, 10.880508311375744, 9.844461521845052, 8.85147881347583, 7.831224682217954, 6.854095882635893, 5.8706765133757575, 4.861119404605289, 3.9137179796279282, 2.950892762680287, 1.9668990928581869, 2.9069167688408553, 3.9394077894664647, 4.918183926733448, 5.891136342752647, 6.833829933682493, 7.022770316357933, 7.980803696897859, 8.97635198812979, 9.938143630902076, 10.925332799593125, 9.939133606852119, 8.886270002682455, 7.841915390734754, 6.937466242253979, 5.975213008954825, 4.959045695038742, 3.959770300445738, 3.00407981721304, 2.0576230852445474, 1.0150467050211736, 1.9803221169827345, 2.9930441524006346, 3.9355335684258055, 4.92188072929706, 5.9711278875587785, 6.121692992610514, 7.189395284299122, 8.171457854930177, 9.162468701322537, 9.884886753493483, 8.910781171963082, 7.862207601675918, 6.879586232254225, 5.9121635518553015, 4.96770679820084, 4.042356677967124, 3.10614880782734, 2.073389211965366, 1.062847719512605, 0.0, 1.042726702093699, 2.1151792055324825, 3.1605046166536557, 4.221855123320415, 5.155995187566731, 6.969121909973576, 7.998624444415789, 9.03694637998828, 10.02073330951945, 10.799639289167983, 9.800682809667157, 8.820988532943705, 7.848897620956872, 6.894476420040599, 5.966732530854524, 4.9800089169788855, 4.037449242430362, 3.0799204148600334, 2.0467021915614967, 1.0331503197984682, 2.0344485792203235, 3.0393121845349587, 4.112472985892564, 5.074578264701927, 6.000064041682379, 7.878563789378011, 8.825437074776145, 9.811468848778068, 10.831559240096164, 11.723194860535024, 10.76807081874628, 9.811769630876734, 8.8188532055357, 7.803612790498358, 6.81556998071521, 5.884411612913325, 4.8636477997324725, 3.935078582269878, 2.994630225612685, 2.056896214057866, 3.0518570125810283, 3.999504915844177, 4.964177553600164, 5.9249810045431035, 6.9248213718746, 8.838902202630129, 9.819615193729838, 10.780791226459119, 11.71770640644257, 12.657131125586666, 11.769771904438953, 10.715438691627376, 9.760414959916263, 8.774270569940942, 7.791243446448216, 6.853911867741874, 5.799741666646425, 4.929911572479362, 4.05265424478545, 3.049636252110253, 3.987385876332917, 4.961746869431416, 5.942350379484771, 6.98444013315906, 7.874712834741409, 9.86665519730498, 10.838634184505342, 11.812682329746318, 12.650398118609768, 13.624722598988551, 12.67858536181828, 11.723065279629152, 10.728665212310837, 9.769753663151969, 8.759699052792238, 7.720151549584089, 6.763197289659237, 5.958319911752902, 5.059889534347961, 4.074867860297822, 5.016364668620003, 5.928391604388717, 6.930805212755365, 7.943296053412293, 8.8980695825912], [8.724581931210741, 7.7749374180911905, 6.781595082547201, 5.82180292900563, 5.018829635285923, 5.9982260320726235, 7.012507934994462, 7.9750835814425605, 8.764746540634677, 9.733891604850605, 10.721457441787855, 11.747933032074007, 12.711875704714402, 13.701868603356504, 14.568868878776955, 13.597833051520293, 12.559332117109694, 11.832577388506637, 10.784030147894764, 9.764393677500996, 9.696057397124605, 8.750973302771346, 7.812401393556043, 6.762201007993573, 6.006408371268079, 6.983621584218881, 7.952401139072399, 8.887626870627091, 9.741665781062961, 10.726045307765855, 11.680150565774635, 12.6097835751759, 13.648507593148626, 14.629784069513377, 14.611974803412963, 13.649041132870215, 13.615174701982113, 12.570193208924607, 11.583573891884505, 10.636647503328485, 10.7137786603873, 9.751629124560159, 8.788960238004432, 7.791094881146538, 7.0155121325566, 7.9719600307181855, 8.976002810560148, 9.93684934820057, 10.717090091222866, 11.659220882310757, 12.655326418526952, 13.547283021105219, 14.604718999333345, 14.565743736032491, 13.592743846165725, 12.598065508242005, 13.388475856023547, 13.539632264067691, 12.575617389351256, 11.574414054140174, 11.726041489027924, 10.687633336329947, 9.703416669510899, 8.753605505138825, 7.968462028621268, 8.995731456804126, 9.933439387147025, 10.9325241866668, 11.69841981449982, 12.61278723316835, 13.658661244050245, 14.55964672558366, 14.517423172550806, 13.536609575331996, 12.648437684653338, 11.583062689536545, 12.434809639757415, 13.372939261746964, 13.498775966035206, 12.561268126300014, 12.652986149215867, 11.621301949921872, 10.653459375867545, 9.79247867712033, 9.028094731235733, 9.961742659944285, 10.94349206035001, 11.886227973972831, 12.720064265442101, 13.646781571473593, 14.599888722251332, 14.534418607451629, 13.541450553073965, 12.610001237573456, 11.578308809978996, 10.62147845403146, 11.454596218586428, 12.461861361845374, 13.284924350434814, 13.552621667246331, 13.576017451470776, 12.620811449974045, 11.700157704809921, 10.791492047464017, 10.099196615022587, 10.895334970767188, 11.935594797616146, 12.811476614758078, 13.73028293434421, 14.624448895895592, 14.38596417274404, 13.522071826193136, 12.540090919033526, 11.56867971831937, 10.625256297229326, 9.662857025194233, 10.49886768211009, 11.413800427413403, 12.350365637910805, 13.401815283185368, 13.381949466550283, 13.634551988846216, 12.73242029966201, 11.780695476452706, 11.09113971731792, 11.946133866367187, 12.94194160143093, 13.757570561474388, 14.713133966397905, 14.443082005707165, 13.437296815522341, 12.471515811734811, 11.541035273304345, 10.574936883004577, 9.567120102704926, 8.670757215651268, 9.566033652592845, 10.47918056376684, 11.444641198200433, 12.44999513459425, 12.567368518896773, 13.55803610179553, 13.723571299981337, 12.804788574005226, 12.146806346300776, 12.931596542209194, 13.895508942255674, 14.704079343914488, 14.415116692611491, 13.44791422306895, 12.494755055305996, 11.539076586059007, 10.608940937442359, 9.581145334560254, 8.596870260168119, 7.654776744871766, 8.602101334770426, 9.53395901504895, 10.559214535057317, 11.550470846800765, 11.638768462792616, 12.549440609962403, 13.528225624059155, 13.87194357138557, 13.178194179667674, 13.913639604908836, 14.900143197451182, 14.363119311377819, 13.403958220639721, 12.484852172719597, 11.54104977766176, 10.587909097182106, 9.666276298454965, 8.608958781552298, 7.655350058562519, 6.717610653243734, 7.722259178331256, 8.6656899184753, 9.667682042770881, 10.725561718556353, 10.632276418082505, 11.575250369456391, 12.567409699033627, 13.515715937607235, 14.228864459269253, 14.925435705255092, 14.355353153079543, 13.419946944852697, 12.450145252939398, 11.514749740695464, 10.561432148427711, 9.586493114426132, 8.652940073925262, 7.7244129494214535, 6.704978655639789, 5.731679275059375, 6.774890731480402, 7.764842702263129, 8.719759619406252, 9.66009755396636, 9.665644992886069, 10.61205509229004, 11.509726726784598, 12.51751317325664, 13.459411653029875, 14.524106246201487, 13.702520324723356, 12.653015617293784, 11.616096042459416, 10.639267619012776, 9.612125690463097, 8.556131456330858, 7.624983458224594, 6.678014072449209, 5.752813629045745, 4.771975684337139, 5.755745780773237, 6.694228248756072, 7.6918953621303245, 8.64844933857454, 8.711071898534609, 9.642559705473547, 10.571819395159963, 11.531502168455118, 12.464774429403533, 13.452328333130737, 12.760683039560453, 11.745546381673256, 10.681539343270794, 9.801192439923724, 8.804898223599745, 7.840571623776001, 6.771518577450594, 5.788249815143576, 4.778429459824424, 3.799201845137966, 4.757500306012585, 5.7420477182464, 6.765628489650411, 7.715987126994285, 7.7038711083758935, 8.706738762789897, 9.636352585509576, 10.688937157664638, 11.64714864718185, 12.641884641458072, 11.752326750189818, 10.710878466680766, 9.673725408427881, 8.814706777833337, 7.796845264598512, 6.798553654445755, 5.79658996678235, 4.789123215413699, 3.795498352517545, 2.8557033051645764, 3.801816282176071, 4.772062865522826, 5.737048932139051, 6.729698635581747, 6.782485937735244, 7.743715687295858, 8.780882025810257, 9.722621487249894, 10.711952963744794, 11.77636227910622, 10.784425597619315, 9.791442889250094, 8.721025945480115, 7.743897145898055, 6.760477776637919, 5.750920667867451, 4.80351924289009, 3.8406940259424487, 2.8567003561203483, 1.918176515804717, 2.930003697388587, 3.8754572246397494, 4.848409640658947, 5.791103231588793, 5.9800436142642335, 6.93807699480416, 7.933625286036091, 8.895416928808375, 9.955209330965785, 10.961135402271827, 9.928996704776155, 8.884642092828454, 7.949133997853794, 6.985604552045883, 5.928741618212122, 4.9294662236191185, 3.9737757403864205, 2.9548303495244115, 1.904847968283335, 0.9375954148890355, 1.9503174503069358, 2.8928068663321067, 3.8791540272033607, 4.928401185465079, 5.078966290516815, 6.1466685822054234, 7.128731152836479, 8.11974199922884, 9.170719667383974, 9.95350787405678, 8.904934303769616, 7.922312934347924, 6.954890253949, 6.010433500294539, 5.085083380060823, 4.148875509921039, 3.116115914059065, 2.105574421606304, 1.042726702093699, 0.0, 1.0724525034387835, 2.117777914559957, 3.179128421226716, 4.113268485473032, 5.926395207879877, 6.95589774232209, 7.99421967789458, 8.97800660742575, 9.977765016887194, 10.843409511760855, 9.863715235037404, 8.891624323050571, 7.937203122134298, 7.009459232948223, 6.022735619072584, 5.052592416033928, 4.0950635884636, 3.0618453651650634, 2.048293493402035, 0.9917218771266245, 1.9965854824412597, 3.0697462837988656, 4.031851562608228, 4.957337339588681, 6.835837087284312, 7.782710372682447, 8.768742146684371, 9.788832538002467, 10.855567356217506, 11.81069139800625, 10.854496332970433, 9.84441379664291, 8.818755964101925, 7.830713154318778, 6.899554786516892, 5.87879097333604, 4.950221755873446, 4.009773399216252, 3.0358611953695895, 2.0409003968464274, 2.9567782137504777, 3.9214508515064646, 4.882254302449404, 5.882094669780901, 7.79617550053643, 8.776888491636141, 9.738064524365422, 10.674979704348871, 11.749252627495343, 12.78491507804252, 11.730581865230944, 10.77555813351983, 9.78941374354451, 8.806386620051782, 7.869055041345441, 6.814884840249992, 5.9450547460829295, 5.067797418389017, 4.013952407996303, 2.9764292605983163, 3.919020167337717, 4.899623677391071, 5.941713431065359, 6.83198613264771, 8.82392849521128, 9.795907482411645, 10.769955627652621, 11.60767141651607, 12.641252778633653, 13.66788890256089, 12.738208453232719, 11.743808385914406, 10.784896836755536, 9.774842226395805, 8.735294723187657, 7.778340463262804, 6.973463085356469, 6.02420569023401, 5.039184016183871, 4.005408052885402, 4.885664902295018, 5.888078510661664, 6.900569351318593, 7.855342880497501], [7.691020338608492, 6.741375825488942, 5.748033489944953, 4.788241336403381, 5.841708040017355, 6.846406355106206, 7.860688258028044, 8.87439218388062, 9.664055143072735, 10.633200207288663, 11.620766044225913, 12.647241634512065, 13.61118430715246, 14.491906817029285, 13.535307286174708, 12.564271458918046, 11.525770524507447, 10.799015795904388, 9.750468555292516, 8.730832084898747, 8.662495804522358, 7.717411710169098, 6.7788398009537945, 5.728639415391324, 6.663792820116624, 7.641006033067426, 8.7020319217155, 9.637257653270192, 10.624004659902653, 11.625353910203913, 12.579459168212693, 13.509092177613958, 14.547816195586684, 15.44384409749889, 14.462272678987445, 13.544573480525099, 12.581613109379866, 11.53663161632236, 10.550012299282258, 9.603085910726238, 9.680217067785053, 8.71806753195791, 7.755398645402182, 6.757533288544289, 7.672896581405145, 8.629344479566731, 9.678558193084747, 10.68648013084367, 11.599428970062558, 12.552257916620626, 13.55463502096501, 14.446591623543277, 15.504027601771403, 15.625335735240634, 14.652335845373868, 13.657657507450148, 12.883486754084664, 12.506070671465444, 11.54205579674901, 10.540852461537927, 10.692479896425676, 9.654071743727698, 8.66985507690865, 7.7200439125365765, 8.625846477469814, 9.653115905652673, 10.635994769671623, 11.635079569191397, 12.580758693339511, 13.505824267478218, 14.551698278360114, 15.458955328021718, 15.57701517175895, 14.596201574540139, 13.708029683861481, 12.642654688744688, 11.929820537818532, 12.821979665459242, 12.465214373432959, 11.527706533697767, 11.61942455661362, 10.587740357319623, 9.619897783265296, 8.758917084518082, 9.685479180084279, 10.619127108792831, 11.608178754067852, 12.550914667690673, 13.533346153589951, 14.539818605783461, 15.4929257565612, 15.594010606659772, 14.601042552282108, 13.6695932367816, 12.637900809187139, 11.681070453239602, 10.949607116647545, 11.86051444470879, 12.683577433298229, 12.519060074644084, 12.542455858868527, 11.587249857371797, 10.666596112207671, 9.757930454861768, 10.756581063871133, 11.552719419615734, 12.592979246464692, 13.47616330847592, 14.449076168911475, 15.43472802253148, 15.445556171952182, 14.581663825401277, 13.599682918241669, 12.628271717527513, 11.684848296437469, 10.722449024402376, 9.993878580171208, 10.812453510276818, 11.74901872077422, 12.756540961752158, 12.607614270659719, 12.600990396243967, 11.69885870705976, 10.74713388385046, 11.723406135704533, 12.603518315215734, 13.599326050279476, 14.42225725519223, 15.380413319566918, 15.502674004915306, 14.496888814730482, 13.531107810942952, 12.600627272512487, 11.63452888221272, 10.62671210191307, 9.73034921485941, 9.061044550653962, 9.877833646630256, 10.843294281063848, 11.767498673833783, 11.640407957361576, 12.631075540260333, 12.690009707379087, 11.771226981402979, 12.779072764687388, 13.58898099105774, 14.55289339110422, 15.36876603763233, 15.474708691819634, 14.507506222277094, 13.554347054514139, 12.59866858526715, 11.6685329366505, 10.640737333768397, 9.656462259376262, 8.71436874407991, 8.097112232831543, 8.932612097912365, 9.922904308190644, 10.759153369101854, 10.71180790125742, 11.622480048427207, 12.601265062523959, 12.838381978783323, 13.810460598054286, 14.571024053757382, 15.557527646299729, 15.42271131058596, 14.463550219847864, 13.54444417192774, 12.600641776869903, 11.647501096390249, 10.725868297663109, 9.668550780760441, 8.714942057770662, 7.777202652451877, 7.094496183236236, 7.930388046117034, 8.881533144961544, 9.798601157021157, 9.705315856547308, 10.648289807921195, 11.64044913749843, 12.588755376072038, 13.476412086988077, 14.472598343933097, 15.414945152287686, 14.47953894406084, 13.509737252147541, 12.574341739903607, 11.621024147635854, 10.646085113634275, 9.712532073133405, 8.784004948629597, 7.764570654847932, 6.791271274267518, 6.038293478355615, 6.978693804453794, 7.933610721596916, 8.733136992431163, 8.738684431350872, 9.685094530754844, 10.582766165249401, 11.590552611721444, 12.532451091494679, 13.597145684666291, 14.515290146236064, 13.712607616501927, 12.67568804166756, 11.698859618220919, 10.67171768967124, 9.615723455539001, 8.684575457432738, 7.7376060716573525, 6.812405628253888, 5.831567683545282, 5.019148527648451, 5.9080793509467355, 6.9057464643209885, 7.721488777039344, 7.784111336999413, 8.71559914393835, 9.644858833624767, 10.604541606919922, 11.537813867868337, 12.52536777159554, 13.494777897502658, 12.817998885112038, 11.753991846709576, 10.873644943362509, 9.877350727038529, 8.913024127214785, 7.843971080889378, 6.858749253218986, 5.838021459032567, 4.858793844346109, 4.020903052887799, 4.9072711542636815, 5.930851925667693, 6.789026565459088, 6.776910546840697, 7.7797782012547, 8.70939202397438, 9.761976596129442, 10.720188085646654, 11.714924079922875, 12.688577933611889, 11.783330970119549, 10.746177911866663, 9.887159281272119, 8.869297768037296, 7.871006157884539, 6.8690424702211335, 5.8615757188524835, 4.867950855956329, 3.9152953043727194, 2.969182327361225, 3.9369467759724244, 4.901932842588649, 5.802738074046551, 5.855525376200048, 6.816755125760662, 7.853921464275061, 8.795660925714698, 9.784992402209598, 10.849401717571023, 11.856878101058097, 10.863895392688876, 9.793478448918897, 8.816349649336837, 7.8329302800767024, 6.823373171306234, 5.875971746328873, 4.913146529381232, 3.929152859559132, 2.9906290192435008, 2.0030431358533907, 2.948496663104553, 3.921449079123751, 4.864142670053597, 5.0318622743358405, 5.989895654875767, 6.985443946107698, 7.947235588879983, 9.007027991037392, 10.012954062343434, 11.001449208214938, 9.957094596267236, 9.021586501292576, 8.058057055484666, 7.001194121650905, 6.001918727057902, 5.046228243825204, 4.027282852963195, 2.9773004717221188, 2.0100479183278193, 1.0233568887717392, 1.9658463047969104, 2.9521934656681643, 4.0014406239298825, 4.006513787078032, 5.07421607876664, 6.0562786493976954, 7.047289495790055, 8.09826716394519, 9.07237274547559, 9.9773868072084, 8.994765437786707, 8.027342757387784, 7.082886003733323, 6.157535883499607, 5.221328013359823, 4.188568417497849, 3.1780269250450877, 2.1151792055324825, 1.0724525034387835, 0.0, 1.0453254111211732, 2.106675917787933, 3.040815982034249, 4.8928336152776275, 5.922336149719841, 6.96065808529233, 7.944445014823501, 8.944203424284945, 9.943159903785771, 10.922854180509223, 9.964076826489354, 9.00965562557308, 8.081911736387006, 7.0937257503476285, 6.028758034060949, 5.071229206490621, 4.038010983192084, 3.0244591114290555, 1.9678874951536454, 0.9630238898390101, 2.0361846911966164, 2.9982899700059784, 3.9237757469864314, 5.802275494682063, 6.749148780080199, 7.735180554082122, 8.755270945400218, 9.822005763615257, 10.777129805404002, 11.733430993273547, 10.743722399080967, 9.718064566539983, 8.730021756756836, 7.798863388954951, 6.778099575774099, 5.849530358311505, 4.909082001654311, 3.9027090144879404, 2.9077482159647783, 1.9232166211482284, 2.8878892589042158, 3.848692709847155, 4.848533077178653, 6.762613907934181, 7.7433268990338915, 8.704502931763173, 9.641418111746624, 10.715691034893096, 11.78846477592642, 12.629890467669004, 11.67486673595789, 10.688722345982569, 9.705695222489842, 8.7683636437835, 7.714193442688051, 6.8443633485209885, 5.942739463719289, 4.880800227114654, 3.843277079716667, 2.885458574735468, 3.8660620847888225, 4.908151838463111, 5.7984245400454615, 7.790366902609032, 8.762345889809394, 9.736394035050372, 10.574109823913822, 11.607691186031406, 12.634327309958643, 13.589847392147771, 12.643116988352464, 11.684205439193596, 10.674150828833863, 9.634603325625715, 8.677649065700862, 7.872771687794528, 6.8910535093523615, 5.9060318353022225, 4.845123825240533, 3.852103309692769, 4.854516918059415, 5.867007758716344, 6.821781287895252], [6.918585054629754, 5.968940541510204, 4.9958309058224675, 5.828517454291447, 6.881984157905421, 7.886682472994272, 8.900964375916109, 9.914668301768685, 10.704331260960801, 11.673476325176729, 12.66104216211398, 13.687517752400131, 14.503971785104374, 13.513978886462272, 12.557379355607695, 11.586343528351033, 10.547842593940434, 9.823593563251734, 8.837806285436738, 7.818169815042969, 7.890060520543619, 6.94497642619036, 6.026637216831309, 6.76891553327939, 7.70406893800469, 8.681282150955493, 9.742308039603566, 10.677533771158258, 11.664280777790719, 12.665630028091979, 13.61973528610076, 14.549368295502024, 15.447192643296628, 14.465916166931876, 13.484344748420432, 12.582916563751635, 11.619956192606402, 10.680409824431973, 9.693790507391872, 8.746864118835852, 8.907781783806314, 7.945632247979173, 7.061468679523239, 7.797809406432355, 8.713172699293212, 9.669620597454799, 10.718834310972815, 11.726756248731736, 12.639705087950624, 13.592534034508692, 14.594911138853076, 15.486867741431343, 16.425159591607144, 15.476575595534436, 14.50357570566767, 13.633892188379845, 12.601901610216146, 11.649848879575059, 10.685834004858624, 9.684630669647541, 9.940775630428732, 8.90704132281832, 8.110593841987559, 8.760320030424642, 9.66612259535788, 10.69339202354074, 11.676270887559692, 12.675355687079467, 13.621034811227577, 14.546100385366284, 15.59197439624818, 16.499231445909786, 16.56754290829293, 15.586729311074116, 14.698557420395458, 13.633182425278665, 12.802726987661512, 11.927528569942876, 11.608992581542573, 10.671484741807381, 10.885798930694236, 9.945216255077407, 9.060636548344204, 9.799193202406148, 10.725755297972345, 11.659403226680897, 12.648454871955918, 13.591190785578739, 14.573622271478017, 15.580094723671527, 16.533201874449265, 16.58453834319375, 15.591570288816085, 14.660120973315577, 13.628428545721116, 12.67159818977358, 11.822513566490525, 10.966063349192423, 11.789126337781862, 11.662838282753698, 11.832841471294726, 10.94472575512958, 10.10733487728658, 10.798206572749834, 11.796857181759199, 12.5929955375038, 13.633255364352758, 14.516439426363986, 15.48935228679954, 16.475004140419546, 16.436083908486157, 15.572191561935254, 14.590210654775646, 13.61879945406149, 12.675376032971446, 11.712976760936353, 10.866785030014187, 9.918002414760451, 10.854567625257854, 11.818453316763412, 11.669526625670974, 11.95846629400175, 11.139597472138668, 11.787410001738525, 12.763682253592599, 13.6437944331038, 14.639602168167542, 15.462533373080296, 16.420689437454985, 16.493201741449283, 15.48741655126446, 14.52163554747693, 13.591155009046464, 12.625056618746697, 11.617239838447047, 10.720876951393388, 9.933951000496942, 8.98338255111389, 9.948843185547481, 10.829411028845037, 10.702320312372832, 11.692987895271589, 12.130748472457995, 12.811503099291045, 13.819348882575454, 14.629257108945806, 15.593169508992286, 16.409042155520396, 16.46523642835361, 15.49803395881107, 14.544874791048114, 13.589196321801126, 12.659060673184477, 11.631265070302375, 10.64698999591024, 9.704896480613886, 8.970018682674523, 8.038161002395999, 9.028453212674277, 9.821065724113108, 9.773720256268675, 10.68439240343846, 11.663177417535213, 12.619867738578016, 13.588994721600908, 14.546306799290605, 15.44823325288031, 16.393598279713522, 15.45407795638184, 14.534971908461715, 13.591169513403878, 12.638028832924224, 11.716396034197084, 10.659078517294416, 9.705469794304637, 8.767730388985854, 7.979367690744712, 7.035936950600668, 7.987082049445178, 8.86051351203241, 8.767228211558562, 9.710202162932449, 10.702361492509683, 11.65066773108329, 12.538324441999329, 13.534510698944349, 14.515019704961555, 15.4504259131884, 14.500264988681517, 13.564869476437583, 12.61155188416983, 11.63661285016825, 10.70305980966738, 9.774532685163573, 8.755098391381908, 7.781799010801493, 6.971255674120368, 6.084242708937428, 7.03915962608055, 7.795049347442417, 7.800596786362126, 8.747006885766094, 9.644678520260653, 10.652464966732696, 11.59436344650593, 12.659058039677543, 13.577202501247315, 14.594292126743346, 13.666215778201535, 12.689387354754894, 11.662245426205216, 10.606251192072977, 9.675103193966713, 8.728133808191329, 7.802933364787863, 6.822095420079258, 5.952110723413203, 5.013628255430369, 6.011295368804622, 6.783401132050598, 6.846023692010666, 7.777511498949601, 8.706771188636019, 9.666453961931174, 10.599726222879589, 11.587280126606792, 12.55669025251391, 13.614103144632193, 12.77055058910537, 11.890203685758303, 10.893909469434323, 9.929582869610579, 8.860529823285173, 7.849276989752961, 6.828549195566542, 5.849321580880084, 4.997367470981129, 4.012820058747315, 5.036400830151327, 5.850938920470342, 5.838822901851951, 6.841690556265952, 7.771304378985631, 8.78198431295605, 9.733588089669224, 10.728324083945445, 11.701977937634458, 12.74342622114351, 11.762736654262458, 10.903718023667913, 9.88585651043309, 8.887564900280333, 7.885601212616929, 6.878134461248279, 5.884509598352125, 4.905823040906695, 3.9597100638952, 3.042495680456058, 3.991062214588628, 4.8646504290578045, 4.917437731211301, 5.878667480771915, 6.8673214682976305, 7.809060929737267, 8.798392406232168, 9.862801721593591, 10.898848511124283, 11.88045413508467, 10.810037191314692, 9.832908391732632, 8.849489022472497, 7.83993191370203, 6.892530488724669, 5.929705271777028, 4.945711601954928, 4.007187761639297, 2.993570872387366, 2.0540455675881866, 2.9833614341350043, 3.92605502506485, 3.986536863214668, 4.944570243754594, 5.940118534986525, 6.90191017775881, 7.96170257991622, 8.967628651222261, 10.020492255391925, 11.002420007388409, 10.038145243688374, 9.074615797880464, 8.017752864046702, 7.018477469453698, 6.062786986221, 5.043841595358991, 3.9938592141179146, 3.026606660723615, 2.0138846253057148, 1.0713952092805439, 2.0141058206794176, 3.04475560147481, 2.9611883759568594, 4.028890667645467, 5.010953238276523, 6.001964084668883, 7.052941752824017, 8.027047334354418, 9.075620904641582, 10.04009084890788, 9.072668168508956, 8.128211414854496, 7.20286129462078, 6.266653424480996, 5.2338938286190215, 4.22335233616626, 3.1605046166536557, 2.117777914559957, 1.0453254111211732, 0.0, 1.0613505066667595, 1.9954905709130757, 3.8754526239370817, 4.904955158379295, 5.943277093951784, 6.927064023482955, 7.926822432944398, 8.925778912445224, 9.905473189168676, 10.887487136603593, 10.054981036694253, 9.127237147508179, 8.139051161468803, 7.074083445182122, 6.116554617611794, 5.083336394313258, 4.069784522550229, 3.0132129062748185, 2.0083493009601834, 1.0188036998560699, 1.9809089786654321, 2.906394755645885, 4.824347564115052, 5.771220849513187, 6.757252623515111, 7.777343014833207, 8.844077833048246, 9.79920187483699, 10.755503062706536, 11.77197831011153, 10.758340684428049, 9.770297874644902, 8.839139506843017, 7.818375693662165, 6.8898064761995705, 5.949358119542377, 4.942985132376006, 3.9480243338528442, 2.963492739036295, 1.9988201012803075, 2.9465941914016134, 3.8706051466116413, 5.78468597736717, 6.76539896846688, 7.726575001196162, 8.663490181179611, 9.737763104326083, 10.810536845359406, 11.708046046625963, 12.663069778337077, 11.728998463870635, 10.745971340377908, 9.808639761671566, 8.754469560576117, 7.884639466409054, 6.983015581607355, 5.92107634500272, 4.8835531976047335, 3.9257346926235344, 2.976992927164914, 4.013477748849406, 4.82049660947845, 6.81243897204202, 7.784417959242384, 8.758466104483361, 9.59618189334681, 10.629763255464393, 11.65639937939163, 12.611919461580758, 13.643175888360695, 12.724481557081662, 11.714426946721929, 10.674879443513781, 9.717925183588928, 8.913047805682595, 7.9313296272404274, 6.9463079531902885, 5.885399943128599, 4.892379427580835, 4.01027078199642, 5.0227616226533485, 5.843853357328241], [5.877911820155942, 5.0622339737616215, 5.9378089383966195, 6.770495486865597, 7.8239621904795715, 8.828660505568422, 9.84294240849026, 10.856646334342837, 11.646309293534953, 12.615454357750881, 13.603020194688131, 14.427220996111984, 13.46327832347159, 12.473285424829488, 11.51668589397491, 10.545650066718249, 9.50714913230765, 8.78290010161895, 7.797112823803953, 6.777476353410185, 6.8503114681533805, 6.038269858441778, 6.968615249405461, 7.7108935658535405, 8.64604697057884, 9.623260183529643, 10.684286072177716, 11.619511803732408, 12.606258810364869, 13.60760806066613, 14.561713318674911, 15.369503891738038, 14.406499181663843, 13.425222705299092, 12.443651286787647, 11.54222310211885, 10.579262730973618, 9.639716362799188, 8.653097045759088, 7.706170657203068, 7.868032731416076, 7.038925680230591, 8.003446712097391, 8.739787439006506, 9.655150731867362, 10.611598630028949, 11.660812343546965, 12.668734281305886, 13.581683120524774, 14.534512067082842, 15.536889171427228, 16.307003337667357, 15.38446612997436, 14.435882133901652, 13.462882244034885, 12.59319872674706, 11.561208148583361, 10.609155417942274, 9.645140543225839, 8.643937208014759, 8.901026578038493, 8.000334755069737, 8.984551421888785, 9.702298062998793, 10.60810062793203, 11.63537005611489, 12.61824892013384, 13.617333719653615, 14.563012843801728, 15.488078417940434, 16.53395242882233, 17.315001978290656, 16.351370929627265, 15.455302526517398, 14.407188405547272, 13.573456540044466, 12.503965071114672, 11.565835449125123, 10.56829911990979, 9.630791280174599, 9.846049878303997, 9.038509687328824, 9.93459412824543, 10.741171234980298, 11.667733330546493, 12.601381259255046, 13.590432904530067, 14.533168818152888, 15.515600304052166, 16.522072756245677, 17.475179907023417, 17.452245608797117, 16.45927755441945, 15.527828238918943, 14.496135811324482, 13.539305455376946, 12.67471566057256, 11.818265443274457, 10.880862743314973, 10.622144821120916, 10.793092418904488, 10.038019187380998, 10.981292457187806, 11.740184605323984, 12.738835214333347, 13.534973570077948, 14.575233396926906, 15.458417458938134, 16.43133031937369, 17.416982172993695, 17.303791174089525, 16.439898827538624, 15.457917920379012, 14.486506719664856, 13.543083298574812, 12.58068402653972, 11.718987124096222, 10.770204508842486, 9.946304030790964, 10.75710281009665, 10.608176119004215, 11.051759726253168, 12.013555052039894, 12.729388034312674, 13.705660286166747, 14.585772465677948, 15.58158020074169, 16.404511405654446, 17.362667470029134, 17.36090900705265, 16.355123816867827, 15.389342813080297, 14.458862274649832, 13.492763884350063, 12.484947104050413, 11.588584216996754, 10.786153094578976, 9.835584645195924, 8.982185715081801, 9.768060522178276, 9.640969805706073, 10.63163738860483, 11.5547812979854, 12.566460815110885, 13.559032048301047, 14.466999355323487, 15.39151700140906, 16.383074447882997, 17.332943693956977, 16.365741224414435, 15.412582056651482, 14.456903587404494, 13.526767938787845, 12.49897233590574, 11.514697261513605, 10.572603746217252, 9.822220776756557, 8.890363096478033, 8.042466550036027, 8.759715217446347, 8.712369749601915, 9.623041896771701, 10.601826910868454, 11.558517231911257, 12.52764421493415, 13.484956292623846, 14.386882746213551, 15.332247773046763, 16.312690066135264, 15.402679174065083, 14.458876779007246, 13.505736098527592, 12.584103299800452, 11.526785782897782, 10.573177059908003, 9.63543765458922, 8.831569784826748, 7.888139044682704, 7.001095386806927, 7.799163005365649, 7.705877704891803, 8.64885165626569, 9.641010985842923, 10.589317224416531, 11.47697393533257, 12.47316019227759, 13.453669198294795, 14.389075406521641, 15.35887709843494, 14.43257674204095, 13.479259149773197, 12.504320115771618, 11.570767075270748, 10.64223995076694, 9.622805656985276, 8.64950627640486, 7.823457768202404, 6.936444803019464, 6.053172963442299, 6.733698840775656, 6.739246279695366, 7.685656379099336, 8.583328013593894, 9.591114460065937, 10.533012939839171, 11.597707533010784, 12.515851994580556, 13.532941620076587, 14.533923043804903, 13.557094620358262, 12.529952691808584, 11.473958457676344, 10.542810459570081, 9.595841073794697, 8.670640630391231, 7.689802685682626, 6.80431281749524, 5.865830349512406, 5.023403026098032, 5.722050625383837, 5.784673185343906, 6.716160992282842, 7.645420681969259, 8.605103455264414, 9.53837571621283, 10.525929619940033, 11.49533974584715, 12.552752637965433, 13.616759676367895, 12.757910951361671, 11.761616735037691, 10.797290135213947, 9.728237088888543, 8.71698425535633, 7.69625646116991, 6.717028846483452, 5.849569565063165, 4.865022152829351, 3.9984491022784328, 4.789588413803582, 4.777472395185191, 5.780340049599193, 6.709953872318872, 7.720633806289292, 8.672237583002465, 9.666973577278686, 10.6406274309677, 11.68207571447675, 12.630443919865826, 11.771425289271281, 10.753563776036458, 9.755272165883701, 8.753308478220298, 7.745841726851647, 6.752216863955493, 5.773530306510063, 4.8274173294985685, 3.8946977745380935, 2.929711707921869, 3.803299922391045, 3.8560872245445417, 4.817316974105156, 5.805970961630871, 6.747710423070508, 7.737041899565408, 8.801451214926832, 9.837498004457524, 10.830480712826745, 11.67774445691806, 10.700615657336, 9.717196288075865, 8.707639179305398, 7.7602377543280365, 6.797412537380396, 5.813418867558296, 4.874895027242665, 3.8612781379907344, 2.921752833191555, 1.922010927468245, 2.864704518398091, 2.925186356547908, 3.8832197370878347, 4.878768028319766, 5.840559671092051, 6.9003520732494605, 7.906278144555502, 8.959141748725166, 9.959220925877043, 10.905852509291742, 9.942323063483832, 8.88546012965007, 7.886184735057066, 6.930494251824368, 5.911548860962359, 4.861566479721283, 3.8943139263269835, 2.881591890909083, 1.9391024748839123, 0.9527553140126583, 1.9834050948080504, 1.8998378692900997, 2.9675401609787073, 3.9496027316097626, 4.9406135780021225, 5.991591246157257, 6.9656968276876565, 8.01427039797482, 8.996891767396514, 9.964314447795438, 9.189561921521255, 8.264211801287539, 7.328003931147755, 6.295244335285781, 5.28470284283302, 4.221855123320415, 3.179128421226716, 2.106675917787933, 1.0613505066667595, 0.0, 0.9341400642463162, 2.8305926768089824, 3.8600952112511955, 4.898417146823685, 5.8822040763548555, 6.881962485816299, 7.880918965317125, 8.860613242040577, 9.842627189475493, 10.797048390391767, 10.188587654174938, 9.180277410850925, 8.115309694564244, 7.1577808669939165, 6.12456264369538, 5.111010771932351, 4.054439155656941, 3.049575550342306, 1.9764147489846997, 1.0143094701753375, 1.8657012940131006, 3.7836541024822674, 4.730527387880403, 5.716559161882326, 6.736649553200422, 7.803384371415461, 8.758508413204206, 9.714809601073751, 10.731284848478746, 11.7003187170022, 10.712275907219052, 9.781117539417167, 8.760353726236316, 7.831784508773721, 6.891336152116527, 5.884963164950157, 4.8900023664269945, 3.905470771610445, 2.940798133854458, 1.979994682911519, 2.829911684978857, 4.743992515734385, 5.724705506834096, 6.685881539563377, 7.622796719546828, 8.6970696426933, 9.769843383726624, 10.667352584993179, 11.622376316704292, 12.608520706679613, 11.68794937295206, 10.750617794245718, 9.69644759315027, 8.826617498983206, 7.924993614181505, 6.86305437757687, 5.825531230178884, 4.867712725197684, 3.918970959739065, 3.0468782403593107, 3.7798031478456653, 5.771745510409236, 6.743724497609599, 7.717772642850576, 8.555488431714025, 9.589069793831609, 10.615705917758845, 11.571225999947973, 12.60248242672791, 13.56139397588678, 12.65640497929608, 11.616857476087933, 10.65990321616308, 9.855025838256745, 8.873307659814579, 7.888285985764439, 6.827377975702749, 5.834357460154985, 4.952248814570571, 4.116055054904766, 4.803159895695456], [4.943771755909626, 5.793298703275077, 6.780546474968519, 7.6132330234374965, 8.666699727051471, 9.671398042140321, 10.685679945062159, 11.699383870914737, 12.489046830106853, 13.45819189432278, 14.44575773126003, 13.49308093186567, 12.529138259225276, 11.539145360583174, 10.582545829728597, 9.611510002471935, 8.573009068061333, 7.848760037372633, 6.862972759557636, 5.843336289163868, 5.9161714039070645, 6.769334587955234, 7.747791794748415, 8.55363110242544, 9.48878450715074, 10.465997720101543, 11.527023608749616, 12.462249340304307, 13.448996346936768, 14.45034559723803, 15.364996836892988, 14.435363827491724, 13.472359117417529, 12.491082641052778, 11.509511222541333, 10.608083037872534, 9.645122666727302, 8.705576298552872, 7.718956981512771, 6.772030592956751, 6.93389266716976, 7.769990409744047, 8.782623257440346, 9.582524975578405, 10.497888268439262, 11.454336166600848, 12.503549880118864, 13.511471817877785, 14.424420657096674, 15.377249603654741, 16.340172689645303, 15.372863273421043, 14.450326065728046, 13.501742069655338, 12.528742179788571, 11.659058662500744, 10.627068084337045, 9.675015353695958, 8.711000478979523, 7.709797143768442, 7.9668865137921765, 8.731399484583193, 9.71561615140224, 10.545035599570692, 11.45083816450393, 12.47810759268679, 13.46098645670574, 14.460071256225515, 15.405750380373627, 16.330815954512335, 17.37668996539423, 16.380861914044342, 15.417230865380951, 14.521162462271084, 13.473048341300958, 12.639316475798148, 11.569825006868355, 10.631695384878805, 9.634159055663472, 8.69665121592828, 8.911909814057681, 9.76957441684228, 10.665658857758887, 11.583908771552197, 12.510470867118393, 13.444118795826945, 14.433170441101966, 15.375906354724787, 16.358337840624067, 17.36481029281758, 18.287772136593865, 17.310953668532136, 16.393203484857793, 15.447770800029623, 14.5431772159753, 13.600900711303234, 12.550038428039342, 11.593160605629258, 10.628595910154985, 9.688004756874598, 9.858952354658172, 10.769083916894454, 11.712357186701261, 12.582922141895883, 13.581572750905247, 14.377711106649848, 15.417970933498806, 16.301154995510036, 17.27406785594559, 18.259719709565594, 18.237931238335843, 17.37403889178494, 16.39205798462533, 15.420646783911174, 14.47722336282113, 13.514824090786037, 12.65312718834254, 11.704344573088804, 10.839977017436798, 9.982330677653174, 9.77842039601315, 10.75400589219494, 11.70104394376186, 12.730573662148442, 13.695507012588225, 14.533270366469816, 15.425892677538123, 16.410391565627418, 17.368547630002105, 18.29504907129897, 17.289263881114145, 16.323482877326615, 15.39300233889615, 14.426903948596381, 13.41908716829673, 12.522724281243072, 11.720293158825294, 10.769724709442242, 9.875858701727635, 8.993288389734799, 8.811214082715008, 9.801881665613765, 10.709892943442533, 11.706480564595923, 12.63984038360537, 13.54780769062781, 14.472325336713379, 15.463882783187318, 16.468471711127876, 17.299881288660753, 16.346722120897798, 15.391043651650811, 14.460908003034163, 13.433112400152059, 12.448837325759923, 11.50674381046357, 10.756360841002875, 9.824503160724351, 8.93613953668186, 7.98494308500287, 7.882614026610851, 8.793286173780638, 9.756938556325586, 10.639325567215579, 11.608452550238471, 12.565764627928168, 13.46769108151787, 14.413056108351082, 15.393498401439581, 16.3368192383114, 15.393016843253564, 14.43987616277391, 13.51824336404677, 12.4609258471441, 11.507317124154321, 10.569577718835538, 9.765709849073065, 8.82227910892902, 7.894768373452761, 7.024390872922172, 6.876121981900739, 7.8190959332746255, 8.721819321147244, 9.670125559720853, 10.557782270636892, 11.553968527581912, 12.534477533599114, 13.46988374182596, 14.439685433739259, 15.366716806287268, 14.413399214019515, 13.438460180017936, 12.504907139517066, 11.576380015013259, 10.556945721231594, 9.583646340651178, 8.75759783244872, 7.87058486726578, 6.946845950088133, 5.958926708332179, 5.909490556704302, 6.766464714403658, 7.664136348898215, 8.671922795370259, 9.613821275143493, 10.678515868315102, 11.596660329884875, 12.613749955380905, 13.650669530215273, 14.49123468460458, 13.464092756054901, 12.408098521922662, 11.476950523816399, 10.529981138041014, 9.60478069463755, 8.623942749928943, 7.738452881741556, 6.799970413758722, 5.947727878551261, 4.9472784929403595, 4.954917462352842, 5.796969327587164, 6.726229017273582, 7.685911790568736, 8.61918405151715, 9.606737955244354, 10.57614808115147, 11.633560973269752, 12.697568011672214, 13.692051015607985, 12.695756799284005, 11.731430199460263, 10.662377153134859, 9.651124319602646, 8.630396525416227, 7.651168910729769, 6.783709629309481, 5.799162217075667, 4.932589166524749, 4.014816281360104, 3.947716672194127, 4.861148384903515, 5.790762207623194, 6.786493742042976, 7.738097518756149, 8.73283351303237, 9.706487366721383, 10.747935650230435, 11.78508870848332, 12.7055653535176, 11.687703840282774, 10.689412230130017, 9.687448542466614, 8.679981791097964, 7.686356928201809, 6.70767037075638, 5.761557393744885, 4.82883783878441, 3.863851772168185, 3.028527789947567, 2.9368955598488635, 3.898125309409477, 4.871830897384555, 5.813570358824192, 6.802901835319092, 7.867311150680517, 8.90335794021121, 9.89634064858043, 10.96675759235041, 11.634755721582318, 10.651336352322183, 9.641779243551714, 8.694377818574353, 7.731552601626712, 6.747558931804612, 5.8090350914889815, 4.795418202237051, 3.8558928974378714, 2.8561509917145615, 2.089932385954613, 1.9910462923015921, 2.9490796728415187, 3.94462796407345, 4.906419606845735, 5.9662120090031445, 6.972138080309186, 8.02500168447885, 9.025080861630727, 10.055477073947799, 10.876463127730148, 9.819600193896386, 8.820324799303382, 7.864634316070684, 6.845688925208675, 5.795706543967599, 4.8284539905732995, 3.8157319551553996, 2.8732425391302288, 1.8868953782589746, 1.0492650305617341, 0.9656978050437836, 2.0334000967323913, 3.0154626673634466, 4.0064735137558065, 5.057451181910941, 6.0315567634413405, 7.080130333728505, 8.062751703150198, 9.030174383549122, 9.974631137203582, 9.198351865533855, 8.262143995394071, 7.229384399532097, 6.218842907079336, 5.155995187566731, 4.113268485473032, 3.040815982034249, 1.9954905709130757, 0.9341400642463162, 0.0, 1.8964526125626664, 2.9259551470048795, 3.964277082577369, 4.9480640121085395, 5.947822421569983, 6.946778901070809, 7.926473177794262, 8.908487125229179, 9.862908326145453, 10.900905976962289, 10.023014947422826, 8.958047231136145, 8.000518403565817, 6.96730018026728, 5.9537483085042515, 4.897176692228841, 3.8923130869142057, 2.8191522855565996, 1.8570470067472373, 0.9315612297667845, 2.8495140382359514, 3.796387323634087, 4.78241909763601, 5.802509488954106, 6.869244307169145, 7.82436834895789, 8.780669536827435, 9.79714478423243, 10.806718989356234, 11.555013443790951, 10.623855075989066, 9.603091262808215, 8.67452204534562, 7.734073688688428, 6.727700701522057, 5.732739902998895, 4.748208308182345, 3.7835356704263585, 2.822732219483419, 1.8957716207325408, 3.809852451488069, 4.79056544258778, 5.751741475317061, 6.688656655300512, 7.762929578446984, 8.835703319480308, 9.733212520746864, 10.688236252457978, 11.674380642433299, 12.53068690952396, 11.593355330817618, 10.539185129722169, 9.669355035555105, 8.767731150753404, 7.70579191414877, 6.668268766750783, 5.7104502617695845, 4.761708496310965, 3.8804777475865118, 2.8456630835993493, 4.837605446162919, 5.809584433363283, 6.78363257860426, 7.621348367467709, 8.654929729585293, 9.681565853512529, 10.637085935701657, 11.668342362481596, 12.627253911640466, 13.49914251586798, 12.459595012659832, 11.50264075273498, 10.697763374828645, 9.716045196386478, 8.731023522336338, 7.670115512274649, 6.677094996726885, 5.794986351142471, 4.847119784418222, 3.8690198314491404], [4.980206821776146, 5.829733769141597, 6.81804311349293, 7.650729661961908, 8.704196365575882, 9.708894680664732, 10.72317658358657, 11.736880509439146, 12.526543468631264, 13.49568853284719, 12.64850675301152, 11.622031162725367, 10.658088490084973, 9.66809559144287, 8.711496060588294, 7.740460233331631, 6.701959298921031, 5.977710268232331, 4.996506888759474, 4.055551315977004, 5.924835725973768, 6.805769653821753, 7.784226860614934, 8.591127740949851, 9.526281145675151, 10.503494358625954, 11.564520247274027, 12.499745978828718, 13.48649298546118, 14.448052325761466, 13.493947067752686, 12.564314058351421, 11.601309348277226, 10.620032871912475, 9.63846145340103, 8.737033268732231, 7.774072897586999, 6.915922337322242, 5.929303020282141, 4.9842456197698874, 6.906018809157715, 7.806425475610566, 8.819058323306864, 9.620021614102816, 10.535384906963673, 11.49183280512526, 12.541046518643276, 13.548968456402196, 14.461917295621085, 15.381227900306369, 14.469122920505002, 13.50181350428074, 12.579276296587743, 11.630692300515035, 10.657692410648268, 9.788008893360441, 8.756018315196743, 7.885361392465327, 6.921346517748892, 5.922012170581578, 7.9390126557801315, 8.767834550449713, 9.752051217268761, 10.582532238095103, 11.48833480302834, 12.515604231211201, 13.498483095230153, 14.497567894749928, 15.443247018898038, 16.334794251163963, 15.535886650042766, 14.50981214490404, 13.546181096240648, 12.650112693130781, 11.601998572160655, 10.779176000392667, 9.709684531462873, 8.843910411691942, 7.8463740824766095, 6.908866242741417, 8.838120387715923, 9.8060094827088, 10.702093923625407, 11.621405410076608, 12.547967505642806, 13.481615434351358, 14.470667079626379, 15.4134029932492, 16.39583447914848, 17.368788589469208, 16.416722367453563, 15.439903899391833, 14.52215371571749, 13.57672103088932, 12.672127446834997, 11.740760235897753, 10.68989795263386, 9.805375632442395, 8.84081093696812, 7.900219783687734, 9.785162928316414, 10.740368929813144, 11.731775943416396, 12.620418780420295, 13.61906938942966, 14.41520774517426, 15.455467572023219, 16.33865163403445, 17.31156449447, 18.297216348090007, 17.475264275545307, 16.461947475444763, 15.523513349757929, 14.618042550143407, 13.667587625852844, 12.620400431905702, 11.645626489110198, 10.711934859989531, 9.775369649492129, 8.875013183188951, 9.743477398488249, 10.719062894670039, 11.66610094623696, 12.695630664623542, 13.660564015063324, 14.498327368944915, 15.390949680013222, 16.375448568102517, 17.333604632477204, 18.28995007667884, 18.423931632767005, 17.499304534025573, 16.568823995595107, 15.524432270797151, 14.5166154904975, 13.537905831993442, 12.578460518627443, 11.646554723636093, 10.739487965201292, 9.864055471107326, 8.776271085190107, 9.766938668088864, 10.674949945917632, 11.671537567071022, 12.604897386080468, 13.512864693102909, 14.437382339188478, 15.428939785662417, 16.433528713602975, 17.273302430831777, 18.243174733460464, 17.287496264213477, 16.35736061559683, 15.329565012714726, 14.34528993832259, 13.403196423026237, 12.590941723484152, 11.659084043205628, 10.739542419197662, 9.788345967518671, 7.84767102908595, 8.758343176255737, 9.721995558800685, 10.604382569690678, 11.57350955271357, 12.530821630403267, 13.43274808399297, 14.378113110826181, 15.35855540391468, 16.310240380482423, 17.273073169960092, 16.336328775336575, 15.414695976609437, 14.357378459706768, 13.403769736716988, 12.466030331398205, 11.600290731554342, 10.656859991410297, 9.698171255968562, 8.827793755437973, 6.841178984375838, 7.7841529357497246, 8.686876323622343, 9.635182562195952, 10.522839273111991, 11.51902553005701, 12.499534536074213, 13.43494074430106, 14.404742436214358, 15.340137948458292, 16.293455540726043, 15.334912792580603, 14.401359752079733, 13.472832627575926, 12.453398333794262, 11.480098953213846, 10.654050445011386, 9.705165749747056, 8.750248832603933, 7.76232959084798, 5.874547559179401, 6.731521716878757, 7.629193351373314, 8.636979797845358, 9.578878277618593, 10.643572870790202, 11.561717332359974, 12.578806957856004, 13.615726532690372, 14.592554956137013, 15.360545368617569, 14.30455113448533, 13.373403136379066, 12.426433750603682, 11.501233307200216, 10.52039536249161, 9.63490549430422, 8.696423026321387, 7.751130761067062, 6.7506813754561605, 4.919974464827941, 5.762026330062263, 6.691286019748681, 7.650968793043835, 8.58424105399225, 9.571794957719453, 10.541205083626568, 11.598617975744851, 12.662625014147313, 13.735915351010908, 14.592209411846675, 13.62788281202293, 12.558829765697526, 11.547576932165313, 10.526849137978894, 9.547621523292436, 8.680162241872148, 7.695614829638333, 6.829041779087415, 5.818219163875905, 3.912773674669226, 4.826205387378614, 5.755819210098293, 6.751550744518075, 7.703154521231248, 8.697890515507469, 9.671544369196482, 10.712992652705534, 11.750145710958419, 12.721503605364486, 13.584156452845441, 12.585864842692684, 11.583901155029281, 10.576434403660631, 9.582809540764476, 8.604122983319046, 7.658010006307552, 6.725290451347076, 5.760304384730851, 4.8319306724633675, 2.9019525623239626, 3.863182311884576, 4.836887899859654, 5.778627361299291, 6.7679588377941915, 7.832368153155616, 8.868414942686309, 9.86139765105553, 10.897133841059883, 11.825911030349943, 12.547788964884848, 11.53823185611438, 10.59083043113702, 9.628005214189379, 8.64401154436728, 7.705487704051649, 6.691870814799717, 5.752345510000538, 4.752603604277228, 3.8933352684704134, 1.9561032947766912, 2.914136675316618, 3.909684966548549, 4.871476609320834, 5.931269011478244, 6.937195082784285, 7.990058686953948, 8.933752024401604, 9.964148236718676, 10.890808510728444, 11.716052806459055, 10.716777411866051, 9.761086928633352, 8.742141537771342, 7.692159156530266, 6.724906603135967, 5.712184567718066, 4.769695151692895, 3.7833479908216407, 2.9457176431244005, 0.9307548075188828, 1.9984570992074908, 2.980519669838546, 3.971530516230906, 5.022508184386041, 5.9966137659164405, 6.9888014964993825, 7.971422865921075, 8.93884554632, 9.88330229997446, 10.808652420208176, 9.999330782562192, 9.042511121938942, 8.03196962948618, 6.969121909973576, 5.926395207879877, 4.8928336152776275, 3.8754526239370817, 2.8305926768089824, 1.8964526125626664, 0.0, 1.0295025344422133, 2.0678244700147026, 3.051611399545873, 4.0513698090073165, 5.050326288508143, 6.030020565231595, 7.012034512666512, 7.966455713582785, 9.00445336439962, 10.034159591401773, 8.995543869660557, 8.038015042090228, 7.004796818791691, 5.991244947028663, 4.934673330753252, 3.9298097254386177, 2.8566489240810116, 1.894543645271649, 0.9690578682911963, 0.9784642690956498, 1.925337554493785, 2.9113693284957085, 3.9314597198138044, 4.9981945380288435, 5.953318579817588, 6.9096197676871345, 7.9260950150921285, 8.910266376793567, 9.898309186576714, 10.66135171451348, 9.640587901332626, 8.712018683870031, 7.771570327212839, 6.765197340046468, 5.770236541523306, 4.7857049467067565, 3.8210323089507696, 2.8602288580078303, 1.9322066865990606, 2.0220674783012047, 2.919515673447478, 3.8806917061767594, 4.81760688616021, 5.891879809306682, 6.964653550340007, 7.862162751606562, 8.817186483317677, 9.803330873292998, 10.786357996785725, 11.630851969342029, 10.57668176824658, 9.706851674079516, 8.805227789277815, 7.743288552673181, 6.705765405275194, 5.747946900293996, 4.799205134835376, 3.916912813453032, 2.882098149465869, 3.049820472976055, 3.9385346642229813, 4.9125828094639585, 5.750298598327407, 6.78387996044499, 7.810516084372226, 8.766036166561355, 9.797292593341293, 10.756204142500163, 11.828611064181887, 12.497091651184242, 11.54013739125939, 10.735260013353056, 9.753541834910887, 8.76852016086075, 7.7076121507990605, 6.714591635251296, 5.832482989666882, 4.8835548502847415, 3.9054548973156598], [5.995278685965863, 6.844805633331314, 7.838147968875303, 8.680232196404122, 9.733698900018096, 10.738397215106946, 11.752679118028784, 12.766383043881362, 13.556046003073478, 12.689702849680891, 11.769832046404964, 10.743356456118812, 9.779413783478418, 8.789420884836316, 7.832821353981739, 6.861785526725077, 5.823284592314477, 5.099035561625778, 4.11783218215292, 5.070623180166721, 6.938144808435488, 7.82084151801147, 8.799298724804652, 9.620630275392065, 10.555783680117365, 11.532996893068168, 12.594022781716241, 13.529248513270932, 14.515995519903393, 13.569377619154912, 12.61527236114613, 11.685639351744866, 10.722634641670671, 9.74135816530592, 8.759786746794475, 7.8583585621256775, 6.895398190980445, 6.037247630715688, 5.050628313675587, 5.997554702231607, 7.919327891619434, 8.821497339800283, 9.834130187496582, 10.64952414854503, 11.564887441405887, 12.521335339567473, 13.57054905308549, 14.57847099084441, 15.455382140257882, 14.502553193699814, 13.590448213898448, 12.623138797674185, 11.700601589981188, 10.75201759390848, 9.779017704041713, 8.909334186753888, 7.87734360859019, 7.006686685858774, 6.042671811142339, 6.9353212530432975, 8.952321738241851, 9.782906414639431, 10.767123081458479, 11.612034772537317, 12.517837337470555, 13.545106765653415, 14.527985629672365, 15.52707042919214, 16.402216611461387, 15.456119544557406, 14.657211943436211, 13.631137438297484, 12.667506389634093, 11.771437986524226, 10.7233238655541, 9.900501293786114, 8.83100982485632, 8.061556107193805, 7.094619670367765, 7.922175325203137, 9.851429470177642, 10.821081346898518, 11.717165787815125, 12.650907944518822, 13.577470040085018, 14.51111796879357, 15.500169614068591, 16.442905527691412, 17.423861062403667, 16.49011388286265, 15.53804766084701, 14.561229192785278, 13.643479009110935, 12.698046324282766, 11.793452740228442, 10.8620855292912, 9.811223246027307, 9.023021327944258, 8.114604629244374, 8.913528866149454, 10.798472010778132, 11.069468530373955, 11.828370356255135, 12.814840908778319, 13.782513932524745, 14.679133079711002, 15.519059126489596, 16.443305157480417, 17.41621801791597, 17.46778120728465, 16.596589568938754, 15.583272768838206, 14.644838643151374, 13.739367843536852, 12.788912919246291, 11.74172572529915, 10.766951782503645, 9.985728552265785, 9.049163341768383, 9.88832226565067, 10.747725067104984, 10.055727991501785, 10.796107761403047, 11.825637479789629, 12.790570830229411, 13.628334184111003, 14.512712322674812, 15.497211210764107, 16.455367275138794, 17.41171271934043, 17.54525692616045, 16.62062982741902, 15.690149288988552, 14.645757564190598, 13.637940783890947, 12.659231125386889, 11.69978581202089, 10.920348415912347, 10.013281657477545, 10.877364553569045, 9.780518753806842, 9.044666070863467, 9.80495676108372, 10.80154438223711, 11.734904201246556, 12.642871508268996, 13.559144981850068, 14.550702428324007, 15.555291356264565, 16.395065073493367, 17.446776311094435, 17.60400728391113, 16.60349311808837, 15.537411309430457, 14.553136235038322, 13.611042719741969, 12.663718129843309, 11.865569964630238, 10.95300082252332, 10.81389391073163, 8.851918697702684, 7.971732101941882, 8.852002373966773, 9.734389384856765, 10.703516367879658, 11.660828445569354, 12.55451072665456, 13.499875753487771, 14.48031804657627, 15.432003023144015, 16.394835812621686, 17.365831309778788, 16.44419851105165, 15.386880994148981, 14.433272271159202, 13.495532865840419, 12.625838674767301, 11.682407934623257, 10.723719199181522, 9.853341698650933, 7.845426652992573, 6.99754186143587, 7.81688313878843, 8.76518937736204, 9.652846088278078, 10.649032345223098, 11.621297178735803, 12.55670338696265, 13.526505078875948, 14.461900591119882, 15.415218183387635, 16.364415327022815, 15.430862286521947, 14.50233516201814, 13.482900868236475, 12.50960148765606, 11.683552979453601, 10.730713692960016, 9.775796775816893, 8.78787753406094, 6.878795227796136, 5.928633478413132, 6.759200166539401, 7.766986613011444, 8.70888509278468, 9.765335513451792, 10.683479975021564, 11.700569600517595, 12.737489175351962, 13.714317598798603, 14.732110201357159, 15.334053668927544, 14.40290567082128, 13.455936285045896, 12.53073584164243, 11.549897896933825, 10.664408028746436, 9.725925560763603, 8.776678704280021, 7.77622931866912, 5.9455224080409, 4.959138091596638, 5.821292834914767, 6.772731435705426, 7.70600369665384, 8.693557600381043, 9.662967726288159, 10.720380618406441, 11.784387656808903, 12.845170311326378, 13.756726677830976, 14.657385346465144, 13.58833230013974, 12.577079466607527, 11.556351672421108, 10.57712405773465, 9.709664776314362, 8.725117364080548, 7.858544313529629, 6.843767107088865, 4.938321617882185, 4.023317148912989, 4.88582602526438, 5.84143412150348, 6.793037898216653, 7.787773892492873, 8.761427746181887, 9.802876029690939, 10.820330769565437, 11.791688663971504, 12.748673718829744, 13.615367377134898, 12.613403689471495, 11.605936938102845, 10.61231207520669, 9.63362551776126, 8.687512540749765, 7.75479298578929, 6.789806919173065, 5.857478615676327, 3.927500505536922, 3.060294073418951, 3.946369081992761, 4.868510738284696, 5.8578422147795965, 6.922251530141021, 7.958298319671713, 8.913812912700468, 9.86763130661767, 10.796408495907729, 11.706474936284742, 12.567734390556595, 11.620332965579234, 10.657507748631593, 9.673514078809493, 8.734990238493863, 7.721373349241931, 6.781848044442752, 5.782106138719442, 4.918883211683373, 2.9816512379896505, 2.0236178574497243, 3.0191661486816557, 3.9058116514679835, 4.965604053625393, 5.971530124931435, 7.008552710898341, 7.9042494899593905, 8.934645702276462, 9.86130597628623, 10.734636167736051, 11.733911562329055, 10.790589463075566, 9.771644072213556, 8.72166169097248, 7.754409137578181, 6.74168710216028, 5.799197686135109, 4.812850525263855, 3.975220177566614, 1.9602573419610962, 1.0654508721036542, 2.0475134427347093, 2.9800416725031367, 4.031019340658271, 4.970365288654578, 5.9592989620571695, 6.941920331478862, 7.909343011877786, 8.853799765532246, 9.779149885765962, 10.715357755905746, 10.072013656381156, 9.061472163928395, 7.998624444415789, 6.95589774232209, 5.922336149719841, 4.904955158379295, 3.8600952112511964, 2.92595514700488, 1.0295025344422133, 0.0, 1.0383219355724895, 2.02210886510366, 3.021867274565104, 4.02082375406593, 5.000518030789382, 5.982531978224299, 6.936953179140572, 7.974950829957407, 9.004657056959559, 10.02504640410277, 9.067517576532442, 8.034299353233905, 7.020747481470876, 5.9641758651954655, 4.95931225988083, 3.8861514585232246, 2.9240461797138626, 1.9985604027334096, 1.9935361332853665, 1.046662847887231, 2.0326946218891546, 2.954292963462676, 4.021027781677715, 4.976151823466459, 5.932453011336006, 6.948928258741, 7.880763842351353, 8.8688066521345, 9.799965019936385, 10.67009043577484, 9.741521218312245, 8.801072861655053, 7.794699874488682, 6.79973907596552, 5.8152074811489705, 4.850534843392984, 3.889731392450044, 2.947278550788777, 3.0371393424909217, 2.040840966840924, 3.0020169995702055, 3.938932179553656, 4.954964046729357, 6.02773778776268, 6.884995995255434, 7.840019726966548, 8.826164116941868, 9.809191240434595, 10.746522819140937, 11.606184302688794, 10.73635420852173, 9.83473032372003, 8.772791087115396, 7.735267939717408, 6.7774494347362095, 5.82870766927759, 4.931984677642748, 3.8971700136555856, 4.064892337165772, 3.0598599576164274, 4.033908102857405, 4.871623891720853, 5.905205253838437, 6.931841377765673, 7.8873614599548025, 8.87590979999158, 9.821647210152895, 10.880655304130016, 11.691105968017943, 12.569639925701605, 11.76476254779527, 10.783044369353103, 9.798022695302963, 8.737114685241274, 7.74409416969351, 6.861985524109096, 5.898626714474458, 4.920526761505377], [7.001961356717566, 7.851488304083017, 8.844830639627006, 9.718554131976612, 10.772020835590586, 11.776719150679437, 12.791001053601274, 13.635682173482095, 12.596144369742179, 11.651380914108401, 10.747407753423138, 9.720932163136986, 8.756989490496592, 7.766996591854489, 6.810397060999911, 5.839361233743248, 4.800860299332648, 4.1436454515502685, 5.084794137535974, 6.077305850918425, 7.905106763818542, 8.827524188763173, 9.805981395556355, 10.658952210964555, 11.594105615689855, 12.571318828640658, 13.632344717288731, 14.554816362001096, 13.568069355368635, 12.546953326173085, 11.592848068164304, 10.66321505876304, 9.700210348688845, 8.718933872324094, 7.737362453812647, 6.8359342691438485, 5.872973897998616, 5.087392242375582, 6.017590269058641, 6.964516657614661, 8.886289847002487, 9.828180010551986, 10.840812858248285, 11.68784608411752, 12.603209376978377, 13.559657275139964, 14.60887098865798, 15.402784162914626, 14.432957847276056, 13.480128900717988, 12.568023920916621, 11.600714504692359, 10.67817729699936, 9.729593300926652, 8.756593411059885, 7.886909893772058, 6.8549193156083605, 6.057670512950597, 7.009633766525393, 7.9022832084263515, 9.919283693624905, 10.789589085391132, 11.77380575221018, 12.650356708109808, 13.556159273043045, 14.583428701225905, 15.566307565244855, 16.33596450977313, 15.379792318479563, 14.43369525157558, 13.634787650454385, 12.608713145315656, 11.645082096652265, 10.749013693542398, 9.700899572572272, 8.878077000804286, 7.808585531874492, 7.112539934285628, 8.061581625750819, 8.88913728058619, 10.818391425560696, 11.82776401765022, 11.963895263726855, 12.797372563292775, 13.761579429756054, 14.596243674704672, 15.543153672332426, 16.330231862693175, 16.401436769421842, 15.467689589880823, 14.515623367865182, 13.53880489980345, 12.621054716129107, 11.675622031300938, 10.771028447246614, 9.839661236309372, 8.788798953045479, 8.074005155036081, 9.051242059574394, 9.880490821532508, 11.765433966161186, 11.866196498028685, 10.91719693478448, 11.79835919294909, 12.766032216695512, 13.66265136388177, 14.480737190917107, 15.404983221907928, 16.377896082343483, 16.44535691430282, 15.574165275956926, 14.560848475856378, 13.622414350169546, 12.716943550555024, 11.766488626264463, 10.719301432317321, 9.744527489521817, 9.122066089468053, 9.985800772098402, 10.855284221033724, 11.628674344705397, 10.852455959156515, 9.884934339932391, 10.8091557639604, 11.774089114400178, 12.61185246828177, 13.474390387102323, 14.458889275191618, 15.417045339566306, 16.37339078376794, 16.522832633178623, 15.59820553443719, 14.667724996006724, 13.62333327120877, 12.615516490909119, 11.63680683240506, 10.677361519039062, 10.056685953114615, 10.949919087807565, 11.844326508952099, 10.661468031407255, 9.841394038518198, 8.893783339613064, 9.78506266640788, 10.718422485417323, 11.626389792439763, 12.52082304627758, 13.512380492751518, 14.516969420692076, 15.35674313792088, 16.408454375521945, 16.581582990929306, 15.581068825106543, 14.514987016448629, 13.530711942056493, 12.58861842676014, 11.64129383686148, 11.001907501832505, 11.88963825285334, 11.722140573138326, 9.732867975303098, 8.852681379542295, 7.940828952496118, 8.717907669027536, 9.687034652050425, 10.644346729740121, 11.51618879108207, 12.46155381791528, 13.441996111003782, 14.393681087571526, 15.356513877049196, 16.36116130035457, 16.480861027838415, 15.417132646696736, 14.463523923706957, 13.525784518388173, 12.643909886456788, 12.004131553627836, 11.683840883523596, 10.784639853836676, 8.726375930592987, 7.878491139036283, 6.905709717317775, 7.7487076615328085, 8.636364372448845, 9.632550629393865, 10.582975243163315, 11.51838145139016, 12.48818314330346, 13.423578655547393, 14.376896247815147, 15.359745317598597, 16.37213862743172, 15.540657097590628, 14.521222803808964, 13.547923423228548, 12.692094920686344, 11.69083537730209, 10.735918460158967, 9.747999218403011, 7.75974450539655, 6.809582756013546, 5.848026745068745, 6.750504897182214, 7.692403376955449, 8.727013577879303, 9.645158039449075, 10.662247664945106, 11.699167239779474, 12.675995663226114, 13.693788265784672, 14.733655130008252, 15.441227606393769, 14.494258220618384, 13.569057777214919, 12.588219832506313, 11.672949969979179, 10.734467501996345, 9.736800388622093, 8.736351003011192, 6.905644092382972, 5.840087369197052, 4.910119413444112, 5.734409500132936, 6.667681761081351, 7.655235664808553, 8.62464579071567, 9.682058682833953, 10.746065721236414, 11.806848375753887, 12.718404742258489, 13.708154546803588, 14.560591333830464, 13.615401402180016, 12.594673607993597, 11.615445993307139, 10.74798671188685, 9.763439299653037, 8.85386767543933, 7.8038887914309365, 5.898443302224257, 4.904266426513403, 3.974652603793724, 4.80311218593099, 5.754715962644164, 6.749451956920384, 7.723105810609399, 8.76455409411845, 9.782008833992947, 10.753366728399014, 11.710351783257256, 12.6928235608709, 13.58566272316222, 12.644258873675334, 11.650634010779179, 10.671947453333749, 9.725834476322254, 8.793114921361779, 7.828128854745554, 6.817600300018399, 4.887622189878994, 4.020415757761023, 3.0351956605221053, 3.830188802712207, 4.819520279207108, 5.883929594568532, 6.9199763840992246, 7.875490977127979, 8.82930937104518, 9.75808656033524, 10.668153000712254, 11.645190574292597, 12.592591999269958, 11.695829684204082, 10.711836014381982, 9.773312174066351, 8.75969528481442, 7.82016998001524, 6.8204280742919305, 5.879004896025445, 3.9417729223317224, 2.983739541791796, 2.107992727211, 2.867489715895494, 3.9272821180529034, 4.933208189358945, 5.9702307753258514, 6.865927554386901, 7.896323766703974, 8.822984040713742, 9.696314232163562, 10.695589626756567, 11.640486021442905, 10.809966007786045, 9.759983626544969, 8.79273107315067, 7.780009037732769, 6.837519621707598, 5.851172460836343, 4.993415351130877, 2.9985792775335853, 2.0255725564457254, 1.0435099858146704, 1.9417197369306471, 2.9926974050857815, 3.9320433530820877, 4.92097702648468, 5.903598395906372, 6.871021076305296, 7.815477829959757, 8.740827950193474, 9.677035820333257, 10.709795416195231, 10.099794099500885, 9.03694637998828, 7.994219677894581, 6.960658085292331, 5.943277093951784, 4.898417146823685, 3.964277082577369, 2.0678244700147026, 1.0383219355724895, 0.0, 0.9837869295311703, 1.9835453389926139, 2.98250181849344, 3.962196095216892, 4.944210042651809, 5.898631243568082, 6.936628894384917, 7.96633512138707, 9.031302837673751, 9.98883166524408, 9.072621288806396, 8.059069417043366, 7.002497800767956, 5.997634195453321, 4.924473394095714, 3.962368115286352, 3.036882338305899, 3.0002188040370705, 2.053345518638935, 1.0673137446370118, 1.915971027890186, 2.982705846105225, 3.9378298878939697, 4.894131075763516, 5.91060632316851, 6.8424419067788635, 7.830484716562011, 8.761643084363897, 9.78240689754475, 10.710976115007345, 9.839394797227543, 8.833021810061172, 7.838061011538009, 6.85352941672146, 5.888856778965473, 4.928053328022534, 3.953961221540481, 4.043822013242625, 3.0078029222239784, 2.046626889494697, 2.9165078865718264, 3.9166421111568672, 4.9894158521901915, 5.846674059682944, 6.801697791394059, 7.787842181369379, 8.770869304862105, 9.708200883568447, 10.718500764458703, 11.70580910521683, 10.873052259292521, 9.811113022687886, 8.773589875289899, 7.815771370308699, 6.86702960485008, 5.9386673483944525, 4.90385268440729, 5.071575007917476, 4.026821912999481, 3.078517992781896, 3.8491995987390237, 4.882780960856607, 5.909417084783843, 6.8543006476847195, 7.837587864419092, 8.783325274580404, 9.842333368557526, 10.652784032445453, 11.609738292370306, 12.657162872025795, 11.821366304925593, 10.836344630875454, 9.775436620813764, 8.782416105266, 7.900307459681586, 6.905309385226162, 5.92720943225708], [7.886922101757666, 8.736449049123117, 9.729791384667106, 10.629263137866156, 11.68272984148013, 12.68742815656898, 13.658498722819248, 12.651895243950925, 11.612357440211008, 10.667593984577232, 9.763620823891968, 8.737145233605816, 7.773202560965421, 6.783209662323318, 5.82661013146874, 4.8555743042120785, 3.8170733698014776, 4.829265328950319, 5.877812569562192, 6.89744903995596, 8.647147931575633, 9.592232025928892, 10.570689232722074, 11.569661216854099, 12.5048146215794, 13.482027834530202, 14.506255164024617, 13.571029432469926, 12.584282425837465, 11.563166396641915, 10.609061138633134, 9.67942812923187, 8.716423419157675, 7.735146942792922, 6.753575524281477, 5.852147339612679, 4.889186968467446, 5.7730121197756326, 6.7596314368157335, 7.706557825371753, 9.62833101475958, 10.592887847717705, 11.605520695414004, 12.598555090007064, 13.51391838286792, 14.470366281029508, 15.437037578096184, 14.418997233383456, 13.449170917744885, 12.496341971186817, 11.58423699138545, 10.616927575161188, 9.69439036746819, 8.745806371395481, 7.772806481528714, 6.90312296424089, 5.871132386077191, 6.743290390350648, 7.707305265067083, 8.644324376183443, 10.661324861381996, 11.554296922556851, 12.5385135893759, 12.85245880574311, 13.837425202839349, 14.616465070977128, 15.56941941600424, 15.35217758024196, 14.396005388948392, 13.44990832204441, 12.651000720923214, 11.624926215784486, 10.661295167121095, 9.765226764011226, 8.7171126430411, 7.894290071273116, 6.824798602343322, 7.762928224332873, 8.759253124292508, 9.631178448343283, 11.560432593317788, 12.592116792611783, 12.701396965652464, 11.813585633761605, 12.777792500224884, 13.612456745173503, 14.559366742801256, 15.346444933162005, 15.417649839890673, 14.483902660349653, 13.531836438334011, 12.55501797027228, 11.637267786597937, 10.691835101769765, 9.787241517715442, 8.855874306778201, 7.805012023514309, 8.724393445083326, 9.701630349621638, 10.6225319892896, 12.507475133918279, 12.603698199954293, 11.654698636710087, 10.814572263417919, 11.782245287164343, 12.6788644343506, 13.496950261385937, 14.421196292376758, 15.394109152812312, 15.461569984771652, 14.590378346425755, 13.577061546325208, 12.638627420638375, 11.733156621023852, 10.782701696733293, 9.73551450278615, 8.760740559990646, 9.772454379515297, 10.636189062145647, 11.597325388790816, 12.366176046631006, 11.589957661082122, 10.622436041857998, 9.825368834429227, 10.79030218486901, 11.628065538750601, 12.490603457571153, 13.475102345660448, 14.433258410035135, 15.389603854236771, 15.539045703647455, 14.61441860490602, 13.683938066475553, 12.6395463416776, 11.631729561377949, 10.65301990287389, 9.693574589507891, 10.707074243161859, 11.60030737785481, 12.586367676709191, 11.398969733332864, 10.578895740443805, 9.631285041538671, 8.801275736876708, 9.734635555886154, 10.642602862908594, 11.537036116746409, 12.528593563220348, 13.533182491160906, 14.37295620838971, 15.424667445990774, 15.597796061398135, 14.597281895575373, 13.531200086917458, 12.546925012525323, 11.60483149722897, 10.65750690733031, 11.589364587608834, 12.540026542900584, 12.459642275063935, 10.470369677228707, 9.590183081467904, 8.678330654421725, 7.7341207394963645, 8.703247722519256, 9.660559800208953, 10.5324018615509, 11.47776688838411, 12.458209181472611, 13.409894158040355, 14.372726947518025, 15.3773743708234, 15.497074098307245, 14.433345717165565, 13.479736994175786, 12.541997588857003, 11.660122956925617, 12.591588639404165, 12.469624294402509, 11.522141555762285, 9.463877632518594, 8.615992840961892, 7.643211419243382, 6.764920732001638, 7.652577442917676, 8.648763699862696, 9.599188313632144, 10.53459452185899, 11.504396213772289, 12.439791726016223, 13.393109318283976, 14.375958388067426, 15.38835169790055, 15.39094473969703, 14.46843898933744, 13.527928967041362, 12.716325661806238, 12.476618788181003, 11.52170187103788, 10.533782629281925, 8.497246207322158, 7.547084457939154, 6.585528446994354, 5.766717967651044, 6.708616447424278, 7.7432266483481325, 8.661371109917905, 9.678460735413935, 10.715380310248303, 11.692208733694944, 12.710001336253502, 13.749868200477081, 14.531207762325622, 15.374910506565834, 14.44971006316237, 13.468872118453763, 12.458733380858092, 11.520250912875259, 10.522583799501007, 9.522134413890106, 7.6471346429865115, 6.57758907112266, 5.64762111536972, 4.750622570601766, 5.68389483155018, 6.671448735277383, 7.640858861184499, 8.698271753302782, 9.762278791705244, 10.823061446222717, 11.734617812727318, 12.724367617272417, 13.576804404299294, 14.496053688127466, 13.475325893941047, 12.49609827925459, 11.59111196944802, 10.606564557214206, 9.665133410975828, 8.615154526967434, 6.654693562760751, 5.641768128439011, 4.7121543057193325, 3.8193252563998197, 4.770929033112994, 5.765665027389214, 6.739318881078228, 7.78076716458728, 8.798221904461776, 9.769579798867843, 10.726564853726085, 11.70903663133973, 12.601875793631049, 13.570142840103372, 12.576517977207217, 11.552599739281199, 10.606486762269704, 9.636240178922948, 8.671254112306723, 7.628866035554897, 5.744925368455737, 4.809863700962112, 3.7726973624477136, 2.8464018731810365, 3.8357333496759374, 4.900142665037362, 5.936189454568054, 6.891704047596808, 7.84552244151401, 8.77429963080407, 9.684366071181083, 10.661403644761426, 11.608805069738787, 12.571630286686428, 11.695622943913152, 10.757099103597522, 9.74348221434559, 8.719995427930824, 7.679001665532034, 6.736308074602189, 4.799076100908466, 3.8410427203685398, 2.8454944291366084, 1.8837027863643236, 2.943495188521733, 3.949421259827775, 4.986443845794681, 5.88214062485573, 6.912536837172803, 7.839197111182572, 8.712527302632392, 9.711802697225396, 10.656699091911735, 11.675644482773745, 10.74377055607614, 9.77651800268184, 8.76379596726394, 7.821306551238768, 6.834959390367514, 5.8507185297076205, 3.982366207064756, 2.931006224422892, 1.9489436537918365, 0.9579328073994767, 2.0089104755546114, 2.948256423550917, 3.9371900969535094, 4.919811466375202, 5.887234146774126, 6.831690900428587, 7.757041020662303, 8.693248890802087, 9.72600848666406, 10.736549979116822, 10.02073330951945, 8.978006607425751, 7.9444450148235015, 6.927064023482955, 5.8822040763548555, 4.9480640121085395, 3.051611399545873, 2.02210886510366, 0.9837869295311703, 0.0, 0.9997584094614437, 1.9987148889622697, 2.9784091656857217, 3.960423113120638, 4.914844314036912, 5.9528419648537465, 6.9825481918559, 8.04751590814258, 9.005044735712909, 10.038262959011446, 9.042856346574537, 7.9862847302991264, 6.981421124984491, 5.908260323626885, 4.946155044817522, 4.02066926783707, 3.8851795490771703, 2.938306263679035, 1.9522744896771114, 0.9321840983590158, 1.998918916574055, 2.9540429583627996, 3.910344146232346, 4.92681939363734, 5.858654977247693, 6.84669778703084, 7.777856154832726, 8.798619968013579, 9.727189185476174, 10.667637542133367, 9.743730815950716, 8.748770017427553, 7.764238422611004, 6.799565784855017, 5.8387623339120776, 4.838921966580581, 4.904222576893947, 3.830812169753388, 2.8696361370241066, 1.9327209570406563, 2.932855181625697, 4.005628922659021, 4.862887130151774, 5.817910861862889, 6.804055251838209, 7.787082375330936, 8.724413954037278, 9.734713834927533, 10.722022175685659, 11.725661561306133, 10.72182202857743, 9.684298881179442, 8.726480376198243, 7.777738610739624, 6.823628093434552, 5.788813429447389, 5.895772681404312, 4.8498311605288915, 3.857608241025489, 2.8654126692078536, 3.898994031325437, 4.925630155252673, 5.87051371815355, 6.853800934887922, 7.799538345049235, 8.858546439026357, 9.668997102914284, 10.625951362839135, 11.673375942494625, 12.665166070049786, 11.747053636764997, 10.686145626703308, 9.693125111155544, 8.80276097092319, 7.790270130266261, 6.81217017729718], [8.88668051121911, 9.73620745858456, 10.72954979412855, 11.629021547327602, 12.682488250941576, 13.634087881060232, 12.683356843890804, 11.676753365022481, 10.637215561282565, 9.692452105648787, 8.79064965076014, 7.764174060473987, 6.800231387833593, 5.81023848919149, 4.853638958336912, 3.8826031310802493, 4.8168317792629205, 5.829023738411761, 6.877570979023634, 7.897207449417403, 9.646906341037075, 10.591990435390334, 11.570447642183517, 12.569419626315545, 13.504573031040845, 14.481786243991648, 13.533283990892789, 12.598058259338098, 11.611311252705637, 10.590195223510086, 9.636089965501306, 8.706456956100041, 7.743452246025846, 6.762175769661094, 5.780604351149648, 4.948176889852696, 5.888945377928889, 6.772770529237075, 7.759389846277176, 8.706316234833196, 10.628089424221022, 11.592646257179148, 12.605279104875446, 13.59831349946851, 14.199860317074686, 14.974167044507423, 14.464066404964356, 13.446026060251627, 12.476199744613057, 11.523370798054989, 10.611265818253623, 9.64395640202936, 8.721419194336361, 7.772835198263653, 6.799835308396886, 5.999152514480906, 6.870890795538633, 7.74304879981209, 8.707063674528525, 9.644082785644885, 11.661083270843438, 12.554055332018294, 13.538271998837342, 13.852217215204552, 13.246910421010018, 13.950395618421481, 14.87826830509649, 14.379206407110132, 13.423034215816564, 12.476937148912581, 11.678029547791386, 10.651955042652657, 9.688323993989266, 8.792255590879398, 7.744141469909271, 7.014155333186366, 7.824557011804765, 8.762686633794315, 9.75901153375395, 10.630936857804725, 12.56019100277923, 13.591875202073226, 13.701155375113906, 12.813344043223047, 12.187277718395553, 12.946387292617857, 13.868215631893504, 14.655293822254253, 14.444678666758845, 13.510931487217825, 12.558865265202183, 11.582046797140451, 10.664296613466108, 9.718863928637937, 8.814270344583614, 7.975739568691452, 8.804770432975753, 9.724151854544768, 10.70138875908308, 11.622290398751042, 13.507233543379721, 13.603456609415737, 12.654457046171531, 11.814330672879361, 11.116175834608699, 12.012794981794954, 12.805799150478185, 13.730045181469006, 14.70295804190456, 14.488598811639823, 13.617407173293927, 12.60409037319338, 11.665656247506547, 10.760185447892024, 9.84372822137149, 8.934360997528678, 9.76049896945209, 10.77221278897674, 11.63594747160709, 12.597083798252259, 13.365934456092448, 12.589716070543567, 11.622194451319443, 10.825127243890671, 10.124232732313365, 10.961996086194954, 11.7994523466634, 12.783951234752696, 13.742107299127383, 14.69845274332902, 14.566074530515627, 13.641447431774191, 12.710966893343725, 11.753928283206816, 10.90186441589589, 9.926460807071644, 10.693332998969336, 11.706832652623302, 12.600065787316252, 13.586126086170633, 12.398728142794306, 11.57865414990525, 10.631043451000115, 9.801034146338152, 9.06856610333051, 9.976533410352948, 10.845885005838657, 11.837442452312596, 12.842031380253154, 13.681805097481957, 14.691107512463471, 14.643575395028474, 13.643061229205712, 12.822088512787165, 11.872114258432697, 10.942441277851145, 11.657265316791754, 12.589122997070278, 13.539784952362027, 13.459400684525377, 11.47012808669015, 10.589941490929347, 9.678089063883169, 8.733879148957808, 8.037178269963611, 8.994490347653306, 9.841250750643148, 10.78661577747636, 11.76705807056486, 12.718743047132604, 13.639167013990722, 14.643814437296097, 14.585725868193105, 13.77095549778774, 12.817346774797961, 11.879607369479178, 12.659881366387062, 13.591347048865607, 13.469382703863952, 12.521899965223728, 10.463636041980038, 9.615751250423335, 8.642969828704826, 7.764679141463082, 6.98650799036203, 7.98269424730705, 8.908037202724392, 9.843443410951238, 10.813245102864537, 11.74864061510847, 12.659549384756673, 13.642398454540123, 14.559405968564846, 14.728554520319205, 13.806048769959615, 12.865538747663537, 13.716084071267684, 13.476377197642446, 12.521460280499323, 11.533541038743369, 9.497004616783602, 8.546842867400597, 7.585286856455797, 6.766476377112488, 6.042546994868633, 7.0596374416082615, 7.970219999010153, 8.95381306155108, 9.848988481483419, 10.814223537476844, 11.71024292679206, 12.750109791015639, 13.531449352864179, 14.478418738639563, 14.75821379655366, 13.825242338385772, 13.458491790319536, 12.520009322336703, 11.522342208962451, 10.52189282335155, 8.646893052447956, 7.577347480584104, 6.647379524831163, 5.75038098006321, 5.000305624810309, 5.987859528537512, 6.9497077502767475, 7.973624079439926, 8.806277429843247, 9.823303036761272, 10.734859403265876, 11.724609207810975, 12.577045994837851, 13.61316095503981, 14.475084303402491, 13.495856688716033, 12.590870378909464, 11.60632296667565, 10.664891820437273, 9.614912936428878, 7.654451972222194, 6.641526537900455, 5.711912715180776, 4.819083665861264, 3.972961612940878, 4.967697607217098, 5.941351460906112, 6.903919638314635, 7.798463495000333, 8.769821389406399, 9.726806444264643, 10.709278221878288, 11.602117384169606, 12.614034355309933, 13.494663543444283, 12.552358148742643, 11.606245171731148, 10.635998588384393, 9.671012521768168, 8.62862444501634, 6.744683777917181, 5.809622110423556, 4.772455771909157, 3.8461602826424803, 3.037765929503821, 4.014256423760061, 5.0503032132907535, 5.891945638135365, 6.845764032052566, 7.774541221342627, 8.68460766171964, 9.661645235299984, 10.609046660277345, 11.571871877224986, 12.555865547047086, 11.756857513058964, 10.743240623807033, 9.719753837392267, 8.678760074993477, 7.736066484063632, 5.798834510369909, 4.840801129829983, 3.845252838598052, 2.883461195825767, 2.1003259054958816, 2.9788054439474427, 3.9866854363332376, 4.882382215394287, 5.912778427711359, 6.839438701721129, 7.712768893170949, 8.712044287763954, 9.656940682450292, 10.675886073312302, 11.725868454553378, 10.776276412143282, 9.763554376725383, 8.82106496070021, 7.834717799828957, 6.850476939169064, 4.9821246165262, 3.9307646338843356, 2.9487020632532803, 1.9576912168609204, 1.0598798593962382, 1.9484980140894739, 2.937431687492066, 3.9200530569137584, 4.887475737312682, 5.8319324909671435, 6.75728261120086, 7.6934904813406435, 8.726250077202618, 9.736791569655379, 10.799639289167985, 9.977765016887192, 8.944203424284943, 7.926822432944398, 6.881962485816299, 5.947822421569983, 4.0513698090073165, 3.0218672745651034, 1.9835453389926139, 0.9997584094614437, 0.0, 0.9989564795008261, 1.9786507562242783, 2.960664703659195, 3.9150859045754682, 4.953083555392303, 5.982789782394456, 7.047757498681136, 8.005286326251465, 9.038504549550002, 10.042614756035979, 8.986043139760568, 7.981179534445934, 6.908018733088328, 5.945913454278966, 5.020427677298513, 4.884937958538614, 3.9380646731404787, 2.952032899138555, 1.9319425078204595, 1.0237770376456115, 1.978901079434356, 2.9352022673039024, 3.930620288238023, 4.85889656778625, 5.846939377569397, 6.778097745371283, 7.798861558552135, 8.72743077601473, 9.667879132671922, 10.674252119838293, 9.748528426889, 8.763996832072449, 7.799324194316461, 6.838520743373522, 5.838680376042024, 5.903980986355391, 4.8305705792148315, 3.86939454648555, 2.9324793665020996, 1.9577133026972535, 3.0304870437305773, 3.8877452512233304, 4.8427689829344445, 5.828913372909764, 6.8119404964024906, 7.749272075108832, 8.734955425466088, 9.722263766224215, 10.725903151844689, 11.66699215789068, 10.684057290640888, 9.726238785659689, 8.777497020201068, 7.823386502895996, 6.788571838908833, 6.895531090865755, 5.849589569990335, 4.857366650486933, 3.865171078669297, 2.9253047760991384, 3.9519409000263748, 4.895371839225106, 5.878659055959478, 6.82439646612079, 7.883404560097912, 8.693855223985839, 9.650809483910692, 10.698234063566181, 11.690024191121342, 12.67504586517148, 11.685904036164754, 10.69288352061699, 9.802519380384634, 8.790028539727706, 7.811928586758624], [9.885636990719936, 10.735163938085387, 11.728506273629376, 12.627978026828428, 13.640737264824319, 12.636038949735468, 11.68530791256604, 10.678704433697717, 9.639166629957801, 8.694403174324023, 7.896705965359384, 6.870230375073232, 5.906287702432838, 4.916294803790735, 4.155750901013291, 4.865638993408594, 5.815788258763747, 6.827980217912588, 7.8765274585244605, 8.896163928918229, 10.645862820537904, 11.590946914891163, 12.569404121684345, 13.568376105816371, 14.503529510541671, 13.59908449722131, 12.538058608573238, 11.602832877018546, 10.616085870386085, 9.686556877239273, 8.74214628010055, 7.812513270699286, 6.849508560625091, 5.868232084260339, 5.082716293826027, 5.9312127521810405, 6.887901857429715, 7.771727008737901, 8.758346325778003, 9.705272714334024, 11.62704590372185, 12.591602736679976, 13.604235584376275, 14.597269978969337, 14.974895091432872, 14.056444315934757, 13.560428058693542, 12.542387713980814, 11.572561398342243, 10.619732451784175, 9.717322132852868, 8.750012716628605, 7.838934327809713, 6.890350331737006, 6.101947251073264, 6.982188376809251, 7.86984727503946, 8.742005279312917, 9.706020154029352, 10.643039265145713, 12.660039750344268, 13.553011811519124, 14.537228478338172, 14.847556471818011, 14.021945195368204, 13.032672889848815, 13.887033283677837, 13.475568060839318, 12.51939586954575, 11.573298802641768, 10.784085862390631, 9.762376421107046, 8.805839127462619, 7.93721054070465, 7.04625341258565, 7.997191195514711, 8.82351349130559, 9.76164311329514, 10.757968013254777, 11.629893337305553, 13.559147482280059, 14.590831681574056, 14.700111854614732, 13.808683299836506, 12.96231249275374, 12.028664564045188, 12.87698061047485, 13.6640588008356, 13.541040320488031, 12.60729314094701, 11.66928664365657, 10.69246817559484, 9.78181174693946, 8.863818878463189, 8.116382287259993, 8.958775431019797, 9.803726912476577, 10.723108334045593, 11.700345238583905, 12.62124687825187, 14.50619002288055, 14.602413088916563, 13.653413525672358, 12.80966992949282, 11.979943091331508, 11.095072253222286, 11.814564129059532, 12.738810160050352, 13.711723020485907, 13.58496046536901, 12.727828551748313, 11.714511751647768, 10.7831713809799, 9.905140397717275, 9.14584016404787, 9.917396859857023, 10.759455448952915, 11.771169268477564, 12.634903951107914, 13.596040277753087, 14.364890935593275, 13.588672550044393, 12.621150930820269, 11.82046650050413, 10.987999989036174, 10.044273357622286, 10.808217325244748, 11.792716213334042, 12.75087227770873, 13.707217721910366, 13.676495908970013, 12.758962565247543, 11.828482026817078, 10.898883233032068, 10.20397635857227, 10.909496669399989, 11.69228947847016, 12.705789132124126, 13.599022266817077, 14.585082565671462, 13.397684622295133, 12.577610629406076, 11.629999930500942, 10.79637340295161, 9.932333360053319, 9.05881068178028, 9.854649984420004, 10.846207430893942, 11.8507963588345, 12.690570076063304, 13.692151032962645, 13.761090528501827, 12.760576362679064, 11.967043462612416, 11.174226201109077, 11.92547714017949, 12.656221796292579, 13.588079476571103, 14.538741431862851, 14.458357164026204, 12.469084566190975, 11.588897970430173, 10.677045543383995, 9.729218405571267, 8.90094552668642, 8.076767619080638, 8.850015729224495, 9.795380756057707, 10.775823049146206, 11.72750802571395, 12.640210534489896, 13.64485795779527, 13.703241001666456, 12.961141655449705, 12.189828103658664, 12.862643231807523, 13.658837845887886, 14.590303528366434, 14.468339183364778, 13.520856444724554, 11.462592521480865, 10.614707729924161, 9.641926308205653, 8.760018398076541, 7.85027524708484, 7.064971518734382, 7.916802181305739, 8.852208389532585, 9.822010081445884, 10.757405593689818, 11.660592905255847, 12.643441975039297, 13.56044948906402, 13.91874067798117, 13.178530098820318, 13.848574609991882, 14.715040550768506, 14.475333677143272, 13.520416760000149, 12.532497518244195, 10.495961096284429, 9.545799346901424, 8.584243335956623, 7.761815633725947, 6.906314251591442, 6.109032890389634, 6.9789849775915, 7.954856582050252, 8.850032001982592, 9.815267057976017, 10.711286447291233, 11.751153311514813, 12.532492873363353, 13.479462259138737, 14.130695125414363, 14.808278200714117, 14.457448269820363, 13.51896580183753, 12.521298688463277, 11.520849302852376, 9.645849531948782, 8.57630396008493, 7.64633600433199, 6.745720236676669, 5.864072881533119, 5.037254977318884, 5.958472728858094, 6.9746675999390995, 7.807320950342421, 8.824346557260446, 9.73590292376505, 10.725652728310148, 11.578089515337025, 12.614204475538983, 13.524611723808212, 14.377952072862177, 13.58982685841029, 12.605279446176477, 11.663848299938099, 10.613869415929704, 8.65340845172302, 7.640483017401281, 6.710869194681602, 5.814422922474723, 4.836728869663688, 3.976462585798445, 4.950116439487459, 5.904963158813809, 6.799507015499508, 7.7708649099055735, 8.727849964763816, 9.710321742377461, 10.60316090466878, 11.615077875809106, 12.495707063943456, 13.434453532888787, 12.605201651231974, 11.634955067885219, 10.669969001268994, 9.627580924517167, 7.743640257418007, 6.808578589924382, 5.771412251409983, 4.845116762143306, 3.9015331862266303, 3.015299944259235, 4.051346733789927, 4.892989158634538, 5.8468075525517405, 6.775584741841801, 7.685651182218814, 8.662688755799158, 9.610090180776519, 10.57291539772416, 11.55690906754626, 12.496926743528928, 11.742197103307863, 10.718710316893093, 9.677716554494303, 8.735022963564457, 6.797790989870736, 5.8397576093308095, 4.844209318098878, 3.882417675326593, 2.964093162218691, 1.9798489644466164, 2.9877289568324112, 3.8834257358934607, 4.913821948210534, 5.840482222220302, 6.713812413670123, 7.7130878082631265, 8.657984202949466, 9.676929593811476, 10.726911975052552, 11.694164528446851, 10.76251085622621, 9.820021440201039, 8.833674279329784, 7.84943341866989, 5.981081096027026, 4.9297211133851615, 3.947658542754106, 2.9566476963617463, 1.9236471161190476, 0.9495415345886477, 1.9384752079912397, 2.921096577412932, 3.8885192578118564, 4.832976011466317, 5.758326131700033, 6.694534001839817, 7.727293597701792, 8.737835090154553, 9.800682809667158, 10.843409511760857, 9.94315990378577, 8.925778912445224, 7.880918965317125, 6.946778901070809, 5.050326288508143, 4.02082375406593, 2.98250181849344, 1.9987148889622697, 0.9989564795008261, 0.0, 0.9796942767234521, 1.9617082241583688, 2.916129425074642, 3.954127075891477, 4.98383330289363, 6.04880101918031, 7.006329846750638, 8.039548070049175, 9.053099941812203, 9.984999619261394, 8.98013601394676, 7.906975212589154, 6.944869933779792, 6.019384156799339, 5.88389443803944, 4.937021152641305, 3.950989378639381, 2.9308989873212856, 2.0068128999739567, 1.051688858185212, 1.9704753746564803, 2.9316638087371967, 3.8599400882854233, 4.847982898068571, 5.779141265870456, 6.7999050790513085, 7.728474296513903, 8.668922653171096, 9.675295640337467, 10.67025643886063, 9.762953311573275, 8.798280673817288, 7.837477222874348, 6.837636855542851, 6.902937465856217, 5.829527058715658, 4.868351025986376, 3.931435846002926, 2.940749165025599, 2.108956503560368, 2.9230183585759084, 3.878042090287023, 4.864186480262343, 5.847213603755069, 6.751223143784068, 7.735998945965261, 8.723307286723387, 9.726946672343862, 10.668035678389854, 11.605785302612519, 10.725195265160515, 9.776453499701894, 8.822342982396822, 7.7875283184096595, 7.894487570366581, 6.848546049491161, 5.856323129987759, 4.864127558170123, 3.9083406384274837, 3.1784466748194777, 3.930644946577684, 4.913932163312056, 5.859669573473369, 6.91867766745049, 7.695806292661075, 8.652760552585928, 9.700185132241417, 10.691975259796578, 11.676996933846716, 12.634764094899605, 11.691840000117816, 10.80147585988546, 9.788985019228532, 8.81088506625945], [10.865331267443388, 11.714858214808839, 12.708200550352828, 13.519736905358151, 12.661042988100865, 11.656344673012015, 10.705613635842587, 9.699010156974266, 8.65947235323435, 7.714708897600572, 6.917011688635931, 5.89053609834978, 4.9265934257093855, 3.9366005270672826, 4.883774978237174, 5.761032421025957, 6.788976128756054, 7.801168087904895, 8.849715328516767, 9.869351798910536, 11.619050690530209, 12.564134784883468, 13.54259199167665, 14.460134984346094, 13.596603433448662, 12.61939022049786, 11.558364331849786, 10.623138600295094, 9.636391593662633, 8.706862600515821, 7.762452003377097, 6.832818993975834, 5.869814283901639, 4.888537807536887, 5.81074037104991, 6.817110252387422, 7.780070623532654, 8.744914878730208, 9.731534195770308, 10.678460584326329, 12.600233773714155, 13.56479060667228, 14.57742345436858, 15.48902885749906, 14.605707194737183, 13.607728666997165, 12.58073378197009, 11.562693437257362, 10.592867121618792, 9.640038175060724, 8.737627856129414, 7.770318439905153, 6.85924005108626, 5.910656055013553, 6.829971328297147, 7.868085877015632, 8.762016041142399, 9.715193149305223, 10.679208024021658, 11.616227135138018, 13.633227620336573, 14.526199681511429, 15.510416348330477, 15.827250748541465, 14.962565254245636, 13.973292948726247, 13.067901639869064, 12.495873784115867, 11.539701592822299, 10.593604525918316, 9.804391585667178, 8.782682144383594, 7.8261448507391655, 6.957516263981198, 7.774277489809533, 8.84845069615023, 9.715682257408531, 10.65381187939808, 11.651348208613413, 12.588856048348605, 14.471005761995421, 15.502689961289416, 15.679806131338186, 14.78837757655996, 13.902932551631173, 12.96928462292262, 12.057848966666079, 12.731135554132884, 12.56134604376458, 11.62759886422356, 10.68959236693312, 9.712773898871388, 8.802117470216007, 7.884124601739737, 8.844406364483875, 9.801236720431412, 10.695895678579518, 11.615277100148534, 12.592514004686846, 13.533105157967233, 15.418048302595912, 15.582107365640017, 14.633107802395811, 13.789364206216273, 12.959637368054958, 12.035692312099718, 10.99543248525076, 11.805886913347637, 12.778799773783192, 12.605266188645558, 11.748134275024864, 10.734817474924316, 9.803477104256446, 8.925446120993824, 9.873864241271752, 10.759858149268638, 11.651624215055856, 12.663338034580505, 13.527072717210855, 14.50789855746845, 15.344585212316728, 14.568366826767846, 13.600845207543722, 12.800160777227584, 11.967694265759624, 11.007641075020517, 9.989085681435975, 10.859792966631327, 11.817949031006014, 12.734705115018338, 12.696801632246563, 11.77926828852409, 10.848787750093624, 9.919188956308616, 10.927005736608267, 11.751957958811603, 12.584458244573101, 13.597957898227067, 14.491191032920018, 15.496544969313835, 14.377378899018586, 13.557304906129529, 12.609694207224395, 11.776067679675064, 10.912027636776768, 10.022178399178511, 9.035518340611231, 9.913284184191227, 10.878283751942472, 11.718057469171276, 12.712456756239192, 12.781396251778373, 11.78088208595561, 10.987349185888965, 11.897255579145074, 12.767938429591105, 13.54839056239552, 14.480248242674044, 15.430910197965792, 15.438051440749657, 13.448778842914429, 12.568592247153626, 11.656739820107449, 10.70891268229472, 9.88063980340987, 9.054954869757324, 8.030884085415723, 8.844603952950642, 9.803310442254178, 10.754995418821922, 11.660516257766442, 12.665163681071817, 12.723546724943002, 11.981447378726253, 12.912857481694662, 13.705104521219138, 14.551006611990827, 15.482472294469375, 15.448033460088231, 14.500550721448008, 12.442286798204318, 11.594402006647615, 10.621620584929106, 9.739712674799993, 8.829969523808291, 8.044665795457833, 7.097670537496967, 7.90143158642552, 8.849497474553855, 9.78489298679779, 10.680898628532393, 11.663747698315843, 12.580755212340568, 12.939046401257718, 13.901559476856315, 14.691035899403497, 15.607209316871447, 15.455027953866725, 14.500111036723602, 13.512191794967649, 11.475655373007882, 10.525493623624877, 9.563937612680077, 8.741509910449398, 7.8860085283148935, 7.088727167113086, 6.159853333782728, 6.9751623053267995, 7.870337725259139, 8.835572781252566, 9.73159217056778, 10.77145903479136, 11.552798596639901, 12.499767982415285, 13.42496842581875, 14.3710316353379, 15.354801731773998, 14.498660078560983, 13.50099296518673, 12.50054357957583, 10.625543808672235, 9.555998236808383, 8.626030281055442, 7.72541451340012, 6.84376715825657, 6.016949254042336, 5.139341085049322, 5.994973323215647, 6.827626673618968, 7.8446522805369945, 8.756208647041596, 9.745958451586695, 10.598395238613573, 11.634510198815532, 12.54491744708476, 13.398257796138726, 14.356556257013345, 13.584973722899928, 12.64354257666155, 11.593563692653156, 9.633102728446472, 8.620177294124733, 7.690563471405055, 6.794117199198174, 5.816423146387139, 4.956156862521897, 4.130984795678686, 4.925268882090356, 5.819812738776055, 6.791170633182121, 7.748155688040365, 8.73062746565401, 9.623466627945328, 10.635383599085655, 11.516012787220005, 12.454759256165335, 13.40087223317683, 12.61464934460867, 11.649663277992445, 10.607275201240618, 8.72333453414146, 7.7882728666478345, 6.751106528133436, 5.824811038866758, 4.881227462950082, 3.994994220982687, 3.0814111589033057, 3.913294881911086, 4.867113275828288, 5.795890465118349, 6.705956905495363, 7.682994479075705, 8.630395904053067, 9.593221121000708, 10.577214790822808, 11.517232466805476, 12.549723487431086, 11.698404593616546, 10.657410831217756, 9.71471724028791, 7.777485266594188, 6.819451886054262, 5.8239035948223306, 4.8621119520500455, 3.9437874389421426, 2.9595432411700684, 2.0080346801089592, 2.9037314591700087, 3.9341276714870816, 4.860787945496851, 5.734118136946671, 6.733393531539675, 7.6782899262260145, 8.697235317088024, 9.7472176983291, 10.7144702517234, 11.7271922871413, 10.799715716924492, 9.813368556053238, 8.829127695393343, 6.960775372750478, 5.909415390108614, 4.927352819477559, 3.9363419730851987, 2.9033413928424996, 1.9292358113120998, 0.9587809312677875, 1.94140230068948, 2.9088249810884044, 3.8532817347428656, 4.778631854976582, 5.714839725116366, 6.74759932097834, 7.758140813431101, 8.820988532943707, 9.863715235037406, 10.922854180509221, 9.905473189168676, 8.860613242040579, 7.926473177794262, 6.030020565231595, 5.000518030789382, 3.9621960952168926, 2.978409165685722, 1.9786507562242783, 0.9796942767234521, 0.0, 0.9820139474349167, 1.93643514835119, 2.974432799168025, 4.0041390261701775, 5.069106742456857, 6.026635570027185, 7.059853793325722, 8.07340566508875, 9.12997728136416, 9.959830290670212, 8.886669489312606, 7.924564210503244, 6.999078433522792, 6.8635887147628925, 5.916715429364757, 4.9306836553628335, 3.910593264044738, 2.902206327591319, 1.9470822858025745, 0.9907810979330282, 1.9519695320137447, 2.880245811561972, 3.8682886213451195, 4.799446989147005, 5.820210802327857, 6.748780019790451, 7.689228376447645, 8.695601363614015, 9.690562162137178, 10.675093756953729, 9.77797495054074, 8.8171714995978, 7.817331132266303, 7.881917135642725, 6.808506728502166, 5.847330695772884, 4.910415515789434, 3.836142592642961, 2.997657294664031, 1.943324081852456, 2.8983478135635705, 3.8844922035388905, 4.8675193270316175, 5.771528867060616, 6.75630466924181, 7.743613009999935, 8.74725239562041, 9.688341401666403, 10.626091025889068, 11.616954143690238, 10.756147776425346, 9.802037259120274, 8.767222595133111, 8.87346724015309, 7.827525719277669, 6.829510999980066, 5.83731542816243, 4.803734066044846, 3.9064707520433606, 2.9509506698542314, 3.934237886588604, 4.879975296749916, 5.938983390727039, 6.7161120159376235, 7.6730662758624755, 8.720490855517964, 9.712280983073125, 10.697302657123263, 11.655069818176154, 12.583598878647539, 11.781170136608912, 10.768679295951983, 9.790579342982902], [11.847345214878306, 12.696872162243757, 13.497515111464805, 12.537722957923235, 11.67902904066595, 10.6743307255771, 9.72359968840767, 8.71699620953935, 7.677458405799433, 6.732694950165656, 5.947476942485359, 4.921001352199207, 4.115482335257596, 4.918614474502199, 5.86578892567209, 6.743046368460874, 7.77099007619097, 8.783182035339811, 9.831729275951684, 10.851365746345452, 12.601064637965127, 13.546148732318386, 14.524605939111568, 13.478121036911178, 12.614589486013745, 11.637376273062943, 10.57635038441487, 9.641124652860178, 8.654377646227717, 7.724848653080905, 6.792917257226525, 5.863284247825261, 5.18104953563758, 5.870551754971803, 6.7927543184848265, 7.799124199822338, 8.762084570967572, 9.726928826165125, 10.713548143205227, 11.660474531761247, 13.582247721149074, 14.546804554107199, 15.504880266922036, 14.507014910064143, 13.623693247302267, 12.625714719562248, 11.598719834535174, 10.580679489822446, 9.610853174183875, 8.658024227625807, 7.768093109978841, 6.80078369375458, 6.202609451294614, 6.89267000244847, 7.811985275732064, 8.850099824450549, 9.744029988577315, 10.69720709674014, 11.661221971456575, 12.598241082572937, 14.615241567771491, 15.508213628946347, 16.419336698428502, 15.46952553405643, 14.565320622322595, 13.496564139310502, 12.512944636200725, 11.51385983668095, 10.557687645387382, 9.6115905784834, 8.834856839516604, 7.8131473982330215, 7.169514250947519, 7.939530211416114, 8.75629143724445, 9.830464643585149, 10.697696204843446, 11.635825826832995, 12.633362156048328, 13.57086999578352, 15.453019709430336, 16.48470390872433, 16.661820078773104, 15.681791546347517, 14.717584679884238, 13.783936751175686, 12.794885105900665, 11.852149192277844, 11.579332096329663, 10.645584916788643, 9.720057620782544, 8.743239152720815, 8.145486870424362, 8.866138549174654, 9.826420311918792, 10.783250667866328, 11.677909626014433, 12.597291047583449, 13.57452795212176, 14.515119105402148, 16.400062250030828, 16.564121313074935, 15.615121749830728, 14.771378153651188, 13.833480267115274, 12.895873207400077, 11.85561338055112, 10.926900551492597, 11.830859762237598, 11.623252241210642, 10.778599528874288, 9.765282728773743, 9.1468465044648, 9.90746006842874, 10.855878188706669, 11.741872096703554, 12.63363816249077, 13.64535198201542, 14.50908666464577, 15.489912504903364, 16.326599159751645, 15.550380774202763, 14.582859154978639, 13.782174724662498, 12.883811802970985, 11.867821970320877, 10.849266576736335, 9.980806604776287, 10.848008730183903, 11.762614203031504, 11.727266886095988, 10.815838743232067, 10.192157150301979, 10.901202903743533, 11.909019684043184, 12.73397190624652, 13.566472192008016, 14.579971845661982, 15.473204980354932, 16.47855891674875, 15.359392846453504, 14.539318853564446, 13.591708154659312, 12.758081627109979, 11.850098583205844, 10.88235929447887, 9.895699235911591, 9.034297822336187, 9.906192839955638, 10.745966557184442, 11.740365844252356, 11.847641691236458, 11.124251486163965, 11.969363133323881, 12.879269526579991, 13.749952377026021, 14.530404509830435, 15.462262190108959, 16.41292414540071, 16.420065388184575, 14.430792790349347, 13.550606194588543, 12.638753767542365, 11.690926629729635, 10.862653750844789, 9.915135765057684, 8.891064980716083, 7.965617591095603, 8.831219530267344, 9.782904506835088, 10.688425345779606, 11.693072769084981, 12.066916125151359, 12.96346132616117, 13.894871429129578, 14.687118468654054, 15.533020559425742, 16.46448624190429, 16.430047407523148, 15.482564668882926, 13.424300745639234, 12.576415954082531, 11.603634532364023, 10.72172662223491, 9.81198347124321, 9.007316657413305, 7.9578514327973275, 7.022445224570482, 7.87740656256702, 8.812802074810955, 9.708807716545557, 10.691656786329007, 11.608664300353732, 12.542217145123294, 13.40504254042596, 14.358644314073299, 15.401855770494326, 16.391807741277052, 15.48212498415852, 14.494205742402565, 12.457669320442799, 11.507507571059794, 10.545951560114993, 9.723523857884315, 8.868022475749811, 8.051378029068559, 7.105733403304688, 6.096175943471761, 6.898246813272305, 7.863481869265732, 8.759501258580944, 9.799368122804523, 10.580707684653065, 11.52767707042845, 12.452877513831915, 13.398940723351064, 14.382710819787162, 15.321193287769995, 14.483006912621647, 13.482557527010746, 11.607557756107152, 10.5380121842433, 9.608044228490359, 8.707428460835036, 7.825781105691487, 6.9989632014772525, 6.085221154571283, 5.115986961360608, 5.855535761632134, 6.87256136855016, 7.784117735054761, 8.773867539599859, 9.626304326626737, 10.662419286828696, 11.572826535097924, 12.42616688415189, 13.38446534502651, 14.369012757260323, 13.625556524096467, 12.575577640088072, 10.615116675881389, 9.60219124155965, 8.672577418839971, 7.776131146633091, 6.798437093822056, 5.938170809956814, 5.076864865200648, 4.046282520235318, 4.847721826789221, 5.819079721195287, 6.776064776053529, 7.758536553667175, 8.651375715958492, 9.663292687098819, 10.543921875233169, 11.4826683441785, 12.428781321189994, 13.39902790453675, 12.631677225427362, 11.589289148675535, 9.705348481576376, 8.770286814082752, 7.733120475568352, 6.806824986301675, 5.863241410384999, 4.977008168417604, 4.027291228425267, 3.0343085200560473, 3.895022363841454, 4.823799553131514, 5.733865993508528, 6.71090356708887, 7.658304992066231, 8.621130209013872, 9.605123878835972, 10.54514155481864, 11.57763257544425, 12.642878797603727, 11.639424778652673, 10.696731187722827, 8.759499214029105, 7.801465833489178, 6.805917542257247, 5.844125899484962, 4.92580138637706, 3.9415571886049854, 2.9900486275438762, 2.02474509731497, 2.962036759500247, 3.8886970335100157, 4.762027224959836, 5.76130261955284, 6.7061990142391785, 7.7251444051011875, 8.775126786342264, 9.742379339736564, 10.755101375154464, 11.697590791179636, 10.795382503488153, 9.811141642828261, 7.942789320185395, 6.8914293375435305, 5.909366766912475, 4.918355920520115, 3.8853553402774166, 2.9112497587470165, 1.9407948787027043, 1.0624159388344414, 1.93673406910157, 2.881190822756031, 3.806540942989747, 4.742748813129531, 5.775508408991504, 6.786049901444265, 7.84889762095687, 8.89162432305057, 9.964076826489354, 10.887487136603594, 9.842627189475495, 8.908487125229179, 7.012034512666512, 5.982531978224299, 4.944210042651809, 3.9604231131206387, 2.960664703659195, 1.9617082241583688, 0.9820139474349167, 0.0, 0.9544212009162731, 1.992418851733108, 3.022125078735261, 4.087092795021941, 5.044621622592269, 6.077839845890805, 7.091391717653834, 8.147963333929244, 9.15282693924388, 9.868683436747524, 8.906578157938162, 7.981092380957708, 7.845602662197809, 6.898729376799674, 5.91269760279775, 4.892607211479654, 3.8842202750262356, 2.929096233237491, 1.9727950453679448, 0.9699555845788281, 1.8982318641270548, 2.8862746739102025, 3.8174330417120883, 4.83819685489294, 5.7667660723555345, 6.707214429012728, 7.713587416179099, 8.708548214702262, 9.693079809518812, 10.657752447274799, 9.799185447032718, 8.79934507970122, 8.863931083077642, 7.790520675937082, 6.829344643207801, 5.89242946322435, 4.818156540077878, 3.9796712420989477, 2.9253380292873725, 2.034977817436814, 2.913942399255894, 3.8969695227486207, 4.7895149196257, 5.774290721806893, 6.761599062565018, 7.765238448185493, 8.706327454231486, 9.644077078454151, 10.634940196255322, 11.635925273159405, 10.784051206555192, 9.74923654256803, 9.855481187588005, 8.809539666712585, 7.811524947414982, 6.819329375597347, 5.785748013479763, 4.888484699478277, 3.932964617289148, 3.070867890461847, 3.9094254924669203, 4.968433586444043, 5.734098068502707, 6.691052328427559, 7.738476908083048, 8.730267035638208, 9.715288709688348, 10.673055870741237, 11.601584931212622, 12.603998539579269, 11.750693243386902, 10.77259329041782], [12.801766415794578, 13.536436246092519, 12.54309391054853, 11.583301757006959, 10.724607839749675, 9.719909524660824, 8.769178487491397, 7.7625750086230765, 6.723037204883159, 5.778273749249382, 4.993055741569085, 3.966580151282934, 4.9305228239233285, 5.873035675418473, 6.820210126588364, 7.697467569377148, 8.725411277107245, 9.737603236256085, 10.786150476867958, 11.805786947261726, 13.555485838881399, 14.500569933234658, 13.573900221557372, 12.523699835994902, 11.660168285097471, 10.682955072146669, 9.621929183498596, 8.686703451943904, 7.699956445311443, 6.770427452164631, 5.838496056310252, 4.908863046908988, 5.947587064881714, 6.824972955888077, 7.7471755194011, 8.753545400738611, 9.716505771883844, 10.681350027081399, 11.667969344121499, 12.61489573267752, 14.536668922065346, 15.501225755023471, 14.550459066005761, 13.552593709147867, 12.669272046385993, 11.671293518645975, 10.6442986336189, 9.626258288906172, 8.656431973267601, 7.7036030267095335, 6.813671909062568, 5.846362492838307, 6.903798471066433, 7.8470912033647435, 8.766406476648338, 9.804521025366821, 10.698451189493587, 11.651628297656414, 12.615643172372849, 13.552662283489209, 15.569662768687763, 16.449132164331278, 15.464915497512228, 14.515104333140155, 13.610899421406321, 12.542142938394228, 11.558523435284451, 10.559438635764677, 9.603266444471108, 8.657169377567126, 7.88043563860033, 6.858726197316749, 7.8223572459801405, 8.867465814765653, 9.710712638160725, 10.784885844501424, 11.652117405759718, 12.590247027749268, 13.5877833569646, 14.525291196699792, 16.407440910346608, 17.3828007779232, 16.414958203868874, 15.419735879589624, 14.455529013126345, 13.521881084417792, 12.532829439142771, 11.59009352551995, 10.62491089541339, 9.691163715872369, 8.765636419866272, 7.788817951804543, 8.781786006182207, 9.794074152524193, 10.780841512835067, 11.737671868782604, 12.632330826930705, 13.55171224849972, 14.528949153038033, 15.46954030631842, 17.3544834509471, 17.518542513991207, 16.569542950747, 15.698422121571465, 14.68261490487299, 13.745007845157794, 12.704748018308836, 11.776035189250312, 10.876438561321326, 10.668831040294368, 9.824178327958016, 8.81086152785747, 9.783145640222646, 10.754556840936802, 11.810299389622944, 12.69629329761983, 13.588059363407043, 14.599773182931692, 15.463507865562041, 16.444333705819638, 17.281020360667917, 16.504801975119037, 15.537280355894913, 14.709218692582773, 13.732946440728702, 12.716956608078593, 11.698401214494051, 10.829941242534002, 9.89358752926763, 10.80819300211523, 10.772845685179716, 9.861417542315795, 10.791898080746261, 11.748299676251595, 12.756116456551245, 13.688393107162796, 14.520893392924288, 15.534393046578254, 16.427626181271204, 17.43298011766502, 16.313814047369775, 15.49374005448072, 14.546129355575586, 13.712502828026254, 12.69923322096356, 11.731493932236587, 10.744833873669307, 9.883432460093902, 8.951771639039366, 9.791545356268168, 10.785944643336085, 10.893220490320186, 11.723992416608247, 12.790074225266162, 13.726366299088053, 14.668459814384406, 15.484825710746707, 16.41668339102523, 17.36734534631698, 17.374486589100844, 15.38521399126562, 14.505027395504817, 13.593174968458639, 12.64534783064591, 11.782974035961601, 10.764270402815402, 9.740199618473799, 8.814752228853317, 7.876798329351072, 8.828483305918814, 9.734004144863336, 10.738651568168711, 11.667579323967162, 12.545394966738485, 13.43932333467134, 14.377062739990123, 15.381711265077644, 16.32514200522169, 17.34022588086853, 16.436985869799198, 14.378721946555508, 13.530837154998805, 12.558055733280296, 11.676147823151185, 10.766404672159481, 9.881571106682335, 8.806986070555043, 7.871579862328196, 6.922985361650748, 7.858380873894682, 8.754386515629287, 9.737235585412737, 10.654243099437458, 11.58779594420702, 12.450621339509686, 13.404223113157027, 14.447434569578053, 15.437386540360782, 16.392303457503903, 15.448626943318839, 13.412090521359072, 12.461928771976067, 11.500372761031267, 10.67794505880059, 9.822443676666085, 8.93869763881834, 7.993053013054469, 6.945310581229475, 5.943825612356033, 6.909060668349458, 7.805080057664672, 8.844946921888251, 9.626286483736791, 10.573255869512176, 11.498456312915641, 12.444519522434792, 13.42828961887089, 14.366772086853723, 15.364439200227975, 14.43697872792702, 12.561978957023426, 11.492433385159574, 10.562465429406632, 9.661849661751312, 8.78020230660776, 7.94195089022818, 6.972540764321064, 5.965121599118323, 4.901114560715861, 5.9181401676338865, 6.829696534138489, 7.819446338683588, 8.671883125710464, 9.707998085912422, 10.618405334181652, 11.471745683235618, 12.430044144110237, 13.414591556344051, 14.438172327748063, 13.529998841004346, 11.569537876797662, 10.556612442475924, 9.626998619756245, 8.730552347549365, 7.7528582947383295, 6.892592010873087, 5.964184474950428, 4.930453684125833, 3.893300625872948, 4.864658520279014, 5.821643575137257, 6.804115352750902, 7.6969545150422185, 8.708871486182545, 9.589500674316897, 10.528247143262227, 11.474360120273722, 12.444606703620478, 13.409592770236703, 12.543710349591809, 10.659769682492652, 9.724708014999026, 8.687541676484626, 7.761246187217948, 6.817662611301272, 5.931429369333877, 4.914610838175047, 3.9216281298058275, 2.940601162925181, 3.869378352215241, 4.779444792592255, 5.756482366172597, 6.703883791149958, 7.666709008097599, 8.6507026779197, 9.590720353902368, 10.623211374527978, 11.688457596687455, 12.593845979568949, 11.651152388639103, 9.71392041494538, 8.755887034405452, 7.76033874317352, 6.798547100401235, 5.880222587293333, 4.895978389521258, 3.944469828460149, 2.91206470706475, 2.007615558583974, 2.934275832593743, 3.8076060240435634, 4.806881418636567, 5.7517778133229065, 6.7707232041849155, 7.8207055854259915, 8.78795813882029, 9.80068017423819, 10.743169590263362, 11.729516751134616, 10.765562843744533, 8.897210521101668, 7.845850538459803, 6.863787967828748, 5.872777121436388, 4.8397765411936895, 3.8656709596632894, 2.8952160796189776, 1.9497355485842212, 0.9823128681852968, 1.9267696218397579, 2.852119742073474, 3.7883276122132576, 4.821087208075232, 5.831628700527993, 6.894476420040598, 7.937203122134297, 9.00965562557308, 10.054981036694253, 10.797048390391767, 9.862908326145451, 7.966455713582785, 6.936953179140572, 5.898631243568082, 4.914844314036912, 3.9150859045754682, 2.916129425074642, 1.93643514835119, 0.9544212009162731, 0.0, 1.037997650816835, 2.067703877818988, 3.132671594105668, 4.090200421675996, 5.1234186449745325, 6.136970516737561, 7.193542133012971, 8.198405738327606, 9.271566539685212, 9.860999358854434, 8.93551358187398, 8.800023863114081, 7.8531505777159465, 6.867118803714023, 5.847028412395927, 4.838641475942509, 3.8835174341537644, 2.927216246284218, 1.9243767854951013, 0.9438106632107817, 1.9318534729939292, 2.8630118407958145, 3.8837756539766666, 4.812344871439261, 5.752793228096454, 6.759166215262825, 7.754127013785987, 8.738658608602536, 9.703331246358523, 10.664134697301463, 9.753766280617493, 9.818352283993914, 8.744941876853355, 7.7837658441240745, 6.846850664140624, 5.772577740994151, 4.9340924430152215, 3.879759230203646, 2.945665588314941, 1.959521198339621, 2.942548321832348, 3.835093718709426, 4.819869520890619, 5.807177861648745, 6.810817247269219, 7.751906253315212, 8.689655877537875, 9.680518995339046, 10.68150407224313, 11.723593825917417, 10.703657743484301, 10.809902388504279, 9.763960867628859, 8.765946148331256, 7.773750576513621, 6.740169214396037, 5.842905900394551, 4.887385818205422, 3.913915840709516, 2.955004291550647, 4.014012385527769, 4.779676867586433, 5.736631127511285, 6.784055707166774, 7.775845834721935, 8.760867508772073, 9.718634669824961, 10.647163730296347, 11.649577338662993, 12.662068179319922, 11.727014491334092], [13.585692846904893, 12.636048333785343, 11.642705998241354, 10.682913844699783, 9.824219927442499, 8.819521612353649, 7.86879057518422, 6.8621870963159, 5.822649292575982, 4.877885836942205, 4.178681514879512, 5.004577802099769, 5.9685204747401635, 6.911033326235307, 7.858207777405198, 8.735465220193982, 9.763408927924079, 10.775600887072919, 11.824148127684792, 12.84378459807856, 14.557168312818758, 13.6120842184655, 12.673512309250196, 11.623311923687726, 10.759780372790294, 9.782567159839491, 8.721541271191418, 7.7863155396367265, 6.799568533004266, 5.870039539857454, 5.216817785844269, 5.946860697725823, 6.985584715698549, 7.862970606704911, 8.785173170217934, 9.791543051555445, 10.754503422700678, 11.719347677898233, 12.705966994938333, 13.652893383494353, 15.57466657288218, 14.612740040254312, 13.650071153698585, 12.652205796840692, 11.768884134078816, 10.770905606338797, 9.743910721311725, 8.725870376598996, 7.756044060960424, 6.803215114402357, 6.191993638596585, 6.884360143655142, 7.941796121883268, 8.885088854181578, 9.804404127465173, 10.842518676183655, 11.736448840310421, 12.689625948473248, 13.653640823189683, 14.590659934306043, 16.587152404722076, 15.5487442520241, 14.564527585205052, 13.614716420832979, 12.710511509099144, 11.64175502608705, 10.658135522977274, 9.659050723457499, 8.70287853216393, 7.756781465259949, 7.258757368134347, 7.8967238481335835, 8.860354896796975, 9.90546346558249, 10.74871028897756, 11.822883495318258, 12.690115056576552, 13.628244678566102, 14.625781007781434, 15.563288847516626, 17.445438561163442, 16.482412865616023, 15.514570291561698, 14.519347967282446, 13.555141100819167, 12.621493172110615, 11.632441526835594, 10.689705613212773, 9.724522983106212, 8.790775803565193, 8.199984846335434, 8.826815602621377, 9.819783656999041, 10.832071803341028, 11.818839163651901, 12.775669519599438, 13.670328477747539, 14.589709899316555, 15.566946803854867, 16.507537957135252, 18.392481101763934, 17.481922365668197, 16.546286539124807, 15.518361337626132, 14.492692542648713, 13.555085482933517, 12.64826940093165, 11.61495425399802, 10.73474165200832, 9.768443127987192, 9.258526754427178, 9.848859178674305, 10.82114329103948, 11.792554491753636, 12.848297040439778, 13.734290948436664, 14.626057014223877, 15.637770833748526, 16.501505516378877, 17.482331356636468, 18.31901801148475, 17.542799625935867, 16.57527800671175, 15.670388310705622, 14.694116058851549, 13.67812622620144, 12.659570832616899, 11.791110860656849, 10.854757147390478, 10.029492045914326, 10.207194111648878, 10.89941519313263, 11.829895731563095, 12.786297327068429, 13.79411410736808, 14.72639075797963, 15.558891043741122, 16.572390697395086, 17.465623832088042, 18.47097776848186, 17.35181169818661, 16.53173770529755, 15.58412700639242, 14.681159879614384, 13.660402839086407, 12.692663550359434, 11.706003491792154, 10.844602078216749, 9.912941257162213, 9.012844400067264, 9.858200754150012, 10.762075167859539, 11.68250007376848, 12.6117492703897, 13.527181348034853, 14.386484942432082, 15.333809532330742, 16.265667212609266, 17.29092273261763, 18.28217904436108, 16.423211642082453, 15.54302504632165, 14.631172619275473, 13.683345481462744, 12.744143654084446, 11.725440020938247, 10.701369236596646, 9.775921846976164, 8.837967947473919, 8.04978234971791, 8.806260255677262, 9.810907678982637, 10.739835434781089, 11.617651077552411, 12.511579445485266, 13.44931885080405, 14.45396737589157, 15.397398116035614, 16.41248199168246, 17.471812735306568, 15.416719597372342, 14.568834805815639, 13.59605338409713, 12.714145473968019, 11.804402322976316, 10.842740724805182, 9.76815568867789, 8.832749480451044, 7.884154979773595, 7.0796799176937775, 7.826642626443213, 8.809491696226663, 9.726499210251385, 10.660052055020946, 11.522877450323612, 12.476479223970953, 13.519690680391982, 14.509642651174708, 15.464559568317831, 16.448792912044624, 14.450088172175906, 13.499926422792901, 12.538370411848101, 11.715942709617424, 10.860441327482919, 9.899867256941187, 8.954222631177316, 7.906480199352323, 6.90499523047888, 6.056846243034892, 6.877336168478599, 7.9172030327021785, 8.698542594550718, 9.645511980326102, 10.570712423729567, 11.516775633248718, 12.500545729684816, 13.43902819766765, 14.436695311041902, 15.437144696652803, 13.59997660784026, 12.530431035976408, 11.600463080223467, 10.699847312568146, 9.818199957424595, 8.903120508351027, 7.933710382443911, 6.926291217241171, 5.862284178838709, 5.065925742319321, 5.901952644952416, 6.891702449497514, 7.74413923652439, 8.78025419672635, 9.690661444995579, 10.544001794049544, 11.502300254924164, 12.486847667157978, 13.51042843856199, 14.510525449214994, 12.607535527614496, 11.594610093292758, 10.664996270573079, 9.768549998366199, 8.790855945555164, 7.8729898873677975, 6.925354093073276, 5.89162330224868, 4.854470243995796, 4.012444094964447, 4.893899685951183, 5.876371463564829, 6.769210625856146, 7.781127596996472, 8.661756785130823, 9.600503254076154, 10.546616231087649, 11.516862814434404, 12.48184888105063, 13.524236957802456, 11.697767333309486, 10.76270566581586, 9.72553932730146, 8.799243838034783, 7.855660262118107, 6.911827245828587, 5.875780456297895, 4.8827977479286755, 3.901770781048029, 2.9416344630291666, 3.851700903406181, 4.8287384769865245, 5.7761399019638855, 6.738965118911526, 7.722958788733626, 8.662976464716294, 9.695467485341904, 10.760713707501381, 11.77102847540413, 12.689150039455937, 10.751918065762213, 9.793884685222286, 8.798336393990354, 7.83654475121807, 6.918220238110168, 5.933976040338093, 4.917588937135299, 3.873234325187598, 2.968785176706822, 2.0065319434076687, 2.8798621348574898, 3.8791375294504937, 4.824033924136832, 5.842979314998841, 6.892961696239917, 7.860214249634216, 8.872936285052116, 9.815425701077288, 10.801772861948542, 11.803560494561367, 9.935208171918502, 8.883848189276637, 7.901785618645583, 6.910774772253223, 5.877774192010524, 4.903668610480125, 3.8935265361287614, 2.910905166707069, 1.9434824863081448, 0.9990257326536839, 1.9243758528874002, 2.860583723027184, 3.893343318889158, 4.90388481134192, 5.966732530854524, 7.009459232948223, 8.081911736387006, 9.127237147508179, 10.188587654174938, 10.900905976962285, 9.00445336439962, 7.974950829957407, 6.936628894384917, 5.9528419648537465, 4.953083555392303, 3.954127075891477, 2.974432799168025, 1.992418851733108, 1.037997650816835, 0.0, 1.0297062270021529, 2.094673943288833, 3.052202770859161, 4.0854209941576975, 5.098972865920726, 6.155544482196136, 7.160408087510771, 8.233568888868378, 9.19567416767774, 9.973511232690816, 9.838021513930917, 8.891148228532781, 7.905116454530858, 6.885026063212762, 5.876639126759343, 4.921515084970599, 3.965213897101053, 2.9623744363119364, 1.9818083140276166, 1.0314655606867522, 1.9626239284886378, 2.98338774166949, 3.9119569591320844, 4.8524053157892775, 5.858778302955648, 6.85373910147881, 7.83827069629536, 8.802943334051347, 9.763746784994288, 10.763587152325785, 10.856349934810748, 9.78293952767019, 8.821763494940909, 7.884848314957458, 6.8105753918109855, 5.972090093832056, 4.91775688102048, 3.9836632391317757, 2.9975188491564557, 2.0733181750220337, 2.934705806402249, 3.919481608583443, 4.906789949341569, 5.910429334962043, 6.851518341008035, 7.7892679652306995, 8.78013108303187, 9.781116159935953, 10.823205913610241, 11.713478615192594, 11.847900039321113, 10.801958518445693, 9.80394379914809, 8.811748227330455, 7.778166865212871, 6.880903551211385, 5.925383469022256, 4.951913491526351, 3.993001942367482, 3.1447822387174553, 3.8792889552792564, 4.836243215204108, 5.883667794859598, 6.875457922414758, 7.860479596464897, 8.818246757517786, 9.746775817989171, 10.749189426355818, 11.761680267012746, 12.736835363042385], [12.632718547932813, 11.683074034813263, 10.689731699269274, 9.729939545727703, 8.871245628470419, 7.866547313381568, 6.915816276212139, 5.909212797343819, 4.869674993603901, 3.9249115379701243, 4.912477374907374, 5.909149162572549, 6.873091835212944, 7.836534776530498, 8.78370922770039, 9.741235210140497, 10.769178917870594, 11.781370877019434, 12.829918117631307, 13.672530294223067, 13.604194013846678, 12.65910991949342, 11.720538010278116, 10.670337624715646, 9.806806073818214, 8.829592860867411, 7.768566972219338, 6.833341240664646, 5.846594234032185, 4.917065240885373, 5.871170498894153, 6.800803508295417, 7.839527526268142, 8.788472057000103, 9.710674620513126, 10.717044501850637, 11.68000487299587, 12.724986366053376, 13.711605683093477, 14.544784120050558, 14.621915277109373, 13.659765741282232, 12.697096854726505, 11.699231497868611, 10.815909835106735, 9.817931307366717, 8.790936422339644, 7.772896077626915, 6.803069761988343, 5.850240815430276, 6.846346351646469, 7.738302954224736, 8.795738932452862, 9.74432292852557, 10.717322818392336, 11.768020126478847, 12.661950290605613, 13.69526463662839, 14.659279511344826, 15.482550670862247, 15.634178105749998, 14.59576995305202, 13.611553286232972, 12.661742121860899, 11.757537210127063, 10.68878072711497, 9.705161224005193, 8.706076424485419, 7.749904233191851, 6.803807166287868, 7.849681177169764, 8.750666658703176, 9.714297707366567, 10.759406276152081, 11.661628979904723, 12.735802186245422, 13.615616506871746, 14.553746128861295, 15.551282458076628, 16.469404743022086, 16.56112276593794, 15.529438566643945, 14.561595992589618, 13.566373668310366, 12.602166801847087, 11.668518873138535, 10.679467227863514, 9.736731314240693, 8.771548684134132, 7.837801504593112, 8.79090865537085, 9.68075841319097, 10.673726467568635, 11.68601461391062, 12.731757854579065, 13.688588210526602, 14.595829928042733, 15.515211349611748, 16.492448254150062, 17.43303940743045, 17.484154068192847, 16.528948066696117, 15.593312240152727, 14.565387038654052, 13.539718243676633, 12.602111183961437, 11.69529510195957, 10.66197995502594, 9.78176735303624, 8.81546882901511, 9.750058817872905, 10.702801989243898, 11.675086101609073, 12.64649730232323, 13.712827313737844, 14.647209639363828, 15.55155846451907, 16.56327228404372, 17.42700696667407, 18.407832806931665, 18.477356156316212, 17.542688605568287, 16.571629805893494, 15.507933597826039, 14.531661345971967, 13.652910079561437, 12.623375222374207, 11.60807390174225, 10.764618385089936, 9.751248855976554, 9.90919568239659, 10.80715450198829, 11.627870795754827, 12.67370846183674, 13.51070757669602, 14.415741799335944, 15.311018236277521, 16.224165147451515, 17.18962578188511, 18.194979718278926, 18.27219690862664, 17.452122915737583, 16.50451221683245, 15.545136506206177, 14.5243794656782, 13.556640176951227, 12.569980118383947, 11.708578704808541, 10.693603556751354, 9.726401087208814, 8.871477140274374, 9.7753515539839, 10.69577645989284, 11.62502565651406, 12.540457734159213, 13.399761328556442, 14.347085918455102, 15.278943598733626, 16.30419911874199, 17.29545543048544, 17.343596852522484, 16.463410256761684, 15.551557829715504, 14.585753603990337, 13.60812028067624, 12.58941664753004, 11.565345863188439, 10.639898473567957, 9.682445084779584, 8.76333903685946, 7.819536641801624, 8.824184065106998, 9.753111820905449, 10.630927463676771, 11.524855831609626, 12.46259523692841, 13.467243762015931, 14.410674502159974, 15.42575837780682, 16.48508912143093, 16.337104807812374, 15.48922001625567, 14.516438594537162, 13.616553596495612, 12.702903608341995, 11.706717351396975, 10.632132315269683, 9.696726107042837, 8.728632117079261, 7.793236604835327, 6.839919012567574, 7.822768082351024, 8.739775596375745, 9.673328441145307, 10.536153836447973, 11.489755610095314, 12.532967066516342, 13.522919037299069, 14.477835954442192, 15.462069298168982, 15.370473382615938, 14.420311633232933, 13.458755622288132, 12.618350832145017, 11.762849450010513, 10.763843883532981, 9.81819925776911, 8.770456825944116, 7.768971857070673, 6.902443748116328, 5.890612554602959, 6.930479418826539, 7.711818980675078, 8.658788366450462, 9.583988809853928, 10.530052019373079, 11.513822115809177, 12.45230458379201, 13.449971697166262, 14.450421082777163, 14.51888660687968, 13.450816246416439, 12.520848290663498, 11.602255435095739, 10.72060807995219, 9.767097134942823, 8.797687009035705, 7.790267843832964, 6.726260805430502, 5.911523247400757, 4.915229031076776, 5.904978835621875, 6.75741562264875, 7.7935305828507095, 8.703937831119939, 9.557278180173904, 10.515576641048524, 11.500124053282338, 12.52370482468635, 13.523801835339354, 13.511685816720963, 12.514995303732789, 11.58538148101311, 10.670958120893793, 9.693264068082758, 8.73696651395959, 7.789330719665069, 6.755599928840473, 5.718446870587589, 4.876420721556241, 3.9071760720755435, 4.889647849689189, 5.782487011980506, 6.794403983120833, 7.675033171255183, 8.613779640200514, 9.55989261721201, 10.530139200558764, 11.49512526717499, 12.537513343926816, 12.618152543749517, 11.683090876255891, 10.645924537741491, 9.719629048474813, 8.758068384645702, 7.775803872420381, 6.739757082889689, 5.746774374520469, 4.765747407639822, 3.8056110896209603, 2.864977289530542, 3.842014863110885, 4.789416288088246, 5.752241505035887, 6.7362351748579865, 7.676252850840655, 8.708743871466265, 9.773990093625741, 10.784304861528492, 11.726998452458337, 11.672303276202245, 10.714269895662317, 9.718721604430385, 8.7569299616581, 7.8206283606377625, 6.834429167896756, 5.781565563727093, 4.737210951779391, 3.8327618032986153, 2.870508569999462, 1.8931385209818505, 2.8924139155748545, 3.8373103102611927, 4.856255701123202, 5.906238082364278, 6.873490635758578, 7.886212671176478, 8.82870208720165, 9.815049248072905, 10.864296406334624, 10.871935691405277, 9.804233399716669, 8.822170829085614, 7.831159982693253, 6.780182314538119, 5.806076733007719, 4.757503162720555, 3.7748817932988623, 2.807459112899938, 1.8630023592454772, 0.937652239011761, 1.8738601091515448, 2.9066197050135187, 3.91716119746628, 4.980008916978885, 6.022735619072583, 7.093725750347629, 8.139051161468803, 9.180277410850925, 10.023014947422825, 10.034159591401773, 9.004657056959559, 7.96633512138707, 6.9825481918559, 5.982789782394456, 4.98383330289363, 4.0041390261701775, 3.022125078735261, 2.067703877818988, 1.0297062270021529, 0.0, 1.0649677162866802, 2.022496543857008, 3.055714767155545, 4.069266638918574, 5.125838255193984, 6.130701860508619, 7.203862661866225, 8.165967940675587, 9.09145371765604, 10.764355270857115, 9.920854455534933, 8.93482268153301, 7.914732290214915, 6.882409116705859, 5.927285074917115, 4.970983887047568, 3.954508639642574, 2.92885080710159, 1.9408079973184427, 1.0096496295165571, 2.030413442697409, 2.9589826601600038, 3.899431016817197, 4.905804003983568, 5.90076480250673, 6.8852963973232795, 7.849969035079266, 8.810772486022206, 9.810612853353703, 11.724693684109232, 10.788709517616706, 9.827533484887425, 8.890618304903974, 7.816345381757501, 6.897591544127247, 5.843258331315671, 4.888234599604557, 3.902090209629237, 2.9190630861365103, 1.9817315074301687, 2.9665073096113623, 3.9538156503694877, 4.9574550359899625, 5.8985440420359545, 6.836293666258619, 7.82715678405979, 8.828141860963873, 9.870231614638161, 10.760504316220512, 12.752446678784082, 11.80772850839221, 10.809713789094605, 9.81751821727697, 8.783936855159386, 7.806405001506576, 6.850884919317447, 5.856484851999132, 4.897573302840263, 3.9658621595153245, 2.926314656307176, 3.8832689162320277, 4.930693495887517, 5.922483623442677, 6.907505297492816, 7.8652724585457054, 8.79380151901709, 9.796215127383737, 10.808705968040666, 11.783861064070303], [11.671962616035668, 10.722318102916118, 9.728975767372129, 8.769183613830558, 7.917938109049081, 6.922061734215132, 6.003550106230467, 4.996946627362146, 3.9574088236222287, 4.926553887838156, 5.914119724775405, 6.940595315061557, 7.904537987701952, 8.894530886344054, 9.84867694398707, 10.80620292642718, 11.834146634157277, 12.846338593306118, 13.73141083271969, 12.711774362325922, 12.643438081949533, 11.698353987596274, 10.75978207838097, 9.709581692818501, 8.894539903836542, 7.917326690885739, 6.856300802237666, 5.921075070682974, 4.934328064050513, 5.918707590753405, 6.872812848762185, 7.802445858163448, 8.841169876136174, 9.822446352500926, 10.775642336799805, 11.782012218137316, 12.744972589282549, 13.789954082340053, 14.530954576709433, 13.584028188153413, 13.661159345212228, 12.699009809385087, 11.73634092282936, 10.738475565971466, 9.903643665125063, 8.905665137385045, 7.879902473725416, 6.87957868984899, 5.909752374210418, 6.851883165298307, 7.847988701514501, 8.739945304092767, 9.797381282320893, 10.745965278393601, 11.718965168260368, 12.775237148833087, 13.726918006892292, 14.760232352915068, 15.522998074176185, 14.521794738965102, 14.673422173852853, 13.635014021154875, 12.650797354335827, 11.700986189963754, 10.856593561189731, 9.820958553422068, 8.837339050312291, 7.84725428878094, 6.891082097487372, 7.8054495161559, 8.851323527037795, 9.752309008571208, 10.715940057234599, 11.761048626020113, 12.663271329772755, 13.737444536113454, 14.680584223158423, 15.618713845147973, 16.446156650860136, 15.508648811124942, 15.600366834040795, 14.5686826347468, 13.600840060692473, 12.707551532605887, 11.743344666142608, 10.809696737434056, 9.820645092159035, 8.877909178536214, 7.912726548429653, 8.839443854461143, 9.792551005238883, 10.682400763059002, 11.675368817436667, 12.687656963778652, 13.733400204447097, 14.690230560394633, 15.66079764432941, 16.580179065898427, 17.440593505351647, 16.50000235207126, 16.523398136295704, 15.568192134798974, 14.64753838963485, 13.706564902949573, 12.680896107972154, 11.743289048256958, 10.83647296625509, 9.803157819321461, 8.922945217331762, 9.817111178883142, 10.751701167740936, 11.181264530264274, 11.76889984092208, 12.740311041636236, 13.664562170550493, 14.503560008208982, 15.339570665124839, 16.25450341042815, 17.191068620925552, 17.454026247006624, 17.51660022441907, 16.581932673671144, 15.679800984486938, 14.64911146212156, 13.672839210267488, 12.794087943856958, 11.764553086669729, 10.749251766037771, 9.905796249385457, 10.752891205844586, 10.911538226426245, 10.13070851580595, 10.723589195084902, 11.769426861166815, 12.606425976026093, 13.511460198666017, 14.406736635607594, 15.31988354678159, 16.285344181215184, 17.290698117609, 17.451846371546583, 17.59299459430946, 16.670951984806266, 15.66247438277404, 14.641717342246062, 13.67397805351909, 12.68731799495181, 11.695760548477871, 10.847612139613721, 10.728743631238471, 9.87381968430403, 9.098905567801557, 9.791494859222915, 10.720744055844133, 11.636176133489286, 12.495479727886515, 13.442804317785175, 14.374661998063699, 15.399917518072066, 16.391173829815514, 16.542301570467757, 17.452973717637544, 16.553900373745165, 15.588096148019996, 14.610462824705898, 13.5917591915597, 12.567688407218098, 11.642241017597616, 10.684787628809241, 9.765681580889117, 8.82187918583128, 8.147738078924656, 8.848830220235522, 9.726645863006844, 10.620574230939699, 11.558313636258482, 12.562962161346004, 13.506392901490049, 14.521476777136893, 15.580807520761002, 15.535809525757646, 16.478783477131532, 15.51878113856682, 14.61889614052527, 13.705246152371654, 12.709059895426634, 11.634474859299342, 10.699068651072496, 9.730974661108919, 8.795579148864984, 7.842261556597231, 7.1463220961686815, 7.835493995705818, 8.76904684047538, 9.631872235778046, 10.585474009425386, 11.628685465846413, 12.618637436629141, 13.573554353772264, 14.557787697499055, 14.56917810056121, 15.422654177262592, 14.461098166317791, 13.620693376174676, 12.76519199404017, 11.766186427562637, 10.820541801798766, 9.772799369973775, 8.771314401100332, 7.904786292145985, 6.8929550986326165, 6.115960438073409, 6.807537380005151, 7.754506765780535, 8.679707209184, 9.625770418703151, 10.60954051513925, 11.548022983122083, 12.545690096496335, 13.546139482107236, 13.61460500620975, 14.453158790446098, 13.523190834693157, 12.604597979125398, 11.722950623981847, 10.769439678972478, 9.800029553065361, 8.792610387862622, 7.728603349460161, 6.913865791430414, 5.917571575106433, 5.090459854868745, 5.853134021978823, 6.889248982180782, 7.799656230450012, 8.652996579503977, 9.611295040378597, 10.59584245261241, 11.619423224016423, 12.619520234669427, 12.607404216051036, 13.517337847762448, 12.58772402504277, 11.67330066492345, 10.695606612112416, 9.739309057989248, 8.791673263694726, 7.757942472870132, 6.720789414617248, 5.878763265585899, 4.909518616105201, 4.048441885538499, 4.878205411310579, 5.8901223824509055, 6.770751570585256, 7.709498039530587, 8.655611016542082, 9.625857599888837, 10.590843666505062, 11.63323174325689, 11.807203861018573, 12.68543342028555, 11.64826708177115, 10.721971592504472, 9.760410928675359, 8.778146416450038, 7.742099626919346, 6.7491169185501265, 5.768089951669481, 4.807953633650619, 3.8673198335601997, 3.000808898960195, 3.8851346874183186, 4.847959904365959, 5.831953574188059, 6.771971250170727, 7.804462270796337, 8.869708492955814, 9.873127563942276, 10.815821154872122, 10.949093523437735, 11.716612439691977, 10.721064148460044, 9.75927250568776, 8.82297090466742, 7.8367717119264135, 6.7839081077567505, 5.739553495809049, 4.835104347328274, 3.87285111402912, 2.8954810650115084, 2.0512079514241646, 2.9261330126749803, 3.9450784035369892, 4.995060784778065, 5.962313338172365, 6.975035373590265, 7.9175247896154355, 8.903871950486689, 9.953119108748407, 9.923745036179927, 10.806575943746326, 9.824513373115272, 8.833502526722912, 7.782524858567776, 6.808419277037377, 5.7598457067502125, 4.77722433732852, 3.8098016569295963, 2.865344903275135, 1.9399947830414188, 1.003786912901635, 1.9954424074273065, 3.005983899880068, 4.037449242430361, 5.052592416033928, 6.028758034060949, 7.074083445182122, 8.115309694564244, 8.958047231136144, 8.995543869660557, 10.02504640410277, 9.031302837673751, 8.04751590814258, 7.047757498681136, 6.04880101918031, 5.069106742456857, 4.087092795021941, 3.132671594105668, 2.094673943288833, 1.0649677162866802, 0.0, 0.957528827570328, 1.9907470508688647, 3.004298922631893, 4.060870538907303, 5.065734144221938, 6.138894945579544, 7.1010002243889065, 8.02648600136936, 9.80359933895997, 10.750472624358105, 9.999790397819693, 8.979700006501597, 7.94737683299254, 6.9922527912037955, 6.035951603334249, 5.019476355929255, 3.993818523388271, 3.0057757136051233, 2.0746173458032375, 1.071453256323591, 2.0000224737861854, 2.938675084920053, 3.945048072086424, 4.940008870609586, 5.924540465426135, 6.889213103182122, 7.8500165541250615, 8.849856921456558, 10.763937752212087, 11.744650743311798, 10.892501201174106, 9.955586021190655, 8.881313098044183, 7.962559260413927, 6.908226047602351, 5.953202315891237, 4.967057925915917, 3.9840308024231907, 3.046699223716849, 2.007547123237544, 2.9948554639956693, 3.9966991040928184, 4.937788110138811, 5.875537734361474, 6.866400852162645, 7.867385929066729, 8.909475682741018, 9.799748384323367, 11.791690746886937, 12.763669734087301, 11.874681505381288, 10.882485933563652, 9.848904571446068, 8.871372717793255, 7.915852635604127, 6.921452568285812, 5.962541019126943, 4.967504509383356, 3.927957006175207, 2.971002746250355, 4.0184273259058445, 5.010217453461005, 5.963019718326379, 6.90451652664856, 7.833045587119946, 8.835459195486592, 9.847950036143521, 10.823105132173158], [10.71443378846534, 9.764789275345791, 8.771446939801802, 7.811654786260231, 6.960409281478754, 5.964532906644804, 5.047759726781255, 4.073450450422126, 4.863113409614243, 5.83225847383017, 6.8198243107674195, 7.8462999010535714, 8.810242573693966, 9.800235472336068, 10.756835003190645, 11.727870830447307, 12.757450943850495, 13.769642902999337, 12.773882005149364, 11.754245534755595, 11.685909254379206, 10.740825160025947, 9.802253250810644, 8.752052865248174, 7.9479880174609105, 7.010488213075904, 5.987652930859192, 5.073818717765265, 5.840032650042527, 6.824412176745419, 7.778517434754199, 8.708150444155462, 9.746874462128188, 10.72815093849294, 11.683800396003381, 12.690170277340892, 13.653130648486124, 14.560045066179207, 13.573425749139107, 12.626499360583086, 12.703630517641901, 11.74148098181476, 10.778812095259033, 9.78094673840114, 8.957091778749431, 7.998826659575209, 7.011254602346942, 6.123041195338744, 6.815456960202432, 7.7575877512903215, 8.753693287506515, 9.645649890084782, 10.703085868312908, 11.651669864385616, 12.624669754252382, 13.680941734825101, 14.635076066095868, 15.529484121322293, 14.565469246605858, 13.564265911394775, 13.715893346282526, 12.677485193584548, 11.6932685267655, 10.743457362393427, 9.9100416748141, 8.952310682043596, 7.968691178933819, 7.179991857897768, 7.796786683479386, 8.711154102147914, 9.75702811302981, 10.658013594563222, 11.621644643226613, 12.666753212012127, 13.568975915764769, 14.643149122105466, 15.588742282361999, 16.48616415250514, 15.488627823289807, 14.551119983554615, 14.64283800647047, 13.611153807176473, 12.643311233122146, 11.782330534374932, 10.889966936555773, 9.95631900784722, 8.978743852136805, 8.210646747653042, 8.818431134421667, 9.745148440453157, 10.698255591230897, 11.588105349051016, 11.81273064739219, 12.824103733319994, 13.736491219768041, 14.50465260947588, 15.337770374030848, 16.345035517289794, 16.483064677781318, 15.542473524500933, 15.565869308725377, 14.610663307228647, 13.690009562064521, 12.781343904718618, 11.827518378385319, 10.889911318670123, 10.041160333552124, 9.13589538843829, 9.828649803323776, 10.722815764875156, 11.65740575373295, 11.747096920403363, 10.811371013351751, 11.782782214065907, 12.707033342980164, 13.546031180638654, 14.38204183755451, 15.296974582857823, 16.233539793355227, 16.496497419436295, 16.55907139684874, 15.624403846100817, 14.72227215691661, 13.77054733370731, 12.819461480680653, 11.940710214270123, 11.047507137366908, 10.0819893351546, 10.81150083537747, 11.6585957918366, 11.662321909732569, 10.696540905945039, 9.766060367514573, 10.811898033596487, 11.648897148455765, 12.553931371095688, 13.449207808037265, 14.362354719211261, 15.327815353644855, 16.333169290038672, 16.494317543976255, 16.635465766739134, 15.713423157235937, 14.794640431259829, 13.875128109663509, 12.926172890112129, 12.001074478191653, 11.0284981175947, 11.753316725605735, 11.67293931727918, 10.719780149516223, 9.764101680269235, 8.833966031652587, 9.763215228273804, 10.678647305918957, 11.537950900316186, 12.485275490214846, 13.41713317049337, 14.442388690501737, 15.433645002245186, 15.584772742897428, 16.495444890067215, 16.666377544352883, 15.861795428640173, 14.906515943030406, 13.908215952811771, 13.005708733387161, 12.097178348835284, 11.62898331484995, 10.709877266929826, 9.76607487187199, 8.812934191392333, 7.891301392665193, 8.769117035436516, 9.66304540336937, 10.600784808688154, 11.605433333775675, 12.54886407391972, 13.563947949566565, 14.623278693190674, 14.578280698187317, 15.521254649561204, 16.476309966137148, 15.5764249680956, 14.651149540362084, 13.654963283417064, 12.580378247289772, 11.644972039062926, 10.675170347149628, 9.739774834905694, 8.78645724263794, 7.811518208636359, 6.87796516813549, 7.811518012905052, 8.674343408207717, 9.627945181855058, 10.671156638276084, 11.661108609058813, 12.616025526201936, 13.600258869928727, 13.611649272990881, 14.561811022373886, 15.41862699388812, 14.578222203745005, 13.7227208216105, 12.723715255132966, 11.778070629369095, 10.730328197544104, 9.72884322867066, 8.862315119716314, 7.837150784673326, 6.781156550541087, 5.850008552434823, 6.796977938210207, 7.722178381613672, 8.668241591132823, 9.65201168756892, 10.590494155551754, 11.588161268926006, 12.588610654536907, 12.657076178639421, 13.598621765486095, 14.480719662263486, 13.562126806695726, 12.680479451552175, 11.726968506542807, 10.75755838063569, 9.75013921543295, 8.686132177030489, 7.871394619000743, 6.875100402676762, 5.963546571781931, 4.895605194408495, 5.9317201546104545, 6.842127402879683, 7.6954677519336485, 8.653766212808268, 9.638313625042082, 10.661894396446094, 11.661991407099098, 11.649875388480707, 12.662800822802446, 13.545252852613098, 12.63082949249378, 11.653135439682744, 10.696837885559574, 9.749202091265055, 8.71547130044046, 7.678318242187575, 6.836292093156227, 5.8670474436755295, 4.921528602451685, 3.920676583740251, 4.932593554880578, 5.813222743014928, 6.751969211960259, 7.698082188971753, 8.668328772318509, 9.633314838934734, 10.67570291568656, 10.849675033448246, 11.81090478300886, 12.605795909341479, 11.6795004200748, 10.717939756245688, 9.735675244020365, 8.699628454489673, 7.706645746120454, 6.725618779239808, 5.765482461220946, 4.8248486611305275, 3.873895615873381, 2.927605859847991, 3.8904310767956316, 4.8744247466177315, 5.8144424226004, 6.846933443226009, 7.9121796653854854, 8.91559873637195, 9.858292327301795, 9.991564695867408, 10.949598076407336, 11.678592976030373, 10.716801333258088, 9.780499732237748, 8.794300539496742, 7.741436935327078, 6.697082323379377, 5.792633174898601, 4.830379941599448, 3.853009892581836, 2.9242946683373505, 1.9686041851046525, 2.9875495759666615, 4.0375319572077375, 5.004784510602037, 6.017506546019938, 6.959995962045109, 7.946343122916363, 8.995590281178082, 8.9662162086096, 10.033918500298208, 10.7820422006856, 9.79103135429324, 8.740053686138106, 7.7659481046077055, 6.71737453432054, 5.734753164898848, 4.767330484499924, 3.822873730845463, 2.8975236106117466, 1.961315740471963, 1.0379135798569785, 2.0484550723097397, 3.0799204148600334, 4.0950635884636, 5.071229206490621, 6.1165546176117935, 7.157780866993917, 8.000518403565817, 8.038015042090228, 9.067517576532442, 9.988831665244078, 9.005044735712907, 8.005286326251463, 7.006329846750638, 6.026635570027185, 5.044621622592269, 4.090200421675996, 3.052202770859161, 2.022496543857008, 0.957528827570328, 0.0, 1.0332182232985367, 2.0467700950615653, 3.1033417113369755, 4.108205316651611, 5.181366118009217, 6.14347139681858, 7.068957173799032, 8.846070511389643, 9.792943796787778, 10.7789755707897, 9.937228834071924, 8.87068114268576, 7.915557100897014, 6.959255913027468, 5.9427806656224735, 4.91712283308149, 3.9290800232983427, 2.9979216554964574, 1.9771578423156053, 1.048588624853011, 1.981146257349725, 2.987519244516096, 3.982480043039258, 4.967011637855808, 5.9316842756117945, 6.892487726554734, 7.892328093886231, 9.80640892464176, 10.787121915741471, 11.748297948470752, 10.878890330883873, 9.804617407737402, 8.883281947022086, 7.82894873421051, 6.873925002499395, 5.887780612524075, 4.904753489031349, 3.9674219103250072, 2.9132517092295585, 2.043421615062495, 3.0391702765224906, 3.980259282568483, 4.918008906791147, 5.908872024592318, 6.909857101496401, 7.951946855170689, 8.84221955675304, 10.83416191931661, 11.806140906516974, 12.78018905175795, 11.80579024325687, 10.772208881139287, 9.792095404401413, 8.836575322212285, 7.84217525489397, 6.883263705735101, 5.87320909537537, 4.833661592167221, 3.8767073322423697, 3.071829954336035, 4.054427074011793, 5.005490890756051, 5.9469876990782335, 6.875516759549619, 7.8779303679162656, 8.890421208573194, 9.86557630460283], [9.681215565166804, 8.731571052047254, 7.738228716503266, 6.778436562961694, 5.927191058180217, 4.931314683346266, 4.014541503482718, 4.913238216277496, 5.702901175469614, 6.672046239685541, 7.65961207662279, 8.686087666908941, 9.650030339549335, 10.640023238191437, 11.596622769046014, 12.567658596302676, 13.536347317916487, 12.7892110224627, 11.740663781850827, 10.721027311457059, 10.65269103108067, 9.70760693672741, 8.769035027512107, 7.718834641949638, 6.914769794162373, 5.9772699897773665, 4.954434707560655, 5.889660439115347, 6.679820415897898, 7.664199942600789, 8.61830520060957, 9.547938210010834, 10.58666222798356, 11.567938704348311, 12.52358816185875, 13.529958043196261, 14.492918414341494, 13.52682684288067, 12.54020752584057, 11.59328113728455, 11.670412294343365, 10.708262758516224, 9.745593871960496, 8.747728515102603, 7.923873555450894, 6.965608436276671, 5.9780363790484055, 6.938882916688826, 7.655244726057803, 8.597375517145691, 9.593481053361886, 10.485437655940153, 11.542873634168279, 12.491457630240987, 13.464457520107754, 14.520729500680472, 15.474863831951238, 14.496265898023756, 13.532251023307321, 12.531047688096239, 12.682675122983989, 11.644266970286012, 10.660050303466964, 9.71023913909489, 8.876823451515563, 7.919092458745059, 6.935472955635282, 7.934557755155057, 8.636574449334757, 9.550941868003283, 10.59681587888518, 11.497801360418594, 12.461432409081985, 13.107132726008885, 14.081828984123048, 14.61850513413418, 15.47025208435505, 15.452945929206603, 14.45540959999127, 13.517901760256079, 13.609619783171933, 12.577935583877936, 11.61009300982361, 10.749112311076395, 9.856748713257236, 8.923100784548684, 7.945525628838268, 8.888261542461088, 9.658218900277038, 10.584936206308527, 11.538043357086266, 12.427893114906388, 12.816551563519067, 12.180524388250346, 13.011700109448705, 13.656920898629094, 14.490038663184063, 15.497303806443009, 15.449846454482783, 14.509255301202396, 14.53265108542684, 13.57744508393011, 12.656791338765984, 11.748125681420081, 10.794300155086782, 9.856693095371586, 9.007942110253587, 9.813510183246335, 10.668437569179147, 11.562603530730525, 12.49719351958832, 12.75091783653024, 11.815191929478628, 11.139202868996259, 11.982242232660829, 12.698299469791868, 13.534310126707725, 14.449242872011038, 15.38580808250844, 15.463279196137758, 15.525853173550203, 14.59118562280228, 13.689053933618073, 12.737329110408773, 11.786243257382116, 10.907491990971586, 10.014288914068372, 10.759604129962645, 11.651288601232842, 12.49838355769197, 12.666142825859446, 11.700361822071915, 10.76988128364145, 10.145460033681466, 10.92410603813643, 11.706199660248902, 12.60147609719048, 13.514623008364476, 14.480083642798068, 15.485437579191885, 15.629213884061835, 15.602247543440598, 14.6802049339374, 13.761422207961292, 12.841909886364972, 11.892954666813592, 10.967856254893116, 11.706112912402745, 12.593104491461107, 12.676760233406055, 11.7236010656431, 10.767922596396112, 9.837786947779463, 9.077299804101118, 9.953856195599622, 10.690219189469401, 11.63754377936806, 12.569401459646585, 13.594656979654951, 14.5859132913984, 14.700613827957678, 15.611285975127466, 15.633159321054347, 14.828577205341636, 13.87329771973187, 12.874997729513234, 11.972490510088624, 12.774793143643329, 12.632804230976825, 11.713698183056701, 10.769895787998864, 9.81675510751921, 8.89512230879207, 8.08320161126383, 8.938254293050035, 9.753053097841368, 10.75770162292889, 11.701132363072933, 12.703124487368516, 13.762455230992625, 13.694121783247567, 14.637095734621454, 15.62925506419869, 15.797777212836362, 14.88298008680451, 13.88679382985949, 12.90570405800738, 12.648792955189801, 11.678991263276503, 10.743595751032569, 9.790278158764815, 8.815339124763236, 7.881786084262366, 7.125602588732365, 7.949552297888381, 8.767121719657009, 9.810333176078036, 10.800285146860764, 11.755202064003887, 12.721942919131422, 12.727490358051131, 13.673900457455103, 14.57157209194966, 15.579358538421703, 14.755939044909036, 13.756933478431502, 12.811288852667632, 11.76354642084264, 10.762061451969197, 9.86811362934988, 8.840971700800202, 7.7849774666679625, 6.853829468561699, 6.079203711760121, 6.997387271294337, 7.807418128934774, 8.791188225370872, 9.729670693353706, 10.727337806727958, 11.710294703739603, 11.772917263699672, 12.70440507063861, 13.633664760325026, 14.59334753362018, 13.713697674850712, 12.760186729841344, 11.790776603934226, 10.783357438731487, 9.719350400329025, 8.90461284229928, 7.908318625975299, 6.967367487908807, 5.899426110535371, 5.097527654367876, 5.981303940681636, 6.834644289735601, 7.79294275061022, 8.777490162844035, 9.801070934248047, 10.777832492159348, 10.765716473540957, 11.76858412795496, 12.698197950674638, 13.664047715792316, 12.686353662981281, 11.730056108858111, 10.782420314563591, 9.748689523738998, 8.711536465486112, 7.869510316454764, 6.900265666974066, 5.925349518578561, 4.924497499867127, 4.098401054637999, 4.952399280816881, 5.891145749762211, 6.8372587267737055, 7.80750531012046, 8.772491376736685, 9.79154400074681, 9.844331302900308, 10.805561052460922, 11.839131077651837, 12.712718643373337, 11.751157979544224, 10.768893467318902, 9.73284667778821, 8.739863969418991, 7.758837002538344, 6.798700684519483, 5.858066884429064, 4.877716532000257, 3.9314267759748667, 3.0562385765530524, 4.013601284419684, 4.953618960402352, 5.986109981027962, 6.937302589804813, 7.910255005824011, 8.852948596753857, 8.958346472568872, 9.916379853108799, 10.911928144340731, 11.750019556556625, 10.813717955536285, 9.827518762795279, 8.774655158625615, 7.730300546677913, 6.825851398197138, 5.863598164897985, 4.886228115880373, 3.9281155844642264, 2.9724251012315284, 2.025968369263036, 3.06174889658267, 3.999440780054099, 5.012162815471999, 5.95465223149717, 6.940999392368425, 7.990246550630143, 7.932997985311063, 9.000700276999671, 9.982762847630726, 10.824249577591777, 9.773271909436643, 8.799166327906242, 7.750592757619077, 6.767971388197385, 5.800548707798461, 4.8560919541439995, 3.9307418339102833, 2.9945339637704995, 2.0417344959838544, 1.0311930035310932, 2.0467021915614967, 3.0618453651650634, 4.038010983192084, 5.083336394313257, 6.124562643695381, 6.96730018026728, 7.004796818791692, 8.034299353233905, 9.072621288806396, 10.038262959011444, 9.03850454955, 8.039548070049173, 7.059853793325722, 6.077839845890805, 5.1234186449745325, 4.0854209941576975, 3.055714767155545, 1.9907470508688647, 1.0332182232985367, 0.0, 1.0135518717630285, 2.0701234880384387, 3.074987093353074, 4.1481478947106805, 5.110253173520043, 6.0357389505004955, 7.812852288091105, 8.75972557348924, 9.745757347491162, 10.765847738809258, 9.710468908541129, 8.755344866752385, 7.799043678882838, 6.782568431477844, 5.7569105989368605, 4.768867789153713, 3.837709421351828, 2.816945608170976, 1.8883763907083813, 0.9479280340511882, 1.954301021217559, 2.9492618197407214, 3.933793414557271, 4.898466052313258, 5.859269503256197, 6.8591098705876945, 8.773190701343223, 9.753903692442933, 10.715079725172213, 11.651994905155664, 10.644405173592771, 9.723069712877457, 8.668736500065881, 7.713712768354767, 6.727568378379447, 5.74454125488672, 4.807209676180378, 3.753039475084929, 2.883209380917865, 2.005952053223954, 2.947041059269946, 3.8847906834926103, 4.875653801293781, 5.8766388781978645, 6.918728631872153, 7.809001333454503, 9.800943696018074, 10.772922683218436, 11.746970828459412, 12.584686617322863, 11.611996646994657, 10.631883170256785, 9.676363088067657, 8.681963020749341, 7.723051471590472, 6.7129968612307405, 5.673449358022592, 4.71649509809774, 3.911617720191405, 3.0212088507132564, 3.972272667457514, 4.913769475779696, 5.842298536251082, 6.844712144617729, 7.857202985274657, 8.832358081304294], [8.750660438208644, 7.801015925089094, 6.807673589545105, 5.847881436003533, 4.996635931222055, 4.000759556388106, 5.015041459309944, 5.926790088040525, 6.716453047232643, 7.68559811144857, 8.67316394838582, 9.699639538671972, 10.663582211312367, 11.653575109954469, 12.610174640809046, 13.581210468065708, 12.605792190958326, 11.85865589550454, 10.810108654892668, 9.790472184498899, 9.722135904122508, 8.77705180976925, 7.8384799005539465, 6.788279514991476, 5.984214667204212, 5.046714862819206, 5.954934663387881, 6.890160394942573, 7.693372287660927, 8.67775181436382, 9.6318570723726, 10.561490081773865, 11.60021409974659, 12.581490576111342, 13.537140033621782, 14.543509914959293, 13.641253208980014, 12.596271715922509, 11.609652398882409, 10.662726010326388, 10.739857167385203, 9.777707631558062, 8.815038745002335, 7.817173388144441, 6.993318428492732, 6.035053309318511, 6.978536334875631, 7.939382872516052, 8.668796597820833, 9.610927388908722, 10.607032925124917, 11.498989527703184, 12.55642550593131, 13.505009502004018, 14.012583273872405, 14.619956081076614, 14.616142699540434, 13.565710771065595, 12.60169589634916, 11.600492561138077, 11.752119996025828, 10.71371184332785, 9.729495176508802, 8.779684012136729, 7.946268324557401, 7.0588247354044515, 7.935972911462508, 8.935057710982282, 9.650126321097787, 10.564493739766315, 11.61036775064821, 12.511353232181625, 13.474984280845016, 13.88004363900047, 13.068277112360018, 13.604953262371154, 14.456700212592024, 14.522390802248442, 13.524854473033109, 12.587346633297917, 12.679064656213772, 11.647380456919775, 10.679537882865448, 9.818557184118234, 8.99648098991663, 8.062833061208078, 8.946025584665493, 9.888761498288314, 10.671770772040068, 11.598488078071558, 12.551595228849298, 13.441444986669419, 13.818727323667524, 12.95343530124193, 11.998148237685676, 12.643369026866068, 13.476486791421037, 14.483751934679983, 14.519291327524622, 13.578700174244235, 13.602095958468679, 12.646889956971949, 11.726236211807823, 10.81757055446192, 9.934032431746177, 8.99642537203098, 10.008442066080812, 10.814010139073561, 11.681989440942177, 12.576155402493557, 13.510745391351351, 13.753093596678697, 12.817367689627085, 11.912113781987843, 10.9686903608978, 11.684747598028842, 12.520758254944699, 13.435691000248012, 14.372256210745414, 14.532724069179597, 14.595298046592042, 13.660630495844119, 12.758498806659912, 11.806773983450611, 10.92597553404151, 10.04722426763098, 11.014788869895597, 11.760104085789871, 12.664840472995872, 13.511935429455, 13.668318586007903, 12.702537582220373, 11.772057043789907, 10.91837094667305, 9.9105541663734, 10.692647788485877, 11.587924225427454, 12.50107113660145, 13.466531771035044, 14.47188570742886, 14.615662012298808, 14.671692416482436, 13.749649806979239, 12.830867081003131, 11.981642163024366, 11.032686943472987, 11.96835621072034, 12.706612868229971, 13.606656363224136, 13.678935993554513, 12.725776825791558, 11.770098356544569, 10.83996270792792, 9.872409337114073, 8.940304323836592, 9.676667317706375, 10.623991907605035, 11.555849587883559, 12.581105107891926, 13.572361419635374, 13.68706195619465, 14.597734103364438, 14.702604194096185, 13.898022078383475, 13.013029996391264, 12.014730006172629, 12.97299046591585, 13.775293099470556, 13.634979991125283, 12.715873943205159, 11.772071548147322, 10.818930867667667, 9.897298068940527, 8.878311144276784, 7.924702421287005, 8.739501226078342, 9.744149751165864, 10.687580491309909, 11.689572615605488, 12.748903359229597, 12.68056991148454, 13.623543862858426, 14.615703192435662, 14.8672220858782, 14.022712363463905, 13.026526106518885, 13.906204013834605, 13.650968715338259, 12.68116702342496, 11.745771511181026, 10.792453918913273, 9.817514884911693, 8.883961844410823, 7.955434719907016, 6.936000426125352, 7.753569847893982, 8.796781304315008, 9.786733275097736, 10.74165019224086, 11.708391047368394, 11.713938486288104, 12.660348585692075, 13.558020220186632, 14.565806666658675, 14.966673358957301, 13.982464734863632, 13.824840724430663, 12.777098292605668, 11.775613323732225, 10.870289389498337, 9.843147460948659, 8.78715322681642, 7.856005228710156, 6.909035842934772, 5.983835399531308, 6.7938662571717465, 7.7776363536078446, 8.716118821590678, 9.71378593496493, 10.696742831976575, 10.759365391936644, 11.690853198875581, 12.620112888561998, 13.579795661857153, 14.513067922805568, 13.773738601604375, 12.804328475697258, 11.796909310494515, 10.732902272092053, 9.918164714062305, 8.921870497738325, 7.9809193596718355, 6.9129779822984, 5.931598871679883, 4.967752068918607, 5.821092417972572, 6.779390878847192, 7.763938291081006, 8.787519062485018, 9.76428062039632, 9.75216460177793, 10.755032256191932, 11.68464607891161, 12.737230651066673, 13.691845827260401, 12.743607980621142, 11.795972186326622, 10.762241395502025, 9.72508833724914, 8.883062188217792, 7.913817538737094, 6.93890139034159, 5.9380493716301554, 4.932472271950006, 3.9388474090538517, 4.877593877999183, 5.823706855010677, 6.793953438357431, 7.7589395049736565, 8.777992128983783, 8.83077943113728, 9.792009180697894, 10.825579205888808, 11.767318667328444, 12.756650143823345, 11.782445339081933, 10.746398549551241, 9.75341584118202, 8.772388874301374, 7.812252556282512, 6.871618756192093, 5.891268403763285, 4.944978647737895, 3.984043082478755, 3.000049412656655, 3.9400670886393234, 4.9725581092649325, 5.923750718041784, 6.896703134060983, 7.839396724990829, 7.944794600805842, 8.90282798134577, 9.898376272577702, 10.860167915349987, 11.827269827299313, 10.841070634558308, 9.788207030388644, 8.743852418440943, 7.839403269960167, 6.877150036661013, 5.899779987643401, 4.941667456227255, 3.985976972994557, 3.0395202410260644, 2.0481970248196415, 2.9858889082910705, 3.9986109437089707, 4.941100359734142, 5.927447520605396, 6.976694678867115, 6.919446113548034, 7.987148405236642, 8.969210975867696, 9.960221822260056, 10.78682378119967, 9.81271819966927, 8.764144629382105, 7.781523259960413, 6.814100579561489, 5.869643825907028, 4.944293705673312, 4.008085835533528, 3.055286367746883, 2.0447448752941217, 1.0331503197984682, 2.048293493402035, 3.0244591114290555, 4.069784522550229, 5.111010771932351, 5.953748308504251, 5.991244947028663, 7.020747481470876, 8.059069417043364, 9.042856346574535, 10.042614756035979, 9.053099941812203, 8.073405665088751, 7.091391717653834, 6.136970516737561, 5.098972865920726, 4.069266638918573, 3.004298922631893, 2.0467700950615653, 1.0135518717630285, 0.0, 1.0565716162754104, 2.0614352215900453, 3.1345960229476515, 4.0967013017570135, 5.022187078737466, 6.882297161132944, 7.829170446531079, 8.815202220533003, 9.835292611851099, 10.724020780304157, 9.768896738515412, 8.812595550645867, 7.796120303240873, 6.770462470699889, 5.782419660916742, 4.851261293114856, 3.8304974799340044, 2.90192826247141, 1.9614799058142167, 1.023745894259398, 2.01870669278256, 3.0032382875991095, 3.9679109253550964, 4.928714376298036, 5.928554743629533, 7.842635574385062, 8.823348565484773, 9.784524598214054, 10.721439778197503, 11.657957045355799, 10.736621584640485, 9.682288371828909, 8.727264640117795, 7.741120250142474, 6.758093126649748, 5.820761547943406, 4.7665913468479575, 3.8967612526808937, 3.0195039249869824, 2.016485932311785, 2.954235556534449, 3.94509867433562, 4.946083751239703, 5.988173504913991, 6.878446206496342, 8.870388569059912, 9.842367556260276, 10.816415701501253, 11.654131490364701, 12.625548518757684, 11.645435042019812, 10.689914959830684, 9.69551489251237, 8.7366033433535, 7.72654873299377, 6.687001229785621, 5.730046969860769, 4.925169591954433, 4.026739214549492, 3.041717540499353, 3.9832143488215346, 4.911743409292921, 5.9141570176595675, 6.926647858316496, 7.901802954346133], [7.732860054084117, 6.783215540964567, 5.7898732054205775, 4.830081051879006, 4.027107758159299, 5.006504154946, 6.020786057867838, 6.983361704315935, 7.773024663508052, 8.74216972772398, 9.72973556466123, 10.756211154947382, 11.720153827587776, 12.710146726229878, 13.577147001650333, 12.606111174393671, 11.567610239983072, 10.840855511380013, 9.79230827076814, 8.772671800374372, 8.704335519997983, 7.759251425644723, 6.820679516429419, 5.770479130866949, 5.014686494141455, 5.991899707092257, 6.960679261945775, 7.895904993500467, 8.749943903936337, 9.734323430639229, 10.68842868864801, 11.618061698049274, 12.656785716022, 13.638062192386752, 14.50411239446307, 13.586413196000724, 12.623452824855491, 11.578471331797985, 10.591852014757883, 9.644925626201863, 9.722056783260678, 8.759907247433535, 7.797238360877807, 6.799373004019914, 6.023790255429976, 6.980238153591562, 7.984280933433525, 8.945127471073945, 9.725368214096243, 10.667499005184132, 11.663604541400327, 12.555561143978593, 13.61299712220672, 14.561581118279427, 14.58446572329235, 13.58978738536863, 13.598342315415909, 12.54791038694107, 11.583895512224634, 10.582692177013552, 10.7343196119013, 9.695911459203323, 8.711694792384275, 7.761883628012201, 6.976740151494644, 8.004009579677502, 8.941717510020402, 9.940802309540176, 10.706697937373196, 11.621065356041724, 12.66693936692362, 13.567924848457034, 14.531555897120425, 14.528331452458621, 13.640159561779964, 12.57478456666317, 13.42653151688404, 13.504590418123916, 12.507054088908584, 11.569546249173392, 11.661264272089245, 10.629580072795248, 9.661737498740921, 8.800756799993707, 8.036372854109107, 8.97002078281766, 9.951770183223388, 10.894506096846209, 11.728342388315477, 12.655059694346967, 13.608166845124707, 14.498016602944828, 14.53317243020059, 13.601723114700082, 12.570030687105621, 11.613200331158085, 12.446318095713053, 13.453583238972, 13.501490943400096, 12.56089979011971, 12.584295574344152, 11.629089572847422, 10.708435827683296, 9.799770170337393, 9.107474737895961, 9.903613093640562, 10.94387292048952, 11.819754737631456, 12.738561057217586, 13.632727018768966, 14.56731700762676, 14.513793703319761, 13.531812796160152, 12.560401595445995, 11.616978174355951, 10.654578902320859, 11.490589559236716, 12.405522304540028, 13.34208751503743, 13.51492368505507, 13.577497662467515, 12.642830111719592, 11.740698422535385, 10.788973599326084, 10.099417840191295, 10.954411989240562, 11.950219724304304, 12.765848684347766, 13.721412089271281, 14.56850704573041, 14.429018692648967, 13.463237688861437, 12.532757150430971, 11.566658760131203, 10.558841979831552, 9.662479092777893, 10.55775552971947, 11.470902440893466, 12.436363075327058, 13.441717011720876, 13.559090396023398, 13.65389203235791, 12.731849422854712, 11.813066696878604, 11.15508446917415, 11.939874665082568, 12.903787065129048, 13.712357466787866, 14.663227979499545, 14.439636100195576, 13.486476932432621, 12.530798463185633, 11.600662814568985, 10.57286721168688, 9.588592137294745, 8.646498621998392, 9.593823211897051, 10.525680892175576, 11.550936412183942, 12.542192723927391, 12.630490339919241, 13.541162487089029, 13.684803809971658, 12.880221694258948, 12.186472302541048, 12.92191772778221, 13.908421320324557, 14.78103769802845, 14.395680097766347, 13.476574049846223, 12.532771654788386, 11.579630974308731, 10.657998175581591, 9.600680658678924, 8.647071935689144, 7.70933253037036, 8.713981055457882, 9.657411795601927, 10.659403919897507, 11.717283595682977, 11.62399829520913, 12.566972246583017, 13.55913157616025, 13.849421701753673, 13.237142582142628, 13.933713828128466, 14.841634868243313, 14.411668821979323, 13.441867130066024, 12.50647161782209, 11.553154025554337, 10.578214991552757, 9.644661951051887, 8.71613482654808, 7.696700532766415, 6.723401152186001, 7.766612608607027, 8.756564579389755, 9.711481496532878, 10.651819431092983, 10.657366870012694, 11.603776969416664, 12.501448603911221, 13.509235050383264, 14.181103577636026, 14.889652456473213, 14.694242201849981, 13.64473749442041, 12.607817919586042, 11.630989496139401, 10.603847567589723, 9.547853333457484, 8.61670533535122, 7.669735949575835, 6.744535506172371, 5.763697561463765, 6.747467657899863, 7.685950125882697, 8.68361723925695, 9.640171215701164, 9.702793775661235, 10.63428158260017, 11.563541272286587, 12.523224045581742, 13.456496306530155, 14.444050210257359, 13.752404916687079, 12.737268258799881, 11.67326122039742, 10.792914317050348, 9.796620100726368, 8.832293500902624, 7.763240454577218, 6.779971692270201, 5.770151336951049, 4.790923722264591, 5.74922218313921, 6.733769595373024, 7.757350366777036, 8.70770900412091, 8.695592985502518, 9.69846063991652, 10.6280744626362, 11.680659034791262, 12.63527421098499, 13.630010205261211, 12.744048627316444, 11.702600343807392, 10.665447285554507, 9.80642865495996, 8.788567141725137, 7.790275531572379, 6.788311843908974, 5.780845092540324, 4.78722022964417, 3.847425182291201, 4.793538159302695, 5.76378474264945, 6.728770809265675, 7.721420512708372, 7.774207814861869, 8.735437564422483, 9.769007589613397, 10.710747051053033, 11.700078527547934, 12.764487842909357, 11.776147474745937, 10.783164766376718, 9.712747822606739, 8.735619023024679, 7.752199653764543, 6.742642544994075, 5.795241120016714, 4.832415903069073, 3.8484222332469726, 2.909898392931342, 3.9217255745152118, 4.867179101766374, 5.840131517785572, 6.782825108715418, 6.888222984530432, 7.846256365070358, 8.84180465630229, 9.803596299074576, 10.863388701231985, 11.869314772538027, 10.844778646664054, 9.800424034716352, 8.895974886235576, 7.933721652936423, 6.920463495338746, 5.921188100745742, 4.965497617513044, 3.9465522266510353, 2.8965698454099593, 1.92931729201566, 2.9420393274335606, 3.8845287434587314, 4.870875904329986, 5.9201230625917045, 5.862874497272624, 6.930576788961232, 7.912639359592287, 8.903650205984647, 9.954627874139781, 10.869289815944681, 9.820716245657517, 8.838094876235823, 7.8706721958368995, 6.926215442182438, 6.000865321948722, 5.064657451808938, 4.107837791185689, 3.097296298732928, 2.0344485792203235, 0.9917218771266245, 1.9678874951536454, 3.0132129062748185, 4.054439155656941, 4.8971766922288404, 4.934673330753252, 5.9641758651954655, 7.002497800767955, 7.986284730299126, 8.98604313976057, 9.984999619261396, 9.12997728136416, 8.147963333929244, 7.193542133012971, 6.155544482196136, 5.125838255193983, 4.060870538907303, 3.1033417113369755, 2.0701234880384387, 1.0565716162754104, 0.0, 1.0048636053146351, 2.0780244066722413, 3.0401296854816033, 3.9656154624620563, 5.844115210157688, 6.7909884955558235, 7.777020269557747, 8.797110660875843, 9.863845479090882, 10.818969520879627, 9.869167166921278, 8.852691919516284, 7.827034086975299, 6.838991277192152, 5.907832909390266, 4.887069096209414, 3.95849987874682, 3.018051522089627, 2.0441393182429652, 1.0491785197198031, 1.9650563366238534, 2.9297289743798407, 3.89053242532278, 4.8903727926542775, 6.804453623409806, 7.785166614509516, 8.746342647238798, 9.68325782722225, 10.757530750368721, 11.793193200915894, 10.738859988104318, 9.783836256393204, 8.797691866417884, 7.8146647429251574, 6.877333164218816, 5.823162963123367, 4.953332868956304, 4.076075541262393, 3.0222305308696784, 1.984707383471692, 2.927298290211093, 3.9079018002644474, 4.949991553938736, 5.840264255521086, 7.832206618084657, 8.804185605285019, 9.778233750525997, 10.615949539389447, 11.649530901507031, 12.676167025434268, 11.746486576106093, 10.75208650878778, 9.79317495962891, 8.78312034926918, 7.7435728460610305, 6.7866185861361785, 5.981741208229844, 5.032483813107386, 4.047462139057247, 3.013686175758778, 3.8939430251683937, 4.89635663353504, 5.908847474191969, 6.863621003370877], [6.727996448769481, 5.778351935649931, 4.7850096001059415, 3.8252174465643702, 4.878684150178344, 5.883382465267195, 6.897664368189033, 7.911368294041609, 8.701031253233726, 9.670176317449652, 10.657742154386902, 11.684217744673054, 12.648160417313449, 13.528882927190274, 12.572283396335697, 11.601247569079035, 10.562746634668436, 9.835991906065377, 8.787444665453505, 7.767808195059736, 7.699471914683347, 6.754387820330087, 5.815815911114783, 4.765615525552314, 5.700768930277614, 6.677982143228416, 7.739008031876489, 8.67423376343118, 9.660980770063642, 10.662330020364902, 11.616435278373682, 12.546068287774947, 13.584792305747673, 14.480820207659878, 13.499248789148433, 12.581549590686087, 11.618589219540855, 10.573607726483349, 9.586988409443247, 8.640062020887227, 8.717193177946042, 7.7550436421189, 6.792374755563172, 5.794509398705279, 6.709872691566135, 7.666320589727721, 8.715534303245738, 9.723456241004659, 10.636405080223547, 11.589234026781615, 12.591611131126, 13.483567733704266, 14.541003711932392, 15.4895877080051, 14.518479746395672, 13.632525215314297, 12.593478710101273, 11.543046781626433, 10.579031906909998, 9.577828571698916, 9.729456006586664, 8.691047853888687, 7.706831187069639, 6.757020022697566, 7.662822587630803, 8.690092015813661, 9.672970879832615, 10.67205567935239, 11.6177348035005, 12.542800377639207, 13.588674388521103, 14.495931438182707, 15.459562486846098, 15.533195057773256, 14.645023167094598, 13.579648171977805, 12.892844427657543, 12.49972681280928, 11.502190483593948, 10.564682643858756, 10.656400666774609, 9.624716467480612, 8.656873893426285, 7.7958931946790715, 8.722455290245268, 9.65610321895382, 10.645154864228841, 11.587890777851662, 12.57032226375094, 13.57679471594445, 14.52990186672219, 15.4260231926705, 15.538036035515224, 14.606586720014716, 13.574894292420256, 12.61806393647272, 11.912631006486556, 12.823538334547797, 12.49662733808546, 11.556036184805073, 11.579431969029516, 10.624225967532785, 9.70357222236866, 8.794906565022757, 9.793557174032122, 10.589695529776723, 11.62995535662568, 12.513139418636909, 13.486052279072464, 14.47170413269247, 15.406294121550264, 15.518657308634394, 14.536676401474786, 13.56526520076063, 12.621841779670586, 11.659442507635493, 10.956902470010219, 11.775477400115825, 12.712042610613228, 12.510060079740434, 12.572634057152879, 11.637966506404956, 10.735834817220749, 9.784109994011448, 10.760382245865522, 11.640494425376723, 12.636302160440465, 13.459233365353219, 14.417389429727907, 15.407484159653913, 15.4338822979636, 14.46810129417607, 13.537620755745603, 12.571522365445837, 11.563705585146186, 10.667342698092527, 10.024068440492973, 10.840857536469263, 11.806318170902856, 12.730522563672793, 12.603431847200588, 12.649028427043273, 11.726985817540076, 10.808203091563968, 11.816048874848377, 12.625957101218729, 13.589869501265209, 14.405742147793319, 15.359205319956171, 15.44449970551021, 14.491340537747256, 13.535662068500267, 12.605526419883617, 11.577730817001514, 10.593455742609379, 9.651362227313026, 9.060136122670555, 9.895635987751373, 10.885928198029655, 11.722177258940864, 11.67483179109643, 12.585503938266218, 12.679940204657022, 11.875358088944312, 12.847436708215275, 13.608000163918371, 14.594503756460718, 15.474422379033903, 15.40054370308098, 14.481437655160857, 13.53763526010302, 12.584494579623366, 11.662861780896225, 10.605544263993556, 9.651935541003777, 8.714196135684993, 8.057520073075247, 8.893411935956044, 9.844557034800555, 10.761625046860166, 10.66833974638632, 11.611313697760206, 12.60347302733744, 12.844558096439037, 13.82794918259507, 14.619796264264627, 15.527717304379474, 15.416532427293957, 14.446730735380658, 13.511335223136724, 12.55801763086897, 11.583078596867391, 10.649525556366521, 9.720998431862714, 8.70156413808105, 7.728264757500635, 7.001317368194626, 7.941717694292803, 8.896634611435926, 9.696160882270172, 9.701708321189884, 10.648118420593853, 11.54579005508841, 12.553576501560453, 13.495474981333688, 14.560169574505299, 15.478314036075071, 14.649601099735044, 13.612681524900676, 12.635853101454035, 11.608711172904357, 10.552716938772118, 9.621568940665854, 8.67459955489047, 7.749399111487005, 6.768561166778399, 5.982172417487462, 6.871103240785745, 7.868770354159998, 8.684512666878353, 8.747135226838424, 9.67862303377736, 10.607882723463776, 11.567565496758931, 12.500837757707345, 13.488391661434548, 14.457801787341666, 13.742131864114514, 12.678124825712052, 11.79777792236498, 10.801483706041001, 9.837157106217258, 8.768104059891852, 7.784835297584835, 6.775014942265684, 5.795787327579226, 4.983926942726809, 5.870295044102691, 6.893875815506703, 7.752050455298098, 7.739934436679707, 8.74280209109371, 9.672415913813388, 10.67880682895718, 11.630410605670354, 12.625146599946575, 13.598800453635588, 12.707463949122024, 11.670310890869139, 10.811292260274595, 9.79343074703977, 8.795139136887013, 7.793175449223608, 6.785708697854958, 5.792083834958804, 4.852288787605836, 3.9322062172002346, 4.899970665811434, 5.864956732427659, 6.765761963885561, 6.818549266039058, 7.779779015599672, 8.76414398429876, 9.705883445738397, 10.695214922233298, 11.759624237594721, 12.781011080060573, 11.788028371691352, 10.717611427921373, 9.740482628339313, 8.757063259079178, 7.747506150308709, 6.800104725331348, 5.837279508383707, 4.853285838561607, 3.9147619982459765, 2.9660670256924004, 3.911520552943563, 4.884472968962761, 5.827166559892607, 5.883359379215798, 6.841392759755724, 7.836941050987655, 8.79873269375994, 9.858525095917349, 10.864451167223391, 11.849642251978688, 10.805287640030986, 9.90083849155021, 8.938585258251058, 7.925327100653381, 6.9260517060603775, 5.9703612228276794, 4.9514158319656705, 3.9014334507245945, 2.934180897330295, 1.9863807786107492, 2.92887019463592, 3.915217355507174, 4.94157811747594, 4.858010891957989, 5.9257131836465975, 6.907775754277653, 7.898786600670013, 8.949764268825147, 9.923869850355548, 10.82557985097215, 9.842958481550458, 8.875535801151534, 7.931079047497073, 7.005728927263357, 6.069521057123573, 5.1127013965003245, 4.102159904047563, 3.0393121845349587, 1.9965854824412597, 0.9630238898390101, 2.0083493009601834, 3.049575550342306, 3.8923130869142057, 3.9298097254386173, 4.95931225988083, 5.99763419545332, 6.98142112498449, 7.981179534445934, 8.98013601394676, 9.959830290670212, 9.15282693924388, 8.198405738327606, 7.160408087510771, 6.130701860508618, 5.065734144221938, 4.108205316651611, 3.074987093353074, 2.0614352215900453, 1.0048636053146351, 0.0, 1.0731608013576062, 2.035266080166968, 2.960751857147421, 4.839251604843053, 5.786124890241188, 6.772156664243112, 7.792247055561208, 8.858981873776248, 9.814105915564992, 10.770407103434538, 9.780698509241958, 8.755040676700974, 7.766997866917826, 6.835839499115941, 5.8150756859350885, 4.886506468472494, 3.946058111815301, 2.93968512464893, 1.9447243261257678, 0.9601927313092182, 1.9248653690652053, 2.885668820008145, 3.885509187339642, 5.79959001809517, 6.780303009194881, 7.741479041924163, 8.678394221907613, 9.752667145054085, 10.825440886087408, 11.666866577829992, 10.711842846118879, 9.725698456143558, 8.742671332650831, 7.80533975394449, 6.751169552849041, 5.881339458681978, 4.979715573880278, 3.917776337275643, 2.8802531898776564, 1.9224346848964577, 2.903038194949812, 3.9451279486241004, 4.83540065020645, 6.8273430127700205, 7.799321999970385, 8.773370145211363, 9.611085934074811, 10.644667296192395, 11.671303420119632, 12.62682350230876, 11.680093098513453, 10.721181549354585, 9.711126938994852, 8.671579435786704, 7.714625175861853, 6.909747797955518, 5.92802961951335, 4.943007945463211, 3.8820999354015227, 2.8890794198537586, 3.8914930282204057, 4.903983868877335, 5.858757398056241], [5.899781354773685, 4.9501368416541345, 3.9770272059663987, 4.809713754435377, 5.863180458049351, 6.867878773138202, 7.88216067606004, 8.895864601912615, 9.685527561104731, 10.654672625320657, 11.642238462257907, 12.66871405254406, 13.485168085248306, 12.495175186606204, 11.538575655751627, 10.567539828494965, 9.529038894084364, 8.804789863395664, 7.819002585580668, 6.799366115186899, 6.871256820687551, 5.926172726334291, 5.00783351697524, 5.75011183342332, 6.68526523814862, 7.662478451099422, 8.723504339747496, 9.658730071302188, 10.645477077934649, 11.646826328235907, 12.600931586244688, 13.530564595645952, 14.42838894344056, 13.447112467075808, 12.465541048564363, 11.564112863895565, 10.601152492750332, 9.661606124575904, 8.674986807535802, 7.728060418979783, 7.888978083950246, 6.926828548123104, 6.04266497966717, 6.779005706576285, 7.694368999437141, 8.650816897598727, 9.700030611116743, 10.707952548875665, 11.620901388094554, 12.573730334652621, 13.576107438997004, 14.468064041575271, 15.406355891751076, 14.457771895678368, 13.484772005811601, 12.615088488523774, 11.583097910360076, 10.631045179718988, 9.667030305002553, 8.665826969791473, 8.921971930572663, 7.888237622962251, 7.091790142131489, 7.741516330568572, 8.64731889550181, 9.674588323684668, 10.65746718770362, 11.656551987223395, 12.602231111371507, 13.527296685510214, 14.57317069639211, 15.480427746053712, 16.37326069140398, 15.477192288294114, 14.429078167323988, 13.59534630182118, 12.525854832891387, 11.587725210901837, 10.590188881686505, 9.652681041951313, 9.866995230838167, 8.926412555221338, 8.041832848488136, 8.780389502550078, 9.706951598116273, 10.640599526824825, 11.629651172099846, 12.572387085722667, 13.554818571621945, 14.561291023815457, 15.514398174593197, 16.410519500541504, 16.610373988672155, 15.678924673171645, 14.647232245577184, 13.690401889629648, 12.841317266346593, 11.984867049048491, 11.584625736178017, 10.64403458289763, 10.814037771438658, 9.925922055273512, 9.08853117743051, 9.779402872893764, 10.778053481903127, 11.574191837647728, 12.614451664496686, 13.497635726507914, 14.470548586943469, 15.456200440563475, 16.39079042942127, 16.590995261791324, 15.609014354631714, 14.637603153917558, 13.694179732827514, 12.731780460792422, 11.885588729870255, 10.93680611461652, 11.873371325113922, 11.618827982398846, 11.80723985956202, 10.939662594145682, 10.1207937722826, 10.768606301882453, 11.744878553736527, 12.624990733247728, 13.62079846831147, 14.443729673224224, 15.401885737598912, 16.39198046752492, 16.506220251120528, 15.540439247332998, 14.609958708902532, 13.643860318602766, 12.636043538303115, 11.739680651249456, 10.95275470035301, 10.002186250969958, 10.958600464066501, 11.744475271162976, 11.617384554690771, 11.950724514784, 11.111944772601927, 11.792699399434973, 12.800545182719382, 13.610453409089734, 14.574365809136214, 15.390238455664324, 16.343701627827176, 16.51683765866714, 15.563678490904184, 14.608000021657196, 13.677864373040546, 12.650068770158443, 11.665793695766308, 10.723700180469955, 9.988822382530591, 9.056964702252067, 10.018881299020727, 10.736129966431047, 10.688784498586614, 11.5994566457564, 12.064899159718873, 12.859854396815317, 13.83193301608628, 14.592496471789376, 15.579000064331723, 16.45891868690491, 16.47288165623791, 15.553775608317785, 14.609973213259948, 13.656832532780294, 12.735199734053154, 11.677882217150485, 10.724273494160705, 9.786534088841922, 8.998171390600781, 8.054740650456738, 8.977510135791627, 9.77557775435035, 9.682292453876501, 10.625266405250388, 11.540971606703845, 12.489277845277453, 13.37693455619349, 14.37312081313851, 15.353629819155715, 16.28903602738256, 15.519068688537587, 14.583673176293653, 13.6303555840259, 12.65541655002432, 11.72186350952345, 10.793336385019643, 9.773902091237979, 8.800602710657563, 7.990059373976438, 7.103046408793498, 8.029587712426999, 8.710113589760356, 8.715661028680065, 9.585616999960259, 10.483288634454816, 11.491075080926858, 12.432973560700093, 13.497668153871704, 14.415812615441476, 15.432902240937507, 14.685019478057605, 13.708191054610964, 12.681049126061286, 11.625054891929047, 10.693906893822783, 9.746937508047399, 8.821737064643933, 7.840899119935328, 6.9709144232692735, 6.032431955286439, 6.9998177750827315, 7.698465374368537, 7.761087934328606, 8.616121613143765, 9.545381302830181, 10.505064076125336, 11.43833633707375, 12.425890240800953, 13.39530036670807, 14.452713258826353, 13.751285627069658, 12.870938723722587, 11.874644507398607, 10.910317907574864, 9.84126486124946, 8.857996098942442, 7.847352895422612, 6.868125280736154, 6.016171170837199, 5.031623758603385, 5.974863851263132, 6.766003162788282, 6.753887144169891, 7.680300670460115, 8.609914493179794, 9.605646027599573, 10.557249804312747, 11.551985798588968, 12.525639652277981, 13.567087935787033, 12.743471692226745, 11.8844530616322, 10.866591548397375, 9.868299938244618, 8.866336250581215, 7.858869499212564, 6.86524463631641, 5.924626740762765, 4.978513763751271, 4.0612993803121284, 4.906126456906568, 5.779714671375745, 5.756047845405463, 6.717277594966077, 7.690983182941154, 8.63272264438079, 9.62205412087569, 10.686463436237116, 11.722510225767808, 12.715492934137028, 11.790772229278979, 10.813643429696919, 9.830224060436784, 8.820666951666315, 7.873265526688954, 6.910440309741313, 5.926446639919213, 4.987922799603583, 4.012374572243436, 3.0728492674442567, 3.898425676452945, 4.8411192673827905, 4.810198577858191, 5.768231958398117, 6.763780249630049, 7.725571892402334, 8.785364294559743, 9.791290365865786, 10.84415397003545, 11.790400948482615, 10.973999292907818, 10.011746059608665, 8.998487902010988, 7.999212507417983, 7.043522024185285, 6.024576633323276, 4.9745942520822, 4.007341698687901, 3.032688325161785, 2.090198909136614, 2.929170062997358, 3.8684173161183337, 3.7848500906003832, 4.852552382288991, 5.834614952920046, 6.825625799312406, 7.8766034674675405, 8.85070904899794, 9.845450420580393, 10.828071790002086, 9.948696602509141, 9.00423984885468, 8.078889728620965, 7.14268185848118, 6.18586219785793, 5.175320705405169, 4.112472985892564, 3.0697462837988656, 2.0361846911966164, 1.0188036998560699, 1.9764147489846997, 2.8191522855565996, 2.8566489240810116, 3.8861514585232246, 4.924473394095714, 5.908260323626885, 6.908018733088328, 7.906975212589154, 8.886669489312606, 9.868683436747522, 9.271566539685214, 8.233568888868378, 7.203862661866225, 6.138894945579545, 5.181366118009217, 4.1481478947106805, 3.134596022947652, 2.0780244066722413, 1.0731608013576062, 0.0, 0.9621052788093623, 1.887591055789815, 3.805543864258982, 4.752417149657117, 5.738448923659041, 6.758539314977137, 7.825274133192176, 8.78039817498092, 9.736699362850466, 10.75317461025546, 9.739536984571979, 8.751494174788832, 7.820335806986947, 6.799571993806095, 5.8710027763435, 4.930554419686307, 3.9241814325199362, 2.929220633996774, 1.9446890391802247, 0.9800164014242376, 1.9277904915455437, 2.8518014467555712, 4.7658822775111, 5.74659526861081, 6.707771301340092, 7.644686481323542, 8.718959404470015, 9.791733145503338, 10.689242346769895, 11.644266078481008, 10.710194764014565, 9.727167640521838, 8.789836061815496, 7.735665860720047, 6.865835766552984, 5.964211881751285, 4.90227264514665, 3.864749497748663, 2.9069309927674643, 1.9581892273088441, 2.9946740489933354, 3.8016929096223797, 5.79363527218595, 6.765614259386314, 7.739662404627291, 8.57737819349074, 9.610959555608323, 10.63759567953556, 11.593115761724688, 12.624372188504626, 11.705677857225592, 10.695623246865857, 9.65607574365771, 8.699121483732858, 7.894244105826524, 6.912525927384357, 5.927504253334218, 4.866596243272529, 3.8735757277247647, 2.9914670821403506, 4.003957922797279, 4.825049657472171], [4.937696303123294, 4.047924503586284, 4.923499468221282, 5.756186016690259, 6.809652720304234, 7.814351035393084, 8.828632938314922, 9.8423368641675, 10.631999823359616, 11.601144887575543, 12.588710724512794, 13.487005479079336, 12.523062806438942, 11.53306990779684, 10.576470376942263, 9.6054345496856, 8.566933615275001, 7.842684584586301, 6.856897306771305, 5.837260836377537, 5.9100959511207325, 5.02396038826644, 5.954305779230124, 6.696584095678203, 7.631737500403503, 8.608950713354306, 9.669976602002379, 10.60520233355707, 11.591949340189531, 12.593298590490793, 13.547403848499574, 14.42928837470539, 13.466283664631195, 12.485007188266444, 11.503435769754999, 10.602007585086202, 9.63904721394097, 8.69950084576654, 7.71288152872644, 6.76595514017042, 6.927817214383428, 6.024616210055253, 6.989137241922053, 7.725477968831168, 8.640841261692024, 9.597289159853611, 10.646502873371627, 11.654424811130548, 12.567373650349436, 13.520202596907504, 14.52257970125189, 15.366787820634709, 14.444250612941712, 13.495666616869004, 12.522666727002237, 11.652983209714412, 10.620992631550713, 9.668939900909626, 8.704925026193191, 7.7037216909821105, 7.9608110610058445, 6.9860252848944, 7.970241951713448, 8.687988592823455, 9.593791157756693, 10.621060585939553, 11.603939449958503, 12.603024249478278, 13.54870337362639, 14.473768947765096, 15.519642958646992, 16.374786461258008, 15.411155412594617, 14.51508700948475, 13.466972888514624, 12.633241023011818, 11.563749554082024, 10.625619932092475, 9.628083602877142, 8.69057576314195, 8.90583436127135, 8.024200217153489, 8.920284658070095, 9.72686176480496, 10.653423860371156, 11.587071789079708, 12.576123434354729, 13.51885934797755, 14.501290833876828, 15.50776328607034, 16.46087043684808, 17.304878215745802, 16.38712803207146, 15.44169534724329, 14.537101763188966, 13.594825258516904, 12.543962975253011, 11.587085152842928, 10.622520457368655, 9.681929304088268, 9.85287690187184, 9.023709717205662, 9.966982987012472, 10.725875135148646, 11.72452574415801, 12.52066409990261, 13.560923926751569, 14.444107988762797, 15.417020849198352, 16.402672702818357, 17.337262691676152, 17.45420829771396, 16.472227390554348, 15.500816189840194, 14.55739276875015, 13.594993496715057, 12.73329659427156, 11.784513979017824, 10.960613500966302, 10.656722703589484, 10.846078989995203, 10.037450256077832, 10.99924558186456, 11.715078564137336, 12.69135081599141, 13.57146299550261, 14.567270730566353, 15.390201935479107, 16.348357999853796, 17.338452729779803, 17.369433287043165, 16.403652283255635, 15.47317174482517, 14.507073354525401, 13.49925657422575, 12.602893687172092, 11.800462564754314, 10.849894115371262, 9.996495185257139, 10.782369992353614, 10.65527927588141, 11.04851217671615, 11.990396582183887, 12.739171661689856, 13.747017444974265, 14.556925671344617, 15.520838071391097, 16.336710717919207, 17.29017389008206, 17.380050694589773, 16.426891526826818, 15.471213057579831, 14.541077408963183, 13.513281806081078, 12.529006731688943, 11.58691321639259, 10.836530246931895, 9.904672566653371, 9.056776020211364, 9.774024687621685, 9.726679219777253, 10.637351366947039, 11.613985563072825, 12.496372573962816, 13.465499556985709, 14.422811634675405, 15.32473808826511, 16.270103115098323, 17.250545408186824, 16.41698864424042, 15.473186249182584, 14.52004556870293, 13.59841276997579, 12.54109525307312, 11.587486530083341, 10.649747124764557, 9.845879255002085, 8.90244851485804, 8.015404856982265, 8.813472475540987, 8.72018717506714, 9.663161126441027, 10.578866327894483, 11.52717256646809, 12.41482927738413, 13.411015534329149, 14.391524540346355, 15.3269307485732, 16.2967324404865, 15.446886212216288, 14.493568619948535, 13.518629585946956, 12.585076545446086, 11.656549420942278, 10.637115127160614, 9.663815746580198, 8.83776723837774, 7.9507542731948, 7.067482433617636, 7.748008310950993, 7.753555749870704, 8.623511721150894, 9.521183355645453, 10.528969802117496, 11.47086828189073, 12.535562875062343, 13.453707336632116, 14.470796962128146, 15.507716536962514, 14.5714040905336, 13.544262161983921, 12.488267927851682, 11.557119929745419, 10.610150543970034, 9.684950100566569, 8.704112155857963, 7.818622287670576, 6.8801398196877415, 6.037712496273369, 6.736360095559174, 6.798982655519244, 7.654016334334401, 8.583276024020819, 9.542958797315974, 10.47623105826439, 11.463784961991593, 12.43319508789871, 13.490607980016993, 14.554615018419454, 13.772220421537009, 12.775926205213029, 11.811599605389285, 10.74254655906388, 9.731293725531668, 8.710565931345249, 7.73133831665879, 6.863879035238502, 5.8793316230046875, 5.0127585724537695, 5.8038978839789195, 5.791781865360528, 6.718195391650752, 7.647809214370431, 8.643540748790212, 9.595144525503386, 10.589880519779607, 11.56353437346862, 12.604982656977672, 13.642135715230557, 12.785734759446619, 11.767873246211796, 10.769581636059039, 9.767617948395635, 8.760151197026985, 7.76652633413083, 6.7878397766854, 5.841726799673906, 4.909007244713431, 3.9440211780972056, 4.817609392566382, 4.793942566596101, 5.755172316156715, 6.728877904131792, 7.670617365571429, 8.65994884206633, 9.724358157427755, 10.760404946958447, 11.753387655327668, 12.692053927093397, 11.714925127511338, 10.731505758251203, 9.721948649480735, 8.774547224503374, 7.811722007555733, 6.8277283377336335, 5.889204497418003, 4.875587608166072, 3.9360623033668927, 2.9363203976435823, 3.879013988573428, 3.8480932990488292, 4.806126679588756, 5.801674970820687, 6.763466613592972, 7.823259015750382, 8.829185087056423, 9.882048691226087, 10.828295669673254, 11.858691881990326, 10.95663253365917, 9.899769599825408, 8.900494205232404, 7.944803721999706, 6.925858331137697, 5.875875949896621, 4.908623396502321, 3.895901361084421, 2.95341194505925, 1.9670647841879958, 2.9063120373089717, 2.8227448117910208, 3.8904471034796284, 4.872509674110684, 5.863520520503044, 6.914498188658178, 7.888603770188578, 8.883345141771033, 9.865966511192726, 10.83338919159165, 9.966345127664042, 9.040995007430325, 8.104787137290542, 7.147967476667293, 6.137425984214532, 5.074578264701927, 4.031851562608228, 2.9982899700059784, 1.9809089786654321, 1.0143094701753375, 1.8570470067472373, 1.894543645271649, 2.924046179713862, 3.9623681152863517, 4.946155044817522, 5.945913454278966, 6.944869933779792, 7.924564210503244, 8.906578157938162, 9.860999358854436, 9.19567416767774, 8.165967940675587, 7.1010002243889065, 6.143471396818579, 5.110253173520042, 4.0967013017570135, 3.0401296854816033, 2.035266080166968, 0.9621052788093623, 0.0, 0.9254857769804529, 2.84343858544962, 3.7903118708477552, 4.776343644849678, 5.796434036167774, 6.863168854382813, 7.818292896171558, 8.774594084041103, 9.791069331446097, 10.686009246826861, 9.697966437043714, 8.76680806924183, 7.746044256060978, 6.817475038598384, 5.8770266819411905, 4.87065369477482, 3.8756928962516577, 2.8911613014351083, 1.926488663679121, 0.9656852127361814, 1.8896961679462092, 3.8037769987017374, 4.784489989801449, 5.74566602253073, 6.68258120251418, 7.756854125660653, 8.829627866693977, 9.72713706796053, 10.682160799671644, 11.65666702626945, 10.673639902776722, 9.73630832407038, 8.682138122974932, 7.812308028807868, 6.910684144006168, 5.8487449074015325, 4.811221760003546, 3.853403255022348, 2.9046614895637273, 2.032568770183973, 2.8395876308130177, 4.831529993376588, 5.803508980576952, 6.777557125817929, 7.615272914681378, 8.64885427679896, 9.675490400726197, 10.631010482915325, 11.662266909695262, 12.621178458854132, 11.642095509120743, 10.602548005912595, 9.645593745987743, 8.840716368081408, 7.85899818963924, 6.873976515589101, 5.813068505527412, 4.820047989979648, 3.9379393443952333, 3.1017455847294286, 3.8629443786628084], [4.012210526142842, 4.861737473508293, 5.848985245201735, 6.681671793670713, 7.735138497284687, 8.739836812373538, 9.754118715295375, 10.767822641147951, 11.557485600340069, 12.526630664555995, 13.514196501493245, 12.561519702098884, 11.59757702945849, 10.607584130816388, 9.650984599961811, 8.67994877270515, 7.641447838294548, 6.917198807605848, 5.931411529790852, 4.911775059397083, 4.98461017414028, 5.837773358188449, 6.81623056498163, 7.622069872658656, 8.557223277383956, 9.534436490334759, 10.595462378982832, 11.530688110537524, 12.517435117169985, 13.518784367471245, 14.433435607126203, 13.503802597724938, 12.540797887650744, 11.559521411285992, 10.577949992774547, 9.676521808105749, 8.713561436960516, 7.774015068786087, 6.787395751745986, 5.840469363189967, 6.002331437402974, 6.838429179977262, 7.85106202767356, 8.650963745811621, 9.566327038672478, 10.522774936834065, 11.57198865035208, 12.579910588111002, 13.49285942732989, 14.445688373887958, 15.40861145987852, 14.441302043654257, 13.51876483596126, 12.570180839888552, 11.597180950021786, 10.727497432733959, 9.69550685457026, 8.743454123929173, 7.7794392492127376, 6.778235914001657, 7.035325284025391, 7.799838254816409, 8.784054921635457, 9.613474369803908, 10.519276934737146, 11.546546362920006, 12.529425226938958, 13.528510026458733, 14.474189150606843, 15.39925472474555, 16.445128735627446, 15.449300684277556, 14.485669635614165, 13.589601232504299, 12.541487111534172, 11.707755246031365, 10.638263777101571, 9.700134155112021, 8.702597825896689, 7.765089986161496, 7.980348584290896, 8.838013187075497, 9.734097627992103, 10.652347541785414, 11.578909637351611, 12.512557566060163, 13.501609211335184, 14.444345124958005, 15.426776610857283, 16.433249063050795, 17.35621090682708, 16.37939243876535, 15.461642255091007, 14.516209570262838, 13.611615986208514, 12.66933948153645, 11.618477198272558, 10.661599375862474, 9.697034680388201, 8.756443527107814, 8.927391124891386, 9.83752268712767, 10.78079595693448, 11.6513609121291, 12.650011521138465, 13.446149876883066, 14.486409703732024, 15.369593765743252, 16.342506626178807, 17.328158479798812, 18.262748468656607, 17.40143601481828, 16.463001889131448, 15.557531089516925, 14.596166871491542, 13.5489796775444, 12.574205734748896, 11.568158603409612, 10.63159339291221, 9.73123692660903, 9.92059321301475, 10.85126322599984, 11.813058551786568, 12.640564341117791, 13.616836592971865, 14.496948772483066, 15.492756507546808, 16.315687712459564, 17.27384377683425, 18.263938506760258, 18.22082511088093, 17.2550441070934, 16.324563568662935, 15.358465178363167, 14.350648398063516, 13.454285511009857, 12.651854388592076, 11.701285939209024, 10.807419931494419, 9.924849619501583, 9.742775312481792, 10.733442895380549, 11.641454173209318, 12.638041794362708, 13.571401613372151, 14.479368920394592, 15.403886566480164, 16.3954440129541, 17.40003294089466, 18.23144251842754, 17.278283350664584, 16.322604881417597, 15.392469232800948, 14.364673629918844, 13.380398555526709, 12.438305040230356, 11.687922070769657, 10.756064390491133, 9.867700766448644, 8.916504314769654, 8.814175256377634, 9.724847403547422, 10.688499786092372, 11.570886796982364, 12.540013780005253, 13.49732585769495, 14.399252311284656, 15.344617338117867, 16.32505963120637, 17.268380468078185, 16.32457807302035, 15.371437392540695, 14.449804593813555, 13.392487076910886, 12.438878353921107, 11.501138948602323, 10.697271078839847, 9.753840338695804, 8.826329603219545, 7.955952102688956, 7.807683211667523, 8.75065716304141, 9.65338055091403, 10.601686789487637, 11.489343500403674, 12.485529757348694, 13.4660387633659, 14.401444971592746, 15.371246663506044, 16.298278036054054, 15.3449604437863, 14.370021409784721, 13.436468369283851, 12.507941244780044, 11.48850695099838, 10.515207570417964, 9.689159062215502, 8.802146097032564, 7.878407179854917, 6.890487938098962, 6.841051786471087, 7.698025944170442, 8.595697578665, 9.603484025137043, 10.545382504910277, 11.610077098081888, 12.52822155965166, 13.54531118514769, 14.582230759982059, 15.422795914371365, 14.395653985821687, 13.339659751689448, 12.408511753583184, 11.4615423678078, 10.536341924404335, 9.555503979695729, 8.670014111508339, 7.731531643525505, 6.879289108318044, 5.878839722707143, 5.886478692119627, 6.728530557353948, 7.657790247040365, 8.61747302033552, 9.550745281283934, 10.538299185011137, 11.507709310918255, 12.565122203036537, 13.629129241439, 14.62361224537477, 13.627318029050791, 12.662991429227048, 11.593938382901644, 10.582685549369431, 9.561957755183013, 8.582730140496555, 7.7152708590762655, 6.730723446842451, 5.864150396291533, 4.946377511126888, 4.879277901960911, 5.792709614670299, 6.722323437389978, 7.718054971809759, 8.669658748522933, 9.664394742799153, 10.638048596488167, 11.679496879997219, 12.716649938250104, 13.637126583284385, 12.61926507004956, 11.620973459896803, 10.6190097722334, 9.61154302086475, 8.617918157968594, 7.639231600523164, 6.69311862351167, 5.7603990685511945, 4.795413001934969, 3.9600890197143515, 3.8684567896156477, 4.829686539176262, 5.803392127151339, 6.745131588590976, 7.734463065085876, 8.7988723804473, 9.834919169977992, 10.827901878347213, 11.86619170935108, 12.566316951349103, 11.582897582088968, 10.573340473318499, 9.625939048341138, 8.663113831393497, 7.679120161571397, 6.740596321255767, 5.726979432003835, 4.787454127204656, 3.7877122214813457, 3.0214936157213974, 2.9226075220683763, 3.8806409026083024, 4.876189193840234, 5.837980836612519, 6.897773238769928, 7.90369931007597, 8.956562914245634, 9.902809892692801, 10.933206105009873, 11.808024357496935, 10.751161423663174, 9.75188602907017, 8.79619554583747, 7.7772501549754605, 6.7272677737343844, 5.760015220340085, 4.747293184922184, 3.804803768897013, 2.818456608025759, 1.9808262603285187, 1.897259034810568, 2.964961326499176, 3.947023897130231, 4.938034743522591, 5.9890124116777255, 6.963117993208125, 7.957859364790579, 8.940480734212272, 9.907903414611196, 10.852360168265657, 9.966480784410779, 9.030272914270995, 8.073453253647745, 7.062911761194984, 6.000064041682379, 4.957337339588681, 3.9237757469864314, 2.906394755645885, 1.8657012940131006, 0.9315612297667845, 0.9690578682911963, 1.9985604027334096, 3.036882338305899, 4.02066926783707, 5.020427677298513, 6.019384156799339, 6.999078433522792, 7.981092380957708, 8.935513581873982, 9.973511232690818, 9.09145371765604, 8.02648600136936, 7.068957173799032, 6.0357389505004955, 5.022187078737467, 3.9656154624620563, 2.960751857147421, 1.887591055789815, 0.9254857769804529, 0.0, 1.917952808469167, 2.8648260938673022, 3.850857867869226, 4.870948259187322, 5.937683077402361, 6.892807119191105, 7.849108307060652, 8.865583554465646, 9.879324245084764, 10.62345221402417, 9.692293846222285, 8.671530033041432, 7.7429608155788365, 6.802512458921643, 5.796139471755272, 4.80117867323211, 3.816647078415561, 2.851974440659574, 1.8911709897166342, 0.9642103909657563, 2.8782912217212844, 3.859004212820995, 4.820180245550277, 5.757095425533727, 6.8313683486802, 7.904142089713524, 8.801651290980079, 9.756675022691192, 10.742819412666513, 11.599125679757176, 10.661794101050834, 9.607623899955385, 8.737793805788321, 7.836169920986621, 6.774230684381986, 5.7367075369839995, 4.7788890320028, 3.8301472665441807, 2.948916517819727, 1.9141018538325647, 3.9060442163961344, 4.8780232035964985, 5.852071348837476, 6.689787137700924, 7.723368499818507, 8.750004623745744, 9.705524705934872, 10.73678113271481, 11.69569268187368, 12.567581286101195, 11.528033782893047, 10.571079522968196, 9.766202145061861, 8.784483966619693, 7.7994622925695545, 6.738554282507865, 5.745533766960101, 4.863425121375687, 3.9155585546514375, 2.937458601682356], [4.001742552680496, 4.851269500045947, 5.844611835589936, 6.744083588788985, 7.79755029240296, 8.80224860749181, 9.816530510413648, 10.830234436266224, 11.619897395458342, 12.589042459674268, 11.67004248391587, 10.643566893629718, 9.679624220989323, 8.689631322347221, 7.733031791492644, 6.7619959642359815, 5.723495029825381, 4.999245999136681, 4.018042619663825, 3.0770870468813545, 4.9463714568781185, 5.827305384726103, 6.805762591519285, 7.684481667776929, 8.619635072502229, 9.596848285453031, 10.657874174101105, 11.593099905655796, 12.579846912288257, 13.469588056665817, 12.515482798657036, 11.585849789255771, 10.622845079181577, 9.641568602816825, 8.65999718430538, 7.758568999636582, 6.795608628491349, 5.937458068226593, 4.950838751186492, 4.005781350674238, 5.927554540062065, 6.8279612065149164, 7.8405940542112145, 8.713375540929894, 9.62873883379075, 10.585186731952337, 11.634400445470353, 12.642322383229274, 13.555271222448162, 14.40276363121072, 13.490658651409353, 12.52334923518509, 11.600812027492093, 10.652228031419385, 9.679228141552619, 8.809544624264792, 7.777554046101094, 6.906897123369678, 5.942882248653243, 4.943547901485928, 6.960548386684482, 7.7893702813540635, 8.773586948173111, 9.675886164922181, 10.581688729855419, 11.608958158038279, 12.59183702205723, 13.590921821577005, 14.536600945725116, 15.356329982068312, 14.557422380947116, 13.53134787580839, 12.567716827144999, 11.671648424035132, 10.623534303065005, 9.80071173129702, 8.731220262367225, 7.8654461425962925, 6.86790981338096, 5.930401973645767, 7.859656118620273, 8.827545213613151, 9.723629654529757, 10.714759336903686, 11.641321432469883, 12.574969361178436, 13.564021006453457, 14.506756920076278, 15.489188405975556, 16.390324320373555, 15.438258098357913, 14.461439630296184, 13.54368944662184, 12.598256761793671, 11.693663177739348, 10.762295966802105, 9.711433683538212, 8.826911363346746, 7.862346667872471, 6.921755514592085, 8.806698659220764, 9.761904660717494, 10.753311674320747, 11.713772707247372, 12.712423316256737, 13.508561672001338, 14.548821498850296, 15.432005560861525, 16.40491842129708, 17.367991644795552, 16.496800006449657, 15.483483206349112, 14.54504908066228, 13.639578281047758, 12.689123356757197, 11.641936162810055, 10.66716222001455, 9.733470590893882, 8.79690538039648, 7.896548914093302, 9.799900747344127, 10.775486243525917, 11.785574269172836, 12.702976136236064, 13.679248388090137, 14.559360567601338, 15.55516830266508, 16.378099507577836, 17.336255571952524, 18.303771671756998, 17.445467363671355, 16.520840264929923, 15.590359726499457, 14.545968001701503, 13.538151221401852, 12.559441562897794, 11.599996249531795, 10.668090454540444, 9.761023696105642, 8.885591202011677, 9.754735354285758, 10.745402937184515, 11.653414215013283, 12.650001836166672, 13.583361655176118, 14.491328962198558, 15.41584660828413, 16.407404054758068, 17.411992982698628, 18.25176669992743, 18.44113730685167, 17.485458837604682, 16.48494467178192, 15.418862863124007, 14.434587788731871, 13.492494273435518, 12.545169683536859, 11.613312003258335, 10.700742861151417, 9.893936506743605, 8.826135298181601, 9.736807445351387, 10.700459827896337, 11.582846838786327, 12.55197382180922, 13.509285899498916, 14.411212353088622, 15.356577379921834, 16.337019673010335, 17.288704649578076, 18.242530881489518, 17.28939020100986, 16.36775740228272, 15.310439885380053, 14.356831162390273, 13.41909175707149, 12.578755000649991, 11.635324260505946, 10.676635525064212, 9.806258024533623, 7.819643253471488, 8.762617204845375, 9.665340592717994, 10.613646831291602, 11.50130354220764, 12.49748979915266, 13.477998805169866, 14.413405013396712, 15.38320670531001, 16.318602217553945, 17.26291325225547, 16.287974218253886, 15.354421177753018, 14.42589405324921, 13.406459759467547, 12.43316037888713, 11.607111870684673, 10.683630018842706, 9.728713101699583, 8.74079385994363, 6.853011828275052, 7.709985985974407, 8.607657620468965, 9.615444066941008, 10.557342546714242, 11.622037139885855, 12.540181601455627, 13.557271226951658, 14.594190801786025, 15.571019225232666, 16.313606794290855, 15.257612560158615, 14.326464562052351, 13.379495176276967, 12.454294732873501, 11.473456788164896, 10.587966919977507, 9.649484451994674, 8.729595030162711, 7.72914564455181, 5.898438733923592, 6.740490599157913, 7.66975028884433, 8.629433062139485, 9.5627053230879, 10.550259226815104, 11.519669352722222, 12.577082244840504, 13.641089283242966, 14.708240995299889, 15.545270837519958, 14.580944237696215, 13.511891191370811, 12.500638357838598, 11.47991056365218, 10.500682948965721, 9.633223667545433, 8.648676255311619, 7.7821032047607, 6.796683432971555, 4.891237943764876, 5.804669656474264, 6.734283479193943, 7.70450480547699, 8.656108582190164, 9.650844576466385, 10.624498430155398, 11.66594671366445, 12.683401453538949, 13.654759347945015, 14.537217878518726, 13.53892626836597, 12.536962580702566, 11.529495829333916, 10.535870966437761, 9.557184408992331, 8.611071431980836, 7.678351877020361, 6.713365810404136, 5.810394941559018, 3.8804168314196126, 4.8416465809802265, 5.815352168955304, 6.731581422258206, 7.720912898753107, 8.785322214114531, 9.821369003645223, 10.77688359667398, 11.73070199059118, 12.65947917988124, 13.500850390558135, 12.491293281787666, 11.543891856810305, 10.581066639862664, 9.597072970040564, 8.658549129724934, 7.644932240473002, 6.705406935673823, 5.705665029950513, 4.871799537566064, 2.934567563872341, 3.8926009444122673, 4.888149235644199, 5.768882335441494, 6.828674737598903, 7.834600808904945, 8.871623394871852, 9.767320173932902, 10.797716386249974, 11.724376660259741, 12.597706851709562, 11.669838837539336, 10.714148354306637, 9.695202963444627, 8.645220582203551, 7.677968028809252, 6.665245993391351, 5.72275657736618, 4.736409416494926, 3.8987790687976855, 1.9092190766145327, 2.976921368303141, 3.958983938934196, 4.843112356476647, 5.894090024631781, 6.833435972628088, 7.82236964603068, 8.804991015452373, 9.772413695851297, 10.716870449505757, 11.642220569739473, 10.807386251861605, 9.854586784074959, 8.844045291622198, 7.878563789378012, 6.835837087284313, 5.802275494682063, 4.824347564115052, 3.7836541024822674, 2.8495140382359514, 0.9784642690956498, 1.9935361332853665, 3.0002188040370705, 3.8851795490771703, 4.884937958538614, 5.88389443803944, 6.8635887147628925, 7.845602662197809, 8.800023863114083, 9.838021513930919, 10.764355270857115, 9.80359933895997, 8.846070511389641, 7.812852288091104, 6.882297161132944, 5.844115210157688, 4.839251604843053, 3.805543864258982, 2.84343858544962, 1.917952808469167, 0.0, 0.9468732853981353, 1.9329050594000587, 2.9529954507181544, 4.019730268933193, 4.974854310721938, 5.931155498591484, 6.947630745996478, 7.973288578537462, 8.961331388320609, 9.754705641340557, 8.733941828159704, 7.80537261069711, 6.8649242540399165, 5.858551266873546, 4.863590468350384, 3.8790588735338343, 2.9143862357778474, 1.9535827848349077, 0.9537424175034107, 1.0436032092055552, 1.9410514043518283, 2.90222743708111, 3.83914261706456, 4.913415540211033, 5.986189281244357, 6.883698482510912, 7.8387222142220265, 8.824866604197346, 9.807893727690074, 10.724205896169106, 9.670035695073658, 8.800205600906594, 7.898581716104894, 6.8366424795002585, 5.799119332102272, 4.841300827121073, 3.892559061662454, 2.9384485443573816, 1.903633880370219, 2.0713562038804056, 2.9600703951273317, 3.934118540368309, 4.7718343292317575, 5.80541569134934, 6.832051815276577, 7.787571897465706, 8.818828324245644, 9.777739873404514, 10.850146795086237, 11.59044557801132, 10.633491318086469, 9.828613940180134, 8.846895761737965, 7.861874087687827, 6.800966077626138, 5.807945562078374, 4.9175814218460205, 3.905090581189092, 2.92699062822001], [4.948615838078632, 5.798142785444083, 6.791485120988072, 7.690956874187121, 8.744423577801095, 9.749121892889946, 10.763403795811783, 11.777107721664361, 12.566770680856477, 11.710735035454986, 10.723169198517736, 9.696693608231584, 8.73275093559119, 7.742758036949087, 6.786158506094509, 5.815122678837846, 4.776621744427246, 4.052372713738546, 3.071169334265689, 4.02396033227949, 5.891481960548257, 6.774178670124239, 7.75263587691742, 8.631354953175064, 9.566508357900364, 10.543721570851167, 11.60474745949924, 12.539973191053932, 13.526720197686393, 12.522714771267683, 11.568609513258902, 10.638976503857638, 9.675971793783443, 8.694695317418692, 7.713123898907245, 6.811695714238446, 5.848735343093214, 4.990584782828457, 4.003965465788356, 4.950891854344376, 6.872665043732203, 7.774834491913052, 8.78746733960935, 9.66024882632803, 10.575612119188886, 11.532060017350473, 12.581273730868489, 13.58919566862741, 14.408719292370654, 13.455890345812586, 12.54378536601122, 11.576475949786957, 10.653938742093958, 9.70535474602125, 8.732354856154483, 7.862671338866656, 6.8306807607029585, 5.9600238379715424, 4.9960089632551075, 5.888658405156066, 7.90565889035462, 8.736243566752199, 9.720460233571247, 10.622759450320316, 11.528562015253554, 12.555831443436414, 13.538710307455364, 14.537795106975139, 15.35555376357416, 14.409456696670178, 13.610549095548983, 12.584474590410254, 11.620843541746863, 10.724775138636996, 9.67666101766687, 8.853838445898884, 7.78434697696909, 7.014893259306573, 6.047956822480533, 6.8755124773159055, 8.804766622290412, 9.774418499011286, 10.670502939927893, 11.661632622301822, 12.588194717868017, 13.52184264657657, 14.51089429185159, 15.453630205474411, 16.37719821451644, 15.443451034975421, 14.49138481295978, 13.514566344898048, 12.596816161223705, 11.651383476395536, 10.746789892341212, 9.81542268140397, 8.764560398140077, 7.976358480057026, 7.067941781357142, 7.866866018262223, 9.751809162890902, 10.707015164387633, 11.698422177990885, 12.660645992645508, 13.659296601654871, 14.455434957399472, 15.49569478424843, 16.37887884625966, 17.351791706695213, 16.42111835939742, 15.549926721051524, 14.536609920950976, 13.598175795264144, 12.692704995649622, 11.742250071359061, 10.69506287741192, 9.720288934616415, 8.939065704378553, 8.00250049388115, 8.84165941776344, 10.745011251014265, 11.102390839389017, 11.842770609290278, 12.763675098108264, 13.728608448548043, 14.566371802429634, 15.42890972125019, 16.413408609339484, 17.371564673714172, 17.356898386358864, 16.49859407827322, 15.573966979531788, 14.643486441101322, 13.599094716303368, 12.591277936003717, 11.612568277499658, 10.65312296413366, 9.873685568025115, 8.966618809590313, 9.830701705681815, 10.701608639683892, 10.0913289187507, 10.851619608970951, 11.739582000555744, 12.672941819565187, 13.580909126587628, 14.475342380425445, 15.466899826899384, 16.471488754839942, 17.311262472068744, 17.51302290527089, 16.557344436023904, 15.556830270201141, 14.490748461543227, 13.506473387151091, 12.564379871854738, 11.617055281956079, 10.818907116743006, 9.906337974636088, 10.839047010413744, 9.773008583579735, 9.018394949829114, 9.898665221854005, 10.6724270031754, 11.64155398619829, 12.598866063887986, 13.470708125229937, 14.416073152063149, 15.396515445151648, 16.34820042171939, 17.31103321119706, 17.416285750427758, 16.456622472933013, 15.392894091791334, 14.439285368801555, 13.501545963482771, 12.619671331551386, 11.821131168538336, 10.947709137865187, 10.753131309931758, 8.766516538869624, 8.044204709323102, 8.863545986675662, 9.703226995680673, 10.59088370659671, 11.58706996354173, 12.53749457731118, 13.472900785538027, 14.442702477451325, 15.37809798969526, 16.33141558196301, 17.234847503652023, 16.30129446315115, 15.372767338647346, 14.353333044865682, 13.380033664285266, 12.553985156082806, 11.630503304240843, 10.67558638709772, 9.687667145341765, 7.799885113673187, 6.975296326300364, 7.805863014426633, 8.705024231330079, 9.646922711103313, 10.68153291202717, 11.599677373596942, 12.616766999092972, 13.65368657392734, 14.63051499737398, 15.648307599932537, 16.20448584555675, 15.273337847450486, 14.326368461675102, 13.401168018271637, 12.420330073563031, 11.534840205375643, 10.59635773739281, 9.676468315560847, 8.676018929949946, 6.845312019321727, 6.00580093948387, 6.867955682801999, 7.688928834280801, 8.622201095229215, 9.609754998956419, 10.579165124863536, 11.636578016981819, 12.70058505538428, 13.761367709901752, 14.672924076406353, 15.52781752309435, 14.458764476768946, 13.447511643236734, 12.426783849050315, 11.447556234363857, 10.580096952943569, 9.595549540709754, 8.728976490158836, 7.743556718369691, 5.838111229163012, 5.069979996800221, 5.932488873151612, 6.757631520078855, 7.709235296792029, 8.70397129106825, 9.677625144757263, 10.719073428266315, 11.736528168140811, 12.707886062546878, 13.66487111740512, 14.485799553764105, 13.483835866100701, 12.476369114732051, 11.482744251835896, 10.504057694390466, 9.557944717378971, 8.625225162418497, 7.660239095802272, 6.757268226957153, 4.827290116817748, 4.106956921306183, 4.993031929879993, 5.784708136860071, 6.774039613354971, 7.838448928716396, 8.874495718247088, 9.830010311275844, 10.783828705193045, 11.712605894483104, 12.622672334860118, 13.438166567185801, 12.49076514220844, 11.5279399252608, 10.5439462554387, 9.60542241512307, 8.591805525871138, 7.652280221071958, 6.652538315348648, 5.818672822964199, 3.881440849270476, 3.070280705336956, 4.065828996568888, 4.822009050043358, 5.881801452200768, 6.887727523506809, 7.924750109473716, 8.820446888534766, 9.850843100851838, 10.777503374861606, 11.650833566311427, 12.616712122937471, 11.661021639704773, 10.642076248842763, 9.592093867601687, 8.624841314207387, 7.6121192787894865, 6.669629862764316, 5.683282701893061, 4.8456523541958205, 2.8560923620126677, 2.1121137199908855, 3.0941762906219408, 3.8962390710785115, 4.947216739233646, 5.886562687229953, 6.875496360632544, 7.858117730054237, 8.825540410453161, 9.769997164107622, 10.695347284341338, 11.631555154481122, 10.801460069473094, 9.790918577020333, 8.825437074776147, 7.782710372682448, 6.749148780080199, 5.771220849513187, 4.730527387880403, 3.796387323634087, 1.925337554493785, 1.046662847887231, 2.053345518638935, 2.938306263679035, 3.9380646731404787, 4.937021152641305, 5.916715429364757, 6.898729376799674, 7.8531505777159465, 8.891148228532781, 9.920854455534935, 10.750472624358105, 9.792943796787776, 8.75972557348924, 7.829170446531079, 6.7909884955558235, 5.786124890241188, 4.752417149657117, 3.7903118708477552, 2.8648260938673022, 0.9468732853981353, 0.0, 0.9860317740019234, 2.006122165320019, 3.072856983535058, 4.027981025323803, 4.9842822131933495, 6.000757460598344, 7.026415293139327, 8.014458102922475, 8.94561647072436, 9.68081511355784, 8.752245896095245, 7.811797539438052, 6.805424552271681, 5.810463753748519, 4.82593215893197, 3.861259521175983, 2.900456070233043, 1.900615702901546, 1.9904764946036906, 0.994178118953693, 1.9553541516829744, 2.8922693316664247, 3.9665422548128975, 5.039315995846222, 5.9368251971127775, 6.891848928823892, 7.877993318799212, 8.861020442291938, 9.79835202099828, 10.616908980471793, 9.74707888630473, 8.845455001503028, 7.783515764898394, 6.7459926175004075, 5.788174112519209, 4.83943234706059, 3.885321829755517, 2.8505071657683545, 3.018229489278541, 2.0131971097291963, 2.9872452549701736, 3.824961043833622, 4.858542405951205, 5.885178529878441, 6.840698612067571, 7.871955038847508, 8.830866588006376, 9.9032735096881, 10.742935169875286, 11.580364603484604, 10.775487225578269, 9.793769047136102, 8.808747373085962, 7.747839363024274, 6.75481884747651, 5.864454707244156, 4.851963866587227, 3.8738639136181456], [5.934647612080555, 6.784174559446006, 7.777516894989995, 8.676988648189045, 9.73045535180302, 10.73515366689187, 11.749435569813707, 12.739801536910004, 11.700263733170088, 10.734694028629697, 9.747128191692447, 8.720652601406295, 7.7567099287659005, 6.7667170301237975, 5.81011749926922, 4.839081672012558, 3.800580737601957, 3.076331706913257, 4.017480392898962, 5.0099921062814134, 6.83779301918153, 7.760210444126162, 8.738667650919345, 9.617386727176989, 10.552540131902289, 11.529753344853091, 12.590779233501165, 13.526004965055856, 12.567789793637944, 11.546673764442394, 10.592568506433613, 9.662935497032349, 8.699930786958154, 7.718654310593402, 6.737082892081956, 5.835654707413158, 4.872694336267926, 4.020078497738571, 4.950276524421629, 5.897202912977649, 7.818976102365476, 8.760866265914975, 9.773499113611274, 10.646280600329954, 11.56164389319081, 12.518091791352397, 13.567305504870413, 14.402504601183935, 13.432678285545364, 12.479849338987297, 11.56774435918593, 10.600434942961668, 9.677897735268669, 8.72931373919596, 7.756313849329193, 6.886630332041369, 5.85463975387767, 4.990356768313587, 5.942320021888381, 6.8349694637893394, 8.851969948987893, 9.722275340754123, 10.706492007573171, 11.60879122432224, 12.514593789255478, 13.541863217438339, 14.52474208145729, 15.33568494804244, 14.379512756748872, 13.433415689844889, 12.634508088723694, 11.608433583584965, 10.644802534921574, 9.748734131811705, 8.700620010841579, 7.877797439073595, 6.808305970143802, 6.045226189648618, 6.994267881113807, 7.821823535949179, 9.751077680923684, 10.76045027301321, 11.656534713929817, 12.647664396303746, 13.574226491869943, 14.507874420578496, 15.496926065853517, 16.366339837797714, 15.401157207691153, 14.467410028150132, 13.515343806134489, 12.538525338072759, 11.620775154398416, 10.675342469570245, 9.770748885515921, 8.83938167457868, 7.7885193913147885, 7.006691410399071, 7.983928314937383, 8.813177076895496, 10.698120221524174, 11.653326223020905, 11.984510679421492, 12.766846753095031, 13.734519776841454, 14.631138924027711, 15.449224751063047, 16.373470782053868, 16.41137587659326, 15.445077352572131, 14.573885714226233, 13.560568914125687, 12.622134788438855, 11.716663988824331, 10.766209064533772, 9.71902187058663, 8.744247927791125, 8.054752344831043, 8.918487027461392, 9.787970476396712, 11.691322309647537, 11.919769703793527, 10.952248084569403, 11.777643324106341, 12.74257667454612, 13.580340028427711, 14.442877947248263, 15.427376835337558, 16.385532899712246, 16.380857379533577, 15.522553071447932, 14.597925972706498, 13.667445434276033, 12.623053709478079, 11.615236929178428, 10.63652727067437, 9.67708195730837, 8.989372208477604, 9.882605343170555, 10.777012764315087, 11.687640413685815, 10.90870778315521, 9.961097084250076, 10.753550226553822, 11.686910045563264, 12.594877352585705, 13.489310606423519, 14.480868052897458, 15.485456980838016, 16.325230698066818, 16.536981898445603, 15.581303429198615, 14.580789263375852, 13.514707454717938, 12.530432380325802, 11.58833886502945, 10.64101427513079, 9.934593757195495, 10.82232450821633, 11.785358069047016, 10.759040357581657, 9.919995124179307, 9.00814269713313, 9.686395229173478, 10.655522212196367, 11.612834289886063, 12.48467635122801, 13.430041378061222, 14.410483671149722, 15.362168647717466, 16.325001437195137, 16.44024474360247, 15.480581466107724, 14.416853084966045, 13.463244361976265, 12.525504956657482, 11.643630324726097, 10.936817808990824, 11.863695671445429, 11.739163083933681, 9.752548312871545, 8.945804883673295, 7.973023461954787, 8.71719522167875, 9.604851932594787, 10.601038189539807, 11.551462803309255, 12.4868690115361, 13.456670703449399, 14.392066215693333, 15.345383807961086, 16.328232877744536, 16.308004952267073, 15.37445210749751, 14.451946357137919, 13.511436334841841, 12.699833029606719, 11.888512050654064, 11.661618161099643, 10.673698919343687, 8.785916887675109, 7.876896500650558, 6.915340489705757, 7.718992457328156, 8.66089093710139, 9.695501138025243, 10.613645599595015, 11.630735225091046, 12.667654799925414, 13.644483223372054, 14.66227582593061, 15.70214269015419, 16.25936962145241, 15.312400235677025, 14.38719979227356, 13.406361847564954, 12.520871979377565, 11.582389511394732, 10.66250008956277, 9.662050703951868, 7.83134379332365, 6.907401113834064, 5.977433158081124, 6.702897060278877, 7.636169321227292, 8.623723224954494, 9.59313335086161, 10.650546242979892, 11.714553281382354, 12.775335935899829, 13.686892302404427, 14.676642106949526, 15.44479625077087, 14.433543417238656, 13.412815623052238, 12.43358800836578, 11.566128726945491, 10.581581314711677, 9.715008264160758, 8.729588492371613, 6.824143003164934, 5.971580171150415, 5.041966348430736, 5.771599746076931, 6.723203522790104, 7.717939517066324, 8.691593370755339, 9.73304165426439, 10.750496394138889, 11.721854288544955, 12.678839343403196, 13.66131112101684, 14.469867640102624, 13.462400888733974, 12.468776025837819, 11.490089468392389, 10.543976491380894, 9.61125693642042, 8.646270869804194, 7.743300000959077, 5.8133218908196715, 5.087729502398034, 4.102509405159117, 4.7986763628581475, 5.788007839353048, 6.852417154714472, 7.8884639442451645, 8.84397853727392, 9.79779693119112, 10.72657412048118, 11.636640560858194, 12.613678134438537, 13.476796916210363, 12.513971699262722, 11.529978029440622, 10.591454189124992, 9.57783729987306, 8.638311995073881, 7.638570089350571, 6.804704596966123, 4.8674726232724, 4.051053286428807, 3.175306471848012, 3.835977276041435, 4.895769678198844, 5.901695749504887, 6.938718335471792, 7.834415114532842, 8.864811326849914, 9.791471600859682, 10.664801792309502, 11.664077186902507, 12.608973581588845, 11.628108022844685, 10.57812564160361, 9.61087308820931, 8.59815105279141, 7.655661636766239, 6.669314475894985, 5.831684128197745, 3.8421241360145912, 3.0928863010827374, 2.110823730451682, 2.910207297076588, 3.9611849652317224, 4.900530913228029, 5.889464586630621, 6.872085956052313, 7.839508636451237, 8.783965390105697, 9.709315510339414, 10.645523380479197, 11.67828297634117, 10.776950351022258, 9.81146884877807, 8.768742146684371, 7.735180554082121, 6.757252623515111, 5.716559161882326, 4.78241909763601, 2.9113693284957085, 2.0326946218891546, 1.0673137446370118, 1.9522744896771114, 2.952032899138555, 3.950989378639381, 4.9306836553628335, 5.91269760279775, 6.867118803714023, 7.905116454530858, 8.93482268153301, 9.999790397819691, 10.7789755707897, 9.745757347491164, 8.815202220533003, 7.777020269557746, 6.772156664243111, 5.738448923659041, 4.776343644849678, 3.850857867869226, 1.9329050594000587, 0.9860317740019234, 0.0, 1.0200903913180956, 2.086825209533135, 3.0419492513218795, 3.998250439191426, 5.01472568659642, 6.040383519137404, 7.028426328920551, 7.959584696722437, 8.980348509903289, 9.738277670097169, 8.797829313439976, 7.791456326273605, 6.796495527750443, 5.811963932933893, 4.847291295177906, 3.8864878442349666, 2.8866474769034696, 2.976508268605614, 1.9404891775869666, 0.9793131448576852, 1.9162283248411356, 2.9905012479876083, 4.0632749890209325, 4.950793423110854, 5.9058171548219685, 6.891961544797288, 7.874988668290015, 8.812320246996357, 9.866490448091806, 10.733110660306654, 9.831486775504954, 8.76954753890032, 7.732024391502332, 6.774205886521132, 5.825464121062513, 4.8713536037574405, 3.836538939770278, 4.004261263280465, 2.9595081683624698, 2.0112042481448844, 2.848920037008333, 3.8825013991259163, 4.909137523053152, 5.864657605242281, 6.895914032022219, 7.854825581181088, 8.927232502862811, 9.756903395873364, 10.713857655798215, 11.761282235453704, 10.779800821138025, 9.794779147087887, 8.733871137026197, 7.740850621478433, 6.8504864812460795, 5.837995640589151, 4.859895687620069], [6.95473800339865, 7.804264950764101, 8.79760728630809, 9.69707903950714, 10.750545743121114, 11.755244058209964, 12.726314624460231, 11.719711145591909, 10.680173341851992, 9.735409886218216, 8.831436725532951, 7.804961135246799, 6.841018462606405, 5.851025563964302, 4.894426033109724, 3.923390205853062, 2.8848892714424617, 3.8970812305913025, 4.945628471203175, 5.965264941596944, 7.7149638332166175, 8.660047927569877, 9.63850513436306, 10.637477118495083, 11.572630523220383, 12.549843736171185, 13.574071065665601, 12.63884533411091, 11.652098327478448, 10.630982298282898, 9.676877040274118, 8.747244030872853, 7.784239320798658, 6.802962844433906, 5.82139142592246, 4.9199632412536625, 3.95700287010843, 4.840828021416616, 5.827447338456717, 6.774373727012737, 8.696146916400563, 9.66070374935869, 10.67333659705499, 11.666370991648048, 12.581734284508904, 13.538182182670491, 14.504853479737168, 13.48681313502444, 12.516986819385869, 11.564157872827801, 10.652052893026434, 9.684743476802172, 8.762206269109173, 7.813622273036465, 6.8406223831696975, 5.970938865881873, 4.9389482877181745, 5.811106291991631, 6.775121166708066, 7.712140277824427, 9.72914076302298, 10.622112824197838, 11.606329491016886, 12.55614065538896, 13.534684180573572, 14.561953608756433, 15.419078281402719, 14.419993481882944, 13.463821290589376, 12.517724223685393, 11.718816622564198, 10.69274211742547, 9.729111068762078, 8.83304266565221, 7.784928544682083, 6.9621059729141, 5.892614503984306, 6.830744125973856, 7.827069025933492, 8.698994349984266, 10.628248494958772, 11.659932694252767, 12.556372197373532, 12.745769732120621, 13.7099765985839, 14.544640843532518, 15.491550841160272, 15.450648371638218, 14.485465741531657, 13.551718561990636, 12.599652339974995, 11.622833871913263, 10.70508368823892, 9.759651003410749, 8.855057419356426, 7.923690208419186, 6.872827925155293, 7.792209346724309, 8.769446251262622, 9.690347890930584, 11.575291035559262, 12.530497037055992, 12.586882735069103, 11.746756361776935, 12.714429385523358, 13.611048532709615, 14.429134359744953, 15.353380390735774, 15.495684410433766, 14.529385886412635, 13.658194248066739, 12.644877447966191, 11.706443322279359, 10.800972522664836, 9.850517598374278, 8.803330404427136, 7.8285564616316305, 8.84027028115628, 9.70400496378663, 10.6651412904318, 12.568493123682625, 12.522141759441139, 11.554620140217015, 10.757552932788245, 11.722486283228024, 12.560249637109616, 13.422787555930169, 14.407286444019464, 15.365442508394151, 15.46516591337408, 14.606861605288438, 13.682234506547003, 12.751753968116537, 11.707362243318585, 10.699545463018934, 9.720835804514875, 8.761390491148877, 9.774890144802843, 10.668123279495793, 11.654183578350175, 12.33115383169188, 11.511079838802821, 10.563469139897688, 9.733459835235726, 10.666819654245169, 11.574786961267609, 12.469220215105425, 13.460777661579364, 14.465366589519922, 15.305140306748726, 15.62129043228611, 14.66561196303912, 13.665097797216358, 12.599015988558444, 11.614740914166308, 10.672647398869955, 9.725322808971296, 10.65718048924982, 11.607842444541568, 12.599098756285017, 11.402553775587723, 10.522367179826919, 9.610514752780741, 8.666304837855382, 9.63543182087827, 10.592743898567967, 11.464585959909916, 12.409950986743127, 13.390393279831628, 14.342078256399372, 15.304911045877041, 15.524553277442974, 14.56488999994823, 13.50116161880655, 12.547552895816771, 11.609813490497988, 10.727938858566603, 11.659404541045149, 12.649213607770667, 12.454325654121302, 10.39606173087761, 9.548176939320907, 8.575395517602399, 7.697104830360654, 8.584761541276691, 9.580947798221711, 10.53137241199116, 11.466778620218006, 12.436580312131305, 13.37197582437524, 14.325293416642992, 15.308142486426442, 15.392313486107577, 14.458760641338015, 13.536254890978425, 12.595744868682347, 11.784141563447225, 12.611098782708389, 12.453885969396897, 11.465966727640941, 9.429430305681175, 8.47926855629817, 7.517712545353369, 6.69890206601006, 7.640800545783295, 8.675410746707149, 9.593555208276921, 10.610644833772952, 11.64756440860732, 12.62439283205396, 13.642185434612518, 14.682052298836098, 15.463391860684638, 15.413620360975935, 14.48841991757247, 13.555448459404582, 12.80328651415439, 12.452435011234275, 11.454767897860023, 10.454318512249122, 8.579318741345528, 7.509773169481676, 6.5798052137287355, 5.682806668960782, 6.616078929909197, 7.603632833636399, 8.573042959543516, 9.630455851661798, 10.69446289006426, 11.755245544581733, 12.666801911086335, 13.656551715631434, 14.50898850265831, 15.428237786486482, 14.407509992300064, 13.428282377613606, 12.523296067807037, 11.538748655573222, 10.597317509334845, 9.54733862532645, 7.586877661119766, 6.573952226798027, 5.644338404078348, 4.751509354758836, 5.70311313147201, 6.69784912574823, 7.6715029794372445, 8.712951262946296, 9.730406002820793, 10.70176389722686, 11.658748952085102, 12.641220729698746, 13.534059891990065, 14.48249128005207, 13.488866417155915, 12.484783837640215, 11.53867086062872, 10.568424277281965, 9.60343821066574, 8.561050133913913, 6.677109466814753, 5.742047799321128, 4.704881460806729, 3.7785859715400525, 4.767917448034953, 5.832326763396377, 6.8683735529270695, 7.823888145955824, 8.777706539873025, 9.706483729163086, 10.6165501695401, 11.593587743120443, 12.540989168097804, 13.503814385045445, 12.550068420758718, 11.611544580443088, 10.597927691191156, 9.652179526289839, 8.611185763891049, 7.668492172961204, 5.731260199267481, 4.773226818727555, 3.777678527495624, 2.8158868847233394, 3.8756792868807484, 4.881605358186791, 5.918627944153696, 6.814324723214746, 7.844720935531818, 8.771381209541588, 9.644711400991408, 10.643986795584413, 11.588883190270751, 12.607828581132761, 11.598216032921705, 10.630963479527406, 9.618241444109506, 8.675752028084334, 7.689404867213081, 6.782902628066636, 4.8622145273326876, 3.8631903227819078, 2.8811277521508525, 1.8901169057584926, 2.9410945739136274, 3.880440521909933, 4.869374195312525, 5.851995564734217, 6.819418245133141, 7.763874998787602, 8.68922511902132, 9.625432989161103, 10.658192585023077, 11.668734077475838, 10.831559240096164, 9.788832538002465, 8.755270945400216, 7.777343014833207, 6.736649553200422, 5.802509488954106, 3.9314597198138044, 2.9542929634626756, 1.915971027890186, 0.9321840983590158, 1.9319425078204595, 2.9308989873212856, 3.9105932640447376, 4.892607211479654, 5.847028412395927, 6.885026063212762, 7.914732290214915, 8.979700006501595, 9.937228834071924, 10.765847738809258, 9.835292611851099, 8.797110660875841, 7.792247055561207, 6.758539314977137, 5.796434036167774, 4.870948259187322, 2.9529954507181544, 2.006122165320019, 1.0200903913180956, 0.0, 1.0667348182150391, 2.0218588600037837, 2.97816004787333, 3.994635295278324, 5.020293127819308, 6.008335937602455, 6.939494305404341, 7.960258118585193, 8.888827336047788, 9.81791970475807, 8.8115467175917, 7.816585919068538, 6.832054324251988, 5.867381686496001, 4.906578235553062, 3.906737868221565, 3.972038478534931, 2.898628071394372, 1.9374520386650906, 1.0005368586816403, 2.000671083266681, 3.073444824300005, 3.930703031792758, 4.885726763503873, 5.8718711534791925, 6.85489827697192, 7.792229855678261, 8.84640005677371, 9.883660326257273, 10.851577166823049, 9.789637930218413, 8.752114782820426, 7.794296277839227, 6.845554512380608, 5.891443995075536, 4.8566293310883735, 4.963588583045295, 3.917647062169875, 2.925424142666473, 1.9332285708488377, 2.966809932966421, 3.9934460568936574, 4.938329619794533, 5.921616836528906, 6.867354246690218, 7.926362340667341, 8.736813004555268, 9.693767264480119, 10.741191844135608, 11.73298197169077, 10.814869538405981, 9.753961528344291, 8.760941012796527, 7.8705768725641745, 6.858086031907246, 5.879986078938164], [8.006957217609472, 8.870999768979141, 9.86434210452313, 10.76381385772218, 11.817280561336155, 12.610310843414624, 11.659579806245194, 10.652976327376871, 9.613438523636955, 8.668675068003179, 7.766872613114527, 6.740397022828375, 5.776454350187981, 4.786461451545878, 3.8298619206913003, 2.858826093434638, 3.8867698011647343, 4.8989617603135756, 5.947509000925448, 6.967145471319217, 8.71684436293889, 9.661928457292149, 10.640385664085331, 11.698923525181963, 12.634076929907263, 13.57053284189525, 12.509506953247177, 11.574281221692486, 10.587534215060025, 9.566418185864475, 8.612312927855694, 7.682679918454429, 6.7196752083802345, 5.738398732015482, 4.756827313504036, 3.9243998522070846, 4.887360223352317, 5.842708551138889, 6.82932786817899, 7.77625425673501, 9.698027446122836, 10.662584279080962, 11.67521712677726, 12.673082483635154, 13.643180691195784, 14.48950308083676, 13.440289367318744, 12.422249022606016, 11.452422706967445, 10.499593760409377, 9.58748878060801, 8.620179364383748, 7.6976421566907485, 6.749058160618041, 5.776058270751274, 4.9753754768352945, 5.869305640962062, 6.8129868217139045, 7.7770016964303395, 8.7140208075467, 10.731021292745254, 11.62399335392011, 12.608210020739158, 13.558021185111231, 14.270687458655626, 14.974172656067093, 14.354514168984295, 13.35542936946452, 12.399257178170952, 11.45316011126697, 10.654252510145774, 9.628178005007046, 8.664546956343655, 7.768478553233786, 6.7203644322636595, 5.990378295540754, 6.822971857228193, 7.761101479217744, 8.758637808433075, 9.696145648168267, 11.578295361815085, 12.609979561109082, 13.558252727095804, 13.81250455033566, 13.211054756041161, 13.970164330263467, 14.883793510448807, 14.386084259219794, 13.420901629113233, 12.487154449572213, 11.535088227556571, 10.55826975949484, 9.640519575820496, 8.695086890992325, 7.790493306938003, 6.95196253104584, 7.80318527839918, 8.722566699968198, 9.69980360450651, 10.640394757786897, 12.525337902415576, 13.480543903912306, 13.653617553284143, 12.813491179991974, 12.139952872254307, 13.036572019440564, 13.821377029033489, 14.708093240938956, 14.431120298015342, 13.464821773994212, 12.593630135648315, 11.580313335547768, 10.641879209860935, 9.736408410246412, 8.81995118372588, 7.910583959883066, 8.758913814875518, 9.770627634400169, 10.634362317030519, 11.615188157288113, 13.518539990538939, 13.588876577656178, 12.621354958432054, 11.824287751003284, 11.148009769958973, 11.985773123840564, 12.815030225218704, 13.761999294222646, 14.720155358597333, 14.400601800955656, 13.542297492870015, 12.617670394128579, 11.687189855698113, 10.730151245561204, 9.87808737825028, 8.902683769426032, 9.691747844392763, 10.705247498046731, 11.598480632739681, 12.603834569133499, 13.39788864990692, 12.57781465701786, 11.630203958112727, 10.800194653450765, 10.092343140976118, 11.000310447998558, 11.86146288439396, 12.815490511782546, 13.780490079533791, 14.620263796762595, 14.575476826629851, 13.619798357382862, 12.6192841915601, 11.798311475141553, 10.848337220787087, 9.918664240205533, 10.655680162215182, 11.587537842493706, 12.538199797785456, 13.529456109528905, 12.469288593802762, 11.589101998041958, 10.67724957099578, 9.73303965607042, 9.06095530760922, 10.018267385298916, 10.856828629198452, 11.746810280541961, 12.705516769845497, 13.657201746413241, 14.562722585357761, 14.521612108042238, 13.561948830547493, 12.747178460142129, 11.79356973715235, 10.855830331833566, 11.65829621181049, 12.589761894289037, 13.579570961014555, 13.521060472336341, 11.46279654909265, 10.614911757535946, 9.642130335817438, 8.763839648575694, 8.01028502800764, 9.00647128495266, 9.923615081279696, 10.80363791401684, 11.751703802145174, 12.687099314389108, 13.583104956123712, 14.565954025907162, 14.575285055077197, 13.704777482673594, 12.782271732314003, 11.841761710017925, 12.71449891669111, 13.541456135952277, 13.520620787611936, 12.53270154585598, 10.496165123896214, 9.546003374513209, 8.584447363568408, 7.765636884225099, 7.066324032514243, 8.083414479253872, 8.985797877565457, 9.877368632918119, 10.772544052850458, 11.737779108843885, 12.633798498159099, 13.673665362382678, 14.455004924231218, 14.659637202311513, 13.734436758908048, 12.80146530074016, 13.733643867398275, 13.519169829449314, 12.521502716075062, 11.521053330464161, 9.646053559560567, 8.576507987696715, 7.646540031943775, 6.749541487175821, 6.024082662455919, 7.011636566183122, 7.965285628832051, 8.897179650806965, 9.729833001210286, 10.746858608128314, 11.658414974632915, 12.648164779178014, 13.50060156620489, 14.536716526406849, 14.750520089520748, 13.774239139939334, 13.590030886022076, 12.605483473788262, 11.664052327549884, 10.61407344354149, 8.653612479334805, 7.640687045013066, 6.711073222293387, 5.818244172973875, 4.996738650586488, 5.983275485772402, 6.956929339461416, 7.827475209681675, 8.722019066367373, 9.69337696077344, 10.650362015631682, 11.632833793245327, 12.525672955536646, 13.537589926676972, 14.418219114811322, 13.551518655855254, 12.60540567884376, 11.635159095497004, 10.670173028880779, 9.627784952128952, 7.743844285029792, 6.808782617536167, 5.771616279021768, 4.845320789755092, 4.061542967149432, 5.022112844233192, 5.983617486494625, 6.815501209502405, 7.769319603419607, 8.698096792709666, 9.60816323308668, 10.585200806667023, 11.532602231644384, 12.495427448592025, 13.479421118414125, 12.678279398658129, 11.664662509406199, 10.718914344504878, 9.677920582106088, 8.735226991176242, 6.7979950174825206, 5.839961636942594, 4.844413345710663, 3.8826217029383785, 3.1241029431414926, 3.986661864420573, 4.910241007700278, 5.805937786761327, 6.8363339990784, 7.762994273088169, 8.636324464537989, 9.635599859130993, 10.580496253817332, 11.599441644679342, 12.649424025920418, 11.697698297742447, 10.684976262324547, 9.742486846299375, 8.75613968542812, 7.849637446281675, 5.928949345547727, 4.9299251409969465, 3.9478625703658916, 2.9568517239735317, 2.0836568970418496, 2.9563544345626043, 3.8609872588591063, 4.843608628280799, 5.8110313086797225, 6.755488062334184, 7.6808381825679, 8.617046052707684, 9.649805648569657, 10.660347141022418, 11.723194860535024, 10.855567356217504, 9.822005763615255, 8.844077833048246, 7.803384371415461, 6.869244307169145, 4.9981945380288435, 4.021027781677715, 2.982705846105225, 1.998918916574055, 1.0237770376456115, 2.0068128999739567, 2.902206327591319, 3.8842202750262356, 4.8386414759425085, 5.876639126759343, 6.882409116705858, 7.947376832992538, 8.87068114268576, 9.710468908541129, 10.724020780304159, 9.86384547909088, 8.858981873776246, 7.825274133192176, 6.863168854382813, 5.937683077402361, 4.019730268933194, 3.0728569835350585, 2.086825209533135, 1.0667348182150391, 0.0, 0.9551240417887447, 1.911425229658291, 2.927900477063285, 3.9535583096042686, 4.941601119387416, 5.872759487189302, 6.893523300370154, 7.822092517832748, 8.762540874489941, 9.768913861656312, 8.883320737283578, 7.898789142467028, 6.934116504711041, 5.973313053768102, 4.973472686436605, 4.979710808051406, 3.9063004009108466, 2.945124368181565, 2.008209188198115, 0.9339362650516422, 2.006710006084966, 2.863968213577719, 3.8189919452888335, 4.805136335264153, 5.78816345875688, 6.725495037463222, 7.779665238558671, 8.816925508042232, 9.820564893662707, 10.7616538997087, 9.818849601035467, 8.861031096054267, 7.912289330595648, 6.958178813290576, 5.9233641493034135, 5.97126091256177, 4.92531939168635, 3.9273046723887455, 2.9351091005711103, 1.9015277384535272, 2.9281638623807638, 3.8715948015794943, 4.854882018313867, 5.800619428475179, 6.859627522452302, 7.67007818634023, 8.627032446265082, 9.67445702592057, 10.666247153475732, 11.651268827525872, 10.820696346559332, 9.827675831011568, 8.937311690779215, 7.924820850122286, 6.946720897153204], [8.962081259398216, 9.826123810767886, 10.819466146311875, 11.718937899510927, 12.659885116714728, 11.655186801625877, 10.70445576445645, 9.697852285588127, 8.65831448184821, 7.713551026214434, 6.882531778572449, 5.856056188286298, 4.892113515645904, 3.902120617003801, 3.1040620428280796, 3.813950135223383, 4.841893842953479, 5.85408580210232, 6.902633042714193, 7.9222695131079615, 9.671968404727634, 10.617052499080893, 11.595509705874075, 12.654047566970707, 13.589200971696007, 12.61823234911172, 11.557206460463647, 10.621980728908955, 9.635233722276494, 8.682077351322397, 7.727972093313616, 6.798339083912352, 5.835334373838157, 4.854057897473405, 4.031027435640816, 4.879523893995829, 5.842484265141062, 6.797832592927634, 7.784451909967735, 8.731378298523754, 10.65315148791158, 11.617708320869706, 12.630341168566005, 13.628206525423899, 14.598304732984529, 13.605162246294682, 12.555948532776666, 11.537908188063938, 10.568081872425367, 9.6152529258673, 8.703147946065933, 7.735838529841671, 6.824760141022779, 5.876176144950072, 5.050258392888053, 5.930499518624039, 6.824429682750806, 7.768110863502649, 8.732125738219084, 9.669144849335444, 11.686145334533997, 12.579117395708852, 13.5633340625279, 14.513145226899974, 15.073634053553416, 14.084361748034027, 13.470173334442217, 12.471088534922442, 11.514916343628874, 10.568819276724891, 9.769911675603696, 8.748202234320113, 7.791664940675684, 6.923036353917716, 5.994564554400439, 6.945502337329499, 7.778095899016938, 8.716225521006487, 9.71376185022182, 10.651269689957012, 12.533419403603828, 13.565103602897825, 14.513376768884546, 14.767628592124403, 14.014001350938953, 13.0803534222304, 13.928669468660063, 13.501743424677716, 12.536560794571155, 11.602813615030135, 10.655112456869638, 9.678293988807907, 8.767637560152526, 7.8496446916762554, 7.064693429074782, 7.907086572834585, 8.758309320187925, 9.67769074175694, 10.654927646295253, 11.59551879957564, 13.480461944204318, 14.435667945701049, 14.608741595072889, 13.768615221780717, 13.03163194951672, 12.146761111407498, 12.866252987244744, 13.75296919915021, 13.546779463473264, 12.580480939452134, 11.713654364961382, 10.700337564860835, 9.768997194192965, 8.890966210930342, 8.09415130586266, 8.86570800167181, 9.714037856664262, 10.725751676188912, 11.589486358819261, 12.570312199076856, 14.473664032327681, 14.544000619444924, 13.5764790002208, 12.779411792792027, 12.039688847221386, 11.095962215807498, 11.85990618342996, 12.8068752524339, 13.765031316808587, 13.516260966413578, 12.662321722183082, 11.744788378460608, 10.814307840030143, 9.884709046245135, 9.15228750038706, 9.857807811214776, 10.646871886181508, 11.660371539835474, 12.553604674528424, 13.558958610922241, 14.353012691695666, 13.532938698806607, 12.585327999901473, 11.755318695239508, 10.98402221823853, 10.110499539965492, 10.906338842605216, 11.8603664699938, 12.825366037745049, 13.665139754973852, 13.700040264305297, 12.746916341714892, 11.746402175892129, 10.952869275825483, 10.122537342923867, 10.873788281994278, 11.610804204003927, 12.54266188428245, 13.493323839574199, 14.484580151317648, 13.424412635591509, 12.544226039830704, 11.632373612784527, 10.688163697859164, 9.952634384871633, 9.12845647726585, 9.901704587409707, 10.791686238753215, 11.750392728056754, 12.702077704624498, 13.607598543569019, 13.648730092374265, 12.68906681487952, 11.946967468662772, 11.138139245473454, 11.81095437362231, 12.613420253599234, 13.54488593607778, 14.534695002803298, 14.476184514125087, 12.417920590881396, 11.570035799324693, 10.597254377606184, 9.718963690364438, 8.901964105270052, 8.116660376919594, 8.968491039490951, 9.848513872228095, 10.796579760356432, 11.731975272600366, 12.62798091433497, 13.61082998411842, 13.702403039409225, 12.904566491194236, 12.126841240635107, 12.79688575180667, 13.669622958479856, 14.49658017774102, 14.475744829400682, 13.487825587644727, 11.45128916568496, 10.501127416301955, 9.539571405357155, 8.720760926013844, 7.958003109776654, 7.160721748574846, 8.030673835776712, 8.922244591129374, 9.817420011061715, 10.78265506705514, 11.678674456370356, 12.718541320593935, 13.499880882442474, 13.95096536816648, 13.079006267229152, 13.756589342528905, 14.688767909187021, 14.47429387123806, 13.476626757863809, 12.476177372252907, 10.601177601349313, 9.531632029485461, 8.60166407373252, 7.704665528964566, 6.915761739718331, 6.088943835504097, 7.0101615870433065, 7.9420556090182215, 8.774708959421543, 9.791734566339569, 10.703290932844173, 11.693040737389271, 12.545477524416146, 13.581592484618104, 14.095089597841852, 14.729363181728079, 14.54515492781082, 13.560607515577006, 12.619176369338629, 11.569197485330234, 9.60873652112355, 8.595811086801811, 7.6661972640821325, 6.77336821476262, 5.8884177278489, 5.028151443983657, 6.0018052976726715, 6.872351167892931, 7.76689502457863, 8.738252918984696, 9.69523797384294, 10.677709751456582, 11.570548913747901, 12.582465884888228, 13.463095073022577, 14.401841541967908, 13.560529720632504, 12.590283137285748, 11.625297070669523, 10.582908993917696, 8.698968326818537, 7.763906659324912, 6.726740320810514, 5.800444831543836, 4.953222044411842, 4.066988802444447, 5.02849344470588, 5.8603771677136605, 6.8141955616308625, 7.742972750920923, 8.653039191297937, 9.630076764878279, 10.57747818985564, 11.54030340680328, 12.52429707662538, 13.464314752608049, 12.619786551194942, 11.674038386293624, 10.633044623894834, 9.690351032964989, 7.753119059271266, 6.79508567873134, 5.7995373874994085, 4.8377457447271235, 4.015782020403903, 3.0315378226318286, 3.9551169659115333, 4.850813744972583, 5.881209957289656, 6.807870231299424, 7.681200422749245, 8.680475817342248, 9.625372212028587, 10.644317602890597, 11.694299984131673, 12.65282233953119, 11.64010030411329, 10.697610888088118, 9.711263727216863, 8.80476148807042, 6.884073387336471, 5.885049182785692, 4.902986612154637, 3.9119757657622762, 2.97533597430426, 2.0012303927738597, 2.9058632170703618, 3.888484586492054, 4.855907266890978, 5.800364020545439, 6.725714140779155, 7.661922010918939, 8.694681606780913, 9.705223099233674, 10.76807081874628, 11.81069139800625, 10.777129805404002, 9.79920187483699, 8.758508413204206, 7.82436834895789, 5.953318579817588, 4.976151823466459, 3.9378298878939697, 2.9540429583627996, 1.978901079434356, 1.051688858185212, 1.9470822858025745, 2.929096233237491, 3.883517434153764, 4.921515084970599, 5.927285074917114, 6.992252791203794, 7.915557100897014, 8.755344866752385, 9.768896738515412, 10.818969520879627, 9.814105915564992, 8.78039817498092, 7.818292896171558, 6.892807119191105, 4.9748543107219385, 4.027981025323803, 3.0419492513218795, 2.0218588600037837, 0.9551240417887447, 0.0, 0.9563011878695463, 1.97277643527454, 2.998434267815524, 3.9864770775986718, 4.917635445400557, 5.938399258581409, 6.866968476044003, 7.807416832701197, 8.813789819867567, 9.80875061839073, 8.853913184255774, 7.889240546499786, 6.928437095556847, 5.928596728225349, 5.934834849840151, 4.861424442699591, 3.9002484099703096, 2.9633332299868593, 1.8890603068403868, 1.0572676453751562, 1.9088441717889744, 2.863867903500089, 3.850012293475409, 4.833039416968136, 5.770370995674478, 6.8245411967699265, 7.861801466253487, 8.865440851873963, 9.806529857919955, 10.74427948214262, 9.816155137843014, 8.867413372384393, 7.913302855079321, 6.878488191092158, 6.926384954350515, 5.880443433475095, 4.8824287141774905, 3.8902331423598553, 2.856651780242272, 2.126757816634266, 2.9164707597907498, 3.8997579765251222, 4.8454953866864345, 5.904503480663557, 6.714954144551485, 7.671908404476337, 8.719332984131826, 9.711123111686987, 10.696144785737125, 11.758313645617363, 10.782799872800314, 9.892435732567959, 8.87994489191103, 7.901844938941949], [9.918382447267762, 10.782424998637431, 11.77576733418142, 12.675239087380472, 11.703583928845182, 10.698885613756332, 9.748154576586902, 8.741551097718581, 7.702013293978664, 6.757249838344887, 5.926230590702902, 4.899755000416751, 3.935812327776357, 2.9458194291342545, 3.8929938803041457, 4.770251323092928, 5.798195030823025, 6.810386989971866, 7.858934230583738, 8.878570700977507, 10.628269592597182, 11.57335368695044, 12.551810893743623, 13.574297778918277, 12.639144374192977, 11.661931161242174, 10.600905272594101, 9.66567954103941, 8.678932534406949, 7.725776163452848, 6.7716709054440685, 5.842037896042805, 4.879033185968611, 3.8977567096038586, 4.819959273116882, 5.826329154454394, 6.789289525599626, 7.754133780797179, 8.740753097837281, 9.687679486393302, 11.609452675781128, 12.574009508739254, 13.586642356435553, 14.584507713293446, 13.647330676449144, 12.648861058425133, 11.599647344907117, 10.581607000194388, 9.611780684555818, 8.65895173799775, 7.7468467581963845, 6.779537341972124, 5.868458953153232, 4.919874957080525, 5.839190230364119, 6.877304779082603, 7.771234943209371, 8.724412051372195, 9.68842692608863, 10.625446037204991, 12.642446522403546, 13.535418583578402, 14.51963525039745, 15.469446414769523, 14.566248132694538, 13.497491649682445, 12.513872146572668, 11.514787347052893, 10.558615155759325, 9.612518088855342, 8.813610487734147, 7.791901046450565, 6.8353637528061375, 5.96673516604817, 6.783496391876505, 7.857669598217203, 8.724901159475502, 9.663030781465052, 10.660567110680384, 11.598074950415576, 13.480224664062392, 14.511908863356389, 15.469677956754095, 15.723929779993952, 14.893713649564202, 13.96006572085565, 13.048630064599108, 12.545442236808167, 11.580259606701606, 10.646512427160586, 9.698811269000089, 8.72199280093836, 7.811336372282979, 6.893343503806709, 7.853625266550848, 8.810455622498385, 9.70511458064649, 10.624496002215505, 11.601732906753817, 12.542324060034204, 14.427267204662883, 15.382473206159613, 15.565042782942436, 14.724916409650266, 13.950418465987989, 13.026473410032747, 11.986213583183789, 12.796668011280664, 12.590478275603715, 11.624179751582584, 10.757353177091833, 9.744036376991287, 8.812696006323419, 7.934665023060796, 8.883083143338725, 9.76907705133561, 10.660843117122827, 11.672556936647476, 12.536291619277826, 13.51711745953542, 15.420469292786246, 15.500301807314472, 14.532780188090348, 13.735712980661576, 12.958475363692655, 11.998422172953546, 10.979866779369004, 11.850574064564354, 12.808730128939041, 12.559959778544028, 11.706020534313533, 10.788487190591063, 9.858006652160597, 8.928407858375587, 9.936224638675238, 10.761176860878576, 11.593677146640072, 12.607176800294038, 13.500409934986989, 14.505763871380806, 15.309313879565211, 14.489239886676154, 13.54162918777102, 12.711619883109057, 11.902808734709799, 11.01295949711154, 10.02629943854426, 10.904065282124254, 11.869064849875501, 12.708838567104305, 12.743739076435748, 11.790615153845346, 10.790100988022584, 9.996568087955936, 10.906474481212046, 11.777157331658078, 12.557609464462491, 13.489467144741015, 14.440129100032763, 15.431385411776212, 14.380713823461054, 13.500527227700251, 12.588674800654074, 11.644464885728713, 10.871420901342901, 10.045735967690355, 9.021665183348752, 9.83538505088367, 10.794091540187207, 11.745776516754951, 12.65129735569947, 12.69242890450472, 11.732765627009975, 10.990666280793224, 11.922076383761633, 12.71432342328611, 13.560225514057798, 14.491691196536344, 15.481500263261863, 15.432485701994633, 13.374221778750943, 12.52633698719424, 11.553555565475731, 10.675264878233985, 9.820750621741322, 9.035446893390862, 8.088451635429996, 8.89221268435855, 9.840278572486884, 10.775674084730818, 11.67167972646542, 12.65452879624887, 12.74610185153968, 11.948265303324689, 12.910778378923286, 13.70025480147047, 14.61642821893842, 15.443385438199584, 15.432046017270228, 14.444126775514274, 12.407590353554507, 11.457428604171502, 10.495872593226702, 9.677062113883391, 8.876789626247923, 8.079508265046115, 7.150634431715757, 7.965943403259828, 8.861118823192168, 9.826353879185595, 10.722373268500807, 11.762240132724386, 12.543579694572928, 12.994664180296933, 13.862943405517331, 14.659958392192705, 15.635573169645586, 15.430595059107608, 14.432927945733356, 13.432478560122455, 11.55747878921886, 10.487933217355009, 9.557965261602067, 8.660966716834112, 7.834548256189599, 7.007730351975365, 6.130122182982351, 6.985754421148676, 7.818407771551997, 8.835433378470023, 9.746989744974623, 10.736739549519722, 11.5891763365466, 12.625291296748559, 13.535698545017787, 14.389038894071753, 15.347337354946372, 14.516908703446553, 13.575477557208176, 12.525498673199781, 10.565037708993097, 9.552112274671359, 8.62249845195168, 7.729669402632166, 6.807204244320168, 5.9469379604549255, 5.121765893611715, 5.916049980023385, 6.810593836709084, 7.78195173111515, 8.738936785973392, 9.721408563587037, 10.614247725878355, 11.626164697018682, 12.506793885153032, 13.445540354098362, 14.391653331109858, 13.546584325155296, 12.58159825853907, 11.539210181787244, 9.655269514688083, 8.720207847194459, 7.68304150868006, 6.756746019413383, 5.872008560883111, 4.9857753189157155, 4.072192256836335, 4.904075979844115, 5.857894373761317, 6.786671563051377, 7.696738003428391, 8.673775577008733, 9.621177001986094, 10.584002218933735, 11.567995888755835, 12.508013564738503, 13.540504585364113, 12.63033957416317, 11.58934581176438, 10.646652220834534, 8.709420247140812, 7.751386866600886, 6.755838575368955, 5.79404693259667, 4.9345685368751715, 3.950324339103097, 2.9988157780419877, 3.8945125571030372, 4.92490876942011, 5.851569043429879, 6.724899234879699, 7.724174629472703, 8.669071024159042, 9.688016415021051, 10.737998796262127, 11.705251349656427, 12.596401491982835, 11.653912075957663, 10.667564915086409, 9.761062675939968, 7.840374575206018, 6.841350370655238, 5.859287800024183, 4.868276953631823, 3.894122490775528, 2.920016909245128, 1.9495620292008158, 2.9321833986225085, 3.899606079021433, 4.844062832675894, 5.76941295290961, 6.705620823049394, 7.738380418911367, 8.748921911364128, 9.811769630876734, 10.854496332970433, 11.733430993273547, 10.755503062706538, 9.714809601073751, 8.780669536827435, 6.9096197676871345, 5.932453011336006, 4.894131075763516, 3.910344146232346, 2.9352022673039024, 1.9704753746564803, 0.9907810979330282, 1.9727950453679448, 2.927216246284218, 3.965213897101053, 4.970983887047568, 6.035951603334248, 6.959255913027468, 7.799043678882839, 8.812595550645867, 9.869167166921278, 10.770407103434538, 9.736699362850468, 8.774594084041105, 7.849108307060652, 5.931155498591485, 4.9842822131933495, 3.998250439191426, 2.97816004787333, 1.911425229658291, 0.9563011878695463, 0.0, 1.0164752474049938, 2.0421330799459776, 3.0301758897291253, 3.9613342575310106, 4.982098070711863, 5.910667288174457, 6.85111564483165, 7.857488631998021, 8.852449430521183, 9.81021437212532, 8.845541734369332, 7.884738283426392, 6.8848979160948955, 6.891136037709696, 5.817725630569138, 4.856549597839856, 3.9196344178564058, 2.845361494709933, 2.006876196731003, 0.9525429839194279, 1.9075667156305423, 2.8937111056058624, 3.876738229098589, 4.81406980780493, 5.868240008900379, 6.905500278383941, 7.909139664004416, 8.850228670050408, 9.787978294273072, 10.77245632571256, 9.823714560253938, 8.869604042948867, 7.834789378961704, 7.882686142220061, 6.836744621344641, 5.838729902047037, 4.846534330229401, 3.812952968111818, 2.9156896541103325, 1.9601695719212033, 2.9434567886555754, 3.8891941988168885, 4.948202292794011, 5.758652956681938, 6.71560721660679, 7.763031796262279, 8.75482192381744, 9.73984359786758, 10.802012457747818, 11.73910106066986, 10.848736920437505, 9.836246079780576, 8.858146126811494], [10.934857694672756, 11.798900246042425, 12.624941079878733, 11.665148926337162, 10.806455009079878, 9.801756693991027, 8.851025656821598, 7.844422177953279, 6.804884374213361, 5.860120918579584, 5.074902910899288, 4.048427320613136, 3.1455267506787674, 3.9622946765392486, 4.90946912770914, 5.7867265704979225, 6.814670278228019, 7.82686223737686, 8.875409477988732, 9.895045948382501, 11.644744840002176, 12.589828934355435, 13.568286141148617, 12.605547005325105, 11.742015454427673, 10.76480224147687, 9.703776352828797, 8.768550621274105, 7.781803614641645, 6.852274621494833, 5.920343225640454, 4.99071021623919, 4.211093951058752, 4.914231957008853, 5.836434520521876, 6.842804401859388, 7.80576477300462, 8.770609028202173, 9.757228345242275, 10.704154733798296, 12.625927923186122, 13.590484756144248, 14.603117603840547, 13.63444087847807, 12.751119215716194, 11.753140687976176, 10.726145802949103, 9.708105458236375, 8.738279142597804, 7.7854501960397355, 6.89551907839277, 5.928209662168509, 5.232653866715785, 5.936350204485519, 6.855665477769113, 7.8937800264875975, 8.787710190614364, 9.740887298777189, 10.704902173493624, 11.641921284609985, 13.65892176980854, 14.551893830983396, 15.536110497802444, 14.596951502470358, 13.692746590736524, 12.623990107724431, 11.640370604614654, 10.64128580509488, 9.685113613801311, 8.739016546897329, 7.962282807930533, 6.940573366646951, 6.199558666368691, 6.983210413453164, 7.799971639281499, 8.874144845622197, 9.741376406880494, 10.679506028870044, 11.677042358085377, 12.614550197820568, 14.496699911467385, 15.52838411076138, 16.48615320415909, 15.501583048919827, 14.537376182456548, 13.603728253747995, 12.614676608472974, 11.671940694850154, 10.706758064743592, 9.773010885202572, 8.847483589196475, 7.870665121134745, 7.1755312858455325, 7.909818751211703, 8.870100513955842, 9.826930869903379, 10.721589828051481, 11.640971249620497, 12.61820815415881, 13.558799307439196, 15.443742452067875, 16.398948453564607, 16.58151803034743, 15.741333738230018, 14.803435851694104, 13.865828791978908, 12.82556896512995, 11.896856136071426, 11.716976733645701, 10.75067820962457, 9.90602549728822, 8.892708697187674, 8.176890919885972, 8.95114027046579, 9.899558390743719, 10.785552298740605, 11.67731836452782, 12.689032184052468, 13.552766866682818, 14.533592706940412, 16.436944540191238, 16.516777054719462, 15.54925543549534, 14.752130309241329, 13.853767387549816, 12.837777554899708, 11.819222161315166, 10.950762189355116, 11.817964314762731, 11.686458236586015, 10.854692854509919, 9.943264711645998, 9.22220156572315, 9.944883105780583, 10.952699886080234, 11.77765210828357, 12.610152394045064, 13.62365204769903, 14.516885182391981, 15.522239118785798, 16.325789126970204, 15.505715134081147, 14.558104435176013, 13.72803721168881, 12.820054167784674, 11.852314879057701, 10.865654820490422, 10.004253406915016, 10.876148424534467, 11.71592214176327, 11.892411396632134, 10.975067659650389, 10.154295901585137, 11.013043335360932, 11.922949728617041, 12.793632579063072, 13.574084711867483, 14.505942392146007, 15.456604347437755, 16.447860659181202, 15.397189070866048, 14.517002475105244, 13.605150048059066, 12.660882214308465, 11.832609335423616, 10.885091349636514, 9.861020565294913, 8.935573175674431, 9.801175114846172, 10.752860091413917, 11.658380930358437, 11.92623514852729, 11.096960540572528, 12.00714152819822, 12.938551631166629, 13.730798670691104, 14.57670076146279, 15.508166443941338, 16.497975510666855, 16.448960949399627, 14.390697026155935, 13.542812234599232, 12.570030812880724, 11.69168220681374, 10.781939055822036, 9.977272241992134, 8.927807017376157, 7.99240080914931, 8.84736214714585, 9.782757659389784, 10.678763301124388, 11.661612370907838, 12.110296765102232, 12.964740550729685, 13.927253626328282, 14.716730048875464, 15.63290346634341, 16.45986068560458, 16.44852126467522, 15.460602022919266, 13.4240656009595, 12.473903851576495, 11.512347840631694, 10.693479442463145, 9.83797806032864, 9.021333613647387, 8.075688987883517, 7.066131528050589, 7.8682023978511335, 8.83343745384456, 9.729456843159774, 10.769323707383354, 11.550663269231894, 12.497632655007278, 13.422833098410743, 14.368896307929893, 15.35266640436599, 16.291148872348824, 15.449403193138348, 14.448953807527447, 12.573954036623853, 11.504408464760001, 10.57444050900706, 9.677384045413866, 8.795736690270315, 7.968918786056081, 7.055176739150111, 6.085942545939437, 6.8254913462109625, 7.842516953128989, 8.75407331963359, 9.74382312417869, 10.596259911205566, 11.632374871407524, 12.542782119676753, 13.396122468730718, 14.354420929605338, 15.338968341839152, 14.591952804613168, 13.541973920604773, 11.58151295639809, 10.568587522076351, 9.638973699356672, 8.74608673121192, 7.768392678400884, 6.908126394535642, 6.046820449779476, 5.016238104814146, 5.81767741136805, 6.7890353057741155, 7.746020360632357, 8.728492138246002, 9.62133130053732, 10.633248271677648, 11.513877459811997, 12.452623928757328, 13.398736905768823, 14.368983489115578, 13.598073505944063, 12.555685429192236, 10.671744762093077, 9.736683094599453, 8.699516756085053, 7.773221266818376, 6.833196994963827, 5.946963752996432, 4.997246813004096, 4.004264104634876, 4.864977948420282, 5.793755137710343, 6.703821578087356, 7.680859151667699, 8.62826057664506, 9.5910857935927, 10.5750794634148, 11.515097139397469, 12.547588160023079, 13.612834382182555, 12.605821059169374, 11.663127468239528, 9.725895494545806, 8.76786211400588, 7.772313822773948, 6.810522180001663, 5.895756970955888, 4.911512773183813, 3.960004212122704, 2.9947006818937982, 3.931992344079075, 4.858652618088844, 5.731982809538665, 6.731258204131668, 7.676154598818007, 8.695099989680017, 9.745082370921093, 10.712334924315392, 11.725056959733292, 12.667546375758464, 11.684040162491403, 10.777537923344962, 8.85684982261101, 7.8578256180602315, 6.875763047429176, 5.884752201036816, 4.855310924856244, 3.881205343325844, 2.9107504632815324, 2.0323715234132695, 2.906689653680398, 3.851146407334859, 4.776496527568575, 5.712704397708359, 6.745463993570333, 7.756005486023094, 8.8188532055357, 9.844413796642907, 10.743722399080967, 11.771978310111532, 10.731284848478746, 9.79714478423243, 7.926095015092128, 6.948928258741, 5.91060632316851, 4.92681939363734, 3.930620288238023, 2.9316638087371967, 1.9519695320137447, 0.9699555845788281, 1.9243767854951013, 2.9623744363119364, 3.9545086396425737, 5.019476355929254, 5.9427806656224735, 6.782568431477845, 7.7961203032408735, 8.852691919516284, 9.780698509241958, 10.753174610255462, 9.7910693314461, 8.865583554465646, 6.947630745996478, 6.000757460598343, 5.014725686596419, 3.9946352952783237, 2.9279004770632846, 1.97277643527454, 1.0164752474049938, 0.0, 1.0256578325409837, 2.0137006423241313, 2.9448590101260166, 3.9656228233068687, 4.894192040769463, 5.834640397426656, 6.841013384593027, 7.835974183116189, 8.82050577793274, 9.785178415688726, 8.901213530831386, 7.901373163499889, 7.90761128511469, 6.834200877974131, 5.873024845244849, 4.936109665261399, 3.8618367421149267, 3.023351444135997, 1.9690182313244218, 1.0650222328579857, 2.041368367669823, 3.0243954911625495, 3.916940888039628, 4.901716690220821, 5.889025030978947, 6.8926644165994215, 7.8337534226454135, 8.771503046868078, 9.762366164669249, 10.763351241573332, 9.88607929035386, 8.851264626366698, 8.899161389625055, 7.853219868749634, 6.855205149452031, 5.863009577634395, 4.829428215516812, 3.9321649015153266, 2.9766448193261974, 2.1009123058830186, 3.036851460880849, 4.095859554857971, 4.861524036916635, 5.818478296841487, 6.8659028764969765, 7.857693004052137, 8.842714678102276, 9.800481839155164, 10.72901089962655, 11.731424507993196, 10.85272132718557, 9.874621374216488], [11.96051552721374, 12.592625582881738, 11.599283247337748, 10.639491093796178, 9.780797176538895, 8.776098861450045, 7.825367824280615, 6.818764345412295, 5.779226541672378, 4.834463086038601, 4.049245078358304, 3.0227694880721527, 3.9867121607125466, 4.9501551020301005, 5.897329553199992, 6.812384403038907, 7.840328110769003, 8.852520069917844, 9.901067310529717, 10.920703780923485, 12.670402672543158, 13.568661467561894, 12.63008955834659, 11.57988917278412, 10.71635762188669, 9.739144408935887, 8.678118520287814, 7.742892788733123, 6.756145782100662, 5.826616788953849, 4.89468539309947, 3.9650523836982066, 5.003776401670932, 5.9020923824997045, 6.824294946012728, 7.8306648273502395, 8.793625198495473, 9.796266860743158, 10.782886177783258, 11.729812566339278, 13.651585755727105, 14.569317289350707, 13.60664840279498, 12.608783045937086, 11.725461383175212, 10.727482855435193, 9.700487970408119, 8.68244762569539, 7.71262131005682, 6.759792363498752, 5.869861245851786, 4.902551829627526, 5.959987807855652, 6.908571803928359, 7.843525903259965, 8.88164045197845, 9.775570616105217, 10.766545131318173, 11.730560006034608, 12.667579117150968, 14.667294803570993, 15.505321501120495, 14.521104834301447, 13.571293669929373, 12.66708875819554, 11.598332275183447, 10.61471277207367, 9.615627972553895, 8.659455781260327, 7.713358714356344, 6.936624975389549, 5.914915534105967, 6.878546582769359, 7.923655151554873, 8.787832064772351, 9.862005271113048, 10.729236832371349, 11.667366454360899, 12.664902783576231, 13.602410623311423, 15.48456033695824, 16.438990114712418, 15.471147540658093, 14.475925216378842, 13.511718349915563, 12.578070421207011, 11.58901877593199, 10.64628286230917, 9.681100232202608, 8.747353052661587, 7.821825756655492, 6.845007288593761, 7.837975342971426, 8.850263489313411, 9.857960939446693, 10.81479129539423, 11.709450253542336, 12.628831675111352, 13.606068579649664, 14.54665973293005, 16.43160287755873, 17.38680887905546, 16.502863788221205, 15.474938586722528, 14.44926979174511, 13.511662732029913, 12.604846650028046, 11.571531503094416, 10.691318901104717, 9.725020377083586, 8.880367664747236, 7.867050864646689, 8.839334977011864, 9.81074617772602, 10.877076189140634, 11.773412724231456, 12.665178790018674, 13.676892609543323, 14.540627292173673, 15.521453132431267, 17.424804965682096, 17.448612638329816, 16.481091019105694, 15.653029355793553, 14.676757103939481, 13.660767271289373, 12.642211877704831, 11.773751905744783, 10.837398192478412, 10.66080040404503, 9.829035021968936, 8.917606879105014, 9.84808741753548, 10.804489013040813, 11.812305793340464, 12.765512533774421, 13.598012819535919, 14.611512473189885, 15.504745607882835, 16.510099544276652, 17.257624710580558, 16.4375507176915, 15.489940018786367, 14.656313491237034, 13.64304388417434, 12.675304595447367, 11.688644536880087, 10.827243123304683, 9.895582302250148, 10.735356019478951, 10.866753564091152, 9.949409827109406, 10.780181753397466, 11.84626356205538, 12.782555635877271, 13.724649151173624, 14.561945137358338, 15.493802817636862, 16.44446477292861, 17.43572108467206, 16.329024654476402, 15.448838058715598, 14.53698563166942, 13.58915849385669, 12.72678469917238, 11.708081066026182, 10.684010281684579, 9.758562892064099, 8.820608992561853, 9.772293969129597, 10.677814808074118, 10.900577315986308, 11.72284639238486, 12.786574773526539, 13.740183496516318, 14.661815242801657, 15.564561186953645, 16.496026869432193, 17.485835936157713, 17.38079653300998, 15.32253260976629, 14.474647818209586, 13.501866396491078, 12.619958486361964, 11.710215335370265, 10.825381769893115, 9.750796733765823, 8.815390525538977, 7.86679602486153, 8.802191537105465, 9.698197178840068, 10.681046248623518, 11.59805376264824, 12.531606607417801, 13.394432002720468, 14.348033776367808, 15.391245232788837, 16.381197203571563, 17.336114120714686, 16.392437606529622, 14.355901184569854, 13.405739435186849, 12.444183424242048, 11.62175572201137, 10.766254339876866, 9.882508302029121, 8.93686367626525, 7.889121244440257, 6.887636275566814, 7.852871331560239, 8.748890720875455, 9.788757585099033, 10.570097146947573, 11.517066532722957, 12.442266976126422, 13.388330185645573, 14.372100282081671, 15.310582750064505, 16.308249863438757, 15.380789391137801, 13.505789620234207, 12.436244048370355, 11.506276092617414, 10.605660324962091, 9.724012969818542, 8.885761553438961, 7.916351427531845, 6.908932262329104, 5.8449252239266425, 6.861950830844668, 7.773507197349271, 8.763257001894369, 9.615693788921245, 10.651808749123205, 11.562215997392434, 12.4155563464464, 13.373854807321019, 14.358402219554833, 15.381982990958845, 14.473809504215128, 12.513348540008444, 11.500423105686705, 10.570809282967026, 9.674363010760146, 8.696668957949111, 7.836402674083868, 6.907995138161209, 5.874264347336615, 4.83711128908373, 5.8084691834897955, 6.765454238348038, 7.747926015961683, 8.640765178253, 9.652682149393328, 10.533311337527678, 11.472057806473009, 12.418170783484504, 13.38841736683126, 14.353403433447484, 13.48752101280259, 11.603580345703431, 10.668518678209807, 9.631352339695407, 8.70505685042873, 7.761473274512054, 6.875240032544658, 5.858421501385829, 4.865438793016609, 3.8844118261359624, 4.813189015426023, 5.723255455803036, 6.700293029383379, 7.64769445436074, 8.610519671308381, 9.594513341130481, 10.53453101711315, 11.56702203773876, 12.632268259898236, 13.537656642779728, 12.594963051849883, 10.65773107815616, 9.699697697616234, 8.704149406384301, 7.742357763612016, 6.824033250504114, 5.83978905273204, 4.888280491670931, 3.8558753702755313, 2.9514262217947556, 3.8780864958045242, 4.751416687254345, 5.750692081847348, 6.695588476533688, 7.714533867395697, 8.764516248636774, 9.731768802031073, 10.741421455311722, 11.683910871336893, 12.65307403101486, 11.709373506955316, 9.84102118431245, 8.789661201670585, 7.80759863103953, 6.81658778464717, 5.783587204404471, 4.809481622874071, 3.839026742829759, 2.8935462117950026, 1.9261235313960785, 2.8705802850505395, 3.7959304052842557, 4.73213827542404, 5.7648978712860135, 6.775439363738775, 7.803612790498358, 8.818755964101923, 9.718064566539983, 10.758340684428049, 11.700318717002201, 10.806718989356233, 8.910266376793567, 7.880763842351353, 6.8424419067788635, 5.858654977247693, 4.85889656778625, 3.8599400882854233, 2.8802458115619713, 1.8982318641270548, 0.9438106632107817, 1.9818083140276166, 2.92885080710159, 3.9938185233882706, 4.917122833081491, 5.7569105989368605, 6.770462470699889, 7.827034086975299, 8.755040676700974, 9.739536984571979, 10.686009246826863, 9.879324245084764, 7.9732885785374625, 7.026415293139327, 6.040383519137404, 5.020293127819308, 3.9535583096042686, 2.998434267815524, 2.0421330799459776, 1.0256578325409837, 0.0, 0.9880428097831476, 1.919201177585033, 2.939964990765885, 3.8685342082284797, 4.808982564885673, 5.8153555520520435, 6.810316350575206, 7.794847945391755, 8.759520583147742, 9.720324034090682, 8.927030996040873, 8.933269117655675, 7.859858710515115, 6.898682677785834, 5.961767497802383, 4.887494574655911, 4.011211869626849, 2.956878656815274, 2.0018549251041593, 1.0157105351288394, 1.998737658621566, 2.8912830554986444, 3.8760588576798383, 4.863367198437964, 5.867006584058438, 6.808095590104431, 7.745845214327094, 8.736708332128265, 9.737693409032348, 10.779783162706636, 9.876922458907682, 9.924819222166038, 8.878877701290618, 7.880862981993015, 6.88866741017538, 5.855086048057796, 4.9200253270061785, 3.9645052448170492, 2.9701051774987346, 2.0111936283398655, 3.0702017223169875, 3.8358662043756517, 4.792820464300504, 5.840245043955993, 6.832035171511153, 7.817056845561292, 8.77482400661418, 9.703353067085565, 10.705766675452212, 11.71825751610914, 10.900279206757473], [12.55422728621814, 11.60458277309859, 10.611240437554601, 9.65144828401303, 8.792754366755748, 7.7880560516668975, 6.837325014497468, 5.830721535629148, 4.79118373188923, 3.8464202762554534, 3.147215954192759, 4.0108122978553, 4.974754970495694, 5.938197911813248, 6.885372362983139, 7.800427212822054, 8.828370920552151, 9.840562879700993, 10.889110120312866, 11.908746590706635, 13.525702752132005, 12.580618657778746, 11.642046748563443, 10.591846363000974, 9.728314812103543, 8.75110159915274, 7.690075710504667, 6.754849978949975, 5.768102972317514, 4.838573979170702, 4.185352225157517, 4.953095193481354, 5.99181921145408, 6.890135192282852, 7.812337755795875, 8.818707637133386, 9.781668008278618, 10.784309670526307, 11.770928987566407, 12.717855376122428, 14.5434240153947, 13.58127447956756, 12.618605593011832, 11.620740236153939, 10.737418573392064, 9.739440045652046, 8.712445160624974, 7.694404815912244, 6.724578500273672, 5.771749553715605, 5.160528077909833, 5.890594639410673, 6.948030617638799, 7.896614613711506, 8.831568713043113, 9.869683261761596, 10.763613425888362, 11.754587941101322, 12.718602815817757, 13.655621926934117, 15.555686844035325, 14.517278691337347, 13.5330620245183, 12.583250860146226, 11.679045948412393, 10.6102894654003, 9.626669962290523, 8.627585162770748, 7.67141297147718, 6.725315904573197, 6.227291807447596, 6.9029583438891144, 7.866589392552506, 8.91169796133802, 9.7758748745555, 10.850048080896197, 11.717279642154494, 12.655409264144044, 13.652945593359377, 14.590453433094568, 16.472603146741385, 15.450947304929272, 14.483104730874945, 13.487882406595695, 12.523675540132416, 11.590027611423864, 10.600975966148843, 9.658240052526022, 8.69305742241946, 7.759310242878441, 7.168519285648683, 7.8330500983769085, 8.826018152754573, 9.838306299096558, 10.846003749229842, 11.802834105177379, 12.697493063325481, 13.616874484894497, 14.59411138943281, 15.534702542713196, 17.405662806478176, 16.450456804981446, 15.514820978438056, 14.486895776939381, 13.461226981961962, 12.523619922246766, 11.616803840244899, 10.583488693311269, 9.70327609132157, 8.736977567300439, 8.227061193740427, 8.855093674429837, 9.827377786795012, 10.798788987509168, 11.865118998923784, 12.761455534014605, 13.65322159980182, 14.664935419326468, 15.528670101956818, 16.509495942214414, 18.39886489460154, 17.464197343853616, 16.493138544178823, 15.429442336111368, 14.453170084257296, 13.574418817846766, 12.544883960659536, 11.529582640027579, 10.686127123375265, 9.672757594261883, 9.175728550962127, 9.905649688888161, 10.836130227318627, 11.79253182282396, 12.800348603123611, 13.75355534355757, 14.586055629319064, 15.59955528297303, 16.49278841766598, 17.498142354059798, 18.245667520363707, 17.42559352747465, 16.477982828569516, 15.644356301020183, 14.631086693957489, 13.663347405230516, 12.676687346663236, 11.815285933087832, 10.883625112033295, 10.044309960754017, 10.213447093084342, 10.937452636892552, 11.768224563180613, 12.834306371838528, 13.770598445660418, 14.712691960956771, 15.549987947141483, 16.481845627420007, 17.432507582711757, 18.423763894455206, 17.31706746425955, 16.436880868498747, 15.52502844145257, 14.57720130363984, 13.71482750895553, 12.69612387580933, 11.672053091467728, 10.746605701847248, 9.808651802345, 9.081247910404663, 9.760344639120065, 10.76499206242544, 11.693919818223891, 12.571735460995214, 13.465663828928069, 14.403403234246852, 15.408051759334374, 16.35148249947842, 17.36656637512526, 18.36883934279313, 16.31057541954944, 15.462690627992735, 14.489909206274227, 13.608001296145114, 12.69825814515341, 11.813424579676264, 10.738839543548972, 9.803433335322126, 8.854838834644678, 8.11114547838053, 8.780727009886016, 9.763576079669466, 10.680583593694188, 11.614136438463749, 12.476961833766415, 13.430563607413756, 14.473775063834783, 15.463727034617511, 16.418643951760632, 17.380480416312768, 15.343943994353003, 14.393782244969998, 13.432226234025197, 12.60979853179452, 11.754297149660013, 10.870551111812269, 9.924906486048398, 8.877164054223405, 7.875679085349962, 7.088311803721645, 7.8314205519214015, 8.87128741614498, 9.65262697799352, 10.599596363768905, 11.52479680717237, 12.470860016691521, 13.45463011312762, 14.393112581110453, 15.390779694484705, 16.36883220092095, 14.493832430017356, 13.424286858153504, 12.494318902400563, 11.59370313474524, 10.71205577960169, 9.87380436322211, 8.904394237314992, 7.8969750721122525, 6.832968033709791, 6.097391303006074, 6.856037028395218, 7.845786832940317, 8.698223619967193, 9.734338580169153, 10.644745828438381, 11.498086177492347, 12.456384638366966, 13.44093205060078, 14.464512822004792, 15.461852313998277, 13.501391349791593, 12.488465915469854, 11.558852092750175, 10.662405820543293, 9.684711767732258, 8.824445483867017, 7.896037947944357, 6.862307157119762, 5.825154098866878, 5.0439096556512, 5.847984069393986, 6.830455847007632, 7.7232950092989485, 8.735211980439276, 9.615841168573626, 10.554587637518956, 11.500700614530452, 12.470947197877207, 13.435933264493432, 14.47556382258574, 12.59162315548658, 11.656561487992956, 10.619395149478557, 9.693099660211878, 8.749516084295202, 7.8632828423278065, 6.846464311168977, 5.853481602799757, 4.8724546359191105, 3.9731000237159195, 4.805785286848985, 5.782822860429327, 6.730224285406688, 7.693049502354329, 8.677043172176429, 9.617060848159097, 10.649551868784707, 11.678518419861389, 12.634286834687298, 13.576980425617144, 11.64577388793931, 10.687740507399383, 9.69219221616745, 8.730400573395166, 7.8120760602872625, 6.827831862515188, 5.876323301454078, 4.8439181800586795, 3.9394690315779033, 3.037997504094421, 3.8339465183002934, 4.833221912893297, 5.778118307579636, 6.794836158416749, 7.830616685736384, 8.768308569207813, 9.753378645528574, 10.695868061553746, 11.665031221231711, 12.604278474352688, 10.829063994095598, 9.777704011453732, 8.795641440822678, 7.804630594430318, 6.771630014187619, 5.7975244326572195, 4.827069552612906, 3.8815890215781503, 2.914166341179226, 2.030491293340436, 2.878460236330204, 3.8146681064699877, 4.847427702331961, 5.800060792684807, 6.81556998071521, 7.830713154318777, 8.730021756756836, 9.770297874644902, 10.712275907219054, 11.555013443790953, 9.898309186576716, 8.868806652134502, 7.830484716562012, 6.846697787030841, 5.846939377569398, 4.8479828980685715, 3.868288621345119, 2.8862746739102025, 1.9318534729939292, 1.0314655606867522, 1.9408079973184427, 3.005775713605123, 3.9290800232983427, 4.768867789153713, 5.782419660916742, 6.838991277192152, 7.766997866917826, 8.751494174788832, 9.697966437043716, 10.62345221402417, 8.961331388320609, 8.014458102922474, 7.028426328920551, 6.008335937602455, 4.941601119387416, 3.9864770775986713, 3.030175889729125, 2.0137006423241313, 0.9880428097831476, 0.0, 0.9311583678018855, 1.9519221809827376, 2.880491398445332, 3.820939755102525, 4.827312742268896, 5.822273540792058, 6.806805135608608, 7.7714777733645946, 8.732281224307535, 9.732121591639032, 9.92131192743882, 8.847901520298262, 7.886725487568981, 6.949810307585531, 5.875537384439058, 4.999254679409996, 3.944921466598421, 2.989897734887307, 2.003753344911987, 1.0418526143352815, 1.903240245715497, 2.8880160478966905, 3.875324388654816, 4.878963774275291, 5.820052780321284, 6.757802404543947, 7.748665522345117, 8.7496505992492, 9.791740352923489, 10.682013054505841, 10.912862031949185, 9.866920511073765, 8.868905791776163, 7.876710219958527, 6.843128857840943, 5.908068136789326, 4.9525480546001965, 3.9581479872818823, 2.999236438123013, 2.113316678030703, 2.8478233945925044, 3.8047776545173564, 4.852202234172846, 5.843992361728006, 6.829014035778145, 7.786781196831033, 8.715310257302418, 9.717723865669065, 10.730214706325993, 11.705369802355632], [11.623068918416255, 10.673424405296705, 9.680082069752716, 8.720289916211145, 7.861595998953862, 6.856897683865012, 5.906166646695582, 4.899563167827261, 3.860025364087344, 2.9152619084535676, 3.902827745390817, 4.899499533055993, 5.863442205696387, 6.8268851470139404, 7.774059598183832, 8.731585580623939, 9.759529288354036, 10.771721247502878, 11.82026848811475, 12.66288066470651, 12.59454438433012, 11.649460289976862, 10.710888380761558, 9.660687995199089, 8.797156444301656, 7.8199432313508535, 6.75891734270278, 5.823691611148089, 4.836944604515629, 3.9074156113688163, 4.861520869377596, 5.79115387877886, 6.829877896751586, 7.7788224274835445, 8.701024990996567, 9.707394872334078, 10.67035524347931, 11.715336736536816, 12.701956053576918, 13.535134490534, 13.612265647592816, 12.650116111765675, 11.687447225209947, 10.689581868352054, 9.806260205590178, 8.80828167785016, 7.781286792823087, 6.763246448110358, 5.793420132471787, 4.840591185913719, 5.836696722129912, 6.728653324708179, 7.786089302936305, 8.734673299009012, 9.707673188875779, 10.758370496962288, 11.652300661089054, 12.685615007111831, 13.649629881828266, 14.47290104134569, 14.62452847623344, 13.586120323535463, 12.601903656716415, 11.652092492344341, 10.747887580610508, 9.679131097598415, 8.695511594488638, 7.696426794968863, 6.740254603675294, 5.794157536771311, 6.840031547653207, 7.7410170291866205, 8.704648077850011, 9.749756646635525, 10.651979350388165, 11.726152556728863, 12.605966877355186, 13.544096499344736, 14.541632828560068, 15.45975511350553, 15.551473136421382, 14.519788937127387, 13.55194636307306, 12.55672403879381, 11.592517172330531, 10.658869243621979, 9.669817598346958, 8.727081684724137, 7.761899054617575, 6.828151875076555, 7.781259025854293, 8.671108783674415, 9.664076838052079, 10.676364984394064, 11.722108225062508, 12.678938581010044, 13.586180298526173, 14.505561720095189, 15.482798624633501, 16.423389777913886, 16.47450443867629, 15.519298437179561, 14.583662610636171, 13.555737409137496, 12.530068614160077, 11.592461554444881, 10.685645472443014, 9.652330325509384, 8.772117723519683, 7.805819199498553, 8.740409188356347, 9.693152359727343, 10.665436472092518, 11.636847672806674, 12.703177684221288, 13.63756000984727, 14.541908835002511, 15.55362265452716, 16.41735733715751, 17.398183177415103, 17.467706526799656, 16.53303897605173, 15.56198017637694, 14.498283968309483, 13.522011716455411, 12.643260450044881, 11.613725592857651, 10.598424272225694, 9.754968755573378, 8.741599226459998, 9.689076545578047, 10.654857549365577, 11.585338087796043, 12.630590508121466, 13.638407288421117, 14.617116946925176, 15.474742864519756, 16.48824251817372, 17.381475652866676, 18.386829589260493, 18.434912840097798, 17.47093710499258, 16.523326406087445, 15.511646888961963, 14.490889848433985, 13.523150559707013, 12.536490501139733, 11.544933054665794, 10.696784645801642, 9.75824687230706, 9.88112676979093, 10.785001183500457, 11.7054260894094, 12.634675286030618, 13.550107363675771, 14.409410958073, 15.35673554797166, 16.288593228250182, 17.313848748258547, 18.305105060001996, 18.248225832061433, 17.368039236300632, 16.456186809254454, 15.508359671441724, 14.617769910192798, 13.5990662770466, 12.574995492704996, 11.649548103084516, 10.692094714296141, 9.772988666376017, 8.82918627131818, 9.833833694623555, 10.762761450422007, 11.640577093193329, 12.534505461126184, 13.472244866444967, 14.476893391532489, 15.420324131676534, 16.435408007323378, 17.494738750947487, 17.241733787351322, 16.39384899579462, 15.421067574076112, 14.539159663946998, 13.629416512955295, 12.716366980913532, 11.64178194478624, 10.706375736559394, 9.738281746595819, 8.802886234351885, 7.849568642084131, 8.832417711867581, 9.749425225892303, 10.682978070661864, 11.54580346596453, 12.499405239611871, 13.542616696032898, 14.532568666815626, 15.48748558395875, 16.47171892768554, 16.275102362154886, 15.324940612771883, 14.363384601827082, 13.540956899596404, 12.685455517461898, 11.773493513049537, 10.827848887285667, 9.780106455460674, 8.77862148658723, 7.9120933776328854, 6.900262184119517, 7.940129048343096, 8.721468610191636, 9.66843799596702, 10.593638439370485, 11.539701648889636, 12.523471745325734, 13.461954213308568, 14.45962132668282, 15.46007071229372, 15.424990797819241, 14.355445225955389, 13.425477270202448, 12.524861502547125, 11.643214147403574, 10.776746764459379, 9.807336638552261, 8.79991747334952, 7.735910434947059, 6.921172876917314, 5.9248786605933335, 6.914628465138432, 7.767065252165308, 8.803180212367268, 9.713587460636496, 10.566927809690462, 11.525226270565081, 12.509773682798896, 13.533354454202907, 14.533451464855911, 14.432549717593478, 13.41962428327174, 12.49001046055206, 11.593564188345178, 10.615870135534143, 9.746616143476148, 8.798980349181626, 7.765249558357031, 6.728096500104146, 5.8860703510727985, 4.916825701592101, 5.899297479205747, 6.792136641497064, 7.80405361263739, 8.684682800771741, 9.623429269717072, 10.569542246728567, 11.539788830075322, 12.504774896691547, 13.547162973443374, 13.522781523288465, 12.587719855794841, 11.550553517280441, 10.624258028013763, 9.680674452097087, 8.785453501936939, 7.749406712406246, 6.756424004037026, 5.775397037156379, 4.815260719137518, 3.874626919047099, 4.851664492627442, 5.799065917604803, 6.761891134552444, 7.745884804374544, 8.685902480357212, 9.718393500982822, 10.747360052059504, 11.703128466885413, 12.64582205781526, 12.576932255741195, 11.618898875201268, 10.623350583969335, 9.66155894119705, 8.743234428089147, 7.758990230317073, 6.79121519324365, 5.746860581295948, 4.842411432815172, 3.8801581995160195, 2.9027881504984077, 3.9020635450914116, 4.84695993977775, 5.863677790614863, 6.8994583179344975, 7.837150201405926, 8.82222027772669, 9.764709693751861, 10.733872853429826, 11.673120106550801, 11.58955288103285, 10.708862379255617, 9.726799808624563, 8.735788962232203, 7.702788381989504, 6.728682800459104, 5.758227920414791, 4.784531422815419, 3.8171087424164956, 2.8726519887620343, 1.947301868528318, 2.883509738668102, 3.916269334530076, 4.868902424882921, 5.884411612913324, 6.899554786516891, 7.79886338895495, 8.839139506843017, 9.781117539417167, 10.623855075989066, 10.66135171451348, 9.799965019936387, 8.761643084363897, 7.777856154832726, 6.778097745371283, 5.779141265870456, 4.799446989147004, 3.8174330417120874, 2.8630118407958145, 1.9626239284886378, 1.0096496295165571, 2.0746173458032375, 2.997921655496458, 3.837709421351828, 4.851261293114856, 5.907832909390266, 6.83583949911594, 7.820335806986947, 8.76680806924183, 9.692293846222283, 9.754705641340557, 8.94561647072436, 7.959584696722437, 6.939494305404341, 5.872759487189302, 4.917635445400557, 3.9613342575310106, 2.9448590101260166, 1.919201177585033, 0.9311583678018855, 0.0, 1.020763813180852, 1.9493330306434467, 2.8897813873006397, 3.8961543744670104, 4.8911151729901725, 5.875646767806722, 6.840319405562709, 7.801122856505648, 8.800963223837146, 10.715044054592674, 9.779059888100146, 8.817883855370866, 7.880968675387416, 6.806695752240944, 5.887941914610689, 4.833608701799114, 3.8785849700879997, 2.89244058011268, 1.9094134566199532, 0.9720818779136116, 1.9568576800948052, 2.9441660208529306, 3.947805406473405, 4.888894412519397, 5.826644036742062, 6.817507154543232, 7.8184922314473155, 8.860581985121604, 9.750854686703954, 11.742797049267525, 10.79807887887565, 9.800064159578048, 8.807868587760412, 7.774287225642829, 6.7967553719900184, 5.841235289800889, 4.846835222482575, 3.887923673323706, 2.9562125299987674, 1.9166650267906187, 2.8736192867154706, 3.92104386637096, 4.91283399392612, 5.897855667976259, 6.855622829029148, 7.784151889500533, 8.78656549786718, 9.799056338524109, 10.774211434553745], [10.602305105235402, 9.652660592115852, 8.659318256571863, 7.699526103030292, 6.848280598248816, 5.852404223414866, 4.932096849906876, 3.925493371038555, 2.885955567298638, 3.8551006315145653, 4.842666468451815, 5.869142058737966, 6.83308473137836, 7.823077630020463, 8.77967716087504, 9.750712988131703, 10.78029310153489, 11.792485060683731, 12.661753321919425, 11.642116851525657, 11.573780571149268, 10.628696476796009, 9.690124567580705, 8.639924182018236, 7.823086647512949, 6.845873434562147, 5.784847545914074, 4.8496218143593826, 3.8628748077269224, 4.847254334429814, 5.801359592438594, 6.730992601839858, 7.769716619812583, 8.750993096177336, 9.706642553687777, 10.713012435025288, 11.67597280617052, 12.720954299228026, 13.461297065909168, 12.514370677353147, 12.591501834411963, 11.629352298584822, 10.666683412029094, 9.6688180551712, 8.83219040880147, 7.834211881061452, 6.808449217401824, 5.808125433525399, 4.8382991178868275, 5.780429908974717, 6.77653544519091, 7.668492047769177, 8.725928025997302, 9.67451202207001, 10.647511911936776, 11.703783892509495, 12.657918223780264, 13.691232569803041, 14.453340563375919, 13.452137228164837, 13.603764663052587, 12.56535651035461, 11.581139843535562, 10.631328679163488, 9.785140304866138, 8.749505297098477, 7.7658857939887005, 6.77580103245735, 5.819628841163781, 6.733996259832309, 7.779870270714205, 8.680855752247618, 9.64448680091101, 10.689595369696523, 11.591818073449163, 12.66599127978986, 13.611584440046396, 14.549714062035946, 15.376499140059869, 14.438991300324677, 14.53070932324053, 13.499025123946534, 12.531182549892208, 11.636098276282297, 10.671891409819018, 9.738243481110466, 8.749191835835445, 7.806455922212624, 6.841273292106062, 7.767990598137553, 8.721097748915291, 9.610947506735412, 10.603915561113077, 11.616203707455062, 12.661946948123505, 13.618777304071042, 14.591797861217383, 15.511179282786399, 16.37093599455138, 15.430344841270994, 15.453740625495438, 14.498534623998708, 13.577880878834584, 12.635111646625983, 11.609442851648565, 10.671835791933368, 9.7650197099315, 8.731704562997871, 7.85149196100817, 8.745657922559552, 9.680247911417347, 10.63299108278834, 11.605275195153515, 12.576686395867672, 13.643016407282285, 14.577398732908268, 15.547526397693721, 16.55924021721837, 17.30549470707539, 16.38436873620636, 16.446942713618803, 15.512275162870878, 14.610143473686673, 13.57765820579797, 12.601385953943899, 11.722634687533368, 10.693099830346139, 9.677798509714181, 8.834342993061865, 9.681437949520996, 10.628915268639046, 11.20216177212954, 11.743218209830179, 12.789055875912092, 13.626054990771372, 14.52314526841988, 15.418421705361457, 16.331568616535453, 17.297029250969047, 17.373411024124735, 17.414149026916945, 16.523337083509194, 15.601294474006, 14.59102112645045, 13.570264085922473, 12.6025247971955, 11.61586473862822, 10.624307292154281, 9.77615888329013, 10.698085595368058, 10.901890582971781, 10.170358824125149, 10.811123873968192, 11.74037307058941, 12.655805148234565, 13.507164797640378, 14.454489387539038, 15.386347067817562, 16.41160258782593, 17.402858899569377, 17.47272347583823, 17.5330338752197, 16.554248861122947, 15.628393107319704, 14.60165191928937, 13.584567859895142, 12.620498993823729, 11.692987523394866, 10.851132192978424, 10.793752479556868, 9.849950084499032, 9.219191335248247, 9.868459234980799, 10.746274877752121, 11.640203245684978, 12.569998706012345, 13.574647231099867, 14.518077971243912, 15.520070095539493, 16.559516731601963, 16.46623143112812, 17.409205382502005, 16.441831387256965, 15.559923477127848, 14.650180326136148, 13.737130794094387, 12.662545757967095, 11.727139549740249, 10.75904555977667, 9.823650047532736, 8.870332455264982, 8.217775352492273, 8.855123010451095, 9.788675855220657, 10.651501250523324, 11.584067327827986, 12.627278784249015, 13.617230755031741, 14.572147672174864, 15.494052567011972, 15.499600005931683, 16.345704425952736, 15.384148415007935, 14.561720712777253, 13.70621933064275, 12.79425732623039, 11.84861270046652, 10.800870268641528, 9.799385299768085, 8.932857190813737, 7.921025997300368, 7.187413694397001, 7.827166394750429, 8.774135780525814, 9.69933622392928, 10.624363737105751, 11.60813383354185, 12.546616301524683, 13.544283414898935, 14.482404351620152, 14.545026911580223, 15.376209039136242, 14.4462410833833, 13.545625315727975, 12.663977960584425, 11.797510577640232, 10.828100451733114, 9.820681286530375, 8.756674248127913, 7.941936690098165, 6.945642473774185, 6.161913111192336, 6.872763036724101, 7.90887799692606, 8.798249548852612, 9.651589897906577, 10.609888358781197, 11.59443577101501, 12.618016542419022, 13.549942140039898, 13.537826121421507, 14.440388096452592, 13.510774273732913, 12.61432800152603, 11.636633948714994, 10.767379956656999, 9.819744162362479, 8.786013371537884, 7.748860313284999, 6.906834164253651, 5.937589514772952, 5.119895141862091, 5.897834426055857, 6.9097513971961835, 7.769344888987856, 8.708091357933187, 9.654204334944682, 10.624450918291437, 11.589436984907662, 12.56365364862736, 12.539986822657077, 13.501216572217691, 12.571317330461294, 11.645021841194616, 10.701438265277938, 9.80621731511779, 8.770170525587098, 7.777187817217878, 6.796160850337232, 5.83602453231837, 4.895390732227951, 4.072262155283786, 4.904763702163597, 5.867588919111237, 6.830546892590659, 7.770564568573327, 8.781142711627488, 9.726596238878653, 10.68236465370456, 11.625058244634406, 11.594137555109805, 12.552170935649732, 11.644114397150188, 10.682322754377903, 9.763998241269999, 8.779754043497926, 7.811979006424502, 6.7676243944768, 5.863175245996025, 4.9009220126968716, 3.9235519636792597, 3.1226612077477554, 3.945762027420258, 4.842913977434011, 5.878694504753646, 6.816386388225075, 7.801456464545838, 8.74394588057101, 9.713109040248973, 10.652356293369948, 10.568789067851997, 11.636491359540605, 10.747563621805416, 9.756552775413056, 8.723552195170356, 7.7494466136399565, 6.778991733595643, 5.8052952359962715, 4.837872555597348, 3.8934158019428864, 2.96806568170917, 2.075240169225226, 3.015071422172584, 3.848138611702069, 4.8636477997324725, 5.87879097333604, 6.778099575774099, 7.818375693662165, 8.760353726236314, 9.603091262808213, 9.640587901332626, 10.67009043577484, 9.78240689754475, 8.798619968013579, 7.798861558552135, 6.7999050790513085, 5.820210802327856, 4.8381968548929395, 3.8837756539766666, 2.98338774166949, 2.030413442697409, 1.071453256323591, 1.9771578423156053, 2.816945608170976, 3.8304974799340044, 4.887069096209415, 5.8150756859350885, 6.799571993806095, 7.746044256060977, 8.67153003304143, 8.733941828159704, 9.68081511355784, 8.980348509903289, 7.960258118585193, 6.893523300370154, 5.938399258581409, 4.982098070711863, 3.9656228233068687, 2.939964990765885, 1.9519221809827376, 1.020763813180852, 0.0, 0.9285692174625945, 1.8690175741197876, 2.8753905612861583, 3.8703513598093204, 4.85488295462587, 5.819555592381857, 6.780359043324796, 7.780199410656293, 9.694280241411821, 10.674993232511532, 9.838647668551719, 8.901732488568268, 7.827459565421796, 6.90612410470648, 5.851790891894905, 4.89676716018379, 3.91062277020847, 2.9275956467157433, 1.9902640680094015, 0.936093866913953, 1.9234022076720785, 2.927041593292553, 3.8681305993385453, 4.805880223561209, 5.7967433413623795, 6.7977284182664635, 7.8398181719407525, 8.730090873523102, 10.722033236086672, 11.694012223287036, 10.8208279727589, 9.828632400941265, 8.795051038823681, 7.8149375620858095, 6.85941747989668, 5.865017412578365, 4.906105863419496, 3.896051253059765, 2.8565037498516164, 1.8995494899267644, 2.9469740695822537, 3.9387641971374143, 4.893362207526113, 5.834859015848295, 6.76338807631968, 7.765801684686327, 8.778292525343256, 9.753447621372892], [9.673735887772809, 8.72409137465326, 7.730749039109271, 6.770956885567699, 5.919711380786222, 4.923835005952272, 4.007061826088723, 3.024861825569115, 3.814524784761232, 4.783669848977159, 5.771235685914409, 6.797711276200561, 7.761653948840955, 8.751646847483057, 9.708246378337634, 10.679282205594296, 11.708862318997484, 12.721054278146326, 11.733184104456832, 10.713547634063064, 10.645211353686674, 9.700127259333415, 8.761555350118112, 7.7113549645556425, 6.907290116768378, 5.969790312383372, 4.94695503016666, 4.025230092912254, 4.7914440251895165, 5.775823551892408, 6.729928809901188, 7.659561819302452, 8.698285837275177, 9.679562313639929, 10.63521177115037, 11.641581652487881, 12.604542023633114, 13.519347165486675, 12.532727848446575, 11.585801459890554, 11.66293261694937, 10.700783081122228, 9.738114194566501, 8.740248837708608, 7.9163938780568985, 6.958128758882677, 5.97055670165441, 5.074452570485733, 5.766868335349422, 6.708999126437311, 7.705104662653504, 8.59706126523177, 9.654497243459897, 10.603081239532605, 11.576081129399372, 12.63235310997209, 13.586487441242857, 14.48878622062976, 13.524771345913326, 12.523568010702244, 12.675195445589994, 11.636787292892016, 10.652570626072968, 9.702759461700895, 8.869343774121567, 7.911612781351064, 6.927993278241287, 6.131403233044757, 6.748198058626375, 7.662565477294903, 8.708439488176799, 9.609424969710211, 10.573056018373602, 11.618164587159116, 12.520387290911758, 13.594560497252456, 14.540153657508988, 15.445466251812608, 14.447929922597275, 13.510422082862084, 13.602140105777938, 12.570455906483941, 11.602613332429614, 10.7416326336824, 9.84926903586324, 8.915621107154688, 7.9380459514442725, 7.1620581228000315, 7.769842509568656, 8.696559815600146, 9.649666966377886, 10.539516724198005, 11.53248477857567, 12.544772924917655, 13.5905161655861, 14.547346521533637, 15.520367078679975, 16.406931472563063, 15.442366777088788, 14.5017756238084, 14.525171408032845, 13.569965406536115, 12.64931166137199, 11.740646004026086, 10.786820477692787, 9.849213417977591, 9.000462432859592, 8.087306763585278, 8.780061178470765, 9.674227140022145, 10.60881712887994, 11.561560300250934, 11.859959638204762, 12.831370838918918, 13.755621967833177, 14.58667586050025, 15.422686517416107, 16.337619262719418, 16.3769254896128, 15.455799518743763, 15.518373496156208, 14.583705945408285, 13.681574256224078, 12.729849433014778, 11.778763579988121, 10.90001231357759, 10.006809236674377, 9.033400710301589, 9.76291221052446, 10.61000716698359, 11.55748448610164, 11.74512953079805, 10.814648992367584, 11.860486658449497, 12.697485773308777, 13.594576050957285, 14.489852487898862, 15.402999399072858, 16.36846003350645, 16.44484180666214, 16.48557980945435, 15.594767866046602, 14.672725256543405, 13.753942530567297, 12.834430208970977, 11.885474989419597, 10.96037657749912, 9.979909492741688, 10.704728100752725, 11.626654812830651, 11.768368774369236, 10.812690305122247, 9.882554656505597, 10.811803853126817, 11.72723593077197, 12.578595580177783, 13.525920170076443, 14.457777850354967, 15.483033370363334, 16.474289682106782, 16.544154258375634, 16.604464657757106, 15.625679643660352, 14.821097527947641, 13.865818042337875, 12.86751805211924, 11.96501083269463, 11.048589723982273, 11.77970141044102, 11.722321697019463, 10.778519301961627, 9.861522816245346, 8.939890017518206, 9.817705660289528, 10.711634028222383, 11.64142948854975, 12.646078013637272, 13.589508753781317, 14.591500878076898, 15.63094751413937, 15.537662213665524, 16.48063616503941, 16.660798878838694, 15.790297535442367, 14.875500409410515, 13.879314152465495, 12.898224380613385, 11.991762090507393, 11.687614777239265, 10.75221926499533, 9.798901672727578, 8.860106833489372, 7.926553792988502, 8.860106637758063, 9.72293203306073, 10.655498110365391, 11.69870956678642, 12.688661537569146, 13.64357845471227, 14.565483349549377, 14.571030788469088, 15.440986759749277, 16.31271763247053, 15.490289930239848, 14.634788548105345, 13.722826543692985, 12.777181917929115, 11.729439486104123, 10.72795451723068, 9.861426408276332, 8.849595214762964, 7.829745175394098, 6.898597177287835, 7.845566563063219, 8.770767006466684, 9.695794519643156, 10.679564616079254, 11.618047084062088, 12.61571419743634, 13.553835134157557, 13.616457694117628, 14.471491372932784, 15.374810300845896, 14.47419453319057, 13.59254717804702, 12.726079795102827, 11.756669669195709, 10.74925050399297, 9.685243465590508, 8.87050590756076, 7.87421169123678, 7.012135196634943, 5.944193819261507, 6.980308779463466, 7.8696803313900165, 8.723020680443982, 9.681319141318601, 10.665866553552416, 11.689447324956427, 12.621372922577303, 12.609256903958912, 13.535670430249134, 14.439343491195508, 13.542897218988625, 12.56520316617759, 11.695949174119594, 10.748313379825074, 9.71458258900048, 8.677429530747595, 7.835403381716246, 6.866158732235547, 5.970117227304697, 4.969265208593263, 5.981182179733589, 6.840775671525261, 7.779522140470592, 8.725635117482087, 9.695881700828842, 10.660867767445067, 11.635084431164765, 11.611417605194482, 12.572647354755096, 13.49988654792389, 12.573591058657211, 11.630007482740533, 10.734786532580385, 9.698739743049693, 8.705757034680472, 7.724730067799827, 6.764593749780965, 5.823959949690545, 4.9224842407263925, 3.976194484701002, 4.939019701648643, 5.901977675128064, 6.841995351110732, 7.852573494164894, 8.798027021416058, 9.753795436241965, 10.696489027171811, 10.665568337647212, 11.623601718187139, 12.572683614612783, 11.610891971840498, 10.692567458732594, 9.708323260960519, 8.740548223887096, 7.696193611939395, 6.79174446345862, 5.829491230159467, 4.852121181141854, 3.9728832931903617, 3.0171928099576637, 3.914344759971417, 4.950125287291051, 5.88781717076248, 6.872887247083243, 7.815376663108414, 8.784539822786378, 9.723787075907355, 9.640219850389403, 10.707922142078012, 11.67613283926801, 10.68512199287565, 9.652121412632951, 8.67801583110255, 7.707560951058238, 6.7338644534588665, 5.766441773059943, 4.821985019405481, 3.8966348991717648, 3.0038093866878204, 2.0865022047099897, 2.9195693942394745, 3.935078582269878, 4.950221755873445, 5.849530358311504, 6.8898064761995705, 7.831784508773721, 8.67452204534562, 8.712018683870031, 9.741521218312245, 10.710976115007345, 9.727189185476174, 8.72743077601473, 7.7284742965139035, 6.748780019790451, 5.7667660723555345, 4.812344871439262, 3.911956959132084, 2.9589826601600038, 2.0000224737861854, 1.048588624853011, 1.8883763907083813, 2.90192826247141, 3.95849987874682, 4.8865064684724935, 5.8710027763435, 6.817475038598383, 7.742960815578836, 7.80537261069711, 8.752245896095245, 9.738277670097167, 8.888827336047788, 7.822092517832749, 6.866968476044004, 5.910667288174458, 4.894192040769464, 3.8685342082284797, 2.880491398445332, 1.9493330306434467, 0.9285692174625945, 0.0, 0.9404483566571932, 1.9468213438235642, 2.9417821423467263, 3.9263137371632757, 4.890986374919263, 5.851789825862202, 6.851630193193699, 8.765711023949228, 9.746424015048937, 10.707600047778218, 9.830301706030863, 8.75602878288439, 7.834693322169074, 6.780360109357499, 5.8253363776463845, 4.8391919876710645, 3.8561648641783375, 2.918833285471996, 1.8646630843765475, 0.994832990209484, 1.9984723758299587, 2.939561381875951, 3.877311006098615, 4.868174123899786, 5.869159200803869, 6.9112489544781575, 7.801521656060508, 9.793464018624078, 10.76544300582444, 11.739491151065417, 10.75720161840386, 9.723620256286276, 8.743506779548403, 7.787986697359274, 6.793586630040959, 5.83467508088209, 4.824620470522359, 3.7850729673142105, 2.8281187073893586, 2.0232413294830236, 3.0137291733192613, 3.9647929900635193, 4.906289798385701, 5.834818858857087, 6.837232467223734, 7.849723307880662, 8.824878403910299], [8.733287531115616, 7.783643017996066, 6.790300682452076, 5.830508528910505, 4.979263024129029, 3.9833866492950785, 3.0666134694315303, 3.9653101822263084, 4.754973141418426, 5.724118205634353, 6.711684042571602, 7.738159632857753, 8.702102305498148, 9.69209520414025, 10.648694734994827, 11.619730562251489, 12.5884192838653, 11.841282988411512, 10.79273574779964, 9.773099277405871, 9.70476299702948, 8.759678902676221, 7.821106993460918, 6.770906607898448, 5.966841760111185, 5.029341955726179, 4.006506673509468, 4.941732405064159, 5.73189238184671, 6.716271908549602, 7.6703771665583815, 8.600010175959646, 9.638734193932372, 10.620010670297123, 11.575660127807563, 12.582030009145074, 13.544990380290306, 12.578898808829482, 11.59227949178938, 10.64535310323336, 10.722484260292175, 9.760334724465034, 8.797665837909307, 7.799800481051413, 6.975945521399706, 6.0176804022254835, 5.030108344997218, 5.990954882637638, 6.707316692006615, 7.649447483094504, 8.645553019310698, 9.537509621888965, 10.594945600117091, 11.5435295961898, 12.516529486056566, 13.572801466629285, 14.52693579790005, 13.548337863972566, 12.584322989256131, 11.58311965404505, 11.7347470889328, 10.696338936234822, 9.712122269415774, 8.7623111050437, 7.928895417464375, 6.971164424693871, 5.987544921584094, 6.986629721103869, 7.688646415283569, 8.603013833952097, 9.648887844833993, 10.549873326367406, 11.513504375030797, 12.55861294381631, 13.460835647568953, 14.535008853909652, 15.443147517144963, 14.505017895155413, 13.50748156594008, 12.56997372620489, 12.661691749120742, 11.630007549826747, 10.66216497577242, 9.801184277025206, 8.90882067920605, 7.975172750497497, 6.99759759478708, 7.9403335084099, 8.71029086622585, 9.63700817225734, 10.59011532303508, 11.4799650808552, 12.472933135232864, 13.128452422301534, 13.959628143499893, 14.604848932680282, 15.43796669723525, 15.466483115905866, 14.501918420431593, 13.561327267151206, 13.58472305137565, 12.62951704987892, 11.708863304714797, 10.800197647368892, 9.846372121035595, 8.908765061320398, 8.0600140762024, 8.865582149195147, 9.72050953512796, 10.61467549667934, 11.549265485537134, 12.502008656908128, 12.763119963529816, 12.087130903047447, 12.930170266712016, 13.646227503843056, 14.482238160758913, 15.397170906062225, 15.436477132955602, 14.515351162086569, 14.577925139499014, 13.64325758875109, 12.741125899566885, 11.789401076357581, 10.838315223330929, 9.959563956920398, 9.066360880017184, 9.811676095911457, 10.703360567181655, 11.550455523640784, 12.497932842758834, 12.648289856123103, 11.717809317692637, 11.093388067732654, 11.872034072187617, 12.65412769430009, 13.549404131241667, 14.462551042415663, 15.428011676849255, 15.504393450004944, 15.545131452797156, 14.654319509389408, 13.732276899886212, 12.813494173910101, 11.893981852313784, 10.945026632762405, 10.019928220841928, 10.758184878351557, 11.645176457409919, 12.567103169487845, 12.67152909969429, 11.715850630447301, 10.785714981830651, 10.025227838152306, 10.90178422965081, 11.638147223520589, 12.585471813419248, 13.517329493697773, 14.54258501370614, 15.533841325449588, 15.603705901718442, 15.664016301099911, 14.685231287003159, 13.880649171290445, 12.925369685680682, 11.927069695462047, 11.024562476037437, 11.826865109592141, 12.720149767098214, 12.66162621710789, 11.717823822050054, 10.7646831415704, 9.843050342843258, 9.031129645315017, 9.886182327101222, 10.700981131892556, 11.705629656980078, 12.64906039712412, 13.651052521419704, 14.690499157482177, 14.597213857008331, 15.540187808382218, 15.720350522181501, 14.84984917878517, 13.935052052753322, 12.938865795808303, 11.957776023956193, 12.770037476117263, 12.626919297327692, 11.691523785083758, 10.738206192816005, 9.763267158814426, 8.829714118313554, 8.073530622783553, 8.897480331939569, 9.715049753708197, 10.758261210129223, 11.748213180911952, 12.703130098055075, 13.625034992892184, 13.630582431811895, 14.500538403092085, 15.398210037586642, 15.820911528019954, 14.879013048246719, 13.841237853434302, 12.895593227670432, 12.669887842761316, 11.668402873887873, 10.801874764933524, 9.788899734851391, 8.732905500719152, 7.801757502612888, 7.0271317458113085, 7.945315305345525, 8.755346162985962, 9.73911625942206, 10.677598727404893, 11.675265840779145, 12.613386777500365, 12.676009337460435, 13.531043016275591, 14.460302705962008, 15.414642889847762, 14.532995534704213, 13.66652815176002, 12.697118025852902, 11.689698860650163, 10.6256918222477, 9.810954264217953, 8.814660047893973, 7.915295521959996, 6.84735414458656, 6.0454556884190636, 6.929231974732824, 7.7825723237867885, 8.740870784661407, 9.725418196895221, 10.748998968299233, 11.68092456592011, 11.668808547301719, 12.595222073591941, 13.52483589631162, 14.483345575645817, 13.505651522834782, 12.636397530776787, 11.688761736482267, 10.655030945657673, 9.617877887404788, 8.775851738373438, 7.80660708889274, 6.87327755262975, 5.872425533918316, 5.046329088689187, 5.900327314868068, 6.839073783813399, 7.785186760824893, 8.755433344171648, 9.720419410787873, 10.694636074507573, 10.67096924853729, 11.632198998097904, 12.605904586072985, 13.514039415314404, 12.570455839397725, 11.675234889237577, 10.639188099706885, 9.646205391337666, 8.66517842445702, 7.705042106438158, 6.764408306347739, 5.825644566051445, 4.879354810026055, 4.004166610604241, 4.9615293184708715, 5.90154699445354, 6.912125137507702, 7.857578664758864, 8.813347079584773, 9.756040670514619, 9.72511998099002, 10.683153361529946, 11.678701652761879, 12.551340328497691, 11.633015815389786, 10.648771617617712, 9.68099658054429, 8.636641968596589, 7.732192820115813, 6.769939586816659, 5.792569537799047, 4.876043618515415, 3.9203531352827166, 2.9738964033142237, 4.009676930633859, 4.947368814105287, 5.9324388904260505, 6.874928306451221, 7.8440914661291865, 8.783338719250162, 8.69977149373221, 9.767473785420819, 10.749536356051873, 11.625570349532843, 10.592569769290144, 9.618464187759743, 8.648009307715432, 7.674312810116059, 6.706890129717135, 5.762433376062674, 4.837083255828958, 3.942461997821688, 2.9896625300350426, 1.9791210375822814, 2.994630225612685, 4.009773399216252, 4.909082001654311, 5.949358119542378, 6.891336152116528, 7.734073688688428, 7.77157032721284, 8.801072861655053, 9.839394797227541, 10.667637542133367, 9.667879132671922, 8.668922653171096, 7.689228376447644, 6.707214429012727, 5.752793228096454, 4.8524053157892775, 3.899431016817197, 2.938675084920053, 1.981146257349725, 0.9479280340511882, 1.9614799058142167, 3.0180515220896273, 3.9460581118153013, 4.930554419686308, 5.8770266819411905, 6.802512458921643, 6.864924254039917, 7.811797539438053, 8.797829313439976, 9.817919704758072, 8.762540874489941, 7.807416832701197, 6.85111564483165, 5.834640397426656, 4.808982564885673, 3.8209397551025255, 2.8897813873006397, 1.8690175741197876, 0.9404483566571932, 0.0, 1.006372987166371, 2.0013337856895332, 2.985865380506083, 3.95053801826207, 4.911341469205009, 5.911181836536507, 7.825262667292035, 8.805975658391747, 9.767151691121027, 10.704066871104477, 9.696477139541583, 8.775141678826268, 7.720808466014692, 6.765784734303577, 5.779640344328257, 4.796613220835531, 3.859281642129189, 2.8051114410337408, 1.9352813468666772, 1.0580240191727655, 1.9991130252187579, 2.936862649441422, 3.927725767242593, 4.928710844146677, 5.970800597820965, 6.861073299403316, 8.853015661966886, 9.82499464916725, 10.799042794408226, 11.636758583271675, 10.664068612943469, 9.683955136205595, 8.728435054016467, 7.734034986698152, 6.775123437539283, 5.765068827179553, 4.725521323971404, 3.768567064046552, 2.963689686140217, 2.073280816662068, 3.0243446334063258, 3.965841441728508, 4.894370502199894, 5.896784110566541, 6.90927495122347, 7.884430047253106], [7.7269145439492455, 6.777270030829695, 5.783927695285706, 4.824135541744134, 3.9728900369626574, 2.9770136621287078, 3.991295565050546, 4.971683169392679, 5.761346128584797, 6.730491192800724, 7.718057029737973, 8.744532620024124, 9.708475292664518, 10.69846819130662, 11.655067722161197, 12.62054723110953, 11.58204629669893, 10.834910001245142, 9.786362760633269, 8.7667262902395, 8.698390009863111, 7.753305915509851, 6.814734006294548, 5.764533620732077, 4.960468772944814, 4.022968968559808, 4.931188769128483, 5.866414500683175, 6.738265369013081, 7.722644895715972, 8.676750153724752, 9.606383163126017, 10.645107181098743, 11.626383657463494, 12.582033114973934, 13.580467685865852, 12.61750731472062, 11.572525821663113, 10.585906504623011, 9.63898011606699, 9.716111273125806, 8.753961737298663, 7.791292850742935, 6.7934274938850425, 5.969572534233334, 5.011307415059113, 5.954790440616233, 6.915636978256654, 7.713689679172986, 8.655820470260874, 9.651926006477069, 10.543882609055336, 11.601318587283462, 12.54990258335617, 13.522902473222937, 14.579174453795655, 13.592396805281037, 12.541964876806198, 11.577950002089763, 10.57674666687868, 10.728374101766429, 9.689965949068451, 8.705749282249403, 7.75593811787733, 6.922522430298002, 6.0350788411450536, 6.91222701720311, 7.911311816722884, 8.69501940244994, 9.609386821118466, 10.655260832000362, 11.556246313533777, 12.519877362197168, 13.564985930982681, 14.092023006619417, 14.618923884906135, 14.436774529978594, 13.498644907989044, 12.501108578773712, 11.56360073903852, 11.655318761954373, 10.623634562660376, 9.65579198860605, 8.794811289858835, 7.9727350956572325, 7.039087166948679, 7.9222796904060955, 8.865015604028915, 9.716663853392221, 10.64338115942371, 11.59648831020145, 12.48633806802157, 13.479306122399235, 13.977181195501329, 13.021894131945075, 13.657339649401049, 14.490457413956017, 14.460110128739498, 13.495545433265224, 12.554954279984837, 12.57835006420928, 11.62314406271255, 10.702490317548424, 9.793824660202521, 8.910286537486778, 7.972679477771582, 8.984696171821415, 9.790264244814162, 10.72688252229433, 11.621048483845708, 12.555638472703503, 13.508381644074499, 13.769492950696185, 12.935859676247242, 11.992436255157198, 12.698718220563823, 13.53472887747968, 14.449661622782992, 14.430104145789233, 13.508978174920198, 13.571552152332643, 12.63688460158472, 11.734752912400513, 10.783028089191212, 9.902229639782112, 9.023478373371582, 9.9910429756362, 10.736358191530472, 11.69451425590516, 12.556828510807152, 13.504305829925203, 13.654662843289472, 12.724182304859006, 11.94211684093245, 10.934300060632799, 11.706618411020857, 12.601894847962434, 13.51504175913643, 14.480502393570024, 14.498020462838573, 14.538758465630785, 13.647946522223037, 12.72590391271984, 11.807121186743732, 10.957896268764967, 10.008941049213588, 10.944610316460944, 11.682866973970572, 12.636330146133425, 13.573476156654214, 13.677902086860659, 12.72222361761367, 11.79208796899702, 10.896155231373472, 9.964050218095991, 10.690637940241356, 11.637962530140015, 12.56982021041854, 13.595075730426906, 14.586332042170355, 14.59733291455207, 14.657643313933539, 13.678858299836786, 12.874276184124076, 11.989284102131865, 10.99098411191323, 11.949244571656452, 12.751547205211157, 13.711303455821719, 13.66799920427426, 12.724196809216423, 11.771056128736769, 10.849423330009628, 9.902057038536183, 8.948448315546404, 9.753471848613323, 10.758120373700844, 11.70155111384489, 12.70354323814047, 13.684126170315807, 13.590840869841958, 14.533814821215845, 14.713977535015129, 13.843476191618802, 12.998966469204506, 12.002780212259486, 12.882458119575208, 13.694719571736279, 13.633292284494061, 12.697896772250127, 11.744579179982374, 10.769640145980794, 9.836087105479924, 8.979180614166415, 7.959746320384751, 8.767540470428964, 9.810751926849992, 10.800703897632719, 11.755620814775842, 12.618662005725813, 12.624209444645523, 13.494165415925716, 14.391837050420273, 14.841678955969396, 13.942927464697902, 12.958718840604233, 13.820275323289447, 13.676260829927685, 12.674775861054242, 11.808247752099893, 10.79527272201776, 9.739278487885521, 8.808130489779257, 7.932781737194171, 7.0075812937907065, 7.807836879706729, 8.791606976142827, 9.73008944412566, 10.727756557499912, 11.607013790333994, 11.669636350294063, 12.524670029109222, 13.453929718795639, 14.413612492090794, 14.985168834756227, 14.030496753674981, 13.703491013019274, 12.696071847816532, 11.63206480941407, 10.817327251384322, 9.821033035060342, 8.921668509126366, 7.8537271317529305, 6.955344765939281, 5.991497963178006, 6.835063040507555, 7.793361501382175, 8.77790891361599, 9.801489685020002, 10.67455157875374, 10.662435560135348, 11.588849086425572, 12.518462909145251, 13.514194443565033, 14.465798220278208, 13.642770517943159, 12.69513472364864, 11.661403932824042, 10.624250874571157, 9.782224725539809, 8.81298007605911, 7.8796505397961205, 6.878798521084686, 5.956218166209404, 4.96259330331325, 5.891564500534166, 6.83767747754566, 7.8079240608924145, 8.77291012750864, 9.688263087341202, 9.66459626137092, 10.625826010931535, 11.599531598906614, 12.54127106034625, 13.530602536841151, 12.68160787640395, 11.645561086873258, 10.652578378504037, 9.67155141162339, 8.711415093604527, 7.770781293514109, 6.832017553217816, 5.885727797192426, 5.007788976738153, 4.023795306916053, 4.954037711174307, 5.905752150341331, 6.851205677592493, 7.806974092418402, 8.749667683348248, 8.718746993823649, 9.676780374363576, 10.672328665595508, 11.627433602315042, 12.639388802556157, 11.655144604784082, 10.687369567710661, 9.64301495576296, 8.738565807282184, 7.77631257398303, 6.798942524965418, 5.882416605681786, 4.926726122449088, 3.9802693904805944, 3.0719429190790395, 3.973456610258625, 4.92606590325968, 5.868555319284851, 6.837718478962816, 7.7769657320837915, 7.69339850656584, 8.761100798254448, 9.743163368885503, 10.701663623350194, 11.598942756456514, 10.624837174926114, 9.654382294881803, 8.68068579728243, 7.713263116883506, 6.768806363229045, 5.8434562429953285, 4.948834984988059, 3.9960355172014133, 2.985494024748652, 2.056896214057866, 3.0358611953695895, 3.9027090144879404, 4.942985132376007, 5.8849631649501575, 6.727700701522057, 6.765197340046469, 7.794699874488682, 8.833021810061172, 9.743730815950718, 10.674252119838293, 9.675295640337467, 8.695601363614015, 7.713587416179098, 6.759166215262825, 5.858778302955648, 4.905804003983568, 3.945048072086424, 2.987519244516096, 1.954301021217559, 1.023745894259398, 2.0441393182429652, 2.93968512464893, 3.924181432519937, 4.87065369477482, 5.796139471755272, 5.858551266873547, 6.805424552271682, 7.791456326273606, 8.811546717591701, 9.768913861656312, 8.813789819867567, 7.857488631998021, 6.841013384593027, 5.8153555520520435, 4.827312742268896, 3.896154374467011, 2.8753905612861588, 1.9468213438235642, 1.006372987166371, 0.0, 0.9949607985231622, 1.979492393339712, 2.9441650310956993, 3.9049684820386386, 4.904808849370136, 6.818889680125665, 7.799602671225375, 8.760778703954657, 9.697693883938108, 10.702850126707954, 9.78151466599264, 8.727181453181064, 7.7721577214699495, 6.78601333149463, 5.802986208001903, 4.865654629295561, 3.811484428200112, 2.941654334033048, 2.0546792746570217, 0.992740038052387, 1.930489662275051, 2.921352780076222, 3.922337856980306, 4.964427610654594, 5.854700312236945, 7.846642674800515, 8.818621662000877, 9.792669807241856, 10.630385596105306, 11.66396695822289, 10.690328123371968, 9.73480804118284, 8.740407973864524, 7.781496424705655, 6.771441814345923, 5.731894311137775, 4.774940051212923, 3.970062673306588, 3.002993320290094, 2.017971646239955, 2.9594684545621366, 3.887997515033523, 4.89041112340017, 5.902901964057099, 6.878057060086736], [6.731953745426083, 5.782309232306533, 4.788966896762544, 3.8291747432209724, 2.9779292384394958, 3.957325635226196, 4.971607538148034, 5.966643967915841, 6.75630692710796, 7.725451991323887, 8.713017828261137, 9.739493418547289, 10.703436091187683, 11.693428989829785, 12.596622259843029, 11.625586432586367, 10.587085498175767, 9.839949202721979, 8.791401962110106, 7.771765491716337, 7.703429211339948, 6.758345116986689, 5.8197732077713855, 4.769572822208916, 3.965507974421652, 4.942721187372454, 5.9115007422259715, 6.846726473780663, 7.733226167536244, 8.717605694239136, 9.671710952247917, 10.601343961649182, 11.640067979621907, 12.621344455986659, 13.523587652655765, 12.585506887342689, 11.622546516197456, 10.57756502313995, 9.590945706099848, 8.644019317543828, 8.721150474602643, 7.759000938775502, 6.796332052219774, 5.798466695361881, 4.974611735710173, 5.931059633871759, 6.935102413713722, 7.895948951354142, 8.70865047769615, 9.650781268784039, 10.646886805000234, 11.5388434075785, 12.596279385806627, 13.544863381879335, 14.517863271746101, 13.636482511970899, 12.597436006757874, 11.547004078283035, 10.5829892035666, 9.581785868355517, 9.733413303243267, 8.69500515054529, 7.710788483726241, 6.7609773193541685, 5.927561631774841, 6.9548310599577, 7.892538990300598, 8.891623789820372, 9.689980200973103, 10.604347619641631, 11.650221630523527, 12.551207112056941, 13.514838160720332, 14.559946729505846, 14.689338081499768, 13.623963086382975, 13.441813731455431, 12.503684109465881, 11.506147780250549, 10.568639940515357, 10.66035796343121, 9.628673764137215, 8.660831190082888, 7.799850491335674, 6.987194334389305, 7.9208422630978585, 8.902591663503584, 9.845327577126405, 10.711624651915384, 11.638341957946874, 12.591449108724614, 13.481298866544735, 14.4742669209224, 14.650901634419887, 13.619209206825426, 12.66237885087789, 13.495496615432858, 13.465149330216335, 12.500584634742061, 11.559993481461674, 11.583389265686119, 10.628183264189389, 9.707529519025265, 8.79886386167936, 8.058296218176158, 8.854434573920761, 9.894694400769719, 10.770576217911652, 11.721843320817493, 12.616009282368873, 13.550599271226668, 14.503342442597663, 14.580991315879956, 13.6095801151658, 12.666156694075756, 11.703757422040663, 12.53976807895652, 13.454700824259833, 13.43514334726607, 12.514017376397037, 12.576591353809482, 11.641923803061559, 10.739792113877353, 9.78806729066805, 9.050239320471492, 9.905233469520761, 10.901041204584503, 11.716670164627962, 12.67482622900265, 13.551789309330317, 14.499266628448368, 14.51241620858124, 13.581935670150774, 12.615837279851007, 11.608020499551357, 10.711657612497698, 11.606934049439275, 12.52008096061327, 13.485541595046865, 13.503059664315412, 13.543797667107624, 12.652985723699876, 11.73094311419668, 10.812160388220569, 10.105905949454348, 10.890696145362767, 11.854608545409247, 12.663178947068062, 13.616642119230914, 14.56843695517738, 14.535655452152424, 13.579976982905436, 12.649841334288787, 11.622045731406685, 10.63777065701455, 9.695677141718196, 10.643001731616856, 11.57485941189538, 12.600114931903747, 13.591371243647195, 13.60237211602891, 13.66268251541038, 12.683897501313627, 11.879315385600913, 11.137293782821246, 11.87273920806241, 12.859242800604756, 13.731859178308646, 14.691615428919208, 14.525752569566025, 13.581950174508188, 12.628809494028534, 11.707176695301394, 10.649859178398726, 9.696250455408947, 8.758511050090164, 9.763159575177685, 10.70659031532173, 11.70858243961731, 12.689165371792646, 12.595880071318799, 13.538854022692686, 13.71901673649197, 12.848515393095639, 12.187964062422825, 12.884535308408665, 13.792456348523512, 14.675031544833768, 14.491045649785827, 13.555650137541893, 12.60233254527414, 11.62739351127256, 10.69384047077169, 9.765313346267883, 8.745879052486218, 7.772579671905803, 8.815791128326829, 9.805743099109558, 10.76066001625268, 11.623701207202652, 11.629248646122363, 12.499204617402553, 13.39687625189711, 13.846718157446233, 13.131925057916224, 13.840473936753412, 14.730273552237751, 14.671221628450848, 13.656996439305845, 12.680168015859204, 11.653026087309525, 10.597031853177286, 9.665883855071023, 8.718914469295639, 7.793714025892173, 6.812876081183568, 7.796646177619666, 8.735128645602499, 9.732795758976751, 10.612052991810833, 10.674675551770903, 11.52970923058606, 12.458968920272476, 13.41865169356763, 14.174166427974548, 14.912251849824163, 14.698451811542434, 13.691032646339695, 12.627025607937233, 11.812288049907488, 10.815993833583509, 9.881472020622427, 8.812418974297021, 7.829150211990004, 6.819329856670851, 5.840102241984393, 6.798400702859013, 7.782948115092827, 8.806528886496839, 9.679590780230578, 9.667474761612187, 10.59388828790241, 11.523502110622088, 12.51923364504187, 13.470837421755045, 14.465573416031265, 13.690095522171799, 12.656364731347205, 11.61921167309432, 10.777185524062972, 9.807940874582275, 8.839454051292181, 7.837490363628777, 6.830023612260127, 5.836398749363973, 4.896603702011004, 5.842716679022498, 6.812963262369252, 7.7779493289854775, 8.69330228881804, 8.669635462847758, 9.630865212408372, 10.604570800383451, 11.546310261823088, 12.535641738317988, 13.600051053679412, 12.640521885396417, 11.647539177027198, 10.666512210146552, 9.70637589212769, 8.765742092037273, 7.7918210647138775, 6.8444196397365165, 5.881594422788876, 4.897600752966776, 3.9590769126511445, 4.910791351818168, 5.8562448790693304, 6.812013293895241, 7.754706884825087, 7.7237861953004865, 8.681819575840413, 9.677367867072345, 10.63247280379188, 11.692265205949289, 12.650105403307244, 11.682330366233822, 10.63797575428612, 9.733526605805345, 8.771273372506192, 7.793903323488581, 6.877377404204949, 5.921686920972251, 4.975230189003757, 3.9457483651297625, 2.978495811735463, 3.931105104736517, 4.873594520761688, 5.842757680439654, 6.7820049335606285, 6.698437708042678, 7.766139999731286, 8.748202570362341, 9.706702824827032, 10.757680492982166, 11.619797973449275, 10.649343093404964, 9.675646595805592, 8.708223915406668, 7.763767161752208, 6.8384170415184915, 5.943795783511221, 4.990996315724576, 3.9804548232718147, 3.0518570125810283, 2.0409003968464274, 2.907748215964778, 3.9480243338528442, 4.890002366426995, 5.732739902998895, 5.770236541523307, 6.79973907596552, 7.838061011538009, 8.748770017427555, 9.748528426889, 10.670256438860628, 9.690562162137176, 8.70854821470226, 7.754127013785987, 6.85373910147881, 5.90076480250673, 4.940008870609586, 3.982480043039258, 2.9492618197407214, 2.01870669278256, 1.0491785197198031, 1.9447243261257678, 2.929220633996774, 3.8756928962516577, 4.80117867323211, 4.8635904683503846, 5.81046375374852, 6.7964955277504435, 7.816585919068539, 8.88332073728358, 9.808750618390729, 8.852449430521183, 7.835974183116189, 6.810316350575206, 5.822273540792058, 4.8911151729901725, 3.870351359809321, 2.9417821423467263, 2.0013337856895332, 0.9949607985231622, 0.0, 0.9845315948165496, 1.9492042325725367, 2.9100076835154765, 3.9098480508469735, 5.823928881602502, 6.804641872702213, 7.765817905431494, 8.702733085414945, 9.777006008561417, 10.776475464515801, 9.722142251704225, 8.767118519993112, 7.780974130017791, 6.797947006525065, 5.860615427818723, 4.806445226723274, 3.93661513255621, 3.0349912477545105, 1.9730520111498755, 0.9355288637518888, 1.92639198155306, 2.927377058457143, 3.9694668121314316, 4.859739513713782, 6.851681876277352, 7.823660863477716, 8.797709008718694, 9.635424797582143, 10.669006159699727, 11.685288921895129, 10.729768839706, 9.735368772387687, 8.776457223228817, 7.766402612869086, 6.726855109660938, 5.769900849736086, 4.96502347182975, 3.9833052933875823, 2.9982836193374434, 1.9645076560389747, 2.8930367165103608, 3.895450324877008, 4.907941165533937, 5.883096261563573], [5.7678037174602625, 4.818159204340712, 3.824816868796723, 2.8650247152551516, 3.9184914188691256, 4.923189733957976, 5.937471636879814, 6.9511755627323915, 7.740838521924508, 8.709983586140435, 9.697549423077685, 10.724025013363837, 11.687967686004232, 12.568690195881057, 11.61209066502648, 10.641054837769818, 9.602553903359217, 8.875799174756159, 7.827251934144286, 6.807615463750517, 6.739279183374128, 5.794195089020868, 4.855623179805565, 3.8054227942430954, 4.740576198968395, 5.717789411919197, 6.77881530056727, 7.714041032121962, 8.700788038754423, 9.702137289055685, 10.656242547064465, 11.58587555646573, 12.624599574438456, 13.520627476350661, 12.539056057839217, 11.621356859376867, 10.658396488231634, 9.613414995174129, 8.626795678134028, 7.679869289578009, 7.757000446636823, 6.794850910809681, 5.832182024253953, 4.8343166673960605, 5.749679960256916, 6.706127858418502, 7.755341571936518, 8.76326350969544, 9.676212348914328, 10.629041295472396, 11.631418399816782, 12.52337500239505, 13.580810980623175, 14.529394976695883, 13.558287015086455, 12.672332484005077, 11.633285978792054, 10.582854050317215, 9.61883917560078, 8.617635840389699, 8.769263275277446, 7.730855122579468, 6.74663845576042, 5.796827291388348, 6.702629856321584, 7.729899284504443, 8.712778148523395, 9.71186294804317, 10.657542072191282, 11.582607646329988, 12.628481657211884, 13.53573870687349, 14.49936975553688, 15.544478324322395, 14.502593176598841, 13.547155172419407, 12.477663703489613, 11.539534081500063, 10.54199775228473, 9.604489912549539, 9.696207935465388, 8.664523736171393, 7.696681162117067, 6.835700463369853, 7.762262558936048, 8.695910487644602, 9.684962132919622, 10.627698046542443, 11.610129532441722, 12.616601984635231, 13.569709135412971, 14.465830461361284, 15.458798515738948, 15.566779451323935, 14.535087023729474, 13.578256667781938, 12.872823737795775, 12.500999302250516, 11.536434606776243, 10.595843453495856, 10.619239237720297, 9.664033236223567, 8.743379491059443, 7.834713833713539, 8.833364442722901, 9.629502798467504, 10.669762625316462, 11.55294668732769, 12.525859547763245, 13.51151140138325, 14.446101390241045, 15.472547468062974, 15.496869132784004, 14.525457932069848, 13.582034510979804, 12.619635238944712, 11.917095201319437, 12.735670131425046, 12.470993319300252, 11.549867348431215, 11.61244132584366, 10.677773775095737, 9.775642085911532, 8.82391726270223, 9.800189514556301, 10.680301694067504, 11.676109429131246, 12.499040634044, 13.457196698418688, 14.447291428344695, 15.394768747462745, 15.42829402548529, 14.497813487054824, 13.531715096755056, 12.523898316455405, 11.627535429401746, 10.984261171802192, 11.801050267778484, 12.766510902212076, 12.53890963634959, 12.579647639141802, 11.688835695734054, 10.766793086230859, 9.848010360254749, 10.855856143539157, 11.66576436990951, 12.62967676995599, 13.4455494164841, 14.399012588646952, 15.366215058189493, 15.451533269056474, 14.495854799809486, 13.565719151192837, 12.537923548310733, 11.553648473918598, 10.611554958622245, 10.020328853979773, 10.855828719060593, 11.846120929338873, 12.665185989056793, 12.617840521212358, 12.698532487444558, 11.719747473347805, 10.915165357635093, 11.887243976906054, 12.647807432609152, 13.634311025151499, 14.514229647724685, 15.473985898335247, 15.441630386470075, 14.497827991412239, 13.544687310932584, 12.623054512205444, 11.565736995302775, 10.612128272312995, 9.674388866994212, 9.017712804384466, 9.853604667265262, 10.804749766109774, 11.704633776976095, 11.611348476502247, 12.554322427876134, 12.754866708526148, 11.88436536512982, 12.867756451285853, 13.659603532955408, 14.567524573070255, 15.457402014249805, 15.406923466689877, 14.471527954445943, 13.51821036217819, 12.54327132817661, 11.60971828767574, 10.681191163171933, 9.661756869390269, 8.688457488809853, 7.961510099503845, 8.901910425602022, 9.856827342745145, 10.639169612386102, 10.644717051305811, 11.514673022586003, 12.41234465708056, 12.882568129480415, 13.811717446779252, 14.615542161300155, 15.505341776784494, 15.609793831044263, 14.572874256209895, 13.596045832763254, 12.568903904213576, 11.512909670081337, 10.581761671975073, 9.634792286199689, 8.709591842796224, 7.728753898087618, 6.94236514879668, 7.8312959720949635, 8.828963085469216, 9.627521396994283, 9.690143956954351, 10.545177635769509, 11.474437325455925, 12.43412009875108, 13.367392359699494, 14.354946263426697, 15.324356389333815, 14.675564241156243, 13.611557202753781, 12.757970653674201, 11.761676437350221, 10.797349837526477, 9.728296791201073, 8.745028028894055, 7.735207673574902, 6.7559800588884436, 5.944119674036028, 6.8304877754119095, 7.854068546815921, 8.695059185414028, 8.682943166795637, 9.609356693085859, 10.538970515805538, 11.53470205022532, 12.486305826938494, 13.481041821214715, 14.454695674903729, 13.640896326163753, 12.603743267910868, 11.761717118879522, 10.753623478348988, 9.755331868196231, 8.753368180532828, 7.745901429164177, 6.752276566268023, 5.812481518915054, 4.892398948509453, 5.860163397120653, 6.825149463736878, 7.70877069400149, 7.6851038680312085, 8.646333617591822, 9.6200392055669, 10.561778667006537, 11.551110143501438, 12.615519458862863, 13.62505348021297, 12.632070771843749, 11.651043804963102, 10.69090748694424, 9.717255990388395, 8.707698881617928, 7.760297456640567, 6.797472239692926, 5.813478569870826, 4.874954729555195, 3.9262597570016187, 4.871713284252781, 5.827481699078691, 6.770175290008536, 6.739254600483937, 7.697287981023863, 8.692836272255795, 9.647941208975329, 10.707733611132738, 11.71365968243878, 12.666861961050373, 11.622507349102671, 10.718058200621895, 9.755804967322742, 8.77843491830513, 7.861908999021497, 6.906218515788799, 5.911608563274889, 4.861626182033813, 3.894373628639513, 2.9465735099199675, 3.8890629259451384, 4.858226085623103, 5.79747333874408, 5.713906113226129, 6.781608404914737, 7.763670975545792, 8.722171230010481, 9.773148898165616, 10.712494846161922, 11.633874688221516, 10.660178190622142, 9.692755510223218, 8.748298756568758, 7.822948636335042, 6.928327378327771, 5.975527910541126, 4.9649864180883645, 3.9995049158441764, 2.9567782137504777, 1.9232166211482284, 2.963492739036295, 3.905470771610445, 4.748208308182345, 4.785704946706757, 5.8152074811489705, 6.85352941672146, 7.764238422611005, 8.763996832072449, 9.762953311573275, 10.675093756953729, 9.693079809518812, 8.738658608602538, 7.8382706962953606, 6.88529639732328, 5.924540465426136, 4.9670116378558085, 3.9337934145572713, 3.00323828759911, 1.9650563366238534, 0.9601927313092182, 1.9446890391802247, 2.891161301435108, 3.816647078415561, 3.8790588735338343, 4.82593215893197, 5.811963932933893, 6.832054324251989, 7.898789142467028, 8.853913184255774, 9.81021437212532, 8.82050577793274, 7.794847945391756, 6.806805135608609, 5.875646767806723, 4.854882954625871, 3.926313737163276, 2.985865380506083, 1.979492393339712, 0.9845315948165496, 0.0, 0.9646726377559871, 1.9254760886989266, 2.9253164560304237, 4.839397286785952, 5.820110277885663, 6.781286310614944, 7.718201490598394, 8.792474413744866, 9.86524815477819, 10.706673846520776, 9.751650114809662, 8.765505724834341, 7.782478601341614, 6.845147022635272, 5.790976821539823, 4.9211467273727605, 4.01952284257106, 2.957583605966425, 1.9200604585684384, 0.9622419535872394, 1.9428454636405936, 2.984935217314882, 3.875207918897232, 5.867150281460803, 6.839129268661166, 7.813177413902143, 8.650893202765593, 9.684474564883176, 10.711110688810413, 11.666630770999541, 10.719900367204236, 9.760988818045368, 8.750934207685635, 7.711386704477486, 6.754432444552634, 5.9495550666463, 4.967836888204133, 3.982815214153993, 2.921907204092304, 1.92888668854454, 2.931300296911187, 3.943791137568116, 4.898564666747023], [4.919764953349447, 3.9701204402298966, 2.997010804542161, 3.8296973530111384, 4.883164056625112, 5.887862371713963, 6.902144274635801, 7.915848200488378, 8.705511159680494, 9.67465622389642, 10.66222206083367, 11.688697651119822, 12.59401045676717, 11.604017558125069, 10.647418027270492, 9.67638220001383, 8.637881265603228, 7.9136322349145285, 6.927844957099532, 5.908208486705764, 5.891240419263312, 4.946156324910053, 4.027817115551002, 4.770095431999082, 5.705248836724382, 6.682462049675184, 7.743487938323257, 8.678713669877949, 9.66546067651041, 10.66680992681167, 11.62091518482045, 12.550548194221715, 13.537231314959424, 12.555954838594673, 11.574383420083228, 10.67295523541443, 9.709994864269197, 8.765376231063314, 7.778756914023212, 6.8318305254671925, 6.908961682526007, 5.946812146698866, 5.062648578242932, 5.798989305152047, 6.714352598012903, 7.670800496174489, 8.720014209692506, 9.727936147451427, 10.640884986670315, 11.593713933228383, 12.596091037572767, 13.488047640151034, 14.51519826326994, 13.566614267197233, 12.593614377330466, 11.723930860042639, 10.69194028187894, 9.734815286206398, 8.770800411489963, 7.769597076278883, 7.941955529148424, 6.908221221538013, 6.111773740707251, 6.7614999291443345, 7.667302494077571, 8.69457192226043, 9.677450786279383, 10.676535585799158, 11.622214709947269, 12.547280284085975, 13.59315429496787, 14.500411344629475, 15.464042393292866, 14.586034659812979, 13.537920538842853, 12.69911640830859, 11.629624939378797, 10.691495317389247, 9.693958988173915, 8.756451148438723, 8.886978829413929, 7.946396153797101, 7.061816447063898, 7.80037310112584, 8.726935196692036, 9.660583125400589, 10.64963477067561, 11.59237068429843, 12.574802170197708, 13.581274622391218, 14.534381773168958, 15.430503099117269, 16.423471153494933, 15.512642997571518, 14.608049413517195, 13.660700643813676, 12.609838360549784, 11.6529605381397, 10.688395842665427, 9.74780468938504, 9.834021370014419, 8.945905653849275, 8.108514776006274, 8.799386471469525, 9.79803708047889, 10.594175436223491, 11.634435263072449, 12.517619325083677, 13.490532185519232, 14.476184039139238, 15.410774027997032, 16.437220105818962, 16.46154177053999, 15.490130569825835, 14.546707148735791, 13.584307876700699, 12.865605131294492, 11.916822516040757, 11.622954555189436, 10.722598088886256, 10.827223458137782, 9.959646192721445, 9.140777370858363, 9.788589900458216, 10.76486215231229, 11.64497433182349, 12.640782066887233, 13.463713271799987, 14.421869336174675, 15.411964066100682, 16.35944138521873, 16.392966663241275, 15.462486124810809, 14.496387734511043, 13.488570954211392, 12.592208067157733, 11.932771101777247, 10.982202652394195, 11.92298384893626, 11.711640376804631, 11.794429771435924, 10.970708113359763, 10.13192837117769, 10.812682998010736, 11.820528781295145, 12.630437007665497, 13.594349407711977, 14.410222054240087, 15.36368522640294, 16.33088769594548, 16.41620590681246, 15.460527437565473, 14.530391788948823, 13.50259618606672, 12.518321111674585, 11.576227596378232, 10.968838783954828, 10.036981103676304, 10.983264683890486, 11.700513351300806, 11.653167883456373, 12.043642082281348, 11.084882758294636, 11.87983799539108, 12.851916614662043, 13.61248007036514, 14.598983662907486, 15.478902285480672, 16.438658536091232, 16.406303024226062, 15.462500629168225, 14.509359948688571, 13.587727149961431, 12.530409633058762, 11.576800910068982, 10.639061504750199, 9.978187792025018, 9.034757051880975, 9.941893520661386, 10.739961139220108, 10.646675838746262, 11.589649790120149, 12.120001993472979, 12.849038002885806, 13.832429089041838, 14.624276170711395, 15.532197210826242, 16.422074652005794, 16.371596104445864, 15.43620059220193, 14.482882999934176, 13.507943965932597, 12.574390925431727, 11.64586380092792, 10.626429507146256, 9.65313012656584, 8.926182737259833, 8.083062810217735, 8.993971097296757, 9.674496974630115, 9.680044413549826, 10.550000384830017, 11.447672019324575, 12.455458465796617, 13.397356945569852, 14.462051538741463, 15.380196000311235, 16.397285625807264, 15.537546893965882, 14.560718470519241, 13.533576541969563, 12.477582307837324, 11.54643430973106, 10.599464923955676, 9.67426448055221, 8.693426535843605, 7.907037786552667, 7.012448356710676, 7.9642011599524904, 8.662848759238296, 8.725471319198366, 9.580504998013524, 10.50976468769994, 11.469447460995095, 12.402719721943509, 13.390273625670712, 14.35968375157783, 15.417096643696112, 14.57622984050977, 13.722643291430186, 12.726349075106206, 11.762022475282464, 10.69296942895706, 9.709700666650042, 8.69988031133089, 7.720652696644431, 6.9087923117920145, 6.011640160027622, 6.939247236132891, 7.730386547658041, 7.71827052903965, 8.644684055329874, 9.574297878049553, 10.570029412469333, 11.521633189182507, 12.516369183458728, 13.490023037147742, 14.531471320656793, 13.568415905666857, 12.726389756635509, 11.718296116104975, 10.720004505952218, 9.718040818288815, 8.710574066920165, 7.71694920402401, 6.777154156671042, 5.85707158626544, 5.041315781736365, 5.870509841776327, 6.7440980562455035, 6.720431230275222, 7.6816609798358355, 8.655366567810914, 9.59710602925055, 10.586437505745451, 11.650846821106875, 12.686893610637567, 13.596743409599735, 12.615716442719089, 11.655580124700228, 10.681928628144384, 9.672371519373915, 8.724970094396554, 7.762144877448913, 6.778151207626813, 5.8396273673111825, 4.8909323947576056, 4.052865668868494, 4.862809061322704, 5.8055026522525495, 5.77458196272795, 6.732615343267876, 7.728163634499808, 8.683268571219342, 9.743060973376751, 10.748987044682794, 11.786009630649698, 12.587179986858658, 11.682730838377882, 10.72047760507873, 9.743107556061117, 8.826581636777487, 7.870891153544788, 6.876281201030876, 5.8262988197898, 4.8590462663955005, 3.9112461476759544, 3.0702153105608514, 3.8935534478671165, 4.832800700988093, 4.749233475470142, 5.81693576715875, 6.798998337789805, 7.757498592254494, 8.808476260409629, 9.747822208405934, 10.736755881808525, 11.624850828378129, 10.657428147979205, 9.712971394324745, 8.787621274091029, 7.893000016083758, 6.940200548297113, 5.929659055844352, 4.964177553600164, 3.9214508515064654, 2.8878892589042153, 1.9988201012803075, 2.940798133854458, 3.7835356704263585, 3.8210323089507705, 4.850534843392984, 5.888856778965473, 6.799565784855018, 7.799324194316461, 8.798280673817287, 9.777974950540738, 10.657752447274799, 9.703331246358525, 8.802943334051347, 7.849969035079267, 6.889213103182123, 5.931684275611795, 4.898466052313259, 3.967910925355097, 2.9297289743798407, 1.9248653690652053, 0.9800164014242376, 1.926488663679121, 2.851974440659574, 2.9143862357778474, 3.861259521175983, 4.847291295177906, 5.867381686496002, 6.934116504711041, 7.889240546499786, 8.845541734369332, 9.785178415688728, 8.759520583147744, 7.771477773364595, 6.84031940556271, 5.819555592381858, 4.8909863749192635, 3.95053801826207, 2.944165031095699, 1.9492042325725367, 0.9646726377559871, 0.0, 0.9608034509429395, 1.9606438182744366, 3.8747246490299645, 4.855437640129676, 5.816613672858957, 6.753528852842408, 7.82780177598888, 8.900575517022205, 9.79808471828876, 10.716322752565649, 9.730178362590328, 8.747151239097601, 7.809819660391259, 6.75564945929581, 5.885819365128747, 4.984195480327047, 3.922256243722412, 2.8847330963244255, 1.9269145913432264, 0.9781728258846065, 2.020262579558895, 2.910535281141245, 4.902477643704815, 5.874456630905179, 6.848504776146156, 7.686220565009605, 8.719801927127188, 9.746438051054424, 10.701958133243552, 11.684573004960225, 10.725661455801355, 9.71560684544162, 8.676059342233472, 7.719105082308621, 6.914227704402287, 5.932509525960119, 4.94748785190998, 3.886579841848291, 2.893559326300527, 2.0114506807161128, 3.0239415213730414, 3.9338920289910355], [4.031883803969653, 3.0822392908501026, 3.9578142554851, 4.790500803954078, 5.843967507568053, 6.848665822656903, 7.862947725578741, 8.876651651431317, 9.666314610623434, 10.63545967483936, 11.62302551177661, 12.597149678464625, 11.63320700582423, 10.643214107182128, 9.686614576327552, 8.71557874907089, 7.677077814660288, 6.952828783971588, 5.967041506156593, 4.9474050357628245, 5.003359269883518, 4.058275175530259, 4.988620566493942, 5.7308988829420215, 6.666052287667322, 7.643265500618123, 8.704291389266197, 9.639517120820889, 10.62626412745335, 11.62761337775461, 12.58171863576339, 13.511351645164655, 12.576427864016484, 11.595151387651732, 10.613579969140288, 9.712151784471489, 8.749191413326256, 7.809645045151829, 6.823025728111728, 5.876099339555708, 6.021080533146213, 5.058930997319072, 6.023452029185871, 6.759792756094987, 7.675156048955842, 8.631603947117428, 9.680817660635444, 10.688739598394367, 11.601688437613255, 12.554517384171323, 13.556894488515708, 14.448851091093974, 13.554394812327, 12.605810816254293, 11.632810926387526, 10.763127409099699, 9.731136830936, 8.779084100294915, 7.81506922557848, 6.813865890367398, 7.05407437976863, 6.020340072158219, 7.004556738977267, 7.722303380087274, 8.628105945020511, 9.65537537320337, 10.63825423722232, 11.637339036742095, 12.583018160890209, 13.508083735028915, 14.553957745910811, 15.461214795572415, 14.521299611979906, 13.625231208870039, 12.577117087899913, 11.743385222397105, 10.673893753467311, 9.735764131477762, 8.73822780226243, 7.800719962527237, 7.999097680034135, 7.058515004417307, 7.954599445333914, 8.761176552068779, 9.687738647634976, 10.621386576343529, 11.61043822161855, 12.55317413524137, 13.535605621140649, 14.542078073334158, 15.495185224111898, 16.391306550060207, 15.497272231456748, 14.551839546628578, 13.647245962574255, 12.704969457902191, 11.654107174638298, 10.697229352228215, 9.732664656753942, 8.792073503473555, 8.946140220634625, 8.058024504469481, 9.001297774276289, 9.760189922412465, 10.75884053142183, 11.554978887166431, 12.59523871401539, 13.478422776026617, 14.451335636462172, 15.436987490082178, 16.371577478939972, 17.398023556761903, 16.498631865497188, 15.593161065882665, 14.631796847857283, 13.58460965391014, 12.609835711114636, 11.603788579775353, 10.66722336927795, 9.76686690297477, 9.939342308757988, 9.071765043341651, 10.033560369128377, 10.749393351401157, 11.72566560325523, 12.605777782766431, 13.601585517830173, 14.424516722742927, 15.382672787117615, 16.372767517043624, 17.32024483616167, 17.35377011418422, 16.423289575753753, 15.457191185453985, 14.449374405154334, 13.553011518100675, 12.766147777490497, 11.815579328107445, 10.96218039799332, 10.755909190893146, 10.90654862205613, 10.082826963979969, 11.024711369447704, 11.773486448953676, 12.781332232238086, 13.591240458608437, 14.555152858654917, 15.371025505183027, 16.32448867734588, 17.29169114688842, 17.3770093577554, 16.421330888508415, 15.491195239891766, 14.463399637009662, 13.479124562617526, 12.537031047321173, 11.802215459668078, 10.870357779389554, 10.022461232947546, 10.739709900357866, 10.692364432513433, 11.155760932901554, 11.977665756564651, 12.84064144633402, 13.812720065604983, 14.57328352130808, 15.559787113850426, 16.439705736423612, 17.399461987034172, 17.367106475169003, 16.42330408011117, 15.470163399631513, 14.548530600904373, 13.491213084001703, 12.537604361011924, 11.59986495569314, 10.811564467738268, 9.868133727594223, 8.981090069718446, 9.779157688277168, 9.68587238780332, 10.628846339177207, 11.544551540630664, 12.492857779204272, 13.380514490120309, 14.376700747065328, 15.357209753082534, 16.29261596130938, 17.26241765322268, 16.39700404314487, 15.443686450877118, 14.468747416875539, 13.535194376374669, 12.606667251870862, 11.587232958089198, 10.613933577508782, 9.803452451113923, 8.916439485930983, 8.033167646353817, 8.713693523687175, 8.719240962606884, 9.589196933887077, 10.486868568381635, 11.494655014853677, 12.436553494626912, 13.501248087798523, 14.419392549368295, 15.436482174864326, 16.47340174969869, 15.521521921462183, 14.494379992912505, 13.438385758780266, 12.507237760674002, 11.560268374898618, 10.635067931495152, 9.654229986786547, 8.784307500406758, 7.8458250324239245, 7.003397709009551, 7.7020453082953555, 7.764667868255425, 8.619701547070584, 9.548961236757, 10.508644010052155, 11.441916271000569, 12.429470174727772, 13.39888030063489, 14.456293192753172, 15.520300231155634, 14.683446742373127, 13.687152526049147, 12.722825926225404, 11.6537728799, 10.670504117592982, 9.66068376227383, 8.681456147587372, 7.829564247974684, 6.84501683574087, 5.978443785189952, 6.769583096715101, 6.75746707809671, 7.683880604386934, 8.613494427106613, 9.609225961526393, 10.560829738239567, 11.555565732515788, 12.529219586204801, 13.570667869713853, 14.529219356609794, 13.687193207578447, 12.679099567047915, 11.680807956895158, 10.678844269231755, 9.671377517863105, 8.67775265496695, 7.737957607613982, 6.807412012410088, 5.874692457449613, 4.909706390833388, 5.783294605302563, 5.759627779332282, 6.720857528892896, 7.694563116867974, 8.63630257830761, 9.62563405480251, 10.690043370163934, 11.726090159694627, 12.719072868063847, 13.576519893662027, 12.616383575643166, 11.642732079087324, 10.633174970316855, 9.685773545339494, 8.722948328391853, 7.738954658569753, 6.800430818254123, 5.841272820902254, 4.9017475161030735, 3.902005610379764, 4.844699201309609, 4.813778511785011, 5.771811892324937, 6.767360183556868, 7.722465120276401, 8.78225752243381, 9.788183593739852, 10.82520617970676, 11.720902958767809, 12.64353428932082, 11.681281056021668, 10.703911007004056, 9.787385087720425, 8.831694604487726, 7.837084651973816, 6.78710227073274, 5.819849717338441, 4.8615865738206026, 3.919097157795431, 2.9327499969241773, 3.871997250045153, 3.7884300245272025, 4.8561323162158105, 5.838194886846866, 6.796695141311554, 7.8476728094666885, 8.787018757462995, 9.775952430865587, 10.75857380028728, 11.618231598922144, 10.673774845267683, 9.748424725033967, 8.853803467026697, 7.901003999240052, 6.890462506787291, 5.9249810045431035, 4.882254302449405, 3.848692709847155, 2.946594191401614, 1.979994682911519, 2.822732219483419, 2.8602288580078303, 3.8897313924500434, 4.928053328022533, 5.8387623339120776, 6.838520743373521, 7.837477222874347, 8.8171714995978, 9.799185447032716, 10.664134697301463, 9.763746784994288, 8.810772486022206, 7.8500165541250615, 6.892487726554734, 5.859269503256197, 4.9287143762980365, 3.89053242532278, 2.885668820008145, 1.9277904915455437, 0.9656852127361814, 1.8911709897166342, 1.9535827848349077, 2.900456070233043, 3.8864878442349666, 4.906578235553062, 5.973313053768101, 6.928437095556846, 7.884738283426392, 8.901213530831386, 9.720324034090682, 8.732281224307535, 7.801122856505649, 6.780359043324797, 5.851789825862203, 4.911341469205009, 3.9049684820386386, 2.9100076835154765, 1.9254760886989266, 0.9608034509429395, 0.0, 0.9998403673314971, 2.913921198087025, 3.894634189186736, 4.855810221916017, 5.792725401899467, 6.86699832504594, 7.939772066079264, 8.83728126734582, 9.792304999056933, 10.690981813533266, 9.70795469004054, 8.770623111334197, 7.71645291023875, 6.846622816071687, 5.944998931269987, 4.883059694665352, 3.8455365472673653, 2.887718042286166, 1.938976276827546, 1.0668835574477917, 1.9497318301983055, 3.9416741927618757, 4.913653179962239, 5.887701325203216, 6.725417114066665, 7.758998476184248, 8.785634600111484, 9.741154682300612, 10.77241110908055, 11.686464906744293, 10.67641029638456, 9.636862793176412, 8.679908533251561, 7.875031155345226, 6.893312976903059, 5.90829130285292, 4.847383292791231, 3.854362777243467, 2.972254131659052, 2.1360603719932474, 2.9730885780480962], [3.0480001351770856, 3.8975270825425357, 4.890869418086525, 5.790341171285576, 6.84380787489955, 7.8485061899884005, 8.862788092910238, 9.876492018762814, 10.66615497795493, 11.635300042170858, 12.622865879108108, 11.597309311133127, 10.633366638492733, 9.643373739850631, 8.686774208996054, 7.715738381739392, 6.677237447328792, 5.952988416640093, 4.967201138825096, 3.947564668431327, 4.020399783174524, 4.873562967222692, 5.852020174015873, 6.730739250273519, 7.665892654998819, 8.643105867949622, 9.704131756597695, 10.639357488152386, 11.626104494784848, 12.627453745086108, 13.469225216160446, 12.539592206759181, 11.576587496684986, 10.595311020320235, 9.61373960180879, 8.712311417139993, 7.74935104599476, 6.809804677820331, 5.82318536078023, 4.8762589722242105, 5.038121046437219, 5.874218789011505, 6.886851636707803, 7.759633123426484, 8.67499641628734, 9.631444314448927, 10.680658027966944, 11.688579965725864, 12.601528804944753, 13.55435775150282, 14.444401068912763, 13.4770916526885, 12.554554444995503, 11.605970448922795, 10.632970559056028, 9.763287041768203, 8.731296463604505, 7.779243732963417, 6.815228858246982, 5.814025523035901, 6.071114893059636, 6.835627863850652, 7.8198445306697, 8.722143747418771, 9.627946312352009, 10.655215740534869, 11.638094604553821, 12.637179404073596, 13.582858528221706, 14.507924102360413, 15.511164798450526, 14.4850902933118, 13.521459244648408, 12.625390841538541, 11.577276720568415, 10.743544855065608, 9.674053386135814, 8.735923764146264, 7.7383874349309325, 6.80087959519574, 7.0161381933251405, 7.873802796109739, 8.769887237026346, 9.761016919400276, 10.687579014966474, 11.621226943675026, 12.610278588950047, 13.553014502572868, 14.535445988472146, 15.541918440665656, 16.392000515861323, 15.415182047799593, 14.49743186412525, 13.55199917929708, 12.647405595242757, 11.705129090570694, 10.6542668073068, 9.697388984896717, 8.732824289422444, 7.792233136142057, 7.963180733925631, 8.873312296161913, 9.816585565968722, 10.760030289743963, 11.758680898753328, 12.554819254497929, 13.595079081346887, 14.478263143358115, 15.45117600379367, 16.436827857413675, 17.37141784627147, 16.437225623852523, 15.498791498165689, 14.593320698551167, 13.631956480525785, 12.584769286578643, 11.609995343783138, 10.603948212443855, 9.667383001946453, 8.767026535643273, 8.956382822048994, 9.887052835034083, 10.848848160820811, 11.749233718732654, 12.725505970586727, 13.605618150097929, 14.601425885161671, 15.424357090074425, 16.382513154449114, 17.37260788437512, 18.320085203493168, 17.46511932998247, 16.534638791552005, 15.488801125470092, 14.480984345170441, 13.502274686666382, 12.542829373300384, 11.538568076090417, 10.631501317655616, 9.756068823561648, 9.923589135347136, 10.8981147556724, 11.839999161140138, 12.773326816285174, 13.781172599569583, 14.591080825939935, 15.554993225986415, 16.370865872514525, 17.324329044677377, 18.29153151421992, 18.24249374163034, 17.286815272383354, 16.356679623766706, 15.328884020884601, 14.344608946492466, 13.402515431196113, 12.652132461735414, 11.72027478145689, 10.831911157414403, 9.88071470573541, 9.778385647343391, 10.689057794513179, 11.652710177058129, 12.535097187948121, 13.50422417097101, 14.461536248660707, 15.363462702250413, 16.308827729083625, 17.289270022172126, 18.232590859043942, 17.28878846398611, 16.335647783506452, 15.414014984779312, 14.356697467876643, 13.403088744886864, 12.46534933956808, 11.661481469805604, 10.71805072966156, 9.790539994185304, 8.920162493654713, 8.77189360263328, 9.714867554007167, 10.617590941879786, 11.565897180453394, 12.453553891369431, 13.44974014831445, 14.430249154331657, 15.365655362558503, 16.335457054471803, 17.26248842701981, 16.30917083475206, 15.334231800750478, 14.400678760249608, 13.472151635745801, 12.452717341964137, 11.47941796138372, 10.65336945318126, 9.76635648799832, 8.842617570820675, 7.854698329064719, 7.805262177436844, 8.6622363351362, 9.559907969630757, 10.5676944161028, 11.509592895876034, 12.574287489047645, 13.492431950617418, 14.509521576113448, 15.546441150947816, 16.38700630533712, 15.359864376787444, 14.303870142655205, 13.372722144548941, 12.425752758773557, 11.500552315370092, 10.519714370661486, 9.634224502474094, 8.69574203449126, 7.843499499283801, 6.8430501136729, 6.850689083085384, 7.692740948319705, 8.622000638006122, 9.581683411301277, 10.514955672249691, 11.502509575976894, 12.471919701884012, 13.529332594002295, 14.593339632404756, 15.587822636340528, 14.591528420016548, 13.627201820192804, 12.5581487738674, 11.546895940335189, 10.52616814614877, 9.546940531462312, 8.679481250042022, 7.694933837808207, 6.828360787257289, 5.9105879020926455, 5.8434882929266685, 6.756920005636056, 7.686533828355735, 8.6582472229804, 9.609850999693574, 10.604586993969795, 11.578240847658808, 12.61968913116786, 13.637143871042358, 14.601336974250138, 13.583475461015315, 12.585183850862558, 11.583220163199154, 10.575753411830505, 9.58212854893435, 8.603441991488921, 7.657329014477426, 6.72460945951695, 5.759623392900725, 4.924299410680108, 4.832667180581405, 5.793896930142019, 6.767602518117096, 7.685323839761617, 8.674655316256517, 9.739064631617943, 10.775111421148635, 11.73062601417739, 12.684444408094592, 13.530527342314857, 12.547107973054722, 11.537550864284254, 10.590149439306893, 9.627324222359253, 8.643330552537153, 7.704806712221522, 6.691189822969592, 5.751664518170412, 4.7519226124471015, 3.9857040066871536, 3.886817913034133, 4.8448512935740595, 5.840399584805991, 6.722624752944904, 7.782417155102314, 8.788343226408356, 9.825365812375264, 10.721062591436313, 11.751458803753385, 12.678119077763153, 11.703751374335553, 10.716096420035925, 9.760405936803226, 8.741460545941216, 7.69147816470014, 6.72422561130584, 5.71150357588794, 4.7690141598627696, 3.782666998991515, 2.945036651294275, 2.8614694257763245, 3.929171717464932, 4.911234288095987, 5.7968547739800576, 6.847832442135192, 7.787178390131499, 8.776112063534091, 9.758733432955784, 10.726156113354708, 11.670612867009169, 10.748265092365465, 9.853643834358195, 8.90084436657155, 7.890302874118788, 6.924821371874601, 5.882094669780902, 4.848533077178652, 3.8706051466116413, 2.829911684978857, 1.8957716207325408, 1.9322066865990606, 2.947278550788777, 3.9539612215404816, 4.838921966580581, 5.838680376042024, 6.837636855542851, 7.817331132266303, 8.79934507970122, 9.753766280617494, 10.763587152325783, 9.810612853353703, 8.84985692145656, 7.892328093886231, 6.8591098705876945, 5.928554743629533, 4.8903727926542775, 3.885509187339642, 2.8518014467555712, 1.8896961679462092, 0.9642103909657563, 0.9537424175034107, 1.900615702901546, 2.8866474769034696, 3.9067378682215654, 4.973472686436605, 5.928596728225349, 6.8848979160948955, 7.90137316349989, 8.927030996040873, 9.73212159163903, 8.800963223837146, 7.7801994106562935, 6.851630193193699, 5.911181836536506, 4.904808849370135, 3.909848050846973, 2.9253164560304237, 1.9606438182744366, 0.9998403673314971, 0.0, 1.9140808307555282, 2.894793821855239, 3.8559698545845205, 4.792885034567971, 5.8671579577144435, 6.939931698747767, 7.8374409000143235, 8.792464631725437, 9.778609021700758, 10.707795057372037, 9.770463478665695, 8.716293277570246, 7.846463183403183, 6.944839298601484, 5.882900061996849, 4.845376914598862, 3.887558409617663, 2.938816644159043, 1.9847061268539712, 0.9498914628668085, 2.941833825430378, 3.9138128126307423, 4.88786095787172, 5.725576746735168, 6.759158108852752, 7.785794232779988, 8.741314314969117, 9.772570741749053, 10.731482290907923, 11.676250663716058, 10.63670316050791, 9.679748900583057, 8.874871522676724, 7.893153344234556, 6.908131670184417, 5.847223660122728, 4.854203144574964, 3.96383900434261, 2.951348163685681, 1.9732482107165994], [3.0622980401989968, 3.9118249875644473, 4.9051673231084365, 5.864959476650008, 6.918426180263983, 7.923124495352833, 8.937406398274671, 9.991515037234675, 11.031052840974592, 11.789967323641852, 10.802401486704602, 9.77592589641845, 8.811983223778055, 7.821990325135952, 6.8653907942813746, 5.894354967024713, 4.855854032614112, 4.101667548681441, 3.053120308069568, 2.033483837675799, 3.9027682476725625, 4.847852342025822, 5.826309548819004, 6.8053575556379515, 7.740510960363252, 8.717724173314053, 9.778750061962127, 10.713975793516818, 11.70072280014928, 12.601947059454549, 11.647841801445768, 10.718208792044503, 9.755204081970309, 8.773927605605557, 7.792356187094111, 6.890928002425313, 5.92796763128008, 4.895723847064803, 3.909104530024702, 2.9621781414686823, 4.883951330856509, 5.8485081638146355, 6.8611410115109335, 7.834251428790917, 8.749614721651772, 9.706062619813359, 10.755276333331375, 11.763198271090296, 12.676147110309184, 13.535122633999451, 12.623017654198085, 11.655708237973823, 10.733171030280824, 9.784587034208116, 8.811587144341349, 7.941903627053524, 6.909913048889825, 5.865162902207889, 4.901148027491454, 3.8999446922803727, 5.916945177478926, 6.8099172386537825, 7.7941339054728305, 8.743945069844903, 9.70256461771644, 10.7298340458993, 11.712712909918253, 12.711797709438027, 13.657476833586138, 14.488688984857044, 13.689781383735848, 12.66370687859712, 11.700075829933729, 10.804007426823862, 9.755893305853736, 8.82946402431008, 7.759972555380288, 6.821842933390737, 5.824306604175405, 4.886798764440212, 6.816052909414718, 7.8477371087087135, 8.744176611829477, 9.782818241826408, 10.747025108289687, 11.68067303699824, 12.66972468227326, 13.612460595896081, 14.59489208179536, 15.522683323162287, 14.570617101146645, 13.593798633084914, 12.67604844941057, 11.730615764582401, 10.747878615762703, 9.791048259815167, 8.740185976551276, 7.78330815414119, 6.818743458666916, 5.878152305386529, 7.763095450015208, 8.71830145151194, 9.709708465115192, 10.737633666613867, 11.766408878092378, 12.614265347821142, 13.6545251746701, 14.537709236681328, 15.510622097116883, 16.49627395073689, 15.62915900923839, 14.615842209137842, 13.67740808345101, 12.771937283836488, 11.71787564977026, 10.670688455823118, 9.695914513027613, 8.689867381688329, 7.753302171190925, 6.8529457048877465, 8.756297538138572, 9.731883034320362, 10.74197105996728, 11.726837095602558, 12.703109347456632, 13.665064243421142, 14.660871978484884, 15.483803183397638, 16.441959247772328, 17.432053977698335, 16.516819503014474, 15.551038499226946, 14.62055796079648, 13.574720294714567, 12.566903514414916, 11.588193855910857, 10.628748542544859, 9.62448724533489, 8.717420486900089, 7.841987992806121, 9.723503851436714, 10.714171434335471, 11.661782133240605, 12.67346165036609, 13.694218690894067, 14.650526919263148, 15.614439319309628, 16.43031196583774, 17.38377513800059, 18.350977607543133, 17.397534097646115, 16.44185562839913, 15.441341462576368, 14.375259653918453, 13.390984579526318, 12.448891064229965, 11.501566474331305, 10.569708794052781, 9.657139651945863, 8.85033329753805, 9.869738507387154, 10.780410654556942, 11.744063037101892, 12.626450047991884, 13.595577031014773, 14.55288910870447, 15.436624438444849, 16.38198946527806, 17.36243175836656, 18.314116734934306, 18.340523135210013, 17.300796942802986, 16.34113366530824, 15.27740528416656, 14.323796561176781, 13.386057155857998, 12.504182523926612, 11.57193284584811, 10.698510815174963, 9.810885509618748, 8.863246462677044, 9.80622041405093, 10.70894380192355, 11.657250040497157, 12.544906751413194, 13.541093008358214, 14.503410890526093, 15.438817098752939, 16.40861879066624, 17.344014302910175, 18.223251665507586, 17.248312631506007, 16.314759591005135, 15.38623246650133, 14.366798172719665, 13.39349879213925, 12.56745028393679, 11.68043731875385, 10.756698401576202, 9.768779159820248, 7.896615037480607, 8.753589195179963, 9.65126082967452, 10.659047276146563, 11.600945755919797, 12.647449225242081, 13.565593686811853, 14.582683312307884, 15.619602887142252, 16.596431310588894, 17.273945207542972, 16.217950973410733, 15.28680297530447, 14.339833589529086, 13.41463314612562, 12.433795201417015, 11.548305333229624, 10.609822865246791, 9.75758033003933, 8.757130944428429, 6.942041943129147, 7.784093808363468, 8.713353498049885, 9.654845147495713, 10.588117408444127, 11.57567131217133, 12.545081438078448, 13.60249433019673, 14.666501368599192, 15.726569416179721, 16.505609250772075, 15.541282650948332, 14.472229604622928, 13.460976771090717, 12.440248976904298, 11.46102136221784, 10.59356208079755, 9.609014668563736, 8.742441618012817, 7.824668732848173, 5.9348411529704315, 6.848272865679819, 7.777886688399498, 8.723547833293766, 9.67515161000694, 10.669887604283161, 11.643541457972175, 12.684989741481226, 13.701729874418781, 14.673087768824848, 15.497556291770843, 14.499264681618087, 13.497300993954683, 12.489834242586033, 11.496209379689878, 10.51752282224445, 9.571409845232955, 8.638690290272478, 7.673704223656253, 6.838380241435636, 4.924020040625168, 5.885249790185782, 6.858955378160859, 7.750624450074983, 8.739955926569884, 9.804365241931308, 10.840412031462, 11.795212017553812, 12.749030411471013, 13.677807600761072, 14.461188803810252, 13.451631695039783, 12.504230270062422, 11.541405053114781, 10.557411383292681, 9.61888754297705, 8.605270653725121, 7.665745348925941, 6.66600344320263, 5.899784837442682, 3.978170773077896, 4.9362041536178225, 5.931752444849754, 6.78792536325827, 7.84771776541568, 8.853643836721721, 9.889951815751685, 10.785648594812734, 11.816044807129806, 12.742705081139574, 13.616035272589395, 12.630177250791453, 11.674486767558754, 10.655541376696744, 9.605558995455668, 8.638306442061369, 7.625584406643469, 6.683094990618298, 5.696747829747044, 4.859117482049803, 2.9528222858200874, 4.020524577508695, 5.00258714813975, 5.862155384293423, 6.913133052448558, 7.852479000444864, 8.840698066910512, 9.823319436332206, 10.79074211673113, 11.73519887038559, 12.660548990619306, 11.767724665113722, 10.814925197327076, 9.804383704874315, 8.838902202630129, 7.79617550053643, 6.76261390793418, 5.78468597736717, 4.743992515734385, 3.809852451488069, 2.0220674783012047, 3.0371393424909217, 4.043822013242626, 4.904222576893947, 5.90398098635539, 6.902937465856216, 7.881917135642724, 8.863931083077642, 9.818352283993915, 10.856349934810751, 11.724693684109232, 10.763937752212087, 9.806408924641758, 8.773190701343221, 7.842635574385061, 6.804453623409805, 5.79959001809517, 4.7658822775111, 3.8037769987017374, 2.8782912217212844, 1.0436032092055552, 1.9904764946036906, 2.976508268605614, 3.972038478534931, 4.979710808051405, 5.93483484984015, 6.891136037709696, 7.90761128511469, 8.933269117655675, 9.921311927438822, 10.715044054592674, 9.694280241411821, 8.765711023949226, 7.825262667292034, 6.818889680125663, 5.823928881602501, 4.839397286785951, 3.8747246490299645, 2.913921198087025, 1.9140808307555282, 0.0, 1.073410407140559, 2.0345864398698406, 2.971501619853291, 4.045774542999763, 5.118548284033087, 6.172881496844663, 7.127905228555777, 8.114049618531098, 9.097076742023825, 10.034408320730167, 9.280181343400724, 8.237762967250225, 7.16363175773142, 6.101692521126785, 5.064169373728799, 4.073306255927628, 3.041093785550171, 1.9990040318758826, 0.9641893678887198, 1.0277529946748503, 2.0736945155502706, 3.0664775431570397, 3.9041933320204882, 4.937774694138072, 5.964410818065308, 6.919930900254437, 7.951187327034375, 8.910098876193244, 9.982505797874968, 10.978991469607173, 10.05997627441996, 9.01255169476447, 8.020761567209309, 7.03573989315917, 5.973571033278933, 4.980550517731169, 3.9781369093645216, 2.9656460687075925, 1.9875461157385108], [4.110503100942127, 4.985235394705007, 5.978577730248996, 6.938369883790568, 7.991836587404542, 8.996534902493392, 10.01081680541523, 11.064925444375234, 11.783401318176969, 10.716556916501293, 9.728991079564043, 8.702515489277891, 7.738572816637497, 6.748579917995394, 5.791980387140816, 4.820944559884154, 3.782443625473553, 3.0581945947848532, 2.0769912153119963, 3.0706913546518724, 4.897303841594563, 5.842387935947823, 6.820845142741004, 7.878767962778511, 8.813921367503811, 9.791134580454614, 10.852160469102687, 11.787386200657378, 12.54965268150954, 11.52853665231399, 10.57443139430521, 9.644798384903945, 8.68179367482975, 7.700517198464998, 6.718945779953552, 5.817517595284754, 4.854557224139522, 3.996406663874764, 3.009787346834663, 3.9567137353906827, 5.878486924778509, 6.843043757736636, 7.855676605432934, 8.853541962290826, 9.823025128792333, 10.77947302695392, 11.828686740471936, 12.836608678230856, 13.41454117341696, 12.461712226858893, 11.549607247057526, 10.582297830833264, 9.659760623140265, 8.711176627067557, 7.7381767372007895, 6.868493219912965, 5.8365026417492665, 4.9658457190178495, 4.001830844301415, 4.894480286202373, 6.911480771400926, 7.804452832575783, 8.788669499394832, 9.738480663766905, 10.74697795059413, 11.803244453039861, 12.786123317058813, 13.785208116578588, 14.361375644620468, 13.415278577716485, 12.61637097659529, 11.590296471456561, 10.62666542279317, 9.730597019683302, 8.682482898713175, 7.859660326945192, 6.790168858015398, 6.0207151403528805, 5.05377870352684, 5.881334358362212, 7.810588503336717, 8.842272702630712, 9.738712205751478, 10.77735383574841, 11.74156070221169, 12.675208630920242, 13.664260276195263, 14.606996189818084, 15.383020095562749, 14.449272916021728, 13.497206694006085, 12.520388225944355, 11.602638042270012, 10.65720535744184, 9.752611773387518, 8.821244562450277, 7.770382279186385, 6.9821803611033335, 6.073763662403449, 6.872687899308529, 8.757631043937208, 9.712837045433938, 10.70424405903719, 11.732169260535866, 12.760944472014376, 13.608800941743144, 14.649060768592102, 15.53224483060333, 16.393238764464858, 15.426940240443727, 14.555748602097829, 13.542431801997283, 12.60399767631045, 11.698526876695928, 10.748071952405368, 9.700884758458226, 8.726110815662722, 7.944887585424861, 7.008322374927459, 7.847481298809746, 9.75083313206057, 10.72641862824236, 11.736506653889279, 12.721372689524557, 13.69764494137863, 14.659599837343144, 15.655407572406887, 16.478338777319642, 17.376089796518553, 16.362720267405173, 15.504415959319529, 14.579788860578095, 13.649308322147629, 12.604916597349675, 11.597099817050024, 10.618390158545965, 9.658944845179967, 8.879507449071422, 7.972440690636621, 8.83652358672812, 10.718039445358713, 11.08550703770439, 11.845797727924644, 12.632087906630096, 13.565447725639542, 14.473415032661983, 15.367848286499797, 16.359405732973734, 17.363994660914294, 17.379367913252235, 16.5188447863172, 15.56316631707021, 14.562652151247448, 13.496570342589534, 12.512295268197398, 11.570201752901045, 10.622877163002386, 9.824728997789313, 8.912159855682397, 9.844868891460049, 10.767186702533426, 10.012573068782805, 10.892843340807698, 11.564932909249752, 12.534059892272644, 13.49137196996234, 14.363214031304288, 15.3085790581375, 16.289021351226, 17.240706327793742, 17.461833823881094, 16.422107631474066, 15.46244435397932, 14.39871597283764, 13.445107249847862, 12.507367844529078, 11.625493212597693, 10.826953049584642, 9.953531018911496, 10.805421103540747, 9.760694657823313, 9.038382828276793, 9.857724105629355, 10.595732901755026, 11.483389612671065, 12.479575869616085, 13.430000483385532, 14.365406691612378, 15.335208383525677, 16.27060389576961, 17.223921488037362, 17.302261149971795, 16.28986784013867, 15.356314995369106, 14.433809245009515, 13.493299222713437, 12.681695917478315, 11.778647291247882, 10.901453442276125, 10.681845264295456, 8.794063232626877, 7.969474445254055, 8.800041133380326, 9.597530137404432, 10.539428617177666, 11.57403881810152, 12.492183279671293, 13.509272905167323, 14.546192480001691, 15.523020903448332, 16.540098899069942, 17.198663964510448, 16.267515966404183, 15.320546580628797, 14.395346137225332, 13.414508192516726, 12.529018324329336, 11.590535856346502, 10.670646434514538, 9.670197048903637, 7.839490138275418, 6.999979058437561, 7.862133801755691, 8.581434740355153, 9.514707001303567, 10.50226090503077, 11.471671030937888, 12.52908392305617, 13.593090961458632, 14.653159009039161, 15.56471537554376, 16.521995642048044, 15.45294259572264, 14.441689762190428, 13.42096196800401, 12.441734353317552, 11.574275071897262, 10.589727659663447, 9.723154609112528, 8.737734837323382, 6.832289348116703, 6.064158115753912, 6.926666992105304, 7.650137426153208, 8.601741202866382, 9.596477197142603, 10.570131050831616, 11.611579334340668, 12.62831946727822, 13.599677361684288, 14.556662416542528, 15.479977672717798, 14.478013985054394, 13.470547233685744, 12.47692237078959, 11.498235813344161, 10.552122836332666, 9.61940328137219, 8.654417214755965, 7.751446345910845, 5.82146823577144, 5.101135040259875, 5.987210048833685, 6.677214042934424, 7.666545519429325, 8.730954834790749, 9.767001624321441, 10.721801610413252, 11.675620004330453, 12.604397193620512, 13.514463633997526, 14.432344686139494, 13.484943261162133, 12.522118044214492, 11.538124374392392, 10.599600534076762, 9.585983644824832, 8.646458340025651, 7.646716434302341, 6.812850941917891, 4.875618968224169, 4.064458824290648, 5.06000711552258, 5.7145149561177115, 6.774307358275121, 7.780233429581163, 8.816541408611124, 9.712238187672174, 10.742634399989246, 11.669294673999014, 12.542624865448834, 13.541900260041839, 12.655199758658465, 11.636254367796456, 10.58627198655538, 9.61901943316108, 8.60629739774318, 7.6638079817180085, 6.677460820846754, 5.839830473149513, 3.8502704809663606, 3.1062918389445784, 4.051312908038649, 4.788744977152865, 5.839722645307999, 6.779068593304306, 7.767287659769953, 8.749909029191645, 9.71733170959057, 10.66178846324503, 11.587138583478746, 12.52334645361853, 11.795638188426787, 10.785096695974026, 9.81961519372984, 8.776888491636141, 7.7433268990338915, 6.76539896846688, 5.724705506834096, 4.79056544258778, 2.919515673447478, 2.040840966840924, 3.0078029222239784, 3.830812169753388, 4.8305705792148315, 5.829527058715658, 6.808506728502166, 7.790520675937082, 8.744941876853355, 9.782939527670191, 10.788709517616706, 11.744650743311798, 10.78712191574147, 9.753903692442933, 8.823348565484771, 7.785166614509516, 6.780303009194881, 5.74659526861081, 4.784489989801448, 3.859004212820995, 1.9410514043518283, 0.994178118953693, 1.9404891775869666, 2.898628071394372, 3.9063004009108466, 4.861424442699591, 5.817725630569138, 6.834200877974132, 7.859858710515115, 8.847901520298263, 9.779059888100148, 10.674993232511532, 9.746424015048937, 8.805975658391745, 7.799602671225374, 6.804641872702212, 5.820110277885663, 4.855437640129676, 3.894634189186736, 2.894793821855239, 1.073410407140559, 0.0, 0.9611760327292814, 1.8980912127127318, 2.9723641358592046, 4.045137876892529, 5.099471089704104, 6.0544948214152186, 7.0406392113905385, 8.023666334883265, 8.960997913589607, 10.015168114685055, 9.311173374390783, 8.237042164871978, 7.175102928267344, 6.137579780869357, 5.146716663068187, 4.114504192690729, 3.072414439016441, 2.0375997750292787, 2.0649605116509235, 1.0190189907755032, 1.9930671360164807, 2.830782924879929, 3.8643642869975126, 4.8910004109247485, 5.846520493113878, 6.877776919893815, 7.836688469052684, 8.909095390734407, 9.905581062466613, 10.862535322391466, 10.08596210190503, 9.09417197434987, 8.10915030029973, 7.046981440419492, 6.053960924871728, 5.05154731650508, 4.0390564758481515, 3.06095652287907], [5.071679133671408, 5.946411427434288, 6.9397537629782775, 7.899545916519849, 8.953012620133823, 9.957710935222673, 10.97199283814451, 11.861763089187603, 10.822225285447686, 9.75538088377201, 8.76781504683476, 7.7413394565486096, 6.777396783908215, 5.787403885266112, 4.830804354411534, 3.859768527154872, 2.8212675927442716, 2.0970185620555717, 3.0381672480412774, 4.031867387381154, 5.858479874323844, 6.8035639686771034, 7.782021175470285, 8.839943995507793, 9.775097400233093, 10.752310613183896, 11.81333650183197, 12.575223655412719, 11.588476648780258, 10.567360619584708, 9.613255361575927, 8.683622352174662, 7.720617642100469, 6.739341165735716, 5.757769747224271, 4.856341562555473, 3.8933811914102403, 3.040765352880886, 3.970963379563944, 4.917889768119964, 6.839662957507791, 7.8042197904659165, 8.816852638162214, 9.814717995020107, 10.784201161521615, 11.740649059683202, 12.789862773201218, 13.423191456326249, 12.453365140687678, 11.50053619412961, 10.588431214328244, 9.621121798103982, 8.698584590410983, 7.750000594338275, 6.777000704471508, 5.907317187183683, 4.875326609019985, 4.011043623455901, 4.963006877030695, 5.855656318931654, 7.872656804130208, 8.765628865305064, 9.749845532124112, 10.699656696496186, 11.708153983323411, 12.764420485769143, 13.747299349788094, 14.356371803184754, 13.400199611891185, 12.454102544987203, 11.655194943866007, 10.629120438727279, 9.665489390063888, 8.769420986954021, 7.721306865983894, 6.89848429421591, 5.828992825286116, 5.065913044790932, 6.01495473625612, 6.842510391091493, 8.771764536066, 9.803448735359996, 10.699888238480758, 11.738529868477691, 12.70273673494097, 13.636384663649523, 14.625436308924543, 15.387026692940028, 14.421844062833467, 13.488096883292446, 12.536030661276804, 11.559212193215073, 10.64146200954073, 9.69602932471256, 8.791435740658237, 7.860068529720996, 6.809206246457103, 6.027378265541385, 7.004615170079697, 7.8338639320378105, 9.71880707666649, 10.67401307816322, 11.665420091766473, 12.693345293265148, 13.722120504743657, 14.569976974472425, 15.610236801321383, 16.312275333725275, 15.432062731735575, 14.465764207714445, 13.594572569368548, 12.581255769268001, 11.642821643581168, 10.737350843966647, 9.786895919676088, 8.739708725728946, 7.764934782933441, 7.075439199973356, 7.939173882603707, 8.808657331539028, 10.712009164789853, 11.687594660971643, 11.931561229427087, 12.695004971453335, 13.659938321893117, 14.497701675774708, 15.36023959459526, 16.344738482684555, 16.414913763789272, 15.401544234675889, 14.543239926590248, 13.618612827848812, 12.688132289418347, 11.643740564620394, 10.635923784320743, 9.657214125816685, 8.697768812450686, 8.010059063619918, 8.90329219831287, 9.797699619457402, 11.679215478087995, 11.888020928012894, 10.94041022910776, 11.670911873900815, 12.604271692910261, 13.512238999932702, 14.406672253770516, 15.398229700244455, 16.402818628185013, 16.41819188052295, 15.557668753587919, 14.60199028434093, 13.601476118518168, 12.535394309860253, 11.551119235468118, 10.609025720171765, 9.661701130273105, 8.955280612337809, 9.843011363358645, 10.806044924189331, 11.728362735262706, 10.899308269036993, 9.987455841990814, 10.603756876520471, 11.572883859543364, 12.53019593723306, 13.402037998575008, 14.34740302540822, 15.327845318496719, 16.27953029506446, 16.50065779115181, 15.460931598744784, 14.50126832125004, 13.43753994010836, 12.483931217118581, 11.546191811799797, 10.664317179868412, 9.95750466413314, 10.884382526587745, 11.766597136270029, 10.721870690552596, 9.925118028530981, 8.952336606812471, 9.634556869025745, 10.522213579941784, 11.518399836886804, 12.468824450656252, 13.404230658883098, 14.374032350796396, 15.30942786304033, 16.26274545530808, 16.34108511724251, 15.328691807409387, 14.395138962639825, 13.472633212280234, 12.532123189984157, 11.720519884749034, 10.90919890579638, 11.832304949952373, 11.64302129702474, 9.75523926535616, 8.856209645508244, 7.894653634563443, 8.636354104675151, 9.578252584448386, 10.61286278537224, 11.531007246942012, 12.548096872438043, 13.58501644727241, 14.561844870719051, 15.578922866340662, 16.61878973056424, 16.29696806805313, 15.349998682277745, 14.42479823887428, 13.491826780706392, 12.7396648354562, 11.979813359303439, 11.631822467243822, 10.63137308163292, 8.8006661710047, 7.886714258691749, 6.956746302938809, 7.620258707625872, 8.553530968574286, 9.54108487230149, 10.510494998208607, 11.56790789032689, 12.631914928729351, 13.69198297630988, 14.603539342814479, 15.593289147359577, 16.41411862845192, 15.402865794919709, 14.38213800073329, 13.402910386046832, 12.535451104626542, 11.550903692392728, 10.68433064184181, 9.698910870052666, 7.793465380845985, 6.9508933160081, 6.0212794932884215, 6.688961393423926, 7.6405651701371, 8.63530116441332, 9.608955018102334, 10.650403301611385, 11.66714343454894, 12.638501328955007, 13.595486383813247, 14.577958161426892, 15.439190017783675, 14.431723266415025, 13.43809840351887, 12.459411846073442, 11.513298869061947, 10.58057931410147, 9.615593247485245, 8.712622378640129, 6.782644268500722, 6.062311072989157, 5.081822550016803, 5.716038010205143, 6.705369486700043, 7.7697788020614675, 8.80582559159216, 9.760625577683971, 10.714443971601172, 11.643221160891231, 12.553287601268245, 13.530325174848588, 14.446119293891414, 13.483294076943773, 12.499300407121673, 11.560776566806043, 10.547159677554113, 9.607634372754932, 8.607892467031622, 7.774026974647174, 5.836795000953451, 5.02563485701993, 4.1546196167056975, 4.75333892338843, 5.8131313255458394, 6.819057396851882, 7.855365375881843, 8.751062154942893, 9.781458367259965, 10.708118641269733, 11.581448832719554, 12.580724227312558, 13.525620621998897, 12.597430400525736, 11.54744801928466, 10.58019546589036, 9.567473430472461, 8.62498401444729, 7.638636853576036, 6.801006505878796, 4.811446513695643, 4.06746787167386, 3.0901368753093674, 3.827568944423583, 4.878546612578718, 5.817892560575024, 6.806111627040671, 7.788732996462364, 8.756155676861288, 9.700612430515749, 10.625962550749465, 11.562170420889249, 12.594930016751222, 11.746272728703309, 10.78079122645912, 9.738064524365422, 8.704502931763171, 7.726575001196162, 6.685881539563377, 5.751741475317061, 3.8806917061767594, 3.0020169995702055, 2.046626889494697, 2.8696361370241066, 3.8693945464855504, 4.868351025986376, 5.847330695772884, 6.829344643207801, 7.783765844124074, 8.821763494940909, 9.827533484887423, 10.892501201174104, 11.748297948470752, 10.715079725172215, 9.784524598214055, 8.746342647238798, 7.741479041924162, 6.707771301340092, 5.745666022530729, 4.820180245550277, 2.90222743708111, 1.9553541516829744, 0.9793131448576852, 1.9374520386650906, 2.945124368181565, 3.9002484099703096, 4.856549597839856, 5.87302484524485, 6.898682677785834, 7.886725487568981, 8.817883855370866, 9.838647668551719, 10.70760004777822, 9.767151691121027, 8.760778703954657, 7.7658179054314935, 6.781286310614944, 5.816613672858957, 4.855810221916018, 3.8559698545845205, 2.0345864398698406, 0.9611760327292814, 0.0, 0.9369151799834503, 2.011188103129923, 3.083961844163247, 4.1382950569748225, 5.093318788685937, 6.079463178661257, 7.062490302153984, 7.999821880860326, 9.053992081955775, 10.096410458106273, 9.198218197601262, 8.136278960996627, 7.09875581359864, 6.107892695797469, 5.075680225420012, 4.033590471745723, 2.9987758077585602, 3.026136544380205, 1.9801950235047845, 1.0318911032871991, 1.8696068921506477, 2.903188254268231, 3.9298243781954674, 4.885344460384596, 5.916600887164534, 6.875512436323403, 7.947919358005127, 8.944405029737332, 9.901359289662185, 10.948783869317674, 10.05534800707915, 9.07032633302901, 8.008157473148772, 7.015136957601008, 6.012723349234362, 5.000232508577433, 4.022132555608351], [6.004539829205559, 6.883326607417739, 7.876668942961728, 8.8364610965033, 9.889927800117274, 10.894626115206124, 11.908908018127962, 10.924847909204153, 9.885310105464237, 8.818465703788561, 7.830899866851311, 6.804424276565159, 5.840481603924765, 4.850488705282662, 3.893889174428084, 2.9228533471714218, 1.8843524127608213, 2.896544371909662, 3.9450916125215354, 4.964728082915304, 6.714426974534978, 7.6595110688882375, 8.63796827568142, 9.696506136778051, 10.631659541503351, 11.608872754454154, 12.573534206983961, 11.63830847542927, 10.651561468796809, 9.630445439601258, 8.676340181592478, 7.746707172191213, 6.783702462117018, 5.802425985752266, 4.82085456724082, 3.919426382572023, 2.95646601142679, 3.8402911627349763, 4.826910479775077, 5.773836868331097, 7.695610057718924, 8.66016689067705, 9.67279973837335, 10.670665095231243, 11.640763302791873, 12.59721120095346, 13.504316621055528, 12.4862762763428, 11.516449960704229, 10.563621014146161, 9.651516034344795, 8.684206618120532, 7.761669410427532, 6.813085414354825, 5.840085524488058, 4.970402007200233, 3.9384114290365346, 4.8105694333099915, 5.7745843080264265, 6.711603419142787, 8.728603904341341, 9.621575965516197, 10.605792632335245, 11.555603796707318, 12.564101083534544, 13.620982627039401, 14.418541422721079, 13.419456623201304, 12.463284431907736, 11.517187365003753, 10.718279763882558, 9.69220525874383, 8.728574210080438, 7.83250580697057, 6.784391686000443, 5.96156911423246, 4.892077645302666, 5.8302072672922165, 6.826532167251852, 7.6984574913026265, 9.627711636277132, 10.659395835571129, 11.55583533869189, 12.594476968688824, 13.558683835152102, 14.492331763860655, 15.392847426579399, 14.450111512956578, 13.484928882850017, 12.551181703308997, 11.599115481293353, 10.622297013231623, 9.70454682955728, 8.759114144729109, 7.8545205606747865, 6.923153349737546, 5.872291066473653, 6.7916724880426695, 7.768909392580982, 8.689811032248944, 10.574754176877622, 11.529960178374353, 12.521367191977605, 12.747293220458573, 13.714966244205, 14.611585391391257, 15.429671218426593, 15.375360153741825, 14.495147551752126, 13.528849027730995, 12.657657389385097, 11.644340589284552, 10.705906463597719, 9.800435663983196, 8.849980739692636, 7.802793545745495, 6.828019602949991, 7.839733422474641, 8.70346810510499, 9.66460443175016, 11.567956265000985, 12.543541761182775, 12.555156998898656, 11.758089791469883, 12.723023141909666, 13.560786495791257, 14.423324414611809, 15.407823302701104, 15.477998583805821, 14.46462905469244, 13.606324746606797, 12.681697647865363, 11.751217109434897, 10.706825384636945, 9.699008604337294, 8.720298945833235, 7.760853632467237, 8.774353286121203, 9.667586420814153, 10.653646719668535, 12.535162578299127, 12.511616697484463, 11.56400599857933, 10.733996693917364, 11.66735651292681, 12.57532381994925, 13.469757073787065, 14.461314520261004, 15.465903448201562, 15.481276700539501, 14.62075357360447, 13.66507510435748, 12.664560938534718, 11.598479129876804, 10.614204055484668, 9.672110540188315, 8.724785950289656, 9.65664363056818, 10.607305585859928, 11.598561897603377, 12.403090634269365, 11.52290403850856, 10.611051611462383, 9.66684169653702, 10.635968679559912, 11.593280757249609, 12.465122818591556, 13.410487845424768, 14.390930138513268, 15.342615115081012, 15.56374261116836, 14.524016418761335, 13.56435314126659, 12.50062476012491, 11.547016037135132, 10.609276631816348, 9.727401999884963, 10.65886768236351, 11.648676749089027, 12.559114109684074, 11.396598589559252, 10.548713798002549, 9.57593237628404, 8.697641689042294, 9.585298399958333, 10.581484656903353, 11.5319092706728, 12.467315478899646, 13.437117170812945, 14.372512683056879, 15.325830275324632, 15.404169937259061, 14.391776627425937, 13.458223782656376, 12.535718032296785, 11.595208010000707, 10.783604704765583, 11.61056192402675, 12.565478841169874, 12.466503586322583, 10.429967164362816, 9.479805414979811, 8.51824940403501, 7.6994389246917, 8.641337404464934, 9.675947605388789, 10.594092066958561, 11.611181692454592, 12.64810126728896, 13.6249296907356, 14.64200768635721, 15.68187455058079, 15.36005288806968, 14.413083502294295, 13.48788305889083, 12.554911600722942, 11.802749655472748, 12.68117637753381, 12.455304756541665, 11.454855370930764, 9.57985560002717, 8.510310028163317, 7.580342072410376, 6.683343527642422, 7.6166157885908365, 8.60416969231804, 9.573579818225156, 10.630992710343438, 11.6949997487459, 12.75506779632643, 13.666624162831027, 14.656373967376126, 15.508810754403004, 15.39475955968654, 14.50396638950353, 13.527685439922116, 12.800995130233401, 12.48781887237618, 11.597854368016485, 10.54787548400809, 8.587414519801406, 7.574489085479668, 6.644875262759989, 5.752046213440476, 6.70364999015365, 7.69838598442987, 8.672039838118884, 9.713488121627936, 10.730228254565489, 11.701586148971556, 12.658571203829796, 13.64104298144344, 14.53388214373476, 15.368638446398476, 14.375013583502321, 13.396327026056893, 12.450214049045398, 11.517494494084922, 10.552508427468696, 9.561586992595553, 7.677646325496394, 6.742584658002769, 5.70541831948837, 4.779122830221692, 5.768454306716593, 6.832863622078017, 7.868910411608709, 8.82371039770052, 9.777528791617721, 10.70630598090778, 11.616372421284794, 12.593409994865137, 13.540811419842498, 14.420209256927224, 13.436215587105124, 12.497691746789494, 11.484074857537564, 10.544549552738383, 9.544807647015073, 8.669029031642845, 6.731797057949122, 5.773763677409196, 4.778215386177265, 3.8164237434049797, 4.876216145562389, 5.882142216868431, 6.918450195898393, 7.814146974959442, 8.844543187276514, 9.771203461286282, 10.644533652736103, 11.643809047329107, 12.588705442015446, 13.534345580509187, 12.484363199268111, 11.517110645873812, 10.504388610455912, 9.56189919443074, 8.575552033559486, 7.737921685862245, 5.748361693679093, 4.863727181463548, 3.881664610832493, 2.890653764440133, 3.9416314325952673, 4.880977380591574, 5.869196447057221, 6.851817816478913, 7.819240496877837, 8.763697250532298, 9.689047370766014, 10.625255240905798, 11.658014836767771, 12.668556329220532, 11.717706406442568, 10.67497970434887, 9.64141811174662, 8.663490181179611, 7.622796719546828, 6.688656655300512, 4.81760688616021, 3.938932179553656, 2.916507886571827, 1.9327209570406563, 2.9324793665021, 3.931435846002926, 4.910415515789434, 5.89242946322435, 6.846850664140623, 7.884848314957458, 8.890618304903974, 9.955586021190655, 10.878890330883873, 11.651994905155664, 10.721439778197503, 9.683257827222246, 8.678394221907611, 7.644686481323542, 6.6825812025141795, 5.757095425533727, 3.83914261706456, 2.8922693316664247, 1.9162283248411356, 1.0005368586816403, 2.008209188198115, 2.9633332299868593, 3.9196344178564058, 4.9361096652614, 5.961767497802383, 6.949810307585531, 7.880968675387416, 8.901732488568268, 9.830301706030863, 10.704066871104477, 9.697693883938106, 8.702733085414943, 7.7182014905983936, 6.753528852842407, 5.792725401899467, 4.792885034567971, 2.971501619853291, 1.8980912127127318, 0.9369151799834503, 0.0, 1.0742729231464725, 2.147046664179796, 3.2013798769913713, 4.156403608702486, 5.142547998677806, 6.125575122170533, 7.062906700876875, 8.117076901972323, 9.159495278122822, 10.135133377584712, 9.073194140980076, 8.03567099358209, 7.0448078757809185, 6.012595405403461, 4.970505651729173, 3.9356909877420105, 3.9630517243636554, 2.9171102034882352, 1.9248872839848328, 0.9326917121671975, 1.9662730742847807, 2.992909198212017, 3.948429280401146, 4.979685707181083, 5.9385972563399525, 7.011004178021676, 8.007489849753881, 8.964444109678734, 10.011868689334223, 10.992263187062601, 10.007241513012461, 8.945072653132224, 7.9520521375844595, 6.949638529217812, 5.937147688560883, 4.959047735591802], [7.07302095255783, 7.957599530564211, 8.9509418661082, 9.910734019649771, 10.964200723263746, 11.873449583681804, 10.922718546512375, 9.916115067644052, 8.876577263904135, 7.820502185000135, 6.832936348062885, 5.806460757776733, 4.842518085136339, 3.852525186494236, 2.895925655639658, 1.9248898283829958, 2.952833536113092, 3.965025495261933, 5.013572735873806, 6.033209206267575, 7.7829080978872485, 8.727992192240508, 9.70644939903369, 10.764987260130322, 11.700140664855622, 12.636596576843607, 11.575570688195533, 10.640344956640842, 9.65359795000838, 8.63248192081283, 7.678376662804051, 6.748743653402787, 5.785738943328592, 4.80446246696384, 3.822891048452394, 2.9904635871554426, 3.9534239583006756, 4.908772286087247, 5.895391603127348, 6.842317991683368, 8.764091181071194, 9.728648014029321, 10.74128086172562, 11.739146218583514, 12.709244426144144, 13.555566815785117, 12.5063531022671, 11.488312757554372, 10.518486441915801, 9.565657495357733, 8.653552515556367, 7.686243099332106, 6.763705891639106, 5.815121895566399, 4.842122005699632, 4.041439211783652, 4.93536937591042, 5.879050556662262, 6.843065431378697, 7.780084542495058, 9.797085027693612, 10.690057088868468, 11.674273755687516, 12.62408492005959, 13.632582206886815, 14.404197407042428, 13.420577903932651, 12.421493104412876, 11.465320913119308, 10.519223846215326, 9.72031624509413, 8.694241739955404, 7.730610691292012, 6.834542288182144, 5.7864281672120175, 5.056442030489112, 5.889035592176551, 6.827165214166102, 7.824701543381434, 8.762209383116627, 10.644359096763443, 11.67604329605744, 12.624316462044161, 13.662958092041094, 14.144991021092803, 14.904100595315109, 14.394883907790971, 13.45214799416815, 12.48696536406159, 11.553218184520569, 10.601151962504929, 9.624333494443198, 8.706583310768854, 7.761150625940683, 6.856557041886361, 6.018026265994198, 6.869249013347538, 7.788630434916555, 8.765867339454868, 9.706458492735255, 11.591401637363933, 12.546607638860664, 13.538014652463916, 13.747427445043616, 13.07388913730595, 13.970508284492206, 14.75531329408513, 14.377396634953397, 13.497184032963698, 12.530885508942568, 11.659693870596673, 10.646377070496126, 9.707942944809293, 8.80247214519477, 7.886014918674238, 6.976647694831424, 7.824977549823876, 8.836691369348525, 9.700426051978877, 10.681251892236471, 12.584603725487296, 13.560189221669086, 13.555291223483698, 12.758224016054927, 12.081946035010615, 12.919709388892207, 13.748966490270346, 14.695935559274288, 14.480035065017393, 13.466665535904012, 12.608361227818373, 11.683734129076937, 10.753253590646471, 9.796214980509562, 8.944151113198638, 7.968747504374389, 8.757811579341121, 9.771311232995087, 10.66454436768804, 11.669898304081856, 13.551810038785439, 13.511750922069504, 12.56414022316437, 11.734130918502407, 11.02627940602776, 11.9342467130502, 12.795399149445602, 13.749426776834188, 14.714426344585434, 14.483313181751074, 13.641540561578209, 12.68586209233122, 11.685347926508458, 10.86437521008991, 9.914400955735445, 8.984727975153891, 9.72174389716354, 10.653601577442064, 11.604263532733814, 12.595519844477263, 13.403224858854404, 12.523038263093602, 11.611185836047424, 10.666975921122063, 9.994891572660862, 10.952203650350558, 11.790764894250094, 12.680746545593603, 13.639453034897139, 14.591138011464883, 14.62740203539762, 13.587675842990595, 12.628012565495851, 11.813242195090487, 10.859633472100708, 9.921894066781924, 10.724359946758847, 11.655825629237395, 12.645634695962913, 13.55607205655796, 12.396732814144293, 11.54884802258759, 10.576066600869082, 9.697775913627336, 8.944221293059282, 9.940407550004302, 10.857551346331338, 11.737574179068483, 12.685640067196816, 13.62103557944075, 14.517041221175354, 14.58909182574657, 13.641348790025555, 12.770841217621951, 11.84833546726236, 10.907825444966283, 11.780562651639467, 12.607519870900635, 13.562436788043758, 13.466637810907624, 11.430101388947858, 10.479939639564853, 9.518383628620052, 8.699573149276741, 8.000260297565886, 9.017350744305514, 9.919734142617099, 10.811304897969762, 11.7064803179021, 12.671715373895527, 13.56773476321074, 14.60760162743432, 14.669305405726222, 13.725700937259871, 12.800500493856406, 11.867529035688518, 12.799707602346633, 13.678134324407694, 13.455438981126706, 12.454989595515805, 10.57998982461221, 9.510444252748359, 8.580476296995418, 7.683477752227463, 6.9580189275075615, 7.945572831234764, 8.899221893883693, 9.831115915858609, 10.663769266261928, 11.680794873179956, 12.592351239684557, 13.582101044229656, 14.434537831256533, 14.707376994652115, 13.816583824469106, 12.840302874887692, 13.797953077107286, 13.539419738839904, 12.597988592601526, 11.548009708593131, 9.587548744386448, 8.574623310064709, 7.64500948734503, 6.752180438025517, 5.93067491563813, 6.917211750824044, 7.890865604513058, 8.761411474733318, 9.655955331419015, 10.627313225825082, 11.584298280683324, 12.566770058296969, 13.459609220588288, 14.471526191728614, 14.807719652787101, 13.783801414861083, 13.524486972191871, 12.569095360548646, 11.60410929393242, 10.561721217180594, 8.677780550081435, 7.74271888258781, 6.705552544073411, 5.779257054806734, 4.995479232201074, 5.956049109284834, 6.917553751546267, 7.749437474554047, 8.703255868471249, 9.632033057761308, 10.542099498138322, 11.519137071718665, 12.466538496696026, 13.429363713643667, 14.413357383465767, 13.571964669935968, 12.558347780684038, 11.618822475884857, 10.611856847157732, 9.669163256227886, 7.7319312825341635, 6.773897901994237, 5.778349610762306, 4.816557967990021, 4.058039208193135, 4.920598129472215, 5.84417727275192, 6.739874051812969, 7.770270264130042, 8.69693053813981, 9.57026072958963, 10.569536124182635, 11.514432518868974, 12.533377909730984, 13.558636122414585, 12.591383569020286, 11.578661533602386, 10.636172117577214, 9.64982495670596, 8.783573711333318, 6.822634616825566, 5.863861406048589, 4.881798835417534, 3.8907879890251738, 3.0175931620934917, 3.8902906996142463, 4.794923523910748, 5.777544893332441, 6.744967573731365, 7.689424327385826, 8.614774447619542, 9.550982317759326, 10.5837419136213, 11.59428340607406, 12.657131125586666, 11.749252627495347, 10.715691034893096, 9.737763104326085, 8.6970696426933, 7.762929578446984, 5.891879809306682, 4.954964046729357, 3.9166421111568672, 2.932855181625697, 1.9577133026972535, 2.940749165025599, 3.836142592642961, 4.818156540077878, 5.7725777409941506, 6.8105753918109855, 7.8163453817575, 8.881313098044181, 9.804617407737402, 10.644405173592771, 11.6579570453558, 10.757530750368723, 9.752667145054087, 8.718959404470015, 7.756854125660652, 6.8313683486802, 4.913415540211033, 3.9665422548128975, 2.9905012479876083, 2.000671083266681, 0.9339362650516422, 1.8890603068403868, 2.845361494709933, 3.861836742114927, 4.887494574655911, 5.875537384439058, 6.806695752240944, 7.827459565421796, 8.75602878288439, 9.696477139541583, 10.702850126707954, 9.777006008561418, 8.792474413744868, 7.82780177598888, 6.866998325045941, 5.8671579577144435, 4.045774542999764, 2.9723641358592046, 2.011188103129923, 1.0742729231464725, 0.0, 1.0727737410333238, 2.1271069538448995, 3.082130685556014, 4.068275075531334, 5.051302199024061, 5.988633777730403, 7.042803978825852, 8.08522235497635, 9.159353564495156, 10.14746706412655, 9.109943916728563, 8.119080798927392, 7.086868328549935, 6.044778574875647, 5.009963910888484, 5.037324647510128, 3.991383126634708, 2.9933684073371034, 2.0011728355194682, 0.967591473401885, 1.9942275973291212, 2.94974767951825, 3.9810041062981876, 4.939915655457057, 6.0123225771387805, 6.93321692660741, 7.890171186532262, 8.937595766187751, 9.929385893742912, 10.914407567793052, 10.019345576278695, 9.026325060730931, 8.023911452364285, 7.011420611707356, 6.033320658738274], [8.145794693591153, 9.030373271597535, 10.023715607141524, 10.983507760683095, 11.805374157737328, 10.800675842648477, 9.84994480547905, 8.843341326610728, 7.803803522870811, 6.859040067237034, 5.9838050898761495, 4.9573294995899975, 3.9933868269496036, 3.003393928307501, 2.0467943974529232, 2.9976635694163196, 4.025607277146416, 5.037799236295257, 6.08634647690713, 7.105982947300898, 8.855681838920571, 9.80076593327383, 10.779223140067012, 11.837761001163644, 12.740934603085124, 11.763721390134322, 10.702695501486248, 9.767469769931557, 8.780722763299096, 7.783350662626095, 6.829245404617315, 5.899612395216051, 4.936607685141857, 3.955331208777105, 2.973759790265659, 3.98012967160317, 4.943090042748403, 5.9815460271205705, 6.9681653441606715, 7.915091732716691, 9.836864922104517, 10.801421755062643, 11.814054602758942, 12.811919959616835, 13.704905175622391, 12.70643555759838, 11.657221844080365, 10.639181499367636, 9.669355183729065, 8.716526237170998, 7.804421257369631, 6.83711184114537, 5.9145746334523706, 4.965990637379663, 3.9929907475128967, 5.031105296231381, 5.925035460358147, 6.951824297695586, 7.915839172412021, 8.85285828352838, 10.816759647823924, 11.762830829901791, 12.747047496720839, 13.696858661092913, 14.623822631867785, 13.555066148855692, 12.571446645745915, 11.57236184622614, 10.616189654932572, 9.67009258802859, 8.871184986907394, 7.845110481768668, 6.881479433105276, 5.985411029995409, 4.9372969090252825, 6.011470115365981, 6.878701676624279, 7.816831298613829, 8.814367627829162, 9.751875467564354, 11.63402518121117, 12.665709380505167, 13.633551954559493, 14.673234655438797, 15.071268996314108, 14.137621067605556, 13.545752649604236, 12.603016735981415, 11.637834105874854, 10.704086926333833, 9.752020704318191, 8.775202236256462, 7.857452052582118, 6.912019367753948, 6.007425783699626, 6.964256139647162, 7.858915097795266, 8.778296519364282, 9.755533423902595, 10.696124577182982, 12.58106772181166, 13.53627372330839, 14.527680736911643, 14.82020118607694, 14.088899594891876, 13.204028756782654, 13.9235206326199, 13.528265376766662, 12.648052774776962, 11.681754250755832, 10.810562612409935, 9.79724581230939, 8.858811686622557, 7.953340887008035, 7.0368836604875025, 7.922877568484388, 8.814643634271603, 9.826357453796254, 10.690092136426603, 11.670917976684198, 13.574269809935023, 14.549855306116813, 14.628064964517021, 13.83099775708825, 13.096956492596542, 12.153229861182654, 12.917173828805115, 13.857450261295357, 13.630903806830657, 12.617534277717276, 11.759229969631635, 10.834602870890201, 9.904122332459735, 8.947083722322827, 8.095019855011902, 8.914977378027354, 9.747477663788848, 10.760977317442816, 11.654210452135766, 12.659564388529583, 14.541476123233165, 14.584524663102828, 13.636913964197694, 12.80690465953573, 12.041289863613686, 11.167767185340647, 11.963606487980371, 12.910941478855257, 13.875941046606503, 13.634181923564338, 12.792409303391473, 11.836730834144484, 10.836216668321722, 10.015243951903175, 9.06526969754871, 9.930957848806855, 10.711409981611267, 11.64326766188979, 12.59392961718154, 13.58518592892499, 14.475998599887728, 13.595812004126925, 12.683959577080747, 11.739749662155386, 11.009902030246788, 10.185724122641005, 10.958972232784863, 11.842261247614672, 12.800967736918208, 13.752652713485952, 13.778270777210883, 12.738544584803858, 11.778881307309113, 11.009342144740463, 10.080871600098297, 10.868123940434888, 11.714026031206574, 12.645491713685121, 13.63530078041064, 14.545738141005687, 13.469506555177617, 12.621621763620913, 11.648840341902405, 10.77054965466066, 9.959231750645209, 9.17392802229475, 10.025758684866107, 10.899088881089552, 11.847154769217886, 12.78255028146182, 13.678555923196424, 13.739960567559832, 12.792217531838817, 11.966941167271928, 11.06957359525995, 11.854055318619247, 12.770228736087194, 13.597185955348362, 14.552102872491485, 14.539411551940947, 12.502875129981181, 11.552713380598176, 10.591157369653375, 9.772346890310066, 9.01527075515181, 8.217989393950003, 9.087941481151868, 9.972819599990832, 10.86799501992317, 11.833230075916596, 12.72924946523181, 13.76911632945539, 13.820174147539484, 12.94693906525746, 12.021738621853995, 12.813758909341482, 13.78937368679436, 14.66780040885542, 14.52821272216003, 13.527763336549128, 11.652763565645534, 10.583217993781682, 9.653250038028741, 8.756251493260788, 7.973029385093486, 7.146211480879252, 8.067429232418462, 8.992630617879678, 9.825283968282998, 10.842309575201025, 11.753865941705627, 12.743615746250725, 13.596052533277604, 13.928615122649704, 13.037821952466695, 13.786532748540656, 14.744831209415276, 14.612193479873227, 13.67076233363485, 12.620783449626455, 10.660322485419771, 9.647397051098032, 8.717783228378353, 7.824954179058841, 6.945685373224055, 6.085419089358813, 7.059072943047827, 7.9229261767543875, 8.817470033440085, 9.788827927846151, 10.745812982704395, 11.72828476031804, 12.621123922609359, 13.633040893749685, 14.06672661233145, 14.730031288514047, 14.597260713225195, 13.64186910158197, 12.676883034965744, 11.634494958213917, 9.75055429111476, 8.815492623621134, 7.7783262851067345, 6.852030795840057, 6.010489689786998, 5.124256447819603, 6.079068453567337, 6.910952176575117, 7.864770570492318, 8.79354775978238, 9.703614200159393, 10.680651773739736, 11.628053198717097, 12.590878415664738, 13.574872085486838, 14.514889761469506, 13.631121521717361, 12.69159621691818, 11.684630588191057, 10.741936997261211, 8.804705023567488, 7.846671643027561, 6.851123351795629, 5.889331709023344, 5.073049665779059, 4.088805468006984, 5.00569197477299, 5.9013887538340395, 6.9317849661511115, 7.858445240160881, 8.731775431610702, 9.731050826203706, 10.675947220890045, 11.694892611752055, 12.74487499299313, 13.664157310053609, 12.651435274635709, 11.708945858610537, 10.722598697739283, 9.856347452366641, 7.895408357858889, 6.936635147081913, 5.9545725764508575, 4.9635617300584975, 4.032603619679415, 3.0584980381490157, 3.9564382259318185, 4.939059595353511, 5.906482275752435, 6.850939029406896, 7.776289149640612, 8.712497019780397, 9.74525661564237, 10.754262716408547, 11.769771904438949, 12.784915078042516, 11.78846477592642, 10.810536845359408, 9.769843383726624, 8.835703319480308, 6.964653550340006, 6.027737787762681, 4.9894158521901915, 4.005628922659021, 3.0304870437305773, 2.108956503560368, 2.997657294664031, 3.9796712420989477, 4.934092443015221, 5.972090093832056, 6.897591544127247, 7.962559260413927, 8.883281947022084, 9.723069712877454, 10.736621584640481, 11.793193200915892, 10.82544088608741, 9.791733145503338, 8.829627866693976, 7.904142089713523, 5.986189281244356, 5.039315995846221, 4.063274989020932, 3.073444824300005, 2.006710006084966, 1.0572676453751562, 2.006876196731003, 3.023351444135997, 4.011211869626849, 4.999254679409996, 5.887941914610689, 6.906124104706479, 7.834693322169073, 8.775141678826266, 9.781514665992637, 10.7764754645158, 9.865248154778191, 8.900575517022205, 7.939772066079264, 6.939931698747767, 5.118548284033087, 4.045137876892528, 3.0839618441632464, 2.147046664179796, 1.0727737410333238, 0.0, 1.0543332128115754, 2.0093569445226898, 2.9955013344980097, 3.9785284579907363, 4.915860036697078, 5.9700302377925265, 7.012448613943025, 8.086579823461829, 9.148519060066464, 10.182717657761886, 9.191854539960715, 8.159642069583258, 7.11755231590897, 6.082737651921807, 6.110098388543451, 5.064156867668031, 4.066142148370427, 3.073946576552792, 2.0403652144352087, 1.0694901712591098, 2.025010253448239, 3.045247017547723, 3.990984427709036, 5.049992521686158, 5.860443185574085, 6.817397445498937, 7.864822025154426, 8.856612152709587, 9.841633826759725, 10.903802686639963, 10.099098801764255, 9.096685193397608, 8.08419435274068, 7.106094399771598], [9.070175074496719, 10.019819587616269, 11.013161923160258, 11.778628016086765, 10.751040944925753, 9.746342629836903, 8.795611592667473, 7.789008113799153, 6.749470310059236, 5.804706854425459, 4.973687606783475, 3.947212016497323, 2.983269343856929, 1.9932764452148266, 2.940450896384718, 3.91148672364138, 4.949987658051981, 5.962179617200822, 7.010726857812696, 8.030363328206464, 9.755863846537704, 10.700947940890963, 11.679405147684145, 12.621754794998848, 11.686601390273548, 10.709388177322746, 9.648362288674672, 8.71313655711998, 7.72638955048752, 6.77323317953342, 5.8191279215246405, 4.889494912123377, 3.9264902020491825, 2.9452137256844306, 3.8674162891974535, 4.873786170534965, 5.836746541680197, 6.881728034737702, 7.868347351777803, 8.815273740333824, 10.73704692972165, 11.701603762679776, 12.714236610376075, 13.650648668151813, 12.694787692529717, 11.696318074505706, 10.64710436098769, 9.629064016274961, 8.65923770063639, 7.706408754078323, 6.7943037742769565, 5.826994358052696, 4.915915969233804, 3.967331973161097, 4.886647246444691, 5.924761795163175, 6.818691959289942, 7.8520063053127185, 8.816021180029153, 9.753040291145513, 11.710416146755717, 12.663012837518924, 13.647229504337972, 14.597040668710045, 13.61370514877511, 12.544948665763018, 11.56132916265324, 10.562244363133466, 9.606072171839898, 8.659975104935915, 7.86106750381472, 6.839358062531137, 5.88282076888671, 5.014192182128742, 5.830953407957077, 6.905126614297775, 7.772358175556073, 8.710487797545623, 9.708024126760955, 10.645531966496147, 12.527681680142964, 13.55936587943696, 14.527208453491287, 15.422541606958413, 14.458334740495134, 13.524686811786582, 12.535635166511561, 11.59289925288874, 10.627716622782179, 9.693969443241159, 8.746268285080662, 7.7694498170189314, 6.8587933883635515, 5.940800519887281, 6.90108228263142, 7.857912638578957, 8.75257159672706, 9.671953018296076, 10.649189922834388, 11.589781076114775, 13.474724220743454, 14.429930222240184, 15.421337235843437, 15.677459393569691, 14.902961449907414, 13.979016393952174, 12.938756567103216, 12.518147893673987, 11.637935291684288, 10.671636767663157, 9.804810193172406, 8.79149339307186, 7.86015302240399, 6.982122039141368, 7.930540159419298, 8.816534067416184, 9.708300133203398, 10.720013952728047, 11.583748635358397, 12.564574475615991, 14.467926308866817, 15.443511805048606, 15.485323172009775, 14.688255964581002, 13.91101834761208, 12.950965156872973, 11.932409763288431, 12.803117048483783, 12.620786323737983, 11.607416794624601, 10.753477550394106, 9.835944206671634, 8.905463668241168, 7.9758648744561595, 8.98368165475581, 9.80863387695915, 10.641134162720643, 11.65463381637461, 12.54786695106756, 13.553220887461377, 15.435132622164959, 15.441782870595581, 14.494172171690447, 13.664162867028482, 12.855351718629224, 11.965502481030967, 10.978842422463687, 11.856608266043683, 12.82160783379493, 12.624064440471663, 11.791196092516321, 10.838072169925917, 9.837558004103155, 9.044025104036509, 9.953931497292617, 10.82461434773865, 11.605066480543062, 12.536924160821586, 13.487586116113334, 14.478842427856783, 15.333256807380483, 14.453070211619679, 13.541217784573501, 12.597007869648138, 11.823963885262327, 10.99827895160978, 9.974208167268179, 10.787928034803098, 11.746634524106636, 12.69831950067438, 12.779612112992316, 11.73988592058529, 10.780222643090546, 10.038123296873797, 10.969533399842204, 11.761780439366683, 12.60768253013837, 13.539148212616915, 14.528957279342434, 15.43939463993748, 14.32676476267037, 13.478879971113667, 12.506098549395158, 11.627807862153412, 10.773293605660747, 9.987989877310287, 9.040994619349423, 9.844755668277976, 10.792821556406313, 11.728217068650247, 12.62422271038485, 12.741301903341265, 11.79355886762025, 10.995722319405262, 11.958235395003857, 12.747711817551043, 13.663885235018991, 14.490842454280155, 15.445759371423279, 15.396669759433701, 13.360133337473934, 12.40997158809093, 11.448415577146129, 10.629605097802818, 9.82933261016735, 9.03205124896554, 8.103177415635184, 8.918486387179255, 9.813661807111597, 10.778896863105022, 11.674916252420235, 12.714783116643815, 12.821515483320917, 12.042121196377506, 12.910400421597902, 13.707415408273278, 14.683030185726157, 15.561456907787214, 15.385470929652783, 14.385021544041882, 12.510021773138288, 11.440476201274436, 10.510508245521494, 9.61350970075354, 8.787091240109026, 7.960273335894792, 7.082665166901778, 7.938297405068103, 8.770950755471425, 9.78797636238945, 10.699532728894052, 11.689282533439151, 12.541719320466028, 13.02379725376975, 13.926483752210602, 14.680189247472452, 15.638487708347071, 15.46945168736598, 14.528020541127603, 13.478041657119208, 11.517580692912524, 10.504655258590786, 9.575041435871107, 8.682212386551592, 7.759747228239595, 6.8994809443743526, 6.074308877531142, 6.868592963942812, 7.763136820628511, 8.734494715034577, 9.69147976989282, 10.673951547506464, 11.566790709797782, 12.578707680938109, 13.459336869072459, 14.39808333801779, 15.344196315029285, 14.499127309074723, 13.534141242458498, 12.49175316570667, 10.607812498607512, 9.672750831113888, 8.635584492599488, 7.70928900333281, 6.824551544802538, 5.9383183028351425, 5.024735240755762, 5.856618963763542, 6.810437357680744, 7.739214546970804, 8.649280987347819, 9.62631856092816, 10.573719985905521, 11.536545202853162, 12.520538872675262, 13.46055654865793, 14.49304756928354, 13.582882558082598, 12.541888795683809, 11.599195204753963, 9.661963231060241, 8.703929850520314, 7.708381559288382, 6.746589916516097, 5.8871115207945985, 4.902867323022524, 3.951358761961415, 4.847055541022464, 5.877451753339537, 6.804112027349306, 7.6774422187991265, 8.67671761339213, 9.621614008078469, 10.640559398940479, 11.690541780181555, 12.657794333575854, 13.548944475902264, 12.606455059877092, 11.620107899005838, 10.713605659859397, 8.792917559125446, 7.793893354574665, 6.81183078394361, 5.82081993755125, 4.846665474694955, 3.8725598931645555, 2.9021050131202433, 3.8847263825419356, 4.8521490629408595, 5.796605816595321, 6.721955936829037, 7.658163806968821, 8.690923402830794, 9.699929503596973, 10.715438691627375, 11.730581865230942, 12.629890467669004, 11.708046046625967, 10.66735258499318, 9.733212520746864, 7.862162751606562, 6.884995995255434, 5.846674059682944, 4.8628871301517735, 3.8877452512233304, 2.923018358575908, 1.943324081852456, 2.9253380292873725, 3.8797592302036454, 4.91775688102048, 5.8432583313156705, 6.9082260476023505, 7.828948734210509, 8.66873650006588, 9.682288371828907, 10.738859988104318, 11.666866577829994, 10.689242346769896, 9.727137067960534, 8.80165129098008, 6.883698482510913, 5.9368251971127775, 4.950793423110854, 3.930703031792758, 2.863968213577719, 1.9088441717889744, 0.9525429839194279, 1.9690182313244218, 2.956878656815274, 3.9449214665984216, 4.833608701799114, 5.851790891894904, 6.780360109357498, 7.720808466014692, 8.727181453181062, 9.722142251704225, 10.706673846520776, 9.798084718288761, 8.837281267345821, 7.8374409000143235, 6.1728814968446635, 5.099471089704104, 4.1382950569748225, 3.201379876991372, 2.1271069538448995, 1.0543332128115754, 0.0, 0.9550237317111143, 1.9411681216864345, 2.924195245179161, 3.8615268238855025, 4.915697024980951, 5.958115401131451, 7.0322466106502555, 8.09418584725489, 9.131708994652877, 10.122572112454048, 9.213975282394834, 8.171885528720546, 7.137070864733383, 7.111474208489997, 6.065532687614577, 5.0155597280533595, 4.023364156235724, 2.989782794118141, 1.9631466701909044, 1.0076265880017754, 1.9909138047361474, 2.9366512148974606, 3.9956593088745826, 4.80610997276251, 5.763064232687362, 6.810488812342851, 7.802278939898011, 8.787300613948151, 9.849469473828389, 10.842489989376153, 10.121602235812777, 9.109111395155848, 8.131011442186766], [10.025198806207833, 10.974843319327382, 11.78339643791722, 10.82360428437565, 9.796017213214638, 8.791318898125787, 7.840587860956359, 6.833984382088039, 5.794446578348121, 4.849683122714344, 4.019678933204785, 2.9932033429186333, 2.080504517820782, 2.948300176925941, 3.8954746280958323, 4.866510455352495, 5.905011389763096, 6.9172033489119364, 7.965750589523809, 8.985387059917578, 10.710887578248819, 11.655971672602078, 12.63442887939526, 11.666731063287733, 10.731577658562433, 9.75436444561163, 8.693338556963557, 7.758112825408865, 6.771365818776405, 5.819224505954731, 4.865119247945951, 3.935486238544687, 3.1460717182007665, 3.900237457395545, 4.8224400209085685, 5.82880990224608, 6.791770273391313, 7.836751766448818, 8.823371083488919, 9.77029747204494, 11.692070661432766, 12.656627494390891, 13.66926034208719, 12.695624936440698, 11.740681419850954, 10.742309400927017, 9.693095687409, 8.675055342696272, 7.705229027057701, 6.752400080499633, 5.840295100698267, 4.872985684474006, 4.1676316338578, 4.922355704872212, 5.841670978155806, 6.87978552687429, 7.773715691001057, 8.807030037023834, 9.771044911740269, 10.708064022856629, 12.665439878466833, 13.61803656923004, 14.602253236049087, 13.658135560432985, 12.659696475196421, 11.590939992184328, 10.607320489074551, 9.608235689554776, 8.652063498261208, 7.705966431357226, 6.90705883023603, 5.885349388952448, 5.134536433510705, 5.969215913839856, 6.785977139668192, 7.86015034600889, 8.727381907267189, 9.665511529256738, 10.663047858472071, 11.600555698207263, 13.482705411854079, 14.514389611148076, 15.482232185202403, 14.468532933379723, 13.504326066916445, 12.570678138207892, 11.581626492932871, 10.63889057931005, 9.67370794920349, 8.739960769662469, 7.792259611501972, 6.815441143440242, 6.110509052987547, 6.895824251598396, 7.856106014342535, 8.812936370290071, 9.707595328438176, 10.626976750007191, 11.604213654545504, 12.54480480782589, 14.42974795245457, 15.3849539539513, 16.37636096755455, 15.46754630372341, 14.441877508745991, 13.504270449030795, 12.597454367028927, 11.564139220095297, 10.683926618105598, 9.717628094084468, 8.850801519593716, 7.83748471949317, 7.111868687027986, 7.937145770852482, 8.885563891130412, 9.771557799127297, 10.663323864914513, 11.675037684439163, 12.538772367069512, 13.519598207327107, 15.422950040577932, 16.39853553675972, 16.44034690372089, 15.643279696292113, 14.866042079323195, 13.902799787757694, 12.884244394173152, 12.015784422213104, 11.666777650159293, 10.653408121045912, 9.799468876815416, 8.888040733951495, 8.157179332865164, 8.930888606167274, 9.938705386466925, 10.763657608670263, 11.596157894431759, 12.609657548085725, 13.502890682778675, 14.508244619172492, 16.390156353876073, 16.396806602306693, 15.449195903401561, 14.619186598739594, 13.81037545034034, 12.917337111915687, 11.930677053348408, 11.069275639773004, 11.897437227354306, 11.670055766892974, 10.837187418937631, 9.919843681955886, 9.08927366872715, 9.999048835747622, 10.908955229003732, 11.779638079449764, 12.560090212254178, 13.491947892532702, 14.44260984782445, 15.433866159567899, 16.288280539091595, 15.408093943330792, 14.496241516284615, 13.55203160135925, 12.778987616973442, 11.950113582494502, 10.9260427981529, 10.00059540853242, 10.822463917666012, 11.774148894233756, 11.88912791741038, 10.871011170832787, 10.031938307714544, 10.99314702858491, 11.92455713155332, 12.716804171077797, 13.562706261849485, 14.49417194432803, 15.48398101105355, 16.394418371648595, 15.281788494381484, 14.43390370282478, 13.461122281106272, 12.582831593864524, 11.728317337371863, 10.943013609021403, 9.992829250234143, 9.057423042007297, 9.868650949965689, 10.804046462209623, 11.700052103944227, 11.872427153588761, 11.045274532244248, 11.950746051116376, 12.913259126714973, 13.702735549262156, 14.618908966730107, 15.445866185991271, 16.400783103134394, 16.351693491144815, 14.315157069185048, 13.364995319802043, 12.403439308857243, 11.58462882951393, 10.784356341878464, 9.987074980676656, 9.058201147346297, 8.131153760908576, 8.889491200670973, 9.8547262566644, 10.750745645979613, 11.790612510203193, 12.073231147944915, 12.99714492808862, 13.865424153309018, 14.662439139984391, 15.638053917437272, 16.51648063949833, 16.3404946613639, 15.340045275752995, 13.465045504849401, 12.39549993298555, 11.465531977232608, 10.568533432464651, 9.74211497182014, 8.915297067605906, 8.037688898612892, 7.150964778797423, 7.846780149030802, 8.863805755948828, 9.77536212245343, 10.765111926998529, 11.617548714025405, 12.653663674227364, 13.564070922496592, 14.417411271550558, 15.375709732425177, 16.36025714465899, 15.483044272838717, 14.433065388830322, 12.472604424623638, 11.4596789903019, 10.53006516758222, 9.637236118262706, 8.714770959950709, 7.854504676085467, 7.029332609242257, 6.081260337672132, 6.838966214187889, 7.810324108593955, 8.767309163452197, 9.749780941065842, 10.64262010335716, 11.654537074497487, 12.535166262631837, 13.473912731577167, 14.420025708588662, 15.390272291935418, 14.489164974169611, 13.446776897417784, 11.562836230318627, 10.627774562825001, 9.590608224310602, 8.664312735043923, 7.779575276513652, 6.893342034546257, 5.979758972466876, 5.069286337492862, 5.886266751240122, 6.815043940530182, 7.7251103809071955, 8.702147954487538, 9.649549379464899, 10.61237459641254, 11.59636826623464, 12.536385942217308, 13.568876962842918, 14.537906289793714, 13.496912527394924, 12.554218936465078, 10.616986962771355, 9.658953582231428, 8.663405290999496, 7.701613648227211, 6.842135252505713, 5.8578910547336385, 4.906382493672529, 4.059722914751784, 4.953281146898915, 5.8799414209086835, 6.753271612358504, 7.752547006951508, 8.697443401637846, 9.716388792499856, 10.766371173740932, 11.713153548408865, 12.698223624729627, 13.561478791588208, 12.575131630716953, 11.668629391570509, 9.74794129083656, 8.748917086285779, 7.766854515654724, 6.775843669262364, 5.80168920640607, 4.82758362487567, 3.857128744831358, 3.0973937562712552, 3.9279784565002376, 4.872435210154698, 5.797785330388415, 6.733993200528198, 7.766752796390172, 8.74490577188586, 9.760414959916263, 10.77555813351983, 11.674866735957888, 12.66306977833708, 11.622376316704294, 10.688236252457978, 8.817186483317677, 7.840019726966547, 6.801697791394058, 5.817910861862887, 4.8427689829344445, 3.8780420902870225, 2.8983478135635705, 2.034977817436814, 2.9456655883149407, 3.9836632391317757, 4.888234599604557, 5.953202315891237, 6.873925002499394, 7.713712768354766, 8.727264640117795, 9.783836256393206, 10.711842846118879, 11.64426607848101, 10.682160799671648, 9.756675022691194, 7.8387222142220265, 6.891848928823891, 5.905817154821968, 4.885726763503872, 3.818991945288833, 2.8638679035000885, 1.9075667156305423, 1.0650222328579857, 2.0018549251041593, 2.989897734887307, 3.8785849700879993, 4.896767160183789, 5.825336377646384, 6.765784734303577, 7.772157721469948, 8.76711851999311, 9.75165011480966, 10.716322752565647, 9.792304999056935, 8.792464631725437, 7.127905228555777, 6.054494821415218, 5.093318788685936, 4.156403608702486, 3.0821306855560135, 2.0093569445226898, 0.9550237317111143, 0.0, 0.9861443899753201, 1.9691715134680465, 2.906503092174388, 3.9606732932698367, 5.003091669420336, 6.07722287893914, 7.139162115543775, 8.176685262941762, 9.167548380742932, 10.168999014105948, 9.12690926043166, 8.092094596444497, 8.066497940201112, 7.0205564193256915, 5.970583459764474, 4.978387887946838, 3.944806525829255, 2.9181704019020187, 1.9626503197128897, 1.035890073025033, 1.981627483186346, 3.040635577163468, 3.8510862410513953, 4.808040500976247, 5.8554650806317365, 6.847255208186897, 7.832276882237036, 8.894445742117274, 9.887466257665038, 10.889879866031684, 10.064135126866962, 9.08603517389788], [11.011343196183152, 11.790594383485889, 10.7972520479419, 9.837459894400329, 8.809872823239319, 7.805174508150468, 6.854443470981039, 5.847839992112719, 4.808302188372801, 3.8635387327390243, 3.0335345432294645, 2.007058952943313, 2.971001625583707, 3.934444566901261, 4.881619018071152, 5.852654845327814, 6.891155779738415, 7.9033477388872555, 8.951894979499128, 9.971531449892897, 11.697031968224138, 12.642116062577397, 11.739124534409045, 10.680586673312414, 9.745433268587114, 8.768220055636311, 7.707194166988238, 6.771968435433546, 5.785221428801085, 4.833080115979411, 3.8789748579706305, 2.9493418485693663, 3.988065866542092, 4.886381847370865, 5.808584410883888, 6.8149542922214, 7.777914663366633, 8.822896156424138, 9.809515473464238, 10.756441862020258, 12.678215051408085, 13.64277188436621, 12.707345903323272, 11.709480546465379, 10.754537029875635, 9.756165010951698, 8.706951297433681, 7.688910952720953, 6.719084637082381, 5.766255690524313, 4.854150710722947, 3.8868412944986854, 4.944277272726811, 5.8928612687995185, 6.827815368131126, 7.865929916849611, 8.759860080976377, 9.793174426999153, 10.757189301715588, 11.694208412831948, 13.651584268442154, 14.604180959205358, 13.62180233482974, 12.671991170457666, 11.673552085221102, 10.604795602209009, 9.621176099099232, 8.622091299579457, 7.665919108285888, 6.719822041381906, 5.9209144402607095, 4.899204998977127, 5.862836047640519, 6.9079446164260325, 7.7721215296435116, 8.846294735984209, 9.71352629724251, 10.65165591923206, 11.649192248447392, 12.586700088182583, 14.4688498018294, 15.489913818338035, 14.522071244283708, 13.482388543404404, 12.518181676941126, 11.584533748232573, 10.595482102957552, 9.652746189334731, 8.68756355922817, 7.75381637968715, 6.806115221526651, 5.829296753464921, 6.822264807842585, 7.834552954184572, 8.842250404317854, 9.79908076026539, 10.693739718413497, 11.613121139982512, 12.590358044520825, 13.530949197801212, 15.41589234242989, 16.371098343926622, 15.509327115246766, 14.48140191374809, 13.455733118770672, 12.518126059055476, 11.611309977053608, 10.577994830119978, 9.69778222813028, 8.731483704109149, 7.864657129618396, 6.851340329517849, 7.823624441883025, 8.795035642597181, 9.861365654011795, 10.757702189102616, 11.649468254889834, 12.661182074414484, 13.524916757044833, 14.505742597302428, 16.409094430553253, 17.384679926735043, 16.487644680987533, 15.423948472920078, 14.447676221066006, 13.568924954655476, 12.539390097468246, 11.524088776836289, 10.680633260183974, 9.667263731070593, 8.813324486840095, 7.901896343976174, 8.83237688240664, 9.788778477911974, 10.796595258211624, 11.749801998645582, 12.58230228440708, 13.595801938061046, 14.489035072753996, 15.494389009147813, 17.376300743851395, 17.382950992282016, 16.435340293376882, 15.605330988714917, 14.65875441930318, 13.691015130576208, 12.704355072008928, 11.842953658433522, 10.911292837378987, 10.683911376917655, 9.85104302896231, 8.933699291980565, 9.764471218268627, 10.830553026926541, 11.766845100748432, 12.708938616044785, 13.546234602229498, 14.478092282508022, 15.42875423779977, 16.420010549543218, 17.274424929066917, 16.394238333306113, 15.482385906259935, 14.538175991334573, 13.74249523430122, 12.723791601155021, 11.69972081681342, 10.774273427192938, 9.836319527690693, 10.788004504258437, 10.90298352743506, 9.884866780857466, 10.70713585725602, 11.7708642383977, 12.724472961387479, 13.646104707672817, 14.548850651824806, 15.480316334303353, 16.47012540102887, 17.380562761623914, 16.267932884356807, 15.420048092800101, 14.447266671081593, 13.568975983839847, 12.714461727347182, 11.841092305021956, 10.766507268894664, 9.831101060667818, 8.88250655999037, 9.817902072234304, 10.713907713968908, 10.88628276361344, 11.720472081785724, 12.654024926555286, 13.713174956549132, 14.632036085857177, 15.605053356705426, 16.432010575966594, 17.386927493109717, 17.337837881120134, 15.301301459160369, 14.351139709777364, 13.389583698832563, 12.570773219489253, 11.770500731853785, 10.89821883715796, 9.95257421139409, 8.904831779569097, 7.903346810695654, 8.86858186668908, 9.764601256004294, 10.804468120227874, 11.585807682076414, 12.532777067851798, 13.457977511255264, 14.404040720774413, 15.38781081721051, 16.326293285193344, 17.323960398567596, 16.326189665728315, 14.451189894824722, 13.38164432296087, 12.451676367207929, 11.554677822439974, 10.72825936179546, 9.901441457581226, 8.932061962660685, 7.9246427974579445, 6.860635759055483, 7.877661365973509, 8.789217732478111, 9.77896753702321, 10.631404324050086, 11.667519284252045, 12.577926532521273, 13.431266881575239, 14.389565342449858, 15.374112754683672, 16.397693526087686, 15.419209778805643, 13.458748814598959, 12.44582338027722, 11.516209557557541, 10.623380508238027, 9.70091534992603, 8.840649066060788, 7.9237056732900495, 6.889974882465454, 5.85282182421257, 6.824179718618636, 7.781164773476878, 8.763636551090523, 9.656475713381841, 10.668392684522168, 11.549021872656517, 12.487768341601848, 13.433881318613343, 14.404127901960099, 15.369113968576324, 14.432921287393105, 12.548980620293946, 11.613918952800322, 10.576752614285923, 9.650457125019244, 8.765719666488973, 7.879486424521578, 6.874132036514669, 5.881149328145449, 4.900122361264803, 5.828899550554863, 6.738965990931876, 7.716003564512219, 8.66340498948958, 9.62623020643722, 10.61022387625932, 11.550241552241989, 12.582732572867599, 13.637219009087122, 14.483056917370243, 13.540363326440398, 11.603131352746676, 10.645097972206749, 9.649549680974816, 8.687758038202531, 7.828279642481034, 6.844035444708959, 5.892526883647849, 4.8715859054043715, 3.9671367569235954, 4.8937970309333645, 5.767127222383185, 6.766402616976189, 7.711299011662527, 8.730244402524537, 9.780226783765613, 10.727009158433544, 11.712079234754308, 12.65456865077948, 13.561276020692272, 12.654773781545831, 10.734085680811878, 9.735061476261098, 8.752998905630044, 7.761988059237685, 6.7878335963813905, 5.813728014850991, 4.843273134806678, 3.9092567469238424, 2.941834066524918, 3.8862908201793793, 4.8116409404130955, 5.747848810552879, 6.780608406414853, 7.75876138191054, 8.774270569940944, 9.78941374354451, 10.688722345982569, 11.728998463870635, 12.608520706679615, 11.674380642433299, 9.803330873292996, 8.826164116941868, 7.787842181369379, 6.804055251838208, 5.828913372909765, 4.864186480262343, 3.8844922035388905, 2.913942399255894, 1.959521198339621, 2.9975188491564557, 3.902090209629237, 4.967057925915917, 5.887780612524075, 6.727568378379447, 7.741120250142475, 8.797691866417885, 9.72569845614356, 10.710194764014565, 11.65666702626945, 10.742819412666515, 8.824866604197346, 7.877993318799212, 6.891961544797288, 5.8718711534791925, 4.805136335264153, 3.850012293475409, 2.8937111056058624, 2.041368367669823, 1.0157105351288394, 2.003753344911987, 2.89244058011268, 3.91062277020847, 4.8391919876710645, 5.779640344328258, 6.786013331494629, 7.780974130017791, 8.765505724834341, 9.730178362590328, 10.690981813533268, 9.778609021700758, 8.114049618531098, 7.0406392113905385, 6.079463178661257, 5.142547998677807, 4.068275075531334, 2.9955013344980097, 1.9411681216864345, 0.9861443899753201, 0.0, 0.9830271234927266, 1.9203587021990682, 2.974528903294517, 4.0169472794450165, 5.091078488963821, 6.153017725568456, 7.190540872966443, 8.181403990767613, 9.21361646114507, 10.11305365040698, 9.078238986419818, 9.052642330176432, 8.006700809301012, 6.956727849739794, 5.964532277922158, 4.9309509158045755, 3.904314791877339, 2.94879470968821, 1.9543946423698952, 0.995483093211026, 2.054491187188148, 2.8649418510760754, 3.8218961110009273, 4.869320690656417, 5.861110818211577, 6.846132492261716, 7.908301352141953, 8.901321867689717, 9.903735476056363, 10.916226316713292, 10.072179563873203], [11.757211773112711, 10.807567259993162, 9.814224924449173, 8.854432770907602, 7.826845699746592, 6.822147384657741, 5.871416347488312, 4.864812868619992, 3.825275064880074, 2.8805116092462972, 2.105363339857478, 2.9900860764360395, 3.9540287490764334, 4.917471690393987, 5.864646141563878, 6.835681968820541, 7.874182903231142, 8.886374862379983, 9.934922102991855, 10.954558573385624, 12.67963871206276, 11.7345546177095, 10.756097410916318, 9.697559549819687, 8.762406145094387, 7.785192932143584, 6.724167043495511, 5.788941311940819, 4.802194305308358, 3.872665312161546, 3.1434996108222353, 3.9323689720620933, 4.971092990034819, 5.869408970863591, 6.791611534376615, 7.797981415714126, 8.760941786859359, 9.805923279916865, 10.792542596956967, 11.739468985512987, 13.661242174900813, 12.735210439498314, 11.724318779830545, 10.726453422972652, 9.771509906382908, 8.77353137864289, 7.7465364936158165, 6.728496148903088, 5.758669833264516, 4.805840886706449, 4.118675463574552, 4.8698684179914125, 5.927304396219538, 6.875888392292246, 7.810842491623852, 8.848957040342336, 9.742887204469103, 10.77620155049188, 11.740216425208315, 12.677235536324677, 14.634611391934879, 13.62299187815606, 12.638775211337013, 11.688964046964939, 10.713137281403236, 9.644380798391143, 8.660761295281366, 7.661676495761592, 6.705504304468024, 5.759407237564041, 5.185439193112314, 5.882232122469854, 6.845863171133246, 7.8909717399187596, 8.755148653136239, 9.829321859476938, 10.696553420735235, 11.634683042724784, 12.632219371940117, 13.569727211675309, 15.451876925322125, 14.52949901452017, 13.561656440465843, 12.521973739586539, 11.55776687312326, 10.624118944414707, 9.635067299139687, 8.692331385516866, 7.727148755410305, 6.793401575869285, 6.1266666713134015, 6.812323876957648, 7.805291931335312, 8.817580077677299, 9.82527752781058, 10.782107883758117, 11.676766841906222, 12.596148263475238, 13.57338516801355, 14.513976321293937, 16.398919465922617, 15.529008514572343, 14.5489123114289, 13.520987109930225, 12.495318314952806, 11.55771125523761, 10.650895173235742, 9.617580026302113, 8.737367424312414, 7.771068900291283, 7.185208579405146, 7.834367453010576, 8.806651565375752, 9.778062766089908, 10.844392777504524, 11.740729312595343, 12.63249537838256, 13.644209197907209, 14.507943880537558, 15.488769720795153, 17.392121554045982, 16.542749053444513, 15.527229877169669, 14.463533669102212, 13.48726141724814, 12.60851015083761, 11.57897529365038, 10.563673973018423, 9.720218456366108, 8.706848927252727, 8.133875936626845, 8.884923467468901, 9.815404005899367, 10.7718056014047, 11.779622381704351, 12.732829122138309, 13.565329407899805, 14.57882906155377, 15.472062196246721, 16.47741613264054, 18.359327867344124, 17.436186805785308, 16.488576106880174, 15.476896589754691, 14.456139549226714, 13.488400260499741, 12.501740201932462, 11.510182755458523, 10.662034346594373, 9.723496573099789, 9.17159447874906, 9.916726415473292, 10.747498341761354, 11.813580150419268, 12.749872224241159, 13.691965739537512, 14.529261725722224, 15.461119406000748, 16.411781361292498, 17.403037673035946, 18.257452052559643, 17.377265456798842, 16.465413029752664, 15.521203114827298, 14.725522357793949, 13.70681872464775, 12.682747940306147, 11.757300550685667, 10.81934665118342, 10.123100524739945, 10.22353497722181, 10.867893904350193, 11.690162980748745, 12.753891361890425, 13.707500084880204, 14.629131831165544, 15.53187777531753, 16.46334345779608, 17.4531525245216, 18.363589885116642, 17.25096000784953, 16.40307521629283, 15.43029379457432, 14.552003107332572, 13.697488850839907, 12.824119428514683, 11.74953439238739, 10.814128184160545, 9.865533683483097, 9.152998092715812, 9.758982098704085, 10.741831168487534, 11.658838682512256, 12.592391527281817, 13.455216922584484, 14.408818696231824, 15.452030152652853, 16.44198212343558, 17.396899040578703, 18.320865004612862, 16.284328582653096, 15.334166833270091, 14.37261082232529, 13.553800342981978, 12.75352785534651, 11.881245960650688, 10.935601334886817, 9.887858903061824, 8.88637393418838, 8.130164418056927, 8.80967564073947, 9.849542504963049, 10.630882066811589, 11.577851452586973, 12.503051895990438, 13.44911510550959, 14.432885201945687, 15.37136766992852, 16.369034783302773, 17.309216789221043, 15.43421701831745, 14.364671446453597, 13.434703490700656, 12.537704945932699, 11.711286485288186, 10.884468581073952, 9.915089086153412, 8.90766992095067, 7.843662882548209, 7.139243917341355, 7.834292117213287, 8.824041921758385, 9.676478708785261, 10.712593668987221, 11.62300091725645, 12.476341266310415, 13.434639727185035, 14.419187139418849, 15.44276791082286, 16.40223690229837, 14.441775938091686, 13.428850503769947, 12.499236681050268, 11.606407631730754, 10.683942473418755, 9.823676189553513, 8.906732796782777, 7.873002005958181, 6.835848947705296, 6.085762269986482, 6.826239158212054, 7.808710935825699, 8.701550098117016, 9.713467069257344, 10.594096257391694, 11.532842726337025, 12.47895570334852, 13.449202286695275, 14.4141883533115, 15.415948410885832, 13.532007743786675, 12.59694607629305, 11.55977973777865, 10.633484248511971, 9.748746789981698, 8.862513548014304, 7.857159160007395, 6.864176451638175, 5.883149484757529, 5.014952638051201, 5.784040375667052, 6.761077949247395, 7.708479374224756, 8.671304591172397, 9.655298260994497, 10.595315936977165, 11.627806957602775, 12.654191885594393, 13.609960300420305, 14.523390449933126, 12.586158476239403, 11.628125095699476, 10.632576804467543, 9.670785161695258, 8.81130676597376, 7.827062568201685, 6.875554007140575, 5.854613028897098, 4.950163880416322, 4.079850118429703, 4.812201607118361, 5.811477001711364, 6.756373396397704, 7.7705096241497555, 8.80629015146939, 9.743982034940817, 10.729052111261579, 11.67154152728675, 12.640704686964717, 13.579951940085694, 11.717112804304605, 10.718088599753825, 9.73602602912277, 8.74501518273041, 7.770860719874117, 6.796755138343717, 5.826300258299404, 4.892283870416569, 3.9248611900176447, 3.0723439076757177, 3.8567153251482713, 4.792923195288055, 5.8256827911500295, 6.775734258417813, 7.791243446448217, 8.806386620051782, 9.70569522248984, 10.745971340377908, 11.68794937295206, 12.53068690952396, 10.786357996785723, 9.809191240434593, 8.770869304862105, 7.787082375330934, 6.8119404964024906, 5.847213603755069, 4.867519327031617, 3.8969695227486207, 2.942548321832348, 2.0733181750220337, 2.9190630861365103, 3.9840308024231907, 4.904753489031349, 5.74454125488672, 6.758093126649748, 7.814664742925158, 8.742671332650831, 9.727167640521838, 10.673639902776722, 11.599125679757176, 9.807893727690074, 8.861020442291938, 7.8749886682900145, 6.854898276971919, 5.7881634587568795, 4.833039416968135, 3.8767382290985886, 3.02439549116255, 1.998737658621566, 1.0418526143352815, 1.9094134566199532, 2.9275956467157433, 3.856164864178338, 4.796613220835531, 5.802986208001902, 6.797947006525064, 7.782478601341613, 8.747151239097601, 9.707954690040541, 10.707795057372039, 9.097076742023821, 8.023666334883263, 7.062490302153982, 6.125575122170532, 5.051302199024059, 3.978528457990736, 2.9241952451791606, 1.9691715134680465, 0.9830271234927266, 0.0, 0.9373315787063417, 1.9915017798017902, 3.0339201559522895, 4.108051365471094, 5.169990602075729, 6.207513749473716, 7.198376867274886, 8.230589337652344, 9.272679091326632, 10.061266109912541, 10.03566945366916, 8.98972793279374, 7.939754973232521, 6.947559401414885, 5.913978039297302, 4.887341915370065, 3.931821833180936, 2.937421765862622, 1.9785102167037527, 1.0714640636954216, 1.8819147275833488, 2.8388689875082007, 3.8862935671636896, 4.87808369471885, 5.863105368768989, 6.925274228649226, 7.91829474419699, 8.920708352563636, 9.933199193220565, 10.911299146189647], [10.81988019440637, 9.87023568128682, 8.87689334574283, 7.91710119220126, 6.889514121040251, 5.8848158059514, 4.934084768781971, 3.9274812899136498, 2.8879434861737328, 1.9431800305399558, 2.9307458674772056, 3.9274176551423814, 4.891360327782776, 5.854803269100329, 6.80197772027022, 7.773013547526883, 8.811514481937483, 9.823706441086323, 10.872253681698195, 11.859691940696624, 11.742307133356418, 10.797223039003159, 9.818765832209976, 8.760227971113345, 7.825074566388044, 6.847861353437242, 5.786835464789169, 4.851609733234477, 3.8648627266020172, 2.9353337334552045, 3.889438991463985, 4.819072000865249, 5.857796018837974, 6.806740549569933, 7.7289431130829565, 8.735312994420468, 9.6982733655657, 10.743254858623207, 11.729874175663308, 12.676800564219329, 12.760028396619113, 11.797878860791972, 10.786987201124203, 9.78912184426631, 8.834178327676565, 7.836199799936547, 6.809204914909475, 5.791164570196746, 4.821338254558174, 3.8685093080001067, 4.864614844216301, 5.756571446794568, 6.814007425022694, 7.762591421095401, 8.735591310962167, 9.786288619048678, 10.680218783175444, 11.713533129198222, 12.677548003914657, 13.614567115031019, 13.724068452147696, 12.685660299449719, 11.70144363263067, 10.751632468258597, 9.775805702696895, 8.707049219684801, 7.7234297165750245, 6.72434491705525, 5.768172725761682, 4.822075658857699, 5.867949669739595, 6.768935151273009, 7.732566199936401, 8.777674768721914, 9.679897472474554, 10.754070678815253, 11.633884999441577, 12.572014621431126, 13.569550950646459, 14.50705879038165, 14.623851635107822, 13.592167435813828, 12.6243248617595, 11.584642160880197, 10.620435294416918, 9.686787365708366, 8.697735720433345, 7.754999806810524, 6.789817176703963, 5.856069997162943, 6.809177147940682, 7.699026905760803, 8.691994960138468, 9.704283106480453, 10.750026347148896, 11.706856703096433, 12.614098420612564, 13.53347984218158, 14.510716746719892, 15.451307900000279, 15.546882937362732, 14.591676935866001, 13.611580732722558, 12.583655531223883, 11.557986736246464, 10.620379676531268, 9.7135635945294, 8.68024844759577, 7.800035845606071, 6.833737321584941, 7.768327310442736, 8.721070481813731, 9.693354594178906, 10.664765794893063, 11.731095806307678, 12.665478131933659, 13.569826957088901, 14.58154077661355, 15.4452754592439, 16.426101299501497, 16.540085025486096, 15.605417474738172, 14.589898298463327, 13.52620209039587, 12.549929838541798, 11.671178572131268, 10.641643714944038, 9.626342394312081, 8.782886877659767, 7.769517348546385, 8.716994667664435, 9.682775671451965, 10.613256209882431, 11.658508630207855, 12.666325410507506, 13.645035069011564, 14.502660986606147, 15.516160640260113, 16.409393774953063, 17.41474771134688, 17.48952280997772, 16.498855227078966, 15.551244528173834, 14.53956501104835, 13.518807970520372, 12.5510686817934, 11.56440862322612, 10.572851176752181, 9.724702767888031, 8.786164994393447, 9.754713209786651, 10.71039167903364, 11.545350545744418, 12.611432354402332, 13.595707428794467, 14.53780094409082, 15.466593304428566, 16.39845098470709, 17.34911293999884, 18.34036925174229, 18.418122866081877, 17.48298392938753, 16.50419891529078, 15.576936991917604, 14.55019580388727, 13.533111744493041, 12.569042878421628, 11.641531407992765, 10.713930041530388, 9.7492270447428, 9.801268149231792, 10.805915572537167, 11.734843328335618, 12.61265897110694, 13.506587339039795, 14.444326744358579, 15.4489752694461, 16.392406009590143, 17.407489885236988, 18.466820628861097, 18.18829158655587, 17.34040679499917, 16.36762537328066, 15.489334686038914, 14.601498390868908, 13.688448858827146, 12.613863822699853, 11.678457614473007, 10.71036362450943, 9.774968112265496, 8.821650519997743, 9.804499589781193, 10.721507103805914, 11.655059948575476, 12.517885343878142, 13.471487117525482, 14.51469857394651, 15.504650544729238, 16.45956746187236, 17.44380080559915, 17.221660161359434, 16.27149841197643, 15.309942401031632, 14.49113192168832, 13.65753739537551, 12.74557539096315, 11.79993076519928, 10.752188333374287, 9.750703364500843, 8.884175255546497, 7.872344062033128, 8.912210926256707, 9.693550488105247, 10.640519873880631, 11.565720317284097, 12.511783526803248, 13.495553623239346, 14.434036091222179, 15.431703204596431, 16.43215259020733, 16.37154859702379, 15.302003025159939, 14.372035069406998, 13.475036524639041, 12.615296025317186, 11.748828642372992, 10.779418516465874, 9.771999351263133, 8.707992312860672, 7.8932547548309255, 6.896960538506945, 7.8867103430520435, 8.73914713007892, 9.775262090280878, 10.685669338550108, 11.539009687604073, 12.497308148478693, 13.481855560712507, 14.505436332116519, 15.505533342769523, 15.379107516798028, 14.36618208247629, 13.43656825975661, 12.543739210437096, 11.587952013447754, 10.71869802138976, 9.77106222709524, 8.737331436270642, 7.700178378017758, 6.85815222898641, 5.888907579505712, 6.871379357119357, 7.764218519410674, 8.776135490551, 9.656764678685352, 10.595511147630683, 11.541624124642178, 12.511870707988933, 13.476856774605158, 14.519244851356985, 14.469339322493017, 13.534277654999391, 12.497111316484991, 11.570815827218313, 10.652756330010698, 9.75753537985055, 8.721488590319858, 7.728505881950637, 6.7474789150699905, 5.787342597051129, 4.84670879696071, 5.823746370541053, 6.771147795518414, 7.733973012466055, 8.717966682288155, 9.657984358270824, 10.690475378896434, 11.716860306888051, 12.672628721713963, 13.615322312643809, 13.523490054945745, 12.565456674405818, 11.569908383173885, 10.6081167404016, 9.715316306002759, 8.731072108230686, 7.763297071157261, 6.7189424592095595, 5.814493310728784, 4.852240077429631, 3.874870028412019, 4.8741454230050225, 5.819041817691362, 6.833178045443414, 7.868958572763049, 8.806650456234477, 9.791720532555237, 10.734209948580409, 11.703373108258376, 12.64262036137935, 12.559053135861399, 11.655420178460167, 10.673357607829113, 9.682346761436753, 8.674870259903116, 7.700764678372717, 6.7303097983284035, 5.756613300729031, 4.789190620330107, 3.8447338666756457, 2.9193837464419294, 3.8555916165817132, 4.888351212443688, 5.838402679711471, 6.853911867741875, 7.869055041345441, 8.768363643783498, 9.808639761671566, 10.750617794245716, 11.593355330817616, 11.630851969342029, 10.746522819140935, 9.708200883568447, 8.724413954037276, 7.749272075108832, 6.751223143784069, 5.771528867060616, 4.7895149196257, 3.8350937187094267, 2.934705806402249, 1.9817315074301687, 3.046699223716849, 3.9674219103250072, 4.807209676180378, 5.820761547943406, 6.8773331642188165, 7.805339753944489, 8.789836061815496, 9.736308324070379, 10.661794101050832, 10.724205896169106, 9.798352020998278, 8.812320246996356, 7.7922298556782605, 6.725495037463221, 5.770370995674477, 4.81406980780493, 3.916940888039629, 2.891283055498645, 1.903240245715497, 0.9720818779136116, 1.9902640680094015, 2.918833285471996, 3.859281642129189, 4.86565462929556, 5.860615427818722, 6.845147022635271, 7.809819660391258, 8.770623111334197, 9.770463478665695, 10.034408320730163, 8.960997913589605, 7.999821880860324, 7.062906700876874, 5.988633777730401, 4.915860036697078, 3.8615268238855025, 2.9065030921743884, 1.9203587021990682, 0.9373315787063417, 0.0, 1.0541702010954486, 2.0965885772459476, 3.170719786764752, 4.232659023369387, 5.270182170767374, 6.261045288568544, 7.293257758946002, 8.33534751262029, 9.370162176607453, 10.973001032375501, 9.927059511500081, 8.877086551938863, 7.884890980121227, 6.8513096180036435, 5.824673494076407, 4.869153411887278, 3.8747533445689633, 2.915841795410094, 1.984130652085156, 0.9445831488770072, 1.9015374088018593, 2.9489619884573486, 3.940752116012509, 4.925773790062648, 5.987942649942885, 6.980963165490649, 7.983376773857296, 8.995867614514225, 9.973967567483307], [9.881798408617323, 8.932153895497773, 7.938811559953785, 6.979019406412213, 5.951432335251202, 4.946734020162352, 3.996002982992923, 2.989399504124602, 1.9498617003846848, 2.9190067646006117, 3.906572601537861, 4.933048191824012, 5.8969908644644065, 6.886983763106509, 7.843583293961087, 8.81461912121775, 9.853120055628349, 10.865312014777189, 11.913859255389061, 10.921610154907578, 10.80422534756737, 9.85914125321411, 8.880684046420928, 7.822146185324296, 6.886992780598996, 5.909779567648195, 4.848753679000121, 3.91352794744543, 2.9267809408129692, 3.9111604675158604, 4.86526572552464, 5.794898734925904, 6.83362275289863, 7.814899229263382, 8.770548686773823, 9.776918568111334, 10.739878939256567, 11.784860432314073, 12.69174184232727, 11.744815453771249, 11.821946610830064, 10.859797075002923, 9.848905415335155, 8.851040058477261, 7.896096541887517, 6.898118014147499, 5.872355350487871, 4.8720315666114455, 3.9022052509728744, 4.844336042060763, 5.840441578276956, 6.732398180855223, 7.789834159083349, 8.738418155156056, 9.711418045022823, 10.767690025595542, 11.72182435686631, 12.755138702889088, 13.68378533979402, 12.682582004582938, 12.785986666358648, 11.74757851366067, 10.763361846841622, 9.813550682469549, 8.849046437952186, 7.813411430184525, 6.829791927074748, 5.8397071655433965, 4.883534974249828, 5.797902392918355, 6.843776403800251, 7.744761885333665, 8.708392933997056, 9.75350150278257, 10.65572420653521, 11.729897412875907, 12.675490573132443, 13.613620195121992, 14.60694391647797, 13.669436076742778, 13.712931326546592, 12.681247127252595, 11.713404553198268, 10.700004409368344, 9.735797542905065, 8.802149614196512, 7.8130979689214906, 6.870362055298671, 5.9051794251921095, 6.831896731223599, 7.785003882001337, 8.674853639821459, 9.667821694199123, 10.680109840541109, 11.725853081209552, 12.682683437157088, 13.65570399430343, 14.575085415872445, 15.552322320410758, 14.65083193057478, 14.635962628801499, 13.680756627304769, 12.726942981210705, 11.69901777971203, 10.673348984734611, 9.735741925019415, 8.828925843017547, 7.7956106960839175, 6.9153980940942175, 7.809564055645597, 8.744154044503391, 9.696897215874387, 10.669181328239562, 11.640592528953718, 12.706922540368332, 13.641304865994314, 14.611432530779767, 15.623146350304417, 16.486881032934768, 15.566590739512417, 15.629164716924862, 14.694497166176939, 13.705260546951473, 12.641564338884017, 11.665292087029945, 10.786540820619415, 9.757005963432185, 8.741704642800228, 7.898249126147913, 8.745344082607042, 9.69282140172509, 10.658602405512621, 11.589082943943087, 12.63433536426851, 13.642152144568161, 14.62086180307222, 15.544266560297013, 16.557766213950977, 17.450999348643933, 16.555633027430794, 16.596371030223004, 15.614217475567115, 14.66660677666198, 13.654927259536496, 12.634170219008519, 11.666430930281546, 10.679770871714267, 9.688213425240328, 8.840065016376178, 9.761991728454104, 10.730539943847306, 11.106452691039102, 11.747217740882146, 12.676466937503363, 13.591899015148517, 14.443258664554332, 15.390583254452991, 16.322440934731514, 17.34769645473988, 17.563978332162723, 17.52497108632716, 16.59834617787568, 15.619561163778927, 14.69229924040575, 13.665558052375417, 12.648473992981188, 11.684405126909775, 10.756893656480912, 9.915038326064472, 10.725053778803458, 10.786043951412985, 10.1552852021622, 10.804553101894752, 11.682368744666075, 12.57629711259893, 13.506092572926299, 14.51074109801382, 15.454171838157865, 16.456163962453445, 17.49561059851592, 17.402325298042072, 17.57253641838169, 16.65468039895727, 15.639847436428497, 14.656456350272464, 13.660270093327444, 12.617618674828531, 11.700066023006034, 10.868851293764795, 10.75974391444669, 9.806426322178936, 9.153869219406227, 9.791216877365049, 10.72476972213461, 11.587595117437276, 12.52016119474194, 13.563372651162968, 14.553324621945695, 15.508241539088818, 16.430146433925927, 16.435693872845636, 17.28179829286669, 16.32024228192189, 15.497814579691207, 14.642313197556703, 13.730351193144344, 12.784706567380473, 11.736964135555482, 10.735479166682039, 9.86895105772769, 8.857119864214322, 8.123507561310953, 8.763260261664382, 9.710229647439766, 10.635430090843231, 11.560457604019705, 12.544227700455803, 13.482710168438636, 14.480377281812888, 15.418498218534106, 15.481120778494176, 16.312302906050196, 15.382334950297254, 14.481719182641928, 13.600071827498379, 12.733604444554185, 11.764194318647068, 10.756775153444329, 9.692768115041867, 8.878030557012119, 7.881736340688138, 7.098006978106289, 7.808856903638054, 8.844971863840014, 9.734343415766565, 10.58768376482053, 11.54598222569515, 12.530529637928964, 13.554110409332976, 14.486036006953851, 14.47391998833546, 15.376481963366546, 14.446868140646867, 13.550421868439983, 12.572727815628948, 11.703473823570953, 10.755838029276433, 9.722107238451839, 8.684954180198954, 7.842928031167604, 6.873683381686906, 6.055989008776043, 6.8339282929698095, 7.845845264110136, 8.70543875590181, 9.64418522484714, 10.590298201858635, 11.56054478520539, 12.525530851821616, 13.499747515541314, 13.476080689571031, 14.437310439131645, 13.507411197375248, 12.58111570810857, 11.637532132191891, 10.742311182031743, 9.706264392501051, 8.71328168413183, 7.732254717251186, 6.7721183992323235, 5.831484599141904, 5.008356022197739, 5.840857569077549, 6.80368278602519, 7.766640759504613, 8.706658435487281, 9.717236578541442, 10.662690105792606, 11.618458520618514, 12.56115211154836, 12.53023142202376, 13.488264802563688, 12.580208264064142, 11.618416621291857, 10.700092108183952, 9.715847910411878, 8.748072873338455, 7.703718261390754, 6.799269112909979, 5.837015879610825, 4.859645830593212, 4.0587550746617085, 4.881855894334211, 5.779007844347965, 6.8147883716676, 7.752480255139028, 8.737550331459792, 9.680039747484964, 10.649202907162927, 11.588450160283903, 11.504882934765952, 12.57258522645456, 11.68365748871937, 10.69264664232701, 9.65964606208431, 8.68554048055391, 7.715085600509597, 6.741389102910225, 5.773966422511301, 4.82950966885684, 3.9041595486231233, 3.011334036139179, 3.951165289086537, 4.784232478616023, 5.799741666646426, 6.814884840249992, 7.714193442688052, 8.754469560576117, 9.69644759315027, 10.539185129722169, 10.576681768246582, 11.606184302688796, 10.718500764458703, 9.734713834927533, 8.734955425466088, 7.735998945965262, 6.75630466924181, 5.774290721806893, 4.81986952089062, 3.9194816085834425, 2.9665073096113623, 2.007547123237544, 2.9132517092295585, 3.753039475084929, 4.7665913468479575, 5.823162963123368, 6.751169552849042, 7.735665860720048, 8.682138122974932, 9.607623899955385, 9.670035695073658, 10.616908980471793, 9.866490448091806, 8.84640005677371, 7.77966523855867, 6.824541196769926, 5.868240008900379, 4.901716690220822, 3.8760588576798383, 2.8880160478966905, 1.9568576800948052, 0.936093866913953, 1.8646630843765475, 2.8051114410337408, 3.811484428200112, 4.806445226723274, 5.790976821539823, 6.75564945929581, 7.71645291023875, 8.716293277570246, 9.280181343400724, 10.015168114685054, 9.053992081955773, 8.117076901972322, 7.04280397882585, 5.9700302377925265, 4.915697024980951, 3.9606732932698367, 2.974528903294517, 1.9915017798017902, 1.0541702010954486, 0.0, 1.0424183761504993, 2.1165495856693037, 3.1784888222739385, 4.216011969671925, 5.206875087473096, 6.239087557850553, 7.281177311524841, 8.315991975512004, 10.055423015391028, 10.98122971259553, 9.931256753034312, 8.939061181216676, 7.905479819099092, 6.878843695171856, 5.923323612982727, 4.9289235456644125, 3.970011996505543, 2.959957386145812, 1.9204098829376632, 0.9634556230128113, 2.0108802026683, 3.0026703302234607, 3.9876920042735997, 5.049860864153837, 6.042881379701601, 7.045294988068248, 8.057785828725176, 9.035885781694258], [8.899326545222564, 7.949682032103014, 6.9563396965590245, 5.996547543017453, 4.968960471856443, 3.964262156767592, 3.0135311195981624, 2.030028835359631, 2.992280076535184, 3.9614251407511114, 4.948990977688361, 5.975466567974513, 6.939409240614907, 7.92940213925701, 8.886001670111588, 9.85703749736825, 10.89553843177885, 11.90773039092769, 10.958774761906588, 9.939138291512819, 9.870802011136428, 8.925717916783169, 7.95023047366053, 6.891692612563899, 5.956539207838599, 5.010217463198692, 3.9534243236760997, 3.030397102702771, 3.9691993169634685, 4.95357884366636, 5.90768410167514, 6.837317111076404, 7.8760411290491295, 8.857317605413881, 9.812967062924324, 10.819336944261835, 11.782297315407067, 12.744937822936429, 11.758318505896328, 10.811392117340308, 10.888523274399123, 9.926373738571982, 8.918451842574758, 7.920586485716864, 6.96564296912712, 5.998555909697997, 4.977025995163849, 4.079619580276249, 4.944623627123374, 5.886754418211263, 6.882859954427456, 7.774816557005723, 8.832252535233849, 9.780836531306557, 10.753836421173324, 11.810108401746042, 12.764242733016811, 13.714376878079515, 12.75036200336308, 11.749158668151997, 11.85553309359825, 10.817124940900273, 9.832908274081225, 8.883097109709151, 7.918592865191789, 6.918082074860503, 5.934462571750726, 5.1365702428352735, 5.925953350400327, 6.840320769068855, 7.886194779950751, 8.787180261484163, 9.750811310147554, 10.795919878933068, 11.69814258268571, 12.772315789026408, 13.717908949282943, 14.656038571272493, 13.673520580047029, 12.736012740311837, 12.782477753786193, 11.750793554492198, 10.782950980437871, 9.81994519583596, 8.85573832937268, 7.922090400664128, 6.9445152449537115, 6.1672251325905485, 6.947597801342608, 7.874315107374099, 8.827422258151838, 9.717272015971957, 10.710240070349622, 11.722528216691607, 12.768271457360052, 13.725101813307589, 14.69812237045393, 15.617503792022946, 14.660969511094768, 13.720378357814381, 13.705509056041102, 12.750303054544371, 11.829649309380248, 10.818958566179646, 9.793289771202227, 8.855682711487031, 8.00693172636903, 7.092473773375795, 7.957816470244716, 8.851982431796097, 9.786572420653892, 10.739315592024886, 11.71159970439006, 12.683010905104217, 13.749340916518833, 14.683723242144815, 15.653850906930268, 16.53209343411618, 15.595528223618777, 14.63613716675202, 14.698711144164465, 13.764043593416542, 12.82520133341909, 11.761505125351633, 10.785232873497561, 9.90648160708703, 9.013278530183815, 8.038567720092106, 8.940667502298412, 9.787762458757541, 10.735239777875591, 11.701020781663122, 11.809481982577068, 12.855319648658982, 13.692318763518262, 14.58940904116677, 15.484685478108347, 16.397832389282343, 16.55964653932794, 15.625179454670395, 15.665917457462607, 14.74488843893477, 13.797277740029637, 12.785598222904152, 11.840899502480417, 10.891944282929037, 9.966845871008559, 8.985076502532205, 9.882483392526677, 10.804410104604603, 11.772958319997807, 11.807523295331732, 10.877387646715082, 11.8066368433363, 12.722068920981455, 13.573428570387268, 14.520753160285928, 15.452610840564452, 16.47786636057282, 16.633524759402324, 16.594517513566764, 15.729017141243336, 14.750232127146583, 13.852753220284496, 12.872287335847314, 11.873987345628679, 10.971480126204067, 10.05375673377279, 10.957456702214971, 11.767472154953957, 11.773352292171108, 10.85635580645483, 9.934723007727689, 10.812538650499011, 11.706467018431868, 12.636262478759235, 13.640911003846757, 14.584341743990802, 15.586333868286383, 16.625780504348853, 16.53249520387501, 16.703207381749348, 15.785351362324926, 14.821953227779222, 13.881969702919955, 12.885783445974935, 11.904693674122823, 10.996929100297912, 11.911269669915294, 11.747052255204812, 10.793734662937059, 9.854939823698857, 8.921386783197985, 9.854939627967546, 10.717765023270214, 11.650331100574876, 12.693542556995904, 13.683494527778631, 14.638411444921754, 15.560316339758861, 15.565863778678573, 16.43581974995876, 16.77561562465863, 15.767829178186586, 14.825930698413352, 13.788155503600933, 12.842510877837062, 11.923198381396633, 11.722787507440161, 10.856259398485813, 9.844428204972445, 8.824578165603583, 7.893430167497319, 8.840399553272704, 9.765599996676169, 10.690627509852641, 11.67439760628874, 12.612880074271573, 13.610547187645825, 14.548668124367042, 14.611290684327113, 15.466324363142268, 16.36964329105538, 15.469027523400054, 14.587380168256503, 13.720912785312311, 12.751502659405194, 11.744083494202451, 10.68007645579999, 9.865338897770242, 8.869044681446262, 8.006968186844427, 6.939026809470991, 7.97514176967295, 8.864513321599501, 9.717853670653467, 10.676152131528086, 11.6606995437619, 12.684280315165912, 13.616205912786787, 13.604089894168396, 14.530503420458619, 15.434176481404991, 14.537730209198108, 13.560036156387072, 12.690782164329079, 11.743146370034559, 10.709415579209962, 9.672262520957077, 8.830236371925729, 7.86099172244503, 6.964950217514181, 5.964098198802747, 6.976015169943073, 7.835608661734746, 8.774355130680076, 9.720468107691572, 10.690714691038327, 11.655700757654552, 12.62991742137425, 12.606250595403967, 13.567480344964581, 14.494719538133372, 13.568424048866694, 12.624840472950016, 11.72961952278987, 10.693572733259177, 9.700590024889957, 8.71956305800931, 7.759426739990448, 6.818792939900029, 5.917317230935876, 4.971027474910486, 5.933852691858127, 6.896810665337549, 7.836828341320217, 8.847406484374378, 9.792860011625542, 10.74862842645145, 11.691322017381296, 11.660401327856695, 12.618434708396622, 13.567516604822266, 12.605724962049981, 11.687400448942077, 10.703156251170002, 9.73538121409658, 8.69102660214888, 7.786577453668103, 6.82432422036895, 5.846954171351338, 4.967716283399846, 4.012025800167148, 4.909177750180901, 5.944958277500536, 6.882650160971965, 7.867720237292728, 8.8102096533179, 9.779372812995863, 10.718620066116838, 10.635052840598886, 11.702755132287495, 12.670965829477494, 11.679954983085134, 10.646954402842434, 9.672848821312034, 8.702393941267722, 7.7286974436683495, 6.761274763269426, 5.816818009614964, 4.891467889381248, 3.9986423768973047, 3.0813351949194736, 3.9144023844489584, 4.929911572479362, 5.945054746082929, 6.8443633485209885, 7.884639466409054, 8.826617498983204, 9.669355035555103, 9.706851674079516, 10.73635420852173, 11.705809105216828, 10.722022175685657, 9.722263766224213, 8.723307286723387, 7.743613009999934, 6.7615990625650175, 5.807177861648745, 4.906789949341568, 3.9538156503694877, 2.9948554639956697, 2.043421615062495, 2.883209380917865, 3.8967612526808937, 4.953332868956304, 5.881339458681978, 6.865835766552984, 7.812308028807867, 8.73779380578832, 8.800205600906594, 9.74707888630473, 10.733110660306652, 9.88366032625727, 8.816925508042232, 7.861801466253487, 6.905500278383941, 5.889025030978947, 4.863367198437963, 3.875324388654816, 2.9441660208529306, 1.9234022076720785, 0.994832990209484, 1.9352813468666772, 2.941654334033048, 3.93661513255621, 4.92114672737276, 5.8858193651287465, 6.846622816071686, 7.846463183403182, 8.237762967250225, 9.311173374390783, 10.096410458106273, 9.159495278122822, 8.08522235497635, 7.012448613943026, 5.958115401131451, 5.0030916694203365, 4.0169472794450165, 3.0339201559522895, 2.0965885772459476, 1.0424183761504993, 0.0, 1.0741312095188045, 2.1360704461234397, 3.173593593521426, 4.164456711322597, 5.196669181700054, 6.238758935374342, 7.273573599361505, 9.072951151996268, 10.118892672871688, 10.973675129184812, 9.981479557367177, 8.947898195249593, 7.921262071322356, 6.965741989133226, 5.971341921814911, 5.012430372656042, 4.002375762296311, 2.9628282590881625, 2.0058739991633106, 1.0284083392735397, 2.0201984668287003, 3.0052201408788393, 4.067389000759077, 5.060409516306841, 6.062823124673487, 7.075313965330416, 8.053413918299498], [7.894384875883166, 6.944740362763615, 5.951398027219626, 4.991605873678054, 3.964018802517045, 2.959320487428194, 2.0085894502587647, 3.0086674211305544, 4.040877582071826, 5.010022646287753, 5.997588483225003, 7.024064073511154, 7.988006746151548, 8.97799964479365, 9.934599175648227, 10.905635002904889, 11.94413593731549, 11.002380333179062, 9.953833092567189, 8.93419662217342, 8.865860341797031, 7.920776247443771, 6.945288804321132, 5.886750943224501, 4.951597538499201, 4.005275793859294, 2.948482654336702, 3.8837083858913934, 4.870455392523854, 5.891571421719404, 6.845676679728184, 7.775309689129448, 8.814033707102173, 9.795310183466924, 10.833831620161558, 11.840201501499068, 12.78497764665454, 11.739996153597033, 10.753376836556932, 9.806450448000911, 9.883581605059726, 8.921432069232583, 7.913510173235359, 6.915644816377466, 5.960701299787722, 4.993614240358599, 3.9720843258244516, 4.932930863464872, 5.845879702683759, 6.798708649241827, 7.8208525324805, 8.712809135058766, 9.770245113286892, 10.7188291093596, 11.691828999226367, 12.748100979799085, 13.759867137214957, 12.709435208740118, 11.745420334023683, 10.7442169988126, 10.850591424258852, 9.812183271560874, 8.827966604741826, 7.878155440369754, 6.91365119585239, 5.913140405521105, 4.929520902411328, 5.928605701931103, 6.827209425960713, 7.752275000099419, 8.798149010981316, 9.725172839537207, 10.688803888200598, 11.733912456986111, 12.636135160738753, 13.710308367079453, 14.604244861912514, 13.666115239922965, 12.668578910707632, 11.73107107097244, 11.777536084446794, 10.745851885152799, 9.778009311098472, 8.815003526496563, 7.850796660033284, 6.917148731324731, 5.939573575614314, 6.882309489237134, 7.848853876902994, 8.786269338404663, 9.739376489182403, 10.655264594025, 11.648232648402665, 12.66052079474465, 13.706264035413096, 14.663094391360632, 15.584458283083501, 14.627580460673418, 13.65602784175537, 12.715436688474982, 12.700567386701703, 11.745361385204973, 10.824707640040849, 9.814016896840249, 8.788348101862828, 7.850741042147632, 7.001990057029634, 7.807558130022381, 8.780470990457935, 9.763936662826662, 10.698526651684457, 11.677308170077929, 12.649592282443104, 13.145154922220213, 13.988194285884783, 14.704251523015824, 15.54026217993168, 15.52715176477678, 14.590586554279378, 13.631195497412621, 13.693769474825066, 12.759101924077143, 11.82025966407969, 10.756563456012234, 9.780291204158162, 8.901539937747632, 8.008336860844418, 8.75365207673869, 9.711808141113378, 10.699716689788106, 11.647194008906157, 12.612975012693687, 12.775833336865404, 12.15141208690542, 12.930058091360383, 13.712151713472858, 14.607428150414435, 15.520575061588431, 15.55470486998854, 14.620237785330996, 14.660975788123208, 13.739946769595372, 12.792336070690238, 11.780656553564754, 10.835957833141018, 9.887002613589639, 8.961904201669162, 9.70016085917879, 10.653624031341643, 11.620826500884183, 12.6804287101212, 12.773874649620065, 11.843739001003417, 11.083251857325072, 11.959808248823576, 12.696171242693357, 13.643495832592016, 14.57535351287054, 15.600609032878907, 15.628583090062925, 15.589575844227365, 14.724075471903937, 13.745290457807185, 12.847811550945098, 11.867345666507916, 10.86904567628928, 9.96653845686467, 10.768841090419375, 11.728597341029937, 12.583888551233537, 12.775847841222818, 11.822707160743164, 10.901074362016024, 10.089153664487784, 10.944206346273988, 11.759005151065324, 12.763653676152845, 13.70708441629689, 14.709076540592472, 15.724156619547156, 15.630871319073307, 15.698265712409949, 14.780409692985527, 13.817011558439823, 12.877028033580556, 11.880841776635537, 10.899752004783426, 11.712013456944497, 12.681815148857796, 12.749547804256522, 11.79623021198877, 10.82129117798719, 9.88773813748632, 9.131554641956319, 9.955504351112335, 10.773073772880965, 11.816285229301993, 12.80623720008472, 13.761154117227843, 14.658692454957162, 14.664239893876871, 15.534195865157061, 15.77067395531923, 14.762887508847188, 13.820989029073953, 12.783213834261536, 11.837569208497666, 12.638282738043218, 12.726426893060639, 11.85989878410629, 10.846923754024155, 9.790929519891916, 8.859781521785653, 8.085155764984075, 9.00333932451829, 9.81337018215873, 10.797140278594828, 11.735622746577661, 12.733289859951913, 13.647044239565343, 13.709666799525412, 14.564700478340567, 15.493960168026984, 15.748317747813804, 14.81504548686539, 13.827491583138187, 12.858081457231071, 12.747722879822929, 11.683715841420467, 10.86897828339072, 9.87268406706674, 8.973319541132762, 7.905378163759326, 7.10347970759183, 7.98725599390559, 8.840596342959556, 9.798894803834175, 10.78344221606799, 11.807022987472001, 12.714582027985088, 12.702466009366697, 13.628879535656917, 14.558493358376596, 15.541369594818581, 14.563675542007546, 13.694421549949553, 12.746785755655033, 11.71305496483044, 10.675901906577554, 9.833875757546204, 8.864631108065506, 7.931301571802516, 6.930449553091082, 6.104353107861953, 6.9583513340408345, 7.897097802986165, 8.84321077999766, 9.813457363344416, 10.77844342996064, 11.72829353657255, 11.704626710602266, 12.66585646016288, 13.639562048137961, 14.572063434487168, 13.62847985857049, 12.733258908410344, 11.697212118879651, 10.704229410510433, 9.723202443629786, 8.763066125610923, 7.822432325520505, 6.883668585224211, 5.937378829198821, 5.062190629777007, 6.019553337643638, 6.959571013626306, 7.94578259957268, 8.891236126823841, 9.847004541649751, 10.789698132579597, 10.758777443054996, 11.716810823594923, 12.712359114826855, 13.609364347670455, 12.69103983456255, 11.706795636790476, 10.739020599717056, 9.694665987769355, 8.790216839288579, 7.827963605989425, 6.8505935569718135, 5.934067637688181, 4.978377154455483, 4.03192042248699, 5.067700949806625, 6.005392833278053, 6.966096352491029, 7.9085857685161995, 8.877748928194164, 9.816996181315139, 9.733428955797187, 10.801131247485795, 11.78319381811685, 12.683594368705608, 11.650593788462908, 10.676488206932508, 9.706033326888196, 8.732336829288826, 7.764914148889901, 6.82045739523544, 5.895107275001724, 5.000486016994453, 4.047686549207809, 3.037145056755047, 4.052654244785451, 5.067797418389017, 5.942739463719289, 6.983015581607355, 7.924993614181505, 8.767731150753404, 8.805227789277817, 9.83473032372003, 10.873052259292521, 11.725661561306131, 10.725903151844687, 9.72694667234386, 8.747252395620409, 7.765238448185492, 6.810817247269219, 5.910429334962043, 4.9574550359899625, 3.9966991040928184, 3.0391702765224906, 2.005952053223954, 3.0195039249869824, 4.076075541262393, 4.979715573880279, 5.964211881751285, 6.910684144006168, 7.83616992098662, 7.898581716104894, 8.845455001503028, 9.83148677550495, 10.851577166823047, 9.820564893662706, 8.865440851873961, 7.909139664004416, 6.8926644165994215, 5.867006584058438, 4.878963774275291, 3.9478054064734054, 2.9270415932925533, 1.9984723758299587, 1.0580240191727655, 2.0546792746570217, 3.0349912477545105, 4.01952284257106, 4.984195480327047, 5.9449989312699865, 6.944839298601483, 7.163631757731421, 8.23704216487198, 9.19821819760126, 10.135133377584712, 9.159353564495154, 8.08657982346183, 7.032246610650255, 6.07722287893914, 5.09107848896382, 4.108051365471094, 3.170719786764752, 2.1165495856693037, 1.0741312095188045, 0.0, 1.061939236604635, 2.0994623840026216, 3.0903255018037927, 4.12253797218125, 5.164627725855539, 6.199442389842702, 8.06800948265687, 9.11395100353229, 10.163923963093508, 11.055610766885978, 10.022029404768395, 8.995393280841158, 8.03987319865203, 7.045473131333715, 6.086561582174846, 5.050973267832953, 4.011425764624804, 3.0544715046999524, 2.007046925044463, 1.0152567974893025, 2.0002784715394415, 3.062447331419679, 4.055467846967443, 5.0578814553340905, 6.070372295991019, 7.048472248960101], [6.833948029072181, 5.88430351595263, 4.890961180408641, 3.9311690268670696, 2.9889719391651717, 1.9842736240763208, 2.9985555269981585, 4.003663905878959, 5.035874066820231, 6.005019131036158, 6.992584967973407, 8.019060558259559, 8.983003230899953, 9.972996129542055, 10.929595660396632, 11.900631487653294, 10.954135445516918, 9.941943486368077, 8.893396245756204, 7.873759775362435, 7.805423494986046, 6.860339400632786, 5.921767491417483, 4.871567105855013, 3.976550675147328, 3.0302289305074206, 3.938448731076096, 4.873674462630787, 5.8604214692632475, 6.881537498458798, 7.8356427564675775, 8.765275765868841, 9.803999783841567, 10.785276260206318, 11.823797696900952, 12.687501170988785, 11.724540799843552, 10.679559306786047, 9.692939989745947, 8.746013601189926, 8.823144758248741, 7.860995222421599, 6.898326335865871, 5.9004609790079785, 4.985654436435849, 4.018567377006725, 4.962050402563846, 5.922896940204266, 6.835845779423153, 7.78867472598122, 8.810818609219893, 9.70277521179816, 10.760211190026286, 11.708795186098994, 12.681795075965761, 13.73806705653848, 12.699430290403972, 11.648998361929133, 10.684983487212698, 9.683780152001615, 9.835407586889364, 8.796999434191386, 7.8127827673723385, 6.862971603000266, 5.938604332500518, 5.042338803092666, 5.919486979150722, 6.918571778670497, 7.817175502700106, 8.742241076838813, 9.788115087720708, 10.7151389162766, 11.678769964939992, 12.723878533725506, 13.626101237478148, 14.613299484031323, 13.54380801510153, 12.60567839311198, 11.608142063896647, 10.670634224161455, 10.762352247077306, 9.730668047783311, 8.762825473728984, 7.901844774981771, 6.979995057604845, 6.046347128896292, 6.929539652353708, 7.872275565976528, 8.838819953642387, 9.776235415144056, 10.729342565921796, 11.645230670764395, 12.63819872514206, 13.650486871484045, 14.014634169997462, 14.635430862027762, 14.524021436272516, 13.567143613862433, 12.60257891838816, 11.661987765107773, 11.685383549332215, 10.730177547835485, 9.809523802671361, 8.900858145325456, 7.9175464994343905, 6.979939439719194, 7.991956133769028, 8.797524206761775, 9.77043706719733, 10.753902739566055, 11.68849272842385, 12.667274246817323, 13.639558359182498, 13.92859971429963, 12.985176293209586, 13.676809433190536, 14.512820090106393, 14.47370284140957, 13.537137630912168, 12.616011660043133, 12.678585637455578, 11.743918086707655, 10.84178639752345, 9.885761853583798, 8.909489601729724, 8.030738335319194, 8.998302937583812, 9.743618153478085, 10.701774217852773, 11.689682766527499, 12.637160085645549, 13.60294108943308, 13.716922342911396, 12.934856878984837, 11.927040098685186, 12.68470962364757, 13.579986060589148, 14.493132971763144, 14.501255946621331, 13.605053947961508, 13.64579195075372, 12.754980007345972, 11.832937397842777, 10.909854951136317, 9.96515623071258, 9.0162010111612, 9.951870278408556, 10.690126935918185, 11.643590108081037, 12.610792577623577, 13.670394786860594, 13.71496365566606, 12.78482800704941, 11.88889526942586, 10.956790256148379, 11.66872915286807, 12.616053742766729, 13.547911423045253, 14.57316694305362, 14.613399252693437, 14.574392006857877, 13.764676799056476, 12.785891784959723, 11.977009948516661, 10.996544064079478, 9.998244073860842, 10.956504533604065, 11.75880716715877, 12.718563417769332, 13.573854627972931, 13.716936847268812, 12.763796166789158, 11.842163368062018, 10.89479707658857, 9.941188353598791, 10.731563061240037, 11.736211586327558, 12.679642326471601, 13.681634450767184, 14.66221738294252, 14.568932082468674, 14.738867039562487, 13.821011020138066, 12.946209956011387, 12.006226431152118, 11.010040174207099, 11.88971808152282, 12.70197953368389, 13.671781225597188, 13.690636810302516, 12.737319218034763, 11.762380184033184, 10.828827143532314, 9.971920652218802, 8.952486358437138, 9.745631683055677, 10.788843139476704, 11.778795110259432, 12.733712027402555, 13.596753218352527, 13.602300657272238, 14.472256628552428, 14.878693992387095, 13.892085906418751, 12.950187426645517, 11.965978802551845, 12.82753528523706, 13.62824881478261, 13.667515899106627, 12.800987790152282, 11.78801276007015, 10.73201852593791, 9.800870527831647, 8.925521775246558, 8.000321331843093, 8.785928092333442, 9.76969818876954, 10.708180656752374, 11.705847770126626, 12.585105002960708, 12.647727562920778, 13.502761241735934, 14.43202093142235, 14.90818130346803, 13.992428796703841, 13.037756715622596, 13.848047533970465, 13.688811885868917, 12.624804847466455, 11.810067289436711, 10.813773073112731, 9.914408547178754, 8.846467169805319, 7.9480848039916685, 6.984238001230393, 7.813154253134269, 8.771452714008888, 9.756000126242702, 10.779580897646714, 11.652642791380453, 11.640526772762062, 12.566940299052284, 13.496554121771963, 14.492285656191747, 15.019772808573272, 14.098549107143034, 13.687874761701025, 12.654143970876428, 11.616990912623542, 10.774964763592196, 9.8057201141115, 8.872390577848508, 7.871538559137074, 6.948958204261792, 5.9553333413656375, 6.8696557131608795, 7.815768690172374, 8.786015273519128, 9.751001340135353, 10.666354299967916, 10.642687473997633, 11.603917223558247, 12.577622811533328, 13.519362272972964, 14.508693749467865, 13.674347914456336, 12.638301124925643, 11.645318416556423, 10.664291449675776, 9.704155131656915, 8.763521331566498, 7.824757591270203, 6.878467835244813, 6.000529014790541, 5.016535344968441, 5.93212892380102, 6.883843362968044, 7.829296890219206, 8.785065305045116, 9.727758895974961, 9.696838206450362, 10.65487158699029, 11.650419878222221, 12.605524814941754, 13.632128840608544, 12.64788464283647, 11.680109605763047, 10.635754993815345, 9.73130584533457, 8.769052612035416, 7.7916825630178055, 6.875156643734173, 5.919466160501475, 4.973009428532982, 4.064682957131427, 4.951547822885338, 5.904157115886393, 6.8466465319115635, 7.8158096915895285, 8.755056944710503, 8.671489719192554, 9.739192010881162, 10.721254581512216, 11.679754835976906, 12.591682794508902, 11.617577212978501, 10.64712233293419, 9.673425835334816, 8.706003154935892, 7.761546401281432, 6.836196281047716, 5.941575023040445, 4.988775555253801, 3.978234062801039, 3.049636252110253, 4.013952407996303, 4.880800227114653, 5.92107634500272, 6.86305437757687, 7.70579191414877, 7.743288552673182, 8.772791087115396, 9.811113022687884, 10.72182202857743, 11.66699215789068, 10.668035678389854, 9.688341401666403, 8.706327454231486, 7.751906253315212, 6.851518341008036, 5.8985440420359545, 4.93778811013881, 3.9802592825684826, 2.947041059269946, 2.016485932311785, 3.0222305308696784, 3.9177763372756433, 4.90227264514665, 5.8487449074015325, 6.774230684381985, 6.8366424795002585, 7.783515764898394, 8.769547538900317, 9.789637930218413, 10.761653899708698, 9.806529857919953, 8.850228670050408, 7.833753422645414, 6.808095590104431, 5.820052780321284, 4.888894412519398, 3.8681305993385457, 2.939561381875951, 1.9991130252187579, 0.992740038052387, 1.9730520111498755, 2.957583605966425, 3.922256243722412, 4.883059694665351, 5.882900061996848, 6.101692521126786, 7.175102928267345, 8.136278960996625, 9.073194140980075, 10.147467064126547, 9.148519060066466, 8.09418584725489, 7.139162115543775, 6.153017725568455, 5.169990602075729, 4.232659023369387, 3.178488822273939, 2.1360704461234397, 1.061939236604635, 0.0, 1.0375231473979867, 2.0283862651991575, 3.0605987355766144, 4.1026884892509035, 5.137503153238066, 7.007572635845885, 8.053514156721306, 9.103487116282524, 10.005885853147273, 11.039467215264857, 10.057332517445793, 9.101812435256665, 8.07728822342195, 7.118376674263081, 6.045969752581358, 5.006422249373209, 4.049467989448357, 3.0020434097928677, 2.010253282237707, 1.025231608187568, 2.0665019396850726, 2.995031000156458, 3.997444608523105, 5.009935449180034, 5.988035402149116], [5.796424881674194, 4.846780368554644, 3.8534380330106544, 2.893645879469083, 2.042400374687607, 3.0217967714743077, 4.036078674396146, 5.041187053276945, 6.073397214218217, 7.042542278434144, 8.030108115371394, 9.056583705657546, 10.02052637829794, 11.010519276940043, 11.926149059786193, 10.95511323252953, 9.916612298118931, 8.90442033897009, 7.855873098358217, 6.836236627964448, 6.767900347588059, 5.8228162532348, 4.884244344019496, 3.834043958457027, 3.029979110669763, 4.007192323620565, 4.975971878474083, 5.911197610028775, 6.897944616661235, 7.919060645856785, 8.873165903865566, 9.80279891326683, 10.841522931239556, 11.822799407604307, 12.656347904928309, 11.649978023590798, 10.687017652445565, 9.64203615938806, 8.65541684234796, 7.708490453791939, 7.785621610850754, 6.823472075023613, 5.860803188467885, 4.862937831609992, 4.039082871958284, 4.99553077011987, 5.999573549961833, 6.9604200876022535, 7.87336892682114, 8.826197873379208, 9.848341756617883, 10.74029835919615, 11.797734337424275, 12.746318333496983, 13.675578862175547, 12.700953648219008, 11.661907143005985, 10.611475214531145, 9.64746033981471, 8.64625700460363, 8.797884439491376, 7.7594762867934, 6.775259619974352, 5.825448455602279, 4.992032768022952, 6.01930219620581, 6.95701012654871, 7.956094926068484, 8.854698650098094, 9.7797642242368, 10.825638235118696, 11.75266206367459, 12.716293112337981, 13.761401681123495, 14.619885023687933, 13.575776336633337, 12.506284867703544, 11.568155245713994, 10.570618916498661, 9.63311107676347, 9.724829099679322, 8.693144900385326, 7.725302326330999, 6.864321627583784, 6.051665470637416, 6.985313399345969, 7.967062799751695, 8.909798713374515, 9.876343101040375, 10.813758562542043, 11.766865713319783, 12.682753818162384, 13.675721872540048, 14.688010018882034, 14.554738070577313, 13.597907714629777, 13.48649828887453, 12.529620466464447, 11.565055770990174, 10.624464617709787, 10.64786040193423, 9.6926544004375, 8.772000655273374, 7.8633349979274705, 7.12276735442427, 7.918905710168872, 8.95916553701783, 9.835047354159762, 10.807960214595317, 11.791425886964042, 12.726015875821837, 13.704797394215312, 14.677081506580487, 14.545108978917687, 13.601685557827643, 12.63928628579255, 13.475296942708407, 13.436179694011585, 12.499614483514183, 11.578488512645148, 11.641062490057593, 10.70639493930967, 9.804263250125462, 8.852538426916162, 8.114710456719605, 8.969704605768872, 9.965512340832614, 10.781141300876072, 11.73929736525076, 12.727205913925486, 13.674683233043536, 14.640464236831066, 14.517464533902661, 13.551366143602895, 12.543549363303244, 11.647186476249585, 12.542462913191162, 13.455609824365158, 13.463732799223346, 12.567530800563523, 12.608268803355735, 11.717456859947987, 10.79541425044479, 9.876631524468682, 9.17037708570246, 9.955167281610878, 10.919079681657358, 11.727650083316172, 12.681113255479024, 13.648315725021565, 14.707917934258582, 14.515505846657325, 13.585370198040675, 12.557574595158572, 11.573299520766437, 10.631206005470084, 11.578530595368743, 12.510388275647268, 13.535643795655634, 13.575876105295452, 13.536868859459892, 12.727153651658488, 11.748368637561736, 10.943786521849026, 10.201764919069358, 10.93721034431052, 11.923713936852867, 12.796330314556757, 13.756086565167319, 14.611377775370919, 14.517479038260078, 13.564338357780423, 12.642705559053283, 11.585388042150614, 10.631779319160835, 9.694039913842051, 10.698688438929572, 11.642119179073617, 12.644111303369199, 13.624694235544533, 13.531408935070687, 13.7013438921645, 12.783487872740078, 11.912986529343751, 11.252435198670938, 11.949006444656776, 12.856927484771623, 13.739502681081877, 14.709304372995176, 14.491179001293782, 13.537861409026029, 12.56292237502445, 11.62936933452358, 10.700842210019772, 9.681407916238108, 8.708108535657692, 9.75131999207872, 10.741271962861447, 11.69618888000457, 12.55923007095454, 12.56477750987425, 13.43473348115444, 13.841170844989108, 12.911189293694346, 12.196396194164336, 12.904945073001523, 13.794744688485862, 14.665771962180598, 14.592525303057734, 13.615696879611093, 12.588554951061415, 11.532560716929176, 10.601412718822912, 9.654443333047528, 8.729242889644063, 7.748404944935457, 8.732175041371555, 9.670657509354388, 10.66832462272864, 11.54758185556272, 11.61020441552279, 12.465238094337947, 13.394497784024363, 13.927284690743624, 13.23863756422266, 13.976722986072271, 14.815256937219267, 14.626561510091582, 13.56255447168912, 12.747816913659376, 11.751522697335396, 10.817000884374316, 9.747947838048912, 8.764679075741894, 7.754858720422741, 6.775631105736283, 7.733929566610902, 8.718476978844716, 9.742057750248728, 10.615119643982466, 10.603003625364074, 11.529417151654297, 12.459030974373976, 13.45476250879376, 14.265981576092091, 15.03751537759271, 14.62562438592369, 13.591893595099092, 12.554740536846207, 11.712714387814861, 10.743469738334163, 9.77498291504407, 8.773019227380667, 7.765552476012016, 6.771927613115862, 5.832132565762893, 6.778245542774387, 7.748492126121142, 8.713478192737366, 9.628831152569928, 9.605164326599645, 10.56639407616026, 11.54009966413534, 12.481839125574977, 13.471170602069877, 14.535579917431303, 13.576050749148308, 12.583068040779088, 11.602041073898441, 10.64190475587958, 9.70127095578916, 8.727349928465767, 7.779948503488406, 6.817123286540765, 5.833129616718665, 4.894605776403034, 5.846320215570057, 6.79177374282122, 7.747542157647128, 8.690235748576974, 8.659315059052375, 9.617348439592302, 10.612896730824234, 11.568001667543768, 12.627794069701178, 13.585634267059135, 12.617859229985712, 11.57350461803801, 10.669055469557234, 9.706802236258081, 8.72943218724047, 7.812906267956836, 6.857215784724138, 5.910759052755646, 4.881277228881652, 3.9140246754873522, 4.866633968488406, 5.809123384513577, 6.778286544191542, 7.717533797312518, 7.633966571794566, 8.701668863483174, 9.683731434114229, 10.64223168857892, 11.693209356734055, 12.555326837201166, 11.584871957156855, 10.611175459557481, 9.643752779158557, 8.699296025504097, 7.773945905270381, 6.87932464726311, 5.926525179476465, 4.9159836870237035, 3.987385876332917, 2.9764292605983167, 3.8432770797166667, 4.8835531976047335, 5.825531230178884, 6.668268766750783, 6.705765405275195, 7.735267939717408, 8.773589875289897, 9.684298881179444, 10.684057290640888, 11.605785302612519, 10.626091025889068, 9.644077078454151, 8.689655877537877, 7.7892679652306995, 6.836293666258619, 5.875537734361475, 4.918008906791147, 3.8847906834926103, 2.954235556534449, 1.984707383471692, 2.8802531898776564, 3.8647494977486634, 4.811221760003546, 5.736707536983999, 5.799119332102273, 6.745992617500408, 7.732024391502332, 8.752114782820428, 9.818849601035467, 10.744279482142618, 9.787978294273072, 8.771503046868078, 7.745845214327095, 6.7578024045439475, 5.826644036742062, 4.80588022356121, 3.877311006098615, 2.936862649441422, 1.930489662275051, 0.9355288637518888, 1.9200604585684384, 2.8847330963244255, 3.845536547267365, 4.845376914598862, 5.064169373728799, 6.137579780869357, 7.098755813598639, 8.03567099358209, 9.109943916728561, 10.182717657761884, 9.131708994652877, 8.176685262941763, 7.190540872966443, 6.207513749473716, 5.270182170767374, 4.216011969671925, 3.173593593521426, 2.0994623840026216, 1.0375231473979867, 0.0, 0.990863117801171, 2.023075588178628, 3.0651653418529166, 4.099980005840079, 5.9700494884478985, 7.015991009323319, 8.065963968884537, 8.968362705749287, 10.001944067866871, 11.028580191794108, 10.139335582654653, 9.114811370819936, 8.155899821661068, 7.083492899979344, 6.043945396771195, 5.086991136846343, 4.039566557190854, 3.047776429635694, 2.062754755585555, 1.0289787922870859, 1.9575078527584715, 2.9599214611251186, 3.9724123017820476, 4.950512254751129], [4.805561763873023, 3.8559172507534725, 2.8625749152094837, 1.9027827616679123, 2.9562494652818865, 3.960947780370737, 4.975229683292575, 6.000266408076692, 7.032476569017964, 8.00162163323389, 8.98918747017114, 10.015663060457292, 10.979605733097687, 11.891885472839597, 10.93528594198502, 9.964250114728358, 8.925749180317759, 7.913557221168919, 6.865009980557046, 5.845373510163277, 5.777037229786888, 4.831953135433628, 3.8933812262183256, 2.843180840655856, 3.778334245381156, 4.755547458331958, 5.816573346980031, 6.751799078534723, 7.738546085167183, 8.759662114362733, 9.713767372371514, 10.643400381772778, 11.682124399745504, 12.663400876110256, 11.66548478712714, 10.659114905789629, 9.696154534644396, 8.65117304158689, 7.6645537245467885, 6.717627335990769, 6.794758493049583, 5.832608957222441, 4.869940070666714, 3.872074713808821, 4.787438006669677, 5.743885904831263, 6.793099618349279, 7.801021556108202, 8.713970395327088, 9.666799341885156, 10.68894322512383, 11.580899827702098, 12.638335805930224, 13.586919802002932, 12.684715744374378, 11.710090530417839, 10.671044025204814, 9.620612096729975, 8.65659722201354, 7.655393886802459, 7.807021321690206, 6.768613168992229, 5.784396502173181, 4.8345853378011086, 5.740387902734346, 6.767657330917204, 7.7505361949361555, 8.74962099445593, 9.695300118604042, 10.620365692742748, 11.666239703624644, 12.593263532180538, 13.55689458084393, 14.602003149629443, 13.629021905886765, 12.584913218832167, 11.515421749902373, 10.577292127912823, 9.57975579869749, 8.6422479589623, 8.73396598187815, 7.702281782584155, 6.734439208529828, 5.873458509782614, 6.80002060534881, 7.733668534057363, 8.722720179332384, 9.665456092955205, 10.647887578854483, 11.654360031047991, 12.607467181825731, 13.523355286668332, 14.516323341045997, 15.528611487387982, 14.50332781028479, 13.546497454337253, 12.49563517107336, 11.538757348663276, 10.574192653189003, 9.633601499908616, 9.656997284133059, 8.701791282636329, 7.781137537472204, 6.8724718801263, 7.871122489135664, 8.667260844880266, 9.707520671729224, 10.590704733740452, 11.563617594176007, 12.549269447796012, 13.483859436653807, 14.510305514475736, 15.517682975086435, 15.487699885657088, 14.544276464567044, 13.581877192531952, 12.879337154906679, 12.445316576210415, 11.508751365713012, 10.587625394843977, 10.650199372256422, 9.715531821508499, 8.813400132324292, 7.8616753091149905, 8.837947560969063, 9.718059740480266, 10.713867475544008, 11.536798680456762, 12.49495474483145, 13.485049474757457, 14.432526793875507, 15.398307797663037, 15.460055440642062, 14.493957050342296, 13.486140270042645, 12.589777382988986, 11.946503125389434, 12.763292221365722, 12.472869681422175, 11.576667682762352, 11.617405685554564, 10.726593742146816, 9.804551132643619, 8.885768406667509, 9.893614189951919, 10.703522416322272, 11.667434816368752, 12.483307462896862, 13.436770635059714, 14.403973104602255, 15.463575313839272, 15.458096753396726, 14.527961104780076, 13.500165501897973, 12.515890427505838, 11.573796912209485, 10.982570807567015, 11.818070672647831, 12.808362882926113, 12.58501298749428, 12.546005741658721, 11.736290533857318, 10.757505519760565, 9.952923404047853, 10.925002023318816, 11.685565479021914, 12.67206907156426, 13.551987694137447, 14.511743944748009, 15.367035154951608, 15.460069944999479, 14.506929264519824, 13.585296465792684, 12.527978948890015, 11.574370225900235, 10.636630820581452, 9.979954757971708, 10.815846620852502, 11.766991719697014, 12.666875730563335, 12.573590430089489, 12.71048077436333, 11.792624754938908, 10.922123411542579, 11.905514497698611, 12.69736157936817, 13.605282619483017, 14.495160060662567, 15.464961752575865, 15.433769908033183, 14.48045231576543, 13.50551328176385, 12.57196024126298, 11.643433116759173, 10.623998822977509, 9.650699442397093, 8.923752053091086, 9.864152379189262, 10.819069296332385, 11.601411565973342, 11.606959004893053, 12.476914976173243, 12.850307727187937, 11.920326175893173, 12.84947549319201, 13.653300207712917, 14.543099823197256, 15.421429341761288, 15.535116209797135, 14.558287786350494, 13.531145857800816, 12.475151623668577, 11.544003625562313, 10.597034239786929, 9.671833796383464, 8.690995851674858, 7.90460710238392, 8.793537925682203, 9.791205039056456, 10.589763350581523, 10.652385910541593, 11.507419589356749, 12.436679279043165, 12.936421572942452, 13.869693833890867, 14.725078120783667, 15.563612071930661, 15.617424627892754, 14.553417589490293, 13.72021260726144, 12.72391839093746, 11.759591791113717, 10.690538744788313, 9.707269982481295, 8.697449627162143, 7.718222012475684, 6.9063616276232676, 7.7927297289991495, 8.816310500403162, 9.657301139001268, 9.645185120382877, 10.571598646673099, 11.501212469392778, 12.49694400381256, 13.448547780525734, 14.443283774801955, 15.416937628490968, 14.582756712900265, 13.54560365464738, 12.703577505616032, 11.715865431936228, 10.717573821783471, 9.715610134120068, 8.708143382751418, 7.714518519855263, 6.774723472502295, 5.854640902096693, 6.822405350707893, 7.787391417324118, 8.67101264758873, 8.647345821618448, 9.608575571179061, 10.58228115915414, 11.524020620593777, 12.513352097088678, 13.577761412450101, 14.566913866949477, 13.573931158580258, 12.592904191699612, 11.63276787368075, 10.679497943975637, 9.669940835205168, 8.722539410227807, 7.759714193280166, 6.775720523458066, 5.837196683142436, 4.888501710588859, 5.833955237840021, 6.789723652665931, 7.732417243595776, 7.701496554071176, 8.659529934611102, 9.655078225843035, 10.610183162562569, 11.669975564719978, 12.67590163602602, 13.608722347786882, 12.56436773583918, 11.659918587358405, 10.697665354059252, 9.72029530504164, 8.80376938575801, 7.848078902525311, 6.873850516862129, 5.823868135621053, 4.856615582226754, 3.9088154635072074, 4.851304879532378, 5.820468039210343, 6.759715292331318, 6.676148066813368, 7.743850358501976, 8.725912929133031, 9.684413183597721, 10.735390851752856, 11.674736799749162, 12.575735074958025, 11.602038577358652, 10.634615896959728, 9.690159143305268, 8.764809023071551, 7.870187765064281, 6.917388297277636, 5.906846804824875, 4.961746869431416, 3.9190201673377176, 2.885458574735468, 3.925734692623534, 4.867712725197685, 5.7104502617695845, 5.7479469002939965, 6.7774494347362095, 7.815771370308699, 8.726480376198245, 9.726238785659689, 10.725195265160515, 11.616954143690238, 10.634940196255322, 9.680518995339048, 8.78013108303187, 7.82715678405979, 6.866400852162646, 5.908872024592318, 4.875653801293781, 3.94509867433562, 2.927298290211093, 1.9224346848964577, 2.906930992767464, 3.8534032550223474, 4.7788890320028, 4.841300827121074, 5.78817411251921, 6.774205886521133, 7.794296277839229, 8.861031096054269, 9.816155137843014, 10.77245632571256, 9.76236616466925, 8.736708332128266, 7.748665522345118, 6.817507154543232, 5.79674334136238, 4.868174123899786, 3.9277257672425927, 2.921352780076222, 1.92639198155306, 0.9622419535872394, 1.9269145913432264, 2.887718042286166, 3.887558409617663, 4.073306255927628, 5.146716663068187, 6.107892695797468, 7.0448078757809185, 8.11908079892739, 9.191854539960714, 10.122572112454048, 9.167548380742934, 8.181403990767613, 7.198376867274886, 6.261045288568544, 5.206875087473096, 4.164456711322597, 3.0903255018037923, 2.0283862651991575, 0.990863117801171, 0.0, 1.032212470377457, 2.0743022240517455, 3.1091168880389084, 4.979186370646728, 6.025127891522148, 7.0751008510833655, 7.977499587948116, 9.011080950065699, 10.037717073992935, 10.993237156182063, 10.073890725619684, 9.114979176460816, 8.042572254779092, 7.003024751570942, 6.04607049164609, 4.998645911990601, 4.006855784435441, 3.021834110385302, 1.9596652505050647, 0.9666447349573006, 1.9690583433239477, 2.9815491839808765, 3.9596491369499582], [3.94159212746484, 2.99194761434529, 2.0188379786575545, 2.9349952320453694, 3.988461935659344, 4.993160250748194, 6.007442153670032, 7.032478878454149, 8.06468903939542, 9.033834103611348, 10.021399940548598, 11.04787553083475, 11.853077009328223, 10.86308411068612, 9.906484579831544, 8.935448752574882, 7.896947818164282, 7.0495875847607365, 6.001040344148863, 4.981403873755094, 4.913067593378706, 3.967983499025446, 3.0496442896663964, 3.8753933110333127, 4.810546715758613, 5.787759928709415, 6.848785817357488, 7.784011548912179, 8.77075855554464, 9.79187458474019, 10.745979842748971, 11.675612852150236, 12.714336870122962, 11.815021391155724, 10.801515150718956, 9.795145269381445, 8.832184898236212, 7.787203405178707, 6.800584088138606, 5.853657699582587, 5.930788856641401, 4.968639320814259, 4.084475752358326, 4.904287184186278, 5.819650477047134, 6.776098375208719, 7.825312088726736, 8.833234026485657, 9.746182865704546, 10.699011812262613, 11.721155695501288, 12.613112298079555, 13.67054827630768, 12.79374599783296, 11.820746107966194, 10.846120894009655, 9.807074388796632, 8.756642460321792, 7.7926275856053575, 6.791424250394277, 6.963782703263818, 5.930048395653406, 5.133600914822646, 5.866797808178565, 6.772600373111802, 7.79986980129466, 8.782748665313612, 9.781833464833387, 10.727512588981499, 11.652578163120205, 12.698452174002101, 13.625476002557996, 14.589107051221387, 13.813166390448707, 12.76505226947858, 11.720943582423985, 10.65145211349419, 9.713322491504641, 8.715786162289309, 7.778278322554116, 7.908806003529323, 6.968223327912494, 6.083643621179292, 6.90567098016007, 7.832233075726266, 8.765881004434819, 9.75493264970984, 10.69766856333266, 11.680100049231939, 12.686572501425449, 13.639679652203188, 14.55556775704579, 15.548535811423454, 14.702767059051894, 13.639358173876607, 12.68252781792907, 11.631665534665178, 10.674787712255094, 9.710223016780821, 8.769631863500434, 8.855848544129813, 7.967732827964667, 7.130341950121668, 7.904684350503756, 8.903334959513119, 9.699473315257721, 10.73973314210668, 11.622917204117908, 12.595830064553462, 13.581481918173468, 14.516071907031263, 15.542517984853191, 16.549895445463893, 15.675685219298778, 14.609355207884162, 13.56216801393702, 12.587394071141516, 11.581346939802232, 10.64478172930483, 9.74442526300165, 9.849050632253176, 8.981473366836838, 8.162604544973757, 8.893887779492447, 9.870160031346519, 10.750272210857721, 11.746079945921464, 12.569011150834218, 13.527167215208905, 14.517261945134912, 15.464739264252962, 16.430520268040492, 16.44065895069542, 15.47456056039565, 14.466743780096, 13.57038089304234, 12.910943927661853, 11.9603754782788, 11.608900045013993, 10.733467550920025, 10.816256945551318, 9.992535287475155, 9.153755545293084, 9.917980877044966, 10.925826660329374, 11.735734886699728, 12.699647286746208, 13.515519933274318, 14.46898310543717, 15.43618557497971, 16.495787784216727, 16.43870026345008, 15.508564614833432, 14.480769011951327, 13.496493937559192, 12.55440042226284, 11.947011609839434, 11.01515392956091, 11.961437509775092, 11.741812855651954, 11.744857001655475, 11.06546925639674, 10.10670993241003, 10.98513587442531, 11.957214493696272, 12.71777794939937, 13.704281541941716, 14.584200164514902, 15.543956415125464, 16.399247625329064, 16.440673455052835, 15.487532774573179, 14.565899975846039, 13.50858245894337, 12.55497373595359, 11.617234330634806, 10.956360617909624, 10.01292987776558, 10.920066346545992, 11.718133965104714, 11.624848664630868, 12.039659496902752, 11.141829167588373, 11.954335881920038, 12.93772696807607, 13.729574049745626, 14.637495089860472, 15.527372531040022, 16.497174222953323, 16.414373418086537, 15.461055825818784, 14.486116791817205, 13.552563751316335, 12.624036626812527, 11.604602333030863, 10.631302952450447, 9.904355563144438, 9.06123563610234, 9.972143923181363, 10.65266980051472, 10.658217239434432, 11.528173210714622, 12.199512139837402, 12.952538646270632, 13.881687963569469, 14.685512678090372, 15.575312293574711, 16.45364181213874, 16.51571971985049, 15.538891296403849, 14.51174936785417, 13.455755133721931, 12.524607135615668, 11.577637749840283, 10.652437306436818, 9.671599361728212, 8.885210612437273, 7.990621182595282, 8.942373985837097, 9.641021585122902, 9.703644145082972, 10.558677823898128, 11.487937513584544, 12.4476202868797, 13.380892547828115, 14.368446451555318, 15.337856577462436, 16.395269469580718, 15.554402666394376, 14.700816117314792, 13.704521900990812, 12.74019530116707, 11.671142254841666, 10.687873492534647, 9.678053137215496, 8.698825522529038, 7.88696513767662, 6.989812985912228, 7.917420062017497, 8.708559373542647, 8.696443354924256, 9.622856881214478, 10.552470703934157, 11.548202238353939, 12.499806015067113, 13.494542009343334, 14.468195863032348, 15.5096441465414, 14.546588731551463, 13.704562582520115, 12.69646894198958, 11.698177331836824, 10.69621364417342, 9.68874689280477, 8.695122029908616, 7.755326982555648, 6.835244412150047, 6.019488607620971, 6.848682667660933, 7.722270882130109, 7.6986040561598275, 8.65983380572044, 9.63353939369552, 10.575278855135156, 11.564610331630057, 12.62901964699148, 13.665066436522173, 14.574916235484341, 13.593889268603695, 12.633752950584833, 11.66010145402899, 10.65054434525852, 9.70314292028116, 8.740317703333519, 7.756324033511419, 6.817800193195788, 5.869105220642212, 5.0310384947531, 5.84098188720731, 6.783675478137155, 6.752754788612556, 7.710788169152482, 8.706336460384414, 9.661441397103948, 10.721233799261357, 11.7271598705674, 12.764182456534305, 13.565352812743264, 12.660903664262488, 11.698650430963335, 10.721280381945723, 9.804754462662093, 8.849063979429394, 7.854454026915482, 6.804471645674406, 5.837219092280106, 4.889418973560561, 4.048388136445458, 4.871726273751723, 5.810973526872699, 5.727406301354748, 6.795108593043356, 7.777171163674411, 8.7356714181391, 9.786649086294235, 10.725995034290541, 11.714928707693133, 12.603023654262735, 11.635600973863811, 10.69114422020935, 9.765794099975635, 8.871172841968363, 7.918373374181719, 6.907831881728958, 5.94235037948477, 4.899623677391071, 3.866062084788822, 2.976992927164914, 3.918970959739065, 4.761708496310964, 4.799205134835376, 5.828707669277589, 6.867029604850079, 7.777738610739624, 8.777497020201068, 9.776453499701894, 10.756147776425346, 11.635925273159403, 10.68150407224313, 9.781116159935953, 8.828141860963873, 7.867385929066729, 6.909857101496401, 5.8766388781978645, 4.946083751239703, 3.907901800264447, 2.903038194949812, 1.9581892273088441, 2.9046614895637273, 3.8301472665441803, 3.8925590616624537, 4.839432347060589, 5.825464121062512, 6.845554512380608, 7.912289330595647, 8.867413372384393, 9.823714560253938, 10.763351241573332, 9.737693409032348, 8.7496505992492, 7.8184922314473155, 6.7977284182664635, 5.869159200803869, 4.928710844146676, 3.922337856980305, 2.927377058457143, 1.9428454636405936, 0.9781728258846065, 1.938976276827546, 2.938816644159043, 3.0410937855501707, 4.114504192690729, 5.075680225420011, 6.012595405403461, 7.086868328549934, 8.159642069583258, 9.213975282394834, 10.168999014105948, 9.21361646114507, 8.230589337652344, 7.293257758946002, 6.239087557850553, 5.196669181700054, 4.12253797218125, 3.0605987355766144, 2.023075588178628, 1.032212470377457, 0.0, 1.0420897536742886, 2.076904417661451, 4.0434058821542855, 5.089347403029706, 6.10757132870721, 6.9452871175706585, 7.978868479688241, 9.005504603615478, 9.961024685804606, 10.992281112584543, 10.147191646838271, 9.074784725156547, 8.0352372219484, 7.078282962023547, 6.0308583823680575, 5.039068254812897, 4.054046580762758, 2.9918777208825214, 1.9988572053347575, 1.0332778548315062, 2.045768695488435, 3.023868648457517], [2.965000246521861, 2.015355733402311, 3.0086980689462997, 3.968490222487871, 5.021956926101845, 6.026655241190696, 7.040937144112534, 8.074568632128438, 9.106778793069708, 10.075923857285634, 11.063489694222884, 11.77492992829433, 10.810987255653936, 9.820994357011834, 8.864394826157257, 7.893358998900594, 6.854858064489994, 6.072995703817757, 5.024448463205884, 4.004811992812115, 3.9364757124357266, 2.991391618082467, 3.9698488248756485, 4.908888301475814, 5.844041706201114, 6.821254919151916, 7.882280807799989, 8.817506539354682, 9.804253545987143, 10.825369575182693, 11.779474833191474, 12.709107842592738, 11.75420811384619, 10.772931637481438, 9.791360218969993, 8.818553388438465, 7.8555930172932324, 6.8106115242357275, 5.8239922071956265, 4.877065818639607, 4.954196975698421, 3.99204743987128, 5.004680287567578, 5.937782174628779, 6.853145467489635, 7.809593365651221, 8.858807079169237, 9.86672901692816, 10.779677856147048, 11.732506802705116, 12.75465068594379, 13.646607288522057, 12.732175062156706, 11.783591066083998, 10.810591176217232, 9.869529013066675, 8.830482507853652, 7.780050579378813, 6.816035704662378, 5.814832369451297, 5.987190822320838, 4.953456514710427, 5.937673181529475, 6.887484345901548, 7.806095363554304, 8.833364791737162, 9.816243655756114, 10.815328455275889, 11.761007579424001, 12.686073153562708, 13.731947164444604, 14.658970993000498, 13.699079861809611, 12.803011458699745, 11.754897337729618, 10.744351701481005, 9.674860232551211, 8.736730610561661, 7.739194281346329, 6.801686441611136, 6.932214122586343, 5.9916314469695156, 6.887715887886122, 7.926357517883053, 8.865728066168767, 9.79937599487732, 10.78842764015234, 11.731163553775161, 12.71359503967444, 13.720067491867951, 14.67317464264569, 15.589062747488292, 14.675052481286453, 13.726175178108914, 12.662766292933627, 11.70593593698609, 10.655073653722198, 9.698195831312114, 8.73363113583784, 7.7930399825574534, 7.879256663186833, 6.991140947021689, 7.934414216828498, 8.92537088822674, 9.936829949955621, 10.732968305700222, 11.77322813254918, 12.656412194560408, 13.629325054995963, 14.614976908615969, 15.549566897473763, 16.576012975295694, 15.670504539069954, 14.699093338355798, 13.632763326941182, 12.58557613299404, 11.610802190198536, 10.60475505885925, 9.668189848361848, 8.76783338205867, 8.872458751310196, 8.00488148589386, 8.966676811680586, 9.914574317215429, 10.890846569069502, 11.783767201300222, 12.779574936363964, 13.602506141276718, 14.560662205651406, 15.550756935577413, 16.49823425469546, 17.46401525848299, 16.535445637967403, 15.489607971885489, 14.481791191585838, 13.50308153308178, 12.543636219715781, 11.539374922505813, 10.632308164071011, 9.756875669977045, 9.839665064608338, 9.015943406532177, 9.957827811999913, 10.938667414767949, 11.946513198052358, 12.769229877142228, 13.733142277188708, 14.549014923716818, 15.50247809587967, 16.469680565422212, 17.52928277465923, 17.48079001712437, 16.550654368507722, 15.522858765625617, 14.538583691233482, 13.596490175937129, 12.869099017115866, 11.937241336837342, 11.089344790395337, 10.765220974708974, 10.768265120712496, 10.088877375453762, 10.91078219911686, 11.927034769212248, 12.953775957242582, 13.75127293984187, 14.737776532384217, 15.617695154957403, 16.577451405567963, 17.432742615771566, 17.482763208727125, 16.52962252824747, 15.607989729520328, 14.550672212617659, 13.59706348962788, 12.659324084309096, 11.878448025186056, 10.935017285042013, 10.047973627166238, 10.84604124572496, 10.752755945251113, 11.063067615959774, 11.945901434295202, 12.896234776706976, 13.879625862863008, 14.763069040188126, 15.670990080302973, 16.560867521482525, 17.530669213395825, 17.456463171760827, 16.503145579493076, 15.528206545491495, 14.594653504990625, 13.666126380486817, 12.646692086705153, 11.673392706124737, 10.870336008561711, 9.983323043378773, 9.100051203801609, 9.780577081134966, 9.786124520054678, 10.646942461990172, 11.544614096484729, 12.552400542956772, 13.494299022730006, 14.558993615901617, 15.47713807747139, 16.494227702967418, 17.531147277801786, 16.580981050078137, 15.55383912152846, 14.497844887396221, 13.566696889289958, 12.619727503514573, 11.694527060111108, 10.713689115402502, 9.851191057854548, 8.912708589871714, 8.070281266457343, 8.768928865743147, 8.831551425703218, 9.677447075173678, 10.606706764860094, 11.56638953815525, 12.499661799103663, 13.487215702830866, 14.456625828737984, 15.514038720856266, 16.57804575925873, 15.742905870989082, 14.746611654665102, 13.78228505484136, 12.713232008515956, 11.729963246208937, 10.720142890889786, 9.740915276203328, 8.896447805422476, 7.9119003931886605, 7.0453273426377425, 7.8364666541628925, 7.824350635544501, 8.741626132490028, 9.671239955209707, 10.642953349834372, 11.594557126547546, 12.589293120823767, 13.56294697451278, 14.604395258021832, 15.58867848522575, 14.746652336194403, 13.73855869566387, 12.740267085511114, 11.73830339784771, 10.73083664647906, 9.737211783582906, 8.797416736229938, 7.87429556985788, 6.941576014897404, 5.976589948281179, 6.850178162750355, 6.817373307435376, 7.77860305699599, 8.752308644971068, 9.670029966615589, 10.65936144311049, 11.723770758471915, 12.759817548002607, 13.71533214103136, 14.635979022277983, 13.675842704259122, 12.70219120770328, 11.69263409893281, 10.74523267395545, 9.782407457007809, 8.798413787185709, 7.859889946870078, 6.9081563783500455, 5.968631073550866, 4.968889167827555, 5.911582758757401, 5.871524039888104, 6.8295574204280305, 7.825105711659962, 8.707330879798876, 9.767123281956286, 10.773049353262328, 11.810071939229232, 12.705768718290281, 13.702993417936776, 12.740740184637623, 11.763370135620011, 10.84684421633638, 9.891153733103682, 8.896543780589772, 7.846561399348696, 6.879308845954396, 5.928470131268394, 4.985980715243223, 3.999633554371969, 4.929742778148246, 4.846175552630296, 5.913877844318904, 6.895940414949959, 7.7815609008340285, 8.832538568989163, 9.771884516985468, 10.76081819038806, 11.743439559809753, 12.6776907275381, 11.733233973883639, 10.807883853649923, 9.913262595642653, 8.960463127856007, 7.949921635403246, 6.984440133159059, 5.94171343106536, 4.90815183846311, 4.013477748849406, 3.0468782403593107, 3.880477747586512, 3.916912813453032, 4.931984677642749, 5.9386673483944525, 6.823628093434552, 7.823386502895995, 8.82234298239682, 9.802037259120272, 10.784051206555189, 11.723593825917417, 10.823205913610241, 9.870231614638161, 8.909475682741018, 7.951946855170689, 6.918728631872153, 5.988173504913991, 4.949991553938736, 3.9451279486241, 2.9946740489933354, 2.032568770183973, 2.9489165178197276, 2.938448544357382, 3.8853218297555174, 4.8713536037574405, 5.891443995075536, 6.9581788132905755, 7.91330285507932, 8.869604042948867, 9.88607929035386, 10.779783162706636, 9.791740352923489, 8.860581985121604, 7.839818171940752, 6.9112489544781575, 5.970800597820964, 4.964427610654593, 3.969466812131431, 2.9849352173148818, 2.020262579558895, 1.0668835574477917, 1.9847061268539712, 1.9990040318758826, 3.0724144390164416, 4.033590471745723, 4.970505651729173, 6.044778574875646, 7.11755231590897, 8.171885528720546, 9.12690926043166, 10.11305365040698, 9.272679091326633, 8.335347512620292, 7.281177311524843, 6.238758935374343, 5.164627725855539, 4.1026884892509035, 3.0651653418529166, 2.0743022240517455, 1.0420897536742886, 0.0, 1.0348146639871627, 3.026757026550733, 4.072698547426153, 5.065481575032922, 5.90319736389637, 6.936778726013953, 7.96341484994119, 8.918934932130318, 9.950191358910256, 10.909102908069126, 10.116874478830834, 9.077326975622686, 8.120372715697835, 7.0729481360423465, 6.081158008487186, 5.096136334437047, 4.03396747455681, 3.0409469590090463, 2.075367608505795, 1.0691768145454559, 2.0472767675145374], [2.0981086723102766, 2.9476356196757276, 3.9409779552197164, 4.900770108761288, 5.954236812375262, 6.9589351274641125, 7.973217030385951, 9.027325669345954, 10.06686347308587, 11.051338048119039, 11.76659085459332, 10.740115264307168, 9.776172591666773, 8.786179693024671, 7.829580162170094, 6.858544334913432, 5.820043400502832, 5.06585691657016, 4.017309675958288, 2.997673205564519, 3.070508320307715, 3.923671504355884, 4.902128711149065, 5.841168187749231, 6.776321592474531, 7.753534805425333, 8.814560694073407, 9.749786425628098, 10.73653343226056, 11.75764946145611, 12.612031169334486, 11.682398159933221, 10.719393449859027, 9.738116973494275, 8.75654555498283, 7.855117370314033, 6.8921569991688, 5.859913214953523, 4.873293897913422, 3.9263675093574024, 4.08822958357041, 4.924327326144697, 5.936960173840995, 6.870062060902196, 7.785425353763052, 8.741873251924638, 9.791086965442654, 10.799008903201576, 11.711957742420465, 12.664786688978532, 13.587207022086803, 12.61989760586254, 11.697360398169543, 10.748776402096835, 9.775776512230069, 8.906092994942243, 7.874102416778545, 6.829352270096608, 5.865337395380173, 4.864134060169093, 5.121223430192827, 5.885736400983844, 6.869953067802892, 7.819764232174965, 8.73837524982772, 9.76564467801058, 10.748523542029531, 11.747608341549306, 12.693287465697418, 13.618353039836125, 14.653970751624566, 13.62789624648584, 12.664265197822449, 11.768196794712582, 10.720082673742455, 9.7936533921988, 8.724161923269007, 7.786032301279457, 6.7884959720641245, 5.850988132328932, 6.066246730458332, 6.923911333242932, 7.819995774159539, 8.85863740415647, 9.798007952442184, 10.731655881150736, 11.720707526425757, 12.663443440048578, 13.645874925947856, 14.652347378141368, 15.534806469035363, 14.557988000973634, 13.64023781729929, 12.69480513247112, 11.712067983651423, 10.755237627703886, 9.704375344439994, 8.74749752202991, 7.782932826555635, 6.842341673275249, 7.013289271058822, 7.923420833295106, 8.866694103101914, 9.857650774500156, 10.869109836229038, 11.665248191973639, 12.705508018822597, 13.588692080833825, 14.56160494126938, 15.547256794889385, 16.48184678374718, 15.580031577026562, 14.64159745133973, 13.736126651725208, 12.682065017658978, 11.634877823711836, 10.660103880916331, 9.654056749577046, 8.717491539079644, 7.817135072776466, 8.006491359182185, 8.937161372167276, 9.898956697954002, 10.846854203488846, 11.82312645534292, 12.716047087573639, 13.711854822637381, 14.534786027550135, 15.492942091924823, 16.48303682185083, 17.430514140968878, 16.515227867115666, 15.584747328685198, 14.538909662603285, 13.531092882303634, 12.552383223799575, 11.592937910433577, 10.588676613223608, 9.681609854788807, 8.806177360694841, 8.973697672480327, 9.948223292805594, 10.89010769827333, 11.870947301041365, 12.878793084325775, 13.701509763415645, 14.665422163462125, 15.481294809990235, 16.434757982153087, 17.40196045169563, 18.361723465534833, 17.406044996287847, 16.405530830465086, 15.339449021807171, 14.355173947415036, 13.413080432118683, 12.465755842220023, 11.533898161941499, 10.621329019834581, 9.81452266542677, 9.902297728584484, 10.89842855395679, 11.843062085390276, 12.859314655485665, 13.886055843515999, 14.683552826115287, 15.670056418657634, 16.54997504123082, 17.50973129184138, 18.365022502044983, 18.238679926852914, 17.285539246373258, 16.36390644764612, 15.306588930743452, 14.352980207753673, 13.415240802434889, 12.611372932672413, 11.66794219252837, 10.740431457052113, 9.870053956521522, 9.721785065500086, 10.664759016873973, 11.567482404746595, 12.515788643320203, 13.40344535423624, 14.39963161118126, 15.380140617198466, 16.31554682542531, 17.285348517338612, 18.212379889886616, 17.259062297618865, 16.284123263617285, 15.350570223116417, 14.42204309861261, 13.402608804830946, 12.42930942425053, 11.603260916048068, 10.71624795086513, 9.792509033687484, 8.804589791931528, 8.75515364030365, 9.612127798003009, 10.509799432497566, 11.517585878969609, 12.459484358742843, 13.524178951914454, 14.442323413484226, 15.459413038980257, 16.496332613814623, 17.33689776820393, 16.30975583965425, 15.253761605522014, 14.32261360741575, 13.375644221640366, 12.4504437782369, 11.469605833528295, 10.584115965340905, 9.645633497358071, 8.79339096215061, 7.792941576539709, 7.800580545952191, 8.642632411186515, 9.571892100872931, 10.531574874168086, 11.4648471351165, 12.452401038843703, 13.421811164750821, 14.479224056869104, 15.543231095271565, 16.53771409920734, 15.541419882883357, 14.577093283059613, 13.508040236734209, 12.496787403201997, 11.476059609015579, 10.49683199432912, 9.62937271290883, 8.644825300675016, 7.778252250124098, 6.8604793649594535, 6.793379755793476, 7.706811468502865, 8.636425291222544, 9.608138685847209, 10.559742462560383, 11.554478456836604, 12.528132310525617, 13.569580594034669, 14.587035333909167, 15.551228437116947, 14.533366923882124, 13.535075313729367, 12.533111626065963, 11.525644874697313, 10.532020011801158, 9.55333345435573, 8.607220477344235, 7.674500922383759, 6.709514855767534, 5.874190873546916, 5.782558643448213, 6.743788393008827, 7.717493980983904, 8.635215302628426, 9.624546779123326, 10.688956094484752, 11.725002884015444, 12.680517477044198, 13.634335870961399, 14.480418805181666, 13.49699943592153, 12.487442327151063, 11.540040902173702, 10.577215685226061, 9.593222015403962, 8.654698175088331, 7.641081285836401, 6.701555981037221, 5.70181407531391, 4.935595469553962, 4.836709375900941, 5.794742756440868, 6.790291047672799, 7.672516215811712, 8.732308617969121, 9.738234689275163, 10.77525727524207, 11.67095405430312, 12.701350266620192, 13.62801054062996, 12.65364283720236, 11.665987882902733, 10.710297399670035, 9.691352008808025, 8.641369627566949, 7.674117074172649, 6.661395038754749, 5.7189056227295785, 4.732558461858324, 3.8949281141610834, 3.811360888643133, 4.879063180331741, 5.861125750962796, 6.746746236846866, 7.797723905002, 8.737069852998307, 9.726003526400898, 10.708624895822592, 11.676047576221515, 12.620504329875976, 11.698156555232272, 10.803535297225002, 9.850735829438356, 8.840194336985595, 7.874712834741409, 6.83198613264771, 5.798424540045461, 4.82049660947845, 3.7798031478456657, 2.8456630835993493, 2.882098149465869, 3.8971700136555856, 4.90385268440729, 5.788813429447389, 6.788571838908832, 7.787528318409659, 8.767222595133111, 9.749236542568028, 10.703657743484301, 11.71347861519259, 10.76050431622051, 9.799748384323367, 8.842219556753038, 7.809001333454502, 6.878446206496341, 5.8402642555210855, 4.83540065020645, 3.80169290962238, 2.8395876308130177, 1.9141018538325647, 1.903633880370219, 2.8505071657683545, 3.836538939770278, 4.8566293310883735, 5.923364149303413, 6.878488191092157, 7.834789378961704, 8.851264626366698, 9.876922458907682, 10.682013054505838, 9.750854686703953, 8.730090873523102, 7.801521656060507, 6.861073299403314, 5.854700312236943, 4.859739513713781, 3.8752079188972317, 2.910535281141245, 1.9497318301983055, 0.9498914628668085, 0.9641893678887198, 2.0375997750292787, 2.9987758077585602, 3.9356909877420105, 5.009963910888483, 6.082737651921807, 7.137070864733382, 8.092094596444497, 9.078238986419818, 10.061266109912545, 9.370162176607453, 8.315991975512004, 7.273573599361505, 6.199442389842701, 5.1375031532380655, 4.099980005840079, 3.109116888038908, 2.076904417661451, 1.0348146639871627, 0.0, 1.9919423625635702, 3.0378838834389903, 4.03066691104576, 4.868382699909208, 5.901964062026792, 6.9286001859540285, 7.884120268143158, 8.915376694923095, 9.874288244081963, 10.946695165763687, 10.05274116645609, 9.095786906531238, 8.048362326875749, 7.056572199320588, 6.071550525270449, 5.009381665390212, 4.016361149842448, 3.013947541475801, 2.0014567008188724, 1.023356747849791], [2.0455425892912027, 2.943816105522706, 3.937158441066695, 4.896950594608266, 5.9504172982222405, 6.955115613311091, 7.969397516232929, 9.023506155192933, 10.06304395893285, 10.973884043875637, 9.986318206938387, 8.959842616652235, 7.995899944011841, 7.005907045369738, 6.04930751451516, 5.078271687258497, 4.039770752847897, 3.0739145540065906, 2.0253673133947174, 1.0057308430009486, 2.8750152529977124, 3.820099347350972, 4.798556554144153, 5.8373486735962095, 6.7725020783215095, 7.749715291272311, 8.810741179920385, 9.745966911475076, 10.732713918107537, 11.753829947303087, 10.831758521679554, 9.902125512278289, 8.902080510989586, 7.920804034624835, 6.882282597930202, 5.8759127165926905, 4.912952345447458, 3.867970852389953, 2.881351535349852, 1.934425146793832, 3.8561983361816585, 4.820755169139785, 5.833388016836083, 6.831253373693976, 7.78160583961003, 8.738053737771617, 9.787267451289633, 10.795189389048554, 11.708138228267442, 12.66096717482551, 11.80693437443187, 10.839624958207608, 9.823097441116914, 8.874513445044206, 7.90151355517744, 6.9268883412209, 5.887841836007878, 4.837409907533039, 3.8733950328166036, 2.872191697605522, 4.889192182804075, 5.782164243978932, 6.76638091079798, 7.716192075170053, 8.724689361997278, 9.761825163857559, 10.744704027876509, 11.743788827396283, 12.689467951544396, 13.614533525683102, 12.807317513337708, 11.75363328943321, 10.79000224076982, 9.893933837659953, 8.845819716689826, 7.801711029635231, 6.732219560705437, 5.794089938715887, 4.796553609500554, 3.8590457697653617, 5.788299914739867, 6.819984114033863, 7.716423617154627, 8.755065247151558, 9.719272113614837, 10.65292004232339, 11.64197168759841, 12.584707601221231, 13.567139087120509, 14.598639058721577, 13.660543511982734, 12.683725043921005, 11.765974860246661, 10.783534506263138, 9.720125621087853, 8.763295265140316, 7.712432981876424, 6.75555515946634, 5.790990463992065, 4.850399310711679, 6.735342455340358, 7.690548456837088, 8.68195547044034, 9.709880671939015, 10.738655883417525, 11.586512353146292, 12.62677217999525, 13.509956242006478, 14.482869102442033, 15.468520956062038, 14.719085420074478, 13.705768619973933, 12.727863867224178, 11.756452666510022, 10.690122655095408, 9.642935461148266, 8.668161518352761, 7.662114387013477, 6.725549176516075, 5.825192710212896, 7.7285445434637206, 8.70413003964551, 9.714218065292428, 10.699084100927706, 11.67535635278178, 12.637311248746292, 13.633118983810034, 14.456050188722788, 15.414206253097475, 16.404300983023482, 15.489066508339624, 14.523285504552094, 13.592804966121628, 12.546967300039714, 11.539150519740064, 10.560440861236005, 9.600995547870006, 8.596734250660038, 7.6896674922252375, 6.814234998131271, 8.695750856761862, 9.686418439660619, 10.634029138565753, 11.645708655691237, 12.666465696219214, 13.622773924588298, 14.586686324634778, 15.402558971162888, 16.35602214332574, 17.32322461286828, 16.369781102971267, 15.414102633724278, 14.413588467901516, 13.347506659243601, 12.363231584851466, 11.421138069555113, 10.473813479656453, 9.541955799377929, 8.629386657271013, 7.8225803028632, 9.624350912866019, 10.620481738238325, 11.5869835256827, 12.603236095778088, 13.629977283808422, 14.60481698728794, 15.591320579830287, 16.47123920240347, 17.43099545301403, 18.286286663217634, 17.312770140535157, 16.273043948128134, 15.313380670633387, 14.249652289491708, 13.296043566501929, 12.358304161183145, 11.47642952925176, 10.544179851173258, 9.670757820500112, 8.783132514943897, 9.89099945735189, 10.833973408725777, 11.7366967965984, 12.66069341340595, 13.548350124321988, 14.544536381267008, 15.494960995036456, 16.4303672032633, 17.400168895176602, 18.335564407420538, 18.136046536409314, 17.153197466625862, 16.140804156792736, 15.207251312023173, 14.284745561663582, 13.344235539367505, 12.5103962335797, 11.495874092836498, 10.618680243864741, 9.848596679533891, 8.924368032155455, 9.781342189854813, 10.67901382434937, 11.662490649055355, 12.60438912882859, 13.638999329752444, 14.557143791322217, 15.574233416818247, 16.611152991652613, 17.587981415099254, 18.301698202217825, 17.245703968085586, 16.31455596997932, 15.367586584203934, 14.442386140800469, 13.461548196091863, 12.576058327904475, 11.637575859921641, 10.785333324714179, 9.784883939103278, 7.969794937803996, 8.81184680303832, 9.741106492724736, 10.646395252006077, 11.57966751295449, 12.567221416681694, 13.536631542588811, 14.594044434707094, 15.658051473109555, 16.718119520690085, 17.533362245446927, 16.56903564562318, 15.499982599297779, 14.488729765765566, 13.468001971579147, 12.488774356892689, 11.6213150754724, 10.636767663238587, 9.770194612687668, 8.852421727523023, 6.96259414764528, 7.87602586035467, 8.805639683074348, 9.71509793780413, 10.666701714517304, 11.661437708793525, 12.635091562482538, 13.67653984599159, 14.693279978929144, 15.664637873335211, 16.525309286445694, 15.527017676292937, 14.525053988629534, 13.517587237260884, 12.523962374364729, 11.545275816919299, 10.599162839907804, 9.666443284947329, 8.701457218331104, 7.866133236110485, 5.951773035300017, 6.913002784860631, 7.886708372835709, 8.742174554585347, 9.731506031080247, 10.79591534644167, 11.831962135972363, 12.786762122064177, 13.740580515981378, 14.669357705271437, 15.4889417984851, 14.479384689714633, 13.531983264737272, 12.569158047789632, 11.585164377967532, 10.646640537651901, 9.63302364839997, 8.69349834360079, 7.6937564378774805, 6.927537832117531, 5.005923767752746, 5.963957148292672, 6.959505439524603, 7.779475467768634, 8.839267869926044, 9.845193941232086, 10.88150192026205, 11.7771986993231, 12.807594911640171, 13.734255185649939, 14.60758537709976, 13.657930245466304, 12.702239762233605, 11.683294371371595, 10.633311990130519, 9.66605943673622, 8.65333740131832, 7.710847985293148, 6.724500824421893, 5.886870476724653, 3.980575280494938, 5.048277572183546, 6.030340142814601, 6.853705488803787, 7.904683156958922, 8.844029104955228, 9.832248171420877, 10.81486954084257, 11.782292221241494, 12.726748974895955, 13.652099095129671, 12.795477659788572, 11.842678192001927, 10.832136699549165, 9.86665519730498, 8.82392849521128, 7.790366902609031, 6.81243897204202, 5.771745510409235, 4.837605446162919, 3.049820472976055, 4.064892337165772, 5.071575007917477, 5.895772681404311, 6.895531090865754, 7.89448757036658, 8.87346724015309, 9.855481187588007, 10.80990238850428, 11.847900039321114, 12.75244667878408, 11.791690746886937, 10.834161919316609, 9.800943696018072, 8.870388569059912, 7.832206618084656, 6.8273430127700205, 5.79363527218595, 4.831529993376588, 3.906044216396135, 2.0713562038804056, 3.018229489278541, 4.004261263280465, 4.963588583045295, 5.97126091256177, 6.926384954350515, 7.882686142220061, 8.899161389625055, 9.92481922216604, 10.912862031949187, 11.742797049267523, 10.722033236086672, 9.793464018624077, 8.853015661966884, 7.846642674800513, 6.851681876277351, 5.867150281460802, 4.902477643704815, 3.9416741927618757, 2.9418338254303786, 1.0277529946748503, 2.0649605116509235, 3.026136544380205, 3.9630517243636554, 5.037324647510128, 6.110098388543452, 7.111474208489997, 8.066497940201112, 9.052642330176432, 10.03566945366916, 10.973001032375501, 10.055423015391028, 9.072951151996268, 8.06800948265687, 7.007572635845885, 5.9700494884478985, 4.979186370646728, 4.0434058821542855, 3.026757026550733, 1.9919423625635702, 0.0, 1.0459415208754204, 2.095914480436638, 3.0881100522542733, 4.121691414371856, 5.1483275382990925, 6.103847620488222, 7.135104047268159, 8.094015596427028, 9.166422518108751, 10.048921652303068, 9.091967392378217, 8.044542812722728, 7.052752685167567, 6.067731011117428, 5.005562151237191, 4.012541635689427, 3.0101280273227795, 1.9976371866658509, 1.0195372336967692], [3.0914841101666233, 3.9897576263981263, 4.9830999619421155, 5.942892115483687, 6.9963588190976616, 8.001057134186512, 9.01533903710835, 10.069447676068354, 10.994786924675893, 9.927942523000217, 8.940376686062967, 7.913901095776815, 6.949958423136421, 5.959965524494318, 5.00336599363974, 4.032330166383078, 2.993829231972477, 2.106519465148366, 1.0579722245364929, 2.051672363876369, 3.8782848508190595, 4.823368945172319, 5.801826151965501, 6.8603640130621315, 7.795517417787432, 8.772730630738234, 9.833756519386307, 10.768982250940999, 11.75572925757346, 10.739922258812914, 9.785817000804133, 8.856183991402869, 7.893179281328674, 6.911902804963922, 5.930331386452476, 4.985329537301999, 4.022369166156766, 2.9773876730992606, 1.9907683560591596, 2.9376947446151793, 4.859467934003006, 5.8240247669611325, 6.8366576146574305, 7.834522971515323, 8.804621179075953, 9.76106907723754, 10.810282790755556, 11.818204728514477, 12.625926779915885, 11.673097833357817, 10.76099285355645, 9.793683437332188, 8.871146229639189, 7.922562233566481, 6.949562343699713, 6.036305161930208, 4.997258656717186, 3.9468267282423466, 2.982811853525911, 3.8754612954268697, 5.892461780625423, 6.7854338418002795, 7.7696505086193275, 8.7194616729914, 9.727958959818626, 10.784840503323482, 11.767719367342433, 12.766804166862208, 13.572761251119392, 12.626664184215409, 11.827756583094214, 10.801682077955485, 9.838051029292094, 8.941982626182226, 7.893868505212099, 7.0093172404967214, 5.939825771566928, 5.001696149577377, 4.034759712751336, 4.862315367586709, 6.791569512561215, 7.823253711855211, 8.719693214975974, 9.758334844972905, 10.722541711436184, 11.656189640144737, 12.645241285419758, 13.587977199042578, 14.570408684941857, 13.660658522520652, 12.70859230050501, 11.73177383244328, 10.814023648768936, 9.868590963940765, 8.927731831949345, 7.970901476001807, 6.920039192737915, 5.96316137032783, 5.054744671627946, 5.8536689085330265, 7.738612053161705, 8.693818054658436, 9.685225068261689, 10.713150269760364, 11.741925481238873, 12.58978195096764, 13.630041777816597, 14.513225839827825, 15.48613870026338, 14.638325846942651, 13.767134208596755, 12.753817408496207, 11.815383282809375, 10.909912483194852, 9.8977288659569, 8.850541672009758, 7.875767729214252, 6.925868594649358, 5.989303384151955, 6.8284623080342435, 8.731814141285069, 9.707399637466859, 10.717487663113777, 11.702353698749054, 12.678625950603127, 13.640580846567639, 14.636388581631381, 15.459319786544135, 16.417475850918823, 15.574105873904095, 14.696672719201116, 13.730891715413586, 12.80041117698312, 11.754573510901206, 10.746756730601556, 9.768047072097497, 8.808601758731498, 7.86048845829592, 6.953421699861118, 7.817504595952618, 9.699020454583211, 10.689688037481968, 11.637298736387102, 12.648978253512587, 13.669735294040564, 14.626043522409645, 15.589955922456125, 16.405828568984237, 17.359291741147086, 16.590753519751157, 15.633535310607147, 14.677856841360159, 13.677342675537396, 12.611260866879482, 11.626985792487346, 10.684892277190993, 9.737567687292334, 8.80571000701381, 7.893140864906893, 8.825849900684547, 10.627620510687368, 11.031592059558308, 11.911862331583201, 12.583951900025255, 13.553078883048148, 14.510390960737844, 15.382233022079792, 16.327598048913003, 17.308040342001505, 17.55381557010051, 16.576524348171038, 15.536798155764012, 14.577134878269268, 13.513406497127589, 12.55979777413781, 11.622058368819026, 10.74018373688764, 9.807934058809138, 8.934512028135993, 9.786402112765245, 10.779713648598818, 10.057401819052297, 10.876743096404859, 11.61475189253053, 12.502408603446568, 13.498594860391588, 14.449019474161036, 15.384425682387882, 16.354227374301182, 17.289622886545118, 17.39980074404519, 16.41695167426174, 15.404558364428615, 14.471005519659053, 13.548499769299463, 12.607989747003385, 11.77415044121558, 10.759628300472379, 9.882434451500622, 10.851866277355239, 9.813082223402382, 8.98849343602956, 9.819060124155829, 10.616549128179935, 11.55844760795317, 12.593057808877024, 13.511202270446796, 14.528291895942827, 15.565211470777195, 16.542039894223837, 17.559117889845446, 17.303982623178623, 16.372834625072358, 15.425865239296973, 14.500664795893508, 13.56769333772562, 12.76872522196227, 11.830242753979437, 10.912204388844888, 10.689216039679142, 8.858509129050923, 8.018998049213065, 8.881152792531195, 9.600453731130656, 10.53372599207907, 11.521279895806273, 12.490690021713391, 13.548102913831674, 14.612109952234135, 15.672177999814664, 16.583734366319263, 17.541014632823547, 16.471961586498143, 15.460708752965932, 14.439980958779513, 13.460753344093055, 12.593294062672765, 11.60874665043895, 10.742173599888032, 9.756753828098887, 7.851308338892208, 7.083177106529416, 7.945685982880807, 8.66915641692871, 9.620760193641884, 10.615496187918104, 11.589150041607118, 12.63059832511617, 13.647338458053724, 14.618696352459791, 15.575681407318031, 16.4989966634933, 15.497032975829898, 14.489566224461248, 13.495941361565093, 12.517254804119665, 11.57114182710817, 10.638422272147693, 9.673436205531468, 8.77046533668635, 6.840487226546944, 6.120154031035378, 7.006229039609188, 7.696233033709927, 8.685564510204827, 9.74997382556625, 10.786020615096943, 11.740820601188755, 12.694638995105956, 13.623416184396016, 14.533482624773029, 15.451363676914998, 14.503962251937637, 13.541137034989996, 12.557143365167896, 11.618619524852265, 10.605002635600336, 9.665477330801155, 8.665735425077845, 7.831869932693396, 5.894637958999673, 5.083477815066152, 6.079026106298083, 6.733533946893214, 7.7933263490506235, 8.799252420356666, 9.835560399386628, 10.731257178447677, 11.76165339076475, 12.688313664774517, 13.561643856224338, 14.560919250817342, 13.674218749433969, 12.655273358571959, 11.605290977330883, 10.638038423936583, 9.625316388518684, 8.682826972493512, 7.6964798116222575, 6.858849463925017, 4.869289471741864, 4.125310829720082, 5.0703318988141515, 5.807763967928367, 6.858741636083502, 7.798087584079808, 8.786306650545455, 9.768928019967149, 10.736350700366073, 11.680807454020533, 12.606157574254249, 13.542365444394033, 12.81465717920229, 11.80411568674953, 10.83863418450534, 9.795907482411641, 8.762345889809392, 7.784417959242384, 6.743724497609599, 5.809584433363283, 3.9385346642229813, 3.0598599576164274, 4.026821912999481, 4.849831160528891, 5.849589569990334, 6.84854604949116, 7.827525719277668, 8.809539666712585, 9.763960867628859, 10.801958518445694, 11.807728508392207, 12.763669734087301, 11.806140906516973, 10.772922683218436, 9.842367556260275, 8.804185605285017, 7.799321999970383, 6.765614259386314, 5.803508980576951, 4.8780232035964985, 2.9600703951273317, 2.0131971097291963, 2.9595081683624698, 3.917647062169875, 4.925319391686349, 5.880443433475094, 6.83674462134464, 7.853219868749634, 8.878877701290618, 9.866920511073765, 10.79807887887565, 11.694012223287036, 10.76544300582444, 9.824994649167248, 8.818621662000877, 7.8236608634777145, 6.839129268661165, 5.874456630905178, 4.913653179962239, 3.9138128126307423, 2.0736945155502706, 1.0190189907755032, 1.9801950235047845, 2.917110203488235, 3.991383126634707, 5.06415686766803, 6.065532687614577, 7.0205564193256915, 8.006700809301012, 8.98972793279374, 9.927059511500081, 10.98122971259553, 10.118892672871688, 9.11395100353229, 8.053514156721306, 7.015991009323319, 6.025127891522148, 5.089347403029706, 4.072698547426153, 3.0378838834389903, 1.0459415208754204, 0.0, 1.0499729595612177, 2.042168531378853, 3.0757498934964365, 4.102386017423672, 5.057906099612802, 6.089162526392739, 7.048074075551608, 8.120480997233333, 9.16002850044148, 10.116982760366334, 9.090484333598148, 8.098694206042987, 7.113672531992848, 6.051503672112611, 5.058483156564847, 4.0560695481982, 3.043578707541271, 2.0654787545721893], [4.14145706972784, 5.039730585959344, 6.033072921503333, 6.992865075044905, 8.046331778658878, 9.051030093747729, 10.065311996669566, 10.98435176885459, 9.944813965114674, 8.877969563438999, 7.890403726501749, 6.863928136215597, 5.899985463575202, 4.909992564933099, 3.953393034078522, 2.9823572068218596, 1.9438562724112591, 1.0651274587683726, 2.1079451840977104, 3.1016453234375865, 4.883010061393688, 5.828094155746948, 6.806551362540129, 7.86508922363676, 8.80024262836206, 9.777455841312863, 10.838481729960936, 11.697812335079707, 10.711065328447246, 9.689949299251696, 8.735844041242915, 7.80621103184165, 6.843206321767456, 5.861929845402703, 4.880358426891258, 3.9789302422224604, 3.0159698710772274, 2.0088742495936867, 2.9954935666337876, 3.9424199551898074, 5.8641931445776345, 6.828749977535761, 7.841382825232059, 8.839248182089952, 9.809346389650582, 10.765794287812168, 11.815008001330185, 12.545780135993237, 11.575953820354666, 10.623124873796598, 9.711019893995232, 8.74371047777097, 7.82117327007797, 6.8725892740052625, 5.899589384138495, 5.029905866850671, 3.997915288686972, 2.9791525201687024, 3.943167394885138, 4.880186506001498, 6.897186991200051, 7.790159052374908, 8.774375719193957, 9.72418688356603, 10.732684170393256, 11.78956571389811, 12.77244457791706, 13.478960482851742, 12.522788291558173, 11.57669122465419, 10.777783623532995, 9.751709118394267, 8.788078069730876, 7.892009666621007, 6.843895545650881, 6.021072973882897, 4.951581504953103, 4.034021941503733, 4.995115254110563, 5.867040578161337, 7.796294723135842, 8.827978922429839, 9.724418425550603, 10.763060055547536, 11.727266922010815, 12.660914850719367, 13.649966495994388, 14.509615372607016, 13.544432742500454, 12.610685562959434, 11.65861934094379, 10.68180087288206, 9.764050689207718, 8.818618004379546, 7.914024420325224, 6.982657209387983, 5.93179492612409, 4.995487162254186, 5.972724066792498, 6.858394119107654, 8.743337263736333, 9.698543265233063, 10.689950278836315, 11.71787548033499, 12.7466506918135, 13.59450716154227, 14.634766988391227, 15.434864013392263, 14.554651411402563, 13.588352887381433, 12.717161249035534, 11.703844448934989, 10.765410323248156, 9.859939523633633, 8.909484599343074, 7.862297405395933, 6.887523462600428, 6.043548096686157, 6.907282779316508, 7.833187518608871, 9.736539351859696, 10.712124848041485, 11.722212873688404, 12.70707890932368, 13.683351161177754, 14.64530605714227, 15.641113792206012, 16.380957960108574, 15.537502443456258, 14.524132914342877, 13.665828606257234, 12.7412015075158, 11.810720969085335, 10.766329244287382, 9.758512463987731, 8.779802805483673, 7.820357492117674, 6.978167960332719, 7.8714010950256705, 8.822229806527247, 10.703745665157838, 11.694413248056595, 11.972301332394961, 12.658883977902198, 13.592243796911644, 14.500211103934085, 15.394644357771899, 16.386201804245836, 16.47931833368452, 15.540780560189939, 14.680257433254907, 13.724578964007918, 12.724064798185156, 11.657982989527241, 10.673707915135106, 9.731614399838753, 8.784289809940093, 7.923389509050609, 8.811120260071446, 9.802376571814895, 11.632345721261995, 11.931199372324192, 11.019346945278015, 11.591728980521854, 12.560855963544746, 13.518168041234443, 14.39001010257639, 15.335375129409602, 16.315817422498103, 16.50384261053929, 15.623246470818797, 14.583520278411772, 13.623857000917027, 12.560128619775348, 11.606519896785569, 10.668780491466785, 9.7869058595354, 8.925613560845939, 9.852491423300545, 10.762928783895592, 11.753761793839796, 10.95700913181818, 9.984227710099672, 10.622528973027128, 11.510185683943167, 12.506371940888187, 13.456796554657634, 14.39220276288448, 15.362004454797779, 16.297399967041713, 16.44652286669295, 15.463673796909498, 14.451280487076374, 13.517727642306813, 12.595221891947222, 11.654711869651145, 10.84310856441602, 9.87730780250918, 10.800413846665174, 11.78833308842113, 10.78713036864336, 9.888100748795443, 8.926544737850643, 9.624326208676534, 10.566224688449768, 11.600834889373623, 12.518979350943395, 13.536068976439426, 14.572988551273793, 15.549816974720434, 16.56110317054784, 16.35070474582638, 15.419556747720117, 14.472587361944733, 13.547386918541267, 12.61441546037338, 11.862253515123186, 10.947922256016238, 11.83018378400944, 11.663264184920118, 9.8325572742919, 8.91860536197895, 7.988637406226008, 8.608230811627255, 9.541503072575669, 10.529056976302872, 11.49846710220999, 12.555879994328272, 13.619887032730734, 14.67416328051706, 15.585719647021659, 16.575469451566757, 16.373960105746445, 15.454263419336977, 14.563470249153967, 13.587189299572554, 12.860498989883839, 11.948730452699293, 11.71622174512901, 10.730801973339863, 8.825356484133184, 7.9827844192952995, 7.053170596575621, 7.676933497425309, 8.628537274138482, 9.623273268414703, 10.596927122103716, 11.638375405612768, 12.64932373875612, 13.620681633162187, 14.577666688020427, 15.560138465634072, 16.45297762792539, 15.463614369702226, 14.46998950680607, 13.491302949360643, 12.545189972349148, 11.612470417388671, 10.647484350772446, 9.744513481927326, 7.814535371787922, 7.094202176276356, 6.113713653304002, 6.704010114206525, 7.693341590701426, 8.75775090606285, 9.793797695593542, 10.742805881891151, 11.696624275808352, 12.625401465098411, 13.535467905475425, 14.512505479055768, 15.45990690403313, 14.515185180230974, 13.531191510408874, 12.592667670093244, 11.579050780841314, 10.639525476042133, 9.639783570318823, 8.805918077934372, 6.86868610424065, 6.057525960307129, 5.186510719992897, 5.741311027389813, 6.801103429547222, 7.807029500853265, 8.837545680089024, 9.733242459150073, 10.763638671467145, 11.690298945476913, 12.563629136926734, 13.562904531519738, 14.507800926206077, 13.629321503812937, 12.579339122571861, 11.612086569177562, 10.599364533759662, 9.65687511773449, 8.670527956863236, 7.832897609165995, 5.843337616982842, 5.099358974961059, 4.1220279785965666, 4.815541048424966, 5.8665187165801, 6.805864664576407, 7.788291931247852, 8.770913300669545, 9.738335981068468, 10.682792734722929, 11.608142854956645, 12.544350725096429, 13.577110320958402, 12.778163831990508, 11.812682329746318, 10.76995562765262, 9.73639403505037, 8.758466104483361, 7.717772642850576, 6.78363257860426, 4.9125828094639585, 4.033908102857405, 3.0785179927818964, 3.857608241025489, 4.857366650486933, 5.856323129987759, 6.829510999980065, 7.8115249474149815, 8.765946148331254, 9.80394379914809, 10.809713789094605, 11.874681505381286, 12.78018905175795, 11.746970828459414, 10.816415701501253, 9.778233750525995, 8.773370145211361, 7.739662404627291, 6.777557125817928, 5.852071348837476, 3.934118540368309, 2.9872452549701736, 2.0112042481448844, 2.925424142666473, 3.9273046723887455, 4.8824287141774905, 5.838729902047037, 6.855205149452031, 7.8808629819930145, 8.868905791776163, 9.800064159578048, 10.820827972758899, 11.739491151065419, 10.799042794408226, 9.792669807241856, 8.797709008718693, 7.813177413902143, 6.848504776146156, 5.887701325203217, 4.88786095787172, 3.0664775431570397, 1.9930671360164807, 1.0318911032871991, 1.9248872839848328, 2.9933684073371034, 4.066142148370427, 5.0155597280533595, 5.970583459764474, 6.956727849739794, 7.939754973232521, 8.877086551938863, 9.931256753034312, 10.97367512918481, 10.163923963093508, 9.103487116282523, 8.065963968884535, 7.075100851083365, 6.107571328707211, 5.065481575032923, 4.03066691104576, 2.095914480436638, 1.0499729595612177, 0.0, 0.9921955718176353, 2.0257769339352185, 3.052413057862455, 4.007933140051584, 5.039189566831522, 5.998101115990391, 7.0705080376721146, 8.110055540880264, 9.067009800805117, 10.114434380460606, 9.148667165604206, 8.163645491554066, 7.101476631673828, 6.108456116126064, 5.106042507759417, 4.0935516671024885, 3.1154517141334073], [5.0718481170383605, 6.021492630157911, 7.0148349657019, 7.974627119243472, 9.028093822857446, 10.032792137946297, 11.046264835996958, 9.992156197036953, 8.952618393297037, 7.885773991621362, 6.898208154684113, 5.871732564397962, 4.9077898917575675, 3.9177969931154646, 2.9611974622608868, 1.9901616350042244, 0.9516607005936238, 1.9638526597424648, 3.012399900354338, 4.032036370748107, 5.78173526236778, 6.726819356721039, 7.705276563514221, 8.763814424610851, 9.698967829336151, 10.676181042286954, 11.640842494816763, 10.705616763262071, 9.71886975662961, 8.69775372743406, 7.743648469425279, 6.814015460024016, 5.851010749949821, 4.869734273585069, 3.8881628550736225, 2.986734670404825, 2.023774299259592, 2.907599450567779, 3.89421876760788, 4.8411451561639, 6.762918345551727, 7.727475178509852, 8.740108026206151, 9.737973383064045, 10.708071590624673, 11.66451948878626, 12.57162490888833, 11.553584564175601, 10.58375824853703, 9.630929301978963, 8.718824322177596, 7.751514905953335, 6.828977698260334, 5.880393702187627, 4.90739381232086, 4.037710295033035, 3.005719716869337, 3.8778777211427946, 4.84189259585923, 5.77891170697559, 7.795912192174144, 8.688884253348998, 9.673100920168046, 10.62291208454012, 11.631409371367345, 12.688290914872201, 13.48584971055388, 12.486764911034106, 11.530592719740538, 10.584495652836555, 9.78558805171536, 8.759513546576631, 7.795882497913239, 6.899814094803372, 5.851699973833246, 5.0288774020652625, 3.959385933135468, 4.897515555125018, 5.893840455084655, 6.765765779135429, 8.695019924109936, 9.72670412340393, 10.623143626524692, 11.661785256521625, 12.625992122984904, 13.559640051693457, 14.4601557144122, 13.51741980078938, 12.552237170682819, 11.618489991141798, 10.666423769126155, 9.689605301064425, 8.771855117390082, 7.826422432561912, 6.921828848507589, 5.990461637570348, 4.939599354306456, 5.858980775875471, 6.8362176804137835, 7.757119320081746, 9.642062464710426, 10.597268466207156, 11.588675479810409, 12.616600681309084, 13.645375892787595, 14.493232362516359, 15.475983588508257, 14.442668441574627, 13.562455839584928, 12.596157315563797, 11.724965677217899, 10.711648877117353, 9.77321475143052, 8.867743951816, 7.91728902752544, 6.870101833578298, 5.895327890782793, 6.907041710307443, 7.770776392937793, 8.731912719582963, 10.635264552833789, 11.610850049015578, 12.620938074662497, 12.690781503637082, 13.655714854076864, 14.493478207958455, 15.356016126779007, 15.388762388290937, 14.545306871638623, 13.531937342525241, 12.673633034439598, 11.749005935698165, 10.818525397267699, 9.774133672469745, 8.766316892170094, 7.787607233666036, 6.8281619203000385, 7.8416615739540045, 8.734894708646957, 9.720955007501338, 11.602470866131931, 12.593138449030688, 12.496697710746528, 11.666688406084562, 12.600048225094008, 13.508015532116449, 14.402448785954263, 15.394006232428202, 15.487122761866887, 14.548584988372303, 13.688061861437271, 12.732383392190282, 11.73186922636752, 10.665787417709605, 9.68151234331747, 8.739418828021117, 7.792094238122457, 8.723951918400981, 9.674613873692731, 10.66587018543618, 12.531070922236088, 12.455595750675757, 11.543743323629581, 10.599533408704218, 11.56866039172711, 12.525972469416807, 13.397814530758755, 14.343179557591966, 15.323621850680466, 15.511647038721657, 14.631050899001162, 13.591324706594136, 12.631661429099392, 11.567933047957712, 10.614324324967933, 9.67658491964915, 8.794710287717765, 9.726175970196312, 10.71598503692183, 11.626422397516878, 12.329290301726449, 11.481405510169745, 10.508624088451239, 9.630333401209493, 10.517990112125531, 11.514176369070551, 12.464600982839999, 13.400007191066845, 14.369808882980143, 15.305204395224077, 15.454327294875313, 14.471478225091863, 13.459084915258739, 12.525532070489177, 11.603026320129587, 10.662516297833509, 9.850912992598385, 10.677870211859553, 11.632787129002676, 12.62070637075863, 11.362658876530013, 10.412497127147008, 9.450941116202209, 8.632130636858898, 9.574029116632133, 10.608639317555987, 11.52678377912576, 12.54387340462179, 13.580792979456158, 14.557621402902798, 15.568907598730206, 15.358509174008745, 14.427361175902481, 13.480391790127097, 12.555191346723632, 11.622219888555744, 10.87005794330555, 11.748484665366611, 12.662557066346942, 12.38754708309796, 10.512547312194366, 9.443001740330514, 8.513033784577575, 7.616035239809619, 8.549307500758033, 9.536861404485236, 10.506271530392354, 11.563684422510637, 12.627691460913098, 13.681967708699425, 14.593524075204023, 15.583273879749122, 15.38176453392881, 14.462067847519341, 13.571274677336332, 12.594993727754918, 11.868303418066203, 12.749292862049666, 12.530546080183681, 11.480567196175286, 9.520106231968603, 8.507180797646864, 7.577566974927186, 6.684737925607673, 7.636341702320847, 8.631077696597067, 9.60473155028608, 10.646179833795133, 11.657128166938485, 12.628486061344551, 13.585471116202791, 14.567942893816436, 15.460782056107755, 15.461194447249218, 14.562410505654327, 13.538492267728309, 12.920024143592777, 12.45018620625212, 11.485200139635895, 10.494278704762749, 8.610338037663592, 7.675276370169966, 6.638110031655567, 5.71181454238889, 6.70114601888379, 7.765555334245215, 8.801602123775908, 9.750610310073515, 10.704428703990716, 11.633205893280776, 12.54327233365779, 13.520309907238133, 14.467711332215494, 15.352900969094422, 14.368907299272323, 13.430383458956692, 12.416766569704762, 11.477241264905581, 10.477499359182271, 9.601720743810043, 7.66448877011632, 6.706455389576393, 5.710907098344462, 4.749115455572177, 5.8089078577295865, 6.814833929035629, 7.845350108271388, 8.741046887332438, 9.77144309964951, 10.698103373659277, 11.571433565109098, 12.570708959702102, 13.515605354388441, 14.467037292676386, 13.41705491143531, 12.44980235804101, 11.43708032262311, 10.494590906597939, 9.508243745726684, 8.670613398029444, 6.68105340584629, 5.7964188936307455, 4.81435632299969, 3.8233454766073303, 4.874323144762465, 5.813669092758771, 6.796096359430217, 7.778717728851909, 8.746140409250833, 9.690597162905293, 10.61594728313901, 11.552155153278793, 12.584914749140767, 13.595456241593528, 12.65039811860977, 11.607671416516071, 10.57410982391382, 9.59618189334681, 8.555488431714025, 7.621348367467709, 5.750298598327407, 4.871623891720853, 3.849199598739024, 2.8654126692078536, 3.8651710786692974, 4.864127558170123, 5.837315428162429, 6.819329375597346, 7.773750576513619, 8.811748227330455, 9.81751821727697, 10.88248593356365, 11.805790243256869, 12.584686617322864, 11.654131490364705, 10.615949539389447, 9.611085934074811, 8.57737819349074, 7.615272914681377, 6.689787137700924, 4.7718343292317575, 3.824961043833622, 2.848920037008333, 1.9332285708488377, 2.9351091005711103, 3.890233142359855, 4.846534330229401, 5.863009577634395, 6.888667410175379, 7.876710219958526, 8.807868587760412, 9.828632400941263, 10.757201618403858, 11.636758583271677, 10.630385596105306, 9.635424797582143, 8.650893202765593, 7.686220565009605, 6.725417114066666, 5.725576746735168, 3.9041933320204882, 2.830782924879929, 1.8696068921506477, 0.9326917121671975, 2.0011728355194682, 3.073946576552792, 4.023364156235724, 4.978387887946838, 5.964532277922158, 6.947559401414885, 7.884890980121227, 8.939061181216676, 9.981479557367175, 11.05561076688598, 10.005885853147275, 8.968362705749287, 7.977499587948117, 6.945287117570659, 5.903197363896371, 4.868382699909208, 3.0881100522542733, 2.042168531378853, 0.9921955718176353, 0.0, 1.0335813621175833, 2.0602174860448197, 3.0157375682339485, 4.046993995013886, 5.005905544172755, 6.078312465854479, 7.117859969062628, 8.07481422898748, 9.122238808642969, 10.11402893619813, 9.155841063371701, 8.093672203491463, 7.100651687943699, 6.098238079577053, 5.085747238920124, 4.1076472859510424], [6.105429479155944, 7.055073992275495, 8.048416327819483, 9.008208481361054, 10.061675184975028, 11.024511264019438, 10.013401555973845, 8.95929291701384, 7.919755113273924, 6.852910711598249, 5.865344874661, 4.838869284374848, 3.8749266117344536, 2.884933713092351, 1.9283341822377733, 0.9572983549811108, 1.9852420627112073, 2.997434021860048, 4.045981262471921, 5.0656177328656895, 6.815316624485364, 7.760400718838623, 8.738857925631805, 9.797395786728437, 10.732549191453737, 11.669005103441721, 10.607979214793648, 9.672753483238957, 8.686006476606495, 7.664890447410945, 6.7107851894021655, 5.781152180000902, 4.818147469926708, 3.8368709935619556, 2.855299575050509, 2.0228721137535572, 2.9858324848987903, 3.9411808126853622, 4.927800129725464, 5.874726518281483, 7.7964997076693106, 8.761056540627436, 9.773689388323735, 10.771554745181628, 11.741652952742259, 12.587975342383231, 11.538761628865215, 10.520721284152486, 9.550894968513916, 8.598066021955848, 7.6859610421544815, 6.718651625930221, 5.796114418237221, 4.847530422164514, 3.8745305322977464, 3.0738477383817675, 3.967777902508535, 4.911459083260378, 5.875473957976814, 6.812493069093174, 8.829493554291727, 9.722465615466582, 10.70668228228563, 11.656493446657704, 12.66499073348493, 13.436605933640543, 12.452986430530766, 11.453901631010991, 10.497729439717423, 9.55163237281344, 8.752724771692245, 7.726650266553518, 6.763019217890126, 5.8669508147802585, 4.818836693810132, 4.088850557087228, 4.921444118774666, 5.859573740764216, 6.857110069979549, 7.794617909714741, 9.676767623361556, 10.708451822655551, 11.656724988642276, 12.69536661863921, 13.659573485102488, 14.416344079664107, 13.427292434389086, 12.484556520766265, 11.519373890659704, 10.585626711118683, 9.633560489103044, 8.656742021041312, 7.738991837366968, 6.793559152538798, 5.888965568484475, 5.050434792592314, 5.901657539945653, 6.821038961514669, 7.798275866052982, 8.738867019333368, 10.623810163962046, 11.579016165458777, 12.570423179062029, 13.598348380560704, 14.041480610707834, 14.938099757894092, 14.443120308485142, 13.409805161551512, 12.529592559561813, 11.563294035540682, 10.692102397194787, 9.67878559709424, 8.740351471407408, 7.8348806717928845, 6.918423445272353, 6.00905622142954, 6.8573860764219905, 7.86909989594664, 8.732834578576991, 9.713660418834584, 11.61701225208541, 12.592597748267199, 13.602685773914118, 13.724362865754665, 13.0495375084125, 13.887300862294092, 14.716557963672232, 14.355899108267822, 13.512443591615508, 12.499074062502126, 11.640769754416487, 10.716142655675052, 9.785662117244586, 8.828623507107677, 7.976559639796753, 7.0011560309725045, 7.790220105939236, 8.803719759593202, 9.696952894286154, 10.702306830679971, 12.584218565383551, 13.574886148282308, 13.530279072864111, 12.700269768202146, 11.993870879429645, 12.901838186452085, 13.762990622847488, 14.717018250236073, 14.454259481843772, 13.515721708349188, 12.673949088176323, 11.718270618929335, 10.717756453106572, 9.896783736688025, 8.94680948233356, 8.017136501752006, 8.754152423761655, 9.686010104040179, 10.636672059331929, 11.627928371075377, 13.512818621487709, 13.489177112793342, 12.577324685747165, 11.633114770821802, 10.962483046062747, 11.919795123752444, 12.75835636765198, 13.648338018995489, 14.607044508299024, 14.478783758698542, 13.659810561995736, 12.62008436958871, 11.660421092093966, 10.845650721688601, 9.892041998698822, 8.954302593380039, 9.756768473356962, 10.68823415583551, 11.678043222561028, 12.588480583156075, 13.362871663844034, 12.51498687228733, 11.542205450568822, 10.663914763327076, 9.911812766461168, 10.907999023406187, 11.825142819733223, 12.705165652470367, 13.653231540598702, 14.588627052842636, 14.604349422128134, 13.621500352344684, 12.67375731662367, 11.803249744220066, 10.880743993860476, 9.940233971564398, 10.812971178237582, 11.63992839749875, 12.594845314641873, 13.582764556397827, 12.396240238647598, 11.446078489264593, 10.484522478319793, 9.665711998976482, 8.967851770967771, 9.984942217707399, 10.887325616018984, 11.778896371371646, 12.674071791303986, 13.639306847297412, 14.535326236612626, 14.6328619304306, 13.701713932324337, 12.758109463857986, 11.83290902045452, 10.899937562286633, 11.832116128944747, 12.710542851005808, 13.624615251986139, 13.421128445215546, 11.546128674311952, 10.4765831024481, 9.546615146695158, 8.649616601927203, 7.925610400909447, 8.91316430463665, 9.866813367285578, 10.798707389260493, 11.631360739663814, 12.648386346581841, 13.559942713086443, 14.549692517631541, 14.656117290350664, 13.73978552125023, 12.84899235106722, 11.872711401485807, 12.8303616037054, 13.711351047688863, 13.564127442301267, 12.514148558292872, 10.553687594086188, 9.54076215976445, 8.61114833704477, 7.718319287725257, 6.898266389040016, 7.884803224225929, 8.858457077914943, 9.729002948135202, 10.6235468048209, 11.594904699226968, 12.55188975408521, 13.534361531698854, 14.427200693990173, 14.738912120980107, 13.840128179385216, 12.816209941459197, 13.762322918470693, 13.483767568369704, 12.518781501753478, 11.527860066880335, 9.643919399781176, 8.70885773228755, 7.671691393773151, 6.7453959045064735, 5.963070705602959, 6.923640582686719, 7.885145224948152, 8.717028947955932, 9.670847341873134, 10.599624531163194, 11.509690971540207, 12.48672854512055, 13.434129970097912, 14.396955187045553, 14.693754406801725, 13.753736730819057, 13.450347931822346, 12.510822627023165, 11.511080721299855, 10.635302105927627, 8.698070132233903, 7.740036751693977, 6.744488460462046, 5.782696817689761, 5.02563068159502, 5.8881896028741005, 6.811768746153805, 7.707465525214855, 8.737861737531928, 9.664522011541695, 10.537852202991516, 11.53712759758452, 12.48202399227086, 13.500969383132869, 14.450636273552893, 13.483383720158594, 12.470661684740694, 11.528172268715522, 10.541825107844268, 9.704194760147027, 7.714634767963874, 6.830000255748329, 5.847937685117274, 4.856926838724914, 3.9851846354953766, 4.857882173016132, 5.762514997312634, 6.745136366734326, 7.71255904713325, 8.657015800787711, 9.582365921021427, 10.518573791161211, 11.551333387023185, 12.561874879475946, 13.624722598988551, 12.641252778633655, 11.607691186031404, 10.629763255464393, 9.589069793831609, 8.654929729585293, 6.783879960444991, 5.905205253838437, 4.882780960856607, 3.898994031325437, 2.9253047760991384, 3.908340638427484, 4.803734066044846, 5.785748013479763, 6.740169214396036, 7.778166865212871, 8.783936855159386, 9.848904571446067, 10.772208881139287, 11.611996646994657, 12.625548518757686, 11.649530901507031, 10.644667296192395, 9.610959555608323, 8.64885427679896, 7.723368499818508, 5.805415691349341, 4.858542405951206, 3.8825013991259163, 2.966809932966421, 1.9015277384535272, 2.856651780242272, 3.8129529681118184, 4.8294282155168125, 5.855086048057796, 6.843128857840943, 7.774287225642829, 8.795051038823681, 9.723620256286276, 10.664068612943469, 11.66396695822289, 10.669006159699727, 9.684474564883176, 8.71980192712719, 7.758998476184249, 6.759158108852752, 4.937774694138072, 3.8643642869975126, 2.903188254268231, 1.9662730742847807, 0.967591473401885, 2.0403652144352087, 2.989782794118141, 3.9448065258292555, 4.9309509158045755, 5.913978039297302, 6.8513096180036435, 7.905479819099092, 8.947898195249591, 10.022029404768396, 11.039467215264859, 10.001944067866871, 9.0110809500657, 7.978868479688243, 6.936778726013954, 5.901964062026791, 4.121691414371856, 3.075749893496436, 2.0257769339352185, 1.0335813621175833, 0.0, 1.0266361239272364, 1.9821562061163653, 3.013412632896303, 3.9723241820551722, 5.044731103736896, 6.084278606945045, 7.041232866869897, 8.088657446525385, 9.080447574080546, 10.065469248130686, 9.127253565609047, 8.134233050061283, 7.131819441694636, 6.119328601037707, 5.141228648068625], [7.107028404305813, 8.056672917425363, 9.050015252969352, 10.009807406510923, 11.002573455181052, 9.997875140092201, 9.047144102922772, 8.00826296096988, 6.968725157229963, 5.901880755554289, 4.914314918617039, 3.8878393283308874, 2.9238966556904935, 1.933903757048391, 0.9773042261938134, 1.9483400534504758, 2.9868409878610764, 3.9990329470099173, 5.04758018762179, 6.067216658015559, 7.792717176346801, 8.73780127070006, 9.716258477493243, 10.774796338589875, 11.695188360348563, 10.71797514739776, 9.656949258749687, 8.721723527194996, 7.734976520562535, 6.713860491366985, 5.759755233358205, 4.830122223956941, 3.867117513882747, 2.885841037517995, 1.9042696190065493, 2.910639500344061, 3.873599871489294, 4.9185813645467995, 5.9052006815869005, 6.85212707014292, 8.773900259530746, 9.738457092488874, 10.751089940185173, 11.748955297043066, 12.635415004363281, 11.63694538633927, 10.587731672821254, 9.569691328108526, 8.599865012469955, 7.6470360659118874, 6.734931086110521, 5.76762166988626, 4.845084462193261, 3.896500466120554, 2.9235005762537867, 3.9616151249722713, 4.855545289099038, 5.888859635121815, 6.85287450983825, 7.789893620954611, 9.747269476564815, 10.699866167328022, 11.68408283414707, 12.633893998519143, 13.554332460608675, 12.485575977596582, 11.501956474486805, 10.50287167496703, 9.546699483673462, 8.60060241676948, 7.801694815648284, 6.7756203105095585, 5.811989261846167, 4.915920858736299, 3.8678067377661725, 4.941979944106871, 5.80921150536517, 6.74734112735472, 7.744877456570053, 8.682385296305245, 10.564535009952062, 11.596219209246058, 12.564061783300385, 13.603744484179689, 14.398962052328699, 13.465314123620146, 12.476262478345125, 11.533526564722305, 10.568343934615744, 9.634596755074723, 8.682530533059083, 7.7057120649973525, 6.7879618813230085, 5.842529196494838, 4.937935612440516, 5.894765968388052, 6.789424926536157, 7.708806348105173, 8.686043252643486, 9.626634405923873, 11.511577550552552, 12.466783552049282, 13.458190565652535, 14.48611576715121, 15.06811673463507, 14.273518928041762, 13.492090352441181, 12.458775205507552, 11.578562603517852, 10.612264079496722, 9.741072441150827, 8.727755641050281, 7.789321515363447, 6.883850715748925, 5.967393489228392, 6.853387397225278, 7.745153463012494, 8.756867282537144, 9.620601965167495, 10.60142780542509, 12.504779638675915, 13.480365134857704, 14.490453160504623, 14.750998989681902, 14.076173632339737, 13.222720032441762, 13.895556433479335, 13.404869152223862, 12.561413635571547, 11.548044106458166, 10.689739798372527, 9.765112699631091, 8.834632161200625, 7.8775935510637165, 7.025529683752793, 7.845487206768243, 8.67798749252974, 9.691487146183706, 10.584720280876658, 11.590074217270475, 13.471985951974057, 14.462653534872814, 14.556915196791346, 13.726905892129382, 13.020507003356881, 12.237257356599756, 12.941989092654591, 13.819754936234588, 13.503229525799812, 12.564691752305228, 11.722919132132363, 10.767240662885374, 9.766726497062612, 8.945753780644065, 7.995779526289599, 8.861467677547745, 9.641919810352158, 10.573777490630683, 11.524439445922432, 12.515695757665881, 14.400586008078214, 14.515813236720577, 13.6039608096744, 12.659750894749038, 11.989119169989984, 11.255214293900114, 11.937354837459083, 12.751074704994004, 13.70978119429754, 13.527753802654582, 12.708780605951775, 11.66905441354475, 10.709391136050005, 9.939851973481353, 9.011381428839186, 9.798633769175778, 10.644535859947466, 11.576001542426013, 12.565810609151532, 13.476247969746579, 14.389507787771269, 13.541622996214565, 12.568841574496057, 11.690550887254313, 10.938448890388404, 10.243418193553858, 11.004141289540327, 11.807902338468882, 12.755968226597217, 13.69136373884115, 13.653319466084174, 12.670470396300724, 11.722727360579709, 10.897450996012818, 10.00008342400084, 10.784565147360137, 11.700738564828086, 12.527695784089254, 13.482612701232377, 14.47053194298833, 13.422876362574833, 12.472714613191828, 11.511158602247027, 10.692348122903718, 9.994487894895007, 9.28747956520911, 10.066324085826087, 10.881633057370161, 11.7768084773025, 12.742043533295927, 13.638062922611141, 13.68183197438664, 12.750683976280376, 11.87744889399835, 10.952248450594885, 11.744268738082372, 12.719883515535251, 13.598310237596312, 14.512382638576643, 14.44776456914278, 12.572764798239186, 11.503219226375334, 10.573251270622393, 9.67625272585444, 8.952246524836683, 8.215701652138362, 9.045811837092682, 9.901444075259008, 10.734097425662329, 11.751123032580356, 12.662679399084958, 13.652429203630057, 13.705087334306704, 12.859124951390594, 11.968331781207585, 12.717042577281546, 13.675341038156166, 14.599118434279367, 14.590763566228501, 13.540784682220107, 11.580323718013423, 10.567398283691684, 9.637784460972005, 8.744955411652493, 7.924902512967252, 7.154909260617923, 8.037455547722047, 8.831739634133717, 9.726283490819416, 10.697641385225483, 11.654626440083725, 12.63709821769737, 13.529937379988688, 13.858251551120471, 12.99723644107234, 13.660541117254937, 14.606654094266432, 14.510403692296936, 13.545417625680711, 12.55449619080757, 10.670555523708412, 9.735493856214786, 8.698327517700386, 7.772032028433709, 6.989706829530196, 6.193746619078713, 6.987881910946666, 7.819765633954447, 8.773584027871648, 9.702361217161709, 10.612427657538722, 11.589465231119066, 12.536866656096427, 13.499691873044068, 13.936034437469537, 14.598067906614796, 14.476984055749579, 13.537458750950398, 12.537716845227088, 11.661938229854863, 9.72470625616114, 8.766672875621213, 7.771124584389281, 6.809332941616996, 6.052266805522256, 5.158295639266094, 5.914505432152319, 6.810202211213369, 7.840598423530441, 8.76725869754021, 9.640588888990031, 10.639864283583035, 11.584760678269374, 12.603706069131384, 13.65368845037246, 14.510019844085827, 13.497297808667927, 12.554808392642755, 11.5684612317715, 10.730830884074262, 8.741270891891109, 7.856636379675565, 6.874573809044509, 5.8835629626521495, 5.011820759422613, 4.127988209408126, 4.865251683311148, 5.84787305273284, 6.815295733131764, 7.759752486786225, 8.685102607019942, 9.621310477159726, 10.6540700730217, 11.663076173787877, 12.67858536181828, 13.667888902560888, 12.634327309958639, 11.65639937939163, 10.615705917758843, 9.681565853512527, 7.810516084372226, 6.931841377765672, 5.909417084783843, 4.925630155252673, 3.9519409000263748, 3.1784466748194777, 3.9064707520433606, 4.888484699478277, 5.84290590039455, 6.880903551211385, 7.806405001506576, 8.871372717793257, 9.792095404401413, 10.631883170256783, 11.645435042019812, 12.676167025434264, 11.67130342011963, 10.63759567953556, 9.675490400726197, 8.750004623745744, 6.832051815276577, 5.885178529878441, 4.909137523053152, 3.9934460568936574, 2.9281638623807633, 2.126757816634266, 2.9156896541103325, 3.9321649015153266, 4.920025327006178, 5.908068136789325, 6.7967553719900184, 7.814937562085809, 8.743506779548403, 9.683955136205595, 10.690328123371966, 11.685288921895129, 10.711110688810411, 9.746438051054424, 8.785634600111484, 7.785794232779987, 5.964410818065307, 4.8910004109247485, 3.9298243781954674, 2.992909198212017, 1.9942275973291212, 1.0694901712591098, 1.9631466701909044, 2.9181704019020187, 3.9043147918773387, 4.887341915370065, 5.824673494076407, 6.878843695171856, 7.921262071322355, 8.99539328084116, 10.057332517445795, 11.028580191794106, 10.037717073992935, 9.005504603615478, 7.96341484994119, 6.928600185954027, 5.1483275382990925, 4.102386017423672, 3.052413057862455, 2.0602174860448197, 1.0266361239272364, 0.0, 0.955520082189129, 1.9867765089690665, 2.945688058127936, 4.01809497980966, 5.057642483017808, 6.01459674294266, 7.06202132259815, 8.05381145015331, 9.03883312420345, 10.101001984083688, 9.16086917398852, 8.158455565621873, 7.145964724964943, 6.167864771995862], [8.062548486494942, 9.012192999614491, 10.00553533515848, 10.965327488700051, 10.047053372991922, 9.042355057903071, 8.091624020733642, 7.060009061134541, 6.0204712573946235, 4.953626855718949, 3.966061018781699, 2.9395854284955476, 1.9756427558551537, 0.9856498572130512, 1.9328243083829424, 2.9038601356396048, 3.942361070050205, 4.954553029199046, 6.003100269810918, 7.022736740204687, 8.748237258535928, 9.693321352889187, 10.67177855968237, 11.682087865238524, 10.746934460513224, 9.76972124756242, 8.708695358914348, 7.773469627359656, 6.786722620727195, 5.765606591531645, 4.811501333522865, 3.8818683241216014, 2.9188636140474076, 1.9375871376826554, 2.859789701195678, 3.8661595825331894, 4.829119953678422, 5.874101446735927, 6.860720763776028, 7.807647152332048, 9.729420341719875, 10.693977174678, 11.7066100223743, 12.704475379232193, 11.687161104527942, 10.68869148650393, 9.639477772985915, 8.621437428273186, 7.651611112634615, 6.698782166076548, 5.786677186275181, 4.8193677700509205, 3.9082893812320294, 2.959705385159322, 3.879020658442916, 4.917135207161399, 5.811065371288167, 6.844379717310943, 7.808394592027378, 8.745413703143738, 10.702789558753942, 11.655386249517147, 12.639602916336194, 13.589414080708268, 12.606078560773335, 11.537322077761242, 10.553702574651465, 9.55461777513169, 8.598445583838123, 7.65234851693414, 6.853440915812945, 5.831731474529362, 4.875194180884935, 4.0065655941269664, 4.823326819955302, 5.897500026296, 6.764731587554298, 7.7028612095438485, 8.70039753875918, 9.637905378494372, 11.52005509214119, 12.551739291435187, 13.519581865489513, 14.414915018956638, 13.450708152493359, 12.517060223784807, 11.528008578509786, 10.585272664886965, 9.620090034780404, 8.686342855239383, 7.7386416970788865, 6.761823229017156, 5.851166800361777, 4.933173931885506, 5.893455694629645, 6.850286050577181, 7.744945008725285, 8.664326430294302, 9.641563334832615, 10.582154488113002, 12.46709763274168, 13.42230363423841, 14.413710647841663, 15.413928389300324, 14.388259594322905, 13.450652534607709, 12.543836452605841, 11.510521305672212, 10.630308703682513, 9.664010179661382, 8.79718360517063, 7.783866805070084, 6.8525264344022165, 5.9744954511395925, 6.9229135714175225, 7.808907479414407, 8.700673545201623, 9.712387364726274, 10.576122047356623, 11.556947887614218, 13.460299720865043, 14.435885217046833, 15.445973242693752, 15.695882552582775, 14.918644935613857, 13.958591744874749, 12.940036351290207, 12.456615252388522, 11.613159735736208, 10.599790206622826, 9.74585096239233, 8.82831761866986, 7.897837080239395, 6.968238286454384, 7.976055066754035, 8.801007288957372, 9.633507574718868, 10.647007228372836, 11.540240363065786, 12.545594299459603, 14.427506034163185, 15.418173617061942, 15.501798759692223, 14.671789455030256, 13.862978306631002, 12.973129069032742, 11.986469010465463, 12.864234854045456, 12.554975625964472, 11.616437852469888, 10.783569504514546, 9.830445581924144, 8.829931416101381, 8.036398516034733, 8.946304909290841, 9.816987759736874, 10.597439892541287, 11.52929757281981, 12.47995952811156, 13.47121583985501, 15.356106090267343, 15.460696799621454, 14.548844372575276, 13.604634457649912, 12.831590473264104, 12.005905539611557, 10.981834755269954, 11.795554622804872, 12.754261112108411, 12.579499902819242, 11.771985524990543, 10.732259332583517, 9.772596055088773, 9.030496708872022, 9.961906811840429, 10.754153851364906, 11.600055942136594, 12.531521624615142, 13.52133069134066, 14.431768051935707, 15.334391350672146, 14.486506559115442, 13.513725137396934, 12.635434450155186, 11.780920193662524, 10.995616465312064, 10.048621207351198, 10.852382256279752, 11.800448144408088, 12.735843656652023, 12.716524385122941, 11.733675315339491, 10.785932279618477, 9.988095731403487, 10.950608807002082, 11.740085229549265, 12.656258647017214, 13.483215866278382, 14.438132783421505, 15.426052025177459, 14.36775992547571, 13.417598176092705, 12.456042165147904, 11.637231685804592, 10.836959198169126, 10.039677836967318, 9.110804003636959, 9.92611297518103, 10.821288395113372, 11.786523451106799, 12.682542840422009, 12.745036893425407, 11.813888895319144, 11.03449460837573, 11.902773833596127, 12.6997888202715, 13.67540359772438, 14.55383031978544, 15.467902720765771, 15.392648132043657, 13.517648361140063, 12.448102789276211, 11.51813483352327, 10.621136288755313, 9.794717828110802, 8.967899923896567, 8.090291754903554, 8.945923993069878, 9.7785773434732, 10.795602950391228, 11.707159316895826, 12.696909121440925, 12.768292253345471, 12.016170665767975, 12.918857164208827, 13.672562659470675, 14.630861120345294, 15.554638516468495, 15.535647129129378, 14.485668245120983, 12.5252072809143, 11.512281846592561, 10.582668023872882, 9.689838974553368, 8.76737381624137, 7.907107532376128, 7.081935465532918, 7.876219551944588, 8.770763408630287, 9.742121303036354, 10.699106357894594, 11.68157813550824, 12.574417297799558, 13.015297265497852, 13.947761824073583, 14.616061199444065, 15.56217417645556, 15.465923774486068, 14.500937707869843, 13.499379753708446, 11.615439086609289, 10.680377419115663, 9.643211080601263, 8.716915591334585, 7.832178132804313, 6.945944890836918, 6.032361828757537, 6.864245551765317, 7.818063945682519, 8.746841134972579, 9.656907575349592, 10.633945148929936, 11.581346573907297, 12.544171790854937, 13.528165460677037, 14.468183136659706, 15.432504137938711, 14.49297883313953, 13.49323692741622, 12.60682179275574, 10.669589819062017, 9.71155643852209, 8.716008147290157, 7.754216504517872, 6.894738108796374, 5.910493911024299, 4.95898534996319, 5.85468212902424, 6.885078341341313, 7.811738615351081, 8.685068806800901, 9.684344201393905, 10.629240596080244, 11.648185986942254, 12.69816836818333, 13.66542092157763, 14.452817890857059, 13.510328474831887, 12.523981313960633, 11.686350966263392, 9.696790974080239, 8.80151994257644, 7.8194573719453855, 6.828446525553026, 5.8542920626967305, 4.880186481166331, 3.9097316011220187, 4.892352970543711, 5.859775650942635, 6.804232404597096, 7.729582524830812, 8.665790394970596, 9.69854999083257, 10.707556091598748, 11.723065279629152, 12.738208453232719, 13.58984739214777, 12.61191946158076, 11.571225999947973, 10.637085935701657, 8.766036166561356, 7.887361459954802, 6.8543006476847195, 5.870513718153549, 4.895371839225106, 3.9306449465776834, 2.9509506698542314, 3.932964617289148, 4.887385818205421, 5.925383469022256, 6.850884919317446, 7.915852635604126, 8.836575322212285, 9.676363088067655, 10.689914959830684, 11.746486576106095, 12.62682350230876, 11.59311576172469, 10.631010482915327, 9.705524705934874, 7.787571897465706, 6.840698612067571, 5.864657605242281, 4.938329619794533, 3.8715948015794943, 2.9164707597907498, 1.9601695719212033, 2.9766448193261974, 3.9645052448170492, 4.9525480546001965, 5.841235289800889, 6.859417479896679, 7.7879866973592735, 8.728435054016467, 9.734808041182838, 10.729768839706, 11.666630770999541, 10.701958133243554, 9.741154682300614, 8.741314314969117, 6.919930900254437, 5.846520493113878, 4.885344460384596, 3.948429280401146, 2.9497476795182505, 2.025010253448239, 1.0076265880017754, 1.9626503197128897, 2.94879470968821, 3.9318218331809365, 4.869153411887278, 5.923323612982727, 6.965741989133226, 8.039873198652032, 9.101812435256667, 10.139335582654654, 10.993237156182065, 9.961024685804608, 8.91893493213032, 7.884120268143157, 6.103847620488222, 5.057906099612802, 4.007933140051584, 3.0157375682339485, 1.9821562061163653, 0.955520082189129, 0.0, 1.0312564267799376, 1.9901679759388067, 3.0625748976205305, 4.102122400828679, 5.059076660753531, 6.10650124040902, 7.098291367964181, 8.08331304201432, 9.145481901894557, 10.116389256177648, 9.113975647811001, 8.101484807154073, 7.123384854184991], [9.09380491327488, 10.04344942639443, 11.003176170914566, 10.043384017372995, 9.015796946211985, 8.011098631123135, 7.060367593953705, 6.053764115085385, 5.0142263113454675, 3.984528836114557, 2.996962999177308, 1.9704874088911561, 1.0446144447957488, 2.0169062839929888, 2.96408073516288, 3.9351165624195423, 4.973617496830142, 5.985809455978983, 7.034356696590857, 8.053993166984625, 9.779493685315865, 10.724577779669124, 11.703034986462306, 10.712989845634132, 9.777836440908832, 8.80062322795803, 7.739597339309956, 6.8043716077552645, 5.817624601122804, 4.796508571927254, 3.842403313918474, 2.9127703045172098, 2.110181645175733, 2.968843564462593, 3.8910461279756157, 4.897416009313127, 5.8603763804583595, 6.9053578735158645, 7.8919771905559655, 8.838903579111985, 10.760676768499811, 11.725233601457937, 12.737866449154236, 11.741883718787097, 10.718063084923552, 9.719593466899541, 8.670379753381525, 7.652339408668796, 6.682513093030225, 5.729684146472157, 4.81757916667079, 3.850269750446529, 3.131741560832767, 3.9909618119392594, 4.910277085222853, 5.948391633941338, 6.842321798068104, 7.87563614409088, 8.839651018807315, 9.776670129923675, 11.73404598553388, 12.686642676297083, 13.595288992368245, 12.64547782799617, 11.636980541168946, 10.568224058156853, 9.584604555047076, 8.5855197555273, 7.629347564233732, 6.683250497329749, 5.884342896208553, 4.86263345492497, 4.098646360485672, 5.037822020906904, 5.854583246735239, 6.928756453075938, 7.7959880143342355, 8.734117636323786, 9.731653965539119, 10.66916180527431, 12.551311518921127, 13.582995718215123, 14.485499700231552, 13.445816999352248, 12.481610132888969, 11.547962204180417, 10.558910558905396, 9.616174645282575, 8.650992015176012, 7.717244835634993, 6.769543677474495, 5.792725209412764, 5.074618979962514, 5.964430358665443, 6.924712121409582, 7.881542477357119, 8.776201435505223, 9.695582857074239, 10.672819761612551, 11.613410914892938, 13.498354059521617, 14.453560061018347, 15.4449670746216, 14.444830369695934, 13.419161574718515, 12.48155451500332, 11.574738433001452, 10.541423286067822, 9.661210684078121, 8.694912160056992, 7.82808558556624, 6.814768785465692, 6.075978614002953, 7.00575187791953, 7.954169998197459, 8.840163906194345, 9.731929971981561, 10.74364379150621, 11.60737847413656, 12.588204314394154, 14.49155614764498, 15.46714164382677, 16.451073136935378, 15.387376928867923, 14.41110467701385, 13.532353410603319, 12.50281855341609, 11.487517232784132, 10.644061716131816, 9.630692187018436, 8.776752942787938, 7.865324799924017, 7.121289259840131, 7.999494713234322, 9.007311493533972, 9.83226371573731, 10.664764001498806, 11.678263655152772, 12.571496789845723, 13.57685072623954, 15.458762460943122, 16.44943004384188, 16.485085976426596, 15.65507667176463, 14.846265523365373, 13.953227184940719, 12.96656712637344, 12.105165712798033, 11.58587760636008, 10.647339832865498, 9.814471484910154, 8.897127747928408, 8.053383595702117, 9.06765494281467, 9.97756133607078, 10.848244186516812, 11.628696319321225, 12.56055399959975, 13.511215954891497, 14.502472266634946, 16.38736251704728, 16.443984016355827, 15.53213158930965, 14.587921674384287, 13.814877689998475, 12.986003655519532, 11.96193287117793, 11.036485481557449, 11.790714170060589, 11.610401883214852, 10.866411983382903, 9.84829523680531, 8.99604823468951, 10.05977661583119, 10.993163238620367, 11.785410278144845, 12.631312368916532, 13.562778051395078, 14.552587118120597, 15.463024478715644, 16.31767856740652, 15.469793775849816, 14.497012354131307, 13.618721666889561, 12.764207410396896, 11.978903682046436, 11.028719323259175, 10.093313115032329, 10.836901202360266, 11.7722967146042, 11.832560289344734, 10.849711219561284, 10.009384459219214, 10.942937303988776, 11.98186523378202, 12.771341656329204, 13.687515073797154, 14.514472293058319, 15.469389210201442, 16.457308451957395, 15.351047142210083, 14.400885392827078, 13.439329381882278, 12.620518902538967, 11.820246414903497, 11.02296505370169, 10.09409122037133, 9.167043833933608, 9.85774145306555, 10.822976509058975, 11.718995898374189, 11.880072877656557, 11.037341074919881, 11.984310460695266, 12.909510904098731, 13.731045247051439, 14.70666002450432, 15.585086746565377, 16.499159147545708, 16.37593534877803, 14.500935577874436, 13.431390006010584, 12.501422050257643, 11.604423505489688, 10.778005044845173, 9.951187140630939, 9.073578971637925, 8.186854851822455, 8.815030401425378, 9.832056008343404, 10.743612374848006, 11.733362179393104, 11.99174443294621, 12.96598651808751, 13.925594234711431, 14.703819086250613, 15.662117547125233, 16.58589494324843, 16.51893434586375, 15.468955461855357, 13.508494497648673, 12.495569063326935, 11.565955240607256, 10.673126191287741, 9.750661032975742, 8.8903947491105, 8.06522268226729, 7.117150410697165, 7.807216466582465, 8.77857436098853, 9.735559415846774, 10.718031193460419, 11.610870355751738, 12.622787326892064, 13.503416515026414, 14.442162983971745, 15.38827596098324, 16.358522544329993, 15.525055047194646, 14.48266697044282, 12.59872630334366, 11.663664635850036, 10.626498297335637, 9.700202808068958, 8.815465349538686, 7.92923210757129, 7.01564904549191, 6.1051764105178945, 6.854517003634697, 7.7832941929247585, 8.693360633301772, 9.670398206882115, 10.617799631859477, 11.580624848807117, 12.564618518629217, 13.504636194611885, 14.537127215237495, 15.524235259919466, 14.524493354196157, 13.590109009490112, 11.65287703579639, 10.694843655256463, 9.69929536402453, 8.737503721252246, 7.878025325530746, 6.893781127758672, 5.942272566697563, 5.095612987776817, 5.921531399293491, 6.84819167330326, 7.721521864753081, 8.720797259346085, 9.665693654032424, 10.684639044894434, 11.73462142613551, 12.68140380080344, 13.666473877124204, 14.541584901611824, 13.55523774074057, 12.704519464595545, 10.728047400860175, 9.784807159310812, 8.802744588679758, 7.811733742287398, 6.837579279431103, 5.863473697900703, 4.893018817856391, 4.133283829296288, 4.896228708894814, 5.840685462549275, 6.766035582782991, 7.702243452922775, 8.73500304878475, 9.713156024280435, 10.728665212310839, 11.743808385914406, 12.643116988352466, 13.643175888360698, 12.602482426727912, 11.668342362481596, 9.797292593341293, 8.875909799991582, 7.837587864419092, 6.853800934887921, 5.878659055959478, 4.913932163312055, 3.9342378865886034, 3.0708678904618467, 3.9139158407095165, 4.951913491526351, 5.856484851999133, 6.921452568285813, 7.84217525489397, 8.681963020749341, 9.69551489251237, 10.752086508787782, 11.680093098513456, 12.624372188504628, 11.662266909695266, 10.736781132714812, 8.818828324245644, 7.871955038847509, 6.89591403202222, 5.921616836528906, 4.854882018313867, 3.899757976525122, 2.9434567886555754, 2.1009123058830186, 2.9701051774987346, 3.9581479872818823, 4.846835222482575, 5.865017412578365, 6.793586630040959, 7.734034986698153, 8.740407973864524, 9.735368772387687, 10.719900367204238, 11.684573004960225, 10.772411109080553, 9.772570741749055, 7.951187327034376, 6.877776919893816, 5.916600887164535, 4.979685707181084, 3.981004106298188, 3.045247017547723, 1.9909138047361474, 1.035890073025033, 1.9543946423698952, 2.937421765862622, 3.8747533445689637, 4.9289235456644125, 5.971341921814911, 7.045473131333716, 8.07728822342195, 9.114811370819938, 10.073890725619684, 10.992281112584546, 9.950191358910258, 8.915376694923095, 7.13510404726816, 6.08916252639274, 5.0391895668315225, 4.046993995013887, 3.013412632896303, 1.9867765089690665, 1.0312564267799376, 0.0, 0.9589115491588691, 2.031318470840593, 3.0708659740487416, 4.027820233973594, 5.075244813629083, 6.067034941184243, 7.052056615234382, 8.114225475114619, 9.107245990662383, 10.10965959902903, 9.132741233934011, 8.15464128096493], [10.051835139981362, 11.001479653100912, 10.044264621755698, 9.084472468214127, 8.056885397053117, 7.052187081964266, 6.101456044794836, 5.094852565926516, 4.055314762186598, 3.025617286955688, 2.038051450018439, 1.011575859732287, 1.9755185323726812, 2.9655114310147836, 3.9221109618693615, 4.893146789126024, 5.931647723536624, 6.943839682685465, 7.992386923297339, 9.012023393691107, 10.737523912022347, 11.682608006375606, 10.812616157571895, 9.754078296475264, 8.818924891749964, 7.841711678799161, 6.780685790151088, 5.845460058596396, 4.858713051963935, 3.837597022768385, 2.883491764759605, 1.9538587553583406, 2.9925827733310664, 3.917448711484388, 4.849076354682097, 5.855446236019609, 6.8184066071648415, 7.8633881002223465, 8.850007417262447, 9.796933805818467, 11.718706995206293, 12.683263828164419, 11.780837526486122, 10.782972169628229, 9.759151535764683, 8.760681917740673, 7.711468204222656, 6.693427859509927, 5.7236015438713554, 4.770772597313288, 3.8586676175119208, 2.8913582012876597, 3.9487941795157857, 4.897378175588493, 5.8683073119293345, 6.90642186064782, 7.800352024774586, 8.833666370797362, 9.797681245513797, 10.734700356630157, 12.692076212240362, 13.620594110028422, 12.636377443209375, 11.6865662788373, 10.678068992010076, 9.609312508997983, 8.625693005888206, 7.626608206368431, 6.670436015074863, 5.72433894817088, 4.925431347049684, 3.9037219057661012, 4.867352954429493, 5.912461523215007, 6.81261347344172, 7.886786679782419, 8.754018241040718, 9.692147863030268, 10.6896841922456, 11.627192031980792, 13.509341745627609, 14.494430725127009, 13.526588151072682, 12.486905450193378, 11.522698583730099, 10.589050655021547, 9.599999009746526, 8.657263096123705, 7.692080466017144, 6.758333286476124, 5.810632128315626, 4.833813660253895, 5.82678171463156, 6.839069860973546, 7.8827423481160634, 8.8395727040636, 9.734231662211705, 10.653613083780721, 11.630849988319033, 12.57144114159942, 14.456384286228099, 15.41159028772483, 14.51384402203574, 13.485918820537064, 12.460250025559645, 11.52264296584445, 10.615826883842582, 9.582511736908952, 8.702299134919253, 7.736000610898122, 6.869174036407371, 5.855857236306823, 6.828141348671998, 7.799552549386155, 8.86588256080077, 9.798194132900827, 10.689960198688043, 11.701674018212692, 12.565408700843042, 13.546234541100636, 15.449586374351462, 16.42517187053325, 15.49216158777651, 14.428465379709053, 13.45219312785498, 12.573441861444449, 11.54390700425722, 10.528605683625262, 9.685150166972948, 8.671780637859566, 7.817841393629069, 6.906413250765148, 7.836893789195614, 8.793295384700947, 9.801112165000598, 10.779821823504657, 11.622794228205288, 12.636293881859254, 13.529527016552205, 14.534880952946022, 16.416792687649604, 17.40111851639215, 16.453507817487015, 15.44182830036153, 14.421071259833553, 13.45333197110658, 12.4666719125393, 11.475114466065362, 10.626966057201212, 9.688428283706628, 8.855559935751286, 7.938216198769539, 8.7689881250576, 9.835069933715515, 10.771362007537405, 11.713455522833758, 12.586726546027707, 13.518584226306231, 14.46924618159798, 15.460502493341428, 17.34539274375376, 17.38972142651714, 16.477868999470964, 15.533659084545597, 14.737978327512248, 13.71927469436605, 12.695203910024446, 11.769756520403966, 10.831802620901719, 10.651490334055982, 9.907500434224035, 8.889383687646442, 9.711652764044992, 10.775381145186671, 11.72898986817645, 12.650621614461791, 13.589342595623014, 14.520808278101562, 15.510617344827079, 16.421054705422126, 17.26341597756783, 16.41553118601113, 15.44274976429262, 14.564459077050872, 13.709944820558206, 12.836575398232982, 11.76199036210569, 10.826584153878844, 9.877989653201396, 10.81338516544533, 10.873648740185866, 9.890799670402416, 10.724988988574696, 11.658541833344257, 12.717691863338104, 13.63655299264615, 14.645545300503635, 15.472502519764802, 16.427419436907925, 17.41533867866388, 16.296784552371395, 15.34662280298839, 14.38506679204359, 13.566256312700277, 12.76598382506481, 11.893701930368987, 10.948057304605117, 9.900314872780124, 8.89882990390668, 9.864064959900105, 10.760084349215319, 10.92116132849769, 11.752945604275363, 12.699914990050747, 13.625115433454212, 14.596256583368385, 15.651910922579821, 16.54311697327186, 17.45718937425219, 17.321672758939343, 15.446672988035749, 14.377127416171897, 13.447159460418955, 12.550160915650999, 11.723742455006485, 10.896924550792251, 9.927545055871711, 8.92012589066897, 7.856118852266508, 8.873144459184534, 9.784700825689136, 10.774450630234234, 11.626887417261113, 12.663002377463071, 13.5734096257323, 14.426749974786265, 15.385048435660885, 16.3695958478947, 17.393176619298714, 16.41469287201667, 14.454231907809985, 13.441306473488247, 12.511692650768568, 11.618863601449053, 10.696398443137054, 9.836132159271813, 8.919188766501076, 7.885457975676481, 6.8483049174235955, 7.819662811829661, 8.776647866687904, 9.759119644301549, 10.651958806592868, 11.663875777733194, 12.544504965867544, 13.483251434812875, 14.42936441182437, 15.399610995171125, 16.36459706178735, 15.428404380604132, 13.544463713504975, 12.609402046011349, 11.572235707496949, 10.64594021823027, 9.761202759699998, 8.874969517732604, 7.869615129725695, 6.876632421356475, 5.895605454475828, 6.8243826437658885, 7.734449084142902, 8.711486657723245, 9.658888082700607, 10.621713299648247, 11.605706969470347, 12.545724645453015, 13.578215666078625, 14.632702102298149, 15.478540010581272, 14.535846419651426, 12.598614445957702, 11.640581065417775, 10.645032774185843, 9.683241131413558, 8.823762735692059, 7.839518537919985, 6.888009976858875, 5.867068998615397, 4.9626198501346215, 5.88928012414439, 6.762610315594211, 7.761885710187214, 8.706782104873554, 9.725727495735564, 10.77570987697664, 11.72249225164457, 12.707562327965334, 13.650051743990506, 14.51414928989944, 13.650256874756856, 11.686958950019045, 10.730544569472125, 9.74848199884107, 8.75747115244871, 7.783316689592416, 6.809211108062017, 5.838756228017703, 4.9047398401348685, 3.937317159735944, 4.881773913390405, 5.807124033624121, 6.743331903763905, 7.776091499625879, 8.754244475121565, 9.769753663151969, 10.784896836755536, 11.684205439193596, 12.724481557081662, 13.561393975886782, 12.627253911640466, 10.756204142500163, 9.821647210152893, 8.783325274580404, 7.799538345049234, 6.82439646612079, 5.859669573473369, 4.879975296749916, 3.9094254924669203, 2.9550042915506474, 3.9930019423674823, 4.897573302840263, 5.962541019126943, 6.883263705735101, 7.7230514715904715, 8.7366033433535, 9.793174959628912, 10.721181549354586, 11.705677857225592, 12.621178458854136, 11.695692681873682, 9.777739873404514, 8.830866588006378, 7.854825581181088, 6.867354246690218, 5.800619428475179, 4.8454953866864345, 3.889194198816888, 3.0368514608808495, 2.0111936283398655, 2.999236438123013, 3.887923673323706, 4.906105863419496, 5.83467508088209, 6.775123437539284, 7.781496424705654, 8.776457223228817, 9.760988818045368, 10.725661455801355, 11.686464906744295, 10.731482290907925, 8.910098876193244, 7.836688469052684, 6.875512436323403, 5.9385972563399525, 4.939915655457058, 3.9909844277090354, 2.93665121489746, 1.981627483186346, 0.995483093211026, 1.9785102167037527, 2.9158417954100946, 3.9700119965055434, 5.012430372656043, 6.0865615821748476, 7.1183766742630805, 8.155899821661068, 9.114979176460816, 10.147191646838273, 10.909102908069126, 9.874288244081963, 8.09401559642703, 7.048074075551608, 5.998101115990391, 5.005905544172755, 3.9723241820551722, 2.945688058127936, 1.9901679759388067, 0.9589115491588691, 0.0, 1.0724069216817238, 2.1119544248898725, 3.0689086848147245, 4.116333264470214, 5.108123392025374, 6.093145066075513, 7.15531392595575, 8.148334441503515, 9.150748049870161, 10.09165278309288, 9.113552830123798], [10.914844548737511, 9.965200035617961, 8.971857700073972, 8.012065546532401, 6.984478475371392, 5.979780160282542, 5.029049123113112, 4.022445644244791, 2.982907840504874, 2.021465113099306, 1.0338992761620562, 2.0603748664482078, 3.0243175390886017, 4.014310437730704, 4.970909968585282, 5.941945795841944, 6.980446730252544, 7.992638689401385, 9.041185930013258, 10.060822400407027, 11.786322918738268, 10.892187393334298, 9.913730186541116, 8.855192325444484, 7.920038920719185, 6.9428257077683835, 5.88179981912031, 4.946574087565619, 3.9598270809331586, 3.0136188160145547, 2.0720355471268137, 3.001668556528078, 4.040392574500803, 4.966247718200308, 5.897875361398018, 6.90424524273553, 7.8672056138807624, 8.912187106938267, 9.898806423978368, 10.845732812534388, 12.767506001922214, 11.892843215123111, 10.881951555455343, 9.88408619859745, 8.929142682007706, 7.931164154267688, 6.887489997468825, 5.869449652756097, 4.899623337117525, 3.9467943905594574, 3.0472113998791297, 3.939168002457397, 4.9966039806855225, 5.94518797675823, 6.9171063186452555, 7.955220867363741, 8.849151031490507, 9.882465377513283, 10.846480252229718, 11.783499363346078, 13.740875218956283, 12.780624653780858, 11.79640798696181, 10.846596822589737, 9.854090785256245, 8.785334302244152, 7.801714799134375, 6.8026299996146005, 5.846457808321032, 4.90036074141705, 4.113975129416893, 4.951531706935838, 5.91516275559923, 6.960271324384744, 7.861412480157641, 8.935585686498339, 9.80281724775664, 10.740946869746189, 11.738483198961521, 12.675991038696713, 14.55814075234353, 13.670452518373178, 12.702609944318851, 11.662927243439547, 10.698720376976269, 9.765072448267716, 8.776020802992695, 7.8332848893698745, 6.868102259263313, 5.934355079722294, 5.05520260761798, 5.881623461423632, 6.8745915158012965, 7.886879662143283, 8.931541354831984, 9.88837171077952, 10.783030668927626, 11.702412090496642, 12.679648995034954, 13.620240148315341, 15.50518329294402, 14.669962018425352, 13.689865815281909, 12.661940613783234, 11.636271818805815, 10.698664759090619, 9.791848677088751, 8.758533530155121, 7.878320928165421, 6.912022404144292, 6.113744515709725, 6.90366703747656, 7.875951149841736, 8.847362350555892, 9.913692361970508, 10.846993139616746, 11.738759205403964, 12.750473024928613, 13.614207707558963, 14.595033547816557, 16.498385381067383, 15.683702557297522, 14.668183381022677, 13.60448717295522, 12.628214921101149, 11.749463654690619, 10.719928797503389, 9.704627476871432, 8.861171960219117, 7.847802431105736, 7.062411872931424, 7.954223051934885, 8.884703590365351, 9.841105185870685, 10.848921966170336, 11.827631624674394, 12.67159323492121, 13.685092888575175, 14.578326023268126, 15.583679959661943, 17.465591694365525, 16.577140309638317, 15.629529610733185, 14.6178500936077, 13.597093053079723, 12.62935376435275, 11.64269370578547, 10.651136259311532, 9.802987850447382, 8.864450076952798, 8.10013041505364, 8.986025999939276, 9.816797926227338, 10.882879734885252, 11.819171808707143, 12.761265324003496, 13.635525552743628, 14.567383233022152, 15.5180451883139, 16.509301500057347, 18.39419175046968, 17.561269011946884, 16.58248399785013, 15.655222074476955, 14.62848088644662, 13.611396827052392, 12.647327960980979, 11.719816490552116, 10.792215124089738, 9.827512127302152, 9.152070913526389, 9.937193488816177, 10.75946256521473, 11.823190946356409, 12.776799669346188, 13.698431415631529, 14.638141602338935, 15.569607284817483, 16.559416351543, 17.469853712138043, 18.32242407154495, 17.47453927998825, 16.50175785826974, 15.623467171027995, 14.76895291453533, 13.895583492210104, 12.820998456082812, 11.885592247855966, 10.936997747178518, 10.224462156411233, 10.131688542760438, 10.938609471572152, 11.772798789744433, 12.706351634513995, 13.765501664507841, 14.684362793815888, 15.694344307219556, 16.521301526480723, 17.476218443623846, 18.4641376853798, 17.355792646348515, 16.405630896965512, 15.444074886020713, 14.6252644066774, 13.824991919041933, 12.952710024346107, 12.007065398582236, 10.959322966757245, 9.957837997883802, 9.201628481752348, 9.856474714118285, 10.896341578341865, 11.677681140190403, 12.624650525965787, 13.549850969369253, 14.495914178888402, 15.4796842753245, 16.418166743307335, 17.415833856681587, 18.37845560467992, 16.50568108201287, 15.43613551014902, 14.506167554396079, 13.609169009628122, 12.782750548983609, 11.955932644769373, 10.986553149848831, 9.979133984646092, 8.91512694624363, 8.210707981036776, 8.881091190592102, 9.8708409951372, 10.723277782164075, 11.759392742366034, 12.669799990635262, 13.523140339689228, 14.481438800563847, 15.465986212797661, 16.489566984201673, 17.445993393099666, 15.513240001787109, 14.50031456746537, 13.570700744745691, 12.677871695426177, 11.755406537114178, 10.895140253248934, 9.978196860478196, 8.9444660696536, 7.907313011400716, 7.157226333681903, 7.8730382315908685, 8.855510009204513, 9.74834917149583, 10.760266142636157, 11.640895330770507, 12.579641799715837, 13.525754776727332, 14.496001360074088, 15.460987426690313, 16.45970490168713, 14.603471807482098, 13.668410139988472, 12.631243801474072, 11.704948312207394, 10.820210853677121, 9.933977611709725, 8.928623223702814, 7.935640515333596, 6.954613548452949, 6.086416701746622, 6.830839449045866, 7.807877022626209, 8.755278447603569, 9.71810366455121, 10.70209733437331, 11.642115010355978, 12.674606030981588, 13.622647491938416, 14.578415906764327, 15.521109497694173, 13.657622539934826, 12.699589159394899, 11.704040868162966, 10.742249225390681, 9.882770829669182, 8.898526631897107, 7.947018070835997, 6.926077092592518, 6.021627944111742, 5.151314182125124, 5.859000680497175, 6.858276075090179, 7.803172469776518, 8.738965230493777, 9.774745757813411, 10.712437641284838, 11.697507717605601, 12.639997133630773, 13.60916029330874, 14.548407546429715, 12.759365871700767, 11.789552663449248, 10.807490092818194, 9.816479246425834, 8.84232478356954, 7.868219202039139, 6.897764321994826, 5.963747934111989, 4.996325253713065, 4.143807971371139, 4.9035143985270855, 5.839722268666869, 6.872481864528844, 7.744189864761834, 8.759699052792238, 9.774842226395803, 10.674150828833863, 11.714426946721929, 12.65640497929608, 13.49914251586798, 11.828611064181885, 10.880655304130016, 9.842333368557528, 8.858546439026357, 7.8834045600979135, 6.918677667450491, 5.938983390727039, 4.968433586444042, 4.014012385527769, 3.144782238717455, 3.9658621595153245, 4.967504509383356, 5.87320909537537, 6.7129968612307405, 7.726548732993769, 8.78312034926918, 9.711126938994854, 10.695623246865859, 11.642095509120743, 12.567581286101197, 10.850146795086236, 9.9032735096881, 8.927232502862811, 7.926362340667341, 6.859627522452302, 5.904503480663557, 4.948202292794011, 4.095859554857971, 3.0702017223169875, 2.113316678030703, 2.9562125299987674, 3.896051253059765, 4.824620470522359, 5.765068827179553, 6.771441814345923, 7.7664026128690855, 8.750934207685635, 9.715606845441622, 10.676410296384562, 11.67625066371606, 9.982505797874966, 8.909095390734407, 7.947919358005127, 7.011004178021676, 6.012322577138781, 5.049992521686158, 3.9956593088745826, 3.040635577163468, 2.054491187188148, 1.0714640636954216, 1.984130652085156, 2.959957386145812, 4.002375762296311, 5.050973267832953, 6.045969752581357, 7.083492899979343, 8.04257225477909, 9.074784725156547, 10.116874478830836, 10.946695165763686, 9.166422518108753, 8.120480997233333, 7.0705080376721146, 6.078312465854479, 5.044731103736896, 4.01809497980966, 3.0625748976205305, 2.031318470840593, 1.0724069216817238, 0.0, 1.0395475032081487, 1.9965017631330007, 3.04392634278849, 4.03571647034365, 5.020738144393789, 6.082907004274026, 7.07592751982179, 8.078341128188438, 9.090831968845366, 10.068931921814448], [9.875297045529363, 8.925652532409813, 7.932310196865825, 6.9725180433242535, 5.9449309721632435, 4.940232657074393, 3.989501619904964, 2.9828981410366424, 1.9433603372967254, 0.9985968816629487, 1.9861627186001982, 3.0126383088863498, 3.9765809815267437, 4.966573880168847, 5.923173411023424, 6.894209238280087, 7.932710172690688, 8.944902131839529, 9.993449372451401, 10.915108791819618, 10.79772398447941, 9.85263989012615, 8.874182683332968, 7.8156448222363375, 6.880491417511037, 5.903278204560236, 4.842252315912162, 3.9070265843574705, 2.92027957772501, 1.9907505845781976, 2.9448558425869775, 3.8744888519882417, 4.913212869960967, 5.894489346325719, 6.850138803836161, 7.856508685173672, 8.819469056318905, 9.86445054937641, 10.851069866416513, 11.73831409068329, 11.815445247742105, 10.853295711914964, 9.842404052247197, 8.844538695389303, 7.889595178799558, 6.8916166510595405, 5.864621766032468, 4.84658142131974, 3.876755105681168, 2.9239261591231003, 3.9200316953392935, 4.81198829791756, 5.869424276145686, 6.8180082722183935, 7.791008162085161, 8.84728014265788, 9.801414473928649, 10.834728819951426, 11.798743694667861, 12.676080641494979, 12.77948530327069, 11.741077150572712, 10.756860483753664, 9.80704931938159, 8.831222553819888, 7.762466070807795, 6.778846567698018, 5.779761768178243, 4.823589576884675, 3.8774925099806925, 4.923366520862588, 5.824352002396002, 6.787983051059394, 7.833091619844907, 8.735314323597548, 9.809487529938245, 10.75508069019478, 11.69321031218433, 12.690746641399663, 13.628254481134855, 13.679268486230818, 12.647584286936821, 11.679741712882494, 10.64005901200319, 9.675852145539912, 8.74220421683136, 7.753152571556337, 6.8104166579335175, 5.845234027826956, 4.911486848285937, 5.8645939990636755, 6.754443756883796, 7.74741181126146, 8.759699957603447, 9.80544319827189, 10.762273554219426, 11.735294111365768, 12.654675532934784, 13.631912437473096, 14.572503590753483, 14.602299788485725, 13.647093786988995, 12.666997583845552, 11.639072382346876, 10.613403587369458, 9.675796527654262, 8.768980445652394, 7.735665298718764, 6.855452696729064, 5.889154172707935, 6.823744161565729, 7.776487332936724, 8.7487714453019, 9.720182646016056, 10.78651265743067, 11.720894983056652, 12.691022647842106, 13.702736467366755, 14.566471149997104, 15.532927899196643, 15.595501876609088, 14.660834325861165, 13.645315149586322, 12.581618941518865, 11.605346689664792, 10.726595423254262, 9.697060566067032, 8.681759245435074, 7.83830372878276, 6.824934199669379, 7.772411518787428, 8.738192522574959, 9.668673061005425, 10.713925481330849, 11.7217422616305, 12.700451920134558, 13.62385667735935, 14.637356331013317, 15.530589465706267, 16.521970187115016, 16.544939661100717, 15.554272078201961, 14.606661379296828, 13.594981862171343, 12.574224821643366, 11.606485532916393, 10.619825474349113, 9.628268027875174, 8.780119619011025, 7.841581845516441, 8.810130060909644, 9.765808530156633, 10.600767396867411, 11.666849205525326, 12.651124279917461, 13.593217795213814, 14.540542385112474, 15.472400065390998, 16.470308630752044, 17.461564942495492, 17.473539717204872, 16.53840078051053, 15.559615766413774, 14.632353843040597, 13.605612655010264, 12.588528595616035, 11.624459729544622, 10.696948259115759, 9.769346892653381, 8.804643895865794, 9.8002899010082, 10.716976019033535, 11.543432035854803, 12.607160416996482, 13.560769139986261, 14.498508545305045, 15.503157070392566, 16.44658781053661, 17.48355674790855, 18.42211715457619, 18.455564972390427, 17.51259102101654, 16.594735001592117, 15.579902039063343, 14.59651095290731, 13.600324695962291, 12.557673277463378, 11.64012062564088, 10.710141840133861, 9.774746327889927, 9.766233668874747, 10.749082738658197, 11.666090252682922, 12.599643097452484, 13.46246849275515, 14.416070266402489, 15.459281722823516, 16.449233693606242, 17.404150610749365, 18.35055631686359, 18.166243310236442, 17.21608156085344, 16.25452554990864, 15.435715070565328, 14.602120544252518, 13.690158539840155, 12.744513914076284, 11.696771482251293, 10.69528651337785, 9.828758404423503, 8.816927210910134, 9.856794075133713, 10.638133636982255, 11.58510302275764, 12.510303466161105, 13.456366675680254, 14.440136772116352, 15.378619240099185, 16.37628635347344, 17.33890810147177, 17.316131745900798, 16.246586174036945, 15.316618218284006, 14.41961967351605, 13.559879174194194, 12.693411791249996, 11.724001665342879, 10.71658250014014, 9.652575461737678, 8.837837903707932, 7.841543687383951, 8.831293491929049, 9.683730278955927, 10.719845239157886, 11.630252487427114, 12.48359283648108, 13.4418912973557, 14.426438709589513, 15.450019480993525, 16.406445889891515, 16.323690665675038, 15.310765231353297, 14.381151408633619, 13.488322359314104, 12.532535162324763, 11.663281170266764, 10.715645375972244, 9.68191458514765, 8.644761526894765, 7.802735377863417, 6.833490728382719, 7.815962505996365, 8.708801668287682, 9.720718639428009, 10.601347827562359, 11.54009429650769, 12.486207273519184, 13.45645385686594, 14.421439923482165, 15.42015739847898, 15.396490572508696, 14.4788608038764, 13.441694465362, 12.515398976095321, 11.597339478887706, 10.702118528727555, 9.666071739196862, 8.673089030827644, 7.692062063946999, 6.7319257459281365, 5.791291945837718, 6.76832951941806, 7.715730944395421, 8.678556161343062, 9.662549831165162, 10.60256750714783, 11.63505852777344, 12.583099988730266, 13.53886840355618, 14.481561994486025, 14.450641304961424, 13.510039823282826, 12.514491532050894, 11.552699889278609, 10.659899454879767, 9.675655257107692, 8.70788022003427, 7.663525608086567, 6.759076459605792, 5.796823226306638, 4.819453177289026, 5.81872857188203, 6.7636249665683685, 7.699417727285629, 8.735198254605264, 9.67289013807669, 10.657960214397452, 11.600449630422624, 12.569612790100592, 13.508860043221567, 13.425292817703616, 12.600003327337175, 11.61794075670612, 10.62692991031376, 9.619453408780124, 8.645347827249724, 7.674892947205411, 6.701196449606038, 5.733773769207114, 4.789317015552653, 3.863966895318937, 4.800174765458721, 5.832934361320694, 6.704642361553686, 7.72015154958409, 8.735294723187655, 9.634603325625713, 10.674879443513781, 11.616857476087933, 12.459595012659832, 12.497091651184245, 11.691105968017943, 10.652784032445455, 9.668997102914284, 8.69385522398584, 7.695806292661076, 6.7161120159376235, 5.734098068502707, 4.779676867586434, 3.8792889552792564, 2.926314656307176, 3.927957006175207, 4.833661592167222, 5.673449358022593, 6.687001229785621, 7.743572846061031, 8.671579435786704, 9.656075743657711, 10.602548005912595, 11.528033782893049, 11.590445578011323, 10.742935169875286, 9.756903395873364, 8.736813004555268, 7.670078186340229, 6.714954144551484, 5.758652956681938, 4.861524036916636, 3.835866204375652, 2.8478233945925044, 1.9166650267906187, 2.8565037498516164, 3.785072967314211, 4.725521323971404, 5.731894311137775, 6.726855109660937, 7.711386704477486, 8.676059342233474, 9.636862793176414, 10.636703160507912, 10.978991469607172, 9.905581062466613, 8.944405029737332, 8.007489849753881, 6.933216926607409, 5.860443185574085, 4.80610997276251, 3.8510862410513953, 2.8649418510760754, 1.8819147275833488, 0.9445831488770072, 1.9204098829376632, 2.9628282590881625, 4.011425764624804, 5.006422249373209, 6.043945396771195, 7.003024751570943, 8.0352372219484, 9.077326975622688, 10.05274116645609, 10.048921652303068, 9.160028500441483, 8.110055540880264, 7.1178599690626285, 6.084278606945045, 5.057642483017808, 4.102122400828679, 3.0708659740487416, 2.1119544248898725, 1.0395475032081487, 0.0, 0.956954259924852, 2.0043788395803412, 2.996168967135502, 3.981190641185641, 5.043359501065878, 6.036380016613642, 7.03879362498029, 8.051284465637218, 9.0293844186063], [8.918342785604512, 7.9686982724849615, 6.975355936940972, 6.015563783399401, 4.987976712238392, 3.983278397149541, 3.0325473599801116, 2.025943881111791, 0.9864060773718736, 1.9555511415878006, 2.94311697852505, 3.9695925688112017, 4.933535241451596, 5.9235281400936985, 6.880127670948276, 7.851163498204938, 8.88966443261554, 9.90185639176438, 10.950403632376252, 9.958154531894767, 9.840769724554557, 8.895685630201298, 7.917228423408116, 6.8586905623114856, 5.9235371575861855, 4.946323944635384, 3.88529805598731, 2.9500723244326186, 1.963325317800158, 2.9477048445030496, 3.9018101025118295, 4.831443111913093, 5.870167129885819, 6.851443606250571, 7.8070930637610125, 8.813462945098523, 9.776423316243756, 10.82140480930126, 11.728286219314457, 10.781359830758436, 10.858490987817252, 9.89634145199011, 8.885449792322344, 7.887584435464451, 6.932640918874706, 5.9346623911346885, 4.90889972747506, 3.9085759435986347, 2.938749627960063, 3.8808804190479522, 4.8769859552641455, 5.768942557842412, 6.826378536070538, 7.774962532143245, 8.747962422010012, 9.80423440258273, 10.7583687338535, 11.791683079876275, 12.720329716781208, 11.719126381570126, 11.822531043345837, 10.78412289064786, 9.799906223828811, 8.850095059456738, 7.885590814939375, 6.849955807171713, 5.866336304061936, 4.876251542530586, 3.9200793512370167, 4.8344467699055444, 5.88032078078744, 6.781306262320854, 7.744937310984246, 8.790045879769758, 9.692268583522399, 10.766441789863098, 11.71203495011963, 12.65016457210918, 13.643488293465158, 12.705980453729966, 12.74947570353378, 11.717791504239784, 10.749948930185457, 9.736548786355533, 8.772341919892254, 7.838693991183701, 6.84964234590868, 5.90690643228586, 4.941723802179298, 5.868441108210789, 6.821548258988527, 7.711398016808648, 8.704366071186312, 9.716654217528298, 10.762397458196741, 11.719227814144277, 12.692248371290617, 13.611629792859633, 14.588866697397945, 13.687376307561967, 13.672507005788688, 12.717301004291958, 11.763487358197894, 10.735562156699219, 9.709893361721798, 8.772286302006602, 7.865470220004736, 6.832155073071107, 5.951942471081406, 6.846108432632787, 7.780698421490581, 8.733441592861576, 9.705725705226751, 10.677136905940907, 11.743466917355523, 12.677849242981504, 13.647976907766955, 14.659690727291604, 15.523425409921954, 14.603135116499606, 14.665709093912051, 13.731041543164128, 12.74180492393866, 11.678108715871204, 10.701836464017132, 9.823085197606602, 8.793550340419374, 7.778249019787418, 6.934793503135102, 7.781888459594231, 8.72936577871228, 9.69514678249981, 10.625627320930276, 11.6708797412557, 12.67869652155535, 13.657406180059409, 14.5808109372842, 15.594310590938166, 16.487543725631117, 15.592177404417981, 15.632915407210193, 14.650761852554306, 13.703151153649172, 12.691471636523687, 11.67071459599571, 10.702975307268737, 9.716315248701457, 8.724757802227519, 7.876609393363366, 8.798536105441293, 9.767084320834496, 10.722762790081484, 11.557721656792262, 12.623803465450177, 13.608078539842312, 14.550172055138665, 15.497496645037325, 16.42935432531585, 17.427262890676893, 16.60052270914991, 16.56151546331435, 15.63489055486287, 14.656105540766118, 13.728843617392942, 12.702102429362608, 11.685018369968379, 10.720949503896966, 9.793438033468103, 8.95158270305166, 9.761598155790647, 10.757244160933054, 11.118740825175012, 11.768008724907565, 12.645824367678888, 13.539752735611742, 14.46954819593911, 15.474196721026631, 16.417627461170675, 17.419619585466254, 17.561074921230606, 17.55205474674277, 16.609080795368882, 15.69122477594446, 14.676391813415687, 13.693000727259655, 12.696814470314635, 11.654163051815722, 10.736610399993225, 9.905395670751982, 10.73170058781478, 10.7231879287996, 10.117324842419038, 10.754672500377861, 11.688225345147423, 12.551050740450089, 13.48361681775475, 14.526828274175777, 15.516780244958506, 16.471697162101627, 17.39360205693874, 17.39914949585845, 17.534510393725093, 16.55353753166232, 15.545751085190279, 14.603852605417044, 13.537624881293832, 12.591980255529961, 11.662879681091946, 10.884555420046699, 10.785712664348354, 9.773881470834986, 9.086963184323764, 9.726715884677194, 10.673685270452578, 11.598885713856044, 12.523913227032516, 13.507683323468614, 14.446165791451447, 15.4438329048257, 16.38195384154692, 16.44457640150699, 17.2035404339618, 16.27357247820886, 15.376573933440902, 14.516833434119043, 13.65036605117485, 12.680955925267732, 11.673536760064993, 10.60952972166253, 9.794792163632783, 8.798497947308803, 8.0614626011191, 8.772312526650866, 9.808427486852825, 10.697799038779376, 11.551139387833341, 12.509437848707961, 13.493985260941775, 14.517566032345787, 15.449491629966664, 15.437375611348273, 16.26771949127815, 15.338105668558471, 14.445276619238957, 13.489489422249612, 12.620235430191617, 11.672599635897097, 10.638868845072503, 9.601715786819618, 8.75968963778827, 7.790444988307572, 7.019444631788855, 7.797383915982621, 8.809300887122948, 9.66889437891462, 10.607640847859951, 11.553753824871446, 12.524000408218201, 13.488986474834427, 14.463203138554126, 14.439536312583844, 15.400766062144458, 14.398648725286852, 13.472353236020174, 12.554293738812556, 11.659072788652407, 10.623025999121715, 9.630043290752496, 8.64901632387185, 7.6888800058529885, 6.74824620576257, 5.9718116452105505, 6.804313192090361, 7.767138409038002, 8.730096382517424, 9.670114058500092, 10.680692201554251, 11.626145728805415, 12.581914143631327, 13.524607734561172, 13.493687045036571, 14.451720425576498, 13.471445791975746, 12.509654149203461, 11.616853714804616, 10.632609517032542, 9.66483447995912, 8.620479868011419, 7.716030719530643, 6.75377748623149, 5.776407437213878, 5.02221069767452, 5.845311517347023, 6.742463467360776, 7.778243994680411, 8.71593587815184, 9.7010059544726, 10.643495370497773, 11.61265853017574, 12.551905783296714, 12.468338557778763, 13.536040849467371, 12.574895016630974, 11.583884170238614, 10.576407668704974, 9.602302087174573, 8.631847207130262, 7.65815070953089, 6.690728029131966, 5.746271275477505, 4.820921155243789, 3.9747896591519902, 4.914620912099348, 5.7476881016288335, 6.763197289659237, 7.778340463262803, 8.677649065700862, 9.717925183588928, 10.65990321616308, 11.50264075273498, 11.540137391259393, 12.569639925701606, 11.609738292370308, 10.625951362839137, 9.650809483910693, 8.652760552585926, 7.673066275862475, 6.691052328427558, 5.736631127511285, 4.836243215204108, 3.8832689162320277, 2.971002746250355, 3.87670733224237, 4.71649509809774, 5.730046969860768, 6.7866185861361785, 7.714625175861853, 8.699121483732858, 9.645593745987743, 10.571079522968196, 10.63349131808647, 11.580364603484606, 10.713857655798217, 9.69376726448012, 8.627032446265082, 7.671908404476337, 6.715607216606791, 5.818478296841487, 4.792820464300504, 3.8047776545173564, 2.8736192867154706, 1.8995494899267644, 2.828118707389359, 3.768567064046552, 4.774940051212923, 5.769900849736085, 6.754432444552634, 7.719105082308621, 8.679908533251561, 9.679748900583059, 10.059976274419958, 10.862535322391466, 9.901359289662185, 8.964444109678734, 7.890171186532262, 6.817397445498938, 5.763064232687363, 4.808040500976248, 3.8218961110009277, 2.838868987508201, 1.9015374088018593, 0.9634556230128113, 2.0058739991633106, 3.054471504699952, 4.049467989448356, 5.0869911368463425, 6.04607049164609, 7.078282962023547, 8.120372715697835, 9.095786906531238, 9.091967392378216, 10.116982760366334, 9.067009800805115, 8.07481422898748, 7.041232866869897, 6.01459674294266, 5.059076660753531, 4.027820233973594, 3.0689086848147245, 1.9965017631330007, 0.956954259924852, 0.0, 1.047424579655489, 2.0392147072106495, 3.0242363812607884, 4.086405241141025, 5.0794257566887895, 6.081839365055437, 7.094330205712366, 8.072430158681447], [7.870918205949025, 6.921273692829474, 5.927931357285485, 4.968139203743913, 3.940552132582903, 2.9358538174940523, 1.9851227803246225, 1.0016204960860913, 2.0338306570273628, 3.00297572124329, 3.9905415581805395, 5.017017148466691, 5.980959821107085, 6.970952719749188, 7.927552250603766, 8.898588077860428, 9.937089012271027, 10.949280971419867, 9.930366422633048, 8.91072995223928, 8.84239367186289, 7.89730957750963, 6.92182213438699, 5.863284273290359, 4.928130868565059, 3.981809123925152, 2.9250159844025596, 2.0019887634292313, 2.988735770061692, 3.995129424158539, 4.949234682167319, 5.8788676915685825, 6.917591709541308, 7.8988681859060605, 8.854517643416502, 9.860887524754013, 10.823847895899245, 11.716529483662892, 10.72991016662279, 9.78298377806677, 9.860114935125585, 8.897965399298442, 7.890043503301217, 6.8921781464433245, 5.93723462985358, 4.970147570424457, 3.9486176558903097, 3.0512112410027097, 3.964160080221597, 4.916989026779665, 5.924410534919635, 6.816367137497902, 7.8738031157260275, 8.822387111798735, 9.795387001665501, 10.85165898223822, 11.805793313508989, 12.685968538805977, 11.721953664089542, 10.72075032887846, 10.82712475432471, 9.788716601626733, 8.804499934807685, 7.854688770435612, 6.890184525918249, 5.889673735586963, 4.906054232477186, 4.108161903561734, 4.945489803498551, 5.870555377637257, 6.916429388519153, 7.828730841976343, 8.792361890639734, 9.837470459425248, 10.739693163177888, 11.813866369518585, 12.759459529775121, 13.642648569988824, 12.645112240773491, 11.7076044010383, 11.754069414512653, 10.722385215218658, 9.754542641164331, 8.79153685656242, 7.827329990099142, 6.893682061390589, 5.916106905680172, 5.138816793317009, 5.967134254440832, 6.904549715942501, 7.857656866720239, 8.758822596464137, 9.751790650841802, 10.764078797183787, 11.80982203785223, 12.766652393799767, 13.739672950946108, 14.604113790739277, 13.632561171821228, 12.691970018540841, 12.677100716767562, 11.721894715270832, 10.801240970106708, 9.790550226906106, 8.764881431928687, 7.827274372213491, 6.978523387095491, 6.064065434102256, 6.97735292334294, 7.882217040364499, 8.816807029222293, 9.780866172517065, 10.75315028488224, 11.724561485596396, 12.79089149701101, 13.725273822636993, 14.695401487422446, 15.50368509484264, 14.567119884345237, 13.60772882747848, 13.670302804890925, 12.735635254143002, 11.79679299414555, 10.733096786078093, 9.756824534224021, 8.878073267813491, 7.984870190910275, 7.010159380818567, 7.9602039553966355, 8.817997067325944, 9.765474386443993, 10.731255390231523, 11.661735928661988, 12.707573594743902, 13.715390375043553, 14.694100033547612, 15.628235516939691, 16.4383049584892, 15.5312382000544, 14.596771115396855, 14.637509118189067, 13.716480099661231, 12.768869400756097, 11.757189883630613, 10.812491163206877, 9.863535943655497, 8.938437531735019, 7.9566681632586675, 8.9020198456249, 9.834644713173006, 10.803192928566208, 11.758871397813197, 11.905795985988622, 12.83504518260984, 13.750477260254993, 14.601836909660808, 15.549161499559467, 16.48101917983799, 16.470957365100176, 15.605116420128784, 15.566109174293224, 14.700608801969796, 13.721823787873044, 12.824344881010957, 11.843878996573775, 10.84557900635514, 9.943071786930528, 9.025348394499252, 9.976993155313194, 10.79770676352236, 11.793352768664766, 11.884764145728369, 10.963131347001228, 11.84094698977255, 12.734875357705405, 13.664670818032775, 14.669319343120296, 15.612750083264341, 16.61474220755992, 16.56566863220948, 16.572601219003335, 15.674799042475808, 14.756943023051386, 13.793544888505682, 12.853561363646415, 11.857375106701395, 10.876285334849284, 9.968520761024372, 10.930806123013516, 11.767809195546493, 11.770612508455091, 10.883348162972394, 9.949795122471524, 10.883347967241086, 11.746173362543752, 12.678739439848416, 13.721950896269444, 14.71190286705217, 15.666819784195294, 16.588724679032403, 16.594272117952112, 16.728180147447862, 15.74720728538509, 14.739420838913047, 13.797522359139812, 12.759747164327393, 11.814102538563523, 10.894790042123093, 11.909965872308232, 11.833137244003845, 10.821306050490477, 9.852986504877121, 8.921838506770857, 9.868807892546242, 10.794008335949707, 11.71903584912618, 12.702805945562279, 13.641288413545112, 14.638955526919364, 15.577076463640582, 15.639699023600652, 16.494732702415806, 16.684533851174816, 15.724851077879663, 14.79157881693125, 13.804024913204046, 12.834614787296928, 11.874979024234246, 11.656954301318022, 10.842216743288274, 9.845922526964294, 9.035376526117966, 7.9674351487445305, 9.00355010894649, 9.892921660873041, 10.746262009927007, 11.704560470801626, 12.68910788303544, 13.712688654439452, 14.644614252060327, 14.632498233441936, 15.558911759732158, 16.38553024821396, 15.492701198894446, 14.536914001905101, 13.667660009847108, 12.720024215552588, 11.686293424727994, 10.649140366475109, 9.80711421744376, 8.837869567963061, 7.993358556787721, 6.992506538076286, 8.004423509216613, 8.864017001008285, 9.802763469953616, 10.748876446965111, 11.719123030311867, 12.684109096928092, 13.65832576064779, 13.634658934677507, 14.59588868423812, 15.446073304942342, 14.519777815675663, 13.601718318468045, 12.706497368307899, 11.670450578777206, 10.677467870407988, 9.696440903527341, 8.736304585508478, 7.79567078541806, 6.945725570209416, 5.999435814184026, 6.962261031131667, 7.925219004611089, 8.865236680593757, 9.875814823647918, 10.821268350899082, 11.77703676572499, 12.719730356654836, 12.688809667130236, 13.646843047670163, 14.518870371631236, 13.55707872885895, 12.664278294460106, 11.680034096688031, 10.712259059614611, 9.66790444766691, 8.763455299186134, 7.80120206588698, 6.8238320168693685, 5.996124622673386, 5.040434139440688, 5.937586089454441, 6.973366616774076, 7.911058500245504, 8.896128576566268, 9.83861799259144, 10.807781152269403, 11.74702840539038, 11.663461179872428, 12.731163471561036, 13.622319596286463, 12.631308749894103, 11.623832248360463, 10.649726666830063, 9.679271786785751, 8.705575289186381, 7.738152608787456, 6.793695855132995, 5.868345734899279, 5.0222142388074795, 4.109743534193013, 4.9428107237224985, 5.958319911752902, 6.973463085356468, 7.872771687794528, 8.913047805682593, 9.855025838256745, 10.697763374828645, 10.735260013353058, 11.764762547795272, 12.657162872025797, 11.673375942494626, 10.698234063566183, 9.700185132241415, 8.720490855517964, 7.738476908083047, 6.784055707166774, 5.883667794859598, 4.9306934958875175, 4.0184273259058445, 3.0718299543360343, 3.911617720191405, 4.925169591954433, 5.981741208229844, 6.909747797955518, 7.894244105826524, 8.840716368081408, 9.766202145061861, 9.828613940180134, 10.775487225578269, 11.761282235453706, 10.74119184413561, 9.67445702592057, 8.719332984131826, 7.76303179626228, 6.8659028764969765, 5.840245043955993, 4.852202234172846, 3.92104386637096, 2.9469740695822533, 2.0232413294830236, 2.9636896861402167, 3.970062673306588, 4.96502347182975, 5.949555066646299, 6.914227704402286, 7.8750311553452255, 8.874871522676722, 9.012551694764468, 10.085962101905027, 10.948783869317673, 10.011868689334223, 8.937595766187751, 7.864822025154427, 6.810488812342852, 5.855465080631737, 4.8693206906564175, 3.8862935671636905, 2.9489619884573486, 2.0108802026683, 1.0284083392735397, 2.007046925044463, 3.0020434097928677, 4.039566557190854, 4.998645911990602, 6.030858382368059, 7.072948136042347, 8.048362326875749, 8.044542812722728, 9.090484333598148, 10.114434380460605, 9.122238808642969, 8.088657446525385, 7.06202132259815, 6.10650124040902, 5.075244813629083, 4.116333264470214, 3.04392634278849, 2.0043788395803412, 1.047424579655489, 0.0, 0.9917901275551605, 1.9768118016052996, 3.038980661485537, 4.032001177033301, 5.034414785399948, 6.046905626056876, 7.025005579025958], [6.879128078393863, 5.929483565274312, 4.936141229730323, 3.9763490761887517, 2.948762005027742, 1.9440636899388917, 0.993332652769462, 1.9934106236412519, 3.025620784582523, 3.9947658487984503, 4.9823316857357, 6.008807276021852, 6.972749948662246, 7.962742847304349, 8.919342378158927, 9.890378205415589, 10.92887913982619, 9.987123535689758, 8.938576295077885, 7.9189398246841165, 7.850603544307727, 6.905519449954468, 5.930032006831829, 4.871494145735198, 3.9363407410098983, 2.990018996369992, 1.9332258568473992, 2.868451588402091, 3.8551985950345515, 4.876314624230101, 5.830419882238881, 6.760052891640145, 7.7987769096128705, 8.780053385977622, 9.818574822672256, 10.824944704009766, 11.769720849165235, 10.72473935610773, 9.738120039067628, 8.791193650511607, 8.868324807570422, 7.906175271743281, 6.898253375746056, 5.900388018888163, 4.945444502298419, 3.9783574428692967, 2.956827528335149, 3.9176740659755698, 4.830622905194456, 5.783451851752524, 6.805595734991197, 7.697552337569464, 8.75498831579759, 9.703572311870298, 10.676572201737065, 11.732844182309783, 12.744610339725654, 11.694178411250814, 10.730163536534379, 9.728960201323297, 9.83533462676955, 8.796926474071572, 7.812709807252523, 6.862898642880451, 5.898394398363088, 4.897883608031802, 3.9142641049220255, 4.9133489044418, 5.81195262847141, 6.737018202610116, 7.782892213492012, 8.709916042047904, 9.673547090711295, 10.71865565949681, 11.620878363249451, 12.695051569590149, 13.58898806442321, 12.65085844243366, 11.653322113218328, 10.715814273483137, 10.762279286957494, 9.730595087663497, 8.76275251360917, 7.799746729007259, 6.835539862543981, 5.901891933835428, 4.924316778125011, 5.867052691747831, 6.833597079413691, 7.77101254091536, 8.7241196916931, 9.640007796535699, 10.632975850913363, 11.645263997255348, 12.691007237923793, 13.64783759387133, 14.569201485594197, 13.612323663184114, 12.640771044266069, 11.700179890985682, 11.685310589212401, 10.73010458771567, 9.809450842551545, 8.798760099350945, 7.773091304373526, 6.83548424465833, 5.98673325954033, 6.7923013325330786, 7.765214192968633, 8.748679865337358, 9.683269854195153, 10.662051372588627, 11.634335484953802, 12.605746685667958, 13.672076697082574, 14.606459022708556, 15.524930022070535, 14.51189496728748, 13.575329756790078, 12.61593869992332, 12.678512677335764, 11.743845126587841, 10.80500286659039, 9.741306658522934, 8.76503440666886, 7.88628314025833, 6.993080063355114, 7.7383952792493895, 8.696551343624078, 9.684459892298802, 10.631937211416853, 11.597718215204383, 12.528198753634848, 13.166668884394722, 13.937293380922892, 14.69496290588528, 15.590239342826857, 15.446514830934042, 14.53944807249924, 13.604980987841694, 13.645718990633906, 12.724689972106072, 11.777079273200938, 10.765399756075453, 9.820701035651716, 8.871745816100336, 7.946647404179858, 8.68490406168949, 9.638367233852343, 10.605569703394883, 11.6651719126319, 12.620850381878888, 12.858995798492721, 12.098508654814374, 12.967043538386084, 13.678982435105778, 14.626307025004438, 15.558164705282962, 15.479167237545015, 14.613326292573623, 14.574319046738063, 13.708818674414637, 12.730033660317885, 11.832554753455797, 10.852088869018614, 9.853788878799978, 8.951281659375367, 9.753584292930075, 10.713340543540637, 11.568631753744237, 12.564277758886643, 12.837963958232468, 11.916331159505328, 11.104410461977086, 11.951441635836497, 12.741816343477746, 13.746464868565267, 14.68989560870931, 15.691887733004894, 15.57387850465432, 15.580811091448176, 14.683008914920649, 13.765152895496227, 12.801754760950523, 11.861771236091254, 10.865584979146234, 9.884495207294123, 10.696756659455197, 11.666558351368495, 12.53873418576837, 12.76240263601025, 11.836547975476494, 10.902994934975624, 10.14681143944562, 10.962739640674844, 11.755884965293387, 12.799096421714413, 13.789048392497142, 14.743965309640265, 15.607006500590233, 15.612553939509944, 15.736390019892703, 14.75541715782993, 13.747630711357887, 12.805732231584653, 11.767957036772232, 10.822312411008362, 11.623025940553918, 12.645718100663212, 12.824927371559005, 11.813096178045637, 10.80618631738122, 9.875038319274957, 9.100412562473377, 10.010574614080799, 10.796181374571152, 11.77995147100725, 12.718433938990083, 13.716101052364335, 14.595358285198413, 14.657980845158484, 15.51301452397364, 15.692743723619655, 14.7330609503245, 13.799788689376086, 12.812234785648883, 11.842824659741767, 12.603214922665071, 12.648744428873178, 11.834006870843433, 10.837712654519454, 9.988576338622064, 8.920634961248629, 8.118736505081133, 8.994491283468099, 9.823407535371977, 10.781705996246597, 11.766253408480411, 12.789834179884423, 13.662896073618159, 13.650780054999768, 14.57719358128999, 15.506807404009669, 15.664358264526445, 14.819570797077636, 13.824834802801416, 12.851180949112402, 12.67808355228315, 11.640930494030265, 10.798904344998919, 9.829659695518222, 8.946558369291818, 7.945706350580384, 7.119609905351255, 7.965586623603343, 8.879908995398587, 9.826021972410082, 10.796268555756837, 11.761254622373063, 12.676607582205621, 12.652940756235338, 13.614170505795952, 14.587876093771033, 15.51156794323082, 14.593508446023206, 13.698287495863058, 12.662240706332366, 11.669257997963145, 10.688231031082498, 9.728094713063637, 8.78746091297322, 7.8989253827135135, 6.9526356266881235, 6.077447427266309, 7.026788627206146, 7.942382206038728, 8.894096645205753, 9.839550172456915, 10.795318587282821, 11.738012178212667, 11.707091488688068, 12.665124869227995, 13.660673160459927, 14.548868856414108, 13.656068422015267, 12.671824224243192, 11.704049187169769, 10.659694575222067, 9.755245426741292, 8.792992193442139, 7.815622144424528, 6.949324435177483, 5.993633951944785, 5.047177219976292, 6.0749362393691335, 6.961801105123046, 7.914410398124101, 8.856899814149273, 9.826062973827234, 10.76531022694821, 10.68174300143026, 11.749445293118868, 12.731507863749922, 13.62309887744926, 12.615622375915624, 11.641516794385224, 10.671061914340912, 9.697365416741539, 8.729942736342615, 7.785485982688154, 6.860135862454438, 6.01400436636264, 5.062943346697111, 4.05240185424435, 5.05988953434796, 6.024205690234011, 6.8910535093523615, 7.9313296272404274, 8.873307659814577, 9.716045196386476, 9.753541834910889, 10.783044369353103, 11.821366304925593, 12.665166070049784, 11.69002419112134, 10.691975259796576, 9.712280983073125, 8.730267035638208, 7.775845834721935, 6.875457922414758, 5.922483623442677, 5.010217453461005, 4.054427074011793, 3.0212088507132564, 4.026739214549492, 5.032483813107386, 5.928029619513351, 6.912525927384357, 7.85899818963924, 8.784483966619693, 8.846895761737967, 9.793769047136102, 10.779800821138025, 11.732981971690768, 10.666247153475728, 9.711123111686984, 8.754821923817438, 7.857693004052137, 6.832035171511153, 5.843992361728006, 4.91283399392612, 3.938764197137414, 3.0137291733192613, 2.073280816662068, 3.002993320290094, 3.9833052933875828, 4.967836888204133, 5.9325095259601195, 6.893312976903059, 7.893153344234555, 8.020761567209307, 9.094171974349866, 10.055348007079147, 10.992263187062598, 9.92938589374291, 8.856612152709587, 7.802278939898011, 6.847255208186897, 5.861110818211577, 4.878083694718851, 3.9407521160125087, 3.0026703302234607, 2.0201984668287003, 1.0152567974893025, 2.010253282237707, 3.047776429635694, 4.006855784435441, 5.039068254812898, 6.081158008487186, 7.056572199320588, 7.052752685167566, 8.098694206042987, 9.148667165604206, 10.11402893619813, 9.080447574080546, 8.05381145015331, 7.098291367964181, 6.067034941184243, 5.108123392025374, 4.03571647034365, 2.9961689671355014, 2.0392147072106495, 0.9917901275551605, 0.0, 0.985021674050139, 2.047190533930376, 3.04021104947814, 4.042624657844787, 5.055115498501715, 6.033215451470797], [5.894106404343724, 4.944461891224173, 3.951119555680184, 2.9913274021386127, 1.9637403309776031, 0.9590420158887526, 1.9733239188105904, 2.978432297691391, 4.010642458632662, 4.979787522848589, 5.967353359785839, 6.99382895007199, 7.957771622712384, 8.947764521354486, 9.904364052209063, 10.875399879465725, 10.01429382078846, 9.00210186163962, 7.953554621027747, 6.933918150633978, 6.865581870257589, 5.920497775904329, 4.94501033278169, 3.8864724716850594, 2.9513190669597593, 2.0049973223198525, 2.9132171228885277, 3.848442854443219, 4.83518986107568, 5.85630589027123, 6.81041114828001, 7.7400441576812735, 8.778768175654, 9.76004465201875, 10.798566088713384, 11.74765954626033, 10.784699175115097, 9.739717682057591, 8.75309836501749, 7.80617197646147, 7.883303133520284, 6.921153597693142, 5.913231701695917, 4.9153663448380245, 3.96042282824828, 2.9933357688191577, 3.9368187943762774, 4.897665332016698, 5.810614171235585, 6.763443117793653, 7.785587001032326, 8.677543603610593, 9.734979581838719, 10.683563577911427, 11.656563467778193, 12.712835448350912, 11.759588665675516, 10.709156737200676, 9.74514186248424, 8.74393852727316, 8.85031295271941, 7.811904800021432, 6.827688133202384, 5.877876968830312, 4.913372724312948, 4.0171071949050985, 4.894255370963154, 5.8933401704829285, 6.7919438945125385, 7.717009468651245, 8.76288347953314, 9.689907308089033, 10.653538356752424, 11.698646925537938, 12.60086962929058, 13.673457859302868, 12.603966390373074, 11.665836768383524, 10.668300439168192, 9.730792599433, 9.777257612907352, 8.745573413613357, 7.777730839559031, 6.916750140811817, 5.954763449417277, 5.021115520708724, 5.9043080441661395, 6.8470439577889595, 7.81358834545482, 8.751003806956488, 9.704110957734228, 10.619999062576827, 11.612967116954492, 12.625255263296477, 13.670998503964922, 14.627828859912459, 13.584179811544061, 12.627301989133978, 11.655749370215927, 10.71515821693554, 10.700288915162261, 9.74508291366553, 8.824429168501407, 7.915763511155503, 6.892314891246823, 5.954707831531627, 6.9667245255814585, 7.772292598574207, 8.745205459009762, 9.728671131378487, 10.663261120236282, 11.642042638629755, 12.61432675099493, 13.585737951709087, 14.010407901397153, 14.702041041378108, 14.539908348020399, 13.526873293237339, 12.590308082739936, 11.63091702587318, 11.693491003285624, 10.758823452537701, 9.856691763353496, 8.86053024539623, 7.884257993542158, 7.0055067271316265, 7.973071329396243, 8.718386545290517, 9.676542609665205, 10.664451158339931, 11.611928477457981, 12.577709481245511, 13.508190019675977, 13.960088487172404, 12.952271706872754, 13.709941231835142, 14.605217668776719, 14.4614931568839, 13.554426398449099, 12.619959313791554, 12.660697316583766, 11.769885373176018, 10.847842763672823, 9.88462334294875, 8.939924622525014, 7.990969402973632, 8.926638670220987, 9.664895327730617, 10.61835849989347, 11.58556096943601, 12.645163178673027, 13.600841647920015, 13.810059615236977, 12.914126877613427, 11.982021864335946, 12.69396076105564, 13.6412853509543, 14.573143031232824, 14.494145563494873, 13.628304618523483, 13.589297372687923, 12.779582164886522, 11.80079715078977, 10.951778340329094, 9.971312455891912, 8.973012465673275, 9.931272925416495, 10.733575558971202, 11.693331809581764, 12.548623019785364, 13.54426902492777, 13.789027774976725, 12.867394976249585, 11.920028684776138, 10.96641996178636, 11.756794669427608, 12.76144319451513, 13.704873934659172, 14.706866058954756, 14.58885683060418, 14.595789417398034, 13.753772405392533, 12.835916385968112, 11.92097834782382, 10.98099482296455, 9.984808566019531, 10.864486473335251, 11.676747925496322, 12.64654961740962, 13.518725451809496, 13.747424310060389, 12.787611792220751, 11.854058751719881, 10.99715226040637, 9.977717966624706, 10.770863291243248, 11.814074747664275, 12.804026718447004, 13.758943635590127, 14.621984826540094, 14.627532265459806, 14.822680788415271, 13.874640744703227, 12.866854298231184, 11.92495581845795, 10.940747194364278, 11.80230367704949, 12.603017206595043, 13.625709366704337, 13.809949045609143, 12.798117852095775, 11.757250134125478, 10.826102136019214, 9.950753383434126, 9.02555294003066, 9.811159700521014, 10.794929796957112, 11.733412264939945, 12.731079378314197, 13.610336611148275, 13.672959171108346, 14.527992849923502, 14.812548076327861, 13.882949695280463, 12.967197188516273, 12.012525107435028, 12.822815925782896, 13.583206188706196, 13.63376610292332, 12.819028544893571, 11.822734328569592, 10.939640155366321, 9.871698777992886, 8.973316412179237, 8.00946960941796, 8.83838586132184, 9.796684322196459, 10.781231734430273, 11.804812505834285, 12.67787439956802, 12.66575838094963, 13.592171907239852, 14.52178572995953, 14.814247009482408, 13.994541200385704, 13.073317498955467, 13.831172215153531, 13.663105226333291, 12.625952168080406, 11.783926019049058, 10.81468136956836, 9.897622186036076, 8.896770167324641, 7.974189812449359, 6.980564949553205, 7.894887321348449, 8.841000298359944, 9.8112468817067, 10.776232948322924, 11.691585908155483, 11.6679190821852, 12.629148831745814, 13.602854419720895, 14.544593881160532, 14.92973688382276, 14.034480140494676, 13.647262380382504, 12.654279672013285, 11.673252705132638, 10.713116387113777, 9.772482587023358, 8.849989199457772, 7.903699443432381, 7.025760622978108, 6.041766953156008, 6.95736053198859, 7.909074971155612, 8.854528498406776, 9.810296913232683, 10.752990504162529, 10.72206981463793, 11.680103195177857, 12.67565148640979, 13.630756423129322, 14.641090096065406, 13.656845898293332, 12.689070861219909, 11.644716249272207, 10.740267100791431, 9.778013867492279, 8.800643818474667, 7.900388251921741, 6.944697768689043, 5.998241036720549, 5.089914565318995, 5.976779431072908, 6.929388724073961, 7.871878140099132, 8.841041299777096, 9.780288552898073, 9.696721327380121, 10.76442361906873, 11.746486189699784, 12.704986444164474, 13.600644049965764, 12.626538468435363, 11.656083588391052, 10.682387090791678, 9.714964410392755, 8.770507656738294, 7.845157536504578, 6.966806631228013, 6.014007163441368, 5.003465670988607, 4.074867860297822, 5.039184016183872, 5.906031835302222, 6.9463079531902885, 7.888285985764439, 8.731023522336338, 8.76852016086075, 9.798022695302963, 10.836344630875452, 11.747053636764997, 12.675045865171482, 11.676996933846716, 10.697302657123265, 9.715288709688348, 8.760867508772074, 7.860479596464897, 6.907505297492817, 5.963019718326378, 5.00549089075605, 3.972272667457514, 3.041717540499353, 4.047462139057247, 4.943007945463211, 5.927504253334218, 6.873976515589101, 7.799462292569554, 7.861874087687828, 8.808747373085962, 9.794779147087885, 10.814869538405981, 11.65126882752587, 10.696144785737125, 9.73984359786758, 8.842714678102276, 7.817056845561292, 6.829014035778145, 5.897855667976259, 4.893362207526113, 3.964792990063519, 3.0243446334063258, 2.017971646239955, 2.998283619337444, 3.9828152141539936, 4.9474878519099805, 5.90829130285292, 6.908131670184417, 7.035739893159169, 8.109150300299728, 9.070326333029008, 10.00724151301246, 10.91440756779305, 9.841633826759727, 8.787300613948151, 7.8322768822370366, 6.846132492261717, 5.86310536876899, 4.925773790062648, 3.9876920042735997, 3.0052201408788393, 2.0002784715394415, 1.025231608187568, 2.062754755585555, 3.021834110385302, 4.054046580762758, 5.0961363344370465, 6.07155052527045, 6.067731011117428, 7.113672531992848, 8.163645491554066, 9.155841063371701, 10.065469248130684, 9.038833124203448, 8.08331304201432, 7.052056615234382, 6.093145066075513, 5.020738144393789, 3.9811906411856404, 3.0242363812607884, 1.9768118016052996, 0.985021674050139, 0.0, 1.0621688598802372, 2.055189375428001, 3.057602983794648, 4.070093824451577, 5.048193777420659], [4.831937544463486, 3.8822930313439357, 2.888950695799947, 1.9291585422583757, 1.013421582400521, 2.0181198974893717, 3.0324018004112094, 4.040601157571627, 5.072811318512899, 6.041956382728826, 7.029522219666076, 8.055997809952228, 9.019940482592622, 10.009933381234724, 10.961661722575483, 9.990625895318821, 8.952124960908222, 7.939933001759382, 6.891385761147509, 5.8717492907537405, 5.803413010377351, 4.8583289160240914, 3.919757006808789, 2.8695566212463195, 2.001000318382677, 2.9782135313334788, 3.9722950044891467, 4.907520736043838, 5.894267742676298, 6.9153837718718485, 7.869489029880628, 8.799122039281892, 9.837846057254618, 10.81912253361937, 11.691860567717603, 10.685490686380092, 9.72253031523486, 8.677548822177354, 7.690929505137252, 6.744003116581232, 6.821134273640046, 5.8589847378129045, 4.896315851257177, 3.8984504943992846, 3.0101040796711978, 3.9665519778327836, 4.995896675976897, 5.956743213617317, 6.8696920528362035, 7.822520999394271, 8.844664882632944, 9.736621485211211, 10.794057463439337, 11.742641459512045, 12.711091524964841, 11.736466311008302, 10.697419805795278, 9.646987877320438, 8.682973002604003, 7.681769667392922, 7.833397102280669, 6.7949889495826925, 5.8107722827636445, 4.860961118391572, 3.9630539757358663, 4.990323403918724, 5.953333252563773, 6.952418052083548, 7.851021776113157, 8.776087350251863, 9.82196136113376, 10.748985189689652, 11.712616238353043, 12.757724807138556, 13.655397686477228, 12.61128899942263, 11.541797530492836, 10.603667908503287, 9.606131579287954, 8.668623739552762, 8.760341762468613, 7.728657563174618, 6.760814989120291, 5.899834290373077, 5.022686678350331, 5.956334607058884, 6.945386252333905, 7.888122165956725, 8.870553651856003, 9.810081688557107, 10.763188839334846, 11.679076944177446, 12.67204499855511, 13.684333144897096, 14.529703590875252, 13.572873234927716, 12.522010951663823, 11.56513312925374, 10.600568433779467, 9.65997728049908, 9.683373064723522, 8.728167063226792, 7.807513318062667, 6.898847660716763, 6.093788562137185, 6.889926917881786, 7.930186744730744, 8.813370806741972, 9.786283667177527, 10.771935520797532, 11.706525509655327, 12.701120520230374, 13.673404632595549, 14.644815833309705, 14.63066435011473, 13.668265078079637, 13.47773948814016, 12.471692356800878, 11.535127146303475, 10.61400117543444, 10.676575152846885, 9.741907602098962, 8.839775912914755, 7.888051089705454, 7.08573166443252, 7.9407258134817855, 8.936533548545528, 9.759464753458282, 10.71762081783297, 11.707715547758976, 12.655192866877027, 13.620973870664557, 14.551454409095022, 14.58034493588998, 13.57252815559033, 12.676165268536671, 13.571441705478248, 13.40631222044744, 12.499245462012638, 11.603043463352815, 11.643781466145027, 10.75296952273728, 9.830926913234082, 8.912144187257972, 8.141398293415376, 8.926188489323792, 9.890100889370272, 10.705973535898382, 11.659436708061234, 12.626639177603774, 13.686241386840791, 14.64191985608778, 14.614348990327763, 13.586553387445658, 12.602278313053523, 11.66018479775717, 12.60750938765583, 13.539367067934354, 13.438964627058413, 12.611388768084744, 12.572381522249184, 11.762666314447781, 10.783881300351029, 9.979299184638316, 9.172786126782274, 9.908231552023434, 10.89473514456578, 11.774653767138966, 12.734410017749529, 13.589701227953128, 14.585347233095534, 14.59331715006751, 13.67168435134037, 12.6143668344377, 11.66075811144792, 10.723018706129137, 11.727667231216659, 12.671097971360702, 13.673090095656285, 13.571940980165442, 13.578873566959295, 12.736856554953793, 11.819000535529371, 10.948499192133042, 10.223456406383853, 10.92002765236969, 11.827948692484537, 12.717826133664087, 13.687627825577385, 14.559803659977261, 14.566840201313115, 13.591901167311535, 12.658348126810665, 11.729821002306858, 10.710386708525194, 9.737087327944778, 10.780298784365804, 11.770250755148533, 12.725167672291656, 13.561076816478405, 13.566624255398114, 13.80576493797653, 12.8766835077784, 11.946701956483636, 11.167417401877252, 11.875966280714437, 12.765765896198776, 13.644095414762807, 14.666787574872101, 14.64467567189818, 13.6175337433485, 12.561539509216262, 11.630391511109998, 10.683422125334614, 9.758221681931149, 8.777383737222543, 9.761153833658641, 10.699636301641474, 11.697303415015726, 12.549428601086586, 12.612051161046654, 13.467084839861814, 13.814590839403035, 12.962797353532915, 12.209658771935576, 12.947744193785187, 13.786278144932181, 14.62428439687396, 14.591533263976208, 13.77679570594646, 12.78050148962248, 11.845979676661402, 10.776926630335998, 9.79365786802898, 8.783837512709828, 7.80460989802337, 8.762908358897988, 9.747455771131802, 10.771036542535814, 11.61696638950633, 11.60485037088794, 12.531263897178164, 13.460877719897843, 13.894094667734862, 13.237002783805007, 14.008536585305626, 14.794634434302816, 14.62087238738618, 13.583719329133295, 12.741693180101947, 11.772448530621249, 10.803961707331156, 9.801998019667753, 8.794531268299103, 7.800906405402948, 6.86111135804998, 7.807224335061474, 8.777470918408229, 9.742456985024454, 10.630677898093793, 10.607011072123512, 11.568240821684126, 12.541946409659205, 13.483685871098842, 14.172198467242064, 14.969699226844835, 14.605029541435393, 13.612046833066174, 12.631019866185527, 11.670883548166666, 10.730249748076247, 9.756328720752853, 8.808927295775492, 7.846102078827851, 6.862108409005751, 5.923584568690121, 6.848166961093923, 7.793620488345085, 8.749388903170994, 9.69208249410084, 9.66116180457624, 10.619195185116167, 11.6147434763481, 12.569848413067634, 13.629640815225043, 14.61461305934622, 13.646838022272798, 12.602483410325096, 11.69803426184432, 10.735781028545167, 9.758410979527556, 8.841885060243925, 7.886194577011226, 6.939737845042733, 5.910256021168738, 4.943003467774439, 5.8684807140122714, 6.810970130037442, 7.780133289715407, 8.719380542836383, 8.635813317318432, 9.70351560900704, 10.685578179638094, 11.644078434102786, 12.69505610225792, 13.584305629488252, 12.613850749443941, 11.640154251844567, 10.672731571445643, 9.728274817791183, 8.802924697557467, 7.908303439550196, 6.955503971763552, 5.9449624793107905, 5.016364668620003, 4.005408052885403, 4.845123825240532, 5.885399943128599, 6.827377975702749, 7.6701155122746485, 7.7076121507990605, 8.737114685241274, 9.775436620813764, 10.68614562670331, 11.685904036164754, 12.634764094899605, 11.655069818176154, 10.673055870741237, 9.718634669824963, 8.818246757517786, 7.8652724585457054, 6.904516526648561, 5.9469876990782335, 4.913769475779697, 3.983214348821535, 3.013686175758778, 3.882099935401522, 4.866596243272529, 5.813068505527411, 6.738554282507864, 6.800966077626138, 7.747839363024274, 8.733871137026197, 9.753961528344293, 10.820696346559332, 11.75831364561736, 10.802012457747814, 9.800481839155166, 8.774824006614182, 7.786781196831034, 6.855622829029148, 5.834859015848296, 4.906289798385702, 3.965841441728508, 2.959468454562137, 1.9645076560389747, 2.921907204092304, 3.886579841848291, 4.84738329279123, 5.847223660122728, 5.973571033278932, 7.046981440419492, 8.008157473148772, 8.945072653132222, 10.019345576278694, 10.903802686639963, 9.849469473828387, 8.894445742117274, 7.908301352141953, 6.925274228649227, 5.987942649942885, 5.049860864153837, 4.067389000759077, 3.0624473314196785, 2.0665019396850726, 1.0289787922870859, 1.9596652505050647, 2.9918777208825214, 4.03396747455681, 5.009381665390213, 5.005562151237191, 6.051503672112611, 7.101476631673829, 8.093672203491463, 9.127253565609047, 10.101001984083684, 9.145481901894556, 8.114225475114619, 7.15531392595575, 6.082907004274026, 5.043359501065877, 4.086405241141025, 3.0389806614855366, 2.047190533930376, 1.0621688598802372, 0.0, 0.993020515547764, 1.995434123914411, 3.00792496457134, 3.986024917540422], [3.8389170289157217, 2.8892725157961716, 1.8959301802521829, 0.9361380267106116, 1.9896047303245858, 2.9943030454134365, 4.008584948335274, 5.0336216731193915, 6.065831834060663, 7.03497689827659, 8.02254273521384, 9.049018325499992, 10.012960998140386, 10.925240737882298, 9.968641207027721, 8.99760537977106, 7.959104445360459, 6.946912486211618, 5.898365245599745, 4.8787287752059765, 4.810392494829587, 3.865308400476328, 2.9267364912610248, 1.8765361056985552, 2.8116895104238555, 3.7889027233746573, 4.8499286120227305, 5.785154343577422, 6.771901350209882, 7.793017379405432, 8.747122637414213, 9.676755646815478, 10.715479664788203, 11.696756141152955, 10.698840052169837, 9.692470170832326, 8.729509799687094, 7.684528306629589, 6.697908989589488, 5.750982601033468, 5.828113758092282, 4.8659642222651405, 3.903295335709413, 2.9054299788515205, 3.8207932717123763, 4.777241169873962, 5.826454883391978, 6.834376821150901, 7.747325660369787, 8.700154606927855, 9.72229849016653, 10.614255092744797, 11.671691070972923, 12.62027506704563, 11.718071009417075, 10.743445795460536, 9.704399290247514, 8.653967361772674, 7.689952487056239, 6.688749151845158, 6.840376586732905, 5.8019684340349285, 4.8177517672158805, 3.8679406028438077, 4.773743167777045, 5.801012595959903, 6.783891459978855, 7.782976259498629, 8.72865538364674, 9.653720957785447, 10.699594968667343, 11.626618797223237, 12.590249845886628, 13.635358414672142, 12.662377170929462, 11.618268483874866, 10.548777014945072, 9.610647392955523, 8.61311106374019, 7.675603224004997, 7.76732124692085, 6.735637047626854, 5.767794473572527, 4.906813774825313, 5.833375870391509, 6.767023799100063, 7.7560754443750834, 8.698811357997904, 9.681242843897182, 10.68771529609069, 11.64082244686843, 12.556710551711031, 13.549678606088696, 14.561966752430681, 13.536683075327488, 12.579852719379952, 11.52899043611606, 10.572112613705976, 9.607547918231703, 8.666956764951316, 8.690352549175758, 7.735146547679028, 6.814492802514903, 5.905827145168999, 6.904477754178363, 7.700616109922965, 8.740875936771923, 9.624059998783151, 10.596972859218706, 11.582624712838712, 12.517214701696506, 13.543660779518436, 14.551038240129134, 15.52244944084329, 14.506680109335043, 13.459492915387901, 12.484718972592397, 11.478671841253114, 10.542106630755711, 9.620980659886676, 9.683554637299121, 8.748887086551198, 7.846755397366991, 6.89503057415769, 7.871302826011762, 8.751415005522965, 9.747222740586707, 10.570153945499461, 11.528310009874149, 12.518404739800156, 13.465882058918206, 14.431663062705736, 15.362143601136202, 15.460601785299597, 14.452785004999946, 13.556422117946287, 12.913147860346733, 12.413291704899676, 11.506224946464874, 10.610022947805051, 10.650760950597263, 9.759949007189515, 8.837906397686318, 7.919123671710209, 8.926969454994618, 9.736877681364971, 10.700790081411451, 11.516662727939561, 12.470125900102413, 13.437328369644954, 14.49693057888197, 15.45260904812896, 15.494605839737378, 14.466810236855274, 13.482535162463138, 12.540441647166785, 11.949215542524314, 12.784715407605134, 12.445944111510649, 11.61836825253698, 11.57936100670142, 10.769645798900017, 9.790860784803264, 8.986278669090552, 9.958357288361515, 10.718920744064613, 11.70542433660696, 12.585342959180146, 13.545099209790708, 14.400390419994308, 15.396036425136714, 15.473573999477125, 14.551941200749985, 13.494623683847315, 12.541014960857536, 11.603275555538753, 10.946599492929007, 11.782491355809803, 12.733636454654315, 12.578920464617678, 12.585853051411533, 11.743836039406029, 10.825980019981607, 9.95547867658528, 10.938869762741312, 11.73071684441087, 12.638637884525716, 13.528515325705268, 14.498317017618566, 15.37049285201844, 15.44709705072273, 14.472158016721151, 13.538604976220281, 12.610077851716474, 11.59064355793481, 10.617344177354394, 9.890396788048385, 10.830797114146563, 11.785714031289686, 12.56805630093064, 12.573603739850352, 12.812744422428766, 11.883662992230636, 10.953681440935874, 11.88283075823471, 12.686655472755616, 13.576455088239955, 14.454784606803988, 15.477476766913282, 15.524932521307795, 14.497790592758117, 13.441796358625878, 12.510648360519614, 11.56367897474423, 10.638478531340764, 9.657640586632159, 8.87125183734122, 9.760182660639504, 10.757849774013756, 11.556408085538822, 11.619030645498892, 12.474064324314048, 12.821570323855271, 11.969776837985153, 12.903049098933568, 13.758433385826365, 14.59696733697336, 15.434973588915142, 15.520062324447592, 14.686857342218739, 13.690563125894759, 12.726236526071016, 11.657183479745612, 10.673914717438594, 9.664094362119442, 8.684866747432984, 7.873006362580567, 8.75937446395645, 9.782955235360461, 10.623945873958567, 10.611829855340176, 11.538243381630398, 12.467857204350077, 12.9010741521871, 13.878768204998135, 14.819225777346803, 15.605323626343996, 15.549401447857564, 14.512248389604679, 13.670222240573333, 12.682510166893527, 11.68421855674077, 10.682254869077367, 9.674788117708717, 8.681163254812562, 7.741368207459594, 6.821285637053993, 7.789050085665192, 8.754036152281417, 9.63765738254603, 9.613990556575747, 10.57522030613636, 11.548925894111441, 12.490665355551078, 13.479996832045979, 14.544406147407404, 15.53355860190678, 14.540575893537559, 13.559548926656912, 12.599412608638051, 11.646142678932936, 10.636585570162467, 9.689184145185106, 8.726358928237465, 7.742365258415365, 6.803841418099735, 5.855146445546159, 6.800599972797321, 7.75636838762323, 8.699061978553075, 8.668141289028476, 9.626174669568403, 10.621722960800335, 11.57682789751987, 12.63662029967728, 13.642546370983322, 14.575367082744183, 13.531012470796481, 12.626563322315706, 11.664310089016553, 10.686940039998941, 9.77041412071531, 8.814723637482611, 7.840495251819428, 6.790512870578352, 5.823260317184053, 4.875460198464507, 5.817949614489678, 6.787112774167643, 7.726360027288619, 7.642792801770668, 8.710495093459276, 9.69255766409033, 10.651057918555022, 11.702035586710156, 12.641381534706463, 13.542379809915325, 12.568683312315953, 11.601260631917029, 10.656803878262568, 9.731453758028852, 8.836832500021583, 7.884033032234937, 6.873491539782176, 5.928391604388716, 4.885664902295018, 3.8521033096927684, 4.892379427580835, 5.834357460154985, 6.6770949967268844, 6.714591635251296, 7.7440941696935095, 8.782416105265998, 9.693125111155545, 10.69288352061699, 11.691840000117816, 12.583598878647537, 11.60158493121262, 10.647163730296347, 9.746775817989171, 8.79380151901709, 7.833045587119947, 6.875516759549619, 5.842298536251082, 4.911743409292921, 3.8939430251683933, 2.889079419853758, 3.8735757277247647, 4.820047989979647, 5.7455337669601, 5.807945562078374, 6.75481884747651, 7.740850621478433, 8.760941012796529, 9.827675831011568, 10.782799872800313, 11.739101060669858, 10.72901089962655, 9.703353067085565, 8.715310257302418, 7.784151889500533, 6.763388076319681, 5.834818858857087, 4.894370502199894, 3.8879975150335224, 2.8930367165103603, 1.92888668854454, 2.893559326300527, 3.854362777243466, 4.854203144574964, 4.980550517731168, 6.053960924871728, 7.015136957601009, 7.9520521375844595, 9.026325060730931, 10.099098801764255, 10.842489989376151, 9.887466257665038, 8.901321867689717, 7.918294744196991, 6.980963165490649, 6.042881379701601, 5.06040951630684, 4.055467846967442, 2.995031000156458, 1.9575078527584715, 0.9666447349573006, 1.9988572053347575, 3.0409469590090463, 4.0163611498424485, 4.012541635689427, 5.058483156564847, 6.108456116126065, 7.1006516879437, 8.134233050061283, 9.16086917398852, 10.116389256177648, 9.107245990662385, 8.148334441503515, 7.07592751982179, 6.036380016613641, 5.0794257566887895, 4.0320011770333, 3.04021104947814, 2.055189375428001, 0.993020515547764, 0.0, 1.002413608366647, 2.014904449023576, 2.993004401992658], [2.908314272633334, 1.9586697595137839, 0.9855601238260481, 1.9385516350772587, 2.992018338691233, 3.9967166537800836, 5.010998556701922, 6.036035281486039, 7.068245442427311, 8.037390506643238, 9.024956343580488, 10.05143193386664, 10.984630880242012, 9.99463798159991, 9.038038450745333, 8.067002623488671, 7.0285016890780705, 6.01630972992923, 4.967762489317357, 3.9481260189235883, 3.8797897385471996, 2.93470564419394, 2.0163664348348895, 2.878949714065202, 3.814103118790502, 4.791316331741304, 5.852342220389377, 6.787567951944069, 7.774314958576529, 8.795430987772079, 9.74953624578086, 10.679169255182124, 11.71789327315485, 10.806758732582082, 9.768237295887449, 8.761867414549938, 7.798907043404705, 6.7539255503472, 5.7673062333070995, 4.82037984475108, 4.897511001809894, 3.935361465982753, 3.0511978975268192, 3.907843587218167, 4.823206880079023, 5.779654778240609, 6.828868491758625, 7.8367904295175475, 8.749739268736434, 9.702568215294502, 10.724712098533177, 11.616668701111443, 12.67410467933957, 11.760468143001454, 10.787468253134687, 9.812843039178148, 8.773796533965125, 7.723364605490286, 6.759349730773851, 5.75814639556277, 5.930504848432311, 4.8967705408219, 4.100323059991139, 4.870354211210454, 5.776156776143692, 6.803426204326549, 7.786305068345501, 8.785389867865275, 9.731068992013387, 10.656134566152094, 11.70200857703399, 12.629032405589884, 13.592663454253275, 12.7798885356172, 11.731774414647074, 10.687665727592478, 9.618174258662684, 8.680044636673134, 7.682508307457802, 6.745000467722609, 6.875528148697816, 5.9349454730809885, 5.0503657663477854, 5.9092273831919595, 6.835789478758156, 7.769437407466709, 8.75848905274173, 9.701224966364551, 10.683656452263829, 11.690128904457337, 12.643236055235077, 13.559124160077678, 14.552092214455342, 13.669489204220387, 12.6060803190451, 11.649249963097564, 10.598387679833671, 9.641509857423587, 8.676945161949313, 7.736354008668926, 7.822570689298306, 6.934454973133162, 6.097064095290161, 6.908240753535646, 7.90689136254501, 8.703029718289612, 9.74328954513857, 10.626473607149798, 11.599386467585353, 12.585038321205358, 13.519628310063153, 14.546074387885081, 15.553451848495781, 14.642407364467271, 13.576077353052655, 12.528890159105513, 11.554116216310009, 10.548069084970724, 9.611503874473321, 8.711147408170143, 8.81577277742167, 7.9481955120053325, 7.129326690142249, 7.897444182524336, 8.873716434378409, 9.753828613889612, 10.749636348953354, 11.572567553866108, 12.530723618240796, 13.520818348166802, 14.468295667284853, 15.434076671072383, 16.36455720950285, 15.432921997996962, 14.425105217697311, 13.446395559193252, 12.486950245827254, 11.482688948617286, 10.575622190182484, 9.700189696088518, 9.782979090719811, 8.95925743264365, 8.120477690461577, 8.921537280076855, 9.929383063361264, 10.739291289731618, 11.703203689778098, 12.519076336306208, 13.47253950846906, 14.4397419780116, 15.499344187248617, 16.455022656495604, 16.497019448104027, 15.469223845221922, 14.484948770829787, 13.542855255533434, 12.951629150890962, 12.04843178439242, 11.515341355228259, 10.708535000820447, 10.711579146823969, 10.032191401565235, 9.073432077578524, 9.988692277457199, 10.960770896728162, 11.72133435243126, 12.707837944973607, 13.587756567546792, 14.547512818157355, 15.402804028360954, 16.398450033503362, 16.475987607843773, 15.554354809116633, 14.497037292213964, 13.543428569224185, 12.605689163905401, 11.949013101295655, 11.04620773259709, 11.953344201377499, 11.669087212901145, 11.71807119153408, 11.006381642071247, 10.108551312756866, 10.957892284951924, 11.941283371107957, 12.733130452777516, 13.641051492892363, 14.530928934071913, 15.500730625985211, 16.372906460385085, 16.44951065908938, 15.4745716250878, 14.54101858458693, 13.612491460083122, 12.593057166301458, 11.619757785721042, 10.892810396415033, 10.09451349093385, 11.00542177801287, 11.685947655346228, 11.691495094265939, 12.075290025093985, 11.166234285005896, 11.956095049302519, 12.885244366601356, 13.689069081122263, 14.578868696606602, 15.457198215170633, 16.479890375279926, 16.52734612967444, 15.500204201124765, 14.444209966992526, 13.513061968886262, 12.566092583110878, 11.640892139707413, 10.660054194998807, 9.873665445707868, 9.02389903742679, 9.975651840668604, 10.674299439954408, 10.736921999914479, 11.591955678729635, 12.10414161663053, 12.972190446351798, 13.905462707300213, 14.760846994193013, 15.599380945340007, 16.437387197281787, 16.522475932814242, 15.689270950585387, 14.692976734261407, 13.728650134437665, 12.65959708811226, 11.676328325805242, 10.66650797048609, 9.687280355799633, 8.875419970947215, 8.023090840743736, 8.950697916849004, 9.741837228374154, 9.729721209755763, 10.656134736045985, 11.585748558765664, 12.581480093185446, 13.53308386989862, 14.527819864174841, 15.501473717863854, 16.542922001372904, 15.514661997971327, 14.67263584893998, 13.684923775260176, 12.686632165107419, 11.684668477444015, 10.677201726075365, 9.68357686317921, 8.743781815826242, 7.823699245420641, 7.052766462452478, 7.88196052249244, 8.755548736961616, 8.731881910991333, 9.693111660551947, 10.666817248527027, 11.608556709966663, 12.597888186461564, 13.662297501822987, 14.69834429135368, 15.542989501904206, 14.561962535023559, 13.601826217004698, 12.648556287299584, 11.638999178529115, 10.691597753551754, 9.728772536604113, 8.744778866782013, 7.806255026466383, 6.857560053912806, 6.064316349584607, 6.8742597420388165, 7.816953332968662, 7.786032643444062, 8.744066023983988, 9.73961431521592, 10.686463757287516, 11.746256159444926, 12.752182230750968, 13.789204816717874, 14.533426079163128, 13.628976930682352, 12.6667236973832, 11.689353648365588, 10.772827729081957, 9.817137245849258, 8.842908860186077, 7.792926478945001, 6.825673925550701, 5.877873806831155, 5.081665991276965, 5.905004128583229, 6.844251381704204, 6.760684156186254, 7.828386447874862, 8.810449018505917, 9.760693778322668, 10.811671446477803, 11.75101739447411, 12.739951067876701, 13.5710969206826, 12.603674240283675, 11.659217486629215, 10.733867366395499, 9.83924610838823, 8.886446640601584, 7.8759051481488225, 6.930805212755364, 5.888078510661665, 4.854516918059415, 4.010270781996421, 4.952248814570571, 5.79498635114247, 5.832482989666882, 6.8619855241090955, 7.900307459681585, 8.802760970923192, 9.802519380384636, 10.801475859885462, 11.781170136608914, 12.603998539579267, 11.649577338662993, 10.749189426355818, 9.796215127383737, 8.835459195486594, 7.8779303679162656, 6.844712144617729, 5.9141570176595675, 4.89635663353504, 3.891493028220405, 2.9914670821403506, 3.9379393443952333, 4.863425121375686, 4.9175814218460205, 5.864454707244156, 6.8504864812460795, 7.870576872564175, 8.937311690779215, 9.892435732567959, 10.848736920437505, 11.731424507993196, 10.705766675452212, 9.717723865669065, 8.78656549786718, 7.765801684686328, 6.837232467223734, 5.89678411056654, 4.8904111234001695, 3.8954503248770074, 2.931300296911187, 2.0114506807161128, 2.972254131659052, 3.9638390043426095, 3.9781369093645207, 5.051547316505079, 6.012723349234361, 6.949638529217811, 8.023911452364283, 9.096685193397606, 10.121602235812777, 10.889879866031686, 9.903735476056365, 8.920708352563638, 7.983376773857296, 7.045294988068248, 6.062823124673487, 5.0578814553340905, 3.9974446085231055, 2.9599214611251186, 1.9690583433239477, 1.0332778548315062, 2.075367608505795, 3.013947541475801, 3.0101280273227795, 4.0560695481982, 5.106042507759417, 6.098238079577053, 7.1318194416946366, 8.158455565621873, 9.113975647811001, 10.10965959902903, 9.150748049870161, 8.078341128188438, 7.038793624980289, 6.081839365055437, 5.034414785399948, 4.0426246578447875, 3.0576029837946486, 1.995434123914411, 1.002413608366647, 0.0, 1.0124908406569288, 1.9905907936260103], [1.8958234319764053, 0.946178918856855, 1.939521254400844, 2.899313407942415, 3.9527801115563896, 4.95747842664524, 5.971760329567078, 7.025868968527082, 8.065406772266998, 9.049881347300165, 10.037447184237415, 10.936082712225478, 9.972140039585083, 8.982147140942981, 8.025547610088404, 7.054511782831742, 6.016010848421142, 5.003818889272301, 3.9552716486604282, 2.9356351782666597, 2.8672988978902705, 1.922214803537011, 2.9006720103301924, 3.8397114869303586, 4.774864891655659, 5.75207810460646, 6.813103993254534, 7.748329724809225, 8.735076731441685, 9.756192760637235, 10.710298018646016, 11.63993102804728, 10.775544368289905, 9.794267891925154, 8.75574645523052, 7.749376573893009, 6.786416202747777, 5.741434709690272, 4.754815392650171, 3.8078890040941507, 3.885020161152965, 2.9228706253258236, 3.935503473022122, 4.868605360083324, 5.783968652944179, 6.740416551105765, 7.789630264623781, 8.797552202382704, 9.71050104160159, 10.663329988159658, 11.685473871398333, 12.5774304739766, 11.696561298417233, 10.747977302344525, 9.774977412477758, 8.80035219852122, 7.761305693308197, 6.710873764833357, 5.746858890116922, 4.745655554905841, 4.918014007775382, 3.8842797001649707, 4.868496366984019, 5.8183075313560915, 6.736918549008848, 7.764187977191706, 8.747066841210657, 9.746151640730432, 10.691830764878544, 11.61689633901725, 12.662770349899146, 13.58979417845504, 12.663466098070138, 11.767397694960271, 10.719283573990145, 9.67517488693555, 8.605683418005755, 7.667553796016205, 6.670017466800872, 5.73250962706568, 5.8630373080408855, 4.922454632424058, 5.8185390733406654, 6.857180703337597, 7.796551251623312, 8.730199180331866, 9.719250825606887, 10.661986739229707, 11.644418225128986, 12.650890677322494, 13.603997828100233, 14.519885932942834, 13.63943871754698, 12.656998363563456, 11.593589478388171, 10.636759122440635, 9.585896839176742, 8.629019016766659, 7.664454321292383, 6.723863168011997, 6.810079848641376, 5.921964132476232, 6.865237402283041, 7.856194073681283, 8.867653135410166, 9.663791491154768, 10.704051318003726, 11.587235380014954, 12.56014824045051, 13.545800094070515, 14.48039008292831, 15.50683616075024, 14.601327724524497, 13.62991652381034, 12.563586512395727, 11.516399318448585, 10.54162537565308, 9.535578244313795, 8.599013033816393, 7.698656567513214, 7.803281936764739, 6.935704671348402, 7.897499997135129, 8.845397502669973, 9.821669754524045, 10.714590386754768, 11.71039812181851, 12.533329326731264, 13.491485391105952, 14.481580121031959, 15.42905744015001, 16.394838443937537, 15.466268823421947, 14.420431157340033, 13.412614377040383, 12.433904718536324, 11.474459405170325, 10.470198107960357, 9.563131349525555, 8.687698855431588, 8.770488250062881, 7.9467665919867185, 8.888650997454457, 9.869490600222493, 10.8773363835069, 11.700053062596774, 12.663965462643255, 13.479838109171364, 14.433301281334217, 15.400503750876757, 16.460105960113776, 17.287566491024595, 16.287052325201834, 15.22097051654392, 14.236695442151785, 13.294601926855432, 12.347277336956772, 11.415419656678248, 10.50285051457133, 9.696044160163517, 9.699088306167038, 9.019700560908305, 9.841605384571404, 10.857857954666793, 11.884599142697127, 12.682096125296416, 13.668599717838763, 14.548518340411949, 15.508274591022511, 16.36356580122611, 17.359211806368517, 17.4884784485007, 16.566845649773562, 15.509528132870892, 14.555919409881113, 13.61818000456233, 12.947624839731514, 12.00419409958747, 11.117150441711692, 10.656596372244215, 10.705580350877149, 9.993890801414317, 10.876724619749746, 11.827057962161518, 12.810449048317551, 13.693892225642672, 14.601813265757519, 15.49169070693707, 16.46149239885037, 17.33366823325024, 17.462001499746307, 16.487062465744728, 15.553509425243858, 14.62498230074005, 13.605548006958387, 12.63224862637797, 11.90530123707196, 11.05249985792423, 10.169228018347063, 10.806046492750399, 10.756610341122524, 11.062799184437054, 11.934407591998776, 12.825260726512113, 13.75441004381095, 14.64983085398742, 15.539630469471758, 16.41795998803579, 17.440652148145087, 17.539836970331372, 16.512695041781694, 15.456700807649455, 14.525552809543191, 13.578583423767807, 12.653382980364341, 11.672545035655736, 10.886156286364796, 9.981885404417172, 9.139458081002797, 9.79439827735858, 9.802037246771064, 10.644089112005386, 11.573348801691802, 12.533031574986957, 13.46630383593537, 14.453857739662574, 15.423267865569692, 16.480680757687974, 17.534966773471172, 16.70176179124232, 15.705467574918337, 14.741140975094593, 13.672087928769189, 12.68881916646217, 11.67899881114302, 10.699771196456561, 9.887910811604144, 8.981077207734117, 8.114504157183198, 8.861936065778325, 8.794836456612348, 9.708268169321736, 10.637881992041414, 11.609595386666081, 12.561199163379255, 13.555935157655476, 14.52958901134449, 15.571037294853541, 16.527152838628258, 15.68512668959691, 14.697414615917104, 13.699123005764347, 12.697159318100944, 11.689692566732294, 10.696067703836139, 9.756272656483171, 8.83619008607757, 8.01075282944286, 7.045766762826634, 7.875647574365788, 7.784015344267084, 8.745245093827698, 9.718950681802777, 10.636672003447298, 11.626003479942199, 12.690412795303622, 13.726459584834314, 14.68197417786307, 15.57445337568049, 14.614317057661628, 13.661047127956511, 12.651490019186044, 11.704088594208683, 10.741263377261042, 9.757269707438942, 8.818745867123312, 7.870050894569736, 7.037807888096322, 6.038065982373011, 6.937052170372834, 6.838166076719813, 7.796199457259739, 8.791747748491671, 9.673972916630586, 10.733765318787995, 11.739691390094038, 12.776713976060943, 13.672410755121993, 14.641467771339283, 13.67921453804013, 12.701844489022518, 11.785318569738886, 10.829628086506187, 9.855399700843005, 8.80541731960193, 7.83816476620763, 6.890364647488084, 6.055157529788679, 5.068810368917425, 5.896384814979955, 5.812817589462004, 6.8805198811506125, 7.862582451781668, 8.748202937665738, 9.799180605820872, 10.738526553817179, 11.72746022721977, 12.710081596641464, 13.616165080940606, 12.671708327286145, 11.74635820705243, 10.851736949045158, 9.898937481258512, 8.888395988805751, 7.943296053412293, 6.900569351318595, 5.867007758716345, 5.022761622653349, 4.116055054904766, 4.847119784418221, 4.8835548502847415, 5.8986267144744575, 6.905309385226162, 7.790270130266261, 8.790028539727706, 9.788985019228532, 10.768679295951983, 11.7506932433869, 12.662068179319924, 11.761680267012748, 10.808705968040668, 9.847950036143523, 8.890421208573194, 7.857202985274657, 6.926647858316497, 5.90884747419197, 4.903983868877335, 4.003957922797279, 3.1017455847294286, 3.915558554651437, 3.9050905811890915, 4.8519638665872264, 5.83799564058915, 6.858086031907246, 7.924820850122285, 8.87994489191103, 9.836246079780576, 10.85272132718557, 11.718257516109142, 10.730214706325995, 9.79905633852411, 8.778292525343257, 7.849723307880663, 6.90927495122347, 5.902901964057099, 4.907941165533937, 3.9437911375681165, 3.0239415213730414, 2.1360603719932474, 2.951348163685681, 2.965646068707592, 4.039056475848151, 5.000232508577432, 5.9371476885608825, 7.011420611707355, 8.08419435274068, 9.109111395155848, 10.064135126866962, 10.916226316713292, 9.933199193220565, 8.995867614514223, 8.057785828725176, 7.075313965330416, 6.070372295991019, 5.009935449180035, 3.972412301782048, 2.981549183980877, 2.045768695488435, 1.0691768145454559, 2.0014567008188724, 1.9976371866658509, 3.043578707541271, 4.0935516671024885, 5.085747238920124, 6.119328601037708, 7.145964724964944, 8.101484807154073, 9.13274123393401, 10.09165278309288, 9.090831968845364, 8.051284465637217, 7.094330205712366, 6.046905626056876, 5.055115498501716, 4.070093824451577, 3.00792496457134, 2.014904449023576, 1.0124908406569288, 0.0, 0.9780999529690816], [1.074751924460486, 1.9242788718259365, 2.9176212073699253, 3.8774133609114965, 4.9308800645254705, 5.935578379614321, 6.949860282536159, 8.003968921496163, 9.04350672523608, 10.027981300269246, 11.005855440635154, 9.979379850349002, 9.015437177708607, 8.025444279066505, 7.068844748211928, 6.097808920955266, 5.059307986544666, 4.09345178770336, 3.0449045470914866, 2.025268076697718, 2.047151572457924, 2.9003147565060927, 3.878771963299274, 4.81781143989944, 5.75296484462474, 6.730178057575542, 7.791203946223615, 8.726429677778306, 9.713176684410767, 10.734292713606317, 11.688397971615098, 10.921662745975055, 9.921617744686356, 8.940341268321605, 7.901819831626971, 6.89544995028946, 5.932489579144227, 4.887508086086722, 3.900888769046621, 2.9539623804906014, 3.0648728357206187, 3.9009705782949053, 4.913603425991203, 5.846705313052405, 6.762068605913261, 7.718516504074847, 8.767730217592863, 9.775652155351784, 10.688600994570672, 11.64142994112874, 12.663573824367415, 11.859162191904375, 10.842634674813684, 9.894050678740976, 8.92105078887421, 7.94642557491767, 6.907379069704648, 5.856947141229808, 4.892932266513373, 3.891728931302292, 4.097866682343035, 4.862379653134052, 5.8465963199531, 6.796407484325173, 7.71501850197793, 8.742287930160789, 9.725166794179739, 10.724251593699513, 11.669930717847626, 12.594996291986332, 13.640870302868228, 12.77317052312998, 11.80953947446659, 10.913471071356723, 9.865356950386596, 8.821248263332, 7.7517567944022066, 6.813627172412656, 5.8160908431973235, 4.878583003462131, 5.042889982608539, 5.90055458539314, 6.796639026309747, 7.835280656306678, 8.774651204592395, 9.708299133300947, 10.697350778575968, 11.640086692198789, 12.622518178098067, 13.628990630291575, 14.582097781069315, 13.703262277617775, 12.785512093943431, 11.803071739959908, 10.739662854784623, 9.782832498837086, 8.731970215573194, 7.775092393163109, 6.810527697688834, 5.869936544408448, 5.9899325232090295, 6.9000640854453135, 7.843337355252123, 8.834294026650364, 9.845753088379249, 10.64189144412385, 11.682151270972808, 12.565335332984036, 13.53824819341959, 14.523900047039596, 15.458490035897391, 14.725305853670703, 13.747401100920948, 12.775989900206792, 11.709659888792178, 10.662472694845036, 9.687698752049531, 8.681651620710246, 7.745086410212844, 6.844729943909665, 6.983134611332392, 7.913804624317484, 8.875599950104212, 9.823497455639053, 10.799769707493127, 11.69269033972385, 12.688498074787592, 13.511429279700346, 14.469585344075034, 15.45968007400104, 16.40715739311909, 15.542822738248864, 14.612342199818398, 13.566504533736484, 12.558687753436834, 11.579978094932775, 10.620532781566776, 9.616271484356808, 8.709204725922007, 7.83377223182804, 7.9503409246305345, 8.924866544955801, 9.866750950423539, 10.847590553191573, 11.855436336475982, 12.678153015565856, 13.642065415612336, 14.457938062140446, 15.411401234303298, 16.37860370384584, 17.389318336668033, 16.433639867421046, 15.433125701598286, 14.367043892940371, 13.382768818548236, 12.440675303251883, 11.493350713353223, 10.561493033074699, 9.648923890967781, 8.84211753655997, 8.878940980734692, 9.875071806106998, 10.819705337540485, 11.835957907635875, 12.862699095666208, 13.660196078265498, 14.646699670807845, 15.52661829338103, 16.48637454399159, 17.341665754195194, 18.33230737423193, 17.292581181824904, 16.33291790433016, 15.269189523188478, 14.315580800198699, 13.377841394879916, 12.49596676294853, 11.563717084870028, 10.69029505419688, 9.802669748640668, 9.885433025444804, 10.828406976818691, 11.854824572718828, 12.8051579151306, 13.788549001286633, 14.671992178611754, 15.5799132187266, 16.469790659906153, 17.439592351819453, 18.311768186219325, 18.282419045468657, 17.307480011467078, 16.37392697096621, 15.4453998464624, 14.425965552680736, 13.45266617210032, 12.62661766389786, 11.73960469871492, 10.815865781537273, 9.827946539781319, 9.778510388153443, 10.6354845458528, 11.533156180347357, 12.5409426268194, 13.482841106592634, 14.547535699764246, 15.465680161334019, 16.482769786830048, 17.519689361664415, 18.360254516053722, 17.333112587504043, 16.277118353371804, 15.34597035526554, 14.399000969490157, 13.473800526086691, 12.492962581378086, 11.607472713190695, 10.668990245207862, 9.816747710000401, 8.8162983243895, 8.823937293801983, 9.665989159036306, 10.595248848722722, 11.554931622017877, 12.488203882966292, 13.475757786693496, 14.445167912600613, 15.502580804718896, 16.566587843121358, 17.561070847057128, 16.564776630733146, 15.600450030909403, 14.531396984584, 13.520144151051788, 12.49941635686537, 11.520188742178911, 10.652729460758621, 9.668182048524807, 8.801608997973888, 7.883836112809245, 7.816736503643266, 8.730168216352656, 9.659782039072335, 10.631495433697, 11.583099210410174, 12.577835204686394, 13.551489058375408, 14.59293734188446, 15.610392081758956, 16.57458518496674, 15.556723671731914, 14.558432061579158, 13.556468373915754, 12.549001622547104, 11.55537675965095, 10.576690202205521, 9.630577225194026, 8.69785767023355, 7.732871603617324, 6.897547621396708, 6.8059153912980035, 7.767145140858617, 8.740850728833696, 9.658572050478217, 10.647903526973117, 11.71231284233454, 12.748359631865233, 13.703874224893989, 14.65769261881119, 15.503775553031458, 14.520356183771323, 13.510799075000854, 12.563397650023493, 11.600572433075852, 10.616578763253752, 9.678054922938122, 8.664438033686192, 7.724912728887012, 6.725170823163701, 5.958952217403754, 5.860066123750732, 6.818099504290658, 7.81364779552259, 8.695872963661504, 9.755665365818913, 10.761591437124956, 11.798614023091861, 12.694310802152911, 13.724707014469983, 14.65136728847975, 13.676999585052153, 12.689344630752524, 11.733654147519825, 10.714708756657815, 9.66472637541674, 8.69747382202244, 7.68475178660454, 6.742262370579369, 5.755915209708115, 4.918284862010875, 4.834717636492924, 5.902419928181532, 6.884482498812587, 7.770102984696657, 8.821080652851792, 9.760426600848097, 10.749360274250689, 11.731981643672382, 12.699404324071306, 13.643861077725767, 12.721513303082064, 11.826892045074793, 10.874092577288147, 9.863551084835386, 8.8980695825912, 7.855342880497501, 6.821781287895251, 5.843853357328241, 4.803159895695456, 3.8690198314491404, 3.9054548973156598, 4.920526761505377, 5.927209432257081, 6.8121701772971806, 7.811928586758624, 8.81088506625945, 9.790579342982902, 10.772593290417818, 11.727014491334092, 12.736835363042383, 11.783861064070303, 10.823105132173158, 9.865576304602829, 8.832358081304292, 7.901802954346132, 6.863621003370876, 5.858757398056241, 4.825049657472171, 3.862944378662809, 2.937458601682356, 2.92699062822001, 3.8738639136181456, 4.859895687620069, 5.879986078938165, 6.946720897153204, 7.901844938941949, 8.858146126811494, 9.874621374216488, 10.900279206757473, 11.70536980235563, 10.774211434553745, 9.753447621372892, 8.824878403910297, 7.884430047253105, 6.878057060086734, 5.883096261563572, 4.898564666747022, 3.9338920289910355, 2.9730885780480962, 1.9732482107165994, 1.9875461157385108, 3.06095652287907, 4.022132555608351, 4.959047735591802, 6.033320658738274, 7.106094399771598, 8.131011442186768, 9.086035173897882, 10.072179563873203, 10.911299146189647, 9.973967567483305, 9.035885781694258, 8.053413918299498, 7.048472248960101, 5.988035402149115, 4.950512254751128, 3.959649136949958, 3.0238686484575164, 2.0472767675145374, 1.023356747849791, 1.0195372336967692, 2.0654787545721893, 3.115451714133407, 4.1076472859510424, 5.141228648068626, 6.167864771995863, 7.123384854184992, 8.15464128096493, 9.113552830123798, 10.068931921814446, 9.029384418606298, 8.072430158681447, 7.025005579025958, 6.033215451470798, 5.048193777420659, 3.9860249175404214, 2.9930044019926574, 1.9905907936260103, 0.9780999529690816, 0.0]]}],
                            {"plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "xaxis": {"constrain": "domain", "scaleanchor": "y"}, "yaxis": {"autorange": "reversed", "constrain": "domain"}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('f9235710-123c-475e-904f-1cf75d1b878e');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Saving the results into an array
    topological_spaces_mat = np.asarray([rp2, klein])

Computing persistent homology
-----------------------------

In the next section we will use ``giotto-tda`` to compute the persistent
homology groups of the topological spaces we just constructed.

.. code:: ipython3

    # the homology ranks we choose to consider
    homology_dimensions = (0, 1, 2)
    VR = VietorisRipsPersistence(
        metric='precomputed', max_edge_length=np.inf, homology_dimensions=homology_dimensions)
    
    # List of all the time-ordered persistence diagrams obtained from the list of correlation matrices
    diagrams = VR.fit_transform(topological_spaces_mat)

Persistence diagrams
--------------------

The topological information of the point cloud is synthesised in the
persistence diagram. The horizontal axis corresponds to the moment in
which an homological generator is born, while the vertical axis
corresponds to the moments in which an homological generator dies.

The generators of the homology groups (at given rank) are colored
differently.

.. code:: ipython3

    # Plotting the persistence diagram of the projective space
    plot_diagram(diagrams[0])



.. raw:: html

    <div>
    
    
                <div id="e5da9583-2463-466b-813d-b4b7b7e98785" class="plotly-graph-div" style="height:500px; width:500px;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("e5da9583-2463-466b-813d-b4b7b7e98785")) {
                        Plotly.newPlot(
                            'e5da9583-2463-466b-813d-b4b7b7e98785',
                            [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-966.5863990783691, 966.5863990783691], "y": [-966.5863990783691, 966.5863990783691]}, {"mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [0.9250187873840332, 0.9250879287719727, 0.9260317087173462, 0.9260429739952087, 0.9260894060134888, 0.9261602163314819, 0.9263830184936523, 0.9265275597572327, 0.9266043305397034, 0.9267378449440002, 0.9272009134292603, 0.9272594451904297, 0.9273721575737, 0.927436888217926, 0.927498459815979, 0.9275341629981995, 0.9276047945022583, 0.9276856184005737, 0.9277164936065674, 0.9280447959899902, 0.9284534454345703, 0.9290545582771301, 0.9292041659355164, 0.9295658469200134, 0.9295682311058044, 0.9298509955406189, 0.929979681968689, 0.9300441741943359, 0.9306854009628296, 0.9307442903518677, 0.9309212565422058, 0.9313540458679199, 0.9314357042312622, 0.9315941333770752, 0.931601881980896, 0.9319145083427429, 0.9321976900100708, 0.9324295520782471, 0.932598888874054, 0.9328181147575378, 0.9331667423248291, 0.9332016110420227, 0.9340196251869202, 0.9341359734535217, 0.9343683123588562, 0.9348980188369751, 0.9350483417510986, 0.9352905750274658, 0.9354701042175293, 0.9354908466339111, 0.9356952905654907, 0.9358386397361755, 0.9360789060592651, 0.9360905885696411, 0.9361037015914917, 0.9366064071655273, 0.9372711181640625, 0.9373815059661865, 0.9374957084655762, 0.9377792477607727, 0.9380078315734863, 0.9381508827209473, 0.9384366869926453, 0.9386523962020874, 0.9390988349914551, 0.9392852187156677, 0.9393342137336731, 0.9393696188926697, 0.9393723607063293, 0.9393985867500305, 0.9394020438194275, 0.9394062161445618, 0.9397482872009277, 0.9397851228713989, 0.9400226473808289, 0.9407461881637573, 0.9407895803451538, 0.9411449432373047, 0.9411703944206238, 0.9412490725517273, 0.9416254758834839, 0.9417469501495361, 0.9419510960578918, 0.9420564770698547, 0.9420657157897949, 0.9427269697189331, 0.942770779132843, 0.9428703188896179, 0.9430175423622131, 0.943244993686676, 0.9433562159538269, 0.943438708782196, 0.9435589909553528, 0.9438157081604004, 0.944107711315155, 0.9441369771957397, 0.944196879863739, 0.9442671537399292, 0.9443168044090271, 0.9445511102676392, 0.9445676803588867, 0.9447395205497742, 0.9448078274726868, 0.9448291659355164, 0.9450492858886719, 0.9450814127922058, 0.9451687335968018, 0.9452102184295654, 0.9452135562896729, 0.9453012347221375, 0.9457280039787292, 0.9459500908851624, 0.9459539651870728, 0.9461705684661865, 0.9466065168380737, 0.9468660354614258, 0.9475354552268982, 0.9476226568222046, 0.9478762149810791, 0.9482364058494568, 0.9482741951942444, 0.9484760761260986, 0.9488157033920288, 0.94899982213974, 0.9490357041358948, 0.9490926265716553, 0.9491446018218994, 0.9491451382637024, 0.9491832256317139, 0.9491840600967407, 0.9493698477745056, 0.9494256377220154, 0.9503745436668396, 0.9506091475486755, 0.9507719874382019, 0.9509673118591309, 0.9509835243225098, 0.951192319393158, 0.9516337513923645, 0.951798677444458, 0.9519843459129333, 0.9522463083267212, 0.9523454308509827, 0.9524090886116028, 0.9525460600852966, 0.9525707364082336, 0.9528031349182129, 0.9528737664222717, 0.9529134035110474, 0.9529338479042053, 0.9533683061599731, 0.9534508585929871, 0.9538258910179138, 0.9539933204650879, 0.9542828798294067, 0.9543259739875793, 0.9548332691192627, 0.9549965262413025, 0.9550818204879761, 0.95512855052948, 0.9551572799682617, 0.9551723003387451, 0.9551956057548523, 0.9558936357498169, 0.9560507535934448, 0.9562011361122131, 0.9562684893608093, 0.9563353061676025, 0.9563915133476257, 0.9564579725265503, 0.956505537033081, 0.9566336870193481, 0.956637978553772, 0.9566637873649597, 0.956697404384613, 0.9568911194801331, 0.9569368958473206, 0.9569442272186279, 0.9571132063865662, 0.9572938084602356, 0.9576725363731384, 0.9577648043632507, 0.9579399228096008, 0.9580188989639282, 0.9581810832023621, 0.9584160447120667, 0.9586913585662842, 0.959097146987915, 0.9591842293739319, 0.9592118263244629, 0.9593132138252258, 0.9595485925674438, 0.9597906470298767, 0.9598557353019714, 0.9602272510528564, 0.9602348804473877, 0.960239589214325, 0.9605653285980225, 0.960719645023346, 0.9608548879623413, 0.9608555436134338, 0.9609093070030212, 0.9610139727592468, 0.9612929224967957, 0.9615373015403748, 0.9615653157234192, 0.962146520614624, 0.9624069333076477, 0.9624353051185608, 0.9628350138664246, 0.9629140496253967, 0.9632700681686401, 0.9637563824653625, 0.964262068271637, 0.9644272327423096, 0.9645923972129822, 0.9648666977882385, 0.9652145504951477, 0.9652600884437561, 0.9653477668762207, 0.9654076099395752, 0.9654921889305115, 0.9656449556350708, 0.9656625390052795, 0.9657642841339111, 0.9658094644546509, 0.9658551216125488, 0.9660788178443909, 0.966525673866272, 0.9665878415107727, 0.9668287038803101, 0.9668586254119873, 0.9668647050857544, 0.9668802618980408, 0.9669371247291565, 0.9677477478981018, 0.9678277373313904, 0.9678657650947571, 0.9684392809867859, 0.9686262607574463, 0.969083309173584, 0.9691418409347534, 0.9692956805229187, 0.9693262577056885, 0.9693905711174011, 0.9694912433624268, 0.969685435295105, 0.969721257686615, 0.9697577953338623, 0.9697882533073425, 0.969951868057251, 0.9702020883560181, 0.9702451229095459, 0.970253050327301, 0.9703148603439331, 0.9706076383590698, 0.9706503748893738, 0.9706792831420898, 0.9708840250968933, 0.9712736010551453, 0.9713430404663086, 0.971887469291687, 0.9721070528030396, 0.9722221493721008, 0.9723938703536987, 0.9724811911582947, 0.9726030230522156, 0.9726728796958923, 0.9729052186012268, 0.9730745553970337, 0.9733578562736511, 0.973586916923523, 0.9737908840179443, 0.9738291501998901, 0.9741942882537842, 0.9747257232666016, 0.9751349687576294, 0.9753748774528503, 0.9754264950752258, 0.9754284620285034, 0.9754647612571716, 0.9758721590042114, 0.9759902358055115, 0.9760839939117432, 0.9761224985122681, 0.9764496088027954, 0.9767483472824097, 0.9767736792564392, 0.9770801663398743, 0.9770920872688293, 0.977911651134491, 0.9780239462852478, 0.9786507487297058, 0.9786607623100281, 0.9787558913230896, 0.9789909720420837, 0.9789992570877075, 0.9792642593383789, 0.9797446727752686, 0.9804174304008484, 0.980844259262085, 0.9811530709266663, 0.9812424778938293, 0.9816571474075317, 0.9817259907722473, 0.9817556738853455, 0.9819086194038391, 0.9820243120193481, 0.9820432662963867, 0.9821175932884216, 0.9826224446296692, 0.9826956391334534, 0.9827942848205566, 0.9832927584648132, 0.9832968711853027, 0.9832992553710938, 0.9835567474365234, 0.983815610408783, 0.9838497042655945, 0.9838767051696777, 0.9842270612716675, 0.9842722415924072, 0.9845542311668396, 0.9846768379211426, 0.9849614500999451, 0.9849673509597778, 0.9851817488670349, 0.9851921796798706, 0.9852206707000732, 0.985414445400238, 0.9856372475624084, 0.9860982894897461, 0.9865549802780151, 0.9866139888763428, 0.9869317412376404, 0.9869909286499023, 0.9874275922775269, 0.9876006841659546, 0.9878584742546082, 0.9880326986312866, 0.9880671501159668, 0.9881801009178162, 0.988438606262207, 0.9890051484107971, 0.9890769720077515, 0.9898939728736877, 0.9899919629096985, 0.9910080432891846, 0.9910285472869873, 0.9924318790435791, 0.9926456212997437, 0.9931173324584961, 0.9931448101997375, 0.9931731224060059, 0.9943570494651794, 0.9948227405548096, 0.994970440864563, 0.9951385855674744, 0.9953123331069946, 0.9954226016998291, 0.9960251450538635, 0.9965554475784302, 0.997191309928894, 0.9975451827049255, 0.997825026512146, 0.9978576302528381, 0.9979255199432373, 0.9980177879333496, 0.9989475607872009, 0.9991936087608337, 0.999557375907898, 0.9995854496955872, 1.0011874437332153, 1.0012599229812622, 1.0026485919952393, 1.0029579401016235, 1.0036461353302002, 1.0037078857421875, 1.0043312311172485, 1.0044771432876587, 1.0061033964157104, 1.0062646865844727, 1.0074716806411743, 1.009323000907898, 1.0093626976013184, 1.009925365447998, 1.0123310089111328, 1.012570858001709, 1.0125982761383057, 1.0146188735961914, 1.022064447402954, 1.023734450340271, 1.0273607969284058, 1.0292606353759766, 1.0340508222579956, 1.0342868566513062, 1.0392357110977173, 1.039259910583496, 1.0413792133331299]}, {"mode": "markers", "name": "H1", "type": "scatter", "x": [1.07474946975708, 1.0743520259857178, 1.0742944478988647, 1.07418692111969, 1.0741630792617798, 1.0740727186203003, 1.0739195346832275, 1.0738651752471924, 1.0736843347549438, 1.0731699466705322, 1.0729767084121704, 1.0728381872177124, 1.0727945566177368, 1.0727133750915527, 1.072620153427124, 1.071887493133545, 1.0717390775680542, 1.0716972351074219, 1.071685791015625, 1.0716259479522705, 1.0715445280075073, 1.0714293718338013, 1.0709277391433716, 1.0709043741226196, 1.070554256439209, 1.0704069137573242, 1.069767951965332, 1.0695807933807373, 1.0693589448928833, 1.0689867734909058, 1.0689647197723389, 1.0685805082321167, 1.0683419704437256, 1.0680392980575562, 1.0677707195281982, 1.0676394701004028, 1.0675233602523804, 1.067517876625061, 1.0674707889556885, 1.0669746398925781, 1.0668745040893555, 1.0668232440948486, 1.066728949546814, 1.0663158893585205, 1.0660775899887085, 1.0659140348434448, 1.065546989440918, 1.0653975009918213, 1.0645331144332886, 1.0644339323043823, 1.0643924474716187, 1.0641810894012451, 1.0640705823898315, 1.0638141632080078, 1.0637998580932617, 1.0634385347366333, 1.0632370710372925, 1.0630443096160889, 1.0628013610839844, 1.062515377998352, 1.0624607801437378, 1.0624363422393799, 1.0623538494110107, 1.061646819114685, 1.0615731477737427, 1.0612359046936035, 1.0610626935958862, 1.060958743095398, 1.0608834028244019, 1.0608720779418945, 1.0606180429458618, 1.0605920553207397, 1.0601263046264648, 1.0598664283752441, 1.0597461462020874, 1.0595992803573608, 1.0594942569732666, 1.0592418909072876, 1.0591907501220703, 1.0591535568237305, 1.0587115287780762, 1.0585817098617554, 1.0585753917694092, 1.0576579570770264, 1.0576088428497314, 1.0575965642929077, 1.0574439764022827, 1.0572673082351685, 1.0571668148040771, 1.0571575164794922, 1.0566833019256592, 1.0566593408584595, 1.0565457344055176, 1.0562140941619873, 1.0551456212997437, 1.0550236701965332, 1.0549920797348022, 1.0549349784851074, 1.0548919439315796, 1.054855465888977, 1.0546101331710815, 1.054246187210083, 1.054242730140686, 1.054073691368103, 1.053551197052002, 1.053368330001831, 1.0532666444778442, 1.0529900789260864, 1.052964687347412, 1.0529494285583496, 1.0528209209442139, 1.0527386665344238, 1.0522019863128662, 1.0518388748168945, 1.0517919063568115, 1.0517863035202026, 1.0517854690551758, 1.0516672134399414, 1.0515254735946655, 1.0512059926986694, 1.0511162281036377, 1.051096796989441, 1.0510278940200806, 1.05064058303833, 1.0502532720565796, 1.0495845079421997, 1.0495620965957642, 1.049500823020935, 1.0491583347320557, 1.0491535663604736, 1.048816204071045, 1.0486830472946167, 1.0486278533935547, 1.048384666442871, 1.0482934713363647, 1.048162817955017, 1.0480996370315552, 1.047834038734436, 1.0477250814437866, 1.0476922988891602, 1.0476555824279785, 1.04763925075531, 1.0475326776504517, 1.0474143028259277, 1.0474086999893188, 1.047402262687683, 1.0470242500305176, 1.0467790365219116, 1.0467748641967773, 1.0466679334640503, 1.046638011932373, 1.046528935432434, 1.046265959739685, 1.0461630821228027, 1.0443257093429565, 1.044305443763733, 1.0441147089004517, 1.0439329147338867, 1.0438112020492554, 1.0437575578689575, 1.04364812374115, 1.0436006784439087, 1.0435749292373657, 1.0430963039398193, 1.0430629253387451, 1.0428844690322876, 1.0424660444259644, 1.0411628484725952, 1.0406650304794312, 1.0406007766723633, 1.0403916835784912, 1.040165662765503, 1.0401028394699097, 1.0399749279022217, 1.0397225618362427, 1.039685606956482, 1.0396456718444824, 1.0396342277526855, 1.0395493507385254, 1.039050817489624, 1.0386680364608765, 1.0385353565216064, 1.0383871793746948, 1.038292646408081, 1.038067102432251, 1.037854552268982, 1.037831425666809, 1.037784218788147, 1.0371233224868774, 1.0369664430618286, 1.0366997718811035, 1.0365103483200073, 1.0360612869262695, 1.036048173904419, 1.0353074073791504, 1.0349102020263672, 1.0348660945892334, 1.0346187353134155, 1.0345076322555542, 1.0344165563583374, 1.0343316793441772, 1.0342026948928833, 1.0339539051055908, 1.0338184833526611, 1.0335348844528198, 1.0333383083343506, 1.0332417488098145, 1.0329838991165161, 1.0327520370483398, 1.0326385498046875, 1.0325781106948853, 1.0325040817260742, 1.0322344303131104, 1.0319644212722778, 1.0317938327789307, 1.0317105054855347, 1.0316892862319946, 1.0310232639312744, 1.03066885471344, 1.0304911136627197, 1.0297744274139404, 1.0296696424484253, 1.0296460390090942, 1.0296406745910645, 1.0291253328323364, 1.0291123390197754, 1.0291080474853516, 1.0290343761444092, 1.0286110639572144, 1.0282057523727417, 1.0281976461410522, 1.027821660041809, 1.0276154279708862, 1.0274097919464111, 1.027397632598877, 1.0272927284240723, 1.0271552801132202, 1.0271536111831665, 1.0270599126815796, 1.0269966125488281, 1.0269627571105957, 1.0267904996871948, 1.0267695188522339, 1.0266337394714355, 1.0264813899993896, 1.0263605117797852, 1.0262662172317505, 1.0258742570877075, 1.0257400274276733, 1.0254690647125244, 1.0251835584640503, 1.025083303451538, 1.0248870849609375, 1.0241994857788086, 1.0241204500198364, 1.0239518880844116, 1.0238430500030518, 1.0236743688583374, 1.0234516859054565, 1.0231252908706665, 1.0231045484542847, 1.022905707359314, 1.0228761434555054, 1.0219874382019043, 1.0218220949172974, 1.021687626838684, 1.0212322473526, 1.0209707021713257, 1.0197826623916626, 1.0196808576583862, 1.0192129611968994, 1.0191134214401245, 1.0187839269638062, 1.018649697303772, 1.0184683799743652, 1.018069863319397, 1.0178061723709106, 1.0177501440048218, 1.0170685052871704, 1.0169451236724854, 1.0169001817703247, 1.0157833099365234, 1.015763521194458, 1.015708088874817, 1.0152523517608643, 1.014817714691162, 1.0145716667175293, 1.0144946575164795, 1.0143426656723022, 1.014278769493103, 1.014247179031372, 1.0141384601593018, 1.0138403177261353, 1.013762354850769, 1.013616919517517, 1.01325523853302, 1.0131428241729736, 1.0129623413085938, 1.0128850936889648, 1.012752890586853, 1.0126906633377075, 1.0125795602798462, 1.012433409690857, 1.012404203414917, 1.012313723564148, 1.0121012926101685, 1.0113240480422974, 1.0113160610198975, 1.0113122463226318, 1.0111380815505981, 1.0109913349151611, 1.0109268426895142, 1.0106664896011353, 1.0104615688323975, 1.0100957155227661, 1.0096944570541382, 1.0092684030532837, 1.0090665817260742, 1.0090352296829224, 1.0089085102081299, 1.0088880062103271, 1.0087521076202393, 1.0086079835891724, 1.0083587169647217, 1.0075405836105347, 1.007048487663269, 1.0069727897644043, 1.0068864822387695, 1.0057817697525024, 1.0055066347122192, 1.0052177906036377, 1.0050737857818604, 1.0050065517425537, 1.0044947862625122, 1.0038845539093018, 1.0037307739257812, 1.0035494565963745, 1.0034475326538086, 1.0033682584762573, 1.0029659271240234, 1.0026873350143433, 1.0025264024734497, 1.0023367404937744, 1.0017807483673096, 1.0012445449829102, 1.001070261001587, 1.0004247426986694, 1.0000498294830322, 0.9998618364334106, 0.999843180179596, 0.9997649788856506, 0.9986063241958618, 0.9985647797584534, 0.9984813928604126, 0.9983765482902527, 0.9977071285247803, 0.997562825679779, 0.9974966049194336, 0.9974425435066223, 0.997148334980011, 0.9968286752700806, 0.996508777141571, 0.9964954853057861, 0.9963626265525818, 0.9958983063697815, 0.9952821135520935, 0.9952208995819092, 0.9951997399330139, 0.9950382709503174, 0.9943155646324158, 0.9942212700843811, 0.9941562414169312, 0.9938697814941406, 0.9938693046569824, 0.9937193393707275, 0.9934358596801758, 0.9930518269538879, 0.9928587079048157, 0.9923936724662781, 0.9914880394935608, 0.9905583262443542, 0.9900270104408264, 0.9898229837417603, 0.9893973469734192, 0.9889914393424988, 0.9888108372688293, 0.9848917126655579, 0.9843487739562988, 0.983198881149292, 0.9828668236732483, 0.9802038073539734, 0.9791017174720764, 0.9776406288146973, 0.9772308468818665, 0.9696455001831055, 0.9680193066596985, 0.9672315120697021, 0.9660635590553284, 0.9658425450325012], "y": [1.873095989227295, 1.8858407735824585, 1.9505720138549805, 1.9212207794189453, 1.884361743927002, 1.899468183517456, 1.9451764822006226, 1.9155750274658203, 1.9822969436645508, 1.8907068967819214, 1.9376517534255981, 1.9514453411102295, 1.9538259506225586, 2.0048820972442627, 1.9802007675170898, 1.9362475872039795, 1.9247560501098633, 2.026724338531494, 1.9001641273498535, 1.9861713647842407, 1.979088306427002, 1.9664404392242432, 1.9238282442092896, 1.8886082172393799, 1.9887791872024536, 1.9533863067626953, 1.9702121019363403, 1.9658632278442383, 1.9706496000289917, 1.9594104290008545, 1.9258389472961426, 1.9763973951339722, 1.9272507429122925, 2.0250589847564697, 1.95413076877594, 1.875773549079895, 1.9292322397232056, 1.9373524188995361, 1.872501015663147, 1.9005309343338013, 1.8691099882125854, 1.893579363822937, 1.9453847408294678, 1.961409091949463, 1.948298454284668, 1.9099419116973877, 1.8666424751281738, 2.0135133266448975, 1.896366000175476, 1.9721286296844482, 1.986812949180603, 1.9647421836853027, 1.9573637247085571, 1.9748730659484863, 1.929418921470642, 1.91560959815979, 1.9276143312454224, 1.9909862279891968, 1.9137473106384277, 1.9235440492630005, 1.9673041105270386, 1.8811676502227783, 1.8887898921966553, 1.9589204788208008, 1.9800336360931396, 2.014709234237671, 1.9291187524795532, 1.990061640739441, 2.022153377532959, 1.9312585592269897, 1.9676839113235474, 2.0003771781921387, 1.9124412536621094, 1.8982257843017578, 1.9103951454162598, 1.9761464595794678, 1.9557957649230957, 1.8838868141174316, 1.9690126180648804, 1.961093783378601, 1.940598487854004, 1.9079999923706055, 1.9917421340942383, 1.9659039974212646, 1.898382544517517, 1.9431043863296509, 1.9008440971374512, 1.8810539245605469, 1.9955281019210815, 1.9338456392288208, 1.9553375244140625, 1.898741364479065, 1.8686925172805786, 1.954028606414795, 1.9533833265304565, 1.867956519126892, 1.9825968742370605, 2.003126621246338, 1.958271861076355, 2.0025434494018555, 1.8629481792449951, 1.8765227794647217, 1.9706895351409912, 1.9353554248809814, 1.8681811094284058, 2.000903844833374, 1.9813145399093628, 1.9423521757125854, 1.9759275913238525, 1.880506157875061, 1.9029206037521362, 1.9243367910385132, 1.9656925201416016, 1.9152802228927612, 1.9055601358413696, 1.8943712711334229, 1.9256339073181152, 1.9702492952346802, 1.936092734336853, 1.968942403793335, 1.8913038969039917, 1.9231852293014526, 1.8826767206192017, 1.981383204460144, 1.919814109802246, 2.0259323120117188, 1.9997224807739258, 2.0074408054351807, 1.9787241220474243, 1.8691519498825073, 1.9858261346817017, 1.9644029140472412, 1.943538784980774, 1.974622130393982, 1.9536811113357544, 1.9727543592453003, 1.9557198286056519, 1.892917275428772, 1.928719162940979, 2.0634710788726807, 1.9405475854873657, 2.024719476699829, 1.8699171543121338, 1.9810667037963867, 2.002314567565918, 1.9336086511611938, 1.9369854927062988, 1.9572075605392456, 2.0048186779022217, 1.9992698431015015, 1.9128098487854004, 1.978078842163086, 1.9504809379577637, 2.022516965866089, 1.9048365354537964, 1.9466866254806519, 1.970287799835205, 1.9356883764266968, 1.9254158735275269, 1.9122799634933472, 1.967221975326538, 1.9714804887771606, 1.9254435300827026, 1.9245165586471558, 1.980629563331604, 1.8976994752883911, 1.9281120300292969, 1.9675437211990356, 2.015148878097534, 1.9441529512405396, 1.913649559020996, 1.8992056846618652, 1.9036263227462769, 1.9642932415008545, 1.8982524871826172, 2.078921318054199, 1.8877737522125244, 1.9772239923477173, 1.9297751188278198, 1.8808624744415283, 2.038511276245117, 1.9162787199020386, 1.970207691192627, 1.959850549697876, 1.8905943632125854, 1.8928643465042114, 2.002530813217163, 1.9535179138183594, 2.0186688899993896, 2.022930383682251, 2.057889699935913, 1.8933202028274536, 2.0338099002838135, 1.8792773485183716, 1.9286705255508423, 1.9784032106399536, 2.000715494155884, 2.000192880630493, 1.9705671072006226, 1.9505562782287598, 1.915898084640503, 1.9908406734466553, 1.969385027885437, 1.9674434661865234, 1.9180225133895874, 2.00581955909729, 1.9555927515029907, 1.9305429458618164, 1.882704734802246, 1.9216957092285156, 1.9001861810684204, 1.9777175188064575, 1.9918538331985474, 2.0113048553466797, 1.9221293926239014, 1.9328880310058594, 2.0135715007781982, 1.8824816942214966, 1.961579442024231, 2.0178136825561523, 1.9628881216049194, 1.8863242864608765, 2.031736373901367, 1.9582104682922363, 1.873754620552063, 1.992866039276123, 1.9993101358413696, 1.87875235080719, 1.8956419229507446, 1.8883302211761475, 1.9179508686065674, 2.0404164791107178, 1.8686894178390503, 1.8871197700500488, 2.0125205516815186, 1.9788336753845215, 1.9252207279205322, 1.9985020160675049, 1.9758902788162231, 1.9140186309814453, 1.8967630863189697, 1.9376405477523804, 1.90443754196167, 1.9502358436584473, 2.004187822341919, 1.92716383934021, 1.9507884979248047, 1.9788926839828491, 1.868363380432129, 1.962143898010254, 2.0084762573242188, 1.951996922492981, 1.9499573707580566, 1.955947756767273, 1.9887127876281738, 2.0024049282073975, 1.9517287015914917, 1.9602770805358887, 1.9552676677703857, 2.033323287963867, 1.8826335668563843, 1.992663860321045, 1.985551118850708, 2.0429012775421143, 1.9254707098007202, 1.9341368675231934, 1.9776902198791504, 2.0062499046325684, 1.9407061338424683, 1.987657070159912, 1.8833224773406982, 1.9697225093841553, 1.9463181495666504, 1.9225271940231323, 2.036886215209961, 1.9615339040756226, 1.9424740076065063, 1.9589204788208008, 1.9839333295822144, 1.89439857006073, 2.0119805335998535, 1.995682716369629, 1.9518625736236572, 1.924223780632019, 1.8949302434921265, 1.9272098541259766, 2.010455846786499, 1.997611165046692, 1.940940260887146, 2.0154263973236084, 2.0122275352478027, 2.0226261615753174, 1.954601764678955, 2.000544786453247, 2.0381500720977783, 1.9602304697036743, 1.9140371084213257, 1.9257322549819946, 1.8955849409103394, 1.9274777173995972, 1.9053157567977905, 1.8916879892349243, 2.0075719356536865, 1.9352033138275146, 2.0055007934570312, 1.9573534727096558, 1.9124566316604614, 1.908324122428894, 1.9417788982391357, 2.026818037033081, 1.9005190134048462, 1.898514986038208, 2.032611846923828, 1.9512077569961548, 2.0228288173675537, 1.9905387163162231, 2.00895357131958, 1.900393009185791, 1.897786021232605, 1.9778274297714233, 1.9605889320373535, 1.986722707748413, 1.943239688873291, 1.9881051778793335, 1.8871252536773682, 1.9373416900634766, 1.9120073318481445, 1.8951512575149536, 1.9444341659545898, 1.9261122941970825, 1.9340711832046509, 1.9508017301559448, 1.9862489700317383, 2.0515289306640625, 1.9925546646118164, 1.9108926057815552, 1.971807599067688, 1.8754435777664185, 1.872225284576416, 2.0135583877563477, 2.046193838119507, 2.000446081161499, 1.936527132987976, 1.9546133279800415, 1.8694264888763428, 1.9643239974975586, 1.9453542232513428, 1.9702519178390503, 1.9740561246871948, 1.924871802330017, 1.933241367340088, 1.8809632062911987, 1.911138892173767, 2.06796932220459, 2.0679872035980225, 1.963945746421814, 1.9004470109939575, 1.908035159111023, 1.942431926727295, 2.033792495727539, 6.960941791534424, 1.9306761026382446, 1.8693751096725464, 1.967635989189148, 1.9112598896026611, 1.9429619312286377, 2.0376315116882324, 1.9448988437652588, 1.9231270551681519, 1.964928388595581, 1.9161560535430908, 1.8918051719665527, 1.9993983507156372, 1.9175959825515747, 1.988034963607788, 2.0366365909576416, 1.9253625869750977, 1.9364176988601685, 1.913504719734192, 1.9405149221420288, 1.8715490102767944, 1.8803460597991943, 1.9123451709747314, 1.9193981885910034, 1.868457555770874, 1.8944261074066162, 1.892479419708252, 1.9096407890319824, 1.897192120552063, 1.908068060874939, 1.9252852201461792, 1.9145925045013428, 1.861634373664856, 1.916792631149292, 1.8841023445129395, 1.8677070140838623, 1.9027990102767944, 1.8765294551849365, 1.9149872064590454]}, {"mode": "markers", "name": "H2", "type": "scatter", "x": [9.614521026611328, 9.594133377075195, 9.590237617492676, 8.764337539672852, 8.71752643585205, 8.716790199279785, 8.705378532409668, 8.631973266601562, 8.591052055358887, 8.588293075561523, 8.584047317504883, 8.580496788024902, 7.861270904541016, 7.78767728805542, 7.777928352355957, 7.746187686920166, 7.74506950378418, 7.72268533706665, 7.713561058044434, 7.128468036651611, 7.089542388916016, 7.0883917808532715, 7.077342510223389, 7.073318958282471, 7.060422420501709, 7.056602478027344, 7.041701316833496, 7.039015769958496, 7.035704612731934, 7.015712738037109, 7.0099310874938965, 7.004547595977783, 7.001699447631836, 6.975990295410156, 2.0953316688537598, 2.030503034591675], "y": [9.665863990783691, 9.628997802734375, 9.618935585021973, 8.768304824829102, 8.722441673278809, 8.747923851013184, 8.715746879577637, 8.632695198059082, 8.604727745056152, 8.617874145507812, 8.610365867614746, 8.637130737304688, 7.8873419761657715, 7.8534088134765625, 7.796899318695068, 7.785425186157227, 7.775380611419678, 7.784049987792969, 7.723777770996094, 7.132621765136719, 7.109415054321289, 7.1058878898620605, 7.176892280578613, 7.1609320640563965, 7.160402297973633, 7.081233501434326, 7.12144136428833, 7.123939037322998, 7.1515889167785645, 7.194880962371826, 7.111262798309326, 7.181010723114014, 7.133271217346191, 8.913239479064941, 9.04585075378418, 2.04706072807312]}],
                            {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 10.632450389862061], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 10.632450389862061], "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('e5da9583-2463-466b-813d-b4b7b7e98785');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Plotting the persistence diagram of the Klein bottle
    plot_diagram(diagrams[1])



.. raw:: html

    <div>
    
    
                <div id="9a1f0c9d-3ad7-4473-aec0-801aac5dc2ba" class="plotly-graph-div" style="height:500px; width:500px;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("9a1f0c9d-3ad7-4473-aec0-801aac5dc2ba")) {
                        Plotly.newPlot(
                            '9a1f0c9d-3ad7-4473-aec0-801aac5dc2ba',
                            [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-1032.856845855713, 1032.856845855713], "y": [-1032.856845855713, 1032.856845855713]}, {"mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [0.9252004623413086, 0.9252486228942871, 0.9253501296043396, 0.9254857897758484, 0.9257699847221375, 0.9262692928314209, 0.9266083240509033, 0.9269654154777527, 0.9272029399871826, 0.9285691976547241, 0.9286000728607178, 0.9286943078041077, 0.9296138286590576, 0.9296330213546753, 0.9300917387008667, 0.9304805397987366, 0.9306281208992004, 0.930690586566925, 0.9307547807693481, 0.9311479926109314, 0.9311583638191223, 0.9312973022460938, 0.9315612316131592, 0.931857705116272, 0.9319543242454529, 0.9320943355560303, 0.932184100151062, 0.932462215423584, 0.9326916933059692, 0.9327961206436157, 0.9328340291976929, 0.9329856038093567, 0.9331755638122559, 0.9332135319709778, 0.9332722425460815, 0.9335528612136841, 0.9335923194885254, 0.9336479306221008, 0.9339362382888794, 0.9341400861740112, 0.9345586895942688, 0.9345899820327759, 0.9346198439598083, 0.9351025223731995, 0.9351534247398376, 0.9351956844329834, 0.9352257251739502, 0.9353955388069153, 0.9354062080383301, 0.9354668259620667, 0.9355288743972778, 0.9357800483703613, 0.9358209371566772, 0.9360938668251038, 0.9361380338668823, 0.9362078905105591, 0.9365652203559875, 0.9369151592254639, 0.9371660947799683, 0.9373315572738647, 0.937440037727356, 0.937499463558197, 0.9375078678131104, 0.9375267624855042, 0.9375954270362854, 0.9376070499420166, 0.9376522302627563, 0.9377394318580627, 0.9377665519714355, 0.9378172159194946, 0.9379006028175354, 0.937907338142395, 0.9381296038627625, 0.9384824633598328, 0.9385954141616821, 0.9387980103492737, 0.9394569396972656, 0.9397191405296326, 0.9398931860923767, 0.9400177001953125, 0.940398097038269, 0.9404483437538147, 0.9405900835990906, 0.9405911564826965, 0.9412274956703186, 0.9417394399642944, 0.9418159127235413, 0.9418984651565552, 0.9420934915542603, 0.9422829151153564, 0.9424894452095032, 0.942664623260498, 0.9426935911178589, 0.9427359104156494, 0.9429739713668823, 0.9431723952293396, 0.9434307217597961, 0.9434985518455505, 0.94374680519104, 0.9438106417655945, 0.9439610242843628, 0.9443061351776123, 0.9444567561149597, 0.9445831775665283, 0.9450232982635498, 0.9450840950012207, 0.9452215433120728, 0.9456446170806885, 0.9458492398262024, 0.9460939764976501, 0.9460970759391785, 0.9461129903793335, 0.9461789131164551, 0.9465087652206421, 0.9468733072280884, 0.9469264149665833, 0.9469693899154663, 0.9470425248146057, 0.9473245739936829, 0.9474014043807983, 0.9476106762886047, 0.94792240858078, 0.9479280114173889, 0.9485840201377869, 0.9486673474311829, 0.9493064284324646, 0.9495415091514587, 0.9496009349822998, 0.9496445059776306, 0.9498111605644226, 0.9498914480209351, 0.950042724609375, 0.9501617550849915, 0.9511674642562866, 0.951660692691803, 0.9516942501068115, 0.9518523812294006, 0.9519372582435608, 0.9521650075912476, 0.9525429606437683, 0.9526994824409485, 0.952755331993103, 0.9528289437294006, 0.9529498815536499, 0.9529544115066528, 0.9533175826072693, 0.9535663723945618, 0.9535673260688782, 0.9536087512969971, 0.9536662101745605, 0.9537424445152283, 0.9538129568099976, 0.9541052579879761, 0.9544033408164978, 0.9544212222099304, 0.9545730948448181, 0.9549168944358826, 0.9550237059593201, 0.955124020576477, 0.9552059769630432, 0.9554862976074219, 0.9555200934410095, 0.9556784629821777, 0.9556905031204224, 0.9557285308837891, 0.9559386372566223, 0.9561721682548523, 0.956301212310791, 0.9565995335578918, 0.9568303823471069, 0.9569542407989502, 0.9572983384132385, 0.9574365615844727, 0.957528829574585, 0.9575990438461304, 0.9579328298568726, 0.9580333828926086, 0.9581560492515564, 0.9581669569015503, 0.9582984447479248, 0.9586214423179626, 0.9587809443473816, 0.9589115381240845, 0.9590420126914978, 0.9594452977180481, 0.9596632719039917, 0.9596827626228333, 0.9597035646438599, 0.9597921371459961, 0.9601927399635315, 0.9605522155761719, 0.9608034491539001, 0.9611626267433167, 0.9611760377883911, 0.9612297415733337, 0.9614090919494629, 0.9614652395248413, 0.961584210395813, 0.9617916345596313, 0.9621052742004395, 0.9622419476509094, 0.9623291492462158, 0.9625106453895569, 0.9628252387046814, 0.9629603624343872, 0.9630230665206909, 0.9630239009857178, 0.963062047958374, 0.9634556174278259, 0.9635294675827026, 0.9636310338973999, 0.9639323353767395, 0.9639426469802856, 0.9640148878097534, 0.9641183018684387, 0.964189350605011, 0.964206874370575, 0.9642103910446167, 0.9646726250648499, 0.9647030234336853, 0.9649860858917236, 0.9656851887702942, 0.9656978249549866, 0.965781033039093, 0.9661391973495483, 0.9666314125061035, 0.9666447639465332, 0.9669048190116882, 0.9672024846076965, 0.9672062993049622, 0.9672525525093079, 0.9674226641654968, 0.9675914645195007, 0.9677392840385437, 0.9678425788879395, 0.9692000150680542, 0.9692556262016296, 0.9694101214408875, 0.969495415687561, 0.969801664352417, 0.969826340675354, 0.969955563545227, 0.9702466130256653, 0.9702498316764832, 0.970278263092041, 0.9703243970870972, 0.9710358381271362, 0.9713578820228577, 0.9714112281799316, 0.9718387722969055, 0.9720818996429443, 0.9723996520042419, 0.9727738499641418, 0.9729128479957581, 0.9729998707771301, 0.9736538529396057, 0.9741055965423584, 0.9741724729537964, 0.9741902351379395, 0.9747739434242249, 0.974928617477417, 0.9751758575439453, 0.9753835201263428, 0.9754242897033691, 0.9755855202674866, 0.975972592830658, 0.9762722253799438, 0.9768184423446655, 0.976828396320343, 0.9769192337989807, 0.9772132039070129, 0.9772369265556335, 0.977304220199585, 0.9776673316955566, 0.977694034576416, 0.9780999422073364, 0.9781728386878967, 0.9784572124481201, 0.9787850379943848, 0.9791597723960876, 0.979227602481842, 0.9793131351470947, 0.9796176552772522, 0.9796862602233887, 0.9796942472457886, 0.9801889657974243, 0.9808379411697388, 0.9812764525413513, 0.9816760420799255, 0.9819453954696655, 0.9820139408111572, 0.9820430874824524, 0.982062578201294, 0.9823128581047058, 0.9824314713478088, 0.9826503396034241, 0.9828490614891052, 0.9830271005630493, 0.9833911061286926, 0.9834193587303162, 0.9836195111274719, 0.983786940574646, 0.983993649482727, 0.9840066432952881, 0.9842166900634766, 0.9842751026153564, 0.984531581401825, 0.9850216507911682, 0.9854626655578613, 0.9855601191520691, 0.9856518507003784, 0.985931396484375, 0.9860317707061768, 0.9861443638801575, 0.9862884879112244, 0.9863471388816833, 0.9864060878753662, 0.9866192936897278, 0.9866600632667542, 0.9867470264434814, 0.986854076385498, 0.9875538945198059, 0.987565815448761, 0.9875787496566772, 0.987919270992279, 0.9880428314208984, 0.9883384704589844, 0.9890422821044922, 0.9890516400337219, 0.9892034530639648, 0.9897497892379761, 0.9906675815582275, 0.9909204840660095, 0.991150975227356, 0.9912562966346741, 0.9913535118103027, 0.991407036781311, 0.9915574193000793, 0.9917218685150146, 0.9917901158332825, 0.9919431209564209, 0.9921537041664124, 0.9921955466270447, 0.9927400350570679, 0.9929826855659485, 0.9930205345153809, 0.9933326244354248, 0.9936248660087585, 0.993742823600769, 0.9947360157966614, 0.9947753548622131, 0.9948329925537109, 0.9949607849121094, 0.9954831004142761, 0.9961862564086914, 0.997667133808136, 0.9978653788566589, 0.9982454776763916, 0.9982916116714478, 0.9984695911407471, 0.9989565014839172, 0.9990257620811462, 0.9990847706794739, 0.9992753863334656, 0.9995095133781433, 1.0003682374954224, 1.0013595819473267, 1.002224087715149, 1.0037869215011597, 1.0040082931518555, 1.0057308673858643, 1.0059260129928589, 1.0063468217849731, 1.0078139305114746, 1.0078167915344238, 1.008052945137024, 1.0095634460449219, 1.0105414390563965, 1.0116795301437378, 1.0119739770889282, 1.0135518312454224, 1.0145221948623657, 1.0150028467178345, 1.0150467157363892, 1.0152567625045776, 1.018703579902649, 1.0188037157058716, 1.0190190076828003, 1.0220435857772827, 1.02358078956604, 1.0248243808746338, 1.029457926750183, 1.029502511024475, 1.0338993072509766, 1.034814715385437, 1.0351191759109497, 1.0406674146652222, 1.0443545579910278, 1.054333209991455]}, {"mode": "markers", "name": "H1", "type": "scatter", "x": [1.0749733448028564, 1.0747519731521606, 1.0747448205947876, 1.0745850801467896, 1.074272871017456, 1.0741732120513916, 1.0741312503814697, 1.073972225189209, 1.073500156402588, 1.073464274406433, 1.0734103918075562, 1.0733765363693237, 1.0732903480529785, 1.0731607675552368, 1.0729339122772217, 1.0727736949920654, 1.0724525451660156, 1.0724148750305176, 1.0724068880081177, 1.0721136331558228, 1.071804165840149, 1.0717779397964478, 1.0714640617370605, 1.0714532136917114, 1.0713951587677002, 1.0711419582366943, 1.0711019039154053, 1.0708096027374268, 1.0706144571304321, 1.0705304145812988, 1.0704169273376465, 1.0701289176940918, 1.0697044134140015, 1.0695456266403198, 1.0694915056228638, 1.0694901943206787, 1.0691767930984497, 1.0689083337783813, 1.0687564611434937, 1.0687373876571655, 1.0686818361282349, 1.0686802864074707, 1.0681601762771606, 1.067702293395996, 1.0676977634429932, 1.0673420429229736, 1.06731379032135, 1.0671550035476685, 1.0668835639953613, 1.0668443441390991, 1.0668386220932007, 1.0667637586593628, 1.066734790802002, 1.0663299560546875, 1.066227674484253, 1.0660817623138428, 1.065573811531067, 1.0655672550201416, 1.0654641389846802, 1.06545090675354, 1.0652462244033813, 1.0651274919509888, 1.0650222301483154, 1.0649677515029907, 1.0648841857910156, 1.0644826889038086, 1.0644092559814453, 1.064228892326355, 1.064007043838501, 1.0637283325195312, 1.063696265220642, 1.0635643005371094, 1.0634183883666992, 1.0634088516235352, 1.0628477334976196, 1.062416434288025, 1.0624159574508667, 1.062168836593628, 1.0619392395019531, 1.0613504648208618, 1.061025857925415, 1.0607924461364746, 1.0606725215911865, 1.0598798990249634, 1.059792399406433, 1.059632658958435, 1.0596022605895996, 1.059330701828003, 1.059148907661438, 1.0585418939590454, 1.0585378408432007, 1.058136224746704, 1.0580240488052368, 1.0579721927642822, 1.0578837394714355, 1.057682991027832, 1.0574359893798828, 1.05741286277771, 1.057267665863037, 1.0569506883621216, 1.0568629503250122, 1.05657160282135, 1.056272029876709, 1.0562026500701904, 1.0559942722320557, 1.0556666851043701, 1.0556542873382568, 1.0548694133758545, 1.0541702508926392, 1.0541086196899414, 1.0536842346191406, 1.0534816980361938, 1.0534666776657104, 1.053194522857666, 1.052863597869873, 1.0525845289230347, 1.051947832107544, 1.0519404411315918, 1.051771879196167, 1.0517207384109497, 1.0516889095306396, 1.0516424179077148, 1.0514496564865112, 1.0509777069091797, 1.0509756803512573, 1.0507988929748535, 1.0506702661514282, 1.0505560636520386, 1.0504319667816162, 1.0499824285507202, 1.0499788522720337, 1.0499730110168457, 1.0495736598968506, 1.0495047569274902, 1.0492650270462036, 1.0492537021636963, 1.049247145652771, 1.049222469329834, 1.0492137670516968, 1.0491784811019897, 1.0491251945495605, 1.0485886335372925, 1.048573613166809, 1.0485472679138184, 1.0481141805648804, 1.0480608940124512, 1.0476329326629639, 1.047424554824829, 1.0474210977554321, 1.0471872091293335, 1.0468602180480957, 1.0466983318328857, 1.0466628074645996, 1.04665207862854, 1.0464986562728882, 1.0463988780975342, 1.0459553003311157, 1.0459414720535278, 1.045873999595642, 1.045837640762329, 1.0458091497421265, 1.0453253984451294, 1.045310616493225, 1.0451085567474365, 1.0449814796447754, 1.0446144342422485, 1.0436031818389893, 1.0435099601745605, 1.042726755142212, 1.0427110195159912, 1.042418360710144, 1.0423880815505981, 1.0422413349151611, 1.0421987771987915, 1.042162537574768, 1.0420897006988525, 1.042017936706543, 1.0419121980667114, 1.041852593421936, 1.0414482355117798, 1.0413711071014404, 1.0413215160369873, 1.0409938097000122, 1.0407451391220093, 1.0407066345214844, 1.0404460430145264, 1.040259838104248, 1.0398117303848267, 1.0397261381149292, 1.0396827459335327, 1.0395475625991821, 1.039537787437439, 1.0388731956481934, 1.0387240648269653, 1.038521409034729, 1.0385009050369263, 1.0384081602096558, 1.0383219718933105, 1.0381749868392944, 1.0381362438201904, 1.0379976034164429, 1.0379135608673096, 1.0377185344696045, 1.0375231504440308, 1.0371663570404053, 1.0371530055999756, 1.0369689464569092, 1.0369195938110352, 1.0366761684417725, 1.0360467433929443, 1.0358901023864746, 1.0358293056488037, 1.0354509353637695, 1.0348314046859741, 1.034312129020691, 1.0339943170547485, 1.0337605476379395, 1.0335813760757446, 1.0333151817321777, 1.0332778692245483, 1.033218264579773, 1.033150315284729, 1.0329937934875488, 1.0327595472335815, 1.0324909687042236, 1.0322625637054443, 1.032212495803833, 1.031891107559204, 1.0318028926849365, 1.031684160232544, 1.031499981880188, 1.0314655303955078, 1.0313878059387207, 1.0312564373016357, 1.0311930179595947, 1.030806303024292, 1.0306549072265625, 1.0303616523742676, 1.030307412147522, 1.0302702188491821, 1.0297698974609375, 1.0297062397003174, 1.0289788246154785, 1.028904676437378, 1.0288938283920288, 1.0287752151489258, 1.0284082889556885, 1.0279566049575806, 1.0279252529144287, 1.0277529954910278, 1.027343988418579, 1.0271419286727905, 1.0269858837127686, 1.0267411470413208, 1.0266361236572266, 1.0264755487442017, 1.0264461040496826, 1.0259050130844116, 1.0256723165512085, 1.0256577730178833, 1.0255005359649658, 1.0253485441207886, 1.0253026485443115, 1.025255560874939, 1.0252315998077393, 1.0249539613723755, 1.0248881578445435, 1.0240931510925293, 1.0240707397460938, 1.0239182710647583, 1.0237770080566406, 1.0237714052200317, 1.0237458944320679, 1.0236016511917114, 1.0233569145202637, 1.0233567953109741, 1.0228337049484253, 1.0221182107925415, 1.0216444730758667, 1.0215599536895752, 1.021116018295288, 1.0207637548446655, 1.0207570791244507, 1.0207277536392212, 1.0205122232437134, 1.0200903415679932, 1.0199849605560303, 1.0196365118026733, 1.0195372104644775, 1.0192309617996216, 1.019144892692566, 1.018945336341858, 1.0180402994155884, 1.0177212953567505, 1.0166476964950562, 1.0164752006530762, 1.0162525177001953, 1.0160953998565674, 1.0160833597183228, 1.0159897804260254, 1.0159804821014404, 1.0157105922698975, 1.0156018733978271, 1.0153013467788696, 1.0143095254898071, 1.0142818689346313, 1.0137405395507812, 1.0136889219284058, 1.0134215354919434, 1.013336181640625, 1.012925386428833, 1.0127220153808594, 1.0124908685684204, 1.0123933553695679, 1.0123636722564697, 1.0121920108795166, 1.0117961168289185, 1.011648178100586, 1.0115758180618286, 1.0110619068145752, 1.0108211040496826, 1.010218620300293, 1.0100526809692383, 1.009649634361267, 1.0095571279525757, 1.009103775024414, 1.0084972381591797, 1.0083563327789307, 1.0083452463150024, 1.0077863931655884, 1.007700800895691, 1.0076265335083008, 1.007506251335144, 1.007200837135315, 1.006492018699646, 1.0063729286193848, 1.0063698291778564, 1.0057852268218994, 1.0053539276123047, 1.0048636198043823, 1.0046982765197754, 1.0046485662460327, 1.0046342611312866, 1.002616047859192, 1.0024136304855347, 1.0016205310821533, 1.0014159679412842, 1.0008082389831543, 1.0006557703018188, 1.0005367994308472, 1.0005141496658325, 1.0004494190216064, 0.9998403787612915, 0.9997584223747253, 0.9991266131401062, 0.999013364315033, 0.9985969066619873, 0.9982027411460876, 0.997536301612854, 0.9962942004203796, 0.9961308240890503, 0.9956459999084473, 0.9955483078956604, 0.9941781163215637, 0.9940981864929199, 0.9933423399925232, 0.9932020902633667, 0.9930707216262817, 0.9929680824279785, 0.9920998215675354, 0.9920434951782227, 0.9913827180862427, 0.9912360906600952, 0.991010844707489, 0.9908631443977356, 0.9907810688018799, 0.9899929165840149, 0.9893314838409424, 0.9887019991874695, 0.9884501099586487, 0.9856498837471008, 0.9845474362373352, 0.9828510284423828, 0.9826213717460632, 0.9813297390937805, 0.9809728860855103, 0.9805811047554016, 0.9802134037017822, 0.9800164103507996, 0.9794083833694458, 0.9787096381187439, 0.9784642457962036, 0.977128803730011, 0.9760358929634094, 0.9747933745384216, 0.9729233980178833, 0.9701024293899536, 0.9690578579902649, 0.9654606580734253, 0.9626991152763367, 0.9590016603469849], "y": [1.9277650117874146, 1.8958234786987305, 1.8773654699325562, 1.883461833000183, 1.9662730693817139, 1.91841459274292, 1.9352813959121704, 1.9905799627304077, 1.8855513334274292, 1.8770792484283447, 1.9410513639450073, 2.0025460720062256, 1.9677488803863525, 1.9248653650283813, 1.9005650281906128, 1.8890602588653564, 1.9503175020217896, 1.9402273893356323, 1.9785102605819702, 1.955938696861267, 1.9297518730163574, 1.9661568403244019, 1.881914734840393, 1.9771578311920166, 1.9391025304794312, 1.9915196895599365, 1.8672401905059814, 1.9240573644638062, 1.9576274156570435, 1.9757912158966064, 1.9898525476455688, 1.9747225046157837, 2.04496693611145, 1.9047348499298096, 2.011549949645996, 1.963146686553955, 2.0014567375183105, 1.9096053838729858, 1.937656283378601, 1.9353104829788208, 1.8650805950164795, 1.9958703517913818, 1.9545248746871948, 1.9162003993988037, 1.9305025339126587, 1.9122573137283325, 1.915971040725708, 1.9646339416503906, 1.9389762878417969, 1.9433603286743164, 1.923670768737793, 1.9917720556259155, 1.9319424629211426, 2.0015597343444824, 1.9401472806930542, 1.9779319763183594, 1.8980011940002441, 1.906225562095642, 1.935841679573059, 1.9602572917938232, 1.922175645828247, 1.9438562393188477, 1.9075666666030884, 1.8738601207733154, 1.88292396068573, 1.8875616788864136, 1.929931640625, 1.944257140159607, 2.01710844039917, 1.8911519050598145, 2.0028305053710938, 1.9387617111206055, 1.884692907333374, 2.0005781650543213, 2.0447449684143066, 1.8679845333099365, 1.9367340803146362, 1.963740348815918, 1.9991130828857422, 1.965846300125122, 1.9541751146316528, 1.9777663946151733, 1.899160623550415, 1.923647165298462, 1.9267715215682983, 1.951419472694397, 1.9587080478668213, 1.9518085718154907, 2.004347085952759, 1.987101435661316, 1.9001902341842651, 1.9708094596862793, 2.0002784729003906, 2.025367259979248, 1.9449057579040527, 2.0059893131256104, 1.9305357933044434, 2.029693603515625, 1.9088441133499146, 1.9375019073486328, 1.8808363676071167, 2.018706798553467, 2.0256009101867676, 1.8951250314712524, 1.9321554899215698, 1.9532020092010498, 1.9310723543167114, 1.8917958736419678, 1.9015374183654785, 1.8751189708709717, 1.9069101810455322, 1.979171872138977, 1.875551462173462, 1.94047212600708, 2.071497678756714, 1.88119637966156, 1.9243619441986084, 1.9068459272384644, 1.9803719520568848, 1.8896114826202393, 1.947082281112671, 1.9372320175170898, 1.8751498460769653, 1.9576911926269531, 2.0292818546295166, 1.9295501708984375, 1.952591061592102, 1.9144483804702759, 2.0152597427368164, 1.9358460903167725, 1.9329116344451904, 1.9801950454711914, 1.9348164796829224, 1.861675500869751, 1.8868954181671143, 1.9449505805969238, 1.9119491577148438, 1.9452506303787231, 1.9410561323165894, 1.9447243213653564, 1.9123218059539795, 1.8883763551712036, 1.929235816001892, 1.9194154739379883, 1.9173060655593872, 1.8711239099502563, 2.028123140335083, 2.005873918533325, 1.8863810300827026, 1.9154517650604248, 1.915488839149475, 1.967352032661438, 1.925337553024292, 1.9529752731323242, 1.9013727903366089, 1.9112077951431274, 1.9647918939590454, 2.064960479736328, 1.9943114519119263, 1.9651540517807007, 1.9854525327682495, 1.9764147996902466, 1.9943276643753052, 1.9514328241348267, 2.015962839126587, 1.970487356185913, 1.9036338329315186, 1.9417197704315186, 1.9048479795455933, 2.025618076324463, 1.8646631240844727, 1.881289005279541, 1.949367642402649, 2.0404903888702393, 1.9227917194366455, 1.9497318267822266, 1.997802734375, 1.8999719619750977, 1.9032402038574219, 2.0049567222595215, 2.027479648590088, 1.9727708101272583, 1.9534361362457275, 1.887280821800232, 1.9457398653030396, 1.9767476320266724, 1.9226438999176025, 1.8692843914031982, 1.9624667167663574, 1.8998538255691528, 1.9861626625061035, 1.9636662006378174, 2.003080129623413, 1.933213710784912, 1.8835649490356445, 1.9852420091629028, 1.9767074584960938, 2.0255725383758545, 1.9178853034973145, 1.8719159364700317, 1.9267696142196655, 1.9613157510757446, 1.9874814748764038, 1.9304896593093872, 1.8690707683563232, 2.0034024715423584, 1.9028393030166626, 1.896070957183838, 1.903882622718811, 2.0498046875, 1.9543946981430054, 1.9456257820129395, 1.9433660507202148, 1.979112982749939, 1.9573503732681274, 1.9677414894104004, 1.9558959007263184, 2.000671148300171, 1.961395263671875, 1.9690583944320679, 2.0304133892059326, 2.0344486236572266, 1.9708607196807861, 1.891694188117981, 1.8836398124694824, 2.0051474571228027, 1.9269145727157593, 1.869606852531433, 1.862574815750122, 1.902248501777649, 1.963319182395935, 1.9318534135818481, 1.949782371520996, 1.9626502990722656, 2.041734457015991, 1.9544930458068848, 1.9527885913848877, 1.9591046571731567, 2.00441312789917, 1.9218268394470215, 1.9846868515014648, 1.8630023002624512, 1.957507848739624, 1.9227261543273926, 1.9614472389221191, 1.963220238685608, 2.007046937942505, 1.9615094661712646, 2.0171287059783936, 1.9875460863113403, 1.8645695447921753, 1.9026240110397339, 1.899594783782959, 2.0079822540283203, 1.9283342361450195, 1.9462589025497437, 1.9988620281219482, 1.9587390422821045, 1.9129739999771118, 1.898231863975525, 1.9651333093643188, 1.9910463094711304, 1.951962947845459, 1.9051798582077026, 2.0259439945220947, 1.9984753131866455, 1.9604610204696655, 2.0003652572631836, 1.9572843313217163, 1.8775445222854614, 1.9789010286331177, 2.0269386768341064, 1.9543009996414185, 1.9588273763656616, 1.9678875207901, 2.0457687377929688, 1.914555311203003, 1.9701439142227173, 1.9778167009353638, 1.9762234687805176, 1.8860045671463013, 1.956857681274414, 2.0375521183013916, 1.9068764448165894, 2.0297951698303223, 1.9162282943725586, 1.928861379623413, 1.875620722770691, 2.025268077850342, 1.9922308921813965, 1.9995675086975098, 1.9412320852279663, 1.9565213918685913, 1.878356695175171, 1.9090183973312378, 1.9519695043563843, 2.0386557579040527, 1.897590160369873, 1.9520014524459839, 2.0466065406799316, 1.9112569093704224, 1.9987376928329468, 1.8749054670333862, 1.9380662441253662, 1.8570469617843628, 1.944063663482666, 1.9484081268310547, 1.9214318990707397, 1.9291585683822632, 1.9610792398452759, 1.9242528676986694, 1.992408275604248, 1.939521312713623, 2.0063929557800293, 2.078881025314331, 2.028534173965454, 1.9687031507492065, 2.0153579711914062, 1.9756428003311157, 1.9427918195724487, 1.9127678871154785, 1.89816153049469, 1.9876278638839722, 1.9408079385757446, 1.9488763809204102, 1.9655516147613525, 2.026759147644043, 2.0148978233337402, 1.9309754371643066, 2.052144765853882, 1.955602765083313, 1.994227647781372, 1.9185218811035156, 1.9487463235855103, 1.9171642065048218, 2.044757843017578, 2.0928666591644287, 1.8703700304031372, 1.9694722890853882, 2.0083494186401367, 2.0627548694610596, 1.884490728378296, 2.0943524837493896, 1.9340816736221313, 1.8959301710128784, 1.985122799873352, 2.022432804107666, 1.9367280006408691, 1.9998172521591187, 2.0326945781707764, 1.9023278951644897, 2.0286765098571777, 1.8896961212158203, 6.810316562652588, 1.9927514791488647, 1.9654756784439087, 1.9980353116989136, 1.885859489440918, 1.93870210647583, 1.9716777801513672, 1.9192676544189453, 1.9234200716018677, 1.9227511882781982, 1.9404891729354858, 1.947706937789917, 6.835872650146484, 1.9196703433990479, 2.0086891651153564, 1.8937227725982666, 1.8922793865203857, 1.9342931509017944, 2.0582640171051025, 1.8686197996139526, 1.9402295351028442, 1.9200605154037476, 2.00185489654541, 2.0380513668060303, 1.9128897190093994, 1.9330029487609863, 1.9363857507705688, 1.9328242540359497, 1.9405709505081177, 1.9042500257492065, 1.940794825553894, 1.8996634483337402, 1.9188802242279053, 1.8918700218200684, 1.9816335439682007, 1.9264886379241943, 1.8671324253082275, 1.9123433828353882, 1.9179527759552002, 1.8965150117874146, 1.9174836874008179, 1.8776706457138062, 1.8909801244735718, 1.889208436012268, 1.8964526653289795, 1.871185064315796, 1.868942379951477, 1.8970023393630981]}, {"mode": "markers", "name": "H2", "type": "scatter", "x": [9.67989730834961, 9.653935432434082, 9.578878402709961, 9.566327095031738, 8.724785804748535, 8.667468070983887, 8.667402267456055, 8.65699291229248, 8.628260612487793, 8.609914779663086, 8.60962963104248, 8.603471755981445, 8.585519790649414, 8.538091659545898, 7.7785964012146, 7.768971920013428, 7.766926288604736, 7.759719371795654, 7.745086193084717, 7.736332893371582, 7.730231761932373, 7.693756580352783, 7.6874308586120605, 7.149027347564697, 7.139162063598633, 7.137070655822754, 7.1334733963012695, 7.123015880584717, 7.117552280426025, 7.113672733306885, 7.11360502243042, 7.1133294105529785, 7.1076226234436035, 7.10302734375, 7.101675033569336, 7.099490642547607, 7.098755836486816, 7.098291397094727, 7.098193645477295, 7.0970540046691895, 7.094330310821533, 7.0868682861328125, 7.085597991943359, 7.081981182098389, 7.081240653991699, 7.080130100250244, 7.078310012817383, 7.075927734375, 7.074073791503906, 7.071203231811523, 7.067379474639893, 7.064296722412109, 7.0642409324646, 7.06393575668335, 7.063706398010254, 7.062906742095947, 7.062859535217285, 7.062402248382568, 7.062021255493164, 7.060731410980225, 7.059758186340332, 7.058681011199951, 7.053288459777832, 7.052941799163818, 7.05208158493042, 7.0518317222595215, 7.050673007965088, 7.048627853393555, 7.047757625579834, 7.0472893714904785, 7.0467729568481445, 7.040375232696533, 7.036504745483398, 7.032804489135742, 7.032416343688965, 7.030958652496338, 7.030174255371094, 7.0300211906433105, 7.027872562408447, 7.026447296142578, 7.025003910064697, 7.022966384887695, 7.020747661590576, 7.020392417907715, 7.019149303436279, 7.0120344161987305, 7.011538505554199, 7.008101463317871, 7.00688362121582, 7.0063300132751465, 7.002497673034668, 7.000717639923096, 6.996818542480469, 6.996774196624756, 6.9948577880859375, 6.985843658447266, 6.9857869148254395, 6.982847690582275, 6.982656002044678, 6.982548236846924, 6.981887340545654, 6.980452060699463, 6.975037574768066, 6.974828243255615, 6.97405481338501, 6.972969055175781, 6.972384929656982, 6.970651626586914, 6.9703521728515625, 6.967916011810303, 6.965696811676025, 6.9589996337890625, 6.949939250946045, 6.948276042938232, 6.942196369171143, 6.942041873931885, 6.941532135009766, 6.938926696777344, 6.935678005218506, 6.935030460357666, 6.934818267822266, 6.933112144470215, 6.9323601722717285, 6.930782794952393, 6.92754602432251, 6.92753791809082, 6.926577091217041, 6.923527240753174, 6.922946453094482, 6.921924114227295, 6.921755313873291, 6.9175801277160645, 6.916916370391846, 6.9166717529296875, 6.9060187339782715, 6.903824329376221, 6.901196479797363, 6.900262355804443, 6.896960735321045, 6.896061897277832, 6.893523216247559, 6.8702006340026855, 6.866968631744385, 6.865066051483154, 6.864924430847168, 6.861423969268799, 6.855584144592285, 6.850571632385254, 6.841013431549072, 6.832054138183594, 2.1065194606781006], "y": [9.682775497436523, 9.657427787780762, 9.613821029663086, 9.603484153747559, 8.733183860778809, 8.690312385559082, 8.670076370239258, 8.671883583068848, 8.663405418395996, 8.613494873046875, 8.624147415161133, 8.652063369750977, 8.622091293334961, 8.574305534362793, 7.782042503356934, 7.79323673248291, 7.806046962738037, 7.782932758331299, 7.753302097320557, 7.742067813873291, 7.777401447296143, 7.768012046813965, 7.72854471206665, 7.1703200340271, 7.163631916046143, 7.190540790557861, 7.196291446685791, 7.13627290725708, 7.273573398590088, 7.135104179382324, 7.184525012969971, 7.1500701904296875, 7.760807514190674, 7.139054298400879, 7.119227886199951, 7.188945293426514, 7.198376655578613, 7.123384952545166, 7.110061168670654, 7.184540748596191, 7.131819248199463, 7.281177520751953, 7.110462188720703, 7.144380569458008, 7.190329551696777, 7.189395427703857, 7.192080974578857, 7.145964622497559, 7.130940914154053, 7.072055339813232, 7.081461429595947, 7.2236647605896, 7.193512439727783, 7.097668647766113, 7.073622226715088, 7.7164530754089355, 7.264068126678467, 7.194616317749023, 7.802278995513916, 7.160061836242676, 7.147716045379639, 7.129836559295654, 7.136184215545654, 7.202861309051514, 7.176682472229004, 7.112285137176514, 7.702097415924072, 7.108051776885986, 7.1010003089904785, 7.1287312507629395, 7.08267068862915, 7.051919937133789, 7.128468036651611, 7.158873081207275, 7.047117233276367, 7.152756690979004, 7.1923322677612305, 7.11245584487915, 7.032839298248291, 7.091269016265869, 7.6559295654296875, 7.192729949951172, 7.091391563415527, 7.714758396148682, 7.075789451599121, 7.068957328796387, 7.725846290588379, 7.763606548309326, 7.133296489715576, 7.193542003631592, 7.160408020019531, 7.660533428192139, 7.021306037902832, 7.229384422302246, 7.092702865600586, 7.13424825668335, 7.003127098083496, 7.057575225830078, 7.146531581878662, 7.689228534698486, 7.099477291107178, 7.113735198974609, 7.653110504150391, 7.1155195236206055, 7.0229058265686035, 7.1320929527282715, 7.023181438446045, 7.109952449798584, 7.04789924621582, 6.9875078201293945, 7.693490505218506, 7.075266361236572, 7.113692283630371, 7.024809837341309, 7.024506092071533, 6.983134746551514, 7.723356246948242, 7.139293193817139, 6.9654364585876465, 7.1653947830200195, 7.024390697479248, 7.102146625518799, 6.950123310089111, 7.648045539855957, 7.6448516845703125, 7.013289451599121, 6.967655181884766, 7.109533786773682, 7.02895450592041, 7.770742893218994, 7.0337042808532715, 7.04416561126709, 7.016138076782227, 7.756343841552734, 10.328568458557129, 7.738454341888428, 6.9750189781188965, 7.185208797454834, 7.1572265625, 7.002466678619385, 6.928437232971191, 7.120316028594971, 6.884897708892822, 7.851163387298584, 6.9394941329956055, 7.168519496917725, 7.223349571228027, 7.191019535064697, 6.947630882263184, 7.0264153480529785, 7.853947162628174]}],
                            {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 11.361425304412842], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 11.361425304412842], "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('9a1f0c9d-3ad7-4473-aec0-801aac5dc2ba');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


Conclusion
----------

As you can see from the persistence diagrams, all the Betti numbers were
found. Some other persistent generators are also appearing, depending on
how dense the sampling is and how much noise there is.

For example, we see a rather neat persistence diagram over the Klein
bottle (we see two persistent generators for :math:`H_1` and one
persistent generator for :math:`H_2`). Notice that all these homology
groups are computed over the field :math:`\mathbb{F}_2`.
